# coding: utf8
from __future__ import unicode_literals


LOOKUP = {
    "A-bombens": "A-bomb",
    "A-bomberna": "A-bomb",
    "A-bombers": "A-bomb",
    "A-ets": "A",
    "A-n": "A",
    "A-na": "A",
    "A-ns": "A",
    "A-stjärnans": "A-stjärnan",
    "A-t": "A",
    "A-vitaminbristen": "A-vitaminbrist",
    "A-vitaminbristens": "A-vitaminbrist",
    "A-vitaminbrister": "A-vitaminbrist",
    "A-vitaminbristerna": "A-vitaminbrist",
    "A-vitaminbristernas": "A-vitaminbrist",
    "A-vitaminbristers": "A-vitaminbrist",
    "A-vitaminbrists": "A-vitaminbrist",
    "A-vitaminer": "A-vitamin",
    "A-vitaminerna": "A-vitamin",
    "A-vitaminernas": "A-vitamin",
    "A-vitaminers": "A-vitamin",
    "A-vitaminet": "A-vitamin",
    "A-vitaminets": "A-vitamin",
    "A-vitamins": "A-vitamin",
    "A3:s": "A3",
    "A4:s": "A4",
    "A4s": "A4",
    "A5:s": "A5",
    "A5s": "A5",
    "A:et": "﻿A",
    "A:n": "A",
    "A:nas": "A",
    "A:t": "A",
    "AB-s": "AB",
    "AB:s": "AB",
    "ABF-s": "ABF",
    "ABF:s": "ABF",
    "ABFs": "ABF",
    "ABs": "AB",
    "ADHD-symtomen": "ADHD-symtom",
    "ADHD-symtomet": "ADHD-symtom",
    "ADHD-symtoms": "ADHD-symtom",
    "ADHD:s": "ADHD",
    "AIDSens": "AIDS",
    "ALS:s": "ALS",
    "ASEA-s": "ASEA",
    "ASEA:s": "ASEA",
    "ASEAs": "ASEA",
    "AT-läkar": "AT-läkare",
    "AT-läkaren": "AT-läkare",
    "AT-läkarens": "AT-läkare",
    "AT-läkares": "AT-läkare",
    "AT-läkarna": "AT-läkare",
    "AT-läkarnas": "AT-läkare",
    "ATP-n": "ATP",
    "ATP-na": "ATP",
    "ATP-nas": "ATP",
    "ATP-ns": "ATP",
    "ATP-s": "ATP",
    "ATP:n": "ATP",
    "ATP:na": "ATP",
    "ATP:nas": "ATP",
    "ATP:ns": "ATP",
    "ATP:s": "ATP",
    "ATPn": "ATP",
    "ATPna": "ATP",
    "ATPnas": "ATP",
    "ATPns": "ATP",
    "ATPs": "ATP",
    "ATs": "AT",
    "Aaltos": "Aalto",
    "Aars": "Aar",
    "Abbas": "Abba",
    "Abessiniens": "Abessinien",
    "Abrahams": "Abraham",
    "Abélards": "Abélard",
    "Ac-s": "Ac",
    "Ac:s": "Ac",
    "Acs": "Ac",
    "Adamar": "Adam",
    "Adamarna": "Adam",
    "Adamarnas": "Adam",
    "Adamars": "Adam",
    "Adams": "Adam",
    "Adens": "Aden",
    "Adlers": "Adler",
    "Adolfar": "Adolf",
    "Adolfarna": "Adolf",
    "Adolfarnas": "Adolf",
    "Adolfars": "Adolf",
    "Adolfs": "Adolf",
    "Adrians": "Adrian",
    "Afganistans": "Afganistan",
    "Afghanistaninsatsen": "Afghanistaninsats",
    "Afghanistaninsatsens": "Afghanistaninsats",
    "Afghanistans": "Afghanistan",
    "Afghanistantruppen": "Afghanistantrupp",
    "Afghanistantruppens": "Afghanistantrupp",
    "Afghanistantrupper": "Afghanistantrupp",
    "Afghanistantrupperna": "Afghanistantrupp",
    "Afghanistantruppernas": "Afghanistantrupp",
    "Afghanistantruppers": "Afghanistantrupp",
    "Afghanistantrupps": "Afghanistantrupp",
    "Afrikainstitutets": "Afrikainstitutet",
    "Afrikas": "Afrika",
    "Aftonbladets": "Aftonbladet",
    "Ag-s": "Ag",
    "Ag:s": "Ag",
    "Agatons": "Agaton",
    "Ags": "Ag",
    "Aidas": "Aida",
    "Aktuellts": "Aktuellt",
    "Al-s": "Al",
    "Al:s": "Al",
    "Alabamas": "Alabama",
    "Aladdins": "Aladdin",
    "Alaskas": "Alaska",
    "Albaniens": "Albanien",
    "Albanys": "Albany",
    "Albertar": "Albert",
    "Albertarna": "Albert",
    "Albertarnas": "Albert",
    "Albertars": "Albert",
    "Albertas": "Alberta",
    "Alberts": "Albert",
    "Albinar": "Albin",
    "Albinarna": "Albin",
    "Albinarnas": "Albin",
    "Albinars": "Albin",
    "Albins": "Albin",
    "Albuquerques": "Albuquerque",
    "Alenan": "Alena",
    "Alenans": "Alena",
    "Alenas": "Alena",
    "Alenor": "Alena",
    "Alenorna": "Alena",
    "Alenornas": "Alena",
    "Alenors": "Alena",
    "Alexanderhuggen": "Alexanderhugg",
    "Alexanderhuggens": "Alexanderhugg",
    "Alexanderhugget": "Alexanderhugg",
    "Alexanderhuggs": "Alexanderhugg",
    "Alexanders": "Alexander",
    "Alexandrias": "Alexandria",
    "Alfapetet": "Alfapet",
    "Alfar": "Alf",
    "Alfarna": "Alf",
    "Alfarnas": "Alf",
    "Alfars": "Alf",
    "Alfredar": "Alfred",
    "Alfredarna": "Alfred",
    "Alfredarnas": "Alfred",
    "Alfredars": "Alfred",
    "Alfreds": "Alfred",
    "Alfredssonen": "Alfredsson",
    "Alfredssonens": "Alfredsson",
    "Alfredssons": "Alfredsson",
    "Alfredssöner": "Alfredsson",
    "Alfredssönerna": "Alfredsson",
    "Alfredssönernas": "Alfredsson",
    "Alfredssöners": "Alfredsson",
    "Alfs": "Alf",
    "Algeriets": "Algeriet",
    "Algers": "Alger",
    "Algols": "Algol",
    "Algolstjärnans": "Algolstjärnan",
    "Algolsystemets": "Algolsystemet",
    "Alhambras": "Alhambra",
    "Alicantes": "Alicante",
    "Alices": "Alice",
    "Allans": "Allan",
    "Almqvists": "Almqvist",
    "Alpernas": "Alperna",
    "Alvan": "Alva",
    "Alvans": "Alva",
    "Alvas": "Alva",
    "Alvings": "Alving",
    "Alvor": "Alva",
    "Alvorna": "Alva",
    "Alvornas": "Alva",
    "Alvors": "Alva",
    "Am-s": "Am",
    "Am:s": "Am",
    "Amazonflodens": "Amazonfloden",
    "Ambios": "Ambio",
    "Amelings": "Ameling",
    "Amerikas": "Amerika",
    "Ammans": "Amman",
    "Amnestys": "Amnesty",
    "Amors": "Amor",
    "Ams": "Am",
    "Amsterdams": "Amsterdam",
    "Amundsens": "Amundsen",
    "Anastasian": "Anastasia",
    "Anastasians": "Anastasia",
    "Anastasias": "Anastasia",
    "Anastasior": "Anastasia",
    "Anastasiorna": "Anastasia",
    "Anastasiornas": "Anastasia",
    "Anastasiors": "Anastasia",
    "Anatoles": "Anatole",
    "Anchorages": "Anchorage",
    "Anderbergs": "Anderberg",
    "Andernas": "Anderna",
    "Andersar": "Anders",
    "Andersarna": "Anders",
    "Andersarnas": "Anders",
    "Andersars": "Anders",
    "Andersens": "Andersen",
    "Andersonen": "Anderson",
    "Andersonens": "Anderson",
    "Andersons": "Anderson",
    "Anderssonen": "Andersson",
    "Anderssonens": "Andersson",
    "Anderssons": "Andersson",
    "Anderssöner": "Andersson",
    "Anderssönerna": "Andersson",
    "Anderssönernas": "Andersson",
    "Anderssöners": "Andersson",
    "Andersöner": "Anderson",
    "Andersönerna": "Anderson",
    "Andersönernas": "Anderson",
    "Andersöners": "Anderson",
    "Andorras": "Andorra",
    "Andrics": "Andric",
    "Andromedas": "Andromeda",
    "Andrés": "André",
    "Angolas": "Angola",
    "Aniaras": "Aniara",
    "Anitan": "Anita",
    "Anitans": "Anita",
    "Anitas": "Anita",
    "Anitor": "Anita",
    "Anitorna": "Anita",
    "Anitornas": "Anita",
    "Anitors": "Anita",
    "Ankaras": "Ankara",
    "Annan": "Anna",
    "Annans": "Anna",
    "Annas": "Anna",
    "Anne-Sophies": "Anne-Sophie",
    "Annelieses": "Anneliese",
    "Annelis": "Anneli",
    "Annes": "Anne",
    "Annor": "Anna",
    "Annorna": "Anna",
    "Annornas": "Anna",
    "Annors": "Anna",
    "Anouilhs": "Anouilh",
    "Ansgars": "Ansgar",
    "Antarktisfördragen": "Antarktisfördrag",
    "Antarktisfördragens": "Antarktisfördrag",
    "Antarktisfördraget": "Antarktisfördrag",
    "Antarktisfördragets": "Antarktisfördrag",
    "Antarktisfördrags": "Antarktisfördrag",
    "Antarktisprojekten": "Antarktisprojekt",
    "Antarktisprojektens": "Antarktisprojekt",
    "Antarktisprojektet": "Antarktisprojekt",
    "Antarktisprojektets": "Antarktisprojekt",
    "Antarktisprojekts": "Antarktisprojekt",
    "Anthonys": "Anthony",
    "Antiguas": "Antigua",
    "Antikrists": "Antikrist",
    "Antillernas": "Antillerna",
    "Antonar": "Anton",
    "Antonarna": "Anton",
    "Antonarnas": "Anton",
    "Antonars": "Anton",
    "Antonionis": "Antonioni",
    "Antons": "Anton",
    "Apollons": "Apollon",
    "Apolloprogrammen": "Apolloprogram",
    "Apolloprogrammens": "Apolloprogram",
    "Apolloprogrammet": "Apolloprogram",
    "Apolloprogrammets": "Apolloprogram",
    "Apolloprograms": "Apolloprogram",
    "Ar-s": "Ar",
    "Ar:s": "Ar",
    "Arabiens": "Arabien",
    "Arafats": "Arafat",
    "Archangelsks": "Archangelsk",
    "Argentinas": "Argentina",
    "Argos": "Argo",
    "Arianeraketen": "Arianeraket",
    "Arianeraketens": "Arianeraket",
    "Arianeraketer": "Arianeraket",
    "Arianeraketerna": "Arianeraket",
    "Arianeraketernas": "Arianeraket",
    "Arianeraketers": "Arianeraket",
    "Arianerakets": "Arianeraket",
    "Ariels": "Ariel",
    "Arizonas": "Arizona",
    "Arlandas": "Arlanda",
    "Armeniens": "Armenien",
    "Armstrongs": "Armstrong",
    "Arnar": "Arne",
    "Arnarna": "Arne",
    "Arnarnas": "Arne",
    "Arnars": "Arne",
    "Arndts": "Arndt",
    "Arnes": "Arne",
    "Aronssonen": "Aronsson",
    "Aronssonens": "Aronsson",
    "Aronssons": "Aronsson",
    "Aronssöner": "Aronsson",
    "Aronssönerna": "Aronsson",
    "Aronssönernas": "Aronsson",
    "Aronssöners": "Aronsson",
    "Arraus": "Arrau",
    "Arthurs": "Arthur",
    "Arturar": "Artur",
    "Arturarna": "Artur",
    "Arturarnas": "Artur",
    "Arturars": "Artur",
    "Arturs": "Artur",
    "Arvidar": "Arvid",
    "Arvidarna": "Arvid",
    "Arvidarnas": "Arvid",
    "Arvidars": "Arvid",
    "Arvids": "Arvid",
    "As-s": "As",
    "As:s": "As",
    "Aschans": "Aschan",
    "Asien-rundresan": "Asien-rundresa",
    "Asien-rundresans": "Asien-rundresa",
    "Asien-rundresas": "Asien-rundresa",
    "Asien-rundrese": "Asien-rundresa",
    "Asien-rundresor": "Asien-rundresa",
    "Asien-rundresorna": "Asien-rundresa",
    "Asien-rundresornas": "Asien-rundresa",
    "Asien-rundresors": "Asien-rundresa",
    "Asiens": "Asien",
    "Asks": "Ask",
    "Askungens": "Askungen",
    "Aspenströms": "Aspenström",
    "Asplunds": "Asplund",
    "Ass": "As",
    "Assyriens": "Assyrien",
    "Astrachans": "Astrachan",
    "Astrids": "Astrid",
    "At-s": "At",
    "At:s": "At",
    "Atatürks": "Atatürk",
    "Athenas": "Athena",
    "Athens": "Athen",
    "Atlantas": "Atlanta",
    "Atlantens": "Atlanten",
    "Atlantpaktens": "Atlantpakten",
    "Atlasbergens": "Atlasbergen",
    "Atomenergis": "Atomenergi",
    "Atterboms": "Atterbom",
    "Atterdags": "Atterdag",
    "Aténs": "Atén",
    "Au-s": "Au",
    "Au:s": "Au",
    "Audens": "Auden",
    "Audhumblas": "Audhumbla",
    "Audis": "Audi",
    "Augustar": "August",
    "Augustarna": "August",
    "Augustarnas": "August",
    "Augustars": "August",
    "Augustas": "Augusta",
    "Augustprisets": "Augustpriset",
    "Augusts": "August",
    "Aurells": "Aurell",
    "Aus": "Au",
    "Austins": "Austin",
    "Australiens": "Australien",
    "Aventinens": "Aventinen",
    "Avestas": "Avesta",
    "Avicennas": "Avicenna",
    "B-s": "B",
    "B-vitaminbristen": "B-vitaminbrist",
    "B-vitaminbristens": "B-vitaminbrist",
    "B-vitaminbrister": "B-vitaminbrist",
    "B-vitaminbristerna": "B-vitaminbrist",
    "B-vitaminbristernas": "B-vitaminbrist",
    "B-vitaminbristers": "B-vitaminbrist",
    "B-vitaminbrists": "B-vitaminbrist",
    "B-vitaminer": "B-vitamin",
    "B-vitaminerna": "B-vitamin",
    "B-vitaminernas": "B-vitamin",
    "B-vitaminers": "B-vitamin",
    "B-vitaminet": "B-vitamin",
    "B-vitaminets": "B-vitamin",
    "B-vitamins": "B-vitamin",
    "BBC-s": "BBC",
    "BBC:s": "BBC",
    "BBCs": "BBC",
    "BNP-n": "BNP",
    "BNP-na": "BNP",
    "BNP-nas": "BNP",
    "BNP-ns": "BNP",
    "BNP-s": "BNP",
    "BNP-tillväxten": "BNP-tillväxt",
    "BNP-tillväxtens": "BNP-tillväxt",
    "BNP-tillväxts": "BNP-tillväxt",
    "BNP:n": "BNP",
    "BNP:na": "BNP",
    "BNP:nas": "BNP",
    "BNP:ns": "BNP",
    "BNP:s": "BNP",
    "BNPn": "BNP",
    "BNPna": "BNP",
    "BNPnas": "BNP",
    "BNPns": "BNP",
    "BNPs": "BNP",
    "BP-s": "BP",
    "BP:s": "BP",
    "BPs": "BP",
    "Ba-s": "Ba",
    "Ba:s": "Ba",
    "Babbitts": "Babbitt",
    "Babels": "Babel",
    "Babyloniens": "Babylonien",
    "Babylons": "Babylon",
    "Bachs": "Bach",
    "Baden-Badens": "Baden-Baden",
    "Baden-Powells": "Baden-Powell",
    "Bagdads": "Bagdad",
    "Bahrains": "Bahrain",
    "Bahreins": "Bahrein",
    "Bakunins": "Bakunin",
    "Balders": "Balder",
    "Balkans": "Balkan",
    "Ballestreros": "Ballestrero",
    "Balmains": "Balmain",
    "Baltikums": "Baltikum",
    "Baltimores": "Baltimore",
    "Baltzars": "Baltzar",
    "Balzacs": "Balzac",
    "Bambaras": "Bambara",
    "Bamses": "Bamse",
    "Bangkoks": "Bangkok",
    "Bangladeshs": "Bangladesh",
    "Bantams": "Bantam",
    "Baptistar": "Baptiste",
    "Baptistarna": "Baptiste",
    "Baptistarnas": "Baptiste",
    "Baptistars": "Baptiste",
    "Baptistes": "Baptiste",
    "Barbaran": "Barbara",
    "Barbarans": "Barbara",
    "Barbaras": "Barbara",
    "Barbaror": "Barbara",
    "Barbarorna": "Barbara",
    "Barbarornas": "Barbara",
    "Barbarors": "Barbara",
    "Barbros": "Barbro",
    "Barcelonas": "Barcelona",
    "Barkas": "Barka",
    "Barnards": "Barnard",
    "Barrows": "Barrow",
    "Barrys": "Barry",
    "Barsebäcks": "Barsebäck",
    "Barths": "Barth",
    "Bartoks": "Bartok",
    "Bas": "Ba",
    "Basels": "Basel",
    "Baskiens": "Baskien",
    "Bastiljens": "Bastiljen",
    "Baudelaires": "Baudelaire",
    "Bayerns": "Bayern",
    "Bayreuths": "Bayreuth",
    "Be-s": "Be",
    "Be:s": "Be",
    "Beatrices": "Beatrice",
    "Bechuanalands": "Bechuanaland",
    "Becketts": "Beckett",
    "Beethovens": "Beethoven",
    "Beethovensonaten": "Beethovensonat",
    "Beethovensonatens": "Beethovensonat",
    "Beethovensonater": "Beethovensonat",
    "Beethovensonaterna": "Beethovensonat",
    "Beethovensonaternas": "Beethovensonat",
    "Beethovensonaters": "Beethovensonat",
    "Beethovensonats": "Beethovensonat",
    "Beiras": "Beira",
    "Beiruts": "Beirut",
    "Bejerots": "Bejerot",
    "Bekännelsers": "Bekännelser",
    "Belfasts": "Belfast",
    "Belgiens": "Belgien",
    "Belgrads": "Belgrad",
    "Belizes": "Belize",
    "Bellas": "Bella",
    "Bellmans": "Bellman",
    "Bells": "Bell",
    "Beltrans": "Beltran",
    "Ben-Gurions": "Ben-Gurion",
    "Benders": "Bender",
    "Bengalens": "Bengalen",
    "Bengtar": "Bengt",
    "Bengtarna": "Bengt",
    "Bengtarnas": "Bengt",
    "Bengtars": "Bengt",
    "Bengts": "Bengt",
    "Bengtssonen": "Bengtsson",
    "Bengtssonens": "Bengtsson",
    "Bengtssons": "Bengtsson",
    "Bengtssöner": "Bengtsson",
    "Bengtssönerna": "Bengtsson",
    "Bengtssönernas": "Bengtsson",
    "Bengtssöners": "Bengtsson",
    "Benidorms": "Benidorm",
    "Benins": "Benin",
    "Bennys": "Benny",
    "Bens": "Ben",
    "Bensonen": "Benson",
    "Bensonens": "Benson",
    "Bensons": "Benson",
    "Bensöner": "Benson",
    "Bensönerna": "Benson",
    "Bensönernas": "Benson",
    "Bensöners": "Benson",
    "Berganzas": "Berganza",
    "Bergens": "Bergen",
    "Berggrens": "Berggren",
    "Berglunds": "Berglund",
    "Bergmans": "Bergman",
    "Bergs": "Berg",
    "Bergspredikans": "Bergspredikan",
    "Bergströms": "Bergström",
    "Berits": "Berit",
    "Berkeleys": "Berkeley",
    "Berlinmurar": "Berlinmur",
    "Berlinmurarna": "Berlinmur",
    "Berlinmurarnas": "Berlinmur",
    "Berlinmurars": "Berlinmur",
    "Berlinmuren": "Berlinmur",
    "Berlinmurens": "Berlinmur",
    "Berlinmurs": "Berlinmur",
    "Berlins": "Berlin",
    "Berlusconis": "Berlusconi",
    "Bernadottes": "Bernadotte",
    "Bernards": "Bernard",
    "Berndtar": "Berndt",
    "Berndtarna": "Berndt",
    "Berndtarnas": "Berndt",
    "Berndtars": "Berndt",
    "Berndts": "Berndt",
    "Bernhards": "Bernhard",
    "Berns": "Bern",
    "Bertan": "Berta",
    "Bertans": "Berta",
    "Bertas": "Berta",
    "Bertells": "Bertell",
    "Bertilar": "Bertil",
    "Bertilarna": "Bertil",
    "Bertilarnas": "Bertil",
    "Bertilars": "Bertil",
    "Bertils": "Bertil",
    "Bertor": "Berta",
    "Bertorna": "Berta",
    "Bertornas": "Berta",
    "Bertors": "Berta",
    "Berwalds": "Berwald",
    "Bes": "Be",
    "Beskows": "Beskow",
    "Bessies": "Bessie",
    "Betlehems": "Betlehem",
    "Bettys": "Betty",
    "Bhutans": "Bhutan",
    "Bi-s": "Bi",
    "Bi:s": "Bi",
    "Bibelns": "Bibeln",
    "Billingens": "Billingen",
    "Billys": "Billy",
    "Birgerar": "Birger",
    "Birgerarna": "Birger",
    "Birgerarnas": "Birger",
    "Birgerars": "Birger",
    "Birgers": "Birger",
    "Birgits": "Birgit",
    "Birgittan": "Birgitta",
    "Birgittans": "Birgitta",
    "Birgittas": "Birgitta",
    "Birgittor": "Birgitta",
    "Birgittorna": "Birgitta",
    "Birgittornas": "Birgitta",
    "Birgittors": "Birgitta",
    "Birminghams": "Birmingham",
    "Bis": "Bi",
    "Bismarcks": "Bismarck",
    "Bizets": "Bizet",
    "Bjuggrens": "Bjuggren",
    "Björcks": "Björck",
    "Björkmans": "Björkman",
    "Björlings": "Björling",
    "Björnbergs": "Björnberg",
    "Björnsons": "Björnson",
    "Björnvaktarens": "Björnvaktaren",
    "Bk-s": "Bk",
    "Bk:s": "Bk",
    "Bks": "Bk",
    "Blairs": "Blair",
    "Blakes": "Blake",
    "Blancks": "Blanck",
    "Blekinges": "Blekinge",
    "Blends": "Blend",
    "Blombergs": "Blomberg",
    "Blomdahls": "Blomdahl",
    "Blomstedts": "Blomstedt",
    "Boccaccios": "Boccaccio",
    "Bocellis": "Bocelli",
    "Bockstensmannens": "Bockstensmannen",
    "Bodagrottornas": "Bodagrottorna",
    "Bodarnas": "Bodarna",
    "Bogarts": "Bogart",
    "Bogotas": "Bogota",
    "Bogotás": "Bogotá",
    "Bohrs": "Bohr",
    "Bohusläns": "Bohuslän",
    "Bohèmes": "Bohème",
    "Boises": "Boise",
    "Bolivias": "Bolivia",
    "Bollar": "Bolle",
    "Bollarna": "Bolle",
    "Bollarnas": "Bolle",
    "Bollars": "Bolle",
    "Bolles": "Bolle",
    "Bollywoods": "Bollywood",
    "Bolognas": "Bologna",
    "Bondeförbundets": "Bondeförbundet",
    "Bondeviks": "Bondevik",
    "Bonns": "Bonn",
    "Borbas": "Borba",
    "Bores": "Bore",
    "Borgenstiernas": "Borgenstierna",
    "Borins": "Borin",
    "Borisar": "Boris",
    "Borisarna": "Boris",
    "Borisarnas": "Boris",
    "Borisars": "Boris",
    "Borlänges": "Borlänge",
    "Borneos": "Borneo",
    "Bosniens": "Bosnien",
    "Bossar": "Bosse",
    "Bossards": "Bossard",
    "Bossarna": "Bosse",
    "Bossarnas": "Bosse",
    "Bossars": "Bosse",
    "Bosses": "Bosse",
    "Bostons": "Boston",
    "Botswanas": "Botswana",
    "Bottenhavets": "Bottenhavet",
    "Bottenvikens": "Bottenviken",
    "Boumediennes": "Boumedienne",
    "Bourgibas": "Bourgiba",
    "Bouvetöns": "Bouvetön",
    "Br-s": "Br",
    "Br:s": "Br",
    "Brages": "Brage",
    "Brahes": "Brahe",
    "Brailles": "Braille",
    "Brambecks": "Brambeck",
    "Brandklipparens": "Brandklipparen",
    "Brandons": "Brandon",
    "Brandts": "Brandt",
    "Brantings": "Branting",
    "Brasilias": "Brasilia",
    "Brasiliens": "Brasilien",
    "Bratislavas": "Bratislava",
    "Brattelis": "Bratteli",
    "Bratts": "Bratt",
    "Brauns": "Braun",
    "Brazzavilles": "Brazzaville",
    "Brechts": "Brecht",
    "Brehms": "Brehm",
    "Bretagnes": "Bretagne",
    "Brezjnevs": "Brezjnev",
    "Bridgeports": "Bridgeport",
    "Bristols": "Bristol",
    "Bristoltraktens": "Bristoltrakten",
    "Britan": "Brita",
    "Britanniens": "Britannien",
    "Britans": "Brita",
    "Britas": "Brita",
    "Britor": "Brita",
    "Britorna": "Brita",
    "Britornas": "Brita",
    "Britors": "Brita",
    "Brochs": "Broch",
    "Brolins": "Brolin",
    "Bromelians": "Bromelia",
    "Bromelior": "Bromelia",
    "Bromeliornas": "Bromelia",
    "Brommamamman": "Brommamamma",
    "Brommamammans": "Brommamamma",
    "Brommamammas": "Brommamamma",
    "Brommamamme": "Brommamamma",
    "Brommamammor": "Brommamamma",
    "Brommamammorna": "Brommamamma",
    "Brommamammornas": "Brommamamma",
    "Brommamammors": "Brommamamma",
    "Brommas": "Bromma",
    "Brooks": "Brook",
    "Broströms": "Broström",
    "Brs": "Br",
    "Brubecks": "Brubeck",
    "Brueghels": "Brueghel",
    "Bruneis": "Brunei",
    "Brunos": "Bruno",
    "Bryssels": "Bryssel",
    "Brändströms": "Brändström",
    "Brückners": "Brückner",
    "Bs": "B",
    "Budapests": "Budapest",
    "Bukarests": "Bukarest",
    "Bulatovics": "Bulatovic",
    "Bulgakovs": "Bulgakov",
    "Bulgariens": "Bulgarien",
    "Bulltoftas": "Bulltofta",
    "Bulow-Hubes": "Bulow-Hube",
    "Bunins": "Bunin",
    "Bunyans": "Bunyan",
    "Burlingtons": "Burlington",
    "Burmas": "Burma",
    "Burundis": "Burundi",
    "Bushs": "Bush",
    "Busters": "Buster",
    "Butterfields": "Butterfield",
    "Buñuels": "Buñuel",
    "Byrons": "Byron",
    "Böhmens": "Böhmen",
    "Börjar": "Börje",
    "Börjarna": "Börje",
    "Börjarnas": "Börje",
    "Börjars": "Börje",
    "Börjes": "Börje",
    "Bööks": "Böök",
    "C-duren": "C-dur",
    "C-durens": "C-dur",
    "C-durs": "C-dur",
    "C-durskal": "C-durskala",
    "C-durskalan": "C-durskala",
    "C-durskalans": "C-durskala",
    "C-durskalas": "C-durskala",
    "C-durskale": "C-durskala",
    "C-durskalor": "C-durskala",
    "C-durskalorna": "C-durskala",
    "C-durskalornas": "C-durskala",
    "C-durskalors": "C-durskala",
    "C-durskals": "C-durskala",
    "C-vitaminer": "C-vitamin",
    "C-vitaminerna": "C-vitamin",
    "C-vitaminernas": "C-vitamin",
    "C-vitaminers": "C-vitamin",
    "C-vitaminet": "C-vitamin",
    "C-vitaminets": "C-vitamin",
    "C-vitamins": "C-vitamin",
    "C14-metoden": "C14-metod",
    "C14-metodens": "C14-metod",
    "C14-metods": "C14-metod",
    "C14-s": "C14",
    "C14:s": "C14",
    "C14s": "C14",
    "CD-ROM-en": "CD-ROM",
    "CD-ROM-ens": "CD-ROM",
    "CD-ROM-et": "CD-ROM",
    "CD-ROM-ets": "CD-ROM",
    "CD-ROM-na": "CD-ROM",
    "CD-ROM-nas": "CD-ROM",
    "CD-ROM-s": "CD-ROM",
    "CD-ROM:en": "CD-ROM",
    "CD-ROM:ens": "CD-ROM",
    "CD-ROM:et": "CD-ROM",
    "CD-ROM:ets": "CD-ROM",
    "CD-ROM:na": "CD-ROM",
    "CD-ROM:nas": "CD-ROM",
    "CD-ROM:s": "CD-ROM",
    "CD-ROMen": "CD-ROM",
    "CD-ROMens": "CD-ROM",
    "CD-ROMet": "CD-ROM",
    "CD-ROMets": "CD-ROM",
    "CD-ROMna": "CD-ROM",
    "CD-ROMnas": "CD-ROM",
    "CD-ROMs": "CD-ROM",
    "CD-spelar": "CD-spelare",
    "CD-spelaren": "CD-spelare",
    "CD-spelares": "CD-spelare",
    "CD-spelarnas": "CD-spelare",
    "CD:ar": "CD",
    "CD:arna": "CD",
    "CD:er": "CD",
    "CD:ernas": "CD",
    "CD:n": "CD",
    "CD:s": "CD",
    "CDarna": "CD",
    "CDer": "CD",
    "CDernas": "CD",
    "CDn": "CD",
    "CERN-s": "CERN",
    "CERN:s": "CERN",
    "CERNs": "CERN",
    "CIA-s": "CIA",
    "CIA:s": "CIA",
    "CIAs": "CIA",
    "CO2-s": "CO2",
    "CO2:s": "CO2",
    "CO2s": "CO2",
    "CP-skadads": "CP-skadad",
    "CP-skadats": "CP-skadad",
    "Ca-s": "Ca",
    "Ca:s": "Ca",
    "CaCO3-s": "CaCO3",
    "CaCO3:s": "CaCO3",
    "CaCO3s": "CaCO3",
    "CaSO4-s": "CaSO4",
    "CaSO4:s": "CaSO4",
    "CaSO4s": "CaSO4",
    "CaSiO3-s": "CaSiO3",
    "CaSiO3:s": "CaSiO3",
    "CaSiO3s": "CaSiO3",
    "Cabotos": "Caboto",
    "Cabots": "Cabot",
    "Caeres": "Caere",
    "Caesars": "Caesar",
    "Cages": "Cage",
    "Cajsan": "Cajsa",
    "Cajsans": "Cajsa",
    "Cajsas": "Cajsa",
    "Cajsor": "Cajsa",
    "Cajsorna": "Cajsa",
    "Cajsornas": "Cajsa",
    "Cajsors": "Cajsa",
    "Caligulas": "Caligula",
    "Callistos": "Callisto",
    "Calvinols": "Calvinol",
    "Calvins": "Calvin",
    "Cambodjas": "Cambodja",
    "Camels": "Camel",
    "Camillos": "Camillo",
    "Canadas": "Canada",
    "Canberras": "Canberra",
    "Candides": "Candide",
    "Cantors": "Cantor",
    "Capeks": "Capek",
    "Capellas": "Capella",
    "Capitoliums": "Capitolium",
    "Caravelles": "Caravelle",
    "Cardins": "Cardin",
    "Carl-Axels": "Carl-Axel",
    "Carlar": "Carl",
    "Carlarna": "Carl",
    "Carlarnas": "Carl",
    "Carlars": "Carl",
    "Carlos": "Carlo",
    "Carls": "Carl",
    "Carlsonen": "Carlson",
    "Carlsonens": "Carlson",
    "Carlsons": "Carlson",
    "Carlssonen": "Carlsson",
    "Carlssonens": "Carlsson",
    "Carlssons": "Carlsson",
    "Carlssöner": "Carlsson",
    "Carlssönerna": "Carlsson",
    "Carlssönernas": "Carlsson",
    "Carlssöners": "Carlsson",
    "Carlsöner": "Carlson",
    "Carlsönerna": "Carlson",
    "Carlsönernas": "Carlson",
    "Carlsöners": "Carlson",
    "Carlzons": "Carlzon",
    "Carmichaels": "Carmichael",
    "Carnés": "Carné",
    "Carolan": "Carola",
    "Carolans": "Carola",
    "Carolas": "Carola",
    "Carolinas": "Carolina",
    "Carolor": "Carola",
    "Carolorna": "Carola",
    "Carolornas": "Carola",
    "Carolors": "Carola",
    "Carpelans": "Carpelan",
    "Carrolls": "Carroll",
    "Carters": "Carter",
    "Carusos": "Caruso",
    "Cas": "Ca",
    "Cassiopejas": "Cassiopeja",
    "Castors": "Castor",
    "Castros": "Castro",
    "Catherines": "Catherine",
    "Cd-s": "Cd",
    "Ce-s": "Ce",
    "Ce:s": "Ce",
    "Ceausescus": "Ceausescu",
    "Cecilian": "Cecilia",
    "Cecilians": "Cecilia",
    "Cecilias": "Cecilia",
    "Cecilior": "Cecilia",
    "Ceciliorna": "Cecilia",
    "Ceciliornas": "Cecilia",
    "Ceciliors": "Cecilia",
    "Celibidaches": "Celibidache",
    "Centaurens": "Centauren",
    "Centauristjärnan": "Centauristjärna",
    "Centauristjärnans": "Centauristjärna",
    "Centauristjärnas": "Centauristjärna",
    "Centauristjärne": "Centauristjärna",
    "Centauristjärnor": "Centauristjärna",
    "Centauristjärnorna": "Centauristjärna",
    "Centauristjärnornas": "Centauristjärna",
    "Centauristjärnors": "Centauristjärna",
    "Centaurisystemets": "Centaurisystemet",
    "Centerns": "Centern",
    "Centerpartiets": "Centerpartiet",
    "Centralafrikas": "Centralafrika",
    "Centralamerikas": "Centralamerika",
    "Centralasiens": "Centralasien",
    "Centralens": "Centralen",
    "Centraleuropas": "Centraleuropa",
    "Cervins": "Cervin",
    "Ces": "Ce",
    "Ceylons": "Ceylon",
    "Cf-s": "Cf",
    "Cf:s": "Cf",
    "Cfs": "Cf",
    "Chagalls": "Chagall",
    "Challengers": "Challenger",
    "Chanels": "Chanel",
    "Chaplins": "Chaplin",
    "Charlestons": "Charleston",
    "Charlies": "Charlie",
    "Charlottes": "Charlotte",
    "Charons": "Charon",
    "Charta77-s": "Charta77",
    "Charta77:s": "Charta77",
    "Chesterfields": "Chesterfield",
    "Cheyennes": "Cheyenne",
    "Chicagos": "Chicago",
    "Chiles": "Chile",
    "Chomskys": "Chomsky",
    "Chopins": "Chopin",
    "Christers": "Christer",
    "Christians": "Christian",
    "Christies": "Christie",
    "Christoffs": "Christoff",
    "Christophers": "Christopher",
    "Chrusjtjovs": "Chrusjtjov",
    "Chrustjevs": "Chrustjev",
    "Churchills": "Churchill",
    "Citroenens": "Citroen",
    "Citroenerna": "Citroen",
    "Citroeners": "Citroen",
    "Citroëns": "Citroën",
    "Cl-s": "Cl",
    "Cl:s": "Cl",
    "Claesar": "Claes",
    "Claesarna": "Claes",
    "Claesarnas": "Claes",
    "Claesars": "Claes",
    "Clartés": "Clarté",
    "Claudar": "Claude",
    "Claudarna": "Claude",
    "Claudarnas": "Claude",
    "Claudars": "Claude",
    "Claudes": "Claude",
    "Claudios": "Claudio",
    "Clerks": "Clerk",
    "Clintons": "Clinton",
    "Cls": "Cl",
    "Cm-s": "Cm",
    "Cm:s": "Cm",
    "Cms": "Cm",
    "Co-s": "Co",
    "Co:s": "Co",
    "Coca-Colas": "Coca-Cola",
    "Cocteaus": "Cocteau",
    "Colemans": "Coleman",
    "Collianders": "Colliander",
    "Colombias": "Colombia",
    "Colombos": "Colombo",
    "Colorados": "Colorado",
    "Columbias": "Columbia",
    "Comorernas": "Comorerna",
    "Conans": "Conan",
    "Concords": "Concord",
    "Connecticuts": "Connecticut",
    "Connys": "Conny",
    "Conrads": "Conrad",
    "Cooks": "Cook",
    "Corneilles": "Corneille",
    "Cornelisar": "Cornelis",
    "Cornelisarna": "Cornelis",
    "Cornelisarnas": "Cornelis",
    "Cornelisars": "Cornelis",
    "Cos": "Co",
    "Couperins": "Couperin",
    "Cr-s": "Cr",
    "Cr:s": "Cr",
    "Cramérs": "Cramér",
    "Crs": "Cr",
    "Crutzens": "Crutzen",
    "Cs": "C",
    "Cs-s": "Cs",
    "Cs:s": "Cs",
    "Css": "Cs",
    "Cu-s": "Cu",
    "Cu:s": "Cu",
    "Cubas": "Cuba",
    "Culbertsonen": "Culbertson",
    "Culbertsonens": "Culbertson",
    "Culbertsons": "Culbertson",
    "Culbertsöner": "Culbertson",
    "Culbertsönerna": "Culbertson",
    "Culbertsönernas": "Culbertson",
    "Culbertsöners": "Culbertson",
    "Cullbergs": "Cullberg",
    "Cupidos": "Cupido",
    "Curtar": "Curt",
    "Curtarna": "Curt",
    "Curtarnas": "Curt",
    "Curtars": "Curt",
    "Curts": "Curt",
    "Cus": "Cu",
    "Cyperns": "Cypern",
    "Césars": "César",
    "Cézannes": "Cézanne",
    "DAMP:ens": "DAMP",
    "DAMP:ets": "DAMP",
    "DAMP:nas": "DAMP",
    "DAMPen": "DAMP",
    "DAMPens": "DAMP",
    "DAMPet": "DAMP",
    "DAMPets": "DAMP",
    "DAMPna": "DAMP",
    "DAMPs": "DAMP",
    "DDR-s": "DDR",
    "DDR:s": "DDR",
    "DDRs": "DDR",
    "DDT-en": "DDT",
    "DDT-ens": "DDT",
    "DDT-et": "DDT",
    "DDT-ets": "DDT",
    "DDT-n": "DDT",
    "DDT-ns": "DDT",
    "DDT-s": "DDT",
    "DDT-t": "DDT",
    "DDT-ts": "DDT",
    "DDT:en": "DDT",
    "DDT:ens": "DDT",
    "DDT:et": "DDT",
    "DDT:ets": "DDT",
    "DDT:n": "DDT",
    "DDT:ns": "DDT",
    "DDT:s": "DDT",
    "DDT:t": "DDT",
    "DDT:ts": "DDT",
    "DDTen": "DDT",
    "DDTens": "DDT",
    "DDTet": "DDT",
    "DDTets": "DDT",
    "DDTn": "DDT",
    "DDTns": "DDT",
    "DDTs": "DDT",
    "DDTt": "DDT",
    "DDTts": "DDT",
    "DJ-ar": "DJ",
    "DJ-arna": "DJ",
    "DJ-arnas": "DJ",
    "DJ-ars": "DJ",
    "DJ-en": "DJ",
    "DJ-ens": "DJ",
    "DJ-n": "DJ",
    "DJ-ns": "DJ",
    "DJ-s": "DJ",
    "DJ:ar": "DJ",
    "DJ:arna": "DJ",
    "DJ:arnas": "DJ",
    "DJ:ars": "DJ",
    "DJ:en": "DJ",
    "DJ:ens": "DJ",
    "DJ:n": "DJ",
    "DJ:ns": "DJ",
    "DJ:s": "DJ",
    "DJar": "DJ",
    "DJarna": "DJ",
    "DJarnas": "DJ",
    "DJars": "DJ",
    "DJen": "DJ",
    "DJens": "DJ",
    "DJn": "DJ",
    "DJns": "DJ",
    "DJs": "DJ",
    "DN-s": "DN",
    "DN:s": "DN",
    "DNA-er": "DNA",
    "DNA-erna": "DNA",
    "DNA-ers": "DNA",
    "DNA-kedjan": "DNA-kedja",
    "DNA-kedjas": "DNA-kedja",
    "DNA-kedjorna": "DNA-kedja",
    "DNA-molekylen": "DNA-molekyl",
    "DNA-molekyler": "DNA-molekyl",
    "DNA-molekylerna": "DNA-molekyl",
    "DNA-n": "DNA",
    "DNA-na": "DNA",
    "DNA-profilen": "DNA-profil",
    "DNA-profilens": "DNA-profil",
    "DNA-profiler": "DNA-profil",
    "DNA-profilerna": "DNA-profil",
    "DNA-profilernas": "DNA-profil",
    "DNA-profilers": "DNA-profil",
    "DNA-profils": "DNA-profil",
    "DNA-sekvensen": "DNA-sekvens",
    "DNA-sekvensens": "DNA-sekvens",
    "DNA-sekvenser": "DNA-sekvens",
    "DNA-sekvenseringar": "DNA-sekvensering",
    "DNA-sekvenseringarna": "DNA-sekvensering",
    "DNA-sekvenseringarnas": "DNA-sekvensering",
    "DNA-sekvenseringars": "DNA-sekvensering",
    "DNA-sekvenseringen": "DNA-sekvensering",
    "DNA-sekvenseringens": "DNA-sekvensering",
    "DNA-sekvenserings": "DNA-sekvensering",
    "DNA-sekvenserna": "DNA-sekvens",
    "DNA-sekvensernas": "DNA-sekvens",
    "DNA-sekvensers": "DNA-sekvens",
    "DNA-testad": "DNA-testa",
    "DNA-testade": "DNA-testa",
    "DNA-testades": "DNA-testa",
    "DNA-testads": "DNA-testa",
    "DNA-testande": "DNA-testa",
    "DNA-testanden": "DNA-testande",
    "DNA-testandena": "DNA-testande",
    "DNA-testandenas": "DNA-testande",
    "DNA-testandens": "DNA-testande",
    "DNA-testandes": "DNA-testande",
    "DNA-testandet": "DNA-testande",
    "DNA-testandets": "DNA-testande",
    "DNA-testar": "DNA-testa",
    "DNA-testas": "DNA-testa",
    "DNA-testat": "DNA-testa",
    "DNA-testats": "DNA-testa",
    "DNA-testen": "DNA-test",
    "DNA-testens": "DNA-test",
    "DNA-tester": "DNA-test",
    "DNA-testerna": "DNA-test",
    "DNA-testernas": "DNA-test",
    "DNA-testers": "DNA-test",
    "DNA-testet": "DNA-test",
    "DNA-testets": "DNA-test",
    "DNA-testningar": "DNA-testning",
    "DNA-testningarna": "DNA-testning",
    "DNA-testningarnas": "DNA-testning",
    "DNA-testningars": "DNA-testning",
    "DNA-testningen": "DNA-testning",
    "DNA-testningens": "DNA-testning",
    "DNA-testnings": "DNA-testning",
    "DNA-tests": "DNA-test",
    "DNA-uppsättningarna": "DNA-uppsättning",
    "DNA-uppsättningars": "DNA-uppsättning",
    "DNA-uppsättningens": "DNA-uppsättning",
    "DNA-uppsättnings": "DNA-uppsättning",
    "DNA:er": "DNA",
    "DNA:ernas": "DNA",
    "DNA:n": "DNA",
    "DNA:nas": "DNA",
    "DNA:s": "DNA",
    "DNA:ts": "DNA",
    "DNAernas": "DNA",
    "DNAnas": "DNA",
    "DNAns": "DNA",
    "DNAs": "DNA",
    "DNAt": "DNA",
    "DNAts": "DNA",
    "DNs": "DN",
    "DVD-ROM-en": "DVD-ROM",
    "DVD-ROM-ens": "DVD-ROM",
    "DVD-ROM-et": "DVD-ROM",
    "DVD-ROM-ets": "DVD-ROM",
    "DVD-ROM-na": "DVD-ROM",
    "DVD-ROM-nas": "DVD-ROM",
    "DVD-ROM-s": "DVD-ROM",
    "DVD-ROM:en": "DVD-ROM",
    "DVD-ROM:ens": "DVD-ROM",
    "DVD-ROM:et": "DVD-ROM",
    "DVD-ROM:ets": "DVD-ROM",
    "DVD-ROM:na": "DVD-ROM",
    "DVD-ROM:nas": "DVD-ROM",
    "DVD-ROM:s": "DVD-ROM",
    "DVD-ROMen": "DVD-ROM",
    "DVD-ROMens": "DVD-ROM",
    "DVD-ROMet": "DVD-ROM",
    "DVD-ROMets": "DVD-ROM",
    "DVD-ROMna": "DVD-ROM",
    "DVD-ROMnas": "DVD-ROM",
    "DVD-ROMs": "DVD-ROM",
    "DVD-filmens": "DVD-film",
    "DVD-filmerna": "DVD-film",
    "DVD-filmers": "DVD-film",
    "DVD-spelar": "DVD-spelare",
    "DVD-spelaren": "DVD-spelare",
    "DVD-spelarens": "DVD-spelare",
    "DVD-spelares": "DVD-spelare",
    "DVD-spelarna": "DVD-spelare",
    "DVD-spelarnas": "DVD-spelare",
    "DVD:arna": "DVD",
    "DVD:ars": "DVD",
    "DVD:erna": "DVD",
    "DVD:ers": "DVD",
    "DVD:ns": "DVD",
    "DVD:s": "DVD",
    "DVDar": "DVD",
    "DVDarnas": "DVD",
    "DVDer": "DVD",
    "DVDernas": "DVD",
    "DVDns": "DVD",
    "DVDs": "DVD",
    "Daccas": "Dacca",
    "Daciens": "Dacien",
    "Daewoos": "Daewoo",
    "Dagermans": "Dagerman",
    "Dagmars": "Dagmar",
    "Dags": "Dag",
    "Dahlbecks": "Dahlbeck",
    "Dahls": "Dahl",
    "Dahlströms": "Dahlström",
    "Dakars": "Dakar",
    "Dalagatans": "Dalagatan",
    "Dalarnas": "Dalarna",
    "Dalgatans": "Dalgatan",
    "Dalins": "Dalin",
    "Dalslands": "Dalsland",
    "Dalälvens": "Dalälven",
    "Dan-Axels": "Dan-Axel",
    "Danielssonen": "Danielsson",
    "Danielssonens": "Danielsson",
    "Danielssons": "Danielsson",
    "Danielssöner": "Danielsson",
    "Danielssönerna": "Danielsson",
    "Danielssönernas": "Danielsson",
    "Danielssöners": "Danielsson",
    "Danmark-Skånes": "Danmark-Skåne",
    "Danmarks": "Danmark",
    "Dans": "Dan",
    "Dantes": "Dante",
    "Daphnias": "Daphnia",
    "Darwins": "Darwin",
    "Davidar": "David",
    "Davidarna": "David",
    "Davidarnas": "David",
    "Davidars": "David",
    "Davids": "David",
    "Dayans": "Dayan",
    "Debussys": "Debussy",
    "Decamerones": "Decamerone",
    "Defoes": "Defoe",
    "Delawares": "Delaware",
    "Delblancs": "Delblanc",
    "Delfis": "Delfi",
    "Delhis": "Delhi",
    "Denvers": "Denver",
    "Detroits": "Detroit",
    "Dhejnes": "Dhejne",
    "Dicks": "Dick",
    "Diderots": "Diderot",
    "Dietrichs": "Dietrich",
    "Dimitrovs": "Dimitrov",
    "Din": "Du",
    "Diones": "Dione",
    "Diors": "Dior",
    "Diracs": "Dirac",
    "Disneys": "Disney",
    "Ditt": "Du",
    "Djakartas": "Djakarta",
    "Djiboutis": "Djibouti",
    "Djungelbokens": "Djungelboken",
    "Djurgårdens": "Djurgården",
    "Djävulens": "Djävulen",
    "Dneprs": "Dnepr",
    "Dolomiternas": "Dolomiterna",
    "Dominicas": "Dominica",
    "Donaus": "Donau",
    "Donkans": "Donkan",
    "Donkens": "Donken",
    "Donners": "Donner",
    "Dons": "Don",
    "Doratis": "Dorati",
    "Dorpats": "Dorpat",
    "Dorés": "Doré",
    "Dostojevskijs": "Dostojevskij",
    "Dovers": "Dover",
    "Doyles": "Doyle",
    "Draculas": "Dracula",
    "Drakens": "Draken",
    "Drakryggens": "Drakryggen",
    "Dramatenchefen": "Dramatenchef",
    "Dramatenchefens": "Dramatenchef",
    "Dramatenchefer": "Dramatenchef",
    "Dramatencheferna": "Dramatenchef",
    "Dramatenchefernas": "Dramatenchef",
    "Dramatenchefers": "Dramatenchef",
    "Dramatenchefs": "Dramatenchef",
    "Dramatens": "Dramaten",
    "Drottningholms": "Drottningholm",
    "Drottningholmsteaterns": "Drottningholmsteatern",
    "Dubaifrossan": "Dubaifrossa",
    "Dubaifrossans": "Dubaifrossa",
    "Dubaifrossas": "Dubaifrossa",
    "Dubaifrosse": "Dubaifrossa",
    "Dubaifrossor": "Dubaifrossa",
    "Dubaifrossorna": "Dubaifrossa",
    "Dubaifrossornas": "Dubaifrossa",
    "Dubaifrossors": "Dubaifrossa",
    "Dubais": "Dubai",
    "Dubceks": "Dubcek",
    "Dvoraks": "Dvorak",
    "Dy-s": "Dy",
    "Dy:s": "Dy",
    "Dürers": "Dürer",
    "Dürrenmatts": "Dürrenmatt",
    "Düsseldorfs": "Düsseldorf",
    "E-s": "E",
    "EEC-s": "EEC",
    "EEC:s": "EEC",
    "EECs": "EEC",
    "EEG-n": "EEG",
    "EEG-na": "EEG",
    "EEG-nas": "EEG",
    "EEG-ns": "EEG",
    "EEG-s": "EEG",
    "EEG-t": "EEG",
    "EEG-ts": "EEG",
    "EEG:n": "EEG",
    "EEG:na": "EEG",
    "EEG:nas": "EEG",
    "EEG:ns": "EEG",
    "EEG:s": "EEG",
    "EEG:t": "EEG",
    "EEG:ts": "EEG",
    "EEGn": "EEG",
    "EEGna": "EEG",
    "EEGnas": "EEG",
    "EEGns": "EEG",
    "EEGs": "EEG",
    "EEGt": "EEG",
    "EEGts": "EEG",
    "EFTA-s": "EFTA",
    "EFTA:s": "EFTA",
    "EFTAs": "EFTA",
    "EG-s": "EG",
    "EG:s": "EG",
    "EGs": "EG",
    "EKG-n": "EKG",
    "EKG-na": "EKG",
    "EKG-nas": "EKG",
    "EKG-ns": "EKG",
    "EKG-s": "EKG",
    "EKG-t": "EKG",
    "EKG-ts": "EKG",
    "EKG:n": "EKG",
    "EKG:na": "EKG",
    "EKG:nas": "EKG",
    "EKG:ns": "EKG",
    "EKG:s": "EKG",
    "EKG:t": "EKG",
    "EKG:ts": "EKG",
    "EKGn": "EKG",
    "EKGna": "EKG",
    "EKGnas": "EKG",
    "EKGns": "EKG",
    "EKGs": "EKG",
    "EKGt": "EKG",
    "EKGts": "EKG",
    "EM-n": "EM",
    "EM-na": "EM",
    "EM-nas": "EM",
    "EM-ns": "EM",
    "EM-s": "EM",
    "EM-t": "EM",
    "EM-ts": "EM",
    "EM:n": "EM",
    "EM:na": "EM",
    "EM:nas": "EM",
    "EM:ns": "EM",
    "EM:s": "EM",
    "EM:t": "EM",
    "EM:ts": "EM",
    "EMP-s": "EMP",
    "EMP:s": "EMP",
    "EMPs": "EMP",
    "EMn": "EM",
    "EMna": "EM",
    "EMnas": "EM",
    "EMns": "EM",
    "EMs": "EM",
    "EMt": "EM",
    "EMts": "EM",
    "EP-n": "EP",
    "EP-na": "EP",
    "EP-nas": "EP",
    "EP-ns": "EP",
    "EP-s": "EP",
    "EP:n": "EP",
    "EP:na": "EP",
    "EP:nas": "EP",
    "EP:ns": "EP",
    "EP:s": "EP",
    "EPn": "EP",
    "EPna": "EP",
    "EPnas": "EP",
    "EPns": "EP",
    "EPs": "EP",
    "EU-korrespondenten": "EU-korrespondent",
    "EU-korrespondentens": "EU-korrespondent",
    "EU-korrespondenter": "EU-korrespondent",
    "EU-korrespondenterna": "EU-korrespondent",
    "EU-korrespondenternas": "EU-korrespondent",
    "EU-korrespondenters": "EU-korrespondent",
    "EU-korrespondents": "EU-korrespondent",
    "EU-landet": "EU-land",
    "EU-landets": "EU-land",
    "EU-lands": "EU-land",
    "EU-länder": "EU-land",
    "EU-länderna": "EU-land",
    "EU-ländernas": "EU-land",
    "EU-länders": "EU-land",
    "EU-ministern": "EU-minister",
    "EU-ministerns": "EU-minister",
    "EU-ministers": "EU-minister",
    "EU-ministrar": "EU-minister",
    "EU-ministrarna": "EU-minister",
    "EU-ministrarnas": "EU-minister",
    "EU-ministrars": "EU-minister",
    "EU-parlamentarikern": "EU-parlamentariker",
    "EU-parlamentarikerna": "EU-parlamentariker",
    "EU-parlamentarikernas": "EU-parlamentariker",
    "EU-parlamentarikerns": "EU-parlamentariker",
    "EU-parlamentarikers": "EU-parlamentariker",
    "EU-parlamenten": "EU-parlament",
    "EU-parlamentens": "EU-parlament",
    "EU-parlamentet": "EU-parlament",
    "EU-parlamentets": "EU-parlament",
    "EU-parlaments": "EU-parlament",
    "EU-valen": "EU-val",
    "EU-valens": "EU-val",
    "EU-valet": "EU-val",
    "EU-valets": "EU-val",
    "EU-vals": "EU-val",
    "EUs": "EU",
    "Ecevits": "Ecevit",
    "Ecuadors": "Ecuador",
    "Edasis": "Edasi",
    "Eddans": "Eddan",
    "Eddies": "Eddie",
    "Edenmans": "Edenman",
    "Edens": "Eden",
    "Edfelts": "Edfelt",
    "Edisons": "Edison",
    "Ediths": "Edith",
    "Edvalls": "Edvall",
    "Edvardar": "Edvard",
    "Edvardarna": "Edvard",
    "Edvardarnas": "Edvard",
    "Edvardars": "Edvard",
    "Edvards": "Edvard",
    "Edwardar": "Edward",
    "Edwardarna": "Edward",
    "Edwardarnas": "Edward",
    "Edwardars": "Edward",
    "Edwards": "Edward",
    "Edwins": "Edwin",
    "Efta-landet": "Efta-land",
    "Efta-landets": "Efta-land",
    "Efta-lands": "Efta-land",
    "Efta-länder": "Efta-land",
    "Efta-länderna": "Efta-land",
    "Efta-ländernas": "Efta-land",
    "Efta-länders": "Efta-land",
    "Egyptens": "Egypten",
    "Ehrensvärds": "Ehrensvärd",
    "Ehrlings": "Ehrling",
    "Eidems": "Eidem",
    "Einars": "Einar",
    "Einsteins": "Einstein",
    "Eisenhowers": "Eisenhower",
    "Ekblads": "Ekblad",
    "Ekborgs": "Ekborg",
    "Ekelunds": "Ekelund",
    "Ekelöfs": "Ekelöf",
    "Ekvatorguineas": "Ekvatorguinea",
    "Ekvatorialguineas": "Ekvatorialguinea",
    "Elbes": "Elbe",
    "Eldjarns": "Eldjarn",
    "Eldslandets": "Eldslandet",
    "Elfenbenskustens": "Elfenbenskusten",
    "Elias": "Elia",
    "Eliots": "Eliot",
    "Elisabeths": "Elisabeth",
    "Elisabets": "Elisabet",
    "Elizabeths": "Elizabeth",
    "Ellingkvinnans": "Ellingkvinnan",
    "Elsan": "Elsa",
    "Elsans": "Elsa",
    "Elsas": "Elsa",
    "Elsor": "Elsa",
    "Elsorna": "Elsa",
    "Elsornas": "Elsa",
    "Elsors": "Elsa",
    "Elvanders": "Elvander",
    "Elvisar": "Elvis",
    "Elvisarna": "Elvis",
    "Elvisarnas": "Elvis",
    "Elvisars": "Elvis",
    "Elyséepalatsets": "Elyséepalatset",
    "Emblas": "Embla",
    "Englands": "England",
    "Engströms": "Engström",
    "Enzensbergers": "Enzensberger",
    "Er-s": "Er",
    "Er:s": "Er",
    "Eratos": "Erato",
    "Erdmanns": "Erdmann",
    "Ericar": "Eric",
    "Ericarna": "Eric",
    "Ericarnas": "Eric",
    "Ericars": "Eric",
    "Erics": "Eric",
    "Ericssonen": "Ericsson",
    "Ericssonens": "Ericsson",
    "Ericssons": "Ericsson",
    "Ericssöner": "Ericsson",
    "Ericssönerna": "Ericsson",
    "Ericssönernas": "Ericsson",
    "Ericssöners": "Ericsson",
    "Erikan": "Erika",
    "Erikans": "Erika",
    "Erikar": "Erik",
    "Erikarna": "Erik",
    "Erikarnas": "Erik",
    "Erikars": "Erik",
    "Erikas": "Erika",
    "Erikor": "Erika",
    "Erikorna": "Erika",
    "Erikornas": "Erika",
    "Erikors": "Erika",
    "Eriks": "Erik",
    "Erikssonen": "Eriksson",
    "Erikssonens": "Eriksson",
    "Erikssons": "Eriksson",
    "Erikssöner": "Eriksson",
    "Erikssönerna": "Eriksson",
    "Erikssönernas": "Eriksson",
    "Erikssöners": "Eriksson",
    "Eritreas": "Eritrea",
    "Erlanders": "Erlander",
    "Erles": "Erle",
    "Ernstar": "Ernst",
    "Ernstarna": "Ernst",
    "Ernstarnas": "Ernst",
    "Ernstars": "Ernst",
    "Ernsts": "Ernst",
    "Ers": "Er",
    "Es": "E",
    "Es-s": "Es",
    "Es:s": "Es",
    "Esaus": "Esau",
    "Eschers": "Escher",
    "Eskolas": "Eskola",
    "Ess": "Es",
    "Essungas": "Essunga",
    "Estlands": "Estland",
    "Estonias": "Estonia",
    "Etiopiens": "Etiopien",
    "Eu-s": "Eu",
    "Eu:s": "Eu",
    "Eurasiens": "Eurasien",
    "Europarådets": "Europarådet",
    "Europas": "Europa",
    "Europaunionens": "Europaunionen",
    "Euterpes": "Euterpe",
    "Evertar": "Evert",
    "Evertarna": "Evert",
    "Evertarnas": "Evert",
    "Evertars": "Evert",
    "Everts": "Evert",
    "Evorna": "Eva",
    "Evors": "Eva",
    "Expressens": "Expressen",
    "FBI-s": "FBI",
    "FBI:s": "FBI",
    "FBIs": "FBI",
    "FN-organen": "FN-organ",
    "FN-organens": "FN-organ",
    "FN-organet": "FN-organ",
    "FN-organets": "FN-organ",
    "FN-organs": "FN-organ",
    "FN-s": "FN",
    "FN-tribunalen": "FN-tribunal",
    "FN-tribunalens": "FN-tribunal",
    "FN-tribunaler": "FN-tribunal",
    "FN-tribunalerna": "FN-tribunal",
    "FN-tribunalernas": "FN-tribunal",
    "FN-tribunalers": "FN-tribunal",
    "FN-tribunals": "FN-tribunal",
    "FN:s": "FN",
    "FNs": "FN",
    "FP:s": "FP",
    "FSH-en": "FSH",
    "FSH-ens": "FSH",
    "FSH-et": "FSH",
    "FSH-ets": "FSH",
    "FSH-n": "FSH",
    "FSH-ns": "FSH",
    "FSH-s": "FSH",
    "FSH-t": "FSH",
    "FSH-ts": "FSH",
    "FSH:en": "FSH",
    "FSH:ens": "FSH",
    "FSH:et": "FSH",
    "FSH:ets": "FSH",
    "FSH:n": "FSH",
    "FSH:ns": "FSH",
    "FSH:s": "FSH",
    "FSH:t": "FSH",
    "FSH:ts": "FSH",
    "FSHen": "FSH",
    "FSHens": "FSH",
    "FSHet": "FSH",
    "FSHets": "FSH",
    "FSHn": "FSH",
    "FSHns": "FSH",
    "FSHs": "FSH",
    "FSHt": "FSH",
    "FSHts": "FSH",
    "Facebookbilden": "Facebookbild",
    "Facebookbilder": "Facebookbild",
    "Facebookbilderna": "Facebookbild",
    "Facebookbilds": "Facebookbild",
    "Facebookgruppen": "Facebookgrupp",
    "Facebookgrupper": "Facebookgrupp",
    "Facebookgrupperna": "Facebookgrupp",
    "Facebookgrupps": "Facebookgrupp",
    "Facebooks": "Facebook",
    "Fahlströms": "Fahlström",
    "Falklandsöarnas": "Falklandsöarna",
    "Falks": "Falk",
    "Falköpings": "Falköping",
    "Falstaffs": "Falstaff",
    "Falsterbos": "Falsterbo",
    "Faluns": "Falun",
    "Fannys": "Fanny",
    "Fants": "Fant",
    "Fargos": "Fargo",
    "Farstas": "Farsta",
    "Fattig-Sveriges": "Fattig-Sverige",
    "Faulkners": "Faulkner",
    "Fausts": "Faust",
    "Fe-s": "Fe",
    "Fe:s": "Fe",
    "Feldts": "Feldt",
    "Felixar": "Felix",
    "Felixarna": "Felix",
    "Felixarnas": "Felix",
    "Felixars": "Felix",
    "Fellinis": "Fellini",
    "Ferlins": "Ferlin",
    "Ferriers": "Ferrier",
    "Feynmans": "Feynman",
    "Figgar": "Figge",
    "Figgarna": "Figge",
    "Figgarnas": "Figge",
    "Figgars": "Figge",
    "Figges": "Figge",
    "Fijis": "Fiji",
    "Filharmonikernas": "Filharmonikerna",
    "Filippinernas": "Filippinerna",
    "Filminstitutets": "Filminstitutet",
    "Fingals": "Fingal",
    "Finlands": "Finland",
    "Finnairs": "Finnair",
    "Finns": "Finn",
    "Fischers": "Fischer",
    "Fiskarnas": "Fiskarna",
    "Fitzgeralds": "Fitzgerald",
    "Flanderns": "Flandern",
    "Flauberts": "Flaubert",
    "Flemings": "Fleming",
    "Floridas": "Florida",
    "Fläckgrottans": "Fläckgrottan",
    "Fm-s": "Fm",
    "Fm:s": "Fm",
    "Fms": "Fm",
    "FoF-s": "FoF",
    "FoF:s": "FoF",
    "FoFs": "FoF",
    "Folkar": "Folke",
    "Folkarna": "Folke",
    "Folkarnas": "Folke",
    "Folkars": "Folke",
    "Folkes": "Folke",
    "Folketingets": "Folketinget",
    "Folkpartiets": "Folkpartiet",
    "Fords": "Ford",
    "Formans": "Forman",
    "Formosas": "Formosa",
    "Fornegyptens": "Fornegypten",
    "Fornitaliens": "Fornitalien",
    "Forsbergs": "Forsberg",
    "Forskningsrådsnämndens": "Forskningsrådsnämnden",
    "Forsmarks": "Forsmark",
    "Forssells": "Forssell",
    "Fortunas": "Fortuna",
    "Fr-s": "Fr",
    "Fr:s": "Fr",
    "FrameNets": "FrameNet",
    "Frances": "France",
    "Francos": "Franco",
    "Frankforts": "Frankfort",
    "Frankfurts": "Frankfurt",
    "Franklins": "Franklin",
    "Frankrikes": "Frankrike",
    "Franks": "Frank",
    "Franzéns": "Franzén",
    "Fredrika-Bremer-Förbundets": "Fredrika-Bremer-Förbundet",
    "Fredrikar": "Fredrik",
    "Fredrikarna": "Fredrik",
    "Fredrikarnas": "Fredrik",
    "Fredrikars": "Fredrik",
    "Fredriks": "Fredrik",
    "Freiburgs": "Freiburg",
    "Frejas": "Freja",
    "Frejs": "Frej",
    "Freuds": "Freud",
    "Fribergs": "Friberg",
    "Fridegårds": "Fridegård",
    "Friedrichs": "Friedrich",
    "Fritzar": "Fritz",
    "Fritzarna": "Fritz",
    "Fritzarnas": "Fritz",
    "Fritzars": "Fritz",
    "Frs": "Fr",
    "Frälsningsarméns": "Frälsningsarmén",
    "Frödings": "Fröding",
    "Fröjas": "Fröja",
    "Fs": "F",
    "Fultons": "Fulton",
    "Fälldins": "Fälldin",
    "Färöarnas": "Färöarna",
    "Fåglums": "Fåglum",
    "Fårarps": "Fårarp",
    "Förbundsrepublikens": "Förbundsrepubliken",
    "Förintelsens": "Förintelsen",
    "Führers": "Führer",
    "G-kraftens": "G-kraft",
    "G-krafterna": "G-kraft",
    "G-krafts": "G-kraft",
    "G-punkten": "G-punkt",
    "G-punkter": "G-punkt",
    "G-punkternas": "G-punkt",
    "G-punkts": "G-punkt",
    "GABA-en": "GABA",
    "GABA-ens": "GABA",
    "GABA-et": "GABA",
    "GABA-ets": "GABA",
    "GABA-n": "GABA",
    "GABA-ns": "GABA",
    "GABA-s": "GABA",
    "GABA-t": "GABA",
    "GABA-ts": "GABA",
    "GABA:en": "GABA",
    "GABA:ens": "GABA",
    "GABA:et": "GABA",
    "GABA:ets": "GABA",
    "GABA:n": "GABA",
    "GABA:ns": "GABA",
    "GABA:s": "GABA",
    "GABA:t": "GABA",
    "GABA:ts": "GABA",
    "GABAen": "GABA",
    "GABAens": "GABA",
    "GABAet": "GABA",
    "GABAets": "GABA",
    "GABAn": "GABA",
    "GABAns": "GABA",
    "GABAs": "GABA",
    "GABAt": "GABA",
    "GABAts": "GABA",
    "GPS-ade": "GPS-a",
    "GPS-ades": "GPS-a",
    "GPS-ar": "GPS-a",
    "GPS-as": "GPS-a",
    "GPS-at": "GPS-a",
    "GPS-ats": "GPS-a",
    "GPS:ad": "GPS:a",
    "GPS:ades": "GPS:a",
    "GPS:ande": "GPS:a",
    "GPS:ar": "GPS:a",
    "GPS:arnas": "GPS",
    "GPS:ars": "GPS",
    "GPS:ats": "GPS:a",
    "GPS:erna": "GPS",
    "GPS:ers": "GPS",
    "GPS:ns": "GPS",
    "GPSad": "GPSa",
    "GPSarna": "GPS",
    "GPSarnas": "GPS",
    "GPSars": "GPS",
    "GPSerna": "GPS",
    "GPSers": "GPS",
    "GPSns": "GPS",
    "GSK-s": "GSK",
    "GSK:s": "GSK",
    "GSKs": "GSK",
    "GU-s": "GU",
    "GU:s": "GU",
    "GUs": "GU",
    "Ga-s": "Ga",
    "Ga:s": "Ga",
    "Gabins": "Gabin",
    "Gablers": "Gabler",
    "Gables": "Gable",
    "Gabriels": "Gabriel",
    "Galapagosöarnas": "Galapagosöarna",
    "Galatiens": "Galatien",
    "Galiciens": "Galicien",
    "Galileis": "Galilei",
    "Galileos": "Galileo",
    "Galiléens": "Galiléen",
    "Gambias": "Gambia",
    "Gandhis": "Gandhi",
    "Garbos": "Garbo",
    "Gas": "Ga",
    "Gascognes": "Gascogne",
    "Gastons": "Gaston",
    "Gaugins": "Gaugin",
    "Gd-s": "Gd",
    "Gd:s": "Gd",
    "Gds": "Gd",
    "Ge-s": "Ge",
    "Ge:s": "Ge",
    "Geijers": "Geijer",
    "Gellivares": "Gellivare",
    "Geminis": "Gemini",
    "Gemzells": "Gemzell",
    "Genèves": "Genève",
    "Georgar": "George",
    "Georgarna": "George",
    "Georgarnas": "George",
    "Georgars": "George",
    "Georges": "George",
    "Georgias": "Georgia",
    "Georgiens": "Georgien",
    "Georgs": "Georg",
    "Gerards": "Gerard",
    "Gerhards": "Gerhard",
    "Gershwins": "Gershwin",
    "Gertar": "Gert",
    "Gertarna": "Gert",
    "Gertarnas": "Gert",
    "Gertars": "Gert",
    "Gerts": "Gert",
    "Ges": "Ge",
    "Gestapos": "Gestapo",
    "Getsemanes": "Getsemane",
    "Ghanas": "Ghana",
    "Giacomettis": "Giacometti",
    "Gibraltars": "Gibraltar",
    "Giesekings": "Gieseking",
    "Giglis": "Gigli",
    "Glinkas": "Glinka",
    "Glistrups": "Glistrup",
    "Globens": "Globen",
    "Godards": "Godard",
    "Goethes": "Goethe",
    "Gofmans": "Gofman",
    "Gogols": "Gogol",
    "Goldscheiders": "Goldscheider",
    "Golgatas": "Golgata",
    "Golgatavandringar": "Golgatavandring",
    "Golgatavandringarna": "Golgatavandring",
    "Golgatavandringarnas": "Golgatavandring",
    "Golgatavandringars": "Golgatavandring",
    "Golgatavandringen": "Golgatavandring",
    "Golgatavandringens": "Golgatavandring",
    "Golgatavandrings": "Golgatavandring",
    "Golgis": "Golgi",
    "Golombs": "Golomb",
    "Gomulkas": "Gomulka",
    "Goodmans": "Goodman",
    "Goodrickes": "Goodricke",
    "Googles": "Google",
    "Gorbatjovs": "Gorbatjov",
    "Gorkijs": "Gorkij",
    "Gotlands": "Gotland",
    "Gotlandsfärjan": "Gotlandsfärja",
    "Gotlandsfärjans": "Gotlandsfärja",
    "Gotlandsfärjas": "Gotlandsfärja",
    "Gotlandsfärje": "Gotlandsfärja",
    "Gotlandsfärjor": "Gotlandsfärja",
    "Gotlandsfärjorna": "Gotlandsfärja",
    "Gotlandsfärjornas": "Gotlandsfärja",
    "Gotlandsfärjors": "Gotlandsfärja",
    "Gottfrieds": "Gottfried",
    "Goyas": "Goya",
    "Granqvists": "Granqvist",
    "Grates": "Grate",
    "Grauballemannens": "Grauballemannen",
    "Grecos": "Greco",
    "Greenwichmeridianen": "Greenwichmeridian",
    "Greenwichmeridianens": "Greenwichmeridian",
    "Greenwichmeridians": "Greenwichmeridian",
    "Greklands": "Grekland",
    "Grenadas": "Grenada",
    "Grenanders": "Grenander",
    "Grens": "Gren",
    "Greppets": "Greppet",
    "Gretan": "Greta",
    "Gretans": "Greta",
    "Gretas": "Greta",
    "Gretor": "Greta",
    "Gretorna": "Greta",
    "Gretornas": "Greta",
    "Gretors": "Greta",
    "Griegs": "Grieg",
    "Grigorijs": "Grigorij",
    "Grimbergs": "Grimberg",
    "Gromykos": "Gromyko",
    "Grouchos": "Groucho",
    "Grundtvigs": "Grundtvig",
    "Grupp-8-s": "Grupp-8",
    "Grupp-8:s": "Grupp-8",
    "Grännas": "Gränna",
    "Grönlands": "Grönland",
    "Guatemalas": "Guatemala",
    "Guayanas": "Guayana",
    "Gudmundssonen": "Gudmundsson",
    "Gudmundssonens": "Gudmundsson",
    "Gudmundssons": "Gudmundsson",
    "Gudmundssöner": "Gudmundsson",
    "Gudmundssönerna": "Gudmundsson",
    "Gudmundssönernas": "Gudmundsson",
    "Gudmundssöners": "Gudmundsson",
    "Gudruns": "Gudrun",
    "Guds": "Gud",
    "Guevaras": "Guevara",
    "Gullbergs": "Gullberg",
    "Gunders": "Gunder",
    "Gunillan": "Gunilla",
    "Gunillans": "Gunilla",
    "Gunillas": "Gunilla",
    "Gunillor": "Gunilla",
    "Gunillorna": "Gunilla",
    "Gunillornas": "Gunilla",
    "Gunillors": "Gunilla",
    "Gunnars": "Gunnar",
    "Gunnels": "Gunnel",
    "Gunters": "Gunter",
    "Gurlis": "Gurli",
    "Gustafs": "Gustaf",
    "Gustafssonen": "Gustafsson",
    "Gustafssonens": "Gustafsson",
    "Gustafssons": "Gustafsson",
    "Gustafssöner": "Gustafsson",
    "Gustafssönerna": "Gustafsson",
    "Gustafssönernas": "Gustafsson",
    "Gustafssöners": "Gustafsson",
    "Gustavs": "Gustav",
    "Gutenbergs": "Gutenberg",
    "Guths": "Guth",
    "Gyllenhammars": "Gyllenhammar",
    "Gyllenstens": "Gyllensten",
    "Gällivares": "Gällivare",
    "Gästriklands": "Gästrikland",
    "Gävles": "Gävle",
    "Görans": "Göran",
    "Görlings": "Görling",
    "Göstas": "Gösta",
    "Götalands": "Götaland",
    "Götaplatsens": "Götaplatsen",
    "Götar": "Göte",
    "Götarna": "Göte",
    "Götarnas": "Göte",
    "Götars": "Göte",
    "Götaverkens": "Götaverken",
    "Göteborgs": "Göteborg",
    "Göteborgsmålar": "Göteborgsmålare",
    "Göteborgsmålaren": "Göteborgsmålare",
    "Göteborgsmålarens": "Göteborgsmålare",
    "Göteborgsmålares": "Göteborgsmålare",
    "Göteborgsmålarna": "Göteborgsmålare",
    "Göteborgsmålarnas": "Göteborgsmålare",
    "H-s": "H",
    "H2O-s": "H2O",
    "H2O:s": "H2O",
    "H2Os": "H2O",
    "HD-s": "HD",
    "HD:s": "HD",
    "HDs": "HD",
    "HIV:s": "HIV",
    "HIVs": "HIV",
    "HK-s": "HK",
    "HK:s": "HK",
    "HKs": "HK",
    "HT-s": "HT",
    "HT:s": "HT",
    "HTs": "HT",
    "HUF-s": "HUF",
    "HUF:s": "HUF",
    "HUFs": "HUF",
    "Haags": "Haag",
    "Habsburgs": "Habsburg",
    "Haekkerups": "Haekkerup",
    "Hagbarths": "Hagbarth",
    "Hagbergs": "Hagberg",
    "Haitis": "Haiti",
    "Haldors": "Haldor",
    "Hallands": "Halland",
    "Halmstads": "Halmstad",
    "Hamburgs": "Hamburg",
    "Hamlets": "Hamlet",
    "Hammarskjölds": "Hammarskjöld",
    "Hammurabis": "Hammurabi",
    "Hamrins": "Hamrin",
    "Handelstidningens": "Handelstidningen",
    "Handynastins": "Handynastin",
    "Hannan": "Hanna",
    "Hannans": "Hanna",
    "Hannas": "Hanna",
    "Hannibals": "Hannibal",
    "Hannor": "Hanna",
    "Hannorna": "Hanna",
    "Hannornas": "Hanna",
    "Hannors": "Hanna",
    "Hanois": "Hanoi",
    "Hansar": "Hans",
    "Hansarna": "Hans",
    "Hansarnas": "Hans",
    "Hansars": "Hans",
    "Hansens": "Hansen",
    "Hansonen": "Hanson",
    "Hansonens": "Hanson",
    "Hansons": "Hanson",
    "Hanssonen": "Hansson",
    "Hanssonens": "Hansson",
    "Hanssons": "Hansson",
    "Hanssöner": "Hansson",
    "Hanssönerna": "Hansson",
    "Hanssönernas": "Hansson",
    "Hanssöners": "Hansson",
    "Hansöner": "Hanson",
    "Hansönerna": "Hanson",
    "Hansönernas": "Hanson",
    "Hansöners": "Hanson",
    "Haralds": "Harald",
    "Harborths": "Harborth",
    "Hardangerviddas": "Hardangervidda",
    "Harlems": "Harlem",
    "Harmagedons": "Harmagedon",
    "Harolds": "Harold",
    "Harpos": "Harpo",
    "Harpsunds": "Harpsund",
    "Harrisburgs": "Harrisburg",
    "Harrys": "Harry",
    "Hartfords": "Hartford",
    "Harvards": "Harvard",
    "Harveys": "Harvey",
    "Haseks": "Hasek",
    "Hassar": "Hasse",
    "Hassarna": "Hasse",
    "Hassarnas": "Hasse",
    "Hassars": "Hasse",
    "Hasselskogs": "Hasselskog",
    "Hasses": "Hasse",
    "Hauptmans": "Hauptman",
    "Hausdorffdimensionen": "Hausdorffdimension",
    "Hausdorffdimensionens": "Hausdorffdimension",
    "Hausdorffdimensioner": "Hausdorffdimension",
    "Hausdorffdimensionerna": "Hausdorffdimension",
    "Hausdorffdimensionernas": "Hausdorffdimension",
    "Hausdorffdimensioners": "Hausdorffdimension",
    "Hausdorffdimensions": "Hausdorffdimension",
    "Hausdorffs": "Hausdorff",
    "Havamals": "Havamal",
    "Havannas": "Havanna",
    "Hawaiis": "Hawaii",
    "Hawkings": "Hawking",
    "Haydns": "Haydn",
    "Hb-s": "Hb",
    "Hb:s": "Hb",
    "Hbs": "Hb",
    "He-s": "He",
    "He:s": "He",
    "Heaths": "Heath",
    "Heddan": "Hedda",
    "Heddans": "Hedda",
    "Heddas": "Hedda",
    "Heddor": "Hedda",
    "Heddorna": "Hedda",
    "Heddornas": "Hedda",
    "Heddors": "Hedda",
    "Hedemoras": "Hedemora",
    "Hedes": "Hede",
    "Hedins": "Hedin",
    "Hedlunds": "Hedlund",
    "Hedéns": "Hedén",
    "Heideggers": "Heidegger",
    "Heidenstams": "Heidenstam",
    "Heidis": "Heidi",
    "Heikos": "Heiko",
    "Heimdalls": "Heimdall",
    "Heines": "Heine",
    "Heinrichar": "Heinrich",
    "Heinricharna": "Heinrich",
    "Heinricharnas": "Heinrich",
    "Heinrichars": "Heinrich",
    "Heinrichs": "Heinrich",
    "Heinzar": "Heinz",
    "Heinzarna": "Heinz",
    "Heinzarnas": "Heinz",
    "Heinzars": "Heinz",
    "Heisenbergs": "Heisenberg",
    "Helanders": "Helander",
    "Helenan": "Helena",
    "Helenans": "Helena",
    "Helenas": "Helena",
    "Helenor": "Helena",
    "Helenorna": "Helena",
    "Helenornas": "Helena",
    "Helenors": "Helena",
    "Helgar": "Helge",
    "Helgarna": "Helge",
    "Helgarnas": "Helge",
    "Helgars": "Helge",
    "Helges": "Helge",
    "Helsingforsvännen": "Helsingforsvän",
    "Helsingforsvännens": "Helsingforsvän",
    "Helsingforsvänner": "Helsingforsvän",
    "Helsingforsvännerna": "Helsingforsvän",
    "Helsingforsvännernas": "Helsingforsvän",
    "Helsingforsvänners": "Helsingforsvän",
    "Helsingforsväns": "Helsingforsvän",
    "Helsinglands": "Helsingland",
    "Heléns": "Helén",
    "Hemsöbornas": "Hemsöborna",
    "Henrikar": "Henrik",
    "Henrikarna": "Henrik",
    "Henrikarnas": "Henrik",
    "Henrikars": "Henrik",
    "Henriks": "Henrik",
    "Henriksonen": "Henrikson",
    "Henriksonens": "Henrikson",
    "Henriksons": "Henrikson",
    "Henriksöner": "Henrikson",
    "Henriksönerna": "Henrikson",
    "Henriksönernas": "Henrikson",
    "Henriksöners": "Henrikson",
    "Herbertar": "Herbert",
    "Herbertarna": "Herbert",
    "Herbertarnas": "Herbert",
    "Herbertars": "Herbert",
    "Herberts": "Herbert",
    "Hermans": "Herman",
    "Hermanssonen": "Hermansson",
    "Hermanssonens": "Hermansson",
    "Hermanssons": "Hermansson",
    "Hermanssöner": "Hermansson",
    "Hermanssönerna": "Hermansson",
    "Hermanssönernas": "Hermansson",
    "Hermanssöners": "Hermansson",
    "Herrens": "Herren",
    "Herzegovinas": "Herzegovina",
    "Hes": "He",
    "Hesses": "Hesse",
    "Hf-s": "Hf",
    "Hf:s": "Hf",
    "Hfs": "Hf",
    "Hg-s": "Hg",
    "Hg:s": "Hg",
    "Hgs": "Hg",
    "Hillarys": "Hillary",
    "Himalayas": "Himalaya",
    "Hiroshimabomben": "Hiroshimabomb",
    "Hiroshimabombens": "Hiroshimabomb",
    "Hiroshimabomber": "Hiroshimabomb",
    "Hiroshimabomberna": "Hiroshimabomb",
    "Hiroshimabombernas": "Hiroshimabomb",
    "Hiroshimabombers": "Hiroshimabomb",
    "Hiroshimabombs": "Hiroshimabomb",
    "Hiroshimas": "Hiroshima",
    "Hitchcockfilmen": "Hitchcockfilm",
    "Hitchcockfilmens": "Hitchcockfilm",
    "Hitchcockfilmer": "Hitchcockfilm",
    "Hitchcockfilmerna": "Hitchcockfilm",
    "Hitchcockfilmernas": "Hitchcockfilm",
    "Hitchcockfilmers": "Hitchcockfilm",
    "Hitchcockfilms": "Hitchcockfilm",
    "Hitchcocks": "Hitchcock",
    "Hitlers": "Hitler",
    "Hjalmars": "Hjalmar",
    "Hjalmarsonen": "Hjalmarson",
    "Hjalmarsonens": "Hjalmarson",
    "Hjalmarsons": "Hjalmarson",
    "Hjalmarssonen": "Hjalmarsson",
    "Hjalmarssonens": "Hjalmarsson",
    "Hjalmarssons": "Hjalmarsson",
    "Hjalmarssöner": "Hjalmarsson",
    "Hjalmarssönerna": "Hjalmarsson",
    "Hjalmarssönernas": "Hjalmarsson",
    "Hjalmarssöners": "Hjalmarsson",
    "Hjalmarsöner": "Hjalmarson",
    "Hjalmarsönerna": "Hjalmarson",
    "Hjalmarsönernas": "Hjalmarson",
    "Hjalmarsöners": "Hjalmarson",
    "Hjorts": "Hjort",
    "Ho-s": "Ho",
    "Ho:s": "Ho",
    "Hobyfyndets": "Hobyfyndet",
    "Hobys": "Hoby",
    "Hodells": "Hodell",
    "Hodjas": "Hodja",
    "Hoels": "Hoel",
    "Holbergs": "Holberg",
    "Holgers": "Holger",
    "Hollands": "Holland",
    "Hollywoodfruar": "Hollywoodfru",
    "Hollywoodfruarna": "Hollywoodfru",
    "Hollywoodfruarnas": "Hollywoodfru",
    "Hollywoodfruars": "Hollywoodfru",
    "Hollywoodfrun": "Hollywoodfru",
    "Hollywoodfruns": "Hollywoodfru",
    "Hollywoodfrus": "Hollywoodfru",
    "Hollywoods": "Hollywood",
    "Holmbergs": "Holmberg",
    "Holmqvists": "Holmqvist",
    "Holms": "Holm",
    "Hondas": "Honda",
    "Honeckers": "Honecker",
    "Honeggers": "Honegger",
    "Hongkongs": "Hongkong",
    "Honolulus": "Honolulu",
    "Hookes": "Hooke",
    "Hoovers": "Hoover",
    "Houstons": "Houston",
    "Howards": "Howard",
    "Hoyles": "Hoyle",
    "Hs": "H",
    "Hubbles": "Hubble",
    "Hubertar": "Hubert",
    "Hubertarna": "Hubert",
    "Hubertarnas": "Hubert",
    "Hubertars": "Hubert",
    "Huberts": "Hubert",
    "Huddinges": "Huddinge",
    "Hugos": "Hugo",
    "Humphreys": "Humphrey",
    "Hunns": "Hunn",
    "Husaks": "Husak",
    "Husseins": "Hussein",
    "Huxleys": "Huxley",
    "Hylands": "Hyland",
    "Hyperions": "Hyperion",
    "Hälsingborgs": "Hälsingborg",
    "Hälsinglands": "Hälsingland",
    "Händels": "Händel",
    "Härjedalens": "Härjedalen",
    "Hässelbys": "Hässelby",
    "Håkans": "Håkan",
    "Håkanssonen": "Håkansson",
    "Håkanssonens": "Håkansson",
    "Håkanssons": "Håkansson",
    "Håkanssöner": "Håkansson",
    "Håkanssönerna": "Håkansson",
    "Håkanssönernas": "Håkansson",
    "Håkanssöners": "Håkansson",
    "Hårlemans": "Hårleman",
    "Högbergs": "Högberg",
    "Högerpartiets": "Högerpartiet",
    "Höglunds": "Höglund",
    "Hölderlins": "Hölderlin",
    "I-landet": "I-land",
    "I-lands": "I-land",
    "I-länder": "I-land",
    "I-länderna": "I-land",
    "I-s": "I",
    "IAEA-s": "IAEA",
    "IAEA:s": "IAEA",
    "IAEAs": "IAEA",
    "ID-kortens": "ID-kort",
    "ID-kortet": "ID-kort",
    "ID-korts": "ID-kort",
    "IP-nummerna": "IP-nummer",
    "IP-nummernas": "IP-nummer",
    "IP-numren": "IP-nummer",
    "IP-numret": "IP-nummer",
    "IP-s": "IP",
    "IP:s": "IP",
    "IPs": "IP",
    "IQ-s": "IQ",
    "IQ:s": "IQ",
    "IQs": "IQ",
    "IRA-s": "IRA",
    "IRA:s": "IRA",
    "IRAs": "IRA",
    "IT-företagens": "IT-företag",
    "IT-företaget": "IT-företag",
    "IT-företags": "IT-företag",
    "IT-jättarna": "IT-jätte",
    "IT-jättars": "IT-jätte",
    "IT-jättens": "IT-jätte",
    "Ians": "Ian",
    "Ibsens": "Ibsen",
    "Idahos": "Idaho",
    "Idols": "Idol",
    "Iduns": "Idun",
    "Iggesunds": "Iggesund",
    "Iliadens": "Iliaden",
    "In-s": "In",
    "In:s": "In",
    "Indianas": "Indiana",
    "Indiens": "Indien",
    "Indokinas": "Indokina",
    "Indonesiens": "Indonesien",
    "Ingan": "Inga",
    "Ingans": "Inga",
    "Ingas": "Inga",
    "Ingeborgs": "Ingeborg",
    "Ingegerds": "Ingegerd",
    "Ingemars": "Ingemar",
    "Ingers": "Inger",
    "Ingmars": "Ingmar",
    "Ingor": "Inga",
    "Ingorna": "Inga",
    "Ingornas": "Inga",
    "Ingors": "Inga",
    "Ingrids": "Ingrid",
    "Ingvars": "Ingvar",
    "Inka-rikets": "Inka-riket",
    "Ins": "In",
    "Internationalens": "Internationalen",
    "Internets": "Internet",
    "Interpols": "Interpol",
    "Investors": "Investor",
    "Ionescos": "Ionesco",
    "Ios": "Io",
    "Iowas": "Iowa",
    "Ir-s": "Ir",
    "Ir:s": "Ir",
    "Iraks": "Irak",
    "Irans": "Iran",
    "Irlands": "Irland",
    "Irs": "Ir",
    "Is": "I",
    "Isaacar": "Isaac",
    "Isaacarna": "Isaac",
    "Isaacarnas": "Isaac",
    "Isaacars": "Isaac",
    "Isaacs": "Isaac",
    "Isabellan": "Isabella",
    "Isabellans": "Isabella",
    "Isabellas": "Isabella",
    "Isabellor": "Isabella",
    "Isabellorna": "Isabella",
    "Isabellornas": "Isabella",
    "Isabellors": "Isabella",
    "Isakssonen": "Isaksson",
    "Isakssonens": "Isaksson",
    "Isakssons": "Isaksson",
    "Isakssöner": "Isaksson",
    "Isakssönerna": "Isaksson",
    "Isakssönernas": "Isaksson",
    "Isakssöners": "Isaksson",
    "Ishavets": "Ishavet",
    "Islamabads": "Islamabad",
    "Islands": "Island",
    "Istanbuls": "Istanbul",
    "Isulas": "Isula",
    "Italiens": "Italien",
    "Ivanar": "Ivan",
    "Ivanarna": "Ivan",
    "Ivanarnas": "Ivan",
    "Ivanars": "Ivan",
    "Ivans": "Ivan",
    "Ivars": "Ivar",
    "Izvestijas": "Izvestija",
    "JO-s": "JO",
    "JO:s": "JO",
    "JOs": "JO",
    "Jablonskis": "Jablonski",
    "Jacksons": "Jackson",
    "Jacksonvilles": "Jacksonville",
    "Jacobar": "Jacob",
    "Jacobarna": "Jacob",
    "Jacobarnas": "Jacob",
    "Jacobars": "Jacob",
    "Jacobs": "Jacob",
    "Jacobsens": "Jacobsen",
    "Jacsonvilles": "Jacsonville",
    "Jaegers": "Jaeger",
    "Jahves": "Jahve",
    "Jakobar": "Jakob",
    "Jakobarna": "Jakob",
    "Jakobarnas": "Jakob",
    "Jakobars": "Jakob",
    "Jakobs": "Jakob",
    "Jakobsonen": "Jakobson",
    "Jakobsonens": "Jakobson",
    "Jakobsons": "Jakobson",
    "Jakobsöner": "Jakobson",
    "Jakobsönerna": "Jakobson",
    "Jakobsönernas": "Jakobson",
    "Jakobsöners": "Jakobson",
    "Jamaicas": "Jamaica",
    "Janar": "Jan",
    "Janarnas": "Jan",
    "Janes": "Jane",
    "Jans": "Jan",
    "Janssonen": "Jansson",
    "Janssonens": "Jansson",
    "Janssons": "Jansson",
    "Janssöner": "Jansson",
    "Janssönerna": "Jansson",
    "Janssönernas": "Jansson",
    "Janssöners": "Jansson",
    "Jantelagar": "Jantelag",
    "Jantelagarnas": "Jantelag",
    "Jantelagen": "Jantelag",
    "Jantelags": "Jantelag",
    "Janáceks": "Janácek",
    "Jarlskogs": "Jarlskog",
    "Jarmos": "Jarmo",
    "Jaroslavs": "Jaroslav",
    "Javas": "Java",
    "Jeans": "Jean",
    "Jeffersonen": "Jefferson",
    "Jeffersonens": "Jefferson",
    "Jeffersons": "Jefferson",
    "Jeffersöner": "Jefferson",
    "Jeffersönerna": "Jefferson",
    "Jeffersönernas": "Jefferson",
    "Jeffersöners": "Jefferson",
    "Jeltsins": "Jeltsin",
    "Jemens": "Jemen",
    "Jenisejs": "Jenisej",
    "Jennys": "Jenny",
    "Jensar": "Jens",
    "Jensarna": "Jens",
    "Jensarnas": "Jens",
    "Jensars": "Jens",
    "Jensens": "Jensen",
    "Jeremias": "Jeremia",
    "Jerikos": "Jeriko",
    "Jernbergs": "Jernberg",
    "Jerrings": "Jerring",
    "Jersilds": "Jersild",
    "Jerusalems": "Jerusalem",
    "Jesenins": "Jesenin",
    "Johannan": "Johanna",
    "Johannans": "Johanna",
    "Johannas": "Johanna",
    "Johannesar": "Johannes",
    "Johannesarna": "Johannes",
    "Johannesarnas": "Johannes",
    "Johannesars": "Johannes",
    "Johannor": "Johanna",
    "Johannorna": "Johanna",
    "Johannornas": "Johanna",
    "Johannors": "Johanna",
    "Johans": "Johan",
    "Johanssonen": "Johansson",
    "Johanssonens": "Johansson",
    "Johanssons": "Johansson",
    "Johanssöner": "Johansson",
    "Johanssönerna": "Johansson",
    "Johanssönernas": "Johansson",
    "Johanssöners": "Johansson",
    "Johnnys": "Johnny",
    "Johns": "John",
    "Johnsonen": "Johnson",
    "Johnsonens": "Johnson",
    "Johnsons": "Johnson",
    "Johnsöner": "Johnson",
    "Johnsönerna": "Johnson",
    "Johnsönernas": "Johnson",
    "Johnsöners": "Johnson",
    "Jokkmokks": "Jokkmokk",
    "Jolos": "Jolo",
    "Jonssonen": "Jonsson",
    "Jonssonens": "Jonsson",
    "Jonssons": "Jonsson",
    "Jonssöner": "Jonsson",
    "Jonssönerna": "Jonsson",
    "Jonssönernas": "Jonsson",
    "Jonssöners": "Jonsson",
    "Jordaniens": "Jordanien",
    "Jordens": "Jorden",
    "Josefar": "Josef",
    "Josefarna": "Josef",
    "Josefarnas": "Josef",
    "Josefars": "Josef",
    "Josefs": "Josef",
    "Josephar": "Joseph",
    "Josepharna": "Joseph",
    "Josepharnas": "Joseph",
    "Josephars": "Joseph",
    "Josephs": "Joseph",
    "Josephsonen": "Josephson",
    "Josephsonens": "Josephson",
    "Josephsons": "Josephson",
    "Josephsöner": "Josephson",
    "Josephsönerna": "Josephson",
    "Josephsönernas": "Josephson",
    "Josephsöners": "Josephson",
    "Joyces": "Joyce",
    "Jr-s": "Jr",
    "Jr:s": "Jr",
    "Jrs": "Jr",
    "Juans": "Juan",
    "Jugoslaviens": "Jugoslavien",
    "Jularbos": "Jularbo",
    "Julian": "Julia",
    "Julians": "Julia",
    "Julias": "Julia",
    "Julies": "Julie",
    "Julior": "Julia",
    "Juliorna": "Julia",
    "Juliornas": "Julia",
    "Juliors": "Julia",
    "Juneaus": "Juneau",
    "Jungfruns": "Jungfrun",
    "Jupitermån": "Jupitermåne",
    "Jupitermånar": "Jupitermåne",
    "Jupitermånarna": "Jupitermåne",
    "Jupitermånarnas": "Jupitermåne",
    "Jupitermånars": "Jupitermåne",
    "Jupitermånen": "Jupitermåne",
    "Jupitermånens": "Jupitermåne",
    "Jupitermånes": "Jupitermåne",
    "Jupitermåns": "Jupitermåne",
    "Jupiters": "Jupiter",
    "Jussis": "Jussi",
    "Jyllands": "Jylland",
    "Jämtlands": "Jämtland",
    "Järnas": "Järna",
    "Järrels": "Järrel",
    "Jönköpings": "Jönköping",
    "Jönssons": "Jönsson",
    "Jörgens": "Jörgen",
    "Jørgensens": "Jørgensen",
    "K-märk": "K-märka",
    "K-märkande": "K-märka",
    "K-märkanden": "K-märkande",
    "K-märkandenas": "K-märkande",
    "K-märkandet": "K-märkande",
    "K-märkas": "K-märka",
    "K-märkes": "K-märka",
    "K-märkt": "K-märka",
    "K-märktas": "K-märka",
    "K-märktes": "K-märka",
    "K-s": "K",
    "KGB-s": "KGB",
    "KGB:s": "KGB",
    "KGBs": "KGB",
    "KOH-s": "KOH",
    "KOH:s": "KOH",
    "KOHs": "KOH",
    "KU-anmäl": "KU-anmäla",
    "KU-anmälande": "KU-anmäla",
    "KU-anmälandes": "KU-anmäla",
    "KU-anmälas": "KU-anmäla",
    "KU-anmäld": "KU-anmäla",
    "KU-anmälda": "KU-anmäla",
    "KU-anmäldas": "KU-anmäla",
    "KU-anmälde": "KU-anmäla",
    "KU-anmäldes": "KU-anmäla",
    "KU-anmälds": "KU-anmäla",
    "KU-anmäler": "KU-anmäla",
    "KU-anmäles": "KU-anmäla",
    "KU-anmäls": "KU-anmäla",
    "KU-anmält": "KU-anmäla",
    "KU-anmälts": "KU-anmäla",
    "KU-s": "KU",
    "KU:s": "KU",
    "KUs": "KU",
    "Kabuls": "Kabul",
    "Kadars": "Kadar",
    "Kafkaartads": "Kafkaartad",
    "Kafkaartats": "Kafkaartad",
    "Kafkaeskare": "Kafkaesk",
    "Kafkaeskas": "Kafkaesk",
    "Kafkaeskaste": "Kafkaesk",
    "Kafkaeskasts": "Kafkaesk",
    "Kafkaeskes": "Kafkaesk",
    "Kafkaesks": "Kafkaesk",
    "Kafkaeskts": "Kafkaesk",
    "Kafkalikare": "Kafkalik",
    "Kafkalikaste": "Kafkalik",
    "Kafkalikasts": "Kafkalik",
    "Kafkalikes": "Kafkalik",
    "Kafkalikt": "Kafkalik",
    "Kafkas": "Kafka",
    "Kafkastämningar": "Kafkastämning",
    "Kafkastämningarnas": "Kafkastämning",
    "Kafkastämningens": "Kafkastämning",
    "Kairobesöken": "Kairobesök",
    "Kairobesökens": "Kairobesök",
    "Kairobesöket": "Kairobesök",
    "Kairobesökets": "Kairobesök",
    "Kairobesöks": "Kairobesök",
    "Kairos": "Kairo",
    "Kalevalas": "Kalevala",
    "Kaliforniens": "Kalifornien",
    "Kallar": "Kalle",
    "Kallarna": "Kalle",
    "Kallarnas": "Kalle",
    "Kallars": "Kalle",
    "Kalles": "Kalle",
    "Kalliopes": "Kalliope",
    "Kalmars": "Kalmar",
    "Kameruns": "Kamerun",
    "Kampucheas": "Kampuchea",
    "Kamtsjatkas": "Kamtsjatka",
    "Kanaans": "Kanaan",
    "Kanadas": "Kanada",
    "Kanarieöarnas": "Kanarieöarna",
    "Kandinskys": "Kandinsky",
    "Kanslihusets": "Kanslihuset",
    "Kants": "Kant",
    "Kapernaums": "Kapernaum",
    "Karabudas": "Karabuda",
    "Karajans": "Karajan",
    "Karelens": "Karelen",
    "Karens": "Karen",
    "Karibiens": "Karibien",
    "Karins": "Karin",
    "Karl-Birgers": "Karl-Birger",
    "Karl-Erikar": "Karl-Erik",
    "Karl-Erikarna": "Karl-Erik",
    "Karl-Erikarnas": "Karl-Erik",
    "Karl-Erikars": "Karl-Erik",
    "Karl-Eriks": "Karl-Erik",
    "Karlarna": "Karl",
    "Karlars": "Karl",
    "Karlavagnens": "Karlavagnen",
    "Karlskronas": "Karlskrona",
    "Karlssonen": "Karlsson",
    "Karlssonens": "Karlsson",
    "Karlssons": "Karlsson",
    "Karlssöner": "Karlsson",
    "Karlssönerna": "Karlsson",
    "Karlssönernas": "Karlsson",
    "Karlssöners": "Karlsson",
    "Karlstads": "Karlstad",
    "Karos": "Karo",
    "Karpaternas": "Karpaterna",
    "Kartagos": "Kartago",
    "Kastiliens": "Kastilien",
    "Kataloniens": "Katalonien",
    "Katarinan": "Katarina",
    "Katarinans": "Katarina",
    "Katarinas": "Katarina",
    "Katarinor": "Katarina",
    "Katarinorna": "Katarina",
    "Katarinornas": "Katarina",
    "Katarinors": "Katarina",
    "Katerinan": "Katerina",
    "Katerinans": "Katerina",
    "Katerinas": "Katerina",
    "Katerinor": "Katerina",
    "Katerinorna": "Katerina",
    "Katerinornas": "Katerina",
    "Katerinors": "Katerina",
    "Katmandus": "Katmandu",
    "Kattegatts": "Kattegatt",
    "Katynmassakern": "Katynmassaker",
    "Katynmassakerns": "Katynmassaker",
    "Katynmassakers": "Katynmassaker",
    "Katynmassakrer": "Katynmassaker",
    "Katynmassakrerna": "Katynmassaker",
    "Katynmassakrernas": "Katynmassaker",
    "Katynmassakrers": "Katynmassaker",
    "Kaufmanns": "Kaufmann",
    "Kaukasiens": "Kaukasien",
    "Kaundas": "Kaunda",
    "Kazakstans": "Kazakstan",
    "Kazans": "Kazan",
    "Keatons": "Keaton",
    "Kebnekajses": "Kebnekajse",
    "Keiths": "Keith",
    "Kekkonens": "Kekkonen",
    "Kellgrens": "Kellgren",
    "Kemals": "Kemal",
    "Kemijärvis": "Kemijärvi",
    "Kennedys": "Kennedy",
    "Kents": "Kent",
    "Kentuckys": "Kentucky",
    "Kenyas": "Kenya",
    "Kenyattas": "Kenyatta",
    "Keplers": "Kepler",
    "Kerstins": "Kerstin",
    "Kevlarens": "Kevlar",
    "Key-Åbergs": "Key-Åberg",
    "Khadaffis": "Khadaffi",
    "Kilaueas": "Kilauea",
    "Kilimandjaros": "Kilimandjaro",
    "Kinabesöken": "Kinabesök",
    "Kinabesökens": "Kinabesök",
    "Kinabesöket": "Kinabesök",
    "Kinabesökets": "Kinabesök",
    "Kinabesöks": "Kinabesök",
    "Kingos": "Kingo",
    "Kings": "King",
    "Kingstons": "Kingston",
    "Kinnekulles": "Kinnekulle",
    "Kiplings": "Kipling",
    "Kirgizistans": "Kirgizistan",
    "Kiribatis": "Kiribati",
    "Kirunas": "Kiruna",
    "Kirunatraktens": "Kirunatrakten",
    "Kjelmöymaterialets": "Kjelmöymaterialet",
    "Kjelmöys": "Kjelmöy",
    "Klaran": "Klara",
    "Klarans": "Klara",
    "Klaror": "Klara",
    "Klarorna": "Klara",
    "Klarornas": "Klara",
    "Klarors": "Klara",
    "Klarälvens": "Klarälven",
    "Klasar": "Klas",
    "Klasarna": "Klas",
    "Klasarnas": "Klas",
    "Klasars": "Klas",
    "Klausar": "Klaus",
    "Klausarna": "Klaus",
    "Klausarnas": "Klaus",
    "Klausars": "Klaus",
    "Klees": "Klee",
    "Kleins": "Klein",
    "Kleopatras": "Kleopatra",
    "Klios": "Klio",
    "Kluges": "Kluge",
    "Klüfts": "Klüft",
    "Knessets": "Knesset",
    "Knutarna": "Knut",
    "Knutars": "Knut",
    "Kobilovs": "Kobilov",
    "Kockums": "Kockum",
    "Kodalys": "Kodaly",
    "Koivistos": "Koivisto",
    "Kolahalvöns": "Kolahalvön",
    "Kolingens": "Kolingen",
    "Komorernas": "Komorerna",
    "Kongos": "Kongo",
    "Konrads": "Konrad",
    "Konsertföreningens": "Konsertföreningen",
    "Konstantinopels": "Konstantinopel",
    "Koranbålen": "Koranbål",
    "Koranbålens": "Koranbål",
    "Koranbålet": "Koranbål",
    "Koranbålets": "Koranbål",
    "Koranbåls": "Koranbål",
    "Koranens": "Koranen",
    "Koreas": "Korea",
    "Korsikas": "Korsika",
    "Kosovos": "Kosovo",
    "Kosygins": "Kosygin",
    "Kr-s": "Kr",
    "Kr.-s": "Kr.",
    "Kr.:s": "Kr.",
    "Kr.s": "Kr.",
    "Kr:s": "Kr",
    "Krags": "Krag",
    "Krakatoas": "Krakatoa",
    "Kramforstraktens": "Kramforstrakten",
    "Kreiskys": "Kreisky",
    "Kremls": "Kreml",
    "Krims": "Krim",
    "Kristdemokraternas": "Kristdemokraterna",
    "Kristers": "Krister",
    "Kristianias": "Kristiania",
    "Kristianssonen": "Kristiansson",
    "Kristianssonens": "Kristiansson",
    "Kristianssons": "Kristiansson",
    "Kristianssöner": "Kristiansson",
    "Kristianssönerna": "Kristiansson",
    "Kristianssönernas": "Kristiansson",
    "Kristianssöners": "Kristiansson",
    "Kristianstads": "Kristianstad",
    "Kristinan": "Kristina",
    "Kristinans": "Kristina",
    "Kristinas": "Kristina",
    "Kristinor": "Kristina",
    "Kristinorna": "Kristina",
    "Kristinornas": "Kristina",
    "Kristinors": "Kristina",
    "Kroatiens": "Kroatien",
    "Kroks": "Krok",
    "Kronobergs": "Kronoberg",
    "Krs": "Kr",
    "Krusjtjevs": "Krusjtjev",
    "Kräftans": "Kräftan",
    "Ks": "K",
    "Kubakrisen": "Kubakris",
    "Kubakrisens": "Kubakris",
    "Kubakriser": "Kubakris",
    "Kubakriserna": "Kubakris",
    "Kubakrisernas": "Kubakris",
    "Kubakrisers": "Kubakris",
    "Kubas": "Kuba",
    "Kulles": "Kulle",
    "Kultsjöns": "Kultsjön",
    "Kulturens": "Kulturen",
    "Kulturhusets": "Kulturhuset",
    "Kungsträdgårdens": "Kungsträdgården",
    "Kurdistans": "Kurdistan",
    "Kurlands": "Kurland",
    "Kurosawas": "Kurosawa",
    "Kursverksamhetens": "Kursverksamheten",
    "Kurtar": "Kurt",
    "Kurtarna": "Kurt",
    "Kurtarnas": "Kurt",
    "Kurtars": "Kurt",
    "Kurts": "Kurt",
    "Kuskens": "Kusken",
    "Kuusinens": "Kuusinen",
    "Kuwaits": "Kuwait",
    "Kyrklunds": "Kyrklund",
    "Kyrkobrödernas": "Kyrkobröderna",
    "Köchelnummerna": "Köchelnummer",
    "Köchelnummernas": "Köchelnummer",
    "Köchelnummers": "Köchelnummer",
    "Köchelnumren": "Köchelnummer",
    "Köchelnumrens": "Köchelnummer",
    "Köchelnumret": "Köchelnummer",
    "Köchelnumrets": "Köchelnummer",
    "Köchels": "Köchel",
    "Köpenhamns": "Köpenhamn",
    "Köpenhamnsackorden": "Köpenhamnsackord",
    "Köpenhamnsackordens": "Köpenhamnsackord",
    "Köpenhamnsackordet": "Köpenhamnsackord",
    "Köpenhamnsackordets": "Köpenhamnsackord",
    "Köpenhamnsackords": "Köpenhamnsackord",
    "LED-belysningar": "LED-belysning",
    "LED-belysningarna": "LED-belysning",
    "LED-belysningarnas": "LED-belysning",
    "LED-belysningars": "LED-belysning",
    "LED-belysningen": "LED-belysning",
    "LED-belysningens": "LED-belysning",
    "LED-belysnings": "LED-belysning",
    "LED-en": "LED",
    "LED-ens": "LED",
    "LED-er": "LED",
    "LED-erna": "LED",
    "LED-ernas": "LED",
    "LED-ers": "LED",
    "LED-lampan": "LED-lampa",
    "LED-lampans": "LED-lampa",
    "LED-lampas": "LED-lampa",
    "LED-lampe": "LED-lampa",
    "LED-lampor": "LED-lampa",
    "LED-lamporna": "LED-lampa",
    "LED-lampornas": "LED-lampa",
    "LED-lampors": "LED-lampa",
    "LED-s": "LED",
    "LED:en": "LED",
    "LED:ens": "LED",
    "LED:er": "LED",
    "LED:erna": "LED",
    "LED:ernas": "LED",
    "LED:ers": "LED",
    "LED:s": "LED",
    "LEDens": "LED",
    "LEDer": "LED",
    "LEDerna": "LED",
    "LEDernas": "LED",
    "LEDers": "LED",
    "LEP-s": "LEP",
    "LEP:s": "LEP",
    "LEPs": "LEP",
    "LH-en": "LH",
    "LH-ens": "LH",
    "LH-et": "LH",
    "LH-ets": "LH",
    "LH-n": "LH",
    "LH-ns": "LH",
    "LH-s": "LH",
    "LH-t": "LH",
    "LH-ts": "LH",
    "LH:en": "LH",
    "LH:ens": "LH",
    "LH:et": "LH",
    "LH:ets": "LH",
    "LH:n": "LH",
    "LH:ns": "LH",
    "LH:s": "LH",
    "LH:t": "LH",
    "LH:ts": "LH",
    "LHen": "LH",
    "LHens": "LH",
    "LHet": "LH",
    "LHets": "LH",
    "LHn": "LH",
    "LHns": "LH",
    "LHs": "LH",
    "LHt": "LH",
    "LHts": "LH",
    "LO-chefen": "LO-chef",
    "LO-chefens": "LO-chef",
    "LO-chefer": "LO-chef",
    "LO-cheferna": "LO-chef",
    "LO-chefernas": "LO-chef",
    "LO-chefers": "LO-chef",
    "LO-chefs": "LO-chef",
    "LO-ordföranden": "LO-ordförande",
    "LO-ordförandena": "LO-ordförande",
    "LO-ordförandenas": "LO-ordförande",
    "LO-ordförandens": "LO-ordförande",
    "LO-ordförandes": "LO-ordförande",
    "LO-s": "LO",
    "LO:s": "LO",
    "LOs": "LO",
    "LP-n": "LP",
    "LP-na": "LP",
    "LP-nas": "LP",
    "LP-ns": "LP",
    "LP-s": "LP",
    "LP:n": "LP",
    "LP:na": "LP",
    "LP:nas": "LP",
    "LP:ns": "LP",
    "LP:s": "LP",
    "LPn": "LP",
    "LPna": "LP",
    "LPnas": "LP",
    "LPns": "LP",
    "LPs": "LP",
    "La-s": "La",
    "La:s": "La",
    "Lagans": "Lagan",
    "Lagerkvists": "Lagerkvist",
    "Lagerlöfs": "Lagerlöf",
    "Lamarcks": "Lamarck",
    "Landskronas": "Landskrona",
    "Landsorganisationens": "Landsorganisationen",
    "Landvetters": "Landvetter",
    "Langes": "Lange",
    "Langs": "Lang",
    "Lansings": "Lansing",
    "Lantbrukshälsans": "Lantbrukshälsan",
    "Laplaces": "Laplace",
    "Lapp-Lisas": "Lapp-Lisa",
    "Lapplands": "Lappland",
    "Lappmarkens": "Lappmarken",
    "Larrys": "Larry",
    "Lars-Erikar": "Lars-Erik",
    "Lars-Erikarna": "Lars-Erik",
    "Lars-Erikarnas": "Lars-Erik",
    "Lars-Erikars": "Lars-Erik",
    "Lars-Eriks": "Lars-Erik",
    "Larsar": "Lars",
    "Larsarna": "Lars",
    "Larsarnas": "Lars",
    "Larsars": "Lars",
    "Larsens": "Larsen",
    "Larssonen": "Larsson",
    "Larssonens": "Larsson",
    "Larssons": "Larsson",
    "Larssöner": "Larsson",
    "Larssönerna": "Larsson",
    "Larssönernas": "Larsson",
    "Larssöners": "Larsson",
    "Las": "La",
    "Laskes": "Laske",
    "Lassar": "Lasse",
    "Lassarna": "Lasse",
    "Lassarnas": "Lasse",
    "Lassars": "Lasse",
    "Lasses": "Lasse",
    "Latinamerikas": "Latinamerika",
    "Latiums": "Latium",
    "Laurents": "Laurent",
    "Laurins": "Laurin",
    "Lavals": "Laval",
    "Lawrences": "Lawrence",
    "Ledins": "Ledin",
    "Lees": "Lee",
    "Leeuwenhoeks": "Leeuwenhoek",
    "Leifar": "Leif",
    "Leifarna": "Leif",
    "Leifarnas": "Leif",
    "Leifars": "Leif",
    "Leifs": "Leif",
    "Lejonets": "Lejonet",
    "Lekholms": "Lekholm",
    "Lenan": "Lena",
    "Lenans": "Lena",
    "Lendls": "Lendl",
    "Leningrads": "Leningrad",
    "Lenins": "Lenin",
    "Lennartar": "Lennart",
    "Lennartarna": "Lennart",
    "Lennartarnas": "Lennart",
    "Lennartars": "Lennart",
    "Lennarts": "Lennart",
    "Lenor": "Lena",
    "Lenorna": "Lena",
    "Lenornas": "Lena",
    "Lenors": "Lena",
    "Leopoldar": "Leopold",
    "Leopoldarna": "Leopold",
    "Leopoldarnas": "Leopold",
    "Leopoldars": "Leopold",
    "Leopolds": "Leopold",
    "Leos": "Leo",
    "Lesothos": "Lesotho",
    "Lessebos": "Lessebo",
    "Lessings": "Lessing",
    "Lethes": "Lethe",
    "Lettlands": "Lettland",
    "Levantens": "Levanten",
    "Levis": "Levi",
    "Lhasas": "Lhasa",
    "Li-s": "Li",
    "Li:s": "Li",
    "Libanons": "Libanon",
    "Liberias": "Liberia",
    "Libyens": "Libyen",
    "Lidans": "Lidan",
    "Lidholms": "Lidholm",
    "Lidmans": "Lidman",
    "Lidners": "Lidner",
    "Lidvalls": "Lidvall",
    "Liechtensteins": "Liechtenstein",
    "Liguriens": "Ligurien",
    "Limhamns": "Limhamn",
    "Lincolns": "Lincoln",
    "Lindahls": "Lindahl",
    "Lindbergs": "Lindberg",
    "Lindegrens": "Lindegren",
    "Lindes": "Linde",
    "Lindgatans": "Lindgatan",
    "Lindgrens": "Lindgren",
    "Lindholms": "Lindholm",
    "Lindmans": "Lindman",
    "Lindqvists": "Lindqvist",
    "Lindroths": "Lindroth",
    "Linds": "Lind",
    "Lindsays": "Lindsay",
    "Lindströms": "Lindström",
    "Lings": "Ling",
    "Linköpings": "Linköping",
    "Linköpingsbon": "Linköpingsbo",
    "Linköpingsbons": "Linköpingsbo",
    "Linköpingsbor": "Linköpingsbo",
    "Linköpingsborna": "Linköpingsbo",
    "Linköpingsbornas": "Linköpingsbo",
    "Linköpingsbors": "Linköpingsbo",
    "Linköpingsbos": "Linköpingsbo",
    "Linnas": "Linna",
    "Linnés": "Linné",
    "Lis": "Li",
    "Lisan": "Lisa",
    "Lisas": "Lisa",
    "Liselotts": "Liselott",
    "Lisor": "Lisa",
    "Lisorna": "Lisa",
    "Lisornas": "Lisa",
    "Lisors": "Lisa",
    "Liszts": "Liszt",
    "Litauens": "Litauen",
    "Litorinahavets": "Litorinahavet",
    "Litorinas": "Litorina",
    "Livingstones": "Livingstone",
    "Livlands": "Livland",
    "Ljungbys": "Ljungby",
    "Ljungs": "Ljung",
    "Lo-Johanssons": "Lo-Johansson",
    "Lockes": "Locke",
    "Lofotens": "Lofoten",
    "Lokes": "Loke",
    "Lollands": "Lolland",
    "Londons": "London",
    "Lorcas": "Lorca",
    "Loreleis": "Lorelei",
    "Lort-Sveriges": "Lort-Sverige",
    "Lottans": "Lotta",
    "Lottorna": "Lotta",
    "Lottors": "Lotta",
    "Louises": "Louise",
    "Louisianas": "Louisiana",
    "Louisvilles": "Louisville",
    "Louvrens": "Louvren",
    "Lovéns": "Lovén",
    "Lu-s": "Lu",
    "Lu:s": "Lu",
    "Lucifers": "Lucifer",
    "Ludvigar": "Ludvig",
    "Ludvigarna": "Ludvig",
    "Ludvigarnas": "Ludvig",
    "Ludvigars": "Ludvig",
    "Ludvigs": "Ludvig",
    "Ludvikas": "Ludvika",
    "Lufthansas": "Lufthansa",
    "Lukasar": "Lukas",
    "Lukasarna": "Lukas",
    "Lukasarnas": "Lukas",
    "Lukasars": "Lukas",
    "Lulejaures": "Lulejaure",
    "Luleås": "Luleå",
    "Lumumbas": "Lumumba",
    "Lundbergs": "Lundberg",
    "Lundgrens": "Lundgren",
    "Lundins": "Lundin",
    "Lundkvists": "Lundkvist",
    "Lus": "Lu",
    "Lusakas": "Lusaka",
    "Luthers": "Luther",
    "Luxemburgs": "Luxemburg",
    "Lw-s": "Lw",
    "Lw:s": "Lw",
    "Lws": "Lw",
    "Lyndons": "Lyndon",
    "Lyrans": "Lyran",
    "Långholmens": "Långholmen",
    "Lönngrens": "Lönngren",
    "Lönnrots": "Lönnrot",
    "Lövstas": "Lövsta",
    "Lützens": "Lützen",
    "MAO-aktiviteten": "MAO-aktivitet",
    "MAO-aktivitetens": "MAO-aktivitet",
    "MAO-aktiviteter": "MAO-aktivitet",
    "MAO-aktiviteterna": "MAO-aktivitet",
    "MAO-aktiviteternas": "MAO-aktivitet",
    "MAO-aktiviteters": "MAO-aktivitet",
    "MAO-aktivitets": "MAO-aktivitet",
    "MAO-en": "MAO",
    "MAO-ens": "MAO",
    "MAO-enzymen": "MAO-enzym",
    "MAO-enzymens": "MAO-enzym",
    "MAO-enzymer": "MAO-enzym",
    "MAO-enzymerna": "MAO-enzym",
    "MAO-enzymernas": "MAO-enzym",
    "MAO-enzymers": "MAO-enzym",
    "MAO-enzymet": "MAO-enzym",
    "MAO-enzymets": "MAO-enzym",
    "MAO-enzyms": "MAO-enzym",
    "MAO-et": "MAO",
    "MAO-ets": "MAO",
    "MAO-n": "MAO",
    "MAO-ns": "MAO",
    "MAO-s": "MAO",
    "MAO-t": "MAO",
    "MAO-ts": "MAO",
    "MAO:en": "MAO",
    "MAO:ens": "MAO",
    "MAO:et": "MAO",
    "MAO:ets": "MAO",
    "MAO:n": "MAO",
    "MAO:ns": "MAO",
    "MAO:s": "MAO",
    "MAO:t": "MAO",
    "MAO:ts": "MAO",
    "MAOen": "MAO",
    "MAOens": "MAO",
    "MAOet": "MAO",
    "MAOets": "MAO",
    "MAOn": "MAO",
    "MAOns": "MAO",
    "MAOs": "MAO",
    "MAOt": "MAO",
    "MAOts": "MAO",
    "MC-s": "MC",
    "MCs": "MC",
    "MP3-bokens": "MP3-bok",
    "MP3-böckerna": "MP3-bok",
    "MP3-böckers": "MP3-bok",
    "MP3-spelar": "MP3-spelare",
    "MP3-spelarens": "MP3-spelare",
    "MP3-spelarna": "MP3-spelare",
    "MRA-s": "MRA",
    "MRA:s": "MRA",
    "MRAs": "MRA",
    "Macbeths": "Macbeth",
    "Macchiavellis": "Macchiavelli",
    "Macmillans": "Macmillan",
    "Madagaskars": "Madagaskar",
    "Madeleines": "Madeleine",
    "Madisons": "Madison",
    "Madrids": "Madrid",
    "Mahlers": "Mahler",
    "Mahmuds": "Mahmud",
    "Mailers": "Mailer",
    "Maines": "Maine",
    "Mais": "Mai",
    "Majakovskijs": "Majakovskij",
    "Majan": "Maja",
    "Majans": "Maja",
    "Major": "Maja",
    "Majorna": "Maja",
    "Majornas": "Maja",
    "Majors": "Maja",
    "Makedoniens": "Makedonien",
    "Malawis": "Malawi",
    "Malaysias": "Malaysia",
    "Malcolms": "Malcolm",
    "Maldivernas": "Maldiverna",
    "Malis": "Mali",
    "Mallorcas": "Mallorca",
    "Malmgrens": "Malmgren",
    "Malmkvists": "Malmkvist",
    "Malmquists": "Malmquist",
    "Malms": "Malm",
    "Malmströms": "Malmström",
    "Malmökaféer": "Malmökafé",
    "Malmökaféerna": "Malmökafé",
    "Malmökaféernas": "Malmökafé",
    "Malmökaféers": "Malmökafé",
    "Malmökafén": "Malmökafé",
    "Malmökaféns": "Malmökafé",
    "Malmökafés": "Malmökafé",
    "Malmös": "Malmö",
    "Maltas": "Malta",
    "Mammons": "Mammon",
    "Manchuriets": "Manchuriet",
    "Manilas": "Manila",
    "Mannerheims": "Mannerheim",
    "Manns": "Mann",
    "Marcels": "Marcel",
    "Marcusar": "Marcus",
    "Marcusarna": "Marcus",
    "Marcusarnas": "Marcus",
    "Marcusars": "Marcus",
    "Margaretan": "Margareta",
    "Margaretans": "Margareta",
    "Margaretas": "Margareta",
    "Margaretor": "Margareta",
    "Margaretorna": "Margareta",
    "Margaretornas": "Margareta",
    "Margaretors": "Margareta",
    "Margaritan": "Margarita",
    "Margaritans": "Margarita",
    "Margaritas": "Margarita",
    "Margaritor": "Margarita",
    "Margaritorna": "Margarita",
    "Margaritornas": "Margarita",
    "Margaritors": "Margarita",
    "Marian": "Maria",
    "Mariannes": "Marianne",
    "Marians": "Maria",
    "Marias": "Maria",
    "Maries": "Marie",
    "Marior": "Maria",
    "Mariorna": "Maria",
    "Mariornas": "Maria",
    "Mariors": "Maria",
    "Marios": "Mario",
    "Maris": "Mari",
    "Marklunds": "Marklund",
    "Markusar": "Markus",
    "Markusarna": "Markus",
    "Markusarnas": "Markus",
    "Markusars": "Markus",
    "Marlboros": "Marlboro",
    "Marlenes": "Marlene",
    "Marockos": "Marocko",
    "Marseillebaserade": "Marseillebaserad",
    "Marseillebaserades": "Marseillebaserad",
    "Marseillebaserads": "Marseillebaserad",
    "Marseillebaserat": "Marseillebaserad",
    "Marseillebaserats": "Marseillebaserad",
    "Marseilles": "Marseille",
    "Marseljäsens": "Marseljäsen",
    "Marsresan": "Marsresa",
    "Marsresans": "Marsresa",
    "Marsresas": "Marsresa",
    "Marsrese": "Marsresa",
    "Marsresor": "Marsresa",
    "Marsresorna": "Marsresa",
    "Marsresornas": "Marsresa",
    "Marsresors": "Marsresa",
    "Martinellis": "Martinelli",
    "Martins": "Martin",
    "Martinssonen": "Martinsson",
    "Martinssonens": "Martinsson",
    "Martinssons": "Martinsson",
    "Martinssöner": "Martinsson",
    "Martinssönerna": "Martinsson",
    "Martinssönernas": "Martinsson",
    "Martinssöners": "Martinsson",
    "Marvikens": "Marviken",
    "Marvins": "Marvin",
    "Marylands": "Maryland",
    "Marys": "Mary",
    "Masaryks": "Masaryk",
    "Mathssonen": "Mathsson",
    "Mathssonens": "Mathsson",
    "Mathssons": "Mathsson",
    "Mathssöner": "Mathsson",
    "Mathssönerna": "Mathsson",
    "Mathssönernas": "Mathsson",
    "Mathssöners": "Mathsson",
    "Matisses": "Matisse",
    "Matssonen": "Matsson",
    "Matssonens": "Matsson",
    "Matssons": "Matsson",
    "Matssöner": "Matsson",
    "Matssönerna": "Matsson",
    "Matssönernas": "Matsson",
    "Matssöners": "Matsson",
    "Matteusar": "Matteus",
    "Matteusarna": "Matteus",
    "Matteusarnas": "Matteus",
    "Matteusars": "Matteus",
    "Mattis": "Matti",
    "Maughams": "Maugham",
    "Maupassants": "Maupassant",
    "Mauretaniens": "Mauretanien",
    "Maxar": "Max",
    "Maxarna": "Max",
    "Maxarnas": "Max",
    "Maxars": "Max",
    "Maxwells": "Maxwell",
    "Mayarikets": "Mayariket",
    "Mayflowers": "Mayflower",
    "Mays": "May",
    "Md-s": "Md",
    "Md:s": "Md",
    "Mds": "Md",
    "Medborgarskolans": "Medborgarskolan",
    "Medelhavets": "Medelhavet",
    "Medelhavslandet": "Medelhavsland",
    "Medelhavslandets": "Medelhavsland",
    "Medelhavslands": "Medelhavsland",
    "Medelhavsländer": "Medelhavsland",
    "Medelhavsländerna": "Medelhavsland",
    "Medelhavsländernas": "Medelhavsland",
    "Medelhavsländers": "Medelhavsland",
    "Medelhavsområdets": "Medelhavsområdet",
    "Medelpads": "Medelpad",
    "Medvedevs": "Medvedev",
    "Meerkels": "Meerkel",
    "Mehrs": "Mehr",
    "Meirs": "Meir",
    "Melanesiens": "Melanesien",
    "Mellansveriges": "Mellansverige",
    "Melpomenes": "Melpomene",
    "Mendels": "Mendel",
    "Menuhins": "Menuhin",
    "Mercan": "Merca",
    "Mercas": "Merca",
    "Mercedesar": "Mercedes",
    "Mercedesarnas": "Mercedes",
    "Mercedesens": "Mercedes",
    "Mercorna": "Merca",
    "Mersan": "Mersa",
    "Mersas": "Mersa",
    "Mersor": "Mersa",
    "Mersorna": "Mersa",
    "Mesopotamiens": "Mesopotamien",
    "Metallarbetareförbundets": "Metallarbetareförbundet",
    "Metallarbetarförbundets": "Metallarbetarförbundet",
    "Metallordföranden": "Metallordförande",
    "Metallordförandena": "Metallordförande",
    "Metallordförandenas": "Metallordförande",
    "Metallordförandens": "Metallordförande",
    "Metallordförandes": "Metallordförande",
    "Metropolitans": "Metropolitan",
    "Mexikos": "Mexiko",
    "Mg-s": "Mg",
    "Mg:s": "Mg",
    "MgSO4-s": "MgSO4",
    "MgSO4:s": "MgSO4",
    "MgSO4s": "MgSO4",
    "Mgs": "Mg",
    "Michaels": "Michael",
    "Michelangelos": "Michelangelo",
    "Michels": "Michel",
    "Michelsons": "Michelson",
    "Michigans": "Michigan",
    "Micrographias": "Micrographia",
    "Mikaels": "Mikael",
    "Miklagårds": "Miklagård",
    "Mikronesiens": "Mikronesien",
    "Milanos": "Milano",
    "Miljöpartiets": "Miljöpartiet",
    "Millers": "Miller",
    "Milnes": "Milne",
    "Milwaukees": "Milwaukee",
    "Minervas": "Minerva",
    "Minnesotas": "Minnesota",
    "Mirandas": "Miranda",
    "Miros": "Miro",
    "Missionsförbundets": "Missionsförbundet",
    "Mississippis": "Mississippi",
    "Missouris": "Missouri",
    "Mitterands": "Mitterand",
    "Mn-s": "Mn",
    "Mn:s": "Mn",
    "Mns": "Mn",
    "Mo-s": "Mo",
    "Mo:s": "Mo",
    "Mobergs": "Moberg",
    "Mocambiques": "Mocambique",
    "Moderaternas": "Moderaterna",
    "Mogontiacums": "Mogontiacum",
    "Mohameds": "Mohamed",
    "Mohammeds": "Mohammed",
    "Mohamuds": "Mohamud",
    "Moldaviens": "Moldavien",
    "Moldovas": "Moldova",
    "Molins": "Molin",
    "Molières": "Molière",
    "Moltkes": "Moltke",
    "Monacos": "Monaco",
    "Monalisas": "Monalisa",
    "Monan": "Mona",
    "Monans": "Mona",
    "Monas": "Mona",
    "Monets": "Monet",
    "Monican": "Monica",
    "Monicans": "Monica",
    "Monicas": "Monica",
    "Monicor": "Monica",
    "Monicorna": "Monica",
    "Monicornas": "Monica",
    "Monicors": "Monica",
    "Monikan": "Monika",
    "Monikans": "Monika",
    "Monikas": "Monika",
    "Monikor": "Monika",
    "Monikorna": "Monika",
    "Monikornas": "Monika",
    "Monikors": "Monika",
    "Monor": "Mona",
    "Monorna": "Mona",
    "Monornas": "Mona",
    "Monors": "Mona",
    "Monrovias": "Monrovia",
    "Montaignes": "Montaigne",
    "Montanas": "Montana",
    "Montenegros": "Montenegro",
    "Montesquieus": "Montesquieu",
    "Monteverdis": "Monteverdi",
    "Montevideos": "Montevideo",
    "Montgomerys": "Montgomery",
    "Montpeliers": "Montpelier",
    "Mora-Nissar": "Mora-Nisse",
    "Mora-Nissarna": "Mora-Nisse",
    "Mora-Nissarnas": "Mora-Nisse",
    "Mora-Nissars": "Mora-Nisse",
    "Mora-Nisses": "Mora-Nisse",
    "Moras": "Mora",
    "Moravias": "Moravia",
    "Morgans": "Morgan",
    "Morganucodons": "Morganucodon",
    "Morleys": "Morley",
    "Morses": "Morse",
    "Moseboken": "Mosebok",
    "Mosebokens": "Mosebok",
    "Moseboks": "Mosebok",
    "Moseböcker": "Mosebok",
    "Moseböckerna": "Mosebok",
    "Moseböckernas": "Mosebok",
    "Moseböckers": "Mosebok",
    "Moses": "Mose",
    "Moskvas": "Moskva",
    "Moskvatrogenheten": "Moskvatrogenhet",
    "Moskvatrogenhetens": "Moskvatrogenhet",
    "Moskvatrogenhets": "Moskvatrogenhet",
    "Moskvatrogens": "Moskvatrogen",
    "Moskvatroget": "Moskvatrogen",
    "Moskvatrogets": "Moskvatrogen",
    "Moskvatrogna": "Moskvatrogen",
    "Moskvatrognare": "Moskvatrogen",
    "Moskvatrognares": "Moskvatrogen",
    "Moskvatrognas": "Moskvatrogen",
    "Moskvatrognast": "Moskvatrogen",
    "Moskvatrognaste": "Moskvatrogen",
    "Moskvatrognastes": "Moskvatrogen",
    "Moskvatrognasts": "Moskvatrogen",
    "Moskvatrogne": "Moskvatrogen",
    "Moskvatrognes": "Moskvatrogen",
    "Motanders": "Motander",
    "Mozarts": "Mozart",
    "Moçambiques": "Moçambique",
    "Mp:s": "Mp",
    "Mps": "Mp",
    "Ms": "M",
    "Muhammeds": "Muhammed",
    "Mumintrollets": "Mumintrollet",
    "Munchlitografien": "Munchlitografi",
    "Munchlitografiens": "Munchlitografi",
    "Munchlitografier": "Munchlitografi",
    "Munchlitografierna": "Munchlitografi",
    "Munchlitografiernas": "Munchlitografi",
    "Munchlitografiers": "Munchlitografi",
    "Munchlitografin": "Munchlitografi",
    "Munchlitografins": "Munchlitografi",
    "Munchlitografis": "Munchlitografi",
    "Munchs": "Munch",
    "Murmansks": "Murmansk",
    "Musikforums": "Musikforum",
    "Musils": "Musil",
    "Mussolinis": "Mussolini",
    "Myanmars": "Myanmar",
    "Myanmas": "Myanma",
    "Myrdals": "Myrdal",
    "Myzostomums": "Myzostomum",
    "Mälardalens": "Mälardalen",
    "Mälarens": "Mälaren",
    "Månens": "Månen",
    "Möllers": "Möller",
    "Mölndals": "Mölndal",
    "Münchens": "München",
    "Münchhausens": "Münchhausen",
    "N.N.-s": "N.N.",
    "N.N.:s": "N.N.",
    "N.N.s": "N.N.",
    "NASA-s": "NASA",
    "NASA:s": "NASA",
    "NASAs": "NASA",
    "NATO-s": "NATO",
    "NATO:s": "NATO",
    "NATOs": "NATO",
    "NF-s": "NF",
    "NF:s": "NF",
    "NFs": "NF",
    "NK-s": "NK",
    "NK:s": "NK",
    "NKs": "NK",
    "NN-s": "NN",
    "NN:s": "NN",
    "NNs": "NN",
    "NOs": "NO",
    "Na-s": "Na",
    "Na2HPO4-s": "Na2HPO4",
    "Na2HPO4:s": "Na2HPO4",
    "Na2HPO4s": "Na2HPO4",
    "Na2SO4-s": "Na2SO4",
    "Na2SO4:s": "Na2SO4",
    "Na2SO4s": "Na2SO4",
    "Na:s": "Na",
    "NaCl-s": "NaCl",
    "NaCl:s": "NaCl",
    "NaCls": "NaCl",
    "NaHCO3-s": "NaHCO3",
    "NaHCO3:s": "NaHCO3",
    "NaHCO3s": "NaHCO3",
    "Nagasakis": "Nagasaki",
    "Nairobis": "Nairobi",
    "Nallos": "Nallo",
    "Namibias": "Namibia",
    "Nansens": "Nansen",
    "Napoleons": "Napoleon",
    "Naranjos": "Naranjo",
    "Narviks": "Narvik",
    "Nas": "Na",
    "Nasarets": "Nasaret",
    "Nashvilles": "Nashville",
    "Nassers": "Nasser",
    "Natans": "Natan",
    "Natosoldaten": "Natosoldat",
    "Natosoldatens": "Natosoldat",
    "Natosoldater": "Natosoldat",
    "Natosoldaterna": "Natosoldat",
    "Natosoldaternas": "Natosoldat",
    "Natosoldaters": "Natosoldat",
    "Natosoldats": "Natosoldat",
    "Naumans": "Nauman",
    "Naurus": "Nauru",
    "Nb-s": "Nb",
    "Nb:s": "Nb",
    "Nbs": "Nb",
    "Nd-s": "Nd",
    "Nd:s": "Nd",
    "Nds": "Nd",
    "Ne-s": "Ne",
    "Ne:s": "Ne",
    "Neapels": "Neapel",
    "Nebraskas": "Nebraska",
    "Nebukadnesars": "Nebukadnesar",
    "Nederländernas": "Nederländerna",
    "Nehrus": "Nehru",
    "Neitiläs": "Neitilä",
    "Nellys": "Nelly",
    "Nelsons": "Nelson",
    "Nepals": "Nepal",
    "Nermans": "Nerman",
    "Neros": "Nero",
    "Nerudas": "Neruda",
    "Nes": "Ne",
    "Neumanns": "Neumann",
    "Nevadas": "Nevada",
    "Newarks": "Newark",
    "Newcastlesjukan": "Newcastlesjuka",
    "Newcastlesjukans": "Newcastlesjuka",
    "Newcastlesjukas": "Newcastlesjuka",
    "Newcastlesjuke": "Newcastlesjuka",
    "Newcastlesjuks": "Newcastlesjuka",
    "Newcastlesmittan": "Newcastlesmitta",
    "Newcastlesmittans": "Newcastlesmitta",
    "Newcastlesmittas": "Newcastlesmitta",
    "Newcastlesmitte": "Newcastlesmitta",
    "Newcastlesmitts": "Newcastlesmitta",
    "Newfoundlands": "Newfoundland",
    "Newtons": "Newton",
    "Ni-s": "Ni",
    "Ni:s": "Ni",
    "Nicaraguas": "Nicaragua",
    "Nices": "Nice",
    "Nielsens": "Nielsen",
    "Nietzsches": "Nietzsche",
    "Nifelhems": "Nifelhem",
    "Nigerias": "Nigeria",
    "Nigers": "Niger",
    "Nightingales": "Nightingale",
    "Nikes": "Nike",
    "Nilens": "Nilen",
    "Nilsar": "Nils",
    "Nilsarna": "Nils",
    "Nilsarnas": "Nils",
    "Nilsars": "Nils",
    "Nilssonen": "Nilsson",
    "Nilssonens": "Nilsson",
    "Nilssons": "Nilsson",
    "Nilssöner": "Nilsson",
    "Nilssönerna": "Nilsson",
    "Nilssönernas": "Nilsson",
    "Nilssöners": "Nilsson",
    "Ninives": "Ninive",
    "Nis": "Ni",
    "Nissans": "Nissan",
    "Nissar": "Nisse",
    "Nissarnas": "Nisse",
    "Nittonhundraåttiofyras": "Nittonhundraåttiofyra",
    "Nixons": "Nixon",
    "Njörvasunds": "Njörvasund",
    "Nkrumahs": "Nkrumah",
    "No-s": "No",
    "No:s": "No",
    "Nobelprisets": "Nobelpriset",
    "Nobels": "Nobel",
    "Noras": "Nora",
    "Norasjöns": "Norasjön",
    "Nord-Vietnams": "Nord-Vietnam",
    "Nordafrikas": "Nordafrika",
    "Nordahls": "Nordahl",
    "Nordamerikas": "Nordamerika",
    "Nordatlantens": "Nordatlanten",
    "Nordens": "Norden",
    "Nordeuropas": "Nordeuropa",
    "Nordins": "Nordin",
    "Nordirlands": "Nordirland",
    "Nordjemens": "Nordjemen",
    "Nordkoreas": "Nordkorea",
    "Nordnorges": "Nordnorge",
    "Nordpolens": "Nordpolen",
    "Nordrysslands": "Nordryssland",
    "Nordsjökusts": "Nordsjökust",
    "Nordsjöns": "Nordsjön",
    "Nordströms": "Nordström",
    "Nordsveriges": "Nordsverige",
    "Nordtysklands": "Nordtyskland",
    "Nordvietnams": "Nordvietnam",
    "Nordvästeuropas": "Nordvästeuropa",
    "Nordyemens": "Nordyemen",
    "Noreens": "Noreen",
    "Norges": "Norge",
    "Normandies": "Normandie",
    "Normans": "Norman",
    "Norrbottens": "Norrbotten",
    "Norrköpings": "Norrköping",
    "Norrlands": "Norrland",
    "Norrtäljefängelsets": "Norrtäljefängelset",
    "Norrtäljes": "Norrtälje",
    "Novgorods": "Novgorod",
    "Novosibirsks": "Novosibirsk",
    "Np-s": "Np",
    "Np:s": "Np",
    "Nps": "Np",
    "Ns": "N",
    "Nubiens": "Nubien",
    "Nurmis": "Nurmi",
    "Nybergs": "Nyberg",
    "Nybergsunds": "Nybergsund",
    "Nybros": "Nybro",
    "Nyereres": "Nyerere",
    "Nygrens": "Nygren",
    "Nykvists": "Nykvist",
    "Nylands": "Nyland",
    "Nyströms": "Nyström",
    "Närkes": "Närke",
    "O'Neills": "O'Neill",
    "O-s": "O",
    "O2-s": "O2",
    "O2:s": "O2",
    "O2s": "O2",
    "O3-s": "O3",
    "O3:s": "O3",
    "O3s": "O3",
    "OCR-ad": "OCR-a",
    "OCR-ade": "OCR-a",
    "OCR-ades": "OCR-a",
    "OCR-ads": "OCR-a",
    "OCR-ande": "OCR-a",
    "OCR-andes": "OCR-ande",
    "OCR-andet": "OCR-ande",
    "OCR-andets": "OCR-ande",
    "OCR-ar": "OCR-a",
    "OCR-as": "OCR-a",
    "OCR-at": "OCR-a",
    "OCR-ats": "OCR-a",
    "OCR-s": "OCR",
    "OCR:ad": "OCR:a",
    "OCR:ade": "OCR:a",
    "OCR:ades": "OCR:a",
    "OCR:ads": "OCR:a",
    "OCR:ande": "OCR:a",
    "OCR:andes": "OCR:ande",
    "OCR:andet": "OCR:ande",
    "OCR:andets": "OCR:ande",
    "OCR:ar": "OCR:a",
    "OCR:as": "OCR:a",
    "OCR:at": "OCR:a",
    "OCR:ats": "OCR:a",
    "OCR:s": "OCR",
    "OCRs": "OCR",
    "OD-s": "OD",
    "OD:s": "OD",
    "ODs": "OD",
    "OECD-landet": "OECD-land",
    "OECD-landets": "OECD-land",
    "OECD-lands": "OECD-land",
    "OECD-länder": "OECD-land",
    "OECD-länderna": "OECD-land",
    "OECD-ländernas": "OECD-land",
    "OECD-länders": "OECD-land",
    "OECD-s": "OECD",
    "OECD:s": "OECD",
    "OECDs": "OECD",
    "OPEC-s": "OPEC",
    "OPEC:s": "OPEC",
    "OPECs": "OPEC",
    "Obamas": "Obama",
    "Oberons": "Oberon",
    "Obs": "Ob",
    "Occidentens": "Occidenten",
    "Oceaniens": "Oceanien",
    "Odens": "Oden",
    "Odysséens": "Odysséen",
    "Ofvandahls": "Ofvandahl",
    "Ohios": "Ohio",
    "Ohlins": "Ohlin",
    "Ohlssonen": "Ohlsson",
    "Ohlssonens": "Ohlsson",
    "Ohlssons": "Ohlsson",
    "Ohlssöner": "Ohlsson",
    "Ohlssönerna": "Ohlsson",
    "Ohlssönernas": "Ohlsson",
    "Ohlssöners": "Ohlsson",
    "Ojstrachs": "Ojstrach",
    "Oklahomas": "Oklahoma",
    "Olavs": "Olav",
    "Oles": "Ole",
    "Ollar": "Olle",
    "Ollarnas": "Olle",
    "Olofar": "Olof",
    "Olofarna": "Olof",
    "Olofarnas": "Olof",
    "Olofars": "Olof",
    "Olofs": "Olof",
    "Olofssonen": "Olofsson",
    "Olofssonens": "Olofsson",
    "Olofssons": "Olofsson",
    "Olofssöner": "Olofsson",
    "Olofssönerna": "Olofsson",
    "Olofssönernas": "Olofsson",
    "Olofssöners": "Olofsson",
    "Olsens": "Olsen",
    "Olssonen": "Olsson",
    "Olssonens": "Olsson",
    "Olssons": "Olsson",
    "Olssöner": "Olsson",
    "Olssönerna": "Olsson",
    "Olssönernas": "Olsson",
    "Olssöners": "Olsson",
    "Olympens": "Olympen",
    "Olympias": "Olympia",
    "Omahas": "Omaha",
    "Omans": "Oman",
    "Omars": "Omar",
    "Omsks": "Omsk",
    "Opels": "Opel",
    "Operabalettens": "Operabaletten",
    "Operans": "Operan",
    "Oppenheimers": "Oppenheimer",
    "Oredar": "Ored",
    "Oredarna": "Ored",
    "Oredarnas": "Ored",
    "Oredars": "Ored",
    "Oreds": "Ored",
    "Oregons": "Oregon",
    "Orelands": "Oreland",
    "Orels": "Orel",
    "Orientens": "Orienten",
    "Orions": "Orion",
    "Orusts": "Orust",
    "Orwells": "Orwell",
    "Os-s": "Os",
    "Os:s": "Os",
    "Osakas": "Osaka",
    "Oscars": "Oscar",
    "Oscarssonen": "Oscarsson",
    "Oscarssonens": "Oscarsson",
    "Oscarssons": "Oscarsson",
    "Oscarssöner": "Oscarsson",
    "Oscarssönerna": "Oscarsson",
    "Oscarssönernas": "Oscarsson",
    "Oscarssöners": "Oscarsson",
    "Oskars": "Oskar",
    "Oskarshamns": "Oskarshamn",
    "Oslos": "Oslo",
    "Oss": "Os",
    "Ostindiens": "Ostindien",
    "Oswalds": "Oswald",
    "Othellos": "Othello",
    "Ottawas": "Ottawa",
    "Ottos": "Otto",
    "Ottossonen": "Ottosson",
    "Ottossonens": "Ottosson",
    "Ottossons": "Ottosson",
    "Ottossöner": "Ottosson",
    "Ottossönerna": "Ottosson",
    "Ottossönernas": "Ottosson",
    "Ottossöners": "Ottosson",
    "Ovar": "Ove",
    "Ovarna": "Ove",
    "Ovarnas": "Ove",
    "Ovars": "Ove",
    "Oves": "Ove",
    "Oxens": "Oxen",
    "Oxenstiernas": "Oxenstierna",
    "Oxfords": "Oxford",
    "Oxfordstudenten": "Oxfordstudent",
    "Oxfordstudentens": "Oxfordstudent",
    "Oxfordstudenter": "Oxfordstudent",
    "Oxfordstudenterna": "Oxfordstudent",
    "Oxfordstudenternas": "Oxfordstudent",
    "Oxfordstudenters": "Oxfordstudent",
    "Oxfordstudents": "Oxfordstudent",
    "P-s": "P",
    "P1-s": "P1",
    "P1:s": "P1",
    "P1s": "P1",
    "P2-s": "P2",
    "P2:s": "P2",
    "P2s": "P2",
    "P3-s": "P3",
    "P3:s": "P3",
    "P3s": "P3",
    "P4-s": "P4",
    "P4:s": "P4",
    "P4s": "P4",
    "PCB-en": "PCB",
    "PCB-ens": "PCB",
    "PCB-et": "PCB",
    "PCB-ets": "PCB",
    "PCB-förbuden": "PCB-förbud",
    "PCB-förbudens": "PCB-förbud",
    "PCB-förbudet": "PCB-förbud",
    "PCB-förbudets": "PCB-förbud",
    "PCB-förbuds": "PCB-förbud",
    "PCB-föreningar": "PCB-förening",
    "PCB-föreningarna": "PCB-förening",
    "PCB-föreningarnas": "PCB-förening",
    "PCB-föreningars": "PCB-förening",
    "PCB-föreningen": "PCB-förening",
    "PCB-föreningens": "PCB-förening",
    "PCB-förenings": "PCB-förening",
    "PCB-förgiftningar": "PCB-förgiftning",
    "PCB-förgiftningarna": "PCB-förgiftning",
    "PCB-förgiftningarnas": "PCB-förgiftning",
    "PCB-förgiftningars": "PCB-förgiftning",
    "PCB-förgiftningen": "PCB-förgiftning",
    "PCB-förgiftningens": "PCB-förgiftning",
    "PCB-förgiftnings": "PCB-förgiftning",
    "PCB-halten": "PCB-halt",
    "PCB-haltens": "PCB-halt",
    "PCB-halter": "PCB-halt",
    "PCB-halterna": "PCB-halt",
    "PCB-halternas": "PCB-halt",
    "PCB-halters": "PCB-halt",
    "PCB-halts": "PCB-halt",
    "PCB-n": "PCB",
    "PCB-ns": "PCB",
    "PCB-oljan": "PCB-olja",
    "PCB-oljans": "PCB-olja",
    "PCB-oljas": "PCB-olja",
    "PCB-olje": "PCB-olja",
    "PCB-oljor": "PCB-olja",
    "PCB-oljorna": "PCB-olja",
    "PCB-oljornas": "PCB-olja",
    "PCB-oljors": "PCB-olja",
    "PCB-s": "PCB",
    "PCB-t": "PCB",
    "PCB-ts": "PCB",
    "PCB:en": "PCB",
    "PCB:ens": "PCB",
    "PCB:et": "PCB",
    "PCB:ets": "PCB",
    "PCB:n": "PCB",
    "PCB:ns": "PCB",
    "PCB:s": "PCB",
    "PCB:t": "PCB",
    "PCB:ts": "PCB",
    "PCBen": "PCB",
    "PCBens": "PCB",
    "PCBet": "PCB",
    "PCBets": "PCB",
    "PCBn": "PCB",
    "PCBns": "PCB",
    "PCBs": "PCB",
    "PCBt": "PCB",
    "PCBts": "PCB",
    "PDA-er": "PDA",
    "PDA-erna": "PDA",
    "PDA-ernas": "PDA",
    "PDA-ers": "PDA",
    "PDA-n": "PDA",
    "PDA-ns": "PDA",
    "PDA-s": "PDA",
    "PDA:er": "PDA",
    "PDA:erna": "PDA",
    "PDA:ernas": "PDA",
    "PDA:ers": "PDA",
    "PDA:n": "PDA",
    "PDA:ns": "PDA",
    "PDA:s": "PDA",
    "PDAer": "PDA",
    "PDAerna": "PDA",
    "PDAernas": "PDA",
    "PDAers": "PDA",
    "PDAn": "PDA",
    "PDAns": "PDA",
    "PDAs": "PDA",
    "PIN-koden": "PIN-kod",
    "PIN-kodens": "PIN-kod",
    "PIN-koder": "PIN-kod",
    "PIN-koderna": "PIN-kod",
    "PIN-kodernas": "PIN-kod",
    "PIN-koders": "PIN-kod",
    "PIN-kods": "PIN-kod",
    "PLO-s": "PLO",
    "PLO:s": "PLO",
    "PLOs": "PLO",
    "PM-en": "PM",
    "PM-ens": "PM",
    "PM-et": "PM",
    "PM-ets": "PM",
    "PM-na": "PM",
    "PM-nas": "PM",
    "PM:en": "PM",
    "PM:ens": "PM",
    "PM:et": "PM",
    "PM:ets": "PM",
    "PM:na": "PM",
    "PM:nas": "PM",
    "PM:s": "PM",
    "PMen": "PM",
    "PMens": "PM",
    "PMet": "PM",
    "PMets": "PM",
    "PMna": "PM",
    "PMnas": "PM",
    "PMs": "PM",
    "PR-kuppen": "PR-kupp",
    "PR-kuppens": "PR-kupp",
    "PR-kupper": "PR-kupp",
    "PR-kupperna": "PR-kupp",
    "PR-kuppernas": "PR-kupp",
    "PR-kuppers": "PR-kupp",
    "PR-kupps": "PR-kupp",
    "PR-mannen": "PR-man",
    "PR-mannens": "PR-man",
    "PR-mans": "PR-man",
    "PR-män": "PR-man",
    "PR-männen": "PR-man",
    "PR-männens": "PR-man",
    "PR-mäns": "PR-man",
    "PRAO-s": "PRAO",
    "PRAO:s": "PRAO",
    "PRs": "PR",
    "PVC-beläggningar": "PVC-beläggning",
    "PVC-beläggningarna": "PVC-beläggning",
    "PVC-beläggningarnas": "PVC-beläggning",
    "PVC-beläggningars": "PVC-beläggning",
    "PVC-beläggningen": "PVC-beläggning",
    "PVC-beläggningens": "PVC-beläggning",
    "PVC-beläggnings": "PVC-beläggning",
    "PVC-n": "PVC",
    "PVC-na": "PVC",
    "PVC-nas": "PVC",
    "PVC-ns": "PVC",
    "PVC-s": "PVC",
    "PVC:n": "PVC",
    "PVC:na": "PVC",
    "PVC:nas": "PVC",
    "PVC:ns": "PVC",
    "PVC:s": "PVC",
    "PVCn": "PVC",
    "PVCna": "PVC",
    "PVCnas": "PVC",
    "PVCns": "PVC",
    "PVCs": "PVC",
    "Pa-s": "Pa",
    "Pa:s": "Pa",
    "Paasikivis": "Paasikivi",
    "Pablos": "Pablo",
    "Paganinis": "Paganini",
    "Palaus": "Palau",
    "Palermos": "Palermo",
    "Palestinas": "Palestina",
    "Palestrinas": "Palestrina",
    "Palmes": "Palme",
    "Pamplonas": "Pamplona",
    "Panduros": "Panduro",
    "Pans": "Pan",
    "Papyrusaktien": "Papyrusaktie",
    "Papyrusaktiens": "Papyrusaktie",
    "Papyrusaktier": "Papyrusaktie",
    "Papyrusaktierna": "Papyrusaktie",
    "Papyrusaktiernas": "Papyrusaktie",
    "Papyrusaktiers": "Papyrusaktie",
    "Papyrusakties": "Papyrusaktie",
    "Paraguays": "Paraguay",
    "Pariskommunens": "Pariskommunen",
    "Parkers": "Parker",
    "Parkvägens": "Parkvägen",
    "Parsifals": "Parsifal",
    "Pas": "Pa",
    "Pasternaks": "Pasternak",
    "Pasteurs": "Pasteur",
    "Pattons": "Patton",
    "Paular": "Paul",
    "Paularna": "Paul",
    "Paularnas": "Paul",
    "Paulars": "Paul",
    "Pauls": "Paul",
    "Pavarottis": "Pavarotti",
    "Pavlovas": "Pavlova",
    "Pavlovs": "Pavlov",
    "Pb-s": "Pb",
    "Pb:s": "Pb",
    "Pbs": "Pb",
    "Pd-s": "Pd",
    "Pd:s": "Pd",
    "Pds": "Pd",
    "Peders": "Peder",
    "Pehrar": "Pehr",
    "Pehrarna": "Pehr",
    "Pehrarnas": "Pehr",
    "Pehrars": "Pehr",
    "Pehrs": "Pehr",
    "Pekings": "Peking",
    "Pelés": "Pelé",
    "Pennsylvanias": "Pennsylvania",
    "Penroses": "Penrose",
    "Pensers": "Penser",
    "Pentagons": "Pentagon",
    "Penzas": "Penza",
    "Per-Arnar": "Per-Arne",
    "Per-Arnarna": "Per-Arne",
    "Per-Arnarnas": "Per-Arne",
    "Per-Arnars": "Per-Arne",
    "Per-Arnes": "Per-Arne",
    "Perar": "Per",
    "Perarna": "Per",
    "Perarnas": "Per",
    "Perars": "Per",
    "Perons": "Peron",
    "Perriers": "Perrier",
    "Pers": "Per",
    "Persiens": "Persien",
    "Perssonen": "Persson",
    "Perssonens": "Persson",
    "Perssons": "Persson",
    "Perssöner": "Persson",
    "Perssönerna": "Persson",
    "Perssönernas": "Persson",
    "Perssöners": "Persson",
    "Perus": "Peru",
    "Peters": "Peter",
    "Petersburgs": "Petersburg",
    "Peterson-Bergers": "Peterson-Berger",
    "Petersonen": "Peterson",
    "Petersonens": "Peterson",
    "Petersons": "Peterson",
    "Peterssonen": "Petersson",
    "Peterssonens": "Petersson",
    "Peterssons": "Petersson",
    "Peterssöner": "Petersson",
    "Peterssönerna": "Petersson",
    "Peterssönernas": "Petersson",
    "Peterssöners": "Petersson",
    "Petersöner": "Peterson",
    "Petersönerna": "Peterson",
    "Petersönernas": "Peterson",
    "Petersöners": "Peterson",
    "Petrarcas": "Petrarca",
    "Petris": "Petri",
    "Petterssonen": "Pettersson",
    "Petterssonens": "Pettersson",
    "Petterssons": "Pettersson",
    "Petterssöner": "Pettersson",
    "Petterssönerna": "Pettersson",
    "Petterssönernas": "Pettersson",
    "Petterssöners": "Pettersson",
    "Petöfis": "Petöfi",
    "Philadelphias": "Philadelphia",
    "Philips": "Philip",
    "Piafs": "Piaf",
    "Picassos": "Picasso",
    "Pierrar": "Pierre",
    "Pierrarna": "Pierre",
    "Pierrarnas": "Pierre",
    "Pierrars": "Pierre",
    "Pierres": "Pierre",
    "Pilsudskis": "Pilsudski",
    "Pingstkyrkans": "Pingstkyrkan",
    "Pinochets": "Pinochet",
    "Pinters": "Pinter",
    "Piratpartiets": "Piratpartiet",
    "Pistolteaterns": "Pistolteatern",
    "Piteås": "Piteå",
    "Plancks": "Planck",
    "Platons": "Platon",
    "Plejadernas": "Plejaderna",
    "Plisetskajas": "Plisetskaja",
    "Plutos": "Pluto",
    "Pm-s": "Pm",
    "Pn-s": "Pn",
    "Pn:s": "Pn",
    "Pns": "Pn",
    "Po-s": "Po",
    "Po:s": "Po",
    "Poes": "Poe",
    "Polanskis": "Polanski",
    "Polarforskningssekretariatets": "Polarforskningssekretariatet",
    "Polarsterns": "Polarstern",
    "Polens": "Polen",
    "Polhems": "Polhem",
    "Polisens": "Polisen",
    "Polstjärnans": "Polstjärnan",
    "Poltavas": "Poltava",
    "Polyhymnias": "Polyhymnia",
    "Polynesiens": "Polynesien",
    "Pommerns": "Pommern",
    "Pompejis": "Pompeji",
    "Pompidous": "Pompidou",
    "Portlands": "Portland",
    "Portugals": "Portugal",
    "Pos": "Po",
    "Poseidons": "Poseidon",
    "Poular": "Poul",
    "Poularna": "Poul",
    "Poularnas": "Poul",
    "Poulars": "Poul",
    "Pouls": "Poul",
    "Pounds": "Pound",
    "Povels": "Povel",
    "Pr-s": "Pr",
    "Pr:s": "Pr",
    "Prags": "Prag",
    "Pravdas": "Pravda",
    "Predikarens": "Predikaren",
    "Presleys": "Presley",
    "Preussens": "Preussen",
    "Prodis": "Prodi",
    "Prokofjevs": "Prokofjev",
    "Prousts": "Proust",
    "Provences": "Provence",
    "Providences": "Providence",
    "Prästgatans": "Prästgatan",
    "Ps": "P",
    "Psaltarens": "Psaltaren",
    "Pt-s": "Pt",
    "Pt:s": "Pt",
    "Pts": "Pt",
    "Puccinis": "Puccini",
    "Pusjkins": "Pusjkin",
    "Putins": "Putin",
    "Pyramidens": "Pyramiden",
    "Pyrenéernas": "Pyrenéerna",
    "Pärar": "Pär",
    "Pärarna": "Pär",
    "Pärarnas": "Pär",
    "Pärars": "Pär",
    "Pärs": "Pär",
    "Påsköns": "Påskön",
    "Q-s": "Q",
    "Q1-s": "Q1",
    "Q1:s": "Q1",
    "Q1s": "Q1",
    "Q2-s": "Q2",
    "Q2:s": "Q2",
    "Q2s": "Q2",
    "Q3-s": "Q3",
    "Q3:s": "Q3",
    "Q3s": "Q3",
    "Q4-s": "Q4",
    "Q4:s": "Q4",
    "Q4s": "Q4",
    "Qatars": "Qatar",
    "Qs": "Q",
    "Quijotes": "Quijote",
    "Quitos": "Quito",
    "RF-ID-s": "RF-ID",
    "RF-ID-t": "RF-ID",
    "RF-ID:n": "RF-ID",
    "RF-ID:ns": "RF-ID",
    "RF-ID:s": "RF-ID",
    "RF-ID:t": "RF-ID",
    "RF-ID:ts": "RF-ID",
    "RF-IDns": "RF-ID",
    "RF-IDs": "RF-ID",
    "RF-id:na": "RF-id",
    "RF-id:nas": "RF-id",
    "RF-idn": "RF-id",
    "RF-idna": "RF-id",
    "RF-idnas": "RF-id",
    "RF-idt": "RF-id",
    "RF-idts": "RF-id",
    "RFID-n": "RFID",
    "RFID-ts": "RFID",
    "RFIDnas": "RFID",
    "RFIDns": "RFID",
    "RFIDs": "RFID",
    "RFIDt": "RFID",
    "RFIDts": "RFID",
    "RLF-s": "RLF",
    "RLF:s": "RLF",
    "RLFs": "RLF",
    "ROT-avdragen": "ROT-avdrag",
    "ROT-avdragens": "ROT-avdrag",
    "ROT-avdraget": "ROT-avdrag",
    "ROT-avdragets": "ROT-avdrag",
    "ROT-avdrags": "ROT-avdrag",
    "RSFSR-s": "RSFSR",
    "RSFSR:s": "RSFSR",
    "RSFSRs": "RSFSR",
    "RUT-avdragen": "RUT-avdrag",
    "RUT-avdragens": "RUT-avdrag",
    "RUT-avdraget": "RUT-avdrag",
    "RUT-avdragets": "RUT-avdrag",
    "RUT-avdrags": "RUT-avdrag",
    "Ra-s": "Ra",
    "Ra:s": "Ra",
    "Rabats": "Rabat",
    "Racines": "Racine",
    "Radiumhemmets": "Radiumhemmet",
    "Rafaels": "Rafael",
    "Ragnars": "Ragnar",
    "Raleighs": "Raleigh",
    "Rambos": "Rambo",
    "Ramels": "Ramel",
    "Ras": "Ra",
    "Rasks": "Rask",
    "Rasmussens": "Rasmussen",
    "Rasputins": "Rasputin",
    "Rb-s": "Rb",
    "Rb:s": "Rb",
    "Rbs": "Rb",
    "Re-s": "Re",
    "Re:s": "Re",
    "Reagans": "Reagan",
    "Redivivas": "Rediviva",
    "Regensburgs": "Regensburg",
    "Reinfeldts": "Reinfeldt",
    "Remarques": "Remarque",
    "Rembrandts": "Rembrandt",
    "Renaults": "Renault",
    "Renoirs": "Renoir",
    "Renässansens": "Renässansen",
    "Renés": "René",
    "Res": "Re",
    "Reykjaviks": "Reykjavik",
    "Reykjavíks": "Reykjavík",
    "Rh-s": "Rh",
    "Rh:s": "Rh",
    "Rheas": "Rhea",
    "Rhendalens": "Rhendalen",
    "Rhenmynningens": "Rhenmynningen",
    "Rhens": "Rhen",
    "Rhodesias": "Rhodesia",
    "Rhs": "Rh",
    "Richards": "Richard",
    "Richmonds": "Richmond",
    "Rickards": "Rickard",
    "Riddarfjärdens": "Riddarfjärden",
    "Riedels": "Riedel",
    "Rifbjergs": "Rifbjerg",
    "Rigas": "Riga",
    "Rigbys": "Rigby",
    "Rigolettos": "Rigoletto",
    "Rijads": "Rijad",
    "Riksbankens": "Riksbanken",
    "Riksgäldskontorets": "Riksgäldskontoret",
    "Riksmuseets": "Riksmuseet",
    "Riksteaterns": "Riksteatern",
    "Riksutställningars": "Riksutställningar",
    "Rilkes": "Rilke",
    "Rimbauds": "Rimbaud",
    "Ritan": "Rita",
    "Ritans": "Rita",
    "Ritas": "Rita",
    "Ritor": "Rita",
    "Ritorna": "Rita",
    "Ritornas": "Rita",
    "Ritors": "Rita",
    "Rivels": "Rivel",
    "Rivierans": "Rivieran",
    "Rjazans": "Rjazan",
    "Rn-s": "Rn",
    "Rn:s": "Rn",
    "Rns": "Rn",
    "Robertar": "Robert",
    "Robertarna": "Robert",
    "Robertarnas": "Robert",
    "Robertars": "Robert",
    "Roberts": "Robert",
    "Rodins": "Rodin",
    "Roffar": "Roffe",
    "Roffarna": "Roffe",
    "Roffarnas": "Roffe",
    "Roffars": "Roffe",
    "Roffes": "Roffe",
    "Rogers": "Roger",
    "Roinar": "Roine",
    "Roinarna": "Roine",
    "Roinarnas": "Roine",
    "Roinars": "Roine",
    "Roines": "Roine",
    "Rolands": "Roland",
    "Rolfar": "Rolf",
    "Rolfarna": "Rolf",
    "Rolfarnas": "Rolf",
    "Rolfars": "Rolf",
    "Rolfs": "Rolf",
    "Rollsar": "Rolls",
    "Rollsarnas": "Rolls",
    "Rollsens": "Rolls",
    "Romas": "Roma",
    "Romkyrkans": "Romkyrkan",
    "Roosevelts": "Roosevelt",
    "Rosalies": "Rosalie",
    "Rosan": "Rosa",
    "Rosans": "Rosa",
    "Rosinantes": "Rosinante",
    "Rosis": "Rosi",
    "Roslagens": "Roslagen",
    "Rosor": "Rosa",
    "Rosorna": "Rosa",
    "Rosornas": "Rosa",
    "Rosors": "Rosa",
    "Rossinis": "Rossini",
    "Roséns": "Rosén",
    "Rothschilds": "Rothschild",
    "Rousseaus": "Rousseau",
    "Ru-s": "Ru",
    "Ru:s": "Ru",
    "Rubicons": "Rubicon",
    "Rubiks": "Rubik",
    "Rudolfar": "Rudolf",
    "Rudolfarna": "Rudolf",
    "Rudolfarnas": "Rudolf",
    "Rudolfars": "Rudolf",
    "Rudolfs": "Rudolf",
    "Rumäniens": "Rumänien",
    "Runar": "Rune",
    "Runarna": "Rune",
    "Runarnas": "Rune",
    "Runars": "Rune",
    "Runebergs": "Runeberg",
    "Runeborgs": "Runeborg",
    "Runes": "Rune",
    "Rus": "Ru",
    "Russels": "Russel",
    "Rutherfords": "Rutherford",
    "Ruts": "Rut",
    "Rwandas": "Rwanda",
    "Rydbergs": "Rydberg",
    "Rysslands": "Ryssland",
    "Rödluvans": "Rödluvan",
    "Röntgens": "Röntgen",
    "SAAB-s": "SAAB",
    "SAAB:s": "SAAB",
    "SACO-SR-s": "SACO-SR",
    "SACO-SR:s": "SACO-SR",
    "SACO-SRs": "SACO-SR",
    "SAF-s": "SAF",
    "SAF:s": "SAF",
    "SAFs": "SAF",
    "SAL-s": "SAL",
    "SAL:s": "SAL",
    "SAP-programmen": "SAP-program",
    "SAP-programmens": "SAP-program",
    "SAP-programmet": "SAP-program",
    "SAP-programmets": "SAP-program",
    "SAP-programs": "SAP-program",
    "SAP-s": "SAP",
    "SAP:s": "SAP",
    "SAPs": "SAP",
    "SAS-chefen": "SAS-chef",
    "SAS-chefens": "SAS-chef",
    "SAS-chefer": "SAS-chef",
    "SAS-cheferna": "SAS-chef",
    "SAS-chefernas": "SAS-chef",
    "SAS-chefers": "SAS-chef",
    "SAS-chefs": "SAS-chef",
    "SCOPE-rapporten": "SCOPE-rapport",
    "SCOPE-rapportens": "SCOPE-rapport",
    "SCOPE-rapporter": "SCOPE-rapport",
    "SCOPE-rapporterna": "SCOPE-rapport",
    "SCOPE-rapporternas": "SCOPE-rapport",
    "SCOPE-rapporters": "SCOPE-rapport",
    "SCOPE-rapports": "SCOPE-rapport",
    "SCOPE-s": "SCOPE",
    "SCOPE:s": "SCOPE",
    "SCOPEs": "SCOPE",
    "SI-systemets": "SI-systemet",
    "SIDA-s": "SIDA",
    "SIDA:s": "SIDA",
    "SIFO-s": "SIFO",
    "SIFOs": "SIFO",
    "SJ-s": "SJ",
    "SJ:s": "SJ",
    "SJs": "SJ",
    "SLU-s": "SLU",
    "SLU:s": "SLU",
    "SLUs": "SLU",
    "SM-n": "SM",
    "SM-na": "SM",
    "SM-nas": "SM",
    "SM-ns": "SM",
    "SM-t": "SM",
    "SM-ts": "SM",
    "SM:n": "SM",
    "SM:na": "SM",
    "SM:nas": "SM",
    "SM:ns": "SM",
    "SM:s": "SM",
    "SM:t": "SM",
    "SM:ts": "SM",
    "SMHI-s": "SMHI",
    "SMHI:s": "SMHI",
    "SMHIs": "SMHI",
    "SMn": "SM",
    "SMna": "SM",
    "SMnas": "SM",
    "SMns": "SM",
    "SMs": "SM",
    "SMt": "SM",
    "SMts": "SM",
    "SSI-s": "SSI",
    "SSI:s": "SSI",
    "SSIs": "SSI",
    "STs": "ST",
    "SU-s": "SU",
    "SU:s": "SU",
    "SUs": "SU",
    "SVT-s": "SVT",
    "SVT:s": "SVT",
    "SVTs": "SVT",
    "Saabarna": "Saab",
    "Saabars": "Saab",
    "Saabens": "Saab",
    "Sacramentos": "Sacramento",
    "Saddams": "Saddam",
    "Sagans": "Sagan",
    "Saigons": "Saigon",
    "Salamas": "Salama",
    "Salazar-regimen": "Salazar-regim",
    "Salazar-regimens": "Salazar-regim",
    "Salazar-regimer": "Salazar-regim",
    "Salazar-regimerna": "Salazar-regim",
    "Salazar-regimernas": "Salazar-regim",
    "Salazar-regimers": "Salazar-regim",
    "Salazar-regims": "Salazar-regim",
    "Salazars": "Salazar",
    "Salems": "Salem",
    "Salisburys": "Salisbury",
    "Salomonöarnas": "Salomonöarna",
    "Salomos": "Salomo",
    "Saléns": "Salén",
    "Samoas": "Samoa",
    "Samoaöarnas": "Samoaöarna",
    "Samuels": "Samuel",
    "Samuelssonen": "Samuelsson",
    "Samuelssonens": "Samuelsson",
    "Samuelssons": "Samuelsson",
    "Samuelssöner": "Samuelsson",
    "Samuelssönerna": "Samuelsson",
    "Samuelssönernas": "Samuelsson",
    "Samuelssöners": "Samuelsson",
    "Sandbergs": "Sandberg",
    "Sandemars": "Sandemar",
    "Sandemoses": "Sandemose",
    "Sandlers": "Sandler",
    "Sandros": "Sandro",
    "Sands": "Sand",
    "Sandströms": "Sandström",
    "Santiagos": "Santiago",
    "Sapfos": "Sapfo",
    "Sarajevos": "Sarajevo",
    "Saran": "Sara",
    "Sarans": "Sara",
    "Saras": "Sara",
    "Saratovs": "Saratov",
    "Sardiniens": "Sardinien",
    "Sarkozys": "Sarkozy",
    "Sarks": "Sark",
    "Saror": "Sara",
    "Sarorna": "Sara",
    "Sarornas": "Sara",
    "Sarors": "Sara",
    "Sartres": "Sartre",
    "Saudi-Arabiens": "Saudi-Arabien",
    "Saudiarabiens": "Saudiarabien",
    "Saussures": "Saussure",
    "Savojens": "Savojen",
    "Saxos": "Saxo",
    "Sb-s": "Sb",
    "Sb:s": "Sb",
    "Sbs": "Sb",
    "Sc-s": "Sc",
    "Sc:s": "Sc",
    "Schartaus": "Schartau",
    "Scheherazades": "Scheherazade",
    "Schildts": "Schildt",
    "Schillers": "Schiller",
    "Schleswig-Holsteins": "Schleswig-Holstein",
    "Schliemanns": "Schliemann",
    "Schopenhauers": "Schopenhauer",
    "Schuberts": "Schubert",
    "Scipios": "Scipio",
    "Scotts": "Scott",
    "Scs": "Sc",
    "Se-s": "Se",
    "Se:s": "Se",
    "Seasats": "Seasat",
    "Seattles": "Seattle",
    "Segerstedts": "Segerstedt",
    "Segovias": "Segovia",
    "Selman": "Selma",
    "Selmans": "Selma",
    "Selmas": "Selma",
    "Selmor": "Selma",
    "Selmorna": "Selma",
    "Selmornas": "Selma",
    "Selmors": "Selma",
    "Senecas": "Seneca",
    "Senegals": "Senegal",
    "Senghors": "Senghor",
    "Serafimerordens": "Serafimerorden",
    "Serangs": "Serang",
    "Serbiens": "Serbien",
    "Sergels": "Sergel",
    "Ses": "Se",
    "Seychellernas": "Seychellerna",
    "Shakespearedraman": "Shakespearedrama",
    "Shakespearedramana": "Shakespearedrama",
    "Shakespearedramanas": "Shakespearedrama",
    "Shakespearedramans": "Shakespearedrama",
    "Shakespearedramas": "Shakespearedrama",
    "Shakespearedramat": "Shakespearedrama",
    "Shakespearedramats": "Shakespearedrama",
    "Shakespearedramer": "Shakespearedrama",
    "Shakespearedramerna": "Shakespearedrama",
    "Shakespearedramernas": "Shakespearedrama",
    "Shakespearedramers": "Shakespearedrama",
    "Shakespeares": "Shakespeare",
    "Shaws": "Shaw",
    "Shells": "Shell",
    "Sherringtons": "Sherrington",
    "Shetlands": "Shetland",
    "Shetlandsöarnas": "Shetlandsöarna",
    "Shivas": "Shiva",
    "Shoutheriums": "Shoutherium",
    "Si-s": "Si",
    "Si:s": "Si",
    "Sibiriens": "Sibirien",
    "Siciliens": "Sicilien",
    "Siegfriedar": "Siegfried",
    "Siegfriedarna": "Siegfried",
    "Siegfriedarnas": "Siegfried",
    "Siegfriedars": "Siegfried",
    "Siegfrieds": "Siegfried",
    "Siggar": "Sigge",
    "Siggarna": "Sigge",
    "Siggarnas": "Sigge",
    "Siggars": "Sigge",
    "Sigges": "Sigge",
    "Sigmunds": "Sigmund",
    "Signes": "Signe",
    "Sigurdar": "Sigurd",
    "Sigurdarna": "Sigurd",
    "Sigurdarnas": "Sigurd",
    "Sigurdars": "Sigurd",
    "Sigurds": "Sigurd",
    "Sigvardar": "Sigvard",
    "Sigvardarna": "Sigvard",
    "Sigvardarnas": "Sigvard",
    "Sigvardars": "Sigvard",
    "Sigvards": "Sigvard",
    "Siikavoupioskidans": "Siikavoupioskidan",
    "Silkeborgs": "Silkeborg",
    "Sillanpääs": "Sillanpää",
    "Silvian": "Silvia",
    "Silvians": "Silvia",
    "Silvias": "Silvia",
    "Silvior": "Silvia",
    "Silviorna": "Silvia",
    "Silviornas": "Silvia",
    "Silviors": "Silvia",
    "Simcas": "Simca",
    "Simenons": "Simenon",
    "Simlångsdalens": "Simlångsdalen",
    "Simonar": "Simon",
    "Simonarna": "Simon",
    "Simonarnas": "Simon",
    "Simonars": "Simon",
    "Simons": "Simon",
    "Simsonar": "Simson",
    "Simsonarna": "Simson",
    "Simsonarnas": "Simson",
    "Simsonars": "Simson",
    "Simsons": "Simson",
    "Sinatras": "Sinatra",
    "Singapores": "Singapore",
    "Singmasters": "Singmaster",
    "Sions": "Sion",
    "Sis": "Si",
    "Sixtens": "Sixten",
    "Sjaljapins": "Sjaljapin",
    "Sjaunjas": "Sjaunja",
    "Sjevarnadzes": "Sjevarnadze",
    "Sjolochovs": "Sjolochov",
    "Sjostakovitjs": "Sjostakovitj",
    "Sjustjärnornas": "Sjustjärnorna",
    "Själlands": "Själland",
    "Sjöbergs": "Sjöberg",
    "Skageracks": "Skagerack",
    "Skagerracks": "Skagerrack",
    "Skagerraks": "Skagerrak",
    "Skanderbegs": "Skanderbeg",
    "Skandinaviens": "Skandinavien",
    "Skansens": "Skansen",
    "Skaraborgs": "Skaraborg",
    "Skatteverkets": "Skatteverket",
    "Skellefteås": "Skellefteå",
    "Skidbladners": "Skidbladner",
    "Skoglunds": "Skoglund",
    "Skogmans": "Skogman",
    "Skolöverstyrelsens": "Skolöverstyrelsen",
    "Skorpionens": "Skorpionen",
    "Skottlands": "Skottland",
    "Skuleskogens": "Skuleskogen",
    "Skyttens": "Skytten",
    "Skånes": "Skåne",
    "Skövdes": "Skövde",
    "Slovakiens": "Slovakien",
    "Sloveniens": "Slovenien",
    "Sm-s": "Sm",
    "Smiths": "Smith",
    "Smålands": "Småland",
    "Sn-s": "Sn",
    "Sn:s": "Sn",
    "Sns": "Sn",
    "Social-Demokratens": "Social-Demokraten",
    "Socialdemokraternas": "Socialdemokraterna",
    "Sofian": "Sofia",
    "Sofians": "Sofia",
    "Sofias": "Sofia",
    "Sofieros": "Sofiero",
    "Sofior": "Sofia",
    "Sofiorna": "Sofia",
    "Sofiornas": "Sofia",
    "Sofiors": "Sofia",
    "Solens": "Solen",
    "Solimans": "Soliman",
    "Solnas": "Solna",
    "Solomons": "Solomon",
    "Solons": "Solon",
    "Somalias": "Somalia",
    "Somozas": "Somoza",
    "Sonjan": "Sonja",
    "Sonjans": "Sonja",
    "Sonjas": "Sonja",
    "Sonjor": "Sonja",
    "Sonjorna": "Sonja",
    "Sonjornas": "Sonja",
    "Sonjors": "Sonja",
    "Sousas": "Sousa",
    "Sovjetrysslands": "Sovjetryssland",
    "Sovjets": "Sovjet",
    "Sovjetunionens": "Sovjetunionen",
    "Spaaks": "Spaak",
    "Spaniens": "Spanien",
    "Sparrings": "Sparring",
    "Spartas": "Sparta",
    "Spendrups": "Spendrup",
    "Spicas": "Spica",
    "Spinozas": "Spinoza",
    "Springers": "Springer",
    "Springfields": "Springfield",
    "Språkbankens": "Språkbanken",
    "Sr-s": "Sr",
    "Sr:s": "Sr",
    "Srs": "Sr",
    "Ss": "S",
    "St-s": "St",
    "St:s": "St",
    "Staafs": "Staaf",
    "Staffans": "Staffan",
    "Stalingrads": "Stalingrad",
    "Stalins": "Stalin",
    "Stallones": "Stallone",
    "Stanfords": "Stanford",
    "Stanislavskijs": "Stanislavskij",
    "Starks": "Stark",
    "Stavangers": "Stavanger",
    "Stavropols": "Stavropol",
    "Steins": "Stein",
    "Stenbockens": "Stenbocken",
    "Stenhammars": "Stenhammar",
    "Stenmarks": "Stenmark",
    "Stens": "Sten",
    "Stephens": "Stephen",
    "Stillahavsfiskes": "Stillahavsfiske",
    "Stillahavsfisket": "Stillahavsfiske",
    "Stillahavsfiskets": "Stillahavsfiske",
    "Stinan": "Stina",
    "Stinans": "Stina",
    "Stinas": "Stina",
    "Stinor": "Stina",
    "Stinorna": "Stina",
    "Stinornas": "Stina",
    "Stinors": "Stina",
    "Stockholms": "Stockholm",
    "Stockholms-Tidningens": "Stockholms-Tidningen",
    "Stockholmsarenan": "Stockholmsarena",
    "Stockholmsarenans": "Stockholmsarena",
    "Stockholmsarenas": "Stockholmsarena",
    "Stockholmsarenor": "Stockholmsarena",
    "Stockholmsarenorna": "Stockholmsarena",
    "Stockholmsarenornas": "Stockholmsarena",
    "Stockholmsarenors": "Stockholmsarena",
    "Stockholmsfotografen": "Stockholmsfotograf",
    "Stockholmsfotografens": "Stockholmsfotograf",
    "Stockholmsfotografer": "Stockholmsfotograf",
    "Stockholmsfotograferna": "Stockholmsfotograf",
    "Stockholmsfotografernas": "Stockholmsfotograf",
    "Stockholmsfotografers": "Stockholmsfotograf",
    "Stockholmsfotografs": "Stockholmsfotograf",
    "Stockholmsguiden": "Stockholmsguide",
    "Stockholmsguidens": "Stockholmsguide",
    "Stockholmsguider": "Stockholmsguide",
    "Stockholmsguiderna": "Stockholmsguide",
    "Stockholmsguidernas": "Stockholmsguide",
    "Stockholmsguiders": "Stockholmsguide",
    "Stockholmsguides": "Stockholmsguide",
    "Stockholmshelgen": "Stockholmshelg",
    "Stockholmshelgens": "Stockholmshelg",
    "Stockholmshelger": "Stockholmshelg",
    "Stockholmshelgerna": "Stockholmshelg",
    "Stockholmshelgernas": "Stockholmshelg",
    "Stockholmshelgers": "Stockholmshelg",
    "Stockholmshelgs": "Stockholmshelg",
    "Stockholmsmässigare": "Stockholmsmässig",
    "Stockholmsmässigas": "Stockholmsmässig",
    "Stockholmsmässigaste": "Stockholmsmässig",
    "Stockholmsmässigasts": "Stockholmsmässig",
    "Stockholmsmässiges": "Stockholmsmässig",
    "Stockholmsmässigt": "Stockholmsmässig",
    "Stockholmsområdets": "Stockholmsområdet",
    "Stoltenbergs": "Stoltenberg",
    "Stor-Stockholms": "Stor-Stockholm",
    "Storbritanniens": "Storbritannien",
    "Storgatans": "Storgatan",
    "Storglaciärens": "Storglaciären",
    "Storvindelns": "Storvindeln",
    "Stravinskijs": "Stravinskij",
    "Strindbergs": "Strindberg",
    "Strindbergsutgåvan": "Strindbergsutgåva",
    "Strindbergsutgåvans": "Strindbergsutgåva",
    "Strindbergsutgåvas": "Strindbergsutgåva",
    "Strindbergsutgåve": "Strindbergsutgåva",
    "Strindbergsutgåvo": "Strindbergsutgåva",
    "Strindbergsutgåvor": "Strindbergsutgåva",
    "Strindbergsutgåvorna": "Strindbergsutgåva",
    "Strindbergsutgåvornas": "Strindbergsutgåva",
    "Strindbergsutgåvors": "Strindbergsutgåva",
    "Strängs": "Sträng",
    "Sturar": "Sture",
    "Sturarna": "Sture",
    "Sturarnas": "Sture",
    "Sturars": "Sture",
    "Stures": "Sture",
    "Sudans": "Sudan",
    "Suhartos": "Suharto",
    "Sukarnos": "Sukarno",
    "Sunar": "Sune",
    "Sunarna": "Sune",
    "Sunarnas": "Sune",
    "Sunars": "Sune",
    "Sundmans": "Sundman",
    "Sundströms": "Sundström",
    "Sundsvalls": "Sundsvall",
    "Sunes": "Sune",
    "Surinames": "Suriname",
    "SvD-s": "SvD",
    "SvD:s": "SvD",
    "SvDs": "SvD",
    "Svanbergs": "Svanberg",
    "Svanens": "Svanen",
    "Svantar": "Svante",
    "Svantarna": "Svante",
    "Svantarnas": "Svante",
    "Svantars": "Svante",
    "Svantes": "Svante",
    "Svartens": "Svarten",
    "Svealands": "Svealand",
    "Svean": "Svea",
    "Sveans": "Svea",
    "Sveas": "Svea",
    "Svedalas": "Svedala",
    "Svejks": "Svejk",
    "Sven-Erikar": "Sven-Erik",
    "Sven-Erikarna": "Sven-Erik",
    "Sven-Erikarnas": "Sven-Erik",
    "Sven-Erikars": "Sven-Erik",
    "Sven-Eriks": "Sven-Erik",
    "Svenssonen": "Svensson",
    "Svenssonens": "Svensson",
    "Svenssons": "Svensson",
    "Svenssöner": "Svensson",
    "Svenssönerna": "Svensson",
    "Svenssönernas": "Svensson",
    "Svenssöners": "Svensson",
    "Sveor": "Svea",
    "Sveorna": "Svea",
    "Sveornas": "Svea",
    "Sveors": "Svea",
    "Sverigemästerskapen": "Sverigemästerskap",
    "Sverigemästerskapens": "Sverigemästerskap",
    "Sverigemästerskapet": "Sverigemästerskap",
    "Sverigemästerskapets": "Sverigemästerskap",
    "Sverigemästerskaps": "Sverigemästerskap",
    "Sveriges": "Sverige",
    "Swahns": "Swahn",
    "Swasilands": "Swasiland",
    "Swazilands": "Swaziland",
    "Swedbergs": "Swedberg",
    "Swedenborgs": "Swedenborg",
    "Sydafrikas": "Sydafrika",
    "Sydamerikas": "Sydamerika",
    "Sydatlantens": "Sydatlanten",
    "Sydeuropas": "Sydeuropa",
    "Sydfinlands": "Sydfinland",
    "Sydgeorgiens": "Sydgeorgien",
    "Sydjemens": "Sydjemen",
    "Sydkoreas": "Sydkorea",
    "Sydkrafts": "Sydkraft",
    "Sydnorges": "Sydnorge",
    "Sydostasiens": "Sydostasien",
    "Sydostnorges": "Sydostnorge",
    "Sydpolens": "Sydpolen",
    "Sydrysslands": "Sydryssland",
    "Sydskandinaviens": "Sydskandinavien",
    "Sydsveriges": "Sydsverige",
    "Sydvietnams": "Sydvietnam",
    "Sydvästafrikas": "Sydvästafrika",
    "Sydyemens": "Sydyemen",
    "Sydöstasiens": "Sydöstasien",
    "Sylvains": "Sylvain",
    "Syriens": "Syrien",
    "Systembolagets": "Systembolaget",
    "Systemets": "Systemet",
    "SÄPO-s": "SÄPO",
    "SÄPO:s": "SÄPO",
    "SÄPOs": "SÄPO",
    "SÖ-s": "SÖ",
    "SÖ:s": "SÖ",
    "SÖs": "SÖ",
    "Sälens": "Sälen",
    "Särimners": "Särimner",
    "Säröbanans": "Säröbanan",
    "Särös": "Särö",
    "Söderbergs": "Söderberg",
    "Söderbloms": "Söderblom",
    "Södergrans": "Södergran",
    "Söderhamns": "Söderhamn",
    "Södermalms": "Södermalm",
    "Södermalmvåningar": "Södermalmvåning",
    "Södermalmvåningarna": "Södermalmvåning",
    "Södermalmvåningarnas": "Södermalmvåning",
    "Södermalmvåningars": "Södermalmvåning",
    "Södermalmvåningen": "Södermalmvåning",
    "Södermalmvåningens": "Södermalmvåning",
    "Södermalmvånings": "Södermalmvåning",
    "Södermanlands": "Södermanland",
    "Södertäljes": "Södertälje",
    "Sörenar": "Sören",
    "Sörenarna": "Sören",
    "Sörenarnas": "Sören",
    "Sörenars": "Sören",
    "Sörens": "Sören",
    "Sörmlands": "Sörmland",
    "Söuls": "Söul",
    "T-s": "T",
    "T-shirtarna": "T-shirt",
    "T-shirtars": "T-shirt",
    "T-shirtens": "T-shirt",
    "T-spriten": "T-sprit",
    "T-spritens": "T-sprit",
    "T-sprits": "T-sprit",
    "T-tröjan": "T-tröja",
    "T-tröjas": "T-tröja",
    "T-tröjorna": "T-tröja",
    "T9-s": "T9",
    "T9:s": "T9",
    "TCO-s": "TCO",
    "TCO:s": "TCO",
    "TCOs": "TCO",
    "TT-s": "TT",
    "TT:s": "TT",
    "TTAPS-gruppens": "TTAPS-gruppen",
    "TTs": "TT",
    "TV-abonnemangen": "TV-abonnemang",
    "TV-abonnemangens": "TV-abonnemang",
    "TV-abonnemanget": "TV-abonnemang",
    "TV-abonnemangets": "TV-abonnemang",
    "TV-abonnemangs": "TV-abonnemang",
    "TV-antennen": "TV-antenn",
    "TV-antennens": "TV-antenn",
    "TV-antenner": "TV-antenn",
    "TV-antennerna": "TV-antenn",
    "TV-antennernas": "TV-antenn",
    "TV-antenners": "TV-antenn",
    "TV-antenns": "TV-antenn",
    "TV-apparaten": "TV-apparat",
    "TV-apparatens": "TV-apparat",
    "TV-apparater": "TV-apparat",
    "TV-apparaterna": "TV-apparat",
    "TV-apparaternas": "TV-apparat",
    "TV-apparaters": "TV-apparat",
    "TV-apparats": "TV-apparat",
    "TV-bilden": "TV-bild",
    "TV-bildens": "TV-bild",
    "TV-bilder": "TV-bild",
    "TV-bilderna": "TV-bild",
    "TV-bildernas": "TV-bild",
    "TV-bilders": "TV-bild",
    "TV-bilds": "TV-bild",
    "TV-chefen": "TV-chef",
    "TV-chefens": "TV-chef",
    "TV-chefer": "TV-chef",
    "TV-cheferna": "TV-chef",
    "TV-chefernas": "TV-chef",
    "TV-chefers": "TV-chef",
    "TV-chefs": "TV-chef",
    "TV-evangelisten": "TV-evangelist",
    "TV-evangelister": "TV-evangelist",
    "TV-evangelisterna": "TV-evangelist",
    "TV-intervjuer": "TV-intervju",
    "TV-intervjuerna": "TV-intervju",
    "TV-intervjuernas": "TV-intervju",
    "TV-intervjuers": "TV-intervju",
    "TV-intervjun": "TV-intervju",
    "TV-intervjuns": "TV-intervju",
    "TV-intervjus": "TV-intervju",
    "TV-kameran": "TV-kamera",
    "TV-kamerans": "TV-kamera",
    "TV-kameras": "TV-kamera",
    "TV-kameror": "TV-kamera",
    "TV-kamerorna": "TV-kamera",
    "TV-kamerornas": "TV-kamera",
    "TV-kamerors": "TV-kamera",
    "TV-kanalen": "TV-kanal",
    "TV-kanalens": "TV-kanal",
    "TV-kanaler": "TV-kanal",
    "TV-kanalerna": "TV-kanal",
    "TV-kanalernas": "TV-kanal",
    "TV-kanalers": "TV-kanal",
    "TV-kanals": "TV-kanal",
    "TV-konferensen": "TV-konferens",
    "TV-konferensens": "TV-konferens",
    "TV-konferenser": "TV-konferens",
    "TV-konferenserna": "TV-konferens",
    "TV-konferensernas": "TV-konferens",
    "TV-konferensers": "TV-konferens",
    "TV-leverantörens": "TV-leverantör",
    "TV-leverantörerna": "TV-leverantör",
    "TV-leverantörs": "TV-leverantör",
    "TV-mottagar": "TV-mottagare",
    "TV-mottagaren": "TV-mottagare",
    "TV-mottagarens": "TV-mottagare",
    "TV-mottagares": "TV-mottagare",
    "TV-mottagarna": "TV-mottagare",
    "TV-mottagarnas": "TV-mottagare",
    "TV-n": "TV",
    "TV-na": "TV",
    "TV-ns": "TV",
    "TV-nyhetens": "TV-nyhet",
    "TV-nyheterna": "TV-nyhet",
    "TV-nyhets": "TV-nyhet",
    "TV-predikanten": "TV-predikant",
    "TV-predikanter": "TV-predikant",
    "TV-predikanterna": "TV-predikant",
    "TV-predikants": "TV-predikant",
    "TV-producenten": "TV-producent",
    "TV-producentens": "TV-producent",
    "TV-producenter": "TV-producent",
    "TV-producenterna": "TV-producent",
    "TV-producenternas": "TV-producent",
    "TV-producenters": "TV-producent",
    "TV-producents": "TV-producent",
    "TV-profilen": "TV-profil",
    "TV-profilens": "TV-profil",
    "TV-profiler": "TV-profil",
    "TV-profilerna": "TV-profil",
    "TV-profilernas": "TV-profil",
    "TV-profilers": "TV-profil",
    "TV-profils": "TV-profil",
    "TV-programmen": "TV-program",
    "TV-programmens": "TV-program",
    "TV-programmet": "TV-program",
    "TV-programmets": "TV-program",
    "TV-programs": "TV-program",
    "TV-reklamen": "TV-reklam",
    "TV-reklamens": "TV-reklam",
    "TV-reklams": "TV-reklam",
    "TV-reparatören": "TV-reparatör",
    "TV-reparatörens": "TV-reparatör",
    "TV-reparatörer": "TV-reparatör",
    "TV-reparatörerna": "TV-reparatör",
    "TV-reparatörernas": "TV-reparatör",
    "TV-reparatörers": "TV-reparatör",
    "TV-reparatörs": "TV-reparatör",
    "TV-rutan": "TV-ruta",
    "TV-rutans": "TV-ruta",
    "TV-rutas": "TV-ruta",
    "TV-rute": "TV-ruta",
    "TV-rutor": "TV-ruta",
    "TV-rutorna": "TV-ruta",
    "TV-rutornas": "TV-ruta",
    "TV-rutors": "TV-ruta",
    "TV-s": "TV",
    "TV-serien": "TV-serie",
    "TV-seriens": "TV-serie",
    "TV-serier": "TV-serie",
    "TV-serierna": "TV-serie",
    "TV-seriernas": "TV-serie",
    "TV-seriers": "TV-serie",
    "TV-series": "TV-serie",
    "TV-signalen": "TV-signal",
    "TV-signalens": "TV-signal",
    "TV-signaler": "TV-signal",
    "TV-signalerna": "TV-signal",
    "TV-signalernas": "TV-signal",
    "TV-signalers": "TV-signal",
    "TV-signals": "TV-signal",
    "TV-skärmar": "TV-skärm",
    "TV-skärmarna": "TV-skärm",
    "TV-skärmarnas": "TV-skärm",
    "TV-skärmars": "TV-skärm",
    "TV-skärmen": "TV-skärm",
    "TV-skärmens": "TV-skärm",
    "TV-skärms": "TV-skärm",
    "TV-soff": "TV-soffa",
    "TV-soffan": "TV-soffa",
    "TV-soffans": "TV-soffa",
    "TV-soffas": "TV-soffa",
    "TV-soffe": "TV-soffa",
    "TV-soffor": "TV-soffa",
    "TV-sofforna": "TV-soffa",
    "TV-soffornas": "TV-soffa",
    "TV-soffors": "TV-soffa",
    "TV-soffs": "TV-soffa",
    "TV-studion": "TV-studio",
    "TV-studions": "TV-studio",
    "TV-studior": "TV-studio",
    "TV-studiorna": "TV-studio",
    "TV-studiornas": "TV-studio",
    "TV-studiors": "TV-studio",
    "TV-studios": "TV-studio",
    "TV-sändar": "TV-sändare",
    "TV-sändaren": "TV-sändare",
    "TV-sändarens": "TV-sändare",
    "TV-sändares": "TV-sändare",
    "TV-sändarna": "TV-sändare",
    "TV-sändarnas": "TV-sändare",
    "TV-sändningar": "TV-sändning",
    "TV-sändningarna": "TV-sändning",
    "TV-sändningarnas": "TV-sändning",
    "TV-sändningars": "TV-sändning",
    "TV-sändningen": "TV-sändning",
    "TV-sändningens": "TV-sändning",
    "TV-sändnings": "TV-sändning",
    "TV-tittanden": "TV-tittande",
    "TV-tittandena": "TV-tittande",
    "TV-tittandenas": "TV-tittande",
    "TV-tittandens": "TV-tittande",
    "TV-tittandes": "TV-tittande",
    "TV-tittandet": "TV-tittande",
    "TV-tittandets": "TV-tittande",
    "TV-tittar": "TV-tittare",
    "TV-tittaren": "TV-tittare",
    "TV-tittarens": "TV-tittare",
    "TV-tittares": "TV-tittare",
    "TV-tittarna": "TV-tittare",
    "TV-tittarnas": "TV-tittare",
    "TV-övervakningar": "TV-övervakning",
    "TV-övervakningarna": "TV-övervakning",
    "TV-övervakningarnas": "TV-övervakning",
    "TV-övervakningars": "TV-övervakning",
    "TV-övervakningen": "TV-övervakning",
    "TV-övervakningens": "TV-övervakning",
    "TV-övervaknings": "TV-övervakning",
    "TV1-s": "TV1",
    "TV1:s": "TV1",
    "TV1s": "TV1",
    "TV2-s": "TV2",
    "TV2:s": "TV2",
    "TV2s": "TV2",
    "TV3-s": "TV3",
    "TV3:s": "TV3",
    "TV3s": "TV3",
    "TV4-s": "TV4",
    "TV4:s": "TV4",
    "TV4s": "TV4",
    "TV5-s": "TV5",
    "TV5:s": "TV5",
    "TV5s": "TV5",
    "TV6-s": "TV6",
    "TV6:s": "TV6",
    "TV6s": "TV6",
    "TV8-s": "TV8",
    "TV8:s": "TV8",
    "TV8s": "TV8",
    "TV9-s": "TV9",
    "TV9:s": "TV9",
    "TV9s": "TV9",
    "TV:na": "TV",
    "TV:nas": "TV",
    "TV:s": "TV",
    "TVnas": "TV",
    "Ta-s": "Ta",
    "Ta:s": "Ta",
    "Tadzjikistans": "Tadzjikistan",
    "Tagar": "Tage",
    "Tagarna": "Tage",
    "Tagarnas": "Tage",
    "Tagars": "Tage",
    "Tages": "Tage",
    "Tagores": "Tagore",
    "Taiwans": "Taiwan",
    "Tallinns": "Tallinn",
    "Talmuds": "Talmud",
    "Tangers": "Tanger",
    "Tanzanias": "Tanzania",
    "Tarkovskijs": "Tarkovskij",
    "Tartuffes": "Tartuffe",
    "Tartus": "Tartu",
    "Tarzanfilmen": "Tarzanfilm",
    "Tarzanfilmens": "Tarzanfilm",
    "Tarzanfilmer": "Tarzanfilm",
    "Tarzanfilmerna": "Tarzanfilm",
    "Tarzanfilmernas": "Tarzanfilm",
    "Tarzanfilmers": "Tarzanfilm",
    "Tarzanfilms": "Tarzanfilm",
    "Tarzans": "Tarzan",
    "Tas": "Ta",
    "Tassos": "Tasso",
    "Taubes": "Taube",
    "Taylors": "Taylor",
    "Tb-s": "Tb",
    "Tb:s": "Tb",
    "Tbs": "Tb",
    "Tc-s": "Tc",
    "Tc:s": "Tc",
    "Tchads": "Tchad",
    "Tcs": "Tc",
    "Te-s": "Te",
    "Te:s": "Te",
    "Tegnérs": "Tegnér",
    "Tellers": "Teller",
    "Tells": "Tell",
    "Tennessees": "Tennessee",
    "Tenzings": "Tenzing",
    "Terpsichores": "Terpsichore",
    "Terrys": "Terry",
    "Teutoburgerskogens": "Teutoburgerskogen",
    "Texacos": "Texaco",
    "Th-s": "Th",
    "Th:s": "Th",
    "Thackerays": "Thackeray",
    "Thailands": "Thailand",
    "Thalias": "Thalia",
    "Thants": "Thant",
    "Thatchers": "Thatcher",
    "Theresienstadts": "Theresienstadt",
    "Thermopyles": "Thermopyle",
    "Thomsons": "Thomson",
    "Thorilds": "Thorild",
    "Ths": "Th",
    "Thules": "Thule",
    "Thörnells": "Thörnell",
    "Ti-s": "Ti",
    "Ti:s": "Ti",
    "Tiberns": "Tibern",
    "Tibets": "Tibet",
    "Tidans": "Tidan",
    "Tierps": "Tierp",
    "Tinbergens": "Tinbergen",
    "Tingstens": "Tingsten",
    "Tiplers": "Tipler",
    "Tiranas": "Tirana",
    "Tis": "Ti",
    "Titanias": "Titania",
    "Titanics": "Titanic",
    "Titos": "Tito",
    "Tizians": "Tizian",
    "Tjajkovskijs": "Tjajkovskij",
    "Tjechovs": "Tjechov",
    "Tjeckiens": "Tjeckien",
    "Tjeckoslovakiens": "Tjeckoslovakien",
    "Tjernobylnedfallen": "Tjernobylnedfall",
    "Tjernobylnedfallens": "Tjernobylnedfall",
    "Tjernobylnedfallet": "Tjernobylnedfall",
    "Tjernobylnedfallets": "Tjernobylnedfall",
    "Tjernobylnedfalls": "Tjernobylnedfall",
    "Tjernobylolyckans": "Tjernobylolyckan",
    "Tjernobyls": "Tjernobyl",
    "Tjetjeniens": "Tjetjenien",
    "Tjurkös": "Tjurkö",
    "Tl-s": "Tl",
    "Tl:s": "Tl",
    "Tls": "Tl",
    "Tm-s": "Tm",
    "Tm:s": "Tm",
    "Tms": "Tm",
    "Togos": "Togo",
    "Tokyokraftverkets": "Tokyokraftverket",
    "Tokyos": "Tokyo",
    "Tollundmannens": "Tollundmannen",
    "Tolstojs": "Tolstoj",
    "Toms": "Tom",
    "Tomsks": "Tomsk",
    "Tongas": "Tonga",
    "Tonis": "Toni",
    "Tonys": "Tony",
    "Topekas": "Topeka",
    "Toran": "Tora",
    "Torans": "Tora",
    "Torar": "Tore",
    "Torarna": "Tore",
    "Torarnas": "Tore",
    "Torars": "Tore",
    "Toras": "Tora",
    "Torbjörnar": "Torbjörn",
    "Torbjörnarna": "Torbjörn",
    "Torbjörnarnas": "Torbjörn",
    "Torbjörnars": "Torbjörn",
    "Torbjörns": "Torbjörn",
    "Tordar": "Tord",
    "Tordarna": "Tord",
    "Tordarnas": "Tord",
    "Tordars": "Tord",
    "Tords": "Tord",
    "Tores": "Tore",
    "Toror": "Tora",
    "Tororna": "Tora",
    "Torornas": "Tora",
    "Torors": "Tora",
    "Torricellis": "Torricelli",
    "Tors": "Tor",
    "Torshavns": "Torshavn",
    "Torstenssonen": "Torstensson",
    "Torstenssonens": "Torstensson",
    "Torstenssons": "Torstensson",
    "Torstenssöner": "Torstensson",
    "Torstenssönerna": "Torstensson",
    "Torstenssönernas": "Torstensson",
    "Torstenssöners": "Torstensson",
    "Toscanas": "Toscana",
    "Toscaninis": "Toscanini",
    "Toscas": "Tosca",
    "Toves": "Tove",
    "Tovetorps": "Tovetorp",
    "Trafiksäkerhetsverkets": "Trafiksäkerhetsverk",
    "Trelleborgs": "Trelleborg",
    "Trenters": "Trenter",
    "Trentons": "Trenton",
    "Trinidads": "Trinidad",
    "Tripolis": "Tripoli",
    "Trojas": "Troja",
    "Trollflöjtens": "Trollflöjten",
    "Tromsös": "Tromsö",
    "Trondheims": "Trondheim",
    "Trotskijs": "Trotskij",
    "Trumans": "Truman",
    "Tryggvar": "Tryggve",
    "Tryggvarna": "Tryggve",
    "Tryggvarnas": "Tryggve",
    "Tryggvars": "Tryggve",
    "Tryggves": "Tryggve",
    "Ts": "T",
    "Tucsons": "Tucson",
    "Tunisiens": "Tunisien",
    "Turandots": "Turandot",
    "Turar": "Ture",
    "Turarna": "Ture",
    "Turarnas": "Ture",
    "Turars": "Ture",
    "Tures": "Ture",
    "Turgenevs": "Turgenev",
    "Turins": "Turin",
    "Turkiets": "Turkiet",
    "Turkmenistans": "Turkmenistan",
    "Tutanchamons": "Tutanchamon",
    "Tuvalus": "Tuvalu",
    "Tvillingarnas": "Tvillingarna",
    "Twains": "Twain",
    "Twitters": "Twitter",
    "Tychos": "Tycho",
    "Tylösands": "Tylösand",
    "Tyrolens": "Tyrolen",
    "Tysklands": "Tyskland",
    "Täbys": "Täby",
    "Törnrosas": "Törnrosa",
    "U-landets": "U-land",
    "U-lands": "U-land",
    "U-länderna": "U-land",
    "U-länders": "U-land",
    "U-s": "U",
    "UCLA-s": "UCLA",
    "UCLA:s": "UCLA",
    "UCLAs": "UCLA",
    "UD-s": "UD",
    "UD:s": "UD",
    "UDs": "UD",
    "UHÄ-s": "UHÄ",
    "UHÄ:s": "UHÄ",
    "UHÄs": "UHÄ",
    "UKÄ-s": "UKÄ",
    "UKÄ:s": "UKÄ",
    "UKÄs": "UKÄ",
    "URL:ar": "URL",
    "URL:arna": "URL",
    "URL:arnas": "URL",
    "URL:ars": "URL",
    "URL:er": "URL",
    "URL:erna": "URL",
    "URL:ernas": "URL",
    "URL:ers": "URL",
    "URL:n": "URL",
    "URL:ns": "URL",
    "URL:s": "URL",
    "URLar": "URL",
    "URLarna": "URL",
    "URLarnas": "URL",
    "URLars": "URL",
    "URLer": "URL",
    "URLerna": "URL",
    "URLernas": "URL",
    "URLers": "URL",
    "URLn": "URL",
    "URLns": "URL",
    "URLs": "URL",
    "USA-s": "USA",
    "USA:s": "USA",
    "USAs": "USA",
    "USSR-s": "USSR",
    "USSR:s": "USSR",
    "USSRs": "USSR",
    "Ugandas": "Uganda",
    "Ukrainas": "Ukraina",
    "Ulbrichts": "Ulbricht",
    "Ulfar": "Ulf",
    "Ulfarna": "Ulf",
    "Ulfarnas": "Ulf",
    "Ulfars": "Ulf",
    "Ulfs": "Ulf",
    "Ullan": "Ulla",
    "Ullans": "Ulla",
    "Ullas": "Ulla",
    "Ullor": "Ulla",
    "Ullorna": "Ulla",
    "Ullornas": "Ulla",
    "Ullors": "Ulla",
    "Ullstens": "Ullsten",
    "Ulricehamns": "Ulricehamn",
    "Umbriels": "Umbriel",
    "Umeås": "Umeå",
    "Undsets": "Undset",
    "Undéns": "Undén",
    "Ungerns": "Ungern",
    "Unos": "Uno",
    "Updikes": "Updike",
    "Upplandskustens": "Upplandskusten",
    "Upplysningens": "Upplysningen",
    "Uppsalas": "Uppsala",
    "Urals": "Ural",
    "Uranias": "Urania",
    "Uruguay-flodens": "Uruguay-floden",
    "Uruguays": "Uruguay",
    "Us": "U",
    "Utahs": "Utah",
    "Uzbekistans": "Uzbekistan",
    "VAB-dagarna": "VAB-dag",
    "VAB-dagarnas": "VAB-dag",
    "VAB-dagen": "VAB-dag",
    "VAB-dagens": "VAB-dag",
    "VABBar": "VABB",
    "VABBarnas": "VABB",
    "VABBen": "VABB",
    "VABBet": "VABB",
    "VABBs": "VABB",
    "VABar": "VAB",
    "VABarnas": "VAB",
    "VABens": "VAB",
    "VABets": "VAB",
    "VD-ars": "VD",
    "VD-en": "VD",
    "VD-ens": "VD",
    "VD-n": "VD",
    "VD-ns": "VD",
    "VD-s": "VD",
    "VD:ar": "VD",
    "VD:arna": "VD",
    "VD:ars": "VD",
    "VD:ens": "VD",
    "VD:ns": "VD",
    "VDar": "VD",
    "VDarna": "VD",
    "VDarnas": "VD",
    "VDars": "VD",
    "VM-n": "VM",
    "VM-na": "VM",
    "VM-nas": "VM",
    "VM-ns": "VM",
    "VM-s": "VM",
    "VM-t": "VM",
    "VM-ts": "VM",
    "VM:n": "VM",
    "VM:na": "VM",
    "VM:nas": "VM",
    "VM:ns": "VM",
    "VM:s": "VM",
    "VM:t": "VM",
    "VM:ts": "VM",
    "VMn": "VM",
    "VMna": "VM",
    "VMnas": "VM",
    "VMns": "VM",
    "VMs": "VM",
    "VMt": "VM",
    "VMts": "VM",
    "VVS-armaturen": "VVS-armatur",
    "VVS-armaturens": "VVS-armatur",
    "VVS-armaturer": "VVS-armatur",
    "VVS-armaturerna": "VVS-armatur",
    "VVS-armaturernas": "VVS-armatur",
    "VVS-armaturers": "VVS-armatur",
    "VVS-armaturs": "VVS-armatur",
    "Vaktpostens": "Vaktposten",
    "Valbos": "Valbo",
    "Valdemars": "Valdemar",
    "Valdemarsviks": "Valdemarsvik",
    "Vanuatus": "Vanuatu",
    "Varangerfjordens": "Varangerfjorden",
    "Varbergs": "Varberg",
    "Vasaloppets": "Vasaloppet",
    "Vasaordens": "Vasaorden",
    "Vasas": "Vasa",
    "Vatikanens": "Vatikanen",
    "Vattumannens": "Vattumannen",
    "Vaxholmskonflikten": "Vaxholmskonflikt",
    "Vaxholmskonfliktens": "Vaxholmskonflikt",
    "Vaxholmskonflikts": "Vaxholmskonflikt",
    "Vedas": "Veda",
    "Vemmenhögs": "Vemmenhög",
    "Venedigs": "Venedig",
    "Venezuelas": "Venezuela",
    "Verdis": "Verdi",
    "Verlaines": "Verlaine",
    "Vermonts": "Vermont",
    "Verners": "Verner",
    "Vernes": "Verne",
    "Vestas": "Vesta",
    "Victoriasjöns": "Victoriasjön",
    "Vietnamkrigen": "Vietnamkrig",
    "Vietnamkrigens": "Vietnamkrig",
    "Vietnamkriget": "Vietnamkrig",
    "Vietnamkrigets": "Vietnamkrig",
    "Vietnamkrigs": "Vietnamkrig",
    "Vietnampolitiken": "Vietnampolitik",
    "Vietnampolitikens": "Vietnampolitik",
    "Vietnampolitiks": "Vietnampolitik",
    "Vietnams": "Vietnam",
    "Vietnamveteranen": "Vietnamveteran",
    "Vietnamveteranens": "Vietnamveteran",
    "Vietnamveteraner": "Vietnamveteran",
    "Vietnamveteranerna": "Vietnamveteran",
    "Vietnamveteranernas": "Vietnamveteran",
    "Vietnamveteraners": "Vietnamveteran",
    "Vietnamveterans": "Vietnamveteran",
    "Viggens": "Viggen",
    "Viktorias": "Viktoria",
    "Viktoriorna": "Viktoria",
    "Viktoriors": "Viktoria",
    "Viktors": "Viktor",
    "Vilhelmar": "Vilhelm",
    "Vilhelmarna": "Vilhelm",
    "Vilhelmarnas": "Vilhelm",
    "Vilhelmars": "Vilhelm",
    "Vilhelminas": "Vilhelmina",
    "Vilhelms": "Vilhelm",
    "Villons": "Villon",
    "Vilnas": "Vilna",
    "Vinlandskartans": "Vinlandskartan",
    "Vintergatans": "Vintergatan",
    "Virginias": "Virginia",
    "Visa-korten": "Visa-kort",
    "Visa-kortens": "Visa-kort",
    "Visa-kortet": "Visa-kort",
    "Visa-kortets": "Visa-kort",
    "Visa-korts": "Visa-kort",
    "Visakortens": "Visakort",
    "Visbys": "Visby",
    "Visbyveck": "Visbyvecka",
    "Visbyveckan": "Visbyvecka",
    "Visbyveckans": "Visbyvecka",
    "Visbyveckas": "Visbyvecka",
    "Visbyvecke": "Visbyvecka",
    "Visbyvecko": "Visbyvecka",
    "Visbyveckor": "Visbyvecka",
    "Visbyveckorna": "Visbyvecka",
    "Visbyveckornas": "Visbyvecka",
    "Visbyveckors": "Visbyvecka",
    "Visbyvecks": "Visbyvecka",
    "Viskans": "Viskan",
    "Vitrysslands": "Vitryssland",
    "Vivaldis": "Vivaldi",
    "Vivekan": "Viveka",
    "Vivekans": "Viveka",
    "Vivekas": "Viveka",
    "Vivekor": "Viveka",
    "Vivekorna": "Viveka",
    "Vivekornas": "Viveka",
    "Vivekors": "Viveka",
    "Vladimirar": "Vladimir",
    "Vladimirarna": "Vladimir",
    "Vladimirarnas": "Vladimir",
    "Vladimirars": "Vladimir",
    "Vladimirs": "Vladimir",
    "Vladislavar": "Vladislav",
    "Vladislavarna": "Vladislav",
    "Vladislavarnas": "Vladislav",
    "Vladislavars": "Vladislav",
    "Vladislavs": "Vladislav",
    "Volgas": "Volga",
    "Volgograds": "Volgograd",
    "Volkswagenbussar": "Volkswagenbuss",
    "Volkswagenbussarna": "Volkswagenbuss",
    "Volkswagenbussarnas": "Volkswagenbuss",
    "Volkswagenbussars": "Volkswagenbuss",
    "Volkswagenbussen": "Volkswagenbuss",
    "Volkswagenbussens": "Volkswagenbuss",
    "Volkswagens": "Volkswagen",
    "Vollsjös": "Vollsjö",
    "Voltaires": "Voltaire",
    "Volvoanställde": "Volvoanställd",
    "Volvoanställdes": "Volvoanställd",
    "Volvoanställds": "Volvoanställd",
    "Volvoanställt": "Volvoanställd",
    "Volvoanställts": "Volvoanställd",
    "Volvon": "Volvo",
    "Vreeswijks": "Vreeswijk",
    "Vs": "V",
    "Vulgatas": "Vulgata",
    "Väddökustens": "Väddökusten",
    "Väddös": "Väddö",
    "Vädurens": "Väduren",
    "Vällingbys": "Vällingby",
    "Vänerns": "Vänern",
    "Vänsterpartiets": "Vänsterpartiet",
    "Världshälsoorganisationens": "Världshälsoorganisationen",
    "Värmlands": "Värmland",
    "Västafrikas": "Västafrika",
    "Västbankens": "Västbanken",
    "Västberlins": "Västberlin",
    "Västerbottens": "Västerbotten",
    "Västergötlands": "Västergötland",
    "Västerns": "Västern",
    "Västeuropas": "Västeuropa",
    "Västindiens": "Västindien",
    "Västmanlands": "Västmanland",
    "Västnorges": "Västnorge",
    "Västsveriges": "Västsverige",
    "Västtysklands": "Västtyskland",
    "Vätterns": "Vättern",
    "Växjös": "Växjö",
    "Vågens": "Vågen",
    "W-s": "W",
    "WC-en": "WC",
    "WC-ens": "WC",
    "WC-n": "WC",
    "WC-na": "WC",
    "WC-nas": "WC",
    "WC-ns": "WC",
    "WC-s": "WC",
    "WC-t": "WC",
    "WC:ens": "WC",
    "WC:na": "WC",
    "WC:ns": "WC",
    "WC:ts": "WC",
    "WCts": "WC",
    "WHO-s": "WHO",
    "WHO:s": "WHO",
    "WHOs": "WHO",
    "WWW:s": "WWW",
    "WWWs": "WWW",
    "Wadköpings": "Wadköping",
    "Wagners": "Wagner",
    "Wajdas": "Wajda",
    "Waldenströms": "Waldenström",
    "Waldheims": "Waldheim",
    "Wallaces": "Wallace",
    "Wallenbergs": "Wallenberg",
    "Wallengrens": "Wallengren",
    "Wallins": "Wallin",
    "Wallraffs": "Wallraff",
    "Waltar": "Walt",
    "Waltarna": "Walt",
    "Waltarnas": "Walt",
    "Waltars": "Walt",
    "Walts": "Walt",
    "Wargs": "Warg",
    "Warszawapaktens": "Warszawapakten",
    "Warszawas": "Warszawa",
    "Washingtons": "Washington",
    "Wassings": "Wassing",
    "Webers": "Weber",
    "Weddellhavets": "Weddellhavet",
    "Weichsels": "Weichsel",
    "Werkströms": "Werkström",
    "Werners": "Werner",
    "Westerbergs": "Westerberg",
    "Wichitas": "Wichita",
    "Widerbergs": "Widerberg",
    "Wiens": "Wien",
    "Wildes": "Wilde",
    "Wilhelmar": "Wilhelm",
    "Wilhelmarna": "Wilhelm",
    "Wilhelmarnas": "Wilhelm",
    "Wilhelmars": "Wilhelm",
    "Wilhelms": "Wilhelm",
    "Williams": "William",
    "Willys": "Willy",
    "Wilmingtons": "Wilmington",
    "Wilsons": "Wilson",
    "Wimbledons": "Wimbledon",
    "Winblads": "Winblad",
    "Windhoeks": "Windhoek",
    "Winstonar": "Winston",
    "Winstonarna": "Winston",
    "Winstonarnas": "Winston",
    "Winstonars": "Winston",
    "Winstons": "Winston",
    "Wisconsins": "Wisconsin",
    "Wislas": "Wisla",
    "Wolfgangs": "Wolfgang",
    "WordNets": "WordNet",
    "Wretmans": "Wretman",
    "Wrights": "Wright",
    "Ws": "W",
    "Wulfilas": "Wulfila",
    "Wyomings": "Wyoming",
    "Wårbys": "Wårby",
    "X-kromosomen": "X-kromosom",
    "X-kromosomer": "X-kromosom",
    "X-kromosomerna": "X-kromosom",
    "Xe-s": "Xe",
    "Xe:s": "Xe",
    "Xes": "Xe",
    "Y-kromosomen": "Y-kromosom",
    "Y-kromosomer": "Y-kromosom",
    "Y-kromosomerna": "Y-kromosom",
    "Y-s": "Y",
    "Yakovs": "Yakov",
    "Yalelåsens": "Yalelås",
    "Yalelåsets": "Yalelås",
    "Yassirs": "Yassir",
    "Yb-s": "Yb",
    "Yb:s": "Yb",
    "Ybs": "Yb",
    "Yemens": "Yemen",
    "Yggdrasils": "Yggdrasil",
    "Yngvar": "Yngve",
    "Yngvarna": "Yngve",
    "Yngvarnas": "Yngve",
    "Yngvars": "Yngve",
    "Yngves": "Yngve",
    "Yoldiahavets": "Yoldiahavet",
    "Yorks": "York",
    "Youngs": "Young",
    "Ys": "Y",
    "Ystads": "Ystad",
    "Yvonnes": "Yvonne",
    "Z-partikeln": "Z-partikel",
    "Z-partikelns": "Z-partikel",
    "Z-partikels": "Z-partikel",
    "Z-partiklar": "Z-partikel",
    "Z-partiklarna": "Z-partikel",
    "Z-partiklarnas": "Z-partikel",
    "Z-partiklars": "Z-partikel",
    "Zaires": "Zaire",
    "Zambias": "Zambia",
    "Zarathustras": "Zarathustra",
    "Zatopeks": "Zatopek",
    "Zeldovichs": "Zeldovich",
    "Zenons": "Zenon",
    "Zetterlings": "Zetterling",
    "Zimbabwes": "Zimbabwe",
    "Zjivkovs": "Zjivkov",
    "Zlatan-grodan": "Zlatan-groda",
    "Zlatan-grodans": "Zlatan-groda",
    "Zlatan-grodas": "Zlatan-groda",
    "Zlatan-grode": "Zlatan-groda",
    "Zlatan-grodor": "Zlatan-groda",
    "Zlatan-grodorna": "Zlatan-groda",
    "Zlatan-grodornas": "Zlatan-groda",
    "Zlatan-grodors": "Zlatan-groda",
    "Zlatans": "Zlatan",
    "Zn-s": "Zn",
    "Zn:s": "Zn",
    "Zns": "Zn",
    "Zolas": "Zola",
    "Zorns": "Zorn",
    "Zr-s": "Zr",
    "Zr:s": "Zr",
    "Zrs": "Zr",
    "Zuckermans": "Zuckerman",
    "Zwinglis": "Zwingli",
    "Zürichs": "Zürich",
    "a-bomben": "a-bomb",
    "a-bomber": "a-bomb",
    "a-bombernas": "a-bomb",
    "a-bombs": "a-bomb",
    "a-et": "a",
    "a-nas": "a",
    "a-s": "a",
    "a-ts": "a",
    "a3-s": "a3",
    "a3s": "a3",
    "a4-s": "a4",
    "a5-s": "a5",
    "a:ets": "a",
    "a:na": "a",
    "a:ns": "a",
    "a:s": "a",
    "a:ts": "a",
    "abakusen": "abakus",
    "abakusens": "abakus",
    "abakuser": "abakus",
    "abakuserna": "abakus",
    "abakusernas": "abakus",
    "abakusers": "abakus",
    "abandonen": "abandon",
    "abandonens": "abandon",
    "abandons": "abandon",
    "abbediss": "abbedissa",
    "abbedissan": "abbedissa",
    "abbedissans": "abbedissa",
    "abbedissas": "abbedissa",
    "abbedisse": "abbedissa",
    "abbedissor": "abbedissa",
    "abbedissorna": "abbedissa",
    "abbedissornas": "abbedissa",
    "abbedissors": "abbedissa",
    "abborr": "abborre",
    "abborrar": "abborre",
    "abborrarna": "abborre",
    "abborrarnas": "abborre",
    "abborrars": "abborre",
    "abborren": "abborre",
    "abborrens": "abborre",
    "abborres": "abborre",
    "abborrfiskar": "abborrfisk",
    "abborrfiskarna": "abborrfisk",
    "abborrfiskarnas": "abborrfisk",
    "abborrfiskars": "abborrfisk",
    "abborrfisken": "abborrfisk",
    "abborrfiskens": "abborrfisk",
    "abborrfisks": "abborrfisk",
    "abborrpinn": "abborrpinne",
    "abborrpinnar": "abborrpinne",
    "abborrpinnarna": "abborrpinne",
    "abborrpinnarnas": "abborrpinne",
    "abborrpinnars": "abborrpinne",
    "abborrpinnen": "abborrpinne",
    "abborrpinnens": "abborrpinne",
    "abborrpinnes": "abborrpinne",
    "abborrpinns": "abborrpinne",
    "abborrs": "abborre",
    "abbotar": "abbot",
    "abbotarna": "abbot",
    "abbotarnas": "abbot",
    "abbotars": "abbot",
    "abboten": "abbot",
    "abbotens": "abbot",
    "abbots": "abbot",
    "abbreviationen": "abbreviation",
    "abbreviationens": "abbreviation",
    "abbreviationer": "abbreviation",
    "abbreviationerna": "abbreviation",
    "abbreviationernas": "abbreviation",
    "abbreviationers": "abbreviation",
    "abbreviations": "abbreviation",
    "abbreviaturen": "abbreviatur",
    "abbreviaturens": "abbreviatur",
    "abbreviaturer": "abbreviatur",
    "abbreviaturerna": "abbreviatur",
    "abbreviaturernas": "abbreviatur",
    "abbreviaturers": "abbreviatur",
    "abbreviaturs": "abbreviatur",
    "abbrevierad": "abbreviera",
    "abbrevierade": "abbreviera",
    "abbrevierades": "abbreviera",
    "abbrevierads": "abbreviera",
    "abbrevierande": "abbreviera",
    "abbrevieranden": "abbrevierande",
    "abbrevierandena": "abbrevierande",
    "abbrevierandenas": "abbrevierande",
    "abbrevierandens": "abbrevierande",
    "abbrevierandes": "abbrevierande",
    "abbrevierandet": "abbrevierande",
    "abbrevierandets": "abbrevierande",
    "abbrevierar": "abbreviera",
    "abbrevieras": "abbreviera",
    "abbrevierat": "abbreviera",
    "abbrevierats": "abbreviera",
    "abbrevierbara": "abbrevierbar",
    "abbrevierbarare": "abbrevierbar",
    "abbrevierbarares": "abbrevierbar",
    "abbrevierbaras": "abbrevierbar",
    "abbrevierbarast": "abbrevierbar",
    "abbrevierbaraste": "abbrevierbar",
    "abbrevierbarastes": "abbrevierbar",
    "abbrevierbarasts": "abbrevierbar",
    "abbrevierbare": "abbrevierbar",
    "abbrevierbares": "abbrevierbar",
    "abbrevierbarheten": "abbrevierbarhet",
    "abbrevierbarhetens": "abbrevierbarhet",
    "abbrevierbarhets": "abbrevierbarhet",
    "abbrevierbars": "abbrevierbar",
    "abbrevierbart": "abbrevierbar",
    "abbrevierbarts": "abbrevierbar",
    "abbrevieringar": "abbreviering",
    "abbrevieringarna": "abbreviering",
    "abbrevieringarnas": "abbreviering",
    "abbrevieringars": "abbreviering",
    "abbrevieringen": "abbreviering",
    "abbrevieringens": "abbreviering",
    "abbrevierings": "abbreviering",
    "abbéen": "abbé",
    "abbéens": "abbé",
    "abbéer": "abbé",
    "abbéerna": "abbé",
    "abbéernas": "abbé",
    "abbéers": "abbé",
    "abbén": "abbé",
    "abbéns": "abbé",
    "abbés": "abbé",
    "abc-boken": "abc-bok",
    "abc-bokens": "abc-bok",
    "abc-boks": "abc-bok",
    "abc-böcker": "abc-bok",
    "abc-böckerna": "abc-bok",
    "abc-böckernas": "abc-bok",
    "abc-böckers": "abc-bok",
    "abc-et": "abc",
    "abc-ets": "abc",
    "abc-n": "abc",
    "abc-na": "abc",
    "abc-nas": "abc",
    "abc-ns": "abc",
    "abc-s": "abc",
    "abc-t": "abc",
    "abc-ts": "abc",
    "abc:et": "abc",
    "abc:ets": "abc",
    "abc:n": "abc",
    "abc:na": "abc",
    "abc:nas": "abc",
    "abc:ns": "abc",
    "abc:s": "abc",
    "abc:t": "abc",
    "abc:ts": "abc",
    "abderitiska": "abderitisk",
    "abderitiskare": "abderitisk",
    "abderitiskares": "abderitisk",
    "abderitiskas": "abderitisk",
    "abderitiskast": "abderitisk",
    "abderitiskaste": "abderitisk",
    "abderitiskastes": "abderitisk",
    "abderitiskasts": "abderitisk",
    "abderitiske": "abderitisk",
    "abderitiskes": "abderitisk",
    "abderitisks": "abderitisk",
    "abderitiskt": "abderitisk",
    "abderitiskts": "abderitisk",
    "abdikationen": "abdikation",
    "abdikationens": "abdikation",
    "abdikationer": "abdikation",
    "abdikationerna": "abdikation",
    "abdikationernas": "abdikation",
    "abdikationers": "abdikation",
    "abdikations": "abdikation",
    "abdikationshoten": "abdikationshot",
    "abdikationshotens": "abdikationshot",
    "abdikationshotet": "abdikationshot",
    "abdikationshotets": "abdikationshot",
    "abdikationshots": "abdikationshot",
    "abdikerad": "abdikera",
    "abdikerade": "abdikera",
    "abdikerades": "abdikera",
    "abdikerads": "abdikera",
    "abdikerande": "abdikera",
    "abdikeranden": "abdikerande",
    "abdikerandena": "abdikerande",
    "abdikerandenas": "abdikerande",
    "abdikerandens": "abdikerande",
    "abdikerandes": "abdikerande",
    "abdikerandet": "abdikerande",
    "abdikerandets": "abdikerande",
    "abdikerar": "abdikera",
    "abdikeras": "abdikera",
    "abdikerat": "abdikera",
    "abdikerats": "abdikera",
    "abdikerbara": "abdikerbar",
    "abdikerbarare": "abdikerbar",
    "abdikerbarares": "abdikerbar",
    "abdikerbaras": "abdikerbar",
    "abdikerbarast": "abdikerbar",
    "abdikerbaraste": "abdikerbar",
    "abdikerbarastes": "abdikerbar",
    "abdikerbarasts": "abdikerbar",
    "abdikerbare": "abdikerbar",
    "abdikerbares": "abdikerbar",
    "abdikerbarheten": "abdikerbarhet",
    "abdikerbarhetens": "abdikerbarhet",
    "abdikerbarhets": "abdikerbarhet",
    "abdikerbars": "abdikerbar",
    "abdikerbart": "abdikerbar",
    "abdikerbarts": "abdikerbar",
    "abdikeringar": "abdikering",
    "abdikeringarna": "abdikering",
    "abdikeringarnas": "abdikering",
    "abdikeringars": "abdikering",
    "abdikeringen": "abdikering",
    "abdikeringens": "abdikering",
    "abdikerings": "abdikering",
    "abdomens": "abdomen",
    "abdomina": "abdomen",
    "abdominas": "abdomen",
    "aberen": "aber",
    "aberens": "aber",
    "aberet": "aber",
    "aberets": "aber",
    "aberrationen": "aberration",
    "aberrationens": "aberration",
    "aberrationer": "aberration",
    "aberrationerna": "aberration",
    "aberrationernas": "aberration",
    "aberrationers": "aberration",
    "aberrations": "aberration",
    "abers": "aber",
    "abessiniern": "abessinier",
    "abessinierna": "abessinier",
    "abessiniernas": "abessinier",
    "abessinierns": "abessinier",
    "abessiniers": "abessinier",
    "abessinska": "abessinsk",
    "abessinskan": "abessinska",
    "abessinskans": "abessinska",
    "abessinskare": "abessinsk",
    "abessinskares": "abessinsk",
    "abessinskas": "abessinska",
    "abessinskast": "abessinsk",
    "abessinskaste": "abessinsk",
    "abessinskastes": "abessinsk",
    "abessinskasts": "abessinsk",
    "abessinske": "abessinska",
    "abessinskes": "abessinsk",
    "abessinskor": "abessinska",
    "abessinskorna": "abessinska",
    "abessinskornas": "abessinska",
    "abessinskors": "abessinska",
    "abessinsks": "abessinsk",
    "abessinskt": "abessinsk",
    "abessinskts": "abessinsk",
    "abessiven": "abessiv",
    "abessivens": "abessiv",
    "abessiver": "abessiv",
    "abessiverna": "abessiv",
    "abessivernas": "abessiv",
    "abessivers": "abessiv",
    "abessivs": "abessiv",
    "abiliteten": "abilitet",
    "abilitetens": "abilitet",
    "abiliteter": "abilitet",
    "abiliteterna": "abilitet",
    "abiliteternas": "abilitet",
    "abiliteters": "abilitet",
    "abilitets": "abilitet",
    "abiturienten": "abiturient",
    "abiturientens": "abiturient",
    "abiturienter": "abiturient",
    "abiturienterna": "abiturient",
    "abiturienternas": "abiturient",
    "abiturienters": "abiturient",
    "abiturientexamens": "abiturientexamen",
    "abiturientexamina": "abiturientexamen",
    "abiturientexaminas": "abiturientexamen",
    "abiturients": "abiturient",
    "ablationen": "ablation",
    "ablationens": "ablation",
    "ablationer": "ablation",
    "ablationerna": "ablation",
    "ablationernas": "ablation",
    "ablationers": "ablation",
    "ablations": "ablation",
    "ablativen": "ablativ",
    "ablativens": "ablativ",
    "ablativer": "ablativ",
    "ablativerna": "ablativ",
    "ablativernas": "ablativ",
    "ablativers": "ablativ",
    "ablativs": "ablativ",
    "abnorma": "abnorm",
    "abnormare": "abnorm",
    "abnormares": "abnorm",
    "abnormas": "abnorm",
    "abnormast": "abnorm",
    "abnormaste": "abnorm",
    "abnormastes": "abnorm",
    "abnormasts": "abnorm",
    "abnorme": "abnorm",
    "abnormes": "abnorm",
    "abnormiteten": "abnormitet",
    "abnormitetens": "abnormitet",
    "abnormiteter": "abnormitet",
    "abnormiteterna": "abnormitet",
    "abnormiteternas": "abnormitet",
    "abnormiteters": "abnormitet",
    "abnormitets": "abnormitet",
    "abnorms": "abnorm",
    "abnormt": "abnorm",
    "abnormts": "abnorm",
    "abolitionen": "abolition",
    "abolitionens": "abolition",
    "abolitioner": "abolition",
    "abolitionerna": "abolition",
    "abolitionernas": "abolition",
    "abolitioners": "abolition",
    "abolitionisten": "abolitionist",
    "abolitionistens": "abolitionist",
    "abolitionister": "abolitionist",
    "abolitionisterna": "abolitionist",
    "abolitionisternas": "abolitionist",
    "abolitionisters": "abolitionist",
    "abolitionistiska": "abolitionistisk",
    "abolitionistiskas": "abolitionistisk",
    "abolitionistiske": "abolitionistisk",
    "abolitionistiskes": "abolitionistisk",
    "abolitionistisks": "abolitionistisk",
    "abolitionistiskt": "abolitionistisk",
    "abolitionistiskts": "abolitionistisk",
    "abolitionists": "abolitionist",
    "abolitions": "abolition",
    "abonnemangen": "abonnemang",
    "abonnemangens": "abonnemang",
    "abonnemanget": "abonnemang",
    "abonnemangets": "abonnemang",
    "abonnemangs": "abonnemang",
    "abonnenten": "abonnent",
    "abonnentens": "abonnent",
    "abonnenter": "abonnent",
    "abonnenterna": "abonnent",
    "abonnenternas": "abonnent",
    "abonnenters": "abonnent",
    "abonnents": "abonnent",
    "abonnerad": "abonnera",
    "abonnerade": "abonnera",
    "abonnerades": "abonnera",
    "abonnerads": "abonnera",
    "abonnerande": "abonnera",
    "abonneranden": "abonnerande",
    "abonnerandena": "abonnerande",
    "abonnerandenas": "abonnerande",
    "abonnerandens": "abonnerande",
    "abonnerandes": "abonnerande",
    "abonnerandet": "abonnerande",
    "abonnerandets": "abonnerande",
    "abonnerar": "abonnera",
    "abonneras": "abonnera",
    "abonnerat": "abonnera",
    "abonnerats": "abonnera",
    "abonnerbara": "abonnerbar",
    "abonnerbarare": "abonnerbar",
    "abonnerbarares": "abonnerbar",
    "abonnerbaras": "abonnerbar",
    "abonnerbarast": "abonnerbar",
    "abonnerbaraste": "abonnerbar",
    "abonnerbarastes": "abonnerbar",
    "abonnerbarasts": "abonnerbar",
    "abonnerbare": "abonnerbar",
    "abonnerbares": "abonnerbar",
    "abonnerbarheten": "abonnerbarhet",
    "abonnerbarhetens": "abonnerbarhet",
    "abonnerbarhets": "abonnerbarhet",
    "abonnerbars": "abonnerbar",
    "abonnerbart": "abonnerbar",
    "abonnerbarts": "abonnerbar",
    "abonneringar": "abonnering",
    "abonneringarna": "abonnering",
    "abonneringarnas": "abonnering",
    "abonneringars": "abonnering",
    "abonneringen": "abonnering",
    "abonneringens": "abonnering",
    "abonnerings": "abonnering",
    "aboriginen": "aborigin",
    "aboriginens": "aborigin",
    "aboriginer": "aborigin",
    "aboriginern": "aboriginer",
    "aboriginerna": "aboriginer",
    "aboriginernas": "aboriginer",
    "aboriginerns": "aboriginer",
    "aboriginers": "aboriginer",
    "aborigins": "aborigin",
    "aborr": "aborre",
    "aborrar": "aborre",
    "aborrarna": "aborre",
    "aborrarnas": "aborre",
    "aborrars": "aborre",
    "aborren": "aborre",
    "aborrens": "aborre",
    "aborres": "aborre",
    "aborrs": "aborre",
    "aborten": "abort",
    "abortens": "abort",
    "aborter": "abort",
    "aborterad": "abortera",
    "aborterade": "abortera",
    "aborterades": "abortera",
    "aborterads": "abortera",
    "aborterande": "abortera",
    "aborteranden": "aborterande",
    "aborterandena": "aborterande",
    "aborterandenas": "aborterande",
    "aborterandens": "aborterande",
    "aborterandes": "aborterande",
    "aborterandet": "aborterande",
    "aborterandets": "aborterande",
    "aborterar": "abortera",
    "aborteras": "abortera",
    "aborterat": "abortera",
    "aborterats": "abortera",
    "aborterbara": "aborterbar",
    "aborterbarare": "aborterbar",
    "aborterbarares": "aborterbar",
    "aborterbaras": "aborterbar",
    "aborterbarast": "aborterbar",
    "aborterbaraste": "aborterbar",
    "aborterbarastes": "aborterbar",
    "aborterbarasts": "aborterbar",
    "aborterbare": "aborterbar",
    "aborterbares": "aborterbar",
    "aborterbarheten": "aborterbarhet",
    "aborterbarhetens": "aborterbarhet",
    "aborterbarhets": "aborterbarhet",
    "aborterbars": "aborterbar",
    "aborterbart": "aborterbar",
    "aborterbarts": "aborterbar",
    "aborteringar": "abortering",
    "aborteringarna": "abortering",
    "aborteringarnas": "abortering",
    "aborteringars": "abortering",
    "aborteringen": "abortering",
    "aborteringens": "abortering",
    "aborterings": "abortering",
    "aborterna": "abort",
    "aborternas": "abort",
    "aborters": "abort",
    "abortfrågan": "abortfråga",
    "abortfrågans": "abortfråga",
    "abortfrågas": "abortfråga",
    "abortfråge": "abortfråga",
    "abortfrågor": "abortfråga",
    "abortfrågorna": "abortfråga",
    "abortfrågornas": "abortfråga",
    "abortfrågors": "abortfråga",
    "abortiva": "abortiv",
    "abortivare": "abortiv",
    "abortivares": "abortiv",
    "abortivas": "abortiv",
    "abortivast": "abortiv",
    "abortivaste": "abortiv",
    "abortivastes": "abortiv",
    "abortivasts": "abortiv",
    "abortive": "abortiv",
    "abortives": "abortiv",
    "abortivs": "abortiv",
    "abortivt": "abortiv",
    "abortivts": "abortiv",
    "abortmotståndar": "abortmotståndare",
    "abortmotståndaren": "abortmotståndare",
    "abortmotståndarens": "abortmotståndare",
    "abortmotståndares": "abortmotståndare",
    "abortmotståndarna": "abortmotståndare",
    "abortmotståndarnas": "abortmotståndare",
    "abortmotstånden": "abortmotstånd",
    "abortmotståndens": "abortmotstånd",
    "abortmotståndet": "abortmotstånd",
    "abortmotståndets": "abortmotstånd",
    "abortmotstånds": "abortmotstånd",
    "abortpillerna": "abortpiller",
    "abortpillernas": "abortpiller",
    "abortpillers": "abortpiller",
    "abortpillren": "abortpiller",
    "abortpillrens": "abortpiller",
    "abortpillret": "abortpiller",
    "abortpillrets": "abortpiller",
    "aborträtten": "aborträtt",
    "aborträttens": "aborträtt",
    "aborträtter": "aborträtt",
    "aborträtterna": "aborträtt",
    "aborträtternas": "aborträtt",
    "aborträtters": "aborträtt",
    "aborträtts": "aborträtt",
    "abortrådgivningar": "abortrådgivning",
    "abortrådgivningarna": "abortrådgivning",
    "abortrådgivningarnas": "abortrådgivning",
    "abortrådgivningars": "abortrådgivning",
    "abortrådgivningen": "abortrådgivning",
    "abortrådgivningens": "abortrådgivning",
    "abortrådgivnings": "abortrådgivning",
    "aborts": "abort",
    "abortören": "abortör",
    "abortörens": "abortör",
    "abortörer": "abortör",
    "abortörerna": "abortör",
    "abortörernas": "abortör",
    "abortörers": "abortör",
    "abortörs": "abortör",
    "abraderad": "abradera",
    "abraderade": "abradera",
    "abraderades": "abradera",
    "abraderads": "abradera",
    "abraderande": "abradera",
    "abraderanden": "abraderande",
    "abraderandena": "abraderande",
    "abraderandenas": "abraderande",
    "abraderandens": "abraderande",
    "abraderandes": "abraderande",
    "abraderandet": "abraderande",
    "abraderandets": "abraderande",
    "abraderar": "abradera",
    "abraderas": "abradera",
    "abraderat": "abradera",
    "abraderats": "abradera",
    "abraderbara": "abraderbar",
    "abraderbarare": "abraderbar",
    "abraderbarares": "abraderbar",
    "abraderbaras": "abraderbar",
    "abraderbarast": "abraderbar",
    "abraderbaraste": "abraderbar",
    "abraderbarastes": "abraderbar",
    "abraderbarasts": "abraderbar",
    "abraderbare": "abraderbar",
    "abraderbares": "abraderbar",
    "abraderbarheten": "abraderbarhet",
    "abraderbarhetens": "abraderbarhet",
    "abraderbarhets": "abraderbarhet",
    "abraderbars": "abraderbar",
    "abraderbart": "abraderbar",
    "abraderbarts": "abraderbar",
    "abraderingar": "abradering",
    "abraderingarna": "abradering",
    "abraderingarnas": "abradering",
    "abraderingars": "abradering",
    "abraderingen": "abradering",
    "abraderingens": "abradering",
    "abraderings": "abradering",
    "abrakadabras": "abrakadabra",
    "abrakadabrat": "abrakadabra",
    "abrakadabrats": "abrakadabra",
    "abrasionen": "abrasion",
    "abrasionens": "abrasion",
    "abrasioner": "abrasion",
    "abrasionerna": "abrasion",
    "abrasionernas": "abrasion",
    "abrasioners": "abrasion",
    "abrasions": "abrasion",
    "abren": "aber",
    "abrens": "aber",
    "abret": "aber",
    "abrets": "aber",
    "abrovinken": "abrovink",
    "abrovinkens": "abrovink",
    "abrovinker": "abrovink",
    "abrovinkerna": "abrovink",
    "abrovinkernas": "abrovink",
    "abrovinkers": "abrovink",
    "abrovinks": "abrovink",
    "abrovinschen": "abrovinsch",
    "abrovinschens": "abrovinsch",
    "abrovinscher": "abrovinsch",
    "abrovinscherna": "abrovinsch",
    "abrovinschernas": "abrovinsch",
    "abrovinschers": "abrovinsch",
    "abrovinschs": "abrovinsch",
    "abrupta": "abrupt",
    "abruptare": "abrupt",
    "abruptares": "abrupt",
    "abruptas": "abrupt",
    "abruptast": "abrupt",
    "abruptaste": "abrupt",
    "abruptastes": "abrupt",
    "abruptasts": "abrupt",
    "abrupte": "abrupt",
    "abruptes": "abrupt",
    "abruptheten": "abrupthet",
    "abrupthetens": "abrupthet",
    "abrupthets": "abrupthet",
    "abrupts": "abrupt",
    "abscessen": "abscess",
    "abscessens": "abscess",
    "abscesser": "abscess",
    "abscesserna": "abscess",
    "abscessernas": "abscess",
    "abscessers": "abscess",
    "absensen": "absens",
    "absensens": "absens",
    "absenser": "absens",
    "absenserna": "absens",
    "absensernas": "absens",
    "absensers": "absens",
    "absiden": "absid",
    "absidens": "absid",
    "absider": "absid",
    "absiderna": "absid",
    "absidernas": "absid",
    "absiders": "absid",
    "absids": "absid",
    "absinten": "absint",
    "absintens": "absint",
    "absinter": "absint",
    "absinterna": "absint",
    "absinternas": "absint",
    "absinters": "absint",
    "absints": "absint",
    "abskiss": "abskissa",
    "abskissan": "abskissa",
    "abskissans": "abskissa",
    "abskissas": "abskissa",
    "abskisse": "abskissa",
    "abskissor": "abskissa",
    "abskissorna": "abskissa",
    "abskissornas": "abskissa",
    "abskissors": "abskissa",
    "absoluta": "absolut",
    "absolutare": "absolut",
    "absolutares": "absolut",
    "absolutas": "absolut",
    "absolutast": "absolut",
    "absolutaste": "absolut",
    "absolutastes": "absolut",
    "absolutasts": "absolut",
    "absolutbeloppen": "absolutbelopp",
    "absolutbeloppens": "absolutbelopp",
    "absolutbeloppet": "absolutbelopp",
    "absolutbeloppets": "absolutbelopp",
    "absolutbelopps": "absolutbelopp",
    "absolute": "absolut",
    "absolutes": "absolut",
    "absolutheten": "absoluthet",
    "absoluthetens": "absoluthet",
    "absoluthets": "absoluthet",
    "absolutionen": "absolution",
    "absolutionens": "absolution",
    "absolutioner": "absolution",
    "absolutionerna": "absolution",
    "absolutionernas": "absolution",
    "absolutioners": "absolution",
    "absolutions": "absolution",
    "absolutismen": "absolutism",
    "absolutismens": "absolutism",
    "absolutismer": "absolutism",
    "absolutismerna": "absolutism",
    "absolutismernas": "absolutism",
    "absolutismers": "absolutism",
    "absolutisms": "absolutism",
    "absolutisten": "absolutist",
    "absolutistens": "absolutist",
    "absolutister": "absolutist",
    "absolutisterna": "absolutist",
    "absolutisternas": "absolutist",
    "absolutisters": "absolutist",
    "absolutistiska": "absolutistisk",
    "absolutistiskare": "absolutistisk",
    "absolutistiskares": "absolutistisk",
    "absolutistiskas": "absolutistisk",
    "absolutistiskast": "absolutistisk",
    "absolutistiskaste": "absolutistisk",
    "absolutistiskastes": "absolutistisk",
    "absolutistiskasts": "absolutistisk",
    "absolutistiske": "absolutistisk",
    "absolutistiskes": "absolutistisk",
    "absolutistisks": "absolutistisk",
    "absolutistiskt": "absolutistisk",
    "absolutistiskts": "absolutistisk",
    "absolutists": "absolutist",
    "absolutiven": "absolutiv",
    "absolutivens": "absolutiv",
    "absolutiver": "absolutiv",
    "absolutiverna": "absolutiv",
    "absolutivernas": "absolutiv",
    "absolutivers": "absolutiv",
    "absolutivobjekten": "absolutivobjekt",
    "absolutivobjektens": "absolutivobjekt",
    "absolutivobjektet": "absolutivobjekt",
    "absolutivobjektets": "absolutivobjekt",
    "absolutivobjekts": "absolutivobjekt",
    "absolutivs": "absolutiv",
    "absolutivsubjekten": "absolutivsubjekt",
    "absolutivsubjektens": "absolutivsubjekt",
    "absolutivsubjektet": "absolutivsubjekt",
    "absolutivsubjektets": "absolutivsubjekt",
    "absolutivsubjekts": "absolutivsubjekt",
    "absoluts": "absolut",
    "absolverad": "absolvera",
    "absolverade": "absolvera",
    "absolverades": "absolvera",
    "absolverads": "absolvera",
    "absolverande": "absolvera",
    "absolveranden": "absolverande",
    "absolverandena": "absolverande",
    "absolverandenas": "absolverande",
    "absolverandens": "absolverande",
    "absolverandes": "absolverande",
    "absolverandet": "absolverande",
    "absolverandets": "absolverande",
    "absolverar": "absolvera",
    "absolveras": "absolvera",
    "absolverat": "absolvera",
    "absolverats": "absolvera",
    "absolverbara": "absolverbar",
    "absolverbarare": "absolverbar",
    "absolverbarares": "absolverbar",
    "absolverbaras": "absolverbar",
    "absolverbarast": "absolverbar",
    "absolverbaraste": "absolverbar",
    "absolverbarastes": "absolverbar",
    "absolverbarasts": "absolverbar",
    "absolverbare": "absolverbar",
    "absolverbares": "absolverbar",
    "absolverbarheten": "absolverbarhet",
    "absolverbarhetens": "absolverbarhet",
    "absolverbarhets": "absolverbarhet",
    "absolverbars": "absolverbar",
    "absolverbart": "absolverbar",
    "absolverbarts": "absolverbar",
    "absolveringar": "absolvering",
    "absolveringarna": "absolvering",
    "absolveringarnas": "absolvering",
    "absolveringars": "absolvering",
    "absolveringen": "absolvering",
    "absolveringens": "absolvering",
    "absolverings": "absolvering",
    "absorber": "absorbera",
    "absorberad": "absorbera",
    "absorberade": "absorbera",
    "absorberades": "absorbera",
    "absorberads": "absorbera",
    "absorberande": "absorbera",
    "absorberanden": "absorberande",
    "absorberandena": "absorberande",
    "absorberandenas": "absorberande",
    "absorberandens": "absorberande",
    "absorberandes": "absorberande",
    "absorberandet": "absorberande",
    "absorberandets": "absorberande",
    "absorberar": "absorbera",
    "absorberas": "absorbera",
    "absorberat": "absorbera",
    "absorberats": "absorbera",
    "absorberbara": "absorberbar",
    "absorberbarare": "absorberbar",
    "absorberbarares": "absorberbar",
    "absorberbaras": "absorberbar",
    "absorberbarast": "absorberbar",
    "absorberbaraste": "absorberbar",
    "absorberbarastes": "absorberbar",
    "absorberbarasts": "absorberbar",
    "absorberbare": "absorberbar",
    "absorberbares": "absorberbar",
    "absorberbarheten": "absorberbarhet",
    "absorberbarhetens": "absorberbarhet",
    "absorberbarhets": "absorberbarhet",
    "absorberbars": "absorberbar",
    "absorberbart": "absorberbar",
    "absorberbarts": "absorberbar",
    "absorberingar": "absorbering",
    "absorberingarna": "absorbering",
    "absorberingarnas": "absorbering",
    "absorberingars": "absorbering",
    "absorberingen": "absorbering",
    "absorberingens": "absorbering",
    "absorberings": "absorbering",
    "absorberingsförmågan": "absorberingsförmåga",
    "absorberingsförmågans": "absorberingsförmåga",
    "absorberingsförmågas": "absorberingsförmåga",
    "absorberingsförmåge": "absorberingsförmåga",
    "absorberingsförmågor": "absorberingsförmåga",
    "absorberingsförmågorna": "absorberingsförmåga",
    "absorberingsförmågornas": "absorberingsförmåga",
    "absorberingsförmågors": "absorberingsförmåga",
    "absorbern": "absorber",
    "absorberns": "absorber",
    "absorbers": "absorber",
    "absorbrar": "absorber",
    "absorbrarna": "absorber",
    "absorbrarnas": "absorber",
    "absorbrars": "absorber",
    "absorptionen": "absorption",
    "absorptionens": "absorption",
    "absorptioner": "absorption",
    "absorptionerna": "absorption",
    "absorptionernas": "absorption",
    "absorptioners": "absorption",
    "absorptions": "absorption",
    "absorptionslinjen": "absorptionslinje",
    "absorptionslinjens": "absorptionslinje",
    "absorptionslinjer": "absorptionslinje",
    "absorptionslinjerna": "absorptionslinje",
    "absorptionslinjernas": "absorptionslinje",
    "absorptionslinjers": "absorptionslinje",
    "absorptionslinjes": "absorptionslinje",
    "abstinensbesvären": "abstinensbesvär",
    "abstinensbesvärens": "abstinensbesvär",
    "abstinensbesvärs": "abstinensbesvär",
    "abstinensen": "abstinens",
    "abstinensens": "abstinens",
    "abstraherad": "abstrahera",
    "abstraherade": "abstrahera",
    "abstraherades": "abstrahera",
    "abstraherads": "abstrahera",
    "abstraherande": "abstrahera",
    "abstraheranden": "abstraherande",
    "abstraherandena": "abstraherande",
    "abstraherandenas": "abstraherande",
    "abstraherandens": "abstraherande",
    "abstraherandes": "abstraherande",
    "abstraherandet": "abstraherande",
    "abstraherandets": "abstraherande",
    "abstraherar": "abstrahera",
    "abstraheras": "abstrahera",
    "abstraherat": "abstrahera",
    "abstraherats": "abstrahera",
    "abstraherbara": "abstraherbar",
    "abstraherbarare": "abstraherbar",
    "abstraherbarares": "abstraherbar",
    "abstraherbaras": "abstraherbar",
    "abstraherbarast": "abstraherbar",
    "abstraherbaraste": "abstraherbar",
    "abstraherbarastes": "abstraherbar",
    "abstraherbarasts": "abstraherbar",
    "abstraherbare": "abstraherbar",
    "abstraherbares": "abstraherbar",
    "abstraherbarheten": "abstraherbarhet",
    "abstraherbarhetens": "abstraherbarhet",
    "abstraherbarhets": "abstraherbarhet",
    "abstraherbars": "abstraherbar",
    "abstraherbart": "abstraherbar",
    "abstraherbarts": "abstraherbar",
    "abstraheringar": "abstrahering",
    "abstraheringarna": "abstrahering",
    "abstraheringarnas": "abstrahering",
    "abstraheringars": "abstrahering",
    "abstraheringen": "abstrahering",
    "abstraheringens": "abstrahering",
    "abstraherings": "abstrahering",
    "abstrakta": "abstrakt",
    "abstraktare": "abstrakt",
    "abstraktares": "abstrakt",
    "abstraktas": "abstrakt",
    "abstraktast": "abstrakt",
    "abstraktaste": "abstrakt",
    "abstraktastes": "abstrakt",
    "abstraktasts": "abstrakt",
    "abstrakte": "abstrakt",
    "abstrakter": "abstrakt",
    "abstrakterna": "abstrakt",
    "abstrakternas": "abstrakt",
    "abstrakters": "abstrakt",
    "abstraktes": "abstrakt",
    "abstraktet": "abstrakt",
    "abstraktets": "abstrakt",
    "abstraktheten": "abstrakthet",
    "abstrakthetens": "abstrakthet",
    "abstrakthets": "abstrakthet",
    "abstraktionen": "abstraktion",
    "abstraktionens": "abstraktion",
    "abstraktioner": "abstraktion",
    "abstraktionerna": "abstraktion",
    "abstraktionernas": "abstraktion",
    "abstraktioners": "abstraktion",
    "abstraktions": "abstraktion",
    "abstrakts": "abstrakt",
    "abstrusa": "abstrus",
    "abstrusare": "abstrus",
    "abstrusares": "abstrus",
    "abstrusas": "abstrus",
    "abstrusast": "abstrus",
    "abstrusaste": "abstrus",
    "abstrusastes": "abstrus",
    "abstrusasts": "abstrus",
    "abstruse": "abstrus",
    "abstruses": "abstrus",
    "abstrust": "abstrus",
    "abstrusts": "abstrus",
    "absurda": "absurd",
    "absurdare": "absurd",
    "absurdares": "absurd",
    "absurdas": "absurd",
    "absurdast": "absurd",
    "absurdaste": "absurd",
    "absurdastes": "absurd",
    "absurdasts": "absurd",
    "absurde": "absurd",
    "absurdes": "absurd",
    "absurdheten": "absurdhet",
    "absurdhetens": "absurdhet",
    "absurdhets": "absurdhet",
    "absurdismen": "absurdism",
    "absurdismens": "absurdism",
    "absurdismer": "absurdism",
    "absurdismerna": "absurdism",
    "absurdismernas": "absurdism",
    "absurdismers": "absurdism",
    "absurdisms": "absurdism",
    "absurdistiska": "absurdistisk",
    "absurdistiskas": "absurdistisk",
    "absurdistiske": "absurdistisk",
    "absurdistiskes": "absurdistisk",
    "absurdistisks": "absurdistisk",
    "absurdistiskt": "absurdistisk",
    "absurdistiskts": "absurdistisk",
    "absurditeten": "absurditet",
    "absurditetens": "absurditet",
    "absurditeter": "absurditet",
    "absurditeterna": "absurditet",
    "absurditeternas": "absurditet",
    "absurditeters": "absurditet",
    "absurditets": "absurditet",
    "absurds": "absurd",
    "absurt": "absurd",
    "absurts": "absurd",
    "abundansen": "abundans",
    "abundansens": "abundans",
    "abundanta": "abundant",
    "abundantare": "abundant",
    "abundantares": "abundant",
    "abundantas": "abundant",
    "abundantast": "abundant",
    "abundantaste": "abundant",
    "abundantastes": "abundant",
    "abundantasts": "abundant",
    "abundante": "abundant",
    "abundantes": "abundant",
    "abundants": "abundant",
    "abyssala": "abyssal",
    "abyssalare": "abyssal",
    "abyssalares": "abyssal",
    "abyssalas": "abyssal",
    "abyssalast": "abyssal",
    "abyssalaste": "abyssal",
    "abyssalastes": "abyssal",
    "abyssalasts": "abyssal",
    "abyssale": "abyssal",
    "abyssales": "abyssal",
    "abyssals": "abyssal",
    "abyssalt": "abyssal",
    "abyssalts": "abyssal",
    "accederad": "accedera",
    "accederade": "accedera",
    "accederades": "accedera",
    "accederads": "accedera",
    "accederande": "accedera",
    "accederanden": "accederande",
    "accederandena": "accederande",
    "accederandenas": "accederande",
    "accederandens": "accederande",
    "accederandes": "accederande",
    "accederandet": "accederande",
    "accederandets": "accederande",
    "accederar": "accedera",
    "accederas": "accedera",
    "accederat": "accedera",
    "accederats": "accedera",
    "accederbara": "accederbar",
    "accederbarare": "accederbar",
    "accederbarares": "accederbar",
    "accederbaras": "accederbar",
    "accederbarast": "accederbar",
    "accederbaraste": "accederbar",
    "accederbarastes": "accederbar",
    "accederbarasts": "accederbar",
    "accederbare": "accederbar",
    "accederbares": "accederbar",
    "accederbarheten": "accederbarhet",
    "accederbarhetens": "accederbarhet",
    "accederbarhets": "accederbarhet",
    "accederbars": "accederbar",
    "accederbart": "accederbar",
    "accederbarts": "accederbar",
    "accederingar": "accedering",
    "accederingarna": "accedering",
    "accederingarnas": "accedering",
    "accederingars": "accedering",
    "accederingen": "accedering",
    "accederingens": "accedering",
    "accederings": "accedering",
    "accelerationen": "acceleration",
    "accelerationens": "acceleration",
    "accelerationer": "acceleration",
    "accelerationerna": "acceleration",
    "accelerationernas": "acceleration",
    "accelerationers": "acceleration",
    "accelerations": "acceleration",
    "acceleratorer": "accelerator",
    "acceleratorerna": "accelerator",
    "acceleratorernas": "accelerator",
    "acceleratorers": "accelerator",
    "acceleratormaskinen": "acceleratormaskin",
    "acceleratormaskinens": "acceleratormaskin",
    "acceleratormaskiner": "acceleratormaskin",
    "acceleratormaskinerna": "acceleratormaskin",
    "acceleratormaskinernas": "acceleratormaskin",
    "acceleratormaskiners": "acceleratormaskin",
    "acceleratormaskins": "acceleratormaskin",
    "acceleratorn": "accelerator",
    "acceleratorns": "accelerator",
    "accelerators": "accelerator",
    "acceleratorsystemen": "acceleratorsystem",
    "acceleratorsystemens": "acceleratorsystem",
    "acceleratorsystemet": "acceleratorsystem",
    "acceleratorsystemets": "acceleratorsystem",
    "acceleratorsystems": "acceleratorsystem",
    "accelererad": "accelerera",
    "accelererade": "accelerera",
    "accelererades": "accelerera",
    "accelererads": "accelerera",
    "accelererande": "accelerera",
    "accelereranden": "accelererande",
    "accelererandena": "accelererande",
    "accelererandenas": "accelererande",
    "accelererandens": "accelererande",
    "accelererandes": "accelererande",
    "accelererandet": "accelererande",
    "accelererandets": "accelererande",
    "accelererar": "accelerera",
    "accelereras": "accelerera",
    "accelererat": "accelerera",
    "accelererats": "accelerera",
    "accelererbara": "accelererbar",
    "accelererbarare": "accelererbar",
    "accelererbarares": "accelererbar",
    "accelererbaras": "accelererbar",
    "accelererbarast": "accelererbar",
    "accelererbaraste": "accelererbar",
    "accelererbarastes": "accelererbar",
    "accelererbarasts": "accelererbar",
    "accelererbare": "accelererbar",
    "accelererbares": "accelererbar",
    "accelererbarheten": "accelererbarhet",
    "accelererbarhetens": "accelererbarhet",
    "accelererbarhets": "accelererbarhet",
    "accelererbars": "accelererbar",
    "accelererbart": "accelererbar",
    "accelererbarts": "accelererbar",
    "accelereringar": "accelerering",
    "accelereringarna": "accelerering",
    "accelereringarnas": "accelerering",
    "accelereringars": "accelerering",
    "accelereringen": "accelerering",
    "accelereringens": "accelerering",
    "accelererings": "accelerering",
    "accenten": "accent",
    "accentens": "accent",
    "accenter": "accent",
    "accenterna": "accent",
    "accenternas": "accent",
    "accenters": "accent",
    "accentförskjutningar": "accentförskjutning",
    "accentförskjutningarna": "accentförskjutning",
    "accentförskjutningarnas": "accentförskjutning",
    "accentförskjutningars": "accentförskjutning",
    "accentförskjutningen": "accentförskjutning",
    "accentförskjutningens": "accentförskjutning",
    "accentförskjutnings": "accentförskjutning",
    "accents": "accent",
    "accentteckens": "accenttecken",
    "accenttecknen": "accenttecken",
    "accenttecknens": "accenttecken",
    "accenttecknet": "accenttecken",
    "accenttecknets": "accenttecken",
    "accentuerad": "accentuera",
    "accentuerade": "accentuera",
    "accentuerades": "accentuera",
    "accentuerads": "accentuera",
    "accentuerande": "accentuera",
    "accentueranden": "accentuerande",
    "accentuerandena": "accentuerande",
    "accentuerandenas": "accentuerande",
    "accentuerandens": "accentuerande",
    "accentuerandes": "accentuerande",
    "accentuerandet": "accentuerande",
    "accentuerandets": "accentuerande",
    "accentuerar": "accentuera",
    "accentueras": "accentuera",
    "accentuerat": "accentuera",
    "accentuerats": "accentuera",
    "accentuerbara": "accentuerbar",
    "accentuerbarare": "accentuerbar",
    "accentuerbarares": "accentuerbar",
    "accentuerbaras": "accentuerbar",
    "accentuerbarast": "accentuerbar",
    "accentuerbaraste": "accentuerbar",
    "accentuerbarastes": "accentuerbar",
    "accentuerbarasts": "accentuerbar",
    "accentuerbare": "accentuerbar",
    "accentuerbares": "accentuerbar",
    "accentuerbarheten": "accentuerbarhet",
    "accentuerbarhetens": "accentuerbarhet",
    "accentuerbarhets": "accentuerbarhet",
    "accentuerbars": "accentuerbar",
    "accentuerbart": "accentuerbar",
    "accentuerbarts": "accentuerbar",
    "accentueringar": "accentuering",
    "accentueringarna": "accentuering",
    "accentueringarnas": "accentuering",
    "accentueringars": "accentuering",
    "accentueringen": "accentuering",
    "accentueringens": "accentuering",
    "accentuerings": "accentuering",
    "acceptabels": "acceptabel",
    "acceptabelt": "acceptabel",
    "acceptabelts": "acceptabel",
    "acceptabla": "acceptabel",
    "acceptablare": "acceptabel",
    "acceptablares": "acceptabel",
    "acceptablas": "acceptabel",
    "acceptablast": "acceptabel",
    "acceptablaste": "acceptabel",
    "acceptablastes": "acceptabel",
    "acceptablasts": "acceptabel",
    "acceptable": "acceptabel",
    "acceptables": "acceptabel",
    "acceptanten": "acceptant",
    "acceptantens": "acceptant",
    "acceptanter": "acceptant",
    "acceptanterna": "acceptant",
    "acceptanternas": "acceptant",
    "acceptanters": "acceptant",
    "acceptants": "acceptant",
    "accepten": "accept",
    "acceptens": "accept",
    "accepter": "accept",
    "accepterad": "acceptera",
    "accepterade": "acceptera",
    "accepterades": "acceptera",
    "accepterads": "acceptera",
    "accepterande": "acceptera",
    "accepteranden": "accepterande",
    "accepterandena": "accepterande",
    "accepterandenas": "accepterande",
    "accepterandens": "accepterande",
    "accepterandes": "accepterande",
    "accepterandet": "accepterande",
    "accepterandets": "accepterande",
    "accepterar": "acceptera",
    "accepteras": "acceptera",
    "accepterat": "acceptera",
    "accepterats": "acceptera",
    "accepterbara": "accepterbar",
    "accepterbarare": "accepterbar",
    "accepterbarares": "accepterbar",
    "accepterbaras": "accepterbar",
    "accepterbarast": "accepterbar",
    "accepterbaraste": "accepterbar",
    "accepterbarastes": "accepterbar",
    "accepterbarasts": "accepterbar",
    "accepterbare": "accepterbar",
    "accepterbares": "accepterbar",
    "accepterbarheten": "accepterbarhet",
    "accepterbarhetens": "accepterbarhet",
    "accepterbarhets": "accepterbarhet",
    "accepterbars": "accepterbar",
    "accepterbart": "accepterbar",
    "accepterbarts": "accepterbar",
    "accepteringar": "acceptering",
    "accepteringarna": "acceptering",
    "accepteringarnas": "acceptering",
    "accepteringars": "acceptering",
    "accepteringen": "acceptering",
    "accepteringens": "acceptering",
    "accepterings": "acceptering",
    "accepterna": "accept",
    "accepternas": "accept",
    "accepters": "accept",
    "acceptet": "accept",
    "acceptets": "accept",
    "acceptkrediten": "acceptkredit",
    "acceptkreditens": "acceptkredit",
    "acceptkrediter": "acceptkredit",
    "acceptkrediterna": "acceptkredit",
    "acceptkrediternas": "acceptkredit",
    "acceptkrediters": "acceptkredit",
    "acceptkredits": "acceptkredit",
    "accepts": "accept",
    "accessad": "accessa",
    "accessade": "accessa",
    "accessades": "accessa",
    "accessads": "accessa",
    "accessande": "accessa",
    "accessanden": "accessande",
    "accessandena": "accessande",
    "accessandenas": "accessande",
    "accessandens": "accessande",
    "accessandes": "accessande",
    "accessandet": "accessande",
    "accessandets": "accessande",
    "accessar": "accessa",
    "accessas": "accessa",
    "accessat": "accessa",
    "accessats": "accessa",
    "accessen": "access",
    "accessens": "access",
    "accesser": "access",
    "accesserna": "access",
    "accessernas": "access",
    "accessers": "access",
    "accessionen": "accession",
    "accessionens": "accession",
    "accessioner": "accession",
    "accessionerna": "accession",
    "accessionernas": "accession",
    "accessioners": "accession",
    "accessions": "accession",
    "accessionskatalogen": "accessionskatalog",
    "accessionskatalogens": "accessionskatalog",
    "accessionskataloger": "accessionskatalog",
    "accessionskatalogerna": "accessionskatalog",
    "accessionskatalogernas": "accessionskatalog",
    "accessionskatalogers": "accessionskatalog",
    "accessionskatalogs": "accessionskatalog",
    "accessoaren": "accessoar",
    "accessoarens": "accessoar",
    "accessoarer": "accessoar",
    "accessoarerna": "accessoar",
    "accessoarernas": "accessoar",
    "accessoarers": "accessoar",
    "accessoars": "accessoar",
    "accessoriska": "accessorisk",
    "accessoriskare": "accessorisk",
    "accessoriskares": "accessorisk",
    "accessoriskas": "accessorisk",
    "accessoriskast": "accessorisk",
    "accessoriskaste": "accessorisk",
    "accessoriskastes": "accessorisk",
    "accessoriskasts": "accessorisk",
    "accessoriske": "accessorisk",
    "accessoriskes": "accessorisk",
    "accessorisks": "accessorisk",
    "accessoriskt": "accessorisk",
    "accessoriskts": "accessorisk",
    "accesstiden": "accesstid",
    "accesstidens": "accesstid",
    "accesstider": "accesstid",
    "accesstiderna": "accesstid",
    "accesstidernas": "accesstid",
    "accesstiders": "accesstid",
    "accesstids": "accesstid",
    "accidensen": "accidens",
    "accidensens": "accidens",
    "accidenser": "accidens",
    "accidenserna": "accidens",
    "accidensernas": "accidens",
    "accidensers": "accidens",
    "accidenstrycken": "accidenstryck",
    "accidenstryckens": "accidenstryck",
    "accidenstrycket": "accidenstryck",
    "accidenstryckets": "accidenstryck",
    "accidenstrycks": "accidenstryck",
    "accidentella": "accidentell",
    "accidentellare": "accidentell",
    "accidentellares": "accidentell",
    "accidentellas": "accidentell",
    "accidentellast": "accidentell",
    "accidentellaste": "accidentell",
    "accidentellastes": "accidentell",
    "accidentellasts": "accidentell",
    "accidentelle": "accidentell",
    "accidentelles": "accidentell",
    "accidentells": "accidentell",
    "accidentellt": "accidentell",
    "accidentellts": "accidentell",
    "accisen": "accis",
    "accisens": "accis",
    "acciser": "accis",
    "acciserna": "accis",
    "accisernas": "accis",
    "accisers": "accis",
    "acerolakörsbären": "acerolakörsbär",
    "acerolakörsbärens": "acerolakörsbär",
    "acerolakörsbäret": "acerolakörsbär",
    "acerolakörsbärets": "acerolakörsbär",
    "acerolakörsbärs": "acerolakörsbär",
    "acetaldehyden": "acetaldehyd",
    "acetaldehydens": "acetaldehyd",
    "acetaldehyder": "acetaldehyd",
    "acetaldehyderna": "acetaldehyd",
    "acetaldehydernas": "acetaldehyd",
    "acetaldehyders": "acetaldehyd",
    "acetaldehyds": "acetaldehyd",
    "acetaten": "acetat",
    "acetatens": "acetat",
    "acetater": "acetat",
    "acetaterna": "acetat",
    "acetaternas": "acetat",
    "acetaters": "acetat",
    "acetatet": "acetat",
    "acetatets": "acetat",
    "acetats": "acetat",
    "acetonen": "aceton",
    "acetonens": "aceton",
    "acetonet": "aceton",
    "acetonets": "aceton",
    "acetons": "aceton",
    "acetylenen": "acetylen",
    "acetylenens": "acetylen",
    "acetylenet": "acetylen",
    "acetylenets": "acetylen",
    "acetylenlamp": "acetylenlampa",
    "acetylenlampan": "acetylenlampa",
    "acetylenlampans": "acetylenlampa",
    "acetylenlampas": "acetylenlampa",
    "acetylenlampe": "acetylenlampa",
    "acetylenlampor": "acetylenlampa",
    "acetylenlamporna": "acetylenlampa",
    "acetylenlampornas": "acetylenlampa",
    "acetylenlampors": "acetylenlampa",
    "acetylenlamps": "acetylenlampa",
    "acetylens": "acetylen",
    "acetylsalicylsyran": "acetylsalicylsyra",
    "acetylsalicylsyrans": "acetylsalicylsyra",
    "acetylsalicylsyras": "acetylsalicylsyra",
    "acetylsalicylsyre": "acetylsalicylsyra",
    "acetylsalicylsyror": "acetylsalicylsyra",
    "acetylsalicylsyrorna": "acetylsalicylsyra",
    "acetylsalicylsyrornas": "acetylsalicylsyra",
    "acetylsalicylsyrors": "acetylsalicylsyra",
    "aciditeten": "aciditet",
    "aciditetens": "aciditet",
    "aciditeter": "aciditet",
    "aciditeterna": "aciditet",
    "aciditeternas": "aciditet",
    "aciditeters": "aciditet",
    "aciditets": "aciditet",
    "ackjan": "ackja",
    "ackjans": "ackja",
    "ackjas": "ackja",
    "ackje": "ackja",
    "ackjor": "ackja",
    "ackjorna": "ackja",
    "ackjornas": "ackja",
    "ackjors": "ackja",
    "acklamationen": "acklamation",
    "acklamationens": "acklamation",
    "acklamationer": "acklamation",
    "acklamationerna": "acklamation",
    "acklamationernas": "acklamation",
    "acklamationers": "acklamation",
    "acklamations": "acklamation",
    "acklimatiserad": "acklimatisera",
    "acklimatiserade": "acklimatisera",
    "acklimatiserades": "acklimatisera",
    "acklimatiserads": "acklimatisera",
    "acklimatiserande": "acklimatisera",
    "acklimatiseranden": "acklimatiserande",
    "acklimatiserandena": "acklimatiserande",
    "acklimatiserandenas": "acklimatiserande",
    "acklimatiserandens": "acklimatiserande",
    "acklimatiserandes": "acklimatiserande",
    "acklimatiserandet": "acklimatiserande",
    "acklimatiserandets": "acklimatiserande",
    "acklimatiserar": "acklimatisera",
    "acklimatiseras": "acklimatisera",
    "acklimatiserat": "acklimatisera",
    "acklimatiserats": "acklimatisera",
    "acklimatiserbara": "acklimatiserbar",
    "acklimatiserbarare": "acklimatiserbar",
    "acklimatiserbarares": "acklimatiserbar",
    "acklimatiserbaras": "acklimatiserbar",
    "acklimatiserbarast": "acklimatiserbar",
    "acklimatiserbaraste": "acklimatiserbar",
    "acklimatiserbarastes": "acklimatiserbar",
    "acklimatiserbarasts": "acklimatiserbar",
    "acklimatiserbare": "acklimatiserbar",
    "acklimatiserbares": "acklimatiserbar",
    "acklimatiserbarheten": "acklimatiserbarhet",
    "acklimatiserbarhetens": "acklimatiserbarhet",
    "acklimatiserbarhets": "acklimatiserbarhet",
    "acklimatiserbars": "acklimatiserbar",
    "acklimatiserbart": "acklimatiserbar",
    "acklimatiserbarts": "acklimatiserbar",
    "acklimatiseringar": "acklimatisering",
    "acklimatiseringarna": "acklimatisering",
    "acklimatiseringarnas": "acklimatisering",
    "acklimatiseringars": "acklimatisering",
    "acklimatiseringen": "acklimatisering",
    "acklimatiseringens": "acklimatisering",
    "acklimatiserings": "acklimatisering",
    "ackommodationen": "ackommodation",
    "ackommodationens": "ackommodation",
    "ackommodationer": "ackommodation",
    "ackommodationerna": "ackommodation",
    "ackommodationernas": "ackommodation",
    "ackommodationers": "ackommodation",
    "ackommodations": "ackommodation",
    "ackommodationsväxeln": "ackommodationsväxel",
    "ackommodationsväxelns": "ackommodationsväxel",
    "ackommodationsväxels": "ackommodationsväxel",
    "ackommodationsväxlar": "ackommodationsväxel",
    "ackommodationsväxlarna": "ackommodationsväxel",
    "ackommodationsväxlarnas": "ackommodationsväxel",
    "ackommodationsväxlars": "ackommodationsväxel",
    "ackommoderad": "ackommodera",
    "ackommoderade": "ackommodera",
    "ackommoderades": "ackommodera",
    "ackommoderads": "ackommodera",
    "ackommoderande": "ackommodera",
    "ackommoderanden": "ackommoderande",
    "ackommoderandena": "ackommoderande",
    "ackommoderandenas": "ackommoderande",
    "ackommoderandens": "ackommoderande",
    "ackommoderandes": "ackommoderande",
    "ackommoderandet": "ackommoderande",
    "ackommoderandets": "ackommoderande",
    "ackommoderar": "ackommodera",
    "ackommoderas": "ackommodera",
    "ackommoderat": "ackommodera",
    "ackommoderats": "ackommodera",
    "ackommoderbara": "ackommoderbar",
    "ackommoderbarare": "ackommoderbar",
    "ackommoderbarares": "ackommoderbar",
    "ackommoderbaras": "ackommoderbar",
    "ackommoderbarast": "ackommoderbar",
    "ackommoderbaraste": "ackommoderbar",
    "ackommoderbarastes": "ackommoderbar",
    "ackommoderbarasts": "ackommoderbar",
    "ackommoderbare": "ackommoderbar",
    "ackommoderbares": "ackommoderbar",
    "ackommoderbarheten": "ackommoderbarhet",
    "ackommoderbarhetens": "ackommoderbarhet",
    "ackommoderbarhets": "ackommoderbarhet",
    "ackommoderbars": "ackommoderbar",
    "ackommoderbart": "ackommoderbar",
    "ackommoderbarts": "ackommoderbar",
    "ackommoderingar": "ackommodering",
    "ackommoderingarna": "ackommodering",
    "ackommoderingarnas": "ackommodering",
    "ackommoderingars": "ackommodering",
    "ackommoderingen": "ackommodering",
    "ackommoderingens": "ackommodering",
    "ackommoderings": "ackommodering",
    "ackompanjatören": "ackompanjatör",
    "ackompanjatörens": "ackompanjatör",
    "ackompanjatörer": "ackompanjatör",
    "ackompanjatörerna": "ackompanjatör",
    "ackompanjatörernas": "ackompanjatör",
    "ackompanjatörers": "ackompanjatör",
    "ackompanjatörs": "ackompanjatör",
    "ackompanjemangen": "ackompanjemang",
    "ackompanjemangens": "ackompanjemang",
    "ackompanjemanget": "ackompanjemang",
    "ackompanjemangets": "ackompanjemang",
    "ackompanjemangs": "ackompanjemang",
    "ackompanjerad": "ackompanjera",
    "ackompanjerade": "ackompanjera",
    "ackompanjerades": "ackompanjera",
    "ackompanjerads": "ackompanjera",
    "ackompanjerande": "ackompanjera",
    "ackompanjeranden": "ackompanjerande",
    "ackompanjerandena": "ackompanjerande",
    "ackompanjerandenas": "ackompanjerande",
    "ackompanjerandens": "ackompanjerande",
    "ackompanjerandes": "ackompanjerande",
    "ackompanjerandet": "ackompanjerande",
    "ackompanjerandets": "ackompanjerande",
    "ackompanjerar": "ackompanjera",
    "ackompanjeras": "ackompanjera",
    "ackompanjerat": "ackompanjera",
    "ackompanjerats": "ackompanjera",
    "ackompanjerbara": "ackompanjerbar",
    "ackompanjerbarare": "ackompanjerbar",
    "ackompanjerbarares": "ackompanjerbar",
    "ackompanjerbaras": "ackompanjerbar",
    "ackompanjerbarast": "ackompanjerbar",
    "ackompanjerbaraste": "ackompanjerbar",
    "ackompanjerbarastes": "ackompanjerbar",
    "ackompanjerbarasts": "ackompanjerbar",
    "ackompanjerbare": "ackompanjerbar",
    "ackompanjerbares": "ackompanjerbar",
    "ackompanjerbarheten": "ackompanjerbarhet",
    "ackompanjerbarhetens": "ackompanjerbarhet",
    "ackompanjerbarhets": "ackompanjerbarhet",
    "ackompanjerbars": "ackompanjerbar",
    "ackompanjerbart": "ackompanjerbar",
    "ackompanjerbarts": "ackompanjerbar",
    "ackompanjeringar": "ackompanjering",
    "ackompanjeringarna": "ackompanjering",
    "ackompanjeringarnas": "ackompanjering",
    "ackompanjeringars": "ackompanjering",
    "ackompanjeringen": "ackompanjering",
    "ackompanjeringens": "ackompanjering",
    "ackompanjerings": "ackompanjering",
    "ackorden": "ackord",
    "ackordens": "ackord",
    "ackorderad": "ackordera",
    "ackorderade": "ackordera",
    "ackorderades": "ackordera",
    "ackorderads": "ackordera",
    "ackorderande": "ackordera",
    "ackorderanden": "ackorderande",
    "ackorderandena": "ackorderande",
    "ackorderandenas": "ackorderande",
    "ackorderandens": "ackorderande",
    "ackorderandes": "ackorderande",
    "ackorderandet": "ackorderande",
    "ackorderandets": "ackorderande",
    "ackorderar": "ackordera",
    "ackorderas": "ackordera",
    "ackorderat": "ackordera",
    "ackorderats": "ackordera",
    "ackorderbara": "ackorderbar",
    "ackorderbarare": "ackorderbar",
    "ackorderbarares": "ackorderbar",
    "ackorderbaras": "ackorderbar",
    "ackorderbarast": "ackorderbar",
    "ackorderbaraste": "ackorderbar",
    "ackorderbarastes": "ackorderbar",
    "ackorderbarasts": "ackorderbar",
    "ackorderbare": "ackorderbar",
    "ackorderbares": "ackorderbar",
    "ackorderbarheten": "ackorderbarhet",
    "ackorderbarhetens": "ackorderbarhet",
    "ackorderbarhets": "ackorderbarhet",
    "ackorderbars": "ackorderbar",
    "ackorderbart": "ackorderbar",
    "ackorderbarts": "ackorderbar",
    "ackorderingar": "ackordering",
    "ackorderingarna": "ackordering",
    "ackorderingarnas": "ackordering",
    "ackorderingars": "ackordering",
    "ackorderingen": "ackordering",
    "ackorderingens": "ackordering",
    "ackorderings": "ackordering",
    "ackordet": "ackord",
    "ackordets": "ackord",
    "ackordgreppen": "ackordgrepp",
    "ackordgreppens": "ackordgrepp",
    "ackordgreppet": "ackordgrepp",
    "ackordgreppets": "ackordgrepp",
    "ackordgrepps": "ackordgrepp",
    "ackordier": "ackordion",
    "ackordierna": "ackordion",
    "ackordiernas": "ackordion",
    "ackordiers": "ackordion",
    "ackordiet": "ackordion",
    "ackordiets": "ackordion",
    "ackordionet": "ackordion",
    "ackordionets": "ackordion",
    "ackordions": "ackordion",
    "ackords": "ackord",
    "ackordsarbeten": "ackordsarbete",
    "ackordsarbetena": "ackordsarbete",
    "ackordsarbetenas": "ackordsarbete",
    "ackordsarbetens": "ackordsarbete",
    "ackordsarbetes": "ackordsarbete",
    "ackordsarbetet": "ackordsarbete",
    "ackordsarbetets": "ackordsarbete",
    "ackordsarbets": "ackordsarbete",
    "ackordshetsen": "ackordshets",
    "ackordshetsens": "ackordshets",
    "ackordslönen": "ackordslön",
    "ackordslönens": "ackordslön",
    "ackordslöner": "ackordslön",
    "ackordslönerna": "ackordslön",
    "ackordslönernas": "ackordslön",
    "ackordslöners": "ackordslön",
    "ackordslöns": "ackordslön",
    "ackordssättningar": "ackordssättning",
    "ackordssättningarna": "ackordssättning",
    "ackordssättningarnas": "ackordssättning",
    "ackordssättningars": "ackordssättning",
    "ackordssättningen": "ackordssättning",
    "ackordssättningens": "ackordssättning",
    "ackordssättnings": "ackordssättning",
    "ackordsättningar": "ackordsättning",
    "ackordsättningarna": "ackordsättning",
    "ackordsättningarnas": "ackordsättning",
    "ackordsättningars": "ackordsättning",
    "ackordsättningen": "ackordsättning",
    "ackordsättningens": "ackordsättning",
    "ackordsättnings": "ackordsättning",
    "ackrediterad": "ackreditera",
    "ackrediterade": "ackreditera",
    "ackrediterades": "ackreditera",
    "ackrediterads": "ackreditera",
    "ackrediterande": "ackreditera",
    "ackrediteranden": "ackrediterande",
    "ackrediterandena": "ackrediterande",
    "ackrediterandenas": "ackrediterande",
    "ackrediterandens": "ackrediterande",
    "ackrediterandes": "ackrediterande",
    "ackrediterandet": "ackrediterande",
    "ackrediterandets": "ackrediterande",
    "ackrediterar": "ackreditera",
    "ackrediteras": "ackreditera",
    "ackrediterat": "ackreditera",
    "ackrediterats": "ackreditera",
    "ackrediterbara": "ackrediterbar",
    "ackrediterbarare": "ackrediterbar",
    "ackrediterbarares": "ackrediterbar",
    "ackrediterbaras": "ackrediterbar",
    "ackrediterbarast": "ackrediterbar",
    "ackrediterbaraste": "ackrediterbar",
    "ackrediterbarastes": "ackrediterbar",
    "ackrediterbarasts": "ackrediterbar",
    "ackrediterbare": "ackrediterbar",
    "ackrediterbares": "ackrediterbar",
    "ackrediterbarheten": "ackrediterbarhet",
    "ackrediterbarhetens": "ackrediterbarhet",
    "ackrediterbarhets": "ackrediterbarhet",
    "ackrediterbars": "ackrediterbar",
    "ackrediterbart": "ackrediterbar",
    "ackrediterbarts": "ackrediterbar",
    "ackrediteringar": "ackreditering",
    "ackrediteringarna": "ackreditering",
    "ackrediteringarnas": "ackreditering",
    "ackrediteringars": "ackreditering",
    "ackrediteringen": "ackreditering",
    "ackrediteringens": "ackreditering",
    "ackrediterings": "ackreditering",
    "ackumulationen": "ackumulation",
    "ackumulationens": "ackumulation",
    "ackumulationer": "ackumulation",
    "ackumulationerna": "ackumulation",
    "ackumulationernas": "ackumulation",
    "ackumulationers": "ackumulation",
    "ackumulations": "ackumulation",
    "ackumulatorer": "ackumulator",
    "ackumulatorerna": "ackumulator",
    "ackumulatorernas": "ackumulator",
    "ackumulatorers": "ackumulator",
    "ackumulatorn": "ackumulator",
    "ackumulatorns": "ackumulator",
    "ackumulators": "ackumulator",
    "ackumulerad": "ackumulera",
    "ackumulerade": "ackumulera",
    "ackumulerades": "ackumulera",
    "ackumulerads": "ackumulera",
    "ackumulerande": "ackumulera",
    "ackumuleranden": "ackumulerande",
    "ackumulerandena": "ackumulerande",
    "ackumulerandenas": "ackumulerande",
    "ackumulerandens": "ackumulerande",
    "ackumulerandes": "ackumulerande",
    "ackumulerandet": "ackumulerande",
    "ackumulerandets": "ackumulerande",
    "ackumulerar": "ackumulera",
    "ackumuleras": "ackumulera",
    "ackumulerat": "ackumulera",
    "ackumulerats": "ackumulera",
    "ackumulerbara": "ackumulerbar",
    "ackumulerbarare": "ackumulerbar",
    "ackumulerbarares": "ackumulerbar",
    "ackumulerbaras": "ackumulerbar",
    "ackumulerbarast": "ackumulerbar",
    "ackumulerbaraste": "ackumulerbar",
    "ackumulerbarastes": "ackumulerbar",
    "ackumulerbarasts": "ackumulerbar",
    "ackumulerbare": "ackumulerbar",
    "ackumulerbares": "ackumulerbar",
    "ackumulerbarheten": "ackumulerbarhet",
    "ackumulerbarhetens": "ackumulerbarhet",
    "ackumulerbarhets": "ackumulerbarhet",
    "ackumulerbars": "ackumulerbar",
    "ackumulerbart": "ackumulerbar",
    "ackumulerbarts": "ackumulerbar",
    "ackumuleringar": "ackumulering",
    "ackumuleringarna": "ackumulering",
    "ackumuleringarnas": "ackumulering",
    "ackumuleringars": "ackumulering",
    "ackumuleringen": "ackumulering",
    "ackumuleringens": "ackumulering",
    "ackumulerings": "ackumulering",
    "ackurata": "ackurat",
    "ackuratare": "ackurat",
    "ackuratares": "ackurat",
    "ackuratas": "ackurat",
    "ackuratast": "ackurat",
    "ackurataste": "ackurat",
    "ackuratastes": "ackurat",
    "ackuratasts": "ackurat",
    "ackurate": "ackurat",
    "ackurates": "ackurat",
    "ackuratessen": "ackuratess",
    "ackuratessens": "ackuratess",
    "ackurats": "ackurat",
    "ackusativa": "ackusativ",
    "ackusativare": "ackusativ",
    "ackusativares": "ackusativ",
    "ackusativas": "ackusativ",
    "ackusativast": "ackusativ",
    "ackusativaste": "ackusativ",
    "ackusativastes": "ackusativ",
    "ackusativasts": "ackusativ",
    "ackusative": "ackusativ",
    "ackusativen": "ackusativ",
    "ackusativens": "ackusativ",
    "ackusativer": "ackusativ",
    "ackusativerna": "ackusativ",
    "ackusativernas": "ackusativ",
    "ackusativers": "ackusativ",
    "ackusatives": "ackusativ",
    "ackusativobjekten": "ackusativobjekt",
    "ackusativobjektens": "ackusativobjekt",
    "ackusativobjektet": "ackusativobjekt",
    "ackusativobjektets": "ackusativobjekt",
    "ackusativobjekts": "ackusativobjekt",
    "ackusativs": "ackusativ",
    "ackusativt": "ackusativ",
    "ackusativts": "ackusativ",
    "ackusatoriska": "ackusatorisk",
    "ackusatoriskare": "ackusatorisk",
    "ackusatoriskares": "ackusatorisk",
    "ackusatoriskas": "ackusatorisk",
    "ackusatoriskast": "ackusatorisk",
    "ackusatoriskaste": "ackusatorisk",
    "ackusatoriskastes": "ackusatorisk",
    "ackusatoriskasts": "ackusatorisk",
    "ackusatoriske": "ackusatorisk",
    "ackusatoriskes": "ackusatorisk",
    "ackusatorisks": "ackusatorisk",
    "ackusatoriskt": "ackusatorisk",
    "ackusatoriskts": "ackusatorisk",
    "ackuschören": "ackuschör",
    "ackuschörens": "ackuschör",
    "ackuschörer": "ackuschör",
    "ackuschörerna": "ackuschör",
    "ackuschörernas": "ackuschör",
    "ackuschörers": "ackuschör",
    "ackuschörs": "ackuschör",
    "ackuschörskan": "ackuschörska",
    "ackuschörskans": "ackuschörska",
    "ackuschörskas": "ackuschörska",
    "ackuschörske": "ackuschörska",
    "ackuschörskor": "ackuschörska",
    "ackuschörskorna": "ackuschörska",
    "ackuschörskornas": "ackuschörska",
    "ackuschörskors": "ackuschörska",
    "ackvirerad": "ackvirera",
    "ackvirerade": "ackvirera",
    "ackvirerades": "ackvirera",
    "ackvirerads": "ackvirera",
    "ackvirerande": "ackvirera",
    "ackvireranden": "ackvirerande",
    "ackvirerandena": "ackvirerande",
    "ackvirerandenas": "ackvirerande",
    "ackvirerandens": "ackvirerande",
    "ackvirerandes": "ackvirerande",
    "ackvirerandet": "ackvirerande",
    "ackvirerandets": "ackvirerande",
    "ackvirerar": "ackvirera",
    "ackvireras": "ackvirera",
    "ackvirerat": "ackvirera",
    "ackvirerats": "ackvirera",
    "ackvirerbara": "ackvirerbar",
    "ackvirerbarare": "ackvirerbar",
    "ackvirerbarares": "ackvirerbar",
    "ackvirerbaras": "ackvirerbar",
    "ackvirerbarast": "ackvirerbar",
    "ackvirerbaraste": "ackvirerbar",
    "ackvirerbarastes": "ackvirerbar",
    "ackvirerbarasts": "ackvirerbar",
    "ackvirerbare": "ackvirerbar",
    "ackvirerbares": "ackvirerbar",
    "ackvirerbarheten": "ackvirerbarhet",
    "ackvirerbarhetens": "ackvirerbarhet",
    "ackvirerbarhets": "ackvirerbarhet",
    "ackvirerbars": "ackvirerbar",
    "ackvirerbart": "ackvirerbar",
    "ackvirerbarts": "ackvirerbar",
    "ackvireringar": "ackvirering",
    "ackvireringarna": "ackvirering",
    "ackvireringarnas": "ackvirering",
    "ackvireringars": "ackvirering",
    "ackvireringen": "ackvirering",
    "ackvireringens": "ackvirering",
    "ackvirerings": "ackvirering",
    "ackvisitionen": "ackvisition",
    "ackvisitionens": "ackvisition",
    "ackvisitioner": "ackvisition",
    "ackvisitionerna": "ackvisition",
    "ackvisitionernas": "ackvisition",
    "ackvisitioners": "ackvisition",
    "ackvisitions": "ackvisition",
    "ackvisitören": "ackvisitör",
    "ackvisitörens": "ackvisitör",
    "ackvisitörer": "ackvisitör",
    "ackvisitörerna": "ackvisitör",
    "ackvisitörernas": "ackvisitör",
    "ackvisitörers": "ackvisitör",
    "ackvisitörs": "ackvisitör",
    "acnen": "acne",
    "acnens": "acne",
    "acnes": "acne",
    "actionfilmen": "actionfilm",
    "actionfilmens": "actionfilm",
    "actionfilmer": "actionfilm",
    "actionfilmerna": "actionfilm",
    "actionfilmernas": "actionfilm",
    "actionfilmers": "actionfilm",
    "actionfilms": "actionfilm",
    "actionrull": "actionrulle",
    "actionrullar": "actionrulle",
    "actionrullarna": "actionrulle",
    "actionrullarnas": "actionrulle",
    "actionrullars": "actionrulle",
    "actionrullen": "actionrulle",
    "actionrullens": "actionrulle",
    "actionrulles": "actionrulle",
    "actionrulls": "actionrulle",
    "actions": "action",
    "actionstjärnan": "actionstjärna",
    "actionstjärnans": "actionstjärna",
    "actionstjärnas": "actionstjärna",
    "actionstjärne": "actionstjärna",
    "actionstjärnor": "actionstjärna",
    "actionstjärnorna": "actionstjärna",
    "actionstjärnornas": "actionstjärna",
    "actionstjärnors": "actionstjärna",
    "adagion": "adagio",
    "adagiona": "adagio",
    "adagionas": "adagio",
    "adagions": "adagio",
    "adagios": "adagio",
    "adagiot": "adagio",
    "adagiots": "adagio",
    "adamsdräkten": "adamsdräkt",
    "adamsdräktens": "adamsdräkt",
    "adamsdräkts": "adamsdräkt",
    "adamsäpplen": "adamsäpple",
    "adamsäpplena": "adamsäpple",
    "adamsäpplenas": "adamsäpple",
    "adamsäpplens": "adamsäpple",
    "adamsäpples": "adamsäpple",
    "adamsäpplet": "adamsäpple",
    "adamsäpplets": "adamsäpple",
    "adamsäppls": "adamsäpple",
    "adaptationen": "adaptation",
    "adaptationens": "adaptation",
    "adaptationer": "adaptation",
    "adaptationerna": "adaptation",
    "adaptationernas": "adaptation",
    "adaptationers": "adaptation",
    "adaptations": "adaptation",
    "adapterad": "adaptera",
    "adapterade": "adaptera",
    "adapterades": "adaptera",
    "adapterads": "adaptera",
    "adapterande": "adaptera",
    "adapteranden": "adapterande",
    "adapterandena": "adapterande",
    "adapterandenas": "adapterande",
    "adapterandens": "adapterande",
    "adapterandes": "adapterande",
    "adapterandet": "adapterande",
    "adapterandets": "adapterande",
    "adapterar": "adaptera",
    "adapteras": "adaptera",
    "adapterat": "adaptera",
    "adapterats": "adaptera",
    "adapterbara": "adapterbar",
    "adapterbarare": "adapterbar",
    "adapterbarares": "adapterbar",
    "adapterbaras": "adapterbar",
    "adapterbarast": "adapterbar",
    "adapterbaraste": "adapterbar",
    "adapterbarastes": "adapterbar",
    "adapterbarasts": "adapterbar",
    "adapterbare": "adapterbar",
    "adapterbares": "adapterbar",
    "adapterbarheten": "adapterbarhet",
    "adapterbarhetens": "adapterbarhet",
    "adapterbarhets": "adapterbarhet",
    "adapterbars": "adapterbar",
    "adapterbart": "adapterbar",
    "adapterbarts": "adapterbar",
    "adapteringar": "adaptering",
    "adapteringarna": "adaptering",
    "adapteringarnas": "adaptering",
    "adapteringars": "adaptering",
    "adapteringen": "adaptering",
    "adapteringens": "adaptering",
    "adapterings": "adaptering",
    "adaptern": "adapter",
    "adapterns": "adapter",
    "adapters": "adapter",
    "adaptionen": "adaption",
    "adaptionens": "adaption",
    "adaptioner": "adaption",
    "adaptionerna": "adaption",
    "adaptionernas": "adaption",
    "adaptioners": "adaption",
    "adaptions": "adaption",
    "adaptiva": "adaptiv",
    "adaptivare": "adaptiv",
    "adaptivares": "adaptiv",
    "adaptivas": "adaptiv",
    "adaptivast": "adaptiv",
    "adaptivaste": "adaptiv",
    "adaptivastes": "adaptiv",
    "adaptivasts": "adaptiv",
    "adaptive": "adaptiv",
    "adaptives": "adaptiv",
    "adaptivs": "adaptiv",
    "adaptivt": "adaptiv",
    "adaptivts": "adaptiv",
    "adaptrar": "adapter",
    "adaptrarna": "adapter",
    "adaptrarnas": "adapter",
    "adaptrars": "adapter",
    "addendan": "addenda",
    "addendana": "addenda",
    "addendanas": "addenda",
    "addendans": "addenda",
    "addendas": "addenda",
    "addenden": "addend",
    "addendens": "addend",
    "addender": "addend",
    "addenderna": "addend",
    "addendernas": "addend",
    "addenders": "addend",
    "addends": "addend",
    "adderad": "addera",
    "adderade": "addera",
    "adderades": "addera",
    "adderads": "addera",
    "adderande": "addera",
    "adderanden": "adderande",
    "adderandena": "adderande",
    "adderandenas": "adderande",
    "adderandens": "adderande",
    "adderandes": "adderande",
    "adderandet": "adderande",
    "adderandets": "adderande",
    "adderar": "addera",
    "adderas": "addera",
    "adderat": "addera",
    "adderats": "addera",
    "adderbara": "adderbar",
    "adderbarare": "adderbar",
    "adderbarares": "adderbar",
    "adderbaras": "adderbar",
    "adderbarast": "adderbar",
    "adderbaraste": "adderbar",
    "adderbarastes": "adderbar",
    "adderbarasts": "adderbar",
    "adderbare": "adderbar",
    "adderbares": "adderbar",
    "adderbarheten": "adderbarhet",
    "adderbarhetens": "adderbarhet",
    "adderbarhets": "adderbarhet",
    "adderbars": "adderbar",
    "adderbart": "adderbar",
    "adderbarts": "adderbar",
    "adderingar": "addering",
    "adderingarna": "addering",
    "adderingarnas": "addering",
    "adderingars": "addering",
    "adderingen": "addering",
    "adderingens": "addering",
    "adderings": "addering",
    "addiktionen": "addiktion",
    "addiktionens": "addiktion",
    "addiktioner": "addiktion",
    "addiktionerna": "addiktion",
    "addiktionernas": "addiktion",
    "addiktioners": "addiktion",
    "addiktions": "addiktion",
    "additamenten": "additament",
    "additamentens": "additament",
    "additamentet": "additament",
    "additamentets": "additament",
    "additaments": "additament",
    "additionen": "addition",
    "additionens": "addition",
    "additioner": "addition",
    "additionerna": "addition",
    "additionernas": "addition",
    "additioners": "addition",
    "additions": "addition",
    "additionsteckens": "additionstecken",
    "additionstecknen": "additionstecken",
    "additionstecknens": "additionstecken",
    "additionstecknet": "additionstecken",
    "additionstecknets": "additionstecken",
    "additiva": "additiv",
    "additivare": "additiv",
    "additivares": "additiv",
    "additivas": "additiv",
    "additivast": "additiv",
    "additivaste": "additiv",
    "additivastes": "additiv",
    "additivasts": "additiv",
    "additive": "additiv",
    "additiven": "additiv",
    "additivens": "additiv",
    "additives": "additiv",
    "additivet": "additiv",
    "additivets": "additiv",
    "additivs": "additiv",
    "additivt": "additiv",
    "additivts": "additiv",
    "adduktionen": "adduktion",
    "adduktionens": "adduktion",
    "adduktioner": "adduktion",
    "adduktionerna": "adduktion",
    "adduktionernas": "adduktion",
    "adduktioners": "adduktion",
    "adduktions": "adduktion",
    "adekvata": "adekvat",
    "adekvatare": "adekvat",
    "adekvatares": "adekvat",
    "adekvatas": "adekvat",
    "adekvatast": "adekvat",
    "adekvataste": "adekvat",
    "adekvatastes": "adekvat",
    "adekvatasts": "adekvat",
    "adekvate": "adekvat",
    "adekvates": "adekvat",
    "adekvats": "adekvat",
    "adeln": "adel",
    "adelns": "adel",
    "adels": "adel",
    "adelsbreven": "adelsbrev",
    "adelsbrevens": "adelsbrev",
    "adelsbrevet": "adelsbrev",
    "adelsbrevets": "adelsbrev",
    "adelsbrevs": "adelsbrev",
    "adelsgodsen": "adelsgods",
    "adelsgodsens": "adelsgods",
    "adelsgodset": "adelsgods",
    "adelsgodsets": "adelsgods",
    "adelshemmen": "adelshem",
    "adelshemmens": "adelshem",
    "adelshemmet": "adelshem",
    "adelshemmets": "adelshem",
    "adelshems": "adelshem",
    "adelshögfärden": "adelshögfärd",
    "adelshögfärdens": "adelshögfärd",
    "adelshögfärds": "adelshögfärd",
    "adelskalendern": "adelskalender",
    "adelskalenderns": "adelskalender",
    "adelskalenders": "adelskalender",
    "adelskalendrar": "adelskalender",
    "adelskalendrarna": "adelskalender",
    "adelskalendrarnas": "adelskalender",
    "adelskalendrars": "adelskalender",
    "adelskapet": "adelskap",
    "adelskapets": "adelskap",
    "adelskaps": "adelskap",
    "adelsmannen": "adelsman",
    "adelsmannens": "adelsman",
    "adelsmans": "adelsman",
    "adelsmän": "adelsman",
    "adelsmännen": "adelsman",
    "adelsmännens": "adelsman",
    "adelsmäns": "adelsman",
    "adelsmärken": "adelsmärke",
    "adelsmärkena": "adelsmärke",
    "adelsmärkenas": "adelsmärke",
    "adelsmärkens": "adelsmärke",
    "adelsmärkes": "adelsmärke",
    "adelsmärket": "adelsmärke",
    "adelsmärkets": "adelsmärke",
    "adelsprivilegie": "adelsprivilegium",
    "adelsprivilegier": "adelsprivilegium",
    "adelsprivilegierna": "adelsprivilegium",
    "adelsprivilegiernas": "adelsprivilegium",
    "adelsprivilegiers": "adelsprivilegium",
    "adelsprivilegiet": "adelsprivilegium",
    "adelsprivilegiets": "adelsprivilegium",
    "adelsprivilegiums": "adelsprivilegium",
    "adelsätten": "adelsätt",
    "adelsättens": "adelsätt",
    "adelsätter": "adelsätt",
    "adelsätterna": "adelsätt",
    "adelsätternas": "adelsätt",
    "adelsätters": "adelsätt",
    "adelsätts": "adelsätt",
    "adeniten": "adenit",
    "adenitens": "adenit",
    "adeniter": "adenit",
    "adeniterna": "adenit",
    "adeniternas": "adenit",
    "adeniters": "adenit",
    "adenits": "adenit",
    "adenoida": "adenoid",
    "adenoidare": "adenoid",
    "adenoidares": "adenoid",
    "adenoidas": "adenoid",
    "adenoidast": "adenoid",
    "adenoidaste": "adenoid",
    "adenoidastes": "adenoid",
    "adenoidasts": "adenoid",
    "adenoide": "adenoid",
    "adenoides": "adenoid",
    "adenoids": "adenoid",
    "adepten": "adept",
    "adeptens": "adept",
    "adepter": "adept",
    "adepterna": "adept",
    "adepternas": "adept",
    "adepters": "adept",
    "adepts": "adept",
    "adertonde": "aderton",
    "adertondes": "aderton",
    "adertons": "aderton",
    "adessiven": "adessiv",
    "adessivens": "adessiv",
    "adessiver": "adessiv",
    "adessiverna": "adessiv",
    "adessivernas": "adessiv",
    "adessivers": "adessiv",
    "adessivs": "adessiv",
    "adhd-s": "adhd",
    "adhd-symtomens": "adhd-symtom",
    "adhd-symtomets": "adhd-symtom",
    "adhds": "adhd",
    "adhesionen": "adhesion",
    "adhesionens": "adhesion",
    "adhesioner": "adhesion",
    "adhesionerna": "adhesion",
    "adhesionernas": "adhesion",
    "adhesioners": "adhesion",
    "adhesions": "adhesion",
    "adhesiva": "adhesiv",
    "adhesivare": "adhesiv",
    "adhesivares": "adhesiv",
    "adhesivas": "adhesiv",
    "adhesivast": "adhesiv",
    "adhesivaste": "adhesiv",
    "adhesivastes": "adhesiv",
    "adhesivasts": "adhesiv",
    "adhesive": "adhesiv",
    "adhesives": "adhesiv",
    "adhesivs": "adhesiv",
    "adhesivt": "adhesiv",
    "adhesivts": "adhesiv",
    "adiabatiska": "adiabatisk",
    "adiabatiskare": "adiabatisk",
    "adiabatiskares": "adiabatisk",
    "adiabatiskas": "adiabatisk",
    "adiabatiskast": "adiabatisk",
    "adiabatiskaste": "adiabatisk",
    "adiabatiskastes": "adiabatisk",
    "adiabatiskasts": "adiabatisk",
    "adiabatiske": "adiabatisk",
    "adiabatiskes": "adiabatisk",
    "adiabatisks": "adiabatisk",
    "adiabatiskt": "adiabatisk",
    "adiabatiskts": "adiabatisk",
    "adiaforan": "adiafora",
    "adiaforana": "adiafora",
    "adiaforanas": "adiafora",
    "adiaforans": "adiafora",
    "adiaforas": "adiafora",
    "adiaforistiska": "adiaforistisk",
    "adiaforistiskas": "adiaforistisk",
    "adiaforistiske": "adiaforistisk",
    "adiaforistiskes": "adiaforistisk",
    "adiaforistisks": "adiaforistisk",
    "adiaforistiskt": "adiaforistisk",
    "adiaforistiskts": "adiaforistisk",
    "adjektivattributen": "adjektivattribut",
    "adjektivattributens": "adjektivattribut",
    "adjektivattributet": "adjektivattribut",
    "adjektivattributets": "adjektivattribut",
    "adjektivattributs": "adjektivattribut",
    "adjektiven": "adjektiv",
    "adjektivens": "adjektiv",
    "adjektivet": "adjektiv",
    "adjektivets": "adjektiv",
    "adjektiviska": "adjektivisk",
    "adjektiviskare": "adjektivisk",
    "adjektiviskares": "adjektivisk",
    "adjektiviskas": "adjektivisk",
    "adjektiviskast": "adjektivisk",
    "adjektiviskaste": "adjektivisk",
    "adjektiviskastes": "adjektivisk",
    "adjektiviskasts": "adjektivisk",
    "adjektiviske": "adjektivisk",
    "adjektiviskes": "adjektivisk",
    "adjektivisks": "adjektivisk",
    "adjektiviskt": "adjektivisk",
    "adjektiviskts": "adjektivisk",
    "adjektivistiska": "adjektivistisk",
    "adjektivistiskare": "adjektivistisk",
    "adjektivistiskares": "adjektivistisk",
    "adjektivistiskas": "adjektivistisk",
    "adjektivistiskast": "adjektivistisk",
    "adjektivistiskaste": "adjektivistisk",
    "adjektivistiskastes": "adjektivistisk",
    "adjektivistiskasts": "adjektivistisk",
    "adjektivistiske": "adjektivistisk",
    "adjektivistiskes": "adjektivistisk",
    "adjektivistisks": "adjektivistisk",
    "adjektivistiskt": "adjektivistisk",
    "adjektivistiskts": "adjektivistisk",
    "adjektivs": "adjektiv",
    "adjungerad": "adjungera",
    "adjungerade": "adjungera",
    "adjungerades": "adjungera",
    "adjungerads": "adjungera",
    "adjungerande": "adjungera",
    "adjungeranden": "adjungerande",
    "adjungerandena": "adjungerande",
    "adjungerandenas": "adjungerande",
    "adjungerandens": "adjungerande",
    "adjungerandes": "adjungerande",
    "adjungerandet": "adjungerande",
    "adjungerandets": "adjungerande",
    "adjungerar": "adjungera",
    "adjungeras": "adjungera",
    "adjungerat": "adjungera",
    "adjungerats": "adjungera",
    "adjungerbara": "adjungerbar",
    "adjungerbarare": "adjungerbar",
    "adjungerbarares": "adjungerbar",
    "adjungerbaras": "adjungerbar",
    "adjungerbarast": "adjungerbar",
    "adjungerbaraste": "adjungerbar",
    "adjungerbarastes": "adjungerbar",
    "adjungerbarasts": "adjungerbar",
    "adjungerbare": "adjungerbar",
    "adjungerbares": "adjungerbar",
    "adjungerbarheten": "adjungerbarhet",
    "adjungerbarhetens": "adjungerbarhet",
    "adjungerbarhets": "adjungerbarhet",
    "adjungerbars": "adjungerbar",
    "adjungerbart": "adjungerbar",
    "adjungerbarts": "adjungerbar",
    "adjungeringar": "adjungering",
    "adjungeringarna": "adjungering",
    "adjungeringarnas": "adjungering",
    "adjungeringars": "adjungering",
    "adjungeringen": "adjungering",
    "adjungeringens": "adjungering",
    "adjungerings": "adjungering",
    "adjunkten": "adjunkt",
    "adjunktens": "adjunkt",
    "adjunkter": "adjunkt",
    "adjunkterna": "adjunkt",
    "adjunkternas": "adjunkt",
    "adjunkters": "adjunkt",
    "adjunktionen": "adjunktion",
    "adjunktionens": "adjunktion",
    "adjunktioner": "adjunktion",
    "adjunktionerna": "adjunktion",
    "adjunktionernas": "adjunktion",
    "adjunktioners": "adjunktion",
    "adjunktions": "adjunktion",
    "adjunkts": "adjunkt",
    "adjunkturen": "adjunktur",
    "adjunkturens": "adjunktur",
    "adjunkturer": "adjunktur",
    "adjunkturerna": "adjunktur",
    "adjunkturernas": "adjunktur",
    "adjunkturers": "adjunktur",
    "adjunkturs": "adjunktur",
    "adjutanten": "adjutant",
    "adjutantens": "adjutant",
    "adjutanter": "adjutant",
    "adjutanterna": "adjutant",
    "adjutanternas": "adjutant",
    "adjutanters": "adjutant",
    "adjutants": "adjutant",
    "adjön": "adjö",
    "adjöna": "adjö",
    "adjönas": "adjö",
    "adjöns": "adjö",
    "adjös": "adjö",
    "adjöt": "adjö",
    "adjöts": "adjö",
    "adlad": "adla",
    "adlade": "adla",
    "adlades": "adla",
    "adlads": "adla",
    "adlande": "adla",
    "adlanden": "adlande",
    "adlandena": "adlande",
    "adlandenas": "adlande",
    "adlandens": "adlande",
    "adlandes": "adlande",
    "adlandet": "adlande",
    "adlandets": "adlande",
    "adlar": "adla",
    "adlas": "adla",
    "adlat": "adla",
    "adlats": "adla",
    "adliga": "adlig",
    "adligare": "adlig",
    "adligares": "adlig",
    "adligas": "adlig",
    "adligast": "adlig",
    "adligaste": "adlig",
    "adligastes": "adlig",
    "adligasts": "adlig",
    "adlige": "adlig",
    "adliges": "adlig",
    "adligheten": "adlighet",
    "adlighetens": "adlighet",
    "adlighets": "adlighet",
    "adligs": "adlig",
    "adligt": "adlig",
    "adligts": "adlig",
    "administrationen": "administration",
    "administrationens": "administration",
    "administrationer": "administration",
    "administrationerna": "administration",
    "administrationernas": "administration",
    "administrationers": "administration",
    "administrations": "administration",
    "administrativa": "administrativ",
    "administrativare": "administrativ",
    "administrativares": "administrativ",
    "administrativas": "administrativ",
    "administrativast": "administrativ",
    "administrativaste": "administrativ",
    "administrativastes": "administrativ",
    "administrativasts": "administrativ",
    "administrative": "administrativ",
    "administratives": "administrativ",
    "administrativs": "administrativ",
    "administrativt": "administrativ",
    "administrativts": "administrativ",
    "administratören": "administratör",
    "administratörens": "administratör",
    "administratörer": "administratör",
    "administratörerna": "administratör",
    "administratörernas": "administratör",
    "administratörers": "administratör",
    "administratörs": "administratör",
    "administratörsstatusen": "administratörsstatus",
    "administratörsstatusens": "administratörsstatus",
    "administrerad": "administrera",
    "administrerade": "administrera",
    "administrerades": "administrera",
    "administrerads": "administrera",
    "administrerande": "administrera",
    "administreranden": "administrerande",
    "administrerandena": "administrerande",
    "administrerandenas": "administrerande",
    "administrerandens": "administrerande",
    "administrerandes": "administrerande",
    "administrerandet": "administrerande",
    "administrerandets": "administrerande",
    "administrerar": "administrera",
    "administreras": "administrera",
    "administrerat": "administrera",
    "administrerats": "administrera",
    "administrerbara": "administrerbar",
    "administrerbarare": "administrerbar",
    "administrerbarares": "administrerbar",
    "administrerbaras": "administrerbar",
    "administrerbarast": "administrerbar",
    "administrerbaraste": "administrerbar",
    "administrerbarastes": "administrerbar",
    "administrerbarasts": "administrerbar",
    "administrerbare": "administrerbar",
    "administrerbares": "administrerbar",
    "administrerbarheten": "administrerbarhet",
    "administrerbarhetens": "administrerbarhet",
    "administrerbarhets": "administrerbarhet",
    "administrerbars": "administrerbar",
    "administrerbart": "administrerbar",
    "administrerbarts": "administrerbar",
    "administreringar": "administrering",
    "administreringarna": "administrering",
    "administreringarnas": "administrering",
    "administreringars": "administrering",
    "administreringen": "administrering",
    "administreringens": "administrering",
    "administrerings": "administrering",
    "admonitionen": "admonition",
    "admonitionens": "admonition",
    "admonitioner": "admonition",
    "admonitionerna": "admonition",
    "admonitionernas": "admonition",
    "admonitioners": "admonition",
    "admonitions": "admonition",
    "adolescensen": "adolescens",
    "adolescensens": "adolescens",
    "adonisar": "adonis",
    "adonisarna": "adonis",
    "adonisarnas": "adonis",
    "adonisars": "adonis",
    "adonisen": "adonis",
    "adonisens": "adonis",
    "adonisgestalten": "adonisgestalt",
    "adonisgestaltens": "adonisgestalt",
    "adonisgestalter": "adonisgestalt",
    "adonisgestalterna": "adonisgestalt",
    "adonisgestalternas": "adonisgestalt",
    "adonisgestalters": "adonisgestalt",
    "adonisgestalts": "adonisgestalt",
    "adoptanten": "adoptant",
    "adoptantens": "adoptant",
    "adoptanter": "adoptant",
    "adoptanterna": "adoptant",
    "adoptanternas": "adoptant",
    "adoptanters": "adoptant",
    "adoptants": "adoptant",
    "adopterad": "adoptera",
    "adopterade": "adoptera",
    "adopterades": "adoptera",
    "adopterads": "adoptera",
    "adopterande": "adoptera",
    "adopteranden": "adopterande",
    "adopterandena": "adopterande",
    "adopterandenas": "adopterande",
    "adopterandens": "adopterande",
    "adopterandes": "adopterande",
    "adopterandet": "adopterande",
    "adopterandets": "adopterande",
    "adopterar": "adoptera",
    "adopteras": "adoptera",
    "adopterat": "adoptera",
    "adopterats": "adoptera",
    "adopterbara": "adopterbar",
    "adopterbarare": "adopterbar",
    "adopterbarares": "adopterbar",
    "adopterbaras": "adopterbar",
    "adopterbarast": "adopterbar",
    "adopterbaraste": "adopterbar",
    "adopterbarastes": "adopterbar",
    "adopterbarasts": "adopterbar",
    "adopterbare": "adopterbar",
    "adopterbares": "adopterbar",
    "adopterbarheten": "adopterbarhet",
    "adopterbarhetens": "adopterbarhet",
    "adopterbarhets": "adopterbarhet",
    "adopterbars": "adopterbar",
    "adopterbart": "adopterbar",
    "adopterbarts": "adopterbar",
    "adopteringar": "adoptering",
    "adopteringarna": "adoptering",
    "adopteringarnas": "adoptering",
    "adopteringars": "adoptering",
    "adopteringen": "adoptering",
    "adopteringens": "adoptering",
    "adopterings": "adoptering",
    "adoptionen": "adoption",
    "adoptionens": "adoption",
    "adoptioner": "adoption",
    "adoptionerna": "adoption",
    "adoptionernas": "adoption",
    "adoptioners": "adoption",
    "adoptions": "adoption",
    "adoptiva": "adoptiv",
    "adoptivare": "adoptiv",
    "adoptivares": "adoptiv",
    "adoptivas": "adoptiv",
    "adoptivast": "adoptiv",
    "adoptivaste": "adoptiv",
    "adoptivastes": "adoptiv",
    "adoptivasts": "adoptiv",
    "adoptivbarnen": "adoptivbarn",
    "adoptivbarnens": "adoptivbarn",
    "adoptivbarnet": "adoptivbarn",
    "adoptivbarnets": "adoptivbarn",
    "adoptivbarns": "adoptivbarn",
    "adoptive": "adoptiv",
    "adoptives": "adoptiv",
    "adoptivföräldern": "adoptivförälder",
    "adoptivförälderns": "adoptivförälder",
    "adoptivförälders": "adoptivförälder",
    "adoptivföräldrar": "adoptivförälder",
    "adoptivföräldrarna": "adoptivförälder",
    "adoptivföräldrarnas": "adoptivförälder",
    "adoptivföräldrars": "adoptivförälder",
    "adoptivs": "adoptiv",
    "adoptivt": "adoptiv",
    "adoptivts": "adoptiv",
    "adoratören": "adoratör",
    "adoratörens": "adoratör",
    "adoratörer": "adoratör",
    "adoratörerna": "adoratör",
    "adoratörernas": "adoratör",
    "adoratörers": "adoratör",
    "adoratörs": "adoratör",
    "adrenalinen": "adrenalin",
    "adrenalinens": "adrenalin",
    "adrenaliner": "adrenalin",
    "adrenalinerna": "adrenalin",
    "adrenalinernas": "adrenalin",
    "adrenaliners": "adrenalin",
    "adrenalinet": "adrenalin",
    "adrenalinets": "adrenalin",
    "adrenalinkickar": "adrenalinkick",
    "adrenalinkickarna": "adrenalinkick",
    "adrenalinkickarnas": "adrenalinkick",
    "adrenalinkickars": "adrenalinkick",
    "adrenalinkicken": "adrenalinkick",
    "adrenalinkickens": "adrenalinkick",
    "adrenalinkicks": "adrenalinkick",
    "adrenalins": "adrenalin",
    "adressaten": "adressat",
    "adressatens": "adressat",
    "adressater": "adressat",
    "adressaterna": "adressat",
    "adressaternas": "adressat",
    "adressaters": "adressat",
    "adressats": "adressat",
    "adressbussar": "adressbuss",
    "adressbussarna": "adressbuss",
    "adressbussarnas": "adressbuss",
    "adressbussars": "adressbuss",
    "adressbussen": "adressbuss",
    "adressbussens": "adressbuss",
    "adressen": "adress",
    "adressens": "adress",
    "adresser": "adress",
    "adresserad": "adressera",
    "adresserade": "adressera",
    "adresserades": "adressera",
    "adresserads": "adressera",
    "adresserande": "adressera",
    "adresseranden": "adresserande",
    "adresserandena": "adresserande",
    "adresserandenas": "adresserande",
    "adresserandens": "adresserande",
    "adresserandes": "adresserande",
    "adresserandet": "adresserande",
    "adresserandets": "adresserande",
    "adresserar": "adressera",
    "adresseras": "adressera",
    "adresserat": "adressera",
    "adresserats": "adressera",
    "adresserbara": "adresserbar",
    "adresserbarare": "adresserbar",
    "adresserbarares": "adresserbar",
    "adresserbaras": "adresserbar",
    "adresserbarast": "adresserbar",
    "adresserbaraste": "adresserbar",
    "adresserbarastes": "adresserbar",
    "adresserbarasts": "adresserbar",
    "adresserbare": "adresserbar",
    "adresserbares": "adresserbar",
    "adresserbarheten": "adresserbarhet",
    "adresserbarhetens": "adresserbarhet",
    "adresserbarhets": "adresserbarhet",
    "adresserbars": "adresserbar",
    "adresserbart": "adresserbar",
    "adresserbarts": "adresserbar",
    "adresseringar": "adressering",
    "adresseringarna": "adressering",
    "adresseringarnas": "adressering",
    "adresseringars": "adressering",
    "adresseringen": "adressering",
    "adresseringens": "adressering",
    "adresserings": "adressering",
    "adresserna": "adress",
    "adressernas": "adress",
    "adressers": "adress",
    "adresskorten": "adresskort",
    "adresskortens": "adresskort",
    "adresskortet": "adresskort",
    "adresskortets": "adresskort",
    "adresskorts": "adresskort",
    "adresslappar": "adresslapp",
    "adresslapparna": "adresslapp",
    "adresslapparnas": "adresslapp",
    "adresslappars": "adresslapp",
    "adresslappen": "adresslapp",
    "adresslappens": "adresslapp",
    "adresslapps": "adresslapp",
    "adsorberad": "adsorbera",
    "adsorberade": "adsorbera",
    "adsorberades": "adsorbera",
    "adsorberads": "adsorbera",
    "adsorberande": "adsorbera",
    "adsorberanden": "adsorberande",
    "adsorberandena": "adsorberande",
    "adsorberandenas": "adsorberande",
    "adsorberandens": "adsorberande",
    "adsorberandes": "adsorberande",
    "adsorberandet": "adsorberande",
    "adsorberandets": "adsorberande",
    "adsorberar": "adsorbera",
    "adsorberas": "adsorbera",
    "adsorberat": "adsorbera",
    "adsorberats": "adsorbera",
    "adsorberbara": "adsorberbar",
    "adsorberbarare": "adsorberbar",
    "adsorberbarares": "adsorberbar",
    "adsorberbaras": "adsorberbar",
    "adsorberbarast": "adsorberbar",
    "adsorberbaraste": "adsorberbar",
    "adsorberbarastes": "adsorberbar",
    "adsorberbarasts": "adsorberbar",
    "adsorberbare": "adsorberbar",
    "adsorberbares": "adsorberbar",
    "adsorberbarheten": "adsorberbarhet",
    "adsorberbarhetens": "adsorberbarhet",
    "adsorberbarhets": "adsorberbarhet",
    "adsorberbars": "adsorberbar",
    "adsorberbart": "adsorberbar",
    "adsorberbarts": "adsorberbar",
    "adsorberingar": "adsorbering",
    "adsorberingarna": "adsorbering",
    "adsorberingarnas": "adsorbering",
    "adsorberingars": "adsorbering",
    "adsorberingen": "adsorbering",
    "adsorberingens": "adsorbering",
    "adsorberings": "adsorbering",
    "adsorptionen": "adsorption",
    "adsorptionens": "adsorption",
    "adsorptioner": "adsorption",
    "adsorptionerna": "adsorption",
    "adsorptionernas": "adsorption",
    "adsorptioners": "adsorption",
    "adsorptions": "adsorption",
    "aducerad": "aducera",
    "aducerade": "aducera",
    "aducerades": "aducera",
    "aducerads": "aducera",
    "aducerande": "aducera",
    "aduceranden": "aducerande",
    "aducerandena": "aducerande",
    "aducerandenas": "aducerande",
    "aducerandens": "aducerande",
    "aducerandes": "aducerande",
    "aducerandet": "aducerande",
    "aducerandets": "aducerande",
    "aducerar": "aducera",
    "aduceras": "aducera",
    "aducerat": "aducera",
    "aducerats": "aducera",
    "aducerbara": "aducerbar",
    "aducerbarare": "aducerbar",
    "aducerbarares": "aducerbar",
    "aducerbaras": "aducerbar",
    "aducerbarast": "aducerbar",
    "aducerbaraste": "aducerbar",
    "aducerbarastes": "aducerbar",
    "aducerbarasts": "aducerbar",
    "aducerbare": "aducerbar",
    "aducerbares": "aducerbar",
    "aducerbarheten": "aducerbarhet",
    "aducerbarhetens": "aducerbarhet",
    "aducerbarhets": "aducerbarhet",
    "aducerbars": "aducerbar",
    "aducerbart": "aducerbar",
    "aducerbarts": "aducerbar",
    "aduceringar": "aducering",
    "aduceringarna": "aducering",
    "aduceringarnas": "aducering",
    "aduceringars": "aducering",
    "aduceringen": "aducering",
    "aduceringens": "aducering",
    "aducerings": "aducering",
    "adventet": "advent",
    "adventets": "advent",
    "adventisten": "adventist",
    "adventistens": "adventist",
    "adventister": "adventist",
    "adventisterna": "adventist",
    "adventisternas": "adventist",
    "adventisters": "adventist",
    "adventistiska": "adventistisk",
    "adventistiskas": "adventistisk",
    "adventistiske": "adventistisk",
    "adventistiskes": "adventistisk",
    "adventistisks": "adventistisk",
    "adventistiskt": "adventistisk",
    "adventistiskts": "adventistisk",
    "adventists": "adventist",
    "adventiva": "adventiv",
    "adventivare": "adventiv",
    "adventivares": "adventiv",
    "adventivas": "adventiv",
    "adventivast": "adventiv",
    "adventivaste": "adventiv",
    "adventivastes": "adventiv",
    "adventivasts": "adventiv",
    "adventive": "adventiv",
    "adventives": "adventiv",
    "adventivs": "adventiv",
    "adventivt": "adventiv",
    "adventivts": "adventiv",
    "advents": "advent",
    "adventskalendern": "adventskalender",
    "adventskalenderns": "adventskalender",
    "adventskalenders": "adventskalender",
    "adventskalendrar": "adventskalender",
    "adventskalendrarna": "adventskalender",
    "adventskalendrarnas": "adventskalender",
    "adventskalendrars": "adventskalender",
    "adventsljusstak": "adventsljusstake",
    "adventsljusstakar": "adventsljusstake",
    "adventsljusstakarna": "adventsljusstake",
    "adventsljusstakarnas": "adventsljusstake",
    "adventsljusstakars": "adventsljusstake",
    "adventsljusstaken": "adventsljusstake",
    "adventsljusstakens": "adventsljusstake",
    "adventsljusstakes": "adventsljusstake",
    "adventsljusstaks": "adventsljusstake",
    "adventsmysen": "adventsmys",
    "adventsmysens": "adventsmys",
    "adventsmyset": "adventsmys",
    "adventsmysets": "adventsmys",
    "adventsstak": "adventsstake",
    "adventsstakar": "adventsstake",
    "adventsstakarna": "adventsstake",
    "adventsstakarnas": "adventsstake",
    "adventsstakars": "adventsstake",
    "adventsstaken": "adventsstake",
    "adventsstakens": "adventsstake",
    "adventsstakes": "adventsstake",
    "adventsstaks": "adventsstake",
    "adventsstjärnan": "adventsstjärna",
    "adventsstjärnans": "adventsstjärna",
    "adventsstjärnas": "adventsstjärna",
    "adventsstjärne": "adventsstjärna",
    "adventsstjärnor": "adventsstjärna",
    "adventsstjärnorna": "adventsstjärna",
    "adventsstjärnornas": "adventsstjärna",
    "adventsstjärnors": "adventsstjärna",
    "adverben": "adverb",
    "adverbens": "adverb",
    "adverbet": "adverb",
    "adverbets": "adverb",
    "adverbialen": "adverbial",
    "adverbialens": "adverbial",
    "adverbialet": "adverbial",
    "adverbialets": "adverbial",
    "adverbials": "adverbial",
    "adverbiella": "adverbiell",
    "adverbiellare": "adverbiell",
    "adverbiellares": "adverbiell",
    "adverbiellas": "adverbiell",
    "adverbiellast": "adverbiell",
    "adverbiellaste": "adverbiell",
    "adverbiellastes": "adverbiell",
    "adverbiellasts": "adverbiell",
    "adverbielle": "adverbiell",
    "adverbielles": "adverbiell",
    "adverbiells": "adverbiell",
    "adverbiellt": "adverbiell",
    "adverbiellts": "adverbiell",
    "adverbs": "adverb",
    "adversativa": "adversativ",
    "adversativare": "adversativ",
    "adversativares": "adversativ",
    "adversativas": "adversativ",
    "adversativast": "adversativ",
    "adversativaste": "adversativ",
    "adversativastes": "adversativ",
    "adversativasts": "adversativ",
    "adversative": "adversativ",
    "adversatives": "adversativ",
    "adversativs": "adversativ",
    "adversativt": "adversativ",
    "adversativts": "adversativ",
    "adversen": "advers",
    "adversens": "advers",
    "adverser": "advers",
    "adverserna": "advers",
    "adversernas": "advers",
    "adversers": "advers",
    "advocerad": "advocera",
    "advocerade": "advocera",
    "advocerades": "advocera",
    "advocerads": "advocera",
    "advocerande": "advocera",
    "advoceranden": "advocerande",
    "advocerandena": "advocerande",
    "advocerandenas": "advocerande",
    "advocerandens": "advocerande",
    "advocerandes": "advocerande",
    "advocerandet": "advocerande",
    "advocerandets": "advocerande",
    "advocerar": "advocera",
    "advoceras": "advocera",
    "advocerat": "advocera",
    "advocerats": "advocera",
    "advocerbara": "advocerbar",
    "advocerbarare": "advocerbar",
    "advocerbarares": "advocerbar",
    "advocerbaras": "advocerbar",
    "advocerbarast": "advocerbar",
    "advocerbaraste": "advocerbar",
    "advocerbarastes": "advocerbar",
    "advocerbarasts": "advocerbar",
    "advocerbare": "advocerbar",
    "advocerbares": "advocerbar",
    "advocerbarheten": "advocerbarhet",
    "advocerbarhetens": "advocerbarhet",
    "advocerbarhets": "advocerbarhet",
    "advocerbars": "advocerbar",
    "advocerbart": "advocerbar",
    "advocerbarts": "advocerbar",
    "advoceringar": "advocering",
    "advoceringarna": "advocering",
    "advoceringarnas": "advocering",
    "advoceringars": "advocering",
    "advoceringen": "advocering",
    "advoceringens": "advocering",
    "advocerings": "advocering",
    "advokaten": "advokat",
    "advokatens": "advokat",
    "advokater": "advokat",
    "advokaterna": "advokat",
    "advokaternas": "advokat",
    "advokaters": "advokat",
    "advokatfiskalen": "advokatfiskal",
    "advokatfiskalens": "advokatfiskal",
    "advokatfiskaler": "advokatfiskal",
    "advokatfiskalerna": "advokatfiskal",
    "advokatfiskalernas": "advokatfiskal",
    "advokatfiskalers": "advokatfiskal",
    "advokatfiskals": "advokatfiskal",
    "advokathjälpen": "advokathjälp",
    "advokathjälpens": "advokathjälp",
    "advokathjälps": "advokathjälp",
    "advokatoriska": "advokatorisk",
    "advokatoriskare": "advokatorisk",
    "advokatoriskares": "advokatorisk",
    "advokatoriskas": "advokatorisk",
    "advokatoriskast": "advokatorisk",
    "advokatoriskaste": "advokatorisk",
    "advokatoriskastes": "advokatorisk",
    "advokatoriskasts": "advokatorisk",
    "advokatoriske": "advokatorisk",
    "advokatoriskes": "advokatorisk",
    "advokatorisks": "advokatorisk",
    "advokatoriskt": "advokatorisk",
    "advokatoriskts": "advokatorisk",
    "advokats": "advokat",
    "advokatyren": "advokatyr",
    "advokatyrens": "advokatyr",
    "advokatyrer": "advokatyr",
    "advokatyrerna": "advokatyr",
    "advokatyrernas": "advokatyr",
    "advokatyrers": "advokatyr",
    "advokatyrs": "advokatyr",
    "adxukibön": "adxukiböna",
    "adxukibönan": "adxukiböna",
    "adxukibönans": "adxukiböna",
    "adxukibönas": "adxukiböna",
    "adxukiböne": "adxukiböna",
    "adxukibönor": "adxukiböna",
    "adxukibönorna": "adxukiböna",
    "adxukibönornas": "adxukiböna",
    "adxukibönors": "adxukiböna",
    "adxukiböns": "adxukiböna",
    "aeroba": "aerob",
    "aerobare": "aerob",
    "aerobares": "aerob",
    "aerobas": "aerob",
    "aerobast": "aerob",
    "aerobaste": "aerob",
    "aerobastes": "aerob",
    "aerobasts": "aerob",
    "aerobe": "aerob",
    "aerobes": "aerob",
    "aerobiska": "aerobisk",
    "aerobiskare": "aerobisk",
    "aerobiskares": "aerobisk",
    "aerobiskas": "aerobisk",
    "aerobiskast": "aerobisk",
    "aerobiskaste": "aerobisk",
    "aerobiskastes": "aerobisk",
    "aerobiskasts": "aerobisk",
    "aerobiske": "aerobisk",
    "aerobiskes": "aerobisk",
    "aerobisks": "aerobisk",
    "aerobiskt": "aerobisk",
    "aerobiskts": "aerobisk",
    "aerobs": "aerob",
    "aerobt": "aerob",
    "aerobts": "aerob",
    "aerodromen": "aerodrom",
    "aerodromens": "aerodrom",
    "aerodromer": "aerodrom",
    "aerodromerna": "aerodrom",
    "aerodromernas": "aerodrom",
    "aerodromers": "aerodrom",
    "aerodroms": "aerodrom",
    "aerodynamiken": "aerodynamik",
    "aerodynamikens": "aerodynamik",
    "aerodynamiks": "aerodynamik",
    "aerodynamiska": "aerodynamisk",
    "aerodynamiskare": "aerodynamisk",
    "aerodynamiskares": "aerodynamisk",
    "aerodynamiskas": "aerodynamisk",
    "aerodynamiskast": "aerodynamisk",
    "aerodynamiskaste": "aerodynamisk",
    "aerodynamiskastes": "aerodynamisk",
    "aerodynamiskasts": "aerodynamisk",
    "aerodynamiske": "aerodynamisk",
    "aerodynamiskes": "aerodynamisk",
    "aerodynamisks": "aerodynamisk",
    "aerodynamiskt": "aerodynamisk",
    "aerodynamiskts": "aerodynamisk",
    "aerogrammen": "aerogram",
    "aerogrammens": "aerogram",
    "aerogrammet": "aerogram",
    "aerogrammets": "aerogram",
    "aerograms": "aerogram",
    "aerologien": "aerologi",
    "aerologiens": "aerologi",
    "aerologin": "aerologi",
    "aerologins": "aerologi",
    "aerologis": "aerologi",
    "aeronauten": "aeronaut",
    "aeronautens": "aeronaut",
    "aeronauter": "aeronaut",
    "aeronauterna": "aeronaut",
    "aeronauternas": "aeronaut",
    "aeronauters": "aeronaut",
    "aeronautiken": "aeronautik",
    "aeronautikens": "aeronautik",
    "aeronautiks": "aeronautik",
    "aeronauts": "aeronaut",
    "aeroplanen": "aeroplan",
    "aeroplanens": "aeroplan",
    "aeroplanet": "aeroplan",
    "aeroplanets": "aeroplan",
    "aeroplans": "aeroplan",
    "aerosolen": "aerosol",
    "aerosolens": "aerosol",
    "aerosoler": "aerosol",
    "aerosolerna": "aerosol",
    "aerosolernas": "aerosol",
    "aerosolers": "aerosol",
    "aerosols": "aerosol",
    "afasien": "afasi",
    "afasiens": "afasi",
    "afasier": "afasi",
    "afasierna": "afasi",
    "afasiernas": "afasi",
    "afasiers": "afasi",
    "afasin": "afasi",
    "afasins": "afasi",
    "afasis": "afasi",
    "afasiska": "afasisk",
    "afasiskare": "afasisk",
    "afasiskares": "afasisk",
    "afasiskas": "afasisk",
    "afasiskast": "afasisk",
    "afasiskaste": "afasisk",
    "afasiskastes": "afasisk",
    "afasiskasts": "afasisk",
    "afasiske": "afasisk",
    "afasiskes": "afasisk",
    "afasisks": "afasisk",
    "afasiskt": "afasisk",
    "afasiskts": "afasisk",
    "afatikern": "afatiker",
    "afatikerna": "afatiker",
    "afatikernas": "afatiker",
    "afatikerns": "afatiker",
    "afatikers": "afatiker",
    "afatiska": "afatisk",
    "afatiskare": "afatisk",
    "afatiskares": "afatisk",
    "afatiskas": "afatisk",
    "afatiskast": "afatisk",
    "afatiskaste": "afatisk",
    "afatiskastes": "afatisk",
    "afatiskasts": "afatisk",
    "afatiske": "afatisk",
    "afatiskes": "afatisk",
    "afatisks": "afatisk",
    "afatiskt": "afatisk",
    "afatiskts": "afatisk",
    "afelie": "afelium",
    "afelier": "afelium",
    "afelierna": "afelium",
    "afeliernas": "afelium",
    "afeliers": "afelium",
    "afeliet": "afelium",
    "afeliets": "afelium",
    "afeliums": "afelium",
    "affektationen": "affektation",
    "affektationens": "affektation",
    "affektationer": "affektation",
    "affektationerna": "affektation",
    "affektationernas": "affektation",
    "affektationers": "affektation",
    "affektations": "affektation",
    "affekten": "affekt",
    "affektens": "affekt",
    "affekter": "affekt",
    "affekterade": "affekterad",
    "affekterades": "affekterad",
    "affekterads": "affekterad",
    "affekterat": "affekterad",
    "affekterats": "affekterad",
    "affekterna": "affekt",
    "affekternas": "affekt",
    "affekters": "affekt",
    "affektionen": "affektion",
    "affektionens": "affektion",
    "affektioner": "affektion",
    "affektionerna": "affektion",
    "affektionernas": "affektion",
    "affektioners": "affektion",
    "affektions": "affektion",
    "affektionsvärden": "affektionsvärde",
    "affektionsvärdena": "affektionsvärde",
    "affektionsvärdenas": "affektionsvärde",
    "affektionsvärdens": "affektionsvärde",
    "affektionsvärdes": "affektionsvärde",
    "affektionsvärdet": "affektionsvärde",
    "affektionsvärdets": "affektionsvärde",
    "affektiva": "affektiv",
    "affektivare": "affektiv",
    "affektivares": "affektiv",
    "affektivas": "affektiv",
    "affektivast": "affektiv",
    "affektivaste": "affektiv",
    "affektivastes": "affektiv",
    "affektivasts": "affektiv",
    "affektive": "affektiv",
    "affektives": "affektiv",
    "affektivs": "affektiv",
    "affektivt": "affektiv",
    "affektivts": "affektiv",
    "affekts": "affekt",
    "afficierad": "afficiera",
    "afficierade": "afficiera",
    "afficierades": "afficiera",
    "afficierads": "afficiera",
    "afficierande": "afficiera",
    "afficieranden": "afficierande",
    "afficierandena": "afficierande",
    "afficierandenas": "afficierande",
    "afficierandens": "afficierande",
    "afficierandes": "afficierande",
    "afficierandet": "afficierande",
    "afficierandets": "afficierande",
    "afficierar": "afficiera",
    "afficieras": "afficiera",
    "afficierat": "afficiera",
    "afficierats": "afficiera",
    "afficierbara": "afficierbar",
    "afficierbarare": "afficierbar",
    "afficierbarares": "afficierbar",
    "afficierbaras": "afficierbar",
    "afficierbarast": "afficierbar",
    "afficierbaraste": "afficierbar",
    "afficierbarastes": "afficierbar",
    "afficierbarasts": "afficierbar",
    "afficierbare": "afficierbar",
    "afficierbares": "afficierbar",
    "afficierbarheten": "afficierbarhet",
    "afficierbarhetens": "afficierbarhet",
    "afficierbarhets": "afficierbarhet",
    "afficierbars": "afficierbar",
    "afficierbart": "afficierbar",
    "afficierbarts": "afficierbar",
    "afficieringar": "afficiering",
    "afficieringarna": "afficiering",
    "afficieringarnas": "afficiering",
    "afficieringars": "afficiering",
    "afficieringen": "afficiering",
    "afficieringens": "afficiering",
    "afficierings": "afficiering",
    "affidaviten": "affidavit",
    "affidavitens": "affidavit",
    "affidavitet": "affidavit",
    "affidavitets": "affidavit",
    "affidavits": "affidavit",
    "affidavten": "affidavit",
    "affidavtens": "affidavit",
    "affidavtet": "affidavit",
    "affidavtets": "affidavit",
    "affina": "affin",
    "affinagen": "affinage",
    "affinagens": "affinage",
    "affinages": "affinage",
    "affinaget": "affinage",
    "affinagets": "affinage",
    "affinare": "affin",
    "affinares": "affin",
    "affinas": "affin",
    "affinast": "affin",
    "affinaste": "affin",
    "affinastes": "affin",
    "affinasts": "affin",
    "affine": "affin",
    "affinerad": "affinera",
    "affinerade": "affinera",
    "affinerades": "affinera",
    "affinerads": "affinera",
    "affinerande": "affinera",
    "affineranden": "affinerande",
    "affinerandena": "affinerande",
    "affinerandenas": "affinerande",
    "affinerandens": "affinerande",
    "affinerandes": "affinerande",
    "affinerandet": "affinerande",
    "affinerandets": "affinerande",
    "affinerar": "affinera",
    "affineras": "affinera",
    "affinerat": "affinera",
    "affinerats": "affinera",
    "affinerbara": "affinerbar",
    "affinerbarare": "affinerbar",
    "affinerbarares": "affinerbar",
    "affinerbaras": "affinerbar",
    "affinerbarast": "affinerbar",
    "affinerbaraste": "affinerbar",
    "affinerbarastes": "affinerbar",
    "affinerbarasts": "affinerbar",
    "affinerbare": "affinerbar",
    "affinerbares": "affinerbar",
    "affinerbarheten": "affinerbarhet",
    "affinerbarhetens": "affinerbarhet",
    "affinerbarhets": "affinerbarhet",
    "affinerbars": "affinerbar",
    "affinerbart": "affinerbar",
    "affinerbarts": "affinerbar",
    "affineringar": "affinering",
    "affineringarna": "affinering",
    "affineringarnas": "affinering",
    "affineringars": "affinering",
    "affineringen": "affinering",
    "affineringens": "affinering",
    "affinerings": "affinering",
    "affines": "affin",
    "affiniteten": "affinitet",
    "affinitetens": "affinitet",
    "affiniteter": "affinitet",
    "affiniteterna": "affinitet",
    "affiniteternas": "affinitet",
    "affiniteters": "affinitet",
    "affinitets": "affinitet",
    "affins": "affin",
    "affint": "affin",
    "affints": "affin",
    "affirmativa": "affirmativ",
    "affirmativare": "affirmativ",
    "affirmativares": "affirmativ",
    "affirmativas": "affirmativ",
    "affirmativast": "affirmativ",
    "affirmativaste": "affirmativ",
    "affirmativastes": "affirmativ",
    "affirmativasts": "affirmativ",
    "affirmative": "affirmativ",
    "affirmatives": "affirmativ",
    "affirmativs": "affirmativ",
    "affirmativt": "affirmativ",
    "affirmativts": "affirmativ",
    "affischen": "affisch",
    "affischens": "affisch",
    "affischer": "affisch",
    "affischerad": "affischera",
    "affischerade": "affischera",
    "affischerades": "affischera",
    "affischerads": "affischera",
    "affischerande": "affischera",
    "affischeranden": "affischerande",
    "affischerandena": "affischerande",
    "affischerandenas": "affischerande",
    "affischerandens": "affischerande",
    "affischerandes": "affischerande",
    "affischerandet": "affischerande",
    "affischerandets": "affischerande",
    "affischerar": "affischera",
    "affischeras": "affischera",
    "affischerat": "affischera",
    "affischerats": "affischera",
    "affischerbara": "affischerbar",
    "affischerbarare": "affischerbar",
    "affischerbarares": "affischerbar",
    "affischerbaras": "affischerbar",
    "affischerbarast": "affischerbar",
    "affischerbaraste": "affischerbar",
    "affischerbarastes": "affischerbar",
    "affischerbarasts": "affischerbar",
    "affischerbare": "affischerbar",
    "affischerbares": "affischerbar",
    "affischerbarheten": "affischerbarhet",
    "affischerbarhetens": "affischerbarhet",
    "affischerbarhets": "affischerbarhet",
    "affischerbars": "affischerbar",
    "affischerbart": "affischerbar",
    "affischerbarts": "affischerbar",
    "affischeringar": "affischering",
    "affischeringarna": "affischering",
    "affischeringarnas": "affischering",
    "affischeringars": "affischering",
    "affischeringen": "affischering",
    "affischeringens": "affischering",
    "affischerings": "affischering",
    "affischerna": "affisch",
    "affischernas": "affisch",
    "affischers": "affisch",
    "affischkampanjen": "affischkampanj",
    "affischkampanjens": "affischkampanj",
    "affischkampanjer": "affischkampanj",
    "affischkampanjerna": "affischkampanj",
    "affischkampanjernas": "affischkampanj",
    "affischkampanjers": "affischkampanj",
    "affischkampanjs": "affischkampanj",
    "affischmässiga": "affischmässig",
    "affischmässigare": "affischmässig",
    "affischmässigares": "affischmässig",
    "affischmässigas": "affischmässig",
    "affischmässigast": "affischmässig",
    "affischmässigaste": "affischmässig",
    "affischmässigastes": "affischmässig",
    "affischmässigasts": "affischmässig",
    "affischmässige": "affischmässig",
    "affischmässiges": "affischmässig",
    "affischmässigs": "affischmässig",
    "affischmässigt": "affischmässig",
    "affischmässigts": "affischmässig",
    "affischnamnen": "affischnamn",
    "affischnamnens": "affischnamn",
    "affischnamnet": "affischnamn",
    "affischnamnets": "affischnamn",
    "affischnamns": "affischnamn",
    "affischpelar": "affischpelare",
    "affischpelaren": "affischpelare",
    "affischpelarens": "affischpelare",
    "affischpelares": "affischpelare",
    "affischpelarna": "affischpelare",
    "affischpelarnas": "affischpelare",
    "affischs": "affisch",
    "affischören": "affischör",
    "affischörens": "affischör",
    "affischörer": "affischör",
    "affischörerna": "affischör",
    "affischörernas": "affischör",
    "affischörers": "affischör",
    "affischörs": "affischör",
    "affixen": "affix",
    "affixens": "affix",
    "affixet": "affix",
    "affixets": "affix",
    "affrikatan": "affrikata",
    "affrikatans": "affrikata",
    "affrikatas": "affrikata",
    "affrikator": "affrikata",
    "affrikatorna": "affrikata",
    "affrikatornas": "affrikata",
    "affrikators": "affrikata",
    "affären": "affär",
    "affärens": "affär",
    "affärer": "affär",
    "affärerna": "affär",
    "affärernas": "affär",
    "affärers": "affär",
    "affärs": "affär",
    "affärsavtalen": "affärsavtal",
    "affärsavtalens": "affärsavtal",
    "affärsavtalet": "affärsavtal",
    "affärsavtalets": "affärsavtal",
    "affärsavtals": "affärsavtal",
    "affärsbanken": "affärsbank",
    "affärsbankens": "affärsbank",
    "affärsbanker": "affärsbank",
    "affärsbankerna": "affärsbank",
    "affärsbankernas": "affärsbank",
    "affärsbankers": "affärsbank",
    "affärsbanks": "affärsbank",
    "affärsbegåvningar": "affärsbegåvning",
    "affärsbegåvningarna": "affärsbegåvning",
    "affärsbegåvningarnas": "affärsbegåvning",
    "affärsbegåvningars": "affärsbegåvning",
    "affärsbegåvningen": "affärsbegåvning",
    "affärsbegåvningens": "affärsbegåvning",
    "affärsbegåvnings": "affärsbegåvning",
    "affärsbiträden": "affärsbiträde",
    "affärsbiträdena": "affärsbiträde",
    "affärsbiträdenas": "affärsbiträde",
    "affärsbiträdens": "affärsbiträde",
    "affärsbiträdes": "affärsbiträde",
    "affärsbiträdet": "affärsbiträde",
    "affärsbiträdets": "affärsbiträde",
    "affärsbreven": "affärsbrev",
    "affärsbrevens": "affärsbrev",
    "affärsbrevet": "affärsbrev",
    "affärsbrevets": "affärsbrev",
    "affärsbrevs": "affärsbrev",
    "affärscentra": "affärscentrum",
    "affärscentrana": "affärscentrum",
    "affärscentranas": "affärscentrum",
    "affärscentras": "affärscentrum",
    "affärscentrer": "affärscentrum",
    "affärscentrerna": "affärscentrum",
    "affärscentrernas": "affärscentrum",
    "affärscentrers": "affärscentrum",
    "affärscentret": "affärscentrum",
    "affärscentrets": "affärscentrum",
    "affärscentrumen": "affärscentrum",
    "affärscentrumens": "affärscentrum",
    "affärscentrumet": "affärscentrum",
    "affärscentrumets": "affärscentrum",
    "affärscentrums": "affärscentrum",
    "affärsdistrikten": "affärsdistrikt",
    "affärsdistriktens": "affärsdistrikt",
    "affärsdistriktet": "affärsdistrikt",
    "affärsdistriktets": "affärsdistrikt",
    "affärsdistrikts": "affärsdistrikt",
    "affärsfastigheten": "affärsfastighet",
    "affärsfastighetens": "affärsfastighet",
    "affärsfastigheter": "affärsfastighet",
    "affärsfastigheterna": "affärsfastighet",
    "affärsfastigheternas": "affärsfastighet",
    "affärsfastigheters": "affärsfastighet",
    "affärsfastighets": "affärsfastighet",
    "affärsförslagen": "affärsförslag",
    "affärsförslagens": "affärsförslag",
    "affärsförslaget": "affärsförslag",
    "affärsförslagets": "affärsförslag",
    "affärsförslags": "affärsförslag",
    "affärsgat": "affärsgata",
    "affärsgatan": "affärsgata",
    "affärsgatans": "affärsgata",
    "affärsgatas": "affärsgata",
    "affärsgate": "affärsgata",
    "affärsgator": "affärsgata",
    "affärsgatorna": "affärsgata",
    "affärsgatornas": "affärsgata",
    "affärsgators": "affärsgata",
    "affärsgats": "affärsgata",
    "affärsidéen": "affärsidé",
    "affärsidéens": "affärsidé",
    "affärsidéer": "affärsidé",
    "affärsidéerna": "affärsidé",
    "affärsidéernas": "affärsidé",
    "affärsidéers": "affärsidé",
    "affärsidén": "affärsidé",
    "affärsidéns": "affärsidé",
    "affärsidés": "affärsidé",
    "affärskedjan": "affärskedja",
    "affärskedjans": "affärskedja",
    "affärskedjas": "affärskedja",
    "affärskedje": "affärskedja",
    "affärskedjor": "affärskedja",
    "affärskedjorna": "affärskedja",
    "affärskedjornas": "affärskedja",
    "affärskedjors": "affärskedja",
    "affärskvarteren": "affärskvarter",
    "affärskvarterens": "affärskvarter",
    "affärskvarteret": "affärskvarter",
    "affärskvarterets": "affärskvarter",
    "affärskvarters": "affärskvarter",
    "affärsliven": "affärsliv",
    "affärslivens": "affärsliv",
    "affärslivet": "affärsliv",
    "affärslivets": "affärsliv",
    "affärslivs": "affärsliv",
    "affärsmannamässiga": "affärsmannamässig",
    "affärsmannamässigare": "affärsmannamässig",
    "affärsmannamässigares": "affärsmannamässig",
    "affärsmannamässigas": "affärsmannamässig",
    "affärsmannamässigast": "affärsmannamässig",
    "affärsmannamässigaste": "affärsmannamässig",
    "affärsmannamässigastes": "affärsmannamässig",
    "affärsmannamässigasts": "affärsmannamässig",
    "affärsmannamässige": "affärsmannamässig",
    "affärsmannamässiges": "affärsmannamässig",
    "affärsmannamässigs": "affärsmannamässig",
    "affärsmannamässigt": "affärsmannamässig",
    "affärsmannamässigts": "affärsmannamässig",
    "affärsmannen": "affärsman",
    "affärsmannens": "affärsman",
    "affärsmans": "affärsman",
    "affärsmän": "affärsman",
    "affärsmännen": "affärsman",
    "affärsmännens": "affärsman",
    "affärsmäns": "affärsman",
    "affärsmässiga": "affärsmässig",
    "affärsmässigare": "affärsmässig",
    "affärsmässigares": "affärsmässig",
    "affärsmässigas": "affärsmässig",
    "affärsmässigast": "affärsmässig",
    "affärsmässigaste": "affärsmässig",
    "affärsmässigastes": "affärsmässig",
    "affärsmässigasts": "affärsmässig",
    "affärsmässige": "affärsmässig",
    "affärsmässiges": "affärsmässig",
    "affärsmässigheten": "affärsmässighet",
    "affärsmässighetens": "affärsmässighet",
    "affärsmässighets": "affärsmässighet",
    "affärsmässigs": "affärsmässig",
    "affärsmässigt": "affärsmässig",
    "affärsmässigts": "affärsmässig",
    "affärsstråken": "affärsstråk",
    "affärsstråkens": "affärsstråk",
    "affärsstråket": "affärsstråk",
    "affärsstråkets": "affärsstråk",
    "affärsstråks": "affärsstråk",
    "affärstiden": "affärstid",
    "affärstidens": "affärstid",
    "affärstider": "affärstid",
    "affärstiderna": "affärstid",
    "affärstidernas": "affärstid",
    "affärstiders": "affärstid",
    "affärstids": "affärstid",
    "affärsuppgörelsen": "affärsuppgörelse",
    "affärsuppgörelsens": "affärsuppgörelse",
    "affärsuppgörelser": "affärsuppgörelse",
    "affärsuppgörelserna": "affärsuppgörelse",
    "affärsuppgörelsernas": "affärsuppgörelse",
    "affärsuppgörelsers": "affärsuppgörelse",
    "affärsuppgörelses": "affärsuppgörelse",
    "affärsverken": "affärsverk",
    "affärsverkens": "affärsverk",
    "affärsverket": "affärsverk",
    "affärsverkets": "affärsverk",
    "affärsverks": "affärsverk",
    "afghanen": "afghan",
    "afghanens": "afghan",
    "afghaner": "afghan",
    "afghanerna": "afghan",
    "afghanernas": "afghan",
    "afghaners": "afghan",
    "afghans": "afghan",
    "afghansk": "afghanska",
    "afghanska": "afghansk",
    "afghanskan": "afghanska",
    "afghanskans": "afghanska",
    "afghanskare": "afghansk",
    "afghanskares": "afghansk",
    "afghanskas": "afghanska",
    "afghanskast": "afghansk",
    "afghanskaste": "afghansk",
    "afghanskastes": "afghansk",
    "afghanskasts": "afghansk",
    "afghanske": "afghanska",
    "afghanskes": "afghansk",
    "afghanskor": "afghanska",
    "afghanskorna": "afghanska",
    "afghanskornas": "afghanska",
    "afghanskors": "afghanska",
    "afghansks": "afghansk",
    "afghanskt": "afghansk",
    "afghanskts": "afghansk",
    "aforismen": "aforism",
    "aforismens": "aforism",
    "aforismer": "aforism",
    "aforismerna": "aforism",
    "aforismernas": "aforism",
    "aforismers": "aforism",
    "aforisms": "aforism",
    "aforistikern": "aforistiker",
    "aforistikerna": "aforistiker",
    "aforistikernas": "aforistiker",
    "aforistikerns": "aforistiker",
    "aforistikers": "aforistiker",
    "aforistiska": "aforistisk",
    "aforistiskare": "aforistisk",
    "aforistiskares": "aforistisk",
    "aforistiskas": "aforistisk",
    "aforistiskast": "aforistisk",
    "aforistiskaste": "aforistisk",
    "aforistiskastes": "aforistisk",
    "aforistiskasts": "aforistisk",
    "aforistiske": "aforistisk",
    "aforistiskes": "aforistisk",
    "aforistisks": "aforistisk",
    "aforistiskt": "aforistisk",
    "aforistiskts": "aforistisk",
    "afrikanen": "afrikan",
    "afrikanens": "afrikan",
    "afrikaner": "afrikan",
    "afrikanerna": "afrikan",
    "afrikanernas": "afrikan",
    "afrikaners": "afrikan",
    "afrikaniserad": "afrikanisera",
    "afrikaniserade": "afrikanisera",
    "afrikaniserades": "afrikanisera",
    "afrikaniserads": "afrikanisera",
    "afrikaniserande": "afrikanisera",
    "afrikaniseranden": "afrikaniserande",
    "afrikaniserandena": "afrikaniserande",
    "afrikaniserandenas": "afrikaniserande",
    "afrikaniserandens": "afrikaniserande",
    "afrikaniserandes": "afrikaniserande",
    "afrikaniserandet": "afrikaniserande",
    "afrikaniserandets": "afrikaniserande",
    "afrikaniserar": "afrikanisera",
    "afrikaniseras": "afrikanisera",
    "afrikaniserat": "afrikanisera",
    "afrikaniserats": "afrikanisera",
    "afrikaniserbara": "afrikaniserbar",
    "afrikaniserbarare": "afrikaniserbar",
    "afrikaniserbarares": "afrikaniserbar",
    "afrikaniserbaras": "afrikaniserbar",
    "afrikaniserbarast": "afrikaniserbar",
    "afrikaniserbaraste": "afrikaniserbar",
    "afrikaniserbarastes": "afrikaniserbar",
    "afrikaniserbarasts": "afrikaniserbar",
    "afrikaniserbare": "afrikaniserbar",
    "afrikaniserbares": "afrikaniserbar",
    "afrikaniserbarheten": "afrikaniserbarhet",
    "afrikaniserbarhetens": "afrikaniserbarhet",
    "afrikaniserbarhets": "afrikaniserbarhet",
    "afrikaniserbars": "afrikaniserbar",
    "afrikaniserbart": "afrikaniserbar",
    "afrikaniserbarts": "afrikaniserbar",
    "afrikaniseringar": "afrikanisering",
    "afrikaniseringarna": "afrikanisering",
    "afrikaniseringarnas": "afrikanisering",
    "afrikaniseringars": "afrikanisering",
    "afrikaniseringen": "afrikanisering",
    "afrikaniseringens": "afrikanisering",
    "afrikaniserings": "afrikanisering",
    "afrikans": "afrikan",
    "afrikanska": "afrikansk",
    "afrikanskan": "afrikanska",
    "afrikanskans": "afrikanska",
    "afrikanskare": "afrikansk",
    "afrikanskares": "afrikansk",
    "afrikanskas": "afrikanska",
    "afrikanskast": "afrikansk",
    "afrikanskaste": "afrikansk",
    "afrikanskastes": "afrikansk",
    "afrikanskasts": "afrikansk",
    "afrikanske": "afrikanska",
    "afrikanskes": "afrikansk",
    "afrikanskor": "afrikanska",
    "afrikanskorna": "afrikanska",
    "afrikanskornas": "afrikanska",
    "afrikanskors": "afrikanska",
    "afrikansks": "afrikansk",
    "afrikanskt": "afrikansk",
    "afrikanskts": "afrikansk",
    "afro-asiatiska": "afro-asiatisk",
    "afro-asiatiskare": "afro-asiatisk",
    "afro-asiatiskares": "afro-asiatisk",
    "afro-asiatiskas": "afro-asiatisk",
    "afro-asiatiskast": "afro-asiatisk",
    "afro-asiatiskaste": "afro-asiatisk",
    "afro-asiatiskastes": "afro-asiatisk",
    "afro-asiatiskasts": "afro-asiatisk",
    "afro-asiatiske": "afro-asiatisk",
    "afro-asiatiskes": "afro-asiatisk",
    "afro-asiatisks": "afro-asiatisk",
    "afro-asiatiskt": "afro-asiatisk",
    "afro-asiatiskts": "afro-asiatisk",
    "afroamerikanen": "afroamerikan",
    "afroamerikanens": "afroamerikan",
    "afroamerikaner": "afroamerikan",
    "afroamerikanerna": "afroamerikan",
    "afroamerikanernas": "afroamerikan",
    "afroamerikaners": "afroamerikan",
    "afroamerikans": "afroamerikan",
    "afroasiatiska": "afroasiatisk",
    "afroasiatiskare": "afroasiatisk",
    "afroasiatiskares": "afroasiatisk",
    "afroasiatiskas": "afroasiatisk",
    "afroasiatiskast": "afroasiatisk",
    "afroasiatiskaste": "afroasiatisk",
    "afroasiatiskastes": "afroasiatisk",
    "afroasiatiskasts": "afroasiatisk",
    "afroasiatiske": "afroasiatisk",
    "afroasiatiskes": "afroasiatisk",
    "afroasiatisks": "afroasiatisk",
    "afroasiatiskt": "afroasiatisk",
    "afroasiatiskts": "afroasiatisk",
    "afrodisiaka": "afrodisiakum",
    "afrodisiakana": "afrodisiakum",
    "afrodisiakanas": "afrodisiakum",
    "afrodisiakas": "afrodisiakum",
    "afrodisiakumet": "afrodisiakum",
    "afrodisiakumets": "afrodisiakum",
    "afrodisiakums": "afrodisiakum",
    "afrofrisyren": "afrofrisyr",
    "afrofrisyrens": "afrofrisyr",
    "afrofrisyrer": "afrofrisyr",
    "afrofrisyrerna": "afrofrisyr",
    "afrofrisyrernas": "afrofrisyr",
    "afrofrisyrers": "afrofrisyr",
    "afrofrisyrs": "afrofrisyr",
    "afs": "af",
    "aftnar": "afton",
    "aftnarna": "afton",
    "aftnarnas": "afton",
    "aftnars": "afton",
    "aftonbönen": "aftonbön",
    "aftonbönens": "aftonbön",
    "aftonböner": "aftonbön",
    "aftonbönerna": "aftonbön",
    "aftonbönernas": "aftonbön",
    "aftonböners": "aftonbön",
    "aftonböns": "aftonbön",
    "aftondräkten": "aftondräkt",
    "aftondräktens": "aftondräkt",
    "aftondräkter": "aftondräkt",
    "aftondräkterna": "aftondräkt",
    "aftondräkternas": "aftondräkt",
    "aftondräkters": "aftondräkt",
    "aftondräkts": "aftondräkt",
    "aftonen": "afton",
    "aftonens": "afton",
    "aftongudstjänsten": "aftongudstjänst",
    "aftongudstjänstens": "aftongudstjänst",
    "aftongudstjänster": "aftongudstjänst",
    "aftongudstjänsterna": "aftongudstjänst",
    "aftongudstjänsternas": "aftongudstjänst",
    "aftongudstjänsters": "aftongudstjänst",
    "aftongudstjänsts": "aftongudstjänst",
    "aftonhandsk": "aftonhandske",
    "aftonhandskar": "aftonhandske",
    "aftonhandskarna": "aftonhandske",
    "aftonhandskarnas": "aftonhandske",
    "aftonhandskars": "aftonhandske",
    "aftonhandsken": "aftonhandske",
    "aftonhandskens": "aftonhandske",
    "aftonhandskes": "aftonhandske",
    "aftonklänningar": "aftonklänning",
    "aftonklänningarna": "aftonklänning",
    "aftonklänningarnas": "aftonklänning",
    "aftonklänningars": "aftonklänning",
    "aftonklänningen": "aftonklänning",
    "aftonklänningens": "aftonklänning",
    "aftonklännings": "aftonklänning",
    "aftonmålen": "aftonmål",
    "aftonmålens": "aftonmål",
    "aftonmålet": "aftonmål",
    "aftonmålets": "aftonmål",
    "aftonmåls": "aftonmål",
    "aftonrodnaden": "aftonrodnad",
    "aftonrodnadens": "aftonrodnad",
    "aftonrodnader": "aftonrodnad",
    "aftonrodnaderna": "aftonrodnad",
    "aftonrodnadernas": "aftonrodnad",
    "aftonrodnaders": "aftonrodnad",
    "aftonrodnads": "aftonrodnad",
    "aftons": "afton",
    "aftonskolan": "aftonskola",
    "aftonskolans": "aftonskola",
    "aftonskolas": "aftonskola",
    "aftonskole": "aftonskola",
    "aftonskolor": "aftonskola",
    "aftonskolorna": "aftonskola",
    "aftonskolornas": "aftonskola",
    "aftonskolors": "aftonskola",
    "aftonstjärnan": "aftonstjärna",
    "aftonstjärnans": "aftonstjärna",
    "aftonstjärnas": "aftonstjärna",
    "aftonstjärne": "aftonstjärna",
    "aftonstjärnor": "aftonstjärna",
    "aftonstjärnorna": "aftonstjärna",
    "aftonstjärnornas": "aftonstjärna",
    "aftonstjärnors": "aftonstjärna",
    "aftonsången": "aftonsång",
    "aftonsångens": "aftonsång",
    "aftonsånger": "aftonsång",
    "aftonsångerna": "aftonsång",
    "aftonsångernas": "aftonsång",
    "aftonsångers": "aftonsång",
    "aftonsångs": "aftonsång",
    "aftontoaletten": "aftontoalett",
    "aftontoalettens": "aftontoalett",
    "aftontoaletter": "aftontoalett",
    "aftontoaletterna": "aftontoalett",
    "aftontoaletternas": "aftontoalett",
    "aftontoaletters": "aftontoalett",
    "aftontoaletts": "aftontoalett",
    "aftonvarden": "aftonvard",
    "aftonvardens": "aftonvard",
    "aftonvarder": "aftonvard",
    "aftonvarderna": "aftonvard",
    "aftonvardernas": "aftonvard",
    "aftonvarders": "aftonvard",
    "aftonvards": "aftonvard",
    "ag": "aga",
    "agad": "aga",
    "agade": "aga",
    "agades": "aga",
    "agads": "aga",
    "agan": "aga",
    "agande": "aga",
    "aganden": "agande",
    "agandena": "agande",
    "agandenas": "agande",
    "agandens": "agande",
    "agandes": "agande",
    "agandet": "agande",
    "agandets": "agande",
    "agans": "aga",
    "agar": "aga",
    "agas": "aga",
    "agat": "aga",
    "agaten": "agat",
    "agatens": "agat",
    "agater": "agat",
    "agaterna": "agat",
    "agaternas": "agat",
    "agaters": "agat",
    "agatglaset": "agatglas",
    "agatglasets": "agatglas",
    "agats": "agat",
    "agaven": "agave",
    "agavens": "agave",
    "agaver": "agave",
    "agaverna": "agave",
    "agavernas": "agave",
    "agavers": "agave",
    "agaves": "agave",
    "agen": "ag",
    "agendan": "agenda",
    "agendans": "agenda",
    "agendas": "agenda",
    "agendor": "agenda",
    "agendorna": "agenda",
    "agendornas": "agenda",
    "agendors": "agenda",
    "agens": "ag",
    "agensen": "agens",
    "agensens": "agens",
    "agenser": "agens",
    "agenserna": "agens",
    "agensernas": "agens",
    "agensers": "agens",
    "agenten": "agent",
    "agentens": "agent",
    "agenter": "agent",
    "agenterna": "agent",
    "agenternas": "agent",
    "agenters": "agent",
    "agentfilmen": "agentfilm",
    "agentfilmens": "agentfilm",
    "agentfilmer": "agentfilm",
    "agentfilmerna": "agentfilm",
    "agentfilmernas": "agentfilm",
    "agentfilmers": "agentfilm",
    "agentfilms": "agentfilm",
    "agentierna": "agentier",
    "agentiernas": "agentier",
    "agentiers": "agentier",
    "agents": "agent",
    "agenturen": "agentur",
    "agenturens": "agentur",
    "agenturer": "agentur",
    "agenturerna": "agentur",
    "agenturernas": "agentur",
    "agenturers": "agentur",
    "agenturs": "agentur",
    "agerad": "agera",
    "agerade": "agera",
    "agerades": "agera",
    "agerads": "agera",
    "agerande": "agera",
    "ageranden": "agerande",
    "agerandena": "agerande",
    "agerandenas": "agerande",
    "agerandens": "agerande",
    "agerandes": "agerande",
    "agerandet": "agerande",
    "agerandets": "agerande",
    "agerar": "agera",
    "ageras": "agera",
    "agerat": "agera",
    "agerats": "agera",
    "agerbara": "agerbar",
    "agerbarare": "agerbar",
    "agerbarares": "agerbar",
    "agerbaras": "agerbar",
    "agerbarast": "agerbar",
    "agerbaraste": "agerbar",
    "agerbarastes": "agerbar",
    "agerbarasts": "agerbar",
    "agerbare": "agerbar",
    "agerbares": "agerbar",
    "agerbarheten": "agerbarhet",
    "agerbarhetens": "agerbarhet",
    "agerbarhets": "agerbarhet",
    "agerbars": "agerbar",
    "agerbart": "agerbar",
    "agerbarts": "agerbar",
    "agget": "agg",
    "aggets": "agg",
    "agglomeraten": "agglomerat",
    "agglomeratens": "agglomerat",
    "agglomeratet": "agglomerat",
    "agglomeratets": "agglomerat",
    "agglomerationen": "agglomeration",
    "agglomerationens": "agglomeration",
    "agglomerationer": "agglomeration",
    "agglomerationerna": "agglomeration",
    "agglomerationernas": "agglomeration",
    "agglomerationers": "agglomeration",
    "agglomerations": "agglomeration",
    "agglomerats": "agglomerat",
    "agglomererad": "agglomerera",
    "agglomererade": "agglomerera",
    "agglomererades": "agglomerera",
    "agglomererads": "agglomerera",
    "agglomererande": "agglomerera",
    "agglomereranden": "agglomererande",
    "agglomererandena": "agglomererande",
    "agglomererandenas": "agglomererande",
    "agglomererandens": "agglomererande",
    "agglomererandes": "agglomererande",
    "agglomererandet": "agglomererande",
    "agglomererandets": "agglomererande",
    "agglomererar": "agglomerera",
    "agglomereras": "agglomerera",
    "agglomererat": "agglomerera",
    "agglomererats": "agglomerera",
    "agglomererbara": "agglomererbar",
    "agglomererbarare": "agglomererbar",
    "agglomererbarares": "agglomererbar",
    "agglomererbaras": "agglomererbar",
    "agglomererbarast": "agglomererbar",
    "agglomererbaraste": "agglomererbar",
    "agglomererbarastes": "agglomererbar",
    "agglomererbarasts": "agglomererbar",
    "agglomererbare": "agglomererbar",
    "agglomererbares": "agglomererbar",
    "agglomererbarheten": "agglomererbarhet",
    "agglomererbarhetens": "agglomererbarhet",
    "agglomererbarhets": "agglomererbarhet",
    "agglomererbars": "agglomererbar",
    "agglomererbart": "agglomererbar",
    "agglomererbarts": "agglomererbar",
    "agglomereringar": "agglomerering",
    "agglomereringarna": "agglomerering",
    "agglomereringarnas": "agglomerering",
    "agglomereringars": "agglomerering",
    "agglomereringen": "agglomerering",
    "agglomereringens": "agglomerering",
    "agglomererings": "agglomerering",
    "agglutinationen": "agglutination",
    "agglutinationens": "agglutination",
    "agglutinationer": "agglutination",
    "agglutinationerna": "agglutination",
    "agglutinationernas": "agglutination",
    "agglutinationers": "agglutination",
    "agglutinations": "agglutination",
    "agglutinerad": "agglutinera",
    "agglutinerade": "agglutinera",
    "agglutinerades": "agglutinera",
    "agglutinerads": "agglutinera",
    "agglutinerande": "agglutinera",
    "agglutineranden": "agglutinerande",
    "agglutinerandena": "agglutinerande",
    "agglutinerandenas": "agglutinerande",
    "agglutinerandens": "agglutinerande",
    "agglutinerandes": "agglutinerande",
    "agglutinerandet": "agglutinerande",
    "agglutinerandets": "agglutinerande",
    "agglutinerar": "agglutinera",
    "agglutineras": "agglutinera",
    "agglutinerat": "agglutinera",
    "agglutinerats": "agglutinera",
    "agglutinerbara": "agglutinerbar",
    "agglutinerbarare": "agglutinerbar",
    "agglutinerbarares": "agglutinerbar",
    "agglutinerbaras": "agglutinerbar",
    "agglutinerbarast": "agglutinerbar",
    "agglutinerbaraste": "agglutinerbar",
    "agglutinerbarastes": "agglutinerbar",
    "agglutinerbarasts": "agglutinerbar",
    "agglutinerbare": "agglutinerbar",
    "agglutinerbares": "agglutinerbar",
    "agglutinerbarheten": "agglutinerbarhet",
    "agglutinerbarhetens": "agglutinerbarhet",
    "agglutinerbarhets": "agglutinerbarhet",
    "agglutinerbars": "agglutinerbar",
    "agglutinerbart": "agglutinerbar",
    "agglutinerbarts": "agglutinerbar",
    "agglutineringar": "agglutinering",
    "agglutineringarna": "agglutinering",
    "agglutineringarnas": "agglutinering",
    "agglutineringars": "agglutinering",
    "agglutineringen": "agglutinering",
    "agglutineringens": "agglutinering",
    "agglutinerings": "agglutinering",
    "aggraverad": "aggravera",
    "aggraverade": "aggravera",
    "aggraverades": "aggravera",
    "aggraverads": "aggravera",
    "aggraverande": "aggravera",
    "aggraverandes": "aggravera",
    "aggraverar": "aggravera",
    "aggraveras": "aggravera",
    "aggraverat": "aggravera",
    "aggraverats": "aggravera",
    "aggregaten": "aggregat",
    "aggregatens": "aggregat",
    "aggregatet": "aggregat",
    "aggregatets": "aggregat",
    "aggregationen": "aggregation",
    "aggregationens": "aggregation",
    "aggregationer": "aggregation",
    "aggregationerna": "aggregation",
    "aggregationernas": "aggregation",
    "aggregationers": "aggregation",
    "aggregations": "aggregation",
    "aggregationsformen": "aggregationsform",
    "aggregationsformens": "aggregationsform",
    "aggregationsformer": "aggregationsform",
    "aggregationsformerna": "aggregationsform",
    "aggregationsformernas": "aggregationsform",
    "aggregationsformers": "aggregationsform",
    "aggregationsforms": "aggregationsform",
    "aggregationstillstånden": "aggregationstillstånd",
    "aggregationstillståndens": "aggregationstillstånd",
    "aggregationstillståndet": "aggregationstillstånd",
    "aggregationstillståndets": "aggregationstillstånd",
    "aggregationstillstånds": "aggregationstillstånd",
    "aggregats": "aggregat",
    "aggressionen": "aggression",
    "aggressionens": "aggression",
    "aggressioner": "aggression",
    "aggressionerna": "aggression",
    "aggressionernas": "aggression",
    "aggressioners": "aggression",
    "aggressions": "aggression",
    "aggressionshämningar": "aggressionshämning",
    "aggressionshämningarna": "aggressionshämning",
    "aggressionshämningarnas": "aggressionshämning",
    "aggressionshämningars": "aggressionshämning",
    "aggressionshämningen": "aggressionshämning",
    "aggressionshämningens": "aggressionshämning",
    "aggressionshämnings": "aggressionshämning",
    "aggressiva": "aggressiv",
    "aggressivare": "aggressiv",
    "aggressivares": "aggressiv",
    "aggressivas": "aggressiv",
    "aggressivast": "aggressiv",
    "aggressivaste": "aggressiv",
    "aggressivastes": "aggressiv",
    "aggressivasts": "aggressiv",
    "aggressive": "aggressiv",
    "aggressives": "aggressiv",
    "aggressiviteten": "aggressivitet",
    "aggressivitetens": "aggressivitet",
    "aggressiviteter": "aggressivitet",
    "aggressiviteterna": "aggressivitet",
    "aggressiviteternas": "aggressivitet",
    "aggressiviteters": "aggressivitet",
    "aggressivitets": "aggressivitet",
    "aggressivs": "aggressiv",
    "aggressivt": "aggressiv",
    "aggressivts": "aggressiv",
    "aggs": "agg",
    "agios": "agio",
    "agiot": "agio",
    "agiots": "agio",
    "agitationen": "agitation",
    "agitationens": "agitation",
    "agitationer": "agitation",
    "agitationerna": "agitation",
    "agitationernas": "agitation",
    "agitationers": "agitation",
    "agitations": "agitation",
    "agitationsvis": "agitationsvisa",
    "agitationsvisan": "agitationsvisa",
    "agitationsvisans": "agitationsvisa",
    "agitationsvisas": "agitationsvisa",
    "agitationsvise": "agitationsvisa",
    "agitationsvisor": "agitationsvisa",
    "agitationsvisorna": "agitationsvisa",
    "agitationsvisornas": "agitationsvisa",
    "agitationsvisors": "agitationsvisa",
    "agitatorer": "agitator",
    "agitatorerna": "agitator",
    "agitatorernas": "agitator",
    "agitatorers": "agitator",
    "agitatoriska": "agitatorisk",
    "agitatoriskare": "agitatorisk",
    "agitatoriskares": "agitatorisk",
    "agitatoriskas": "agitatorisk",
    "agitatoriskast": "agitatorisk",
    "agitatoriskaste": "agitatorisk",
    "agitatoriskastes": "agitatorisk",
    "agitatoriskasts": "agitatorisk",
    "agitatoriske": "agitatorisk",
    "agitatoriskes": "agitatorisk",
    "agitatorisks": "agitatorisk",
    "agitatoriskt": "agitatorisk",
    "agitatoriskts": "agitatorisk",
    "agitatorn": "agitator",
    "agitatorns": "agitator",
    "agitators": "agitator",
    "agiterad": "agitera",
    "agiterade": "agitera",
    "agiterades": "agitera",
    "agiterads": "agitera",
    "agiterande": "agitera",
    "agiteranden": "agiterande",
    "agiterandena": "agiterande",
    "agiterandenas": "agiterande",
    "agiterandens": "agiterande",
    "agiterandes": "agiterande",
    "agiterandet": "agiterande",
    "agiterandets": "agiterande",
    "agiterar": "agitera",
    "agiteras": "agitera",
    "agiterat": "agitera",
    "agiterats": "agitera",
    "agiterbara": "agiterbar",
    "agiterbarare": "agiterbar",
    "agiterbarares": "agiterbar",
    "agiterbaras": "agiterbar",
    "agiterbarast": "agiterbar",
    "agiterbaraste": "agiterbar",
    "agiterbarastes": "agiterbar",
    "agiterbarasts": "agiterbar",
    "agiterbare": "agiterbar",
    "agiterbares": "agiterbar",
    "agiterbarheten": "agiterbarhet",
    "agiterbarhetens": "agiterbarhet",
    "agiterbarhets": "agiterbarhet",
    "agiterbars": "agiterbar",
    "agiterbart": "agiterbar",
    "agiterbarts": "agiterbar",
    "agiteringar": "agitering",
    "agiteringarna": "agitering",
    "agiteringarnas": "agitering",
    "agiteringars": "agitering",
    "agiteringen": "agitering",
    "agiteringens": "agitering",
    "agiterings": "agitering",
    "agn": "agnar",
    "agnad": "agna",
    "agnade": "agna",
    "agnades": "agna",
    "agnads": "agna",
    "agnande": "agna",
    "agnanden": "agnande",
    "agnandena": "agnande",
    "agnandenas": "agnande",
    "agnandens": "agnande",
    "agnandes": "agnande",
    "agnandet": "agnande",
    "agnandets": "agnande",
    "agnar": "agna",
    "agnarna": "agnar",
    "agnarnas": "agnar",
    "agnars": "agnar",
    "agnas": "agna",
    "agnat": "agna",
    "agnaten": "agnat",
    "agnatens": "agnat",
    "agnater": "agnat",
    "agnaterna": "agnat",
    "agnaternas": "agnat",
    "agnaters": "agnat",
    "agnatiska": "agnatisk",
    "agnatiskare": "agnatisk",
    "agnatiskares": "agnatisk",
    "agnatiskas": "agnatisk",
    "agnatiskast": "agnatisk",
    "agnatiskaste": "agnatisk",
    "agnatiskastes": "agnatisk",
    "agnatiskasts": "agnatisk",
    "agnatiske": "agnatisk",
    "agnatiskes": "agnatisk",
    "agnatisks": "agnatisk",
    "agnatiskt": "agnatisk",
    "agnatiskts": "agnatisk",
    "agnats": "agnat",
    "agnblommiga": "agnblommig",
    "agnblommigare": "agnblommig",
    "agnblommigares": "agnblommig",
    "agnblommigas": "agnblommig",
    "agnblommigast": "agnblommig",
    "agnblommigaste": "agnblommig",
    "agnblommigastes": "agnblommig",
    "agnblommigasts": "agnblommig",
    "agnblommige": "agnblommig",
    "agnblommiges": "agnblommig",
    "agnblommigs": "agnblommig",
    "agnblommigt": "agnblommig",
    "agnblommigts": "agnblommig",
    "agnborsten": "agnborst",
    "agnborstens": "agnborst",
    "agnborstet": "agnborst",
    "agnborstets": "agnborst",
    "agnborsts": "agnborst",
    "agnen": "agn",
    "agnens": "agn",
    "agnet": "agn",
    "agnets": "agn",
    "agnosien": "agnosi",
    "agnosiens": "agnosi",
    "agnosier": "agnosi",
    "agnosierna": "agnosi",
    "agnosiernas": "agnosi",
    "agnosiers": "agnosi",
    "agnosin": "agnosi",
    "agnosins": "agnosi",
    "agnosis": "agnosi",
    "agnosticismen": "agnosticism",
    "agnosticismens": "agnosticism",
    "agnosticismer": "agnosticism",
    "agnosticismerna": "agnosticism",
    "agnosticismernas": "agnosticism",
    "agnosticismers": "agnosticism",
    "agnosticisms": "agnosticism",
    "agnostikern": "agnostiker",
    "agnostikerna": "agnostiker",
    "agnostikernas": "agnostiker",
    "agnostikerns": "agnostiker",
    "agnostikers": "agnostiker",
    "agnostiska": "agnostisk",
    "agnostiskare": "agnostisk",
    "agnostiskares": "agnostisk",
    "agnostiskas": "agnostisk",
    "agnostiskast": "agnostisk",
    "agnostiskaste": "agnostisk",
    "agnostiskastes": "agnostisk",
    "agnostiskasts": "agnostisk",
    "agnostiske": "agnostisk",
    "agnostiskes": "agnostisk",
    "agnostisks": "agnostisk",
    "agnostiskt": "agnostisk",
    "agnostiskts": "agnostisk",
    "agnrosten": "agnrost",
    "agnrostens": "agnrost",
    "agnrosts": "agnrost",
    "agns": "agnar",
    "agonien": "agoni",
    "agoniens": "agoni",
    "agonier": "agoni",
    "agonierna": "agoni",
    "agoniernas": "agoni",
    "agoniers": "agoni",
    "agonin": "agoni",
    "agonins": "agoni",
    "agonis": "agoni",
    "agonistiska": "agonistisk",
    "agonistiskas": "agonistisk",
    "agonistiske": "agonistisk",
    "agonistiskes": "agonistisk",
    "agonistisks": "agonistisk",
    "agonistiskt": "agonistisk",
    "agonistiskts": "agonistisk",
    "agor": "aga",
    "agorafobien": "agorafobi",
    "agorafobiens": "agorafobi",
    "agorafobin": "agorafobi",
    "agorafobins": "agorafobi",
    "agorafobis": "agorafobi",
    "agorna": "aga",
    "agornas": "aga",
    "agors": "aga",
    "agraffen": "agraff",
    "agraffens": "agraff",
    "agraffer": "agraff",
    "agrafferna": "agraff",
    "agraffernas": "agraff",
    "agraffers": "agraff",
    "agraffs": "agraff",
    "agrara": "agrar",
    "agrarare": "agrar",
    "agrarares": "agrar",
    "agraras": "agrar",
    "agrarast": "agrar",
    "agraraste": "agrar",
    "agrarastes": "agrar",
    "agrarasts": "agrar",
    "agrare": "agrar",
    "agraren": "agrar",
    "agrarens": "agrar",
    "agrarer": "agrar",
    "agrarerna": "agrar",
    "agrarernas": "agrar",
    "agrarers": "agrar",
    "agrares": "agrar",
    "agrarkommunistiska": "agrarkommunistisk",
    "agrarkommunistiskas": "agrarkommunistisk",
    "agrarkommunistiske": "agrarkommunistisk",
    "agrarkommunistiskes": "agrarkommunistisk",
    "agrarkommunistisks": "agrarkommunistisk",
    "agrarkommunistiskt": "agrarkommunistisk",
    "agrarkommunistiskts": "agrarkommunistisk",
    "agrars": "agrar",
    "agrart": "agrar",
    "agrarts": "agrar",
    "agreabels": "agreabel",
    "agreabelt": "agreabel",
    "agreabelts": "agreabel",
    "agreabla": "agreabel",
    "agreablare": "agreabel",
    "agreablares": "agreabel",
    "agreablas": "agreabel",
    "agreablast": "agreabel",
    "agreablaste": "agreabel",
    "agreablastes": "agreabel",
    "agreablasts": "agreabel",
    "agreable": "agreabel",
    "agreables": "agreabel",
    "agremang": "agremanger",
    "agremangen": "agremang",
    "agremangens": "agremang",
    "agremangerna": "agremanger",
    "agremangernas": "agremanger",
    "agremangers": "agremanger",
    "agremanget": "agremang",
    "agremangets": "agremang",
    "agremangs": "agremanger",
    "agrikulturella": "agrikulturell",
    "agrikulturellare": "agrikulturell",
    "agrikulturellares": "agrikulturell",
    "agrikulturellas": "agrikulturell",
    "agrikulturellast": "agrikulturell",
    "agrikulturellaste": "agrikulturell",
    "agrikulturellastes": "agrikulturell",
    "agrikulturellasts": "agrikulturell",
    "agrikulturelle": "agrikulturell",
    "agrikulturelles": "agrikulturell",
    "agrikulturells": "agrikulturell",
    "agrikulturellt": "agrikulturell",
    "agrikulturellts": "agrikulturell",
    "agrikulturen": "agrikultur",
    "agrikulturens": "agrikultur",
    "agrikulturs": "agrikultur",
    "agronomen": "agronom",
    "agronomens": "agronom",
    "agronomer": "agronom",
    "agronomerna": "agronom",
    "agronomernas": "agronom",
    "agronomers": "agronom",
    "agronomien": "agronomi",
    "agronomiens": "agronomi",
    "agronomin": "agronomi",
    "agronomins": "agronomi",
    "agronomis": "agronomi",
    "agronomiska": "agronomisk",
    "agronomiskare": "agronomisk",
    "agronomiskares": "agronomisk",
    "agronomiskas": "agronomisk",
    "agronomiskast": "agronomisk",
    "agronomiskaste": "agronomisk",
    "agronomiskastes": "agronomisk",
    "agronomiskasts": "agronomisk",
    "agronomiske": "agronomisk",
    "agronomiskes": "agronomisk",
    "agronomisks": "agronomisk",
    "agronomiskt": "agronomisk",
    "agronomiskts": "agronomisk",
    "agronoms": "agronom",
    "agutier": "aguti",
    "agutierna": "aguti",
    "agutiernas": "aguti",
    "agutiers": "aguti",
    "agutin": "aguti",
    "agutins": "aguti",
    "agutis": "aguti",
    "aha-upplevelsen": "aha-upplevelse",
    "aha-upplevelsens": "aha-upplevelse",
    "aha-upplevelser": "aha-upplevelse",
    "aha-upplevelserna": "aha-upplevelse",
    "aha-upplevelsernas": "aha-upplevelse",
    "aha-upplevelsers": "aha-upplevelse",
    "aha-upplevelses": "aha-upplevelse",
    "ahaupplevelsen": "ahaupplevelse",
    "ahaupplevelsens": "ahaupplevelse",
    "ahaupplevelser": "ahaupplevelse",
    "ahaupplevelserna": "ahaupplevelse",
    "ahaupplevelsernas": "ahaupplevelse",
    "ahaupplevelsers": "ahaupplevelse",
    "ahaupplevelses": "ahaupplevelse",
    "aidsen": "aids",
    "aidsmedicinen": "aidsmedicin",
    "aidsmedicinens": "aidsmedicin",
    "aidsmediciner": "aidsmedicin",
    "aidsmedicinerna": "aidsmedicin",
    "aidsmedicinernas": "aidsmedicin",
    "aidsmediciners": "aidsmedicin",
    "aidsmedicins": "aidsmedicin",
    "aidspaniken": "aidspanik",
    "aidspanikens": "aidspanik",
    "aidspaniker": "aidspanik",
    "aidspanikerna": "aidspanik",
    "aidspanikernas": "aidspanik",
    "aidspanikers": "aidspanik",
    "aidspaniks": "aidspanik",
    "aikidon": "aikido",
    "aikidons": "aikido",
    "aikidos": "aikido",
    "aikidotricken": "aikidotrick",
    "aikidotrickens": "aikidotrick",
    "aikidotricket": "aikidotrick",
    "aikidotrickets": "aikidotrick",
    "aikidotricks": "aikidotrick",
    "airdaleterriern": "airdaleterrier",
    "airdaleterrierna": "airdaleterrier",
    "airdaleterriernas": "airdaleterrier",
    "airdaleterrierns": "airdaleterrier",
    "airdaleterriers": "airdaleterrier",
    "airen": "air",
    "airens": "air",
    "airer": "air",
    "airerna": "air",
    "airernas": "air",
    "airers": "air",
    "airs": "air",
    "ajournerad": "ajournera",
    "ajournerade": "ajournera",
    "ajournerades": "ajournera",
    "ajournerads": "ajournera",
    "ajournerande": "ajournera",
    "ajourneranden": "ajournerande",
    "ajournerandena": "ajournerande",
    "ajournerandenas": "ajournerande",
    "ajournerandens": "ajournerande",
    "ajournerandes": "ajournerande",
    "ajournerandet": "ajournerande",
    "ajournerandets": "ajournerande",
    "ajournerar": "ajournera",
    "ajourneras": "ajournera",
    "ajournerat": "ajournera",
    "ajournerats": "ajournera",
    "ajournerbara": "ajournerbar",
    "ajournerbarare": "ajournerbar",
    "ajournerbarares": "ajournerbar",
    "ajournerbaras": "ajournerbar",
    "ajournerbarast": "ajournerbar",
    "ajournerbaraste": "ajournerbar",
    "ajournerbarastes": "ajournerbar",
    "ajournerbarasts": "ajournerbar",
    "ajournerbare": "ajournerbar",
    "ajournerbares": "ajournerbar",
    "ajournerbarheten": "ajournerbarhet",
    "ajournerbarhetens": "ajournerbarhet",
    "ajournerbarhets": "ajournerbarhet",
    "ajournerbars": "ajournerbar",
    "ajournerbart": "ajournerbar",
    "ajournerbarts": "ajournerbar",
    "ajourneringar": "ajournering",
    "ajourneringarna": "ajournering",
    "ajourneringarnas": "ajournering",
    "ajourneringars": "ajournering",
    "ajourneringen": "ajournering",
    "ajourneringens": "ajournering",
    "ajournerings": "ajournering",
    "akaci": "akacia",
    "akacian": "akacia",
    "akacians": "akacia",
    "akacias": "akacia",
    "akacie": "akacia",
    "akacior": "akacia",
    "akaciorna": "akacia",
    "akaciornas": "akacia",
    "akaciors": "akacia",
    "akacis": "akacia",
    "akademien": "akademi",
    "akademiens": "akademi",
    "akademier": "akademi",
    "akademierna": "akademi",
    "akademiernas": "akademi",
    "akademiers": "akademi",
    "akademikern": "akademiker",
    "akademikerna": "akademiker",
    "akademikernas": "akademiker",
    "akademikerns": "akademiker",
    "akademikers": "akademiker",
    "akademin": "akademi",
    "akademins": "akademi",
    "akademis": "akademi",
    "akademiska": "akademisk",
    "akademiskare": "akademisk",
    "akademiskares": "akademisk",
    "akademiskas": "akademisk",
    "akademiskast": "akademisk",
    "akademiskaste": "akademisk",
    "akademiskastes": "akademisk",
    "akademiskasts": "akademisk",
    "akademiske": "akademisk",
    "akademiskes": "akademisk",
    "akademisks": "akademisk",
    "akademiskt": "akademisk",
    "akademiskts": "akademisk",
    "akademisten": "akademist",
    "akademistens": "akademist",
    "akademister": "akademist",
    "akademisterna": "akademist",
    "akademisternas": "akademist",
    "akademisters": "akademist",
    "akademists": "akademist",
    "akanten": "akant",
    "akantens": "akant",
    "akanter": "akant",
    "akanterna": "akant",
    "akanternas": "akant",
    "akanters": "akant",
    "akants": "akant",
    "akantusar": "akantus",
    "akantusarna": "akantus",
    "akantusarnas": "akantus",
    "akantusars": "akantus",
    "akantusbladen": "akantusblad",
    "akantusbladens": "akantusblad",
    "akantusbladet": "akantusblad",
    "akantusbladets": "akantusblad",
    "akantusblads": "akantusblad",
    "akantusen": "akantus",
    "akantusens": "akantus",
    "akatalektiska": "akatalektisk",
    "akatalektiskare": "akatalektisk",
    "akatalektiskares": "akatalektisk",
    "akatalektiskas": "akatalektisk",
    "akatalektiskast": "akatalektisk",
    "akatalektiskaste": "akatalektisk",
    "akatalektiskastes": "akatalektisk",
    "akatalektiskasts": "akatalektisk",
    "akatalektiske": "akatalektisk",
    "akatalektiskes": "akatalektisk",
    "akatalektisks": "akatalektisk",
    "akatalektiskt": "akatalektisk",
    "akatalektiskts": "akatalektisk",
    "akilleshälar": "akilleshäl",
    "akilleshälarna": "akilleshäl",
    "akilleshälarnas": "akilleshäl",
    "akilleshälars": "akilleshäl",
    "akilleshälen": "akilleshäl",
    "akilleshälens": "akilleshäl",
    "akilleshäls": "akilleshäl",
    "akillessen": "akillessena",
    "akillessenan": "akillessena",
    "akillessenans": "akillessena",
    "akillessenas": "akillessena",
    "akillessene": "akillessena",
    "akillessenor": "akillessena",
    "akillessenorna": "akillessena",
    "akillessenornas": "akillessena",
    "akillessenors": "akillessena",
    "akillessens": "akillessena",
    "aklej": "akleja",
    "aklejan": "akleja",
    "aklejans": "akleja",
    "aklejas": "akleja",
    "akleje": "akleja",
    "aklejor": "akleja",
    "aklejorna": "akleja",
    "aklejornas": "akleja",
    "aklejors": "akleja",
    "aklejs": "akleja",
    "aknen": "akne",
    "aknens": "akne",
    "aknes": "akne",
    "akribien": "akribi",
    "akribiens": "akribi",
    "akribin": "akribi",
    "akribins": "akribi",
    "akribis": "akribi",
    "akrobaten": "akrobat",
    "akrobatens": "akrobat",
    "akrobater": "akrobat",
    "akrobaterna": "akrobat",
    "akrobaternas": "akrobat",
    "akrobaters": "akrobat",
    "akrobatiken": "akrobatik",
    "akrobatikens": "akrobatik",
    "akrobatiks": "akrobatik",
    "akrobatiska": "akrobatisk",
    "akrobatiskare": "akrobatisk",
    "akrobatiskares": "akrobatisk",
    "akrobatiskas": "akrobatisk",
    "akrobatiskast": "akrobatisk",
    "akrobatiskaste": "akrobatisk",
    "akrobatiskastes": "akrobatisk",
    "akrobatiskasts": "akrobatisk",
    "akrobatiske": "akrobatisk",
    "akrobatiskes": "akrobatisk",
    "akrobatisks": "akrobatisk",
    "akrobatiskt": "akrobatisk",
    "akrobatiskts": "akrobatisk",
    "akrobats": "akrobat",
    "akromatiska": "akromatisk",
    "akromatiskare": "akromatisk",
    "akromatiskares": "akromatisk",
    "akromatiskas": "akromatisk",
    "akromatiskast": "akromatisk",
    "akromatiskaste": "akromatisk",
    "akromatiskastes": "akromatisk",
    "akromatiskasts": "akromatisk",
    "akromatiske": "akromatisk",
    "akromatiskes": "akromatisk",
    "akromatisks": "akromatisk",
    "akromatiskt": "akromatisk",
    "akromatiskts": "akromatisk",
    "akromegalien": "akromegali",
    "akromegaliens": "akromegali",
    "akromegalier": "akromegali",
    "akromegalierna": "akromegali",
    "akromegaliernas": "akromegali",
    "akromegaliers": "akromegali",
    "akromegalin": "akromegali",
    "akromegalins": "akromegali",
    "akromegalis": "akromegali",
    "akronymen": "akronym",
    "akronymens": "akronym",
    "akronymer": "akronym",
    "akronymerna": "akronym",
    "akronymernas": "akronym",
    "akronymers": "akronym",
    "akronyms": "akronym",
    "akropolen": "akropol",
    "akropolens": "akropol",
    "akropoler": "akropol",
    "akropolerna": "akropol",
    "akropolernas": "akropol",
    "akropolers": "akropol",
    "akropols": "akropol",
    "akrostikonen": "akrostikon",
    "akrostikonens": "akrostikon",
    "akrostikoner": "akrostikon",
    "akrostikonerna": "akrostikon",
    "akrostikonernas": "akrostikon",
    "akrostikoners": "akrostikon",
    "akrostikonet": "akrostikon",
    "akrostikonets": "akrostikon",
    "akrostikons": "akrostikon",
    "akrylen": "akryl",
    "akrylens": "akryl",
    "akryls": "akryl",
    "akt": "akta",
    "aktad": "akta",
    "aktade": "akta",
    "aktades": "akta",
    "aktads": "akta",
    "aktande": "akta",
    "aktanden": "aktande",
    "aktandena": "aktande",
    "aktandenas": "aktande",
    "aktandens": "aktande",
    "aktandes": "aktande",
    "aktandet": "aktande",
    "aktandets": "aktande",
    "aktar": "akta",
    "aktas": "akta",
    "aktat": "akta",
    "aktats": "akta",
    "akten": "akt",
    "aktens": "akt",
    "akter": "akt",
    "akterdelar": "akterdel",
    "akterdelarna": "akterdel",
    "akterdelarnas": "akterdel",
    "akterdelars": "akterdel",
    "akterdelen": "akterdel",
    "akterdelens": "akterdel",
    "akterdels": "akterdel",
    "akterdäcken": "akterdäck",
    "akterdäckens": "akterdäck",
    "akterdäcket": "akterdäck",
    "akterdäckets": "akterdäck",
    "akterdäcks": "akterdäck",
    "akterliga": "akterlig",
    "akterligare": "akterlig",
    "akterligares": "akterlig",
    "akterligas": "akterlig",
    "akterligast": "akterlig",
    "akterligaste": "akterlig",
    "akterligastes": "akterlig",
    "akterligasts": "akterlig",
    "akterlige": "akterlig",
    "akterliges": "akterlig",
    "akterligs": "akterlig",
    "akterligt": "akterlig",
    "akterligts": "akterlig",
    "aktern": "akter",
    "akterna": "akt",
    "akternas": "akt",
    "akterns": "akter",
    "akters": "akter",
    "akterseglade": "akterseglad",
    "akterseglades": "akterseglad",
    "akterseglads": "akterseglad",
    "akterseglat": "akterseglad",
    "akterseglats": "akterseglad",
    "akterskeppen": "akterskepp",
    "akterskeppens": "akterskepp",
    "akterskeppet": "akterskepp",
    "akterskeppets": "akterskepp",
    "akterskepps": "akterskepp",
    "aktersnurr": "aktersnurra",
    "aktersnurran": "aktersnurra",
    "aktersnurrans": "aktersnurra",
    "aktersnurras": "aktersnurra",
    "aktersnurre": "aktersnurra",
    "aktersnurror": "aktersnurra",
    "aktersnurrorna": "aktersnurra",
    "aktersnurrornas": "aktersnurra",
    "aktersnurrors": "aktersnurra",
    "aktersnurrs": "aktersnurra",
    "akterspegeln": "akterspegel",
    "akterspegelns": "akterspegel",
    "akterspegels": "akterspegel",
    "akterspeglar": "akterspegel",
    "akterspeglarna": "akterspegel",
    "akterspeglarnas": "akterspegel",
    "akterspeglars": "akterspegel",
    "aktersta": "aktre",
    "akterstas": "aktre",
    "akterste": "aktre",
    "akterstes": "aktre",
    "aktiebolagen": "aktiebolag",
    "aktiebolagens": "aktiebolag",
    "aktiebolaget": "aktiebolag",
    "aktiebolagets": "aktiebolag",
    "aktiebolags": "aktiebolag",
    "aktiebreven": "aktiebrev",
    "aktiebrevens": "aktiebrev",
    "aktiebrevet": "aktiebrev",
    "aktiebrevets": "aktiebrev",
    "aktiebrevs": "aktiebrev",
    "aktiebörsen": "aktiebörs",
    "aktiebörsens": "aktiebörs",
    "aktiebörser": "aktiebörs",
    "aktiebörserna": "aktiebörs",
    "aktiebörsernas": "aktiebörs",
    "aktiebörsers": "aktiebörs",
    "aktieemissionen": "aktieemission",
    "aktieemissionens": "aktieemission",
    "aktieemissioner": "aktieemission",
    "aktieemissionerna": "aktieemission",
    "aktieemissionernas": "aktieemission",
    "aktieemissioners": "aktieemission",
    "aktieemissions": "aktieemission",
    "aktiehandeln": "aktiehandel",
    "aktiehandelns": "aktiehandel",
    "aktiehandels": "aktiehandel",
    "aktieinnehaven": "aktieinnehav",
    "aktieinnehavens": "aktieinnehav",
    "aktieinnehavet": "aktieinnehav",
    "aktieinnehavets": "aktieinnehav",
    "aktieinnehavs": "aktieinnehav",
    "aktiekapitalen": "aktiekapital",
    "aktiekapitalens": "aktiekapital",
    "aktiekapitalet": "aktiekapital",
    "aktiekapitalets": "aktiekapital",
    "aktiekapitals": "aktiekapital",
    "aktiekupongen": "aktiekupong",
    "aktiekupongens": "aktiekupong",
    "aktiekuponger": "aktiekupong",
    "aktiekupongerna": "aktiekupong",
    "aktiekupongernas": "aktiekupong",
    "aktiekupongers": "aktiekupong",
    "aktiekupongs": "aktiekupong",
    "aktiekursen": "aktiekurs",
    "aktiekursens": "aktiekurs",
    "aktiekurser": "aktiekurs",
    "aktiekurserna": "aktiekurs",
    "aktiekursernas": "aktiekurs",
    "aktiekursers": "aktiekurs",
    "aktiemajoriteten": "aktiemajoritet",
    "aktiemajoritetens": "aktiemajoritet",
    "aktiemajoriteter": "aktiemajoritet",
    "aktiemajoriteterna": "aktiemajoritet",
    "aktiemajoriteternas": "aktiemajoritet",
    "aktiemajoriteters": "aktiemajoritet",
    "aktiemajoritets": "aktiemajoritet",
    "aktien": "aktie",
    "aktiens": "aktie",
    "aktieportföljen": "aktieportfölj",
    "aktieportföljens": "aktieportfölj",
    "aktieportföljer": "aktieportfölj",
    "aktieportföljerna": "aktieportfölj",
    "aktieportföljernas": "aktieportfölj",
    "aktieportföljers": "aktieportfölj",
    "aktieportföljs": "aktieportfölj",
    "aktieposten": "aktiepost",
    "aktiepostens": "aktiepost",
    "aktieposter": "aktiepost",
    "aktieposterna": "aktiepost",
    "aktieposternas": "aktiepost",
    "aktieposters": "aktiepost",
    "aktieposts": "aktiepost",
    "aktier": "aktie",
    "aktierna": "aktie",
    "aktiernas": "aktie",
    "aktiers": "aktie",
    "akties": "aktie",
    "aktiesparandes": "aktiesparande",
    "aktiesparandet": "aktiesparande",
    "aktiesparandets": "aktiesparande",
    "aktiesparklubbar": "aktiesparklubb",
    "aktiesparklubbarna": "aktiesparklubb",
    "aktiesparklubbarnas": "aktiesparklubb",
    "aktiesparklubbars": "aktiesparklubb",
    "aktiesparklubben": "aktiesparklubb",
    "aktiesparklubbens": "aktiesparklubb",
    "aktiesparklubbs": "aktiesparklubb",
    "aktiestockar": "aktiestock",
    "aktiestockarna": "aktiestock",
    "aktiestockarnas": "aktiestock",
    "aktiestockars": "aktiestock",
    "aktiestocken": "aktiestock",
    "aktiestockens": "aktiestock",
    "aktiestocks": "aktiestock",
    "aktieutdelningar": "aktieutdelning",
    "aktieutdelningarna": "aktieutdelning",
    "aktieutdelningarnas": "aktieutdelning",
    "aktieutdelningars": "aktieutdelning",
    "aktieutdelningen": "aktieutdelning",
    "aktieutdelningens": "aktieutdelning",
    "aktieutdelnings": "aktieutdelning",
    "aktievinsten": "aktievinst",
    "aktievinstens": "aktievinst",
    "aktievinster": "aktievinst",
    "aktievinsterna": "aktievinst",
    "aktievinsternas": "aktievinst",
    "aktievinsters": "aktievinst",
    "aktievinsts": "aktievinst",
    "aktieäganden": "aktieägande",
    "aktieägandena": "aktieägande",
    "aktieägandenas": "aktieägande",
    "aktieägandens": "aktieägande",
    "aktieägandes": "aktieägande",
    "aktieägandet": "aktieägande",
    "aktieägandets": "aktieägande",
    "aktieägar": "aktieägare",
    "aktieägaren": "aktieägare",
    "aktieägarens": "aktieägare",
    "aktieägares": "aktieägare",
    "aktieägarna": "aktieägare",
    "aktieägarnas": "aktieägare",
    "aktiga": "aktig",
    "aktigare": "aktig",
    "aktigares": "aktig",
    "aktigas": "aktig",
    "aktigast": "aktig",
    "aktigaste": "aktig",
    "aktigastes": "aktig",
    "aktigasts": "aktig",
    "aktige": "aktig",
    "aktiges": "aktig",
    "aktigs": "aktig",
    "aktigt": "aktig",
    "aktigts": "aktig",
    "aktiniet": "aktinium",
    "aktiniets": "aktinium",
    "aktiniumet": "aktinium",
    "aktiniumets": "aktinium",
    "aktiniums": "aktinium",
    "aktionen": "aktion",
    "aktionens": "aktion",
    "aktioner": "aktion",
    "aktionerna": "aktion",
    "aktionernas": "aktion",
    "aktioners": "aktion",
    "aktionistiska": "aktionistisk",
    "aktionistiskas": "aktionistisk",
    "aktionistiske": "aktionistisk",
    "aktionistiskes": "aktionistisk",
    "aktionistisks": "aktionistisk",
    "aktionistiskt": "aktionistisk",
    "aktionistiskts": "aktionistisk",
    "aktions": "aktion",
    "aktionsarten": "aktionsart",
    "aktionsartens": "aktionsart",
    "aktionsarter": "aktionsart",
    "aktionsarterna": "aktionsart",
    "aktionsarternas": "aktionsart",
    "aktionsarters": "aktionsart",
    "aktionsarts": "aktionsart",
    "aktionsgruppen": "aktionsgrupp",
    "aktionsgruppens": "aktionsgrupp",
    "aktionsgrupper": "aktionsgrupp",
    "aktionsgrupperna": "aktionsgrupp",
    "aktionsgruppernas": "aktionsgrupp",
    "aktionsgruppers": "aktionsgrupp",
    "aktionsgrupps": "aktionsgrupp",
    "aktionsradien": "aktionsradie",
    "aktionsradiens": "aktionsradie",
    "aktionsradier": "aktionsradie",
    "aktionsradierna": "aktionsradie",
    "aktionsradiernas": "aktionsradie",
    "aktionsradiers": "aktionsradie",
    "aktionsradies": "aktionsradie",
    "aktionsströmmar": "aktionsström",
    "aktionsströmmarna": "aktionsström",
    "aktionsströmmarnas": "aktionsström",
    "aktionsströmmars": "aktionsström",
    "aktionsströmmen": "aktionsström",
    "aktionsströmmens": "aktionsström",
    "aktionsströms": "aktionsström",
    "aktionssätten": "aktionssätt",
    "aktionssättens": "aktionssätt",
    "aktionssättet": "aktionssätt",
    "aktionssättets": "aktionssätt",
    "aktionssätts": "aktionssätt",
    "aktionsturbinen": "aktionsturbin",
    "aktionsturbinens": "aktionsturbin",
    "aktionsturbiner": "aktionsturbin",
    "aktionsturbinerna": "aktionsturbin",
    "aktionsturbinernas": "aktionsturbin",
    "aktionsturbiners": "aktionsturbin",
    "aktionsturbins": "aktionsturbin",
    "aktiv": "aktivum",
    "aktiva": "aktiv",
    "aktivan": "aktiva",
    "aktivana": "aktiva",
    "aktivanas": "aktiva",
    "aktivans": "aktiva",
    "aktivare": "aktiv",
    "aktivares": "aktiv",
    "aktivas": "aktiva",
    "aktivast": "aktiv",
    "aktivaste": "aktiv",
    "aktivastes": "aktiv",
    "aktivasts": "aktiv",
    "aktive": "aktiv",
    "aktiven": "aktivum",
    "aktivens": "aktivum",
    "aktiver": "aktivum",
    "aktiverad": "aktivera",
    "aktiverade": "aktivera",
    "aktiverades": "aktivera",
    "aktiverads": "aktivera",
    "aktiverande": "aktivera",
    "aktiveranden": "aktiverande",
    "aktiverandena": "aktiverande",
    "aktiverandenas": "aktiverande",
    "aktiverandens": "aktiverande",
    "aktiverandes": "aktiverande",
    "aktiverandet": "aktiverande",
    "aktiverandets": "aktiverande",
    "aktiverar": "aktivera",
    "aktiveras": "aktivera",
    "aktiverat": "aktivera",
    "aktiverats": "aktivera",
    "aktiverbara": "aktiverbar",
    "aktiverbarare": "aktiverbar",
    "aktiverbarares": "aktiverbar",
    "aktiverbaras": "aktiverbar",
    "aktiverbarast": "aktiverbar",
    "aktiverbaraste": "aktiverbar",
    "aktiverbarastes": "aktiverbar",
    "aktiverbarasts": "aktiverbar",
    "aktiverbare": "aktiverbar",
    "aktiverbares": "aktiverbar",
    "aktiverbarheten": "aktiverbarhet",
    "aktiverbarhetens": "aktiverbarhet",
    "aktiverbarhets": "aktiverbarhet",
    "aktiverbars": "aktiverbar",
    "aktiverbart": "aktiverbar",
    "aktiverbarts": "aktiverbar",
    "aktiveringar": "aktivering",
    "aktiveringarna": "aktivering",
    "aktiveringarnas": "aktivering",
    "aktiveringars": "aktivering",
    "aktiveringen": "aktivering",
    "aktiveringens": "aktivering",
    "aktiverings": "aktivering",
    "aktiveringsmönsterna": "aktiveringsmönster",
    "aktiveringsmönsternas": "aktiveringsmönster",
    "aktiveringsmönsters": "aktiveringsmönster",
    "aktiveringsmönstren": "aktiveringsmönster",
    "aktiveringsmönstrens": "aktiveringsmönster",
    "aktiveringsmönstret": "aktiveringsmönster",
    "aktiveringsmönstrets": "aktiveringsmönster",
    "aktiverna": "aktivum",
    "aktivernas": "aktivum",
    "aktivers": "aktivum",
    "aktives": "aktiv",
    "aktivet": "aktivum",
    "aktivets": "aktivum",
    "aktivismen": "aktivism",
    "aktivismens": "aktivism",
    "aktivismer": "aktivism",
    "aktivismerna": "aktivism",
    "aktivismernas": "aktivism",
    "aktivismers": "aktivism",
    "aktivisms": "aktivism",
    "aktivisten": "aktivist",
    "aktivistens": "aktivist",
    "aktivister": "aktivist",
    "aktivisterna": "aktivist",
    "aktivisternas": "aktivist",
    "aktivisters": "aktivist",
    "aktivistiska": "aktivistisk",
    "aktivistiskas": "aktivistisk",
    "aktivistiske": "aktivistisk",
    "aktivistiskes": "aktivistisk",
    "aktivistisks": "aktivistisk",
    "aktivistiskt": "aktivistisk",
    "aktivistiskts": "aktivistisk",
    "aktivists": "aktivist",
    "aktiviteten": "aktivitet",
    "aktivitetens": "aktivitet",
    "aktiviteter": "aktivitet",
    "aktiviteterna": "aktivitet",
    "aktiviteternas": "aktivitet",
    "aktiviteters": "aktivitet",
    "aktivitets": "aktivitet",
    "aktivitetsersättningar": "aktivitetsersättning",
    "aktivitetsersättningarna": "aktivitetsersättning",
    "aktivitetsersättningarnas": "aktivitetsersättning",
    "aktivitetsersättningars": "aktivitetsersättning",
    "aktivitetsersättningen": "aktivitetsersättning",
    "aktivitetsersättningens": "aktivitetsersättning",
    "aktivitetsersättnings": "aktivitetsersättning",
    "aktivs": "aktivum",
    "aktivt": "aktiv",
    "aktivts": "aktiv",
    "aktivumet": "aktivum",
    "aktivumets": "aktivum",
    "aktivums": "aktivum",
    "aktningar": "aktning",
    "aktningarna": "aktning",
    "aktningarnas": "aktning",
    "aktningars": "aktning",
    "aktningen": "aktning",
    "aktningens": "aktning",
    "aktnings": "aktning",
    "aktningsfulla": "aktningsfull",
    "aktningsfullare": "aktningsfull",
    "aktningsfullares": "aktningsfull",
    "aktningsfullas": "aktningsfull",
    "aktningsfullast": "aktningsfull",
    "aktningsfullaste": "aktningsfull",
    "aktningsfullastes": "aktningsfull",
    "aktningsfullasts": "aktningsfull",
    "aktningsfulle": "aktningsfull",
    "aktningsfulles": "aktningsfull",
    "aktningsfullheten": "aktningsfullhet",
    "aktningsfullhetens": "aktningsfullhet",
    "aktningsfullhets": "aktningsfullhet",
    "aktningsfulls": "aktningsfull",
    "aktningsfullt": "aktningsfull",
    "aktningsfullts": "aktningsfull",
    "aktningsvärda": "aktningsvärd",
    "aktningsvärdare": "aktningsvärd",
    "aktningsvärdares": "aktningsvärd",
    "aktningsvärdas": "aktningsvärd",
    "aktningsvärdast": "aktningsvärd",
    "aktningsvärdaste": "aktningsvärd",
    "aktningsvärdastes": "aktningsvärd",
    "aktningsvärdasts": "aktningsvärd",
    "aktningsvärde": "aktningsvärd",
    "aktningsvärdes": "aktningsvärd",
    "aktningsvärds": "aktningsvärd",
    "aktningsvärt": "aktningsvärd",
    "aktningsvärts": "aktningsvärd",
    "aktorer": "aktor",
    "aktorerna": "aktor",
    "aktorernas": "aktor",
    "aktorers": "aktor",
    "aktorn": "aktor",
    "aktorns": "aktor",
    "aktors": "aktor",
    "aktrar": "akter",
    "aktrarna": "akter",
    "aktrarnas": "akter",
    "aktrars": "akter",
    "aktres": "aktre",
    "aktrisen": "aktris",
    "aktrisens": "aktris",
    "aktriser": "aktris",
    "aktriserna": "aktris",
    "aktrisernas": "aktris",
    "aktrisers": "aktris",
    "akts": "akt",
    "aktsamheten": "aktsamhet",
    "aktsamhetens": "aktsamhet",
    "aktsamheter": "aktsamhet",
    "aktsamheterna": "aktsamhet",
    "aktsamheternas": "aktsamhet",
    "aktsamheters": "aktsamhet",
    "aktsamhets": "aktsamhet",
    "aktsamhetsplikten": "aktsamhetsplikt",
    "aktsamhetspliktens": "aktsamhetsplikt",
    "aktsamhetsplikter": "aktsamhetsplikt",
    "aktsamhetsplikterna": "aktsamhetsplikt",
    "aktsamhetsplikternas": "aktsamhetsplikt",
    "aktsamhetsplikters": "aktsamhetsplikt",
    "aktsamhetsplikts": "aktsamhetsplikt",
    "aktsamma": "aktsam",
    "aktsammare": "aktsam",
    "aktsammares": "aktsam",
    "aktsammas": "aktsam",
    "aktsammast": "aktsam",
    "aktsammaste": "aktsam",
    "aktsammastes": "aktsam",
    "aktsammasts": "aktsam",
    "aktsamme": "aktsam",
    "aktsammes": "aktsam",
    "aktsams": "aktsam",
    "aktsamt": "aktsam",
    "aktsamts": "aktsam",
    "aktstycken": "aktstycke",
    "aktstyckena": "aktstycke",
    "aktstyckenas": "aktstycke",
    "aktstyckens": "aktstycke",
    "aktstyckes": "aktstycke",
    "aktstycket": "aktstycke",
    "aktstyckets": "aktstycke",
    "aktstycks": "aktstycke",
    "aktualiserad": "aktualisera",
    "aktualiserade": "aktualisera",
    "aktualiserades": "aktualisera",
    "aktualiserads": "aktualisera",
    "aktualiserande": "aktualisera",
    "aktualiseranden": "aktualiserande",
    "aktualiserandena": "aktualiserande",
    "aktualiserandenas": "aktualiserande",
    "aktualiserandens": "aktualiserande",
    "aktualiserandes": "aktualiserande",
    "aktualiserandet": "aktualiserande",
    "aktualiserandets": "aktualiserande",
    "aktualiserar": "aktualisera",
    "aktualiseras": "aktualisera",
    "aktualiserat": "aktualisera",
    "aktualiserats": "aktualisera",
    "aktualiserbara": "aktualiserbar",
    "aktualiserbarare": "aktualiserbar",
    "aktualiserbarares": "aktualiserbar",
    "aktualiserbaras": "aktualiserbar",
    "aktualiserbarast": "aktualiserbar",
    "aktualiserbaraste": "aktualiserbar",
    "aktualiserbarastes": "aktualiserbar",
    "aktualiserbarasts": "aktualiserbar",
    "aktualiserbare": "aktualiserbar",
    "aktualiserbares": "aktualiserbar",
    "aktualiserbarheten": "aktualiserbarhet",
    "aktualiserbarhetens": "aktualiserbarhet",
    "aktualiserbarhets": "aktualiserbarhet",
    "aktualiserbars": "aktualiserbar",
    "aktualiserbart": "aktualiserbar",
    "aktualiserbarts": "aktualiserbar",
    "aktualiseringar": "aktualisering",
    "aktualiseringarna": "aktualisering",
    "aktualiseringarnas": "aktualisering",
    "aktualiseringars": "aktualisering",
    "aktualiseringen": "aktualisering",
    "aktualiseringens": "aktualisering",
    "aktualiserings": "aktualisering",
    "aktualismen": "aktualism",
    "aktualismens": "aktualism",
    "aktualisms": "aktualism",
    "aktualistiska": "aktualistisk",
    "aktualistiskas": "aktualistisk",
    "aktualistiske": "aktualistisk",
    "aktualistiskes": "aktualistisk",
    "aktualistisks": "aktualistisk",
    "aktualistiskt": "aktualistisk",
    "aktualistiskts": "aktualistisk",
    "aktualiteten": "aktualitet",
    "aktualitetens": "aktualitet",
    "aktualiteter": "aktualitet",
    "aktualiteterna": "aktualitet",
    "aktualiteternas": "aktualitet",
    "aktualiteters": "aktualitet",
    "aktualitets": "aktualitet",
    "aktualitetspressen": "aktualitetspress",
    "aktualitetspressens": "aktualitetspress",
    "aktuarien": "aktuarie",
    "aktuariens": "aktuarie",
    "aktuarier": "aktuarie",
    "aktuarierna": "aktuarie",
    "aktuariernas": "aktuarie",
    "aktuariers": "aktuarie",
    "aktuaries": "aktuarie",
    "aktuella": "aktuell",
    "aktuellare": "aktuell",
    "aktuellares": "aktuell",
    "aktuellas": "aktuell",
    "aktuellast": "aktuell",
    "aktuellaste": "aktuell",
    "aktuellastes": "aktuell",
    "aktuellasts": "aktuell",
    "aktuelle": "aktuell",
    "aktuelles": "aktuell",
    "aktuells": "aktuell",
    "aktuellt": "aktuell",
    "aktuellts": "aktuell",
    "aktören": "aktör",
    "aktörens": "aktör",
    "aktörer": "aktör",
    "aktörerna": "aktör",
    "aktörernas": "aktör",
    "aktörers": "aktör",
    "aktörs": "aktör",
    "akupunkturen": "akupunktur",
    "akupunkturens": "akupunktur",
    "akupunkturs": "akupunktur",
    "akustiken": "akustik",
    "akustikens": "akustik",
    "akustikplatt": "akustikplatta",
    "akustikplattan": "akustikplatta",
    "akustikplattans": "akustikplatta",
    "akustikplattas": "akustikplatta",
    "akustikplatte": "akustikplatta",
    "akustikplattor": "akustikplatta",
    "akustikplattorna": "akustikplatta",
    "akustikplattornas": "akustikplatta",
    "akustikplattors": "akustikplatta",
    "akustikplatts": "akustikplatta",
    "akustiks": "akustik",
    "akustiska": "akustisk",
    "akustiskare": "akustisk",
    "akustiskares": "akustisk",
    "akustiskas": "akustisk",
    "akustiskast": "akustisk",
    "akustiskaste": "akustisk",
    "akustiskastes": "akustisk",
    "akustiskasts": "akustisk",
    "akustiske": "akustisk",
    "akustiskes": "akustisk",
    "akustisks": "akustisk",
    "akustiskt": "akustisk",
    "akustiskts": "akustisk",
    "akuta": "akut",
    "akutare": "akut",
    "akutares": "akut",
    "akutas": "akut",
    "akutast": "akut",
    "akutaste": "akut",
    "akutastes": "akut",
    "akutasts": "akut",
    "akutavdelningar": "akutavdelning",
    "akutavdelningarna": "akutavdelning",
    "akutavdelningarnas": "akutavdelning",
    "akutavdelningars": "akutavdelning",
    "akutavdelningen": "akutavdelning",
    "akutavdelningens": "akutavdelning",
    "akutavdelnings": "akutavdelning",
    "akute": "akut",
    "akuten": "akut",
    "akutens": "akut",
    "akuter": "akut",
    "akuterna": "akut",
    "akuternas": "akut",
    "akuters": "akut",
    "akutes": "akut",
    "akutfallen": "akutfall",
    "akutfallens": "akutfall",
    "akutfallet": "akutfall",
    "akutfallets": "akutfall",
    "akutfalls": "akutfall",
    "akutmottagningar": "akutmottagning",
    "akutmottagningarna": "akutmottagning",
    "akutmottagningarnas": "akutmottagning",
    "akutmottagningars": "akutmottagning",
    "akutmottagningen": "akutmottagning",
    "akutmottagningens": "akutmottagning",
    "akutmottagnings": "akutmottagning",
    "akuts": "akut",
    "akutvården": "akutvård",
    "akutvårdens": "akutvård",
    "akutvårds": "akutvård",
    "akutvårdsdatan": "akutvårdsdata",
    "akutvårdsdatana": "akutvårdsdata",
    "akutvårdsdatanas": "akutvårdsdata",
    "akutvårdsdatans": "akutvårdsdata",
    "akutvårdsdatas": "akutvårdsdata",
    "akutvårdsdatat": "akutvårdsdata",
    "akutvårdsdatats": "akutvårdsdata",
    "akvakulturen": "akvakultur",
    "akvakulturens": "akvakultur",
    "akvakulturer": "akvakultur",
    "akvakulturerna": "akvakultur",
    "akvakulturernas": "akvakultur",
    "akvakulturers": "akvakultur",
    "akvakulturs": "akvakultur",
    "akvamarinen": "akvamarin",
    "akvamarinens": "akvamarin",
    "akvamariner": "akvamarin",
    "akvamarinerna": "akvamarin",
    "akvamarinernas": "akvamarin",
    "akvamariners": "akvamarin",
    "akvamarins": "akvamarin",
    "akvanauten": "akvanaut",
    "akvanautens": "akvanaut",
    "akvanauter": "akvanaut",
    "akvanauterna": "akvanaut",
    "akvanauternas": "akvanaut",
    "akvanauters": "akvanaut",
    "akvanauts": "akvanaut",
    "akvaplaningar": "akvaplaning",
    "akvaplaningarna": "akvaplaning",
    "akvaplaningarnas": "akvaplaning",
    "akvaplaningars": "akvaplaning",
    "akvaplaningen": "akvaplaning",
    "akvaplaningens": "akvaplaning",
    "akvaplanings": "akvaplaning",
    "akvarellen": "akvarell",
    "akvarellens": "akvarell",
    "akvareller": "akvarell",
    "akvarellerna": "akvarell",
    "akvarellernas": "akvarell",
    "akvarellers": "akvarell",
    "akvarellfärgen": "akvarellfärg",
    "akvarellfärgens": "akvarellfärg",
    "akvarellfärger": "akvarellfärg",
    "akvarellfärgerna": "akvarellfärg",
    "akvarellfärgernas": "akvarellfärg",
    "akvarellfärgers": "akvarellfärg",
    "akvarellfärgs": "akvarellfärg",
    "akvarellisten": "akvarellist",
    "akvarellistens": "akvarellist",
    "akvarellister": "akvarellist",
    "akvarellisterna": "akvarellist",
    "akvarellisternas": "akvarellist",
    "akvarellisters": "akvarellist",
    "akvarellists": "akvarellist",
    "akvarells": "akvarell",
    "akvarellutställningar": "akvarellutställning",
    "akvarellutställningarna": "akvarellutställning",
    "akvarellutställningarnas": "akvarellutställning",
    "akvarellutställningars": "akvarellutställning",
    "akvarellutställningen": "akvarellutställning",
    "akvarellutställningens": "akvarellutställning",
    "akvarellutställnings": "akvarellutställning",
    "akvarie": "akvarium",
    "akvariefiskar": "akvariefisk",
    "akvariefiskarna": "akvariefisk",
    "akvariefiskarnas": "akvariefisk",
    "akvariefiskars": "akvariefisk",
    "akvariefisken": "akvariefisk",
    "akvariefiskens": "akvariefisk",
    "akvariefisks": "akvariefisk",
    "akvarier": "akvarium",
    "akvarierna": "akvarium",
    "akvariernas": "akvarium",
    "akvariers": "akvarium",
    "akvariet": "akvarium",
    "akvariets": "akvarium",
    "akvaristiken": "akvaristik",
    "akvaristikens": "akvaristik",
    "akvaristiks": "akvaristik",
    "akvaristiska": "akvaristisk",
    "akvaristiskas": "akvaristisk",
    "akvaristiske": "akvaristisk",
    "akvaristiskes": "akvaristisk",
    "akvaristisks": "akvaristisk",
    "akvaristiskt": "akvaristisk",
    "akvaristiskts": "akvaristisk",
    "akvariums": "akvarium",
    "akvatinten": "akvatint",
    "akvatintens": "akvatint",
    "akvatinter": "akvatint",
    "akvatinterna": "akvatint",
    "akvatinternas": "akvatint",
    "akvatinters": "akvatint",
    "akvatints": "akvatint",
    "akvatiska": "akvatisk",
    "akvatiskare": "akvatisk",
    "akvatiskares": "akvatisk",
    "akvatiskas": "akvatisk",
    "akvatiskast": "akvatisk",
    "akvatiskaste": "akvatisk",
    "akvatiskastes": "akvatisk",
    "akvatiskasts": "akvatisk",
    "akvatiske": "akvatisk",
    "akvatiskes": "akvatisk",
    "akvatisks": "akvatisk",
    "akvatiskt": "akvatisk",
    "akvatiskts": "akvatisk",
    "akvaviten": "akvavit",
    "akvavitens": "akvavit",
    "akvaviter": "akvavit",
    "akvaviterna": "akvavit",
    "akvaviternas": "akvavit",
    "akvaviters": "akvavit",
    "akvavits": "akvavit",
    "akvedukten": "akvedukt",
    "akveduktens": "akvedukt",
    "akvedukter": "akvedukt",
    "akvedukterna": "akvedukt",
    "akvedukternas": "akvedukt",
    "akvedukters": "akvedukt",
    "akvedukts": "akvedukt",
    "alabasterhyn": "alabasterhy",
    "alabasterhyns": "alabasterhy",
    "alabasterhys": "alabasterhy",
    "alabastern": "alabaster",
    "alabasterns": "alabaster",
    "alabasters": "alabaster",
    "aladåben": "aladåb",
    "aladåbens": "aladåb",
    "aladåber": "aladåb",
    "aladåberna": "aladåb",
    "aladåbernas": "aladåb",
    "aladåbers": "aladåb",
    "aladåbs": "aladåb",
    "alagrecken": "alagreck",
    "alagreckens": "alagreck",
    "alagrecker": "alagreck",
    "alagreckerna": "alagreck",
    "alagreckernas": "alagreck",
    "alagreckers": "alagreck",
    "alagrecks": "alagreck",
    "alanen": "alan",
    "alanens": "alan",
    "alaner": "alan",
    "alanerna": "alan",
    "alanernas": "alan",
    "alaners": "alan",
    "alaninen": "alanin",
    "alaninens": "alanin",
    "alaninet": "alanin",
    "alaninets": "alanin",
    "alanins": "alanin",
    "alans": "alan",
    "alanten": "alant",
    "alantens": "alant",
    "alanter": "alant",
    "alanterna": "alant",
    "alanternas": "alant",
    "alanters": "alant",
    "alants": "alant",
    "alar": "al",
    "alarmen": "alarm",
    "alarmens": "alarm",
    "alarmerad": "alarmera",
    "alarmerade": "alarmera",
    "alarmerades": "alarmera",
    "alarmerads": "alarmera",
    "alarmerande": "alarmera",
    "alarmeranden": "alarmerande",
    "alarmerandena": "alarmerande",
    "alarmerandenas": "alarmerande",
    "alarmerandens": "alarmerande",
    "alarmerandes": "alarmerande",
    "alarmerandet": "alarmerande",
    "alarmerandets": "alarmerande",
    "alarmerar": "alarmera",
    "alarmeras": "alarmera",
    "alarmerat": "alarmera",
    "alarmerats": "alarmera",
    "alarmerbara": "alarmerbar",
    "alarmerbarare": "alarmerbar",
    "alarmerbarares": "alarmerbar",
    "alarmerbaras": "alarmerbar",
    "alarmerbarast": "alarmerbar",
    "alarmerbaraste": "alarmerbar",
    "alarmerbarastes": "alarmerbar",
    "alarmerbarasts": "alarmerbar",
    "alarmerbare": "alarmerbar",
    "alarmerbares": "alarmerbar",
    "alarmerbarheten": "alarmerbarhet",
    "alarmerbarhetens": "alarmerbarhet",
    "alarmerbarhets": "alarmerbarhet",
    "alarmerbars": "alarmerbar",
    "alarmerbart": "alarmerbar",
    "alarmerbarts": "alarmerbar",
    "alarmeringar": "alarmering",
    "alarmeringarna": "alarmering",
    "alarmeringarnas": "alarmering",
    "alarmeringars": "alarmering",
    "alarmeringen": "alarmering",
    "alarmeringens": "alarmering",
    "alarmerings": "alarmering",
    "alarmet": "alarm",
    "alarmets": "alarm",
    "alarmismen": "alarmism",
    "alarmismens": "alarmism",
    "alarmisms": "alarmism",
    "alarmisten": "alarmist",
    "alarmistens": "alarmist",
    "alarmister": "alarmist",
    "alarmisterna": "alarmist",
    "alarmisternas": "alarmist",
    "alarmisters": "alarmist",
    "alarmistiska": "alarmistisk",
    "alarmistiskas": "alarmistisk",
    "alarmistiske": "alarmistisk",
    "alarmistiskes": "alarmistisk",
    "alarmistisks": "alarmistisk",
    "alarmistiskt": "alarmistisk",
    "alarmistiskts": "alarmistisk",
    "alarmists": "alarmist",
    "alarms": "alarm",
    "alarna": "al",
    "alarnas": "al",
    "alars": "al",
    "alb": "alba",
    "alban": "alba",
    "albanen": "alban",
    "albanens": "alban",
    "albaner": "alban",
    "albanerna": "alban",
    "albanernas": "alban",
    "albaners": "alban",
    "albans": "alban",
    "albansk": "albanska",
    "albanska": "albansk",
    "albanskan": "albanska",
    "albanskans": "albanska",
    "albanskare": "albansk",
    "albanskares": "albansk",
    "albanskas": "albanska",
    "albanskast": "albansk",
    "albanskaste": "albansk",
    "albanskastes": "albansk",
    "albanskasts": "albansk",
    "albanske": "albanska",
    "albanskes": "albansk",
    "albanskor": "albanska",
    "albanskorna": "albanska",
    "albanskornas": "albanska",
    "albanskors": "albanska",
    "albansks": "albansk",
    "albanskt": "albansk",
    "albanskts": "albansk",
    "albas": "alba",
    "albatrossen": "albatross",
    "albatrossens": "albatross",
    "albatrosser": "albatross",
    "albatrosserna": "albatross",
    "albatrossernas": "albatross",
    "albatrossers": "albatross",
    "albe": "alba",
    "albigensen": "albigens",
    "albigensens": "albigens",
    "albigenser": "albigens",
    "albigensern": "albigenser",
    "albigenserna": "albigenser",
    "albigensernas": "albigenser",
    "albigenserns": "albigenser",
    "albigensers": "albigenser",
    "albiner": "albino",
    "albinerna": "albino",
    "albinernas": "albino",
    "albiners": "albino",
    "albinismen": "albinism",
    "albinismens": "albinism",
    "albinismer": "albinism",
    "albinismerna": "albinism",
    "albinismernas": "albinism",
    "albinismers": "albinism",
    "albinisms": "albinism",
    "albinistiska": "albinistisk",
    "albinistiskas": "albinistisk",
    "albinistiske": "albinistisk",
    "albinistiskes": "albinistisk",
    "albinistisks": "albinistisk",
    "albinistiskt": "albinistisk",
    "albinistiskts": "albinistisk",
    "albinon": "albino",
    "albinons": "albino",
    "albinos": "albino",
    "albinosarna": "albino",
    "albinosarnas": "albino",
    "albor": "alba",
    "alborna": "alba",
    "albornas": "alba",
    "albors": "alba",
    "albs": "alba",
    "albumen": "album",
    "albumens": "album",
    "albumet": "album",
    "albumets": "album",
    "albuminen": "albumin",
    "albuminens": "albumin",
    "albuminer": "albumin",
    "albuminerna": "albumin",
    "albuminernas": "albumin",
    "albuminers": "albumin",
    "albuminet": "albumin",
    "albuminets": "albumin",
    "albumins": "albumin",
    "albuminurien": "albuminuri",
    "albuminuriens": "albuminuri",
    "albuminurin": "albuminuri",
    "albuminurins": "albuminuri",
    "albuminuris": "albuminuri",
    "albums": "album",
    "albusk": "albuske",
    "albuskar": "albuske",
    "albuskarna": "albuske",
    "albuskarnas": "albuske",
    "albuskars": "albuske",
    "albusken": "albuske",
    "albuskens": "albuske",
    "albuskes": "albuske",
    "albylen": "albyl",
    "albylens": "albyl",
    "albyls": "albyl",
    "alcantaran": "alcantara",
    "alcantarans": "alcantara",
    "alcantaras": "alcantara",
    "aldehyden": "aldehyd",
    "aldehydens": "aldehyd",
    "aldehyder": "aldehyd",
    "aldehyderna": "aldehyd",
    "aldehydernas": "aldehyd",
    "aldehyders": "aldehyd",
    "aldehyds": "aldehyd",
    "alemannen": "alemann",
    "alemannens": "alemann",
    "alemanner": "alemann",
    "alemannerna": "alemann",
    "alemannernas": "alemann",
    "alemanners": "alemann",
    "alemanns": "alemann",
    "alen": "al",
    "alens": "al",
    "alerta": "alert",
    "alertare": "alert",
    "alertares": "alert",
    "alertas": "alert",
    "alertast": "alert",
    "alertaste": "alert",
    "alertastes": "alert",
    "alertasts": "alert",
    "alerte": "alert",
    "alertes": "alert",
    "alerts": "alert",
    "ales": "ale",
    "alet": "ale",
    "alets": "ale",
    "alexanderhuggets": "alexanderhugg",
    "alexandrinen": "alexandrin",
    "alexandrinens": "alexandrin",
    "alexandriner": "alexandrin",
    "alexandrinerna": "alexandrin",
    "alexandrinernas": "alexandrin",
    "alexandriners": "alexandrin",
    "alexandrins": "alexandrin",
    "alexandrinska": "alexandrinsk",
    "alexandrinskare": "alexandrinsk",
    "alexandrinskares": "alexandrinsk",
    "alexandrinskas": "alexandrinsk",
    "alexandrinskast": "alexandrinsk",
    "alexandrinskaste": "alexandrinsk",
    "alexandrinskastes": "alexandrinsk",
    "alexandrinskasts": "alexandrinsk",
    "alexandrinske": "alexandrinsk",
    "alexandrinskes": "alexandrinsk",
    "alexandrinsks": "alexandrinsk",
    "alexandrinskt": "alexandrinsk",
    "alexandrinskts": "alexandrinsk",
    "alexien": "alexi",
    "alexiens": "alexi",
    "alexier": "alexi",
    "alexierna": "alexi",
    "alexiernas": "alexi",
    "alexiers": "alexi",
    "alexin": "alexi",
    "alexins": "alexi",
    "alexis": "alexi",
    "alfabeten": "alfabet",
    "alfabetens": "alfabet",
    "alfabetet": "alfabet",
    "alfabetets": "alfabet",
    "alfabetiserad": "alfabetisera",
    "alfabetiserade": "alfabetisera",
    "alfabetiserades": "alfabetisera",
    "alfabetiserads": "alfabetisera",
    "alfabetiserande": "alfabetisera",
    "alfabetiseranden": "alfabetiserande",
    "alfabetiserandena": "alfabetiserande",
    "alfabetiserandenas": "alfabetiserande",
    "alfabetiserandens": "alfabetiserande",
    "alfabetiserandes": "alfabetiserande",
    "alfabetiserandet": "alfabetiserande",
    "alfabetiserandets": "alfabetiserande",
    "alfabetiserar": "alfabetisera",
    "alfabetiseras": "alfabetisera",
    "alfabetiserat": "alfabetisera",
    "alfabetiserats": "alfabetisera",
    "alfabetiserbara": "alfabetiserbar",
    "alfabetiserbarare": "alfabetiserbar",
    "alfabetiserbarares": "alfabetiserbar",
    "alfabetiserbaras": "alfabetiserbar",
    "alfabetiserbarast": "alfabetiserbar",
    "alfabetiserbaraste": "alfabetiserbar",
    "alfabetiserbarastes": "alfabetiserbar",
    "alfabetiserbarasts": "alfabetiserbar",
    "alfabetiserbare": "alfabetiserbar",
    "alfabetiserbares": "alfabetiserbar",
    "alfabetiserbarheten": "alfabetiserbarhet",
    "alfabetiserbarhetens": "alfabetiserbarhet",
    "alfabetiserbarhets": "alfabetiserbarhet",
    "alfabetiserbars": "alfabetiserbar",
    "alfabetiserbart": "alfabetiserbar",
    "alfabetiserbarts": "alfabetiserbar",
    "alfabetiseringar": "alfabetisering",
    "alfabetiseringarna": "alfabetisering",
    "alfabetiseringarnas": "alfabetisering",
    "alfabetiseringars": "alfabetisering",
    "alfabetiseringen": "alfabetisering",
    "alfabetiseringens": "alfabetisering",
    "alfabetiserings": "alfabetisering",
    "alfabetiska": "alfabetisk",
    "alfabetiskare": "alfabetisk",
    "alfabetiskares": "alfabetisk",
    "alfabetiskas": "alfabetisk",
    "alfabetiskast": "alfabetisk",
    "alfabetiskaste": "alfabetisk",
    "alfabetiskastes": "alfabetisk",
    "alfabetiskasts": "alfabetisk",
    "alfabetiske": "alfabetisk",
    "alfabetiskes": "alfabetisk",
    "alfabetisks": "alfabetisk",
    "alfabetiskt": "alfabetisk",
    "alfabetiskts": "alfabetisk",
    "alfabets": "alfabet",
    "alfahann": "alfahanne",
    "alfahannar": "alfahanne",
    "alfahannarna": "alfahanne",
    "alfahannarnas": "alfahanne",
    "alfahannars": "alfahanne",
    "alfahannen": "alfahanne",
    "alfahannens": "alfahanne",
    "alfahannes": "alfahanne",
    "alfahanns": "alfahanne",
    "alfalfan": "alfalfa",
    "alfalfans": "alfalfa",
    "alfalfas": "alfalfa",
    "alfametyltyrosinen": "alfametyltyrosin",
    "alfametyltyrosinens": "alfametyltyrosin",
    "alfametyltyrosiner": "alfametyltyrosin",
    "alfametyltyrosinerna": "alfametyltyrosin",
    "alfametyltyrosinernas": "alfametyltyrosin",
    "alfametyltyrosiners": "alfametyltyrosin",
    "alfametyltyrosinet": "alfametyltyrosin",
    "alfametyltyrosinets": "alfametyltyrosin",
    "alfametyltyrosins": "alfametyltyrosin",
    "alfan": "alfa",
    "alfana": "alfa",
    "alfanas": "alfa",
    "alfans": "alfa",
    "alfanumeriska": "alfanumerisk",
    "alfanumeriskare": "alfanumerisk",
    "alfanumeriskares": "alfanumerisk",
    "alfanumeriskas": "alfanumerisk",
    "alfanumeriskast": "alfanumerisk",
    "alfanumeriskaste": "alfanumerisk",
    "alfanumeriskastes": "alfanumerisk",
    "alfanumeriskasts": "alfanumerisk",
    "alfanumeriske": "alfanumerisk",
    "alfanumeriskes": "alfanumerisk",
    "alfanumerisks": "alfanumerisk",
    "alfanumeriskt": "alfanumerisk",
    "alfanumeriskts": "alfanumerisk",
    "alfapartikeln": "alfapartikel",
    "alfapartikelns": "alfapartikel",
    "alfapartikels": "alfapartikel",
    "alfapartiklar": "alfapartikel",
    "alfapartiklarna": "alfapartikel",
    "alfapartiklarnas": "alfapartikel",
    "alfapartiklars": "alfapartikel",
    "alfapetets": "alfapet",
    "alfapets": "alfapet",
    "alfas": "alfa",
    "alfastrålningar": "alfastrålning",
    "alfastrålningarna": "alfastrålning",
    "alfastrålningarnas": "alfastrålning",
    "alfastrålningars": "alfastrålning",
    "alfastrålningen": "alfastrålning",
    "alfastrålningens": "alfastrålning",
    "alfastrålnings": "alfastrålning",
    "alfat": "alfa",
    "alfats": "alfa",
    "alfen": "alf",
    "alfens": "alf",
    "alfer": "alf",
    "alferna": "alf",
    "alfernas": "alf",
    "alfers": "alf",
    "alfkorsen": "alfkors",
    "alfkorsens": "alfkors",
    "alfkorset": "alfkors",
    "alfkorsets": "alfkors",
    "alfonsen": "alfons",
    "alfonsens": "alfons",
    "alfonser": "alfons",
    "alfonserna": "alfons",
    "alfonsernas": "alfons",
    "alfonsers": "alfons",
    "alfågeln": "alfågel",
    "alfågelns": "alfågel",
    "alfågels": "alfågel",
    "alfågelskytten": "alfågelskytte",
    "alfågelskyttena": "alfågelskytte",
    "alfågelskyttenas": "alfågelskytte",
    "alfågelskyttens": "alfågelskytte",
    "alfågelskyttes": "alfågelskytte",
    "alfågelskyttet": "alfågelskytte",
    "alfågelskyttets": "alfågelskytte",
    "alfåglar": "alfågel",
    "alfåglarna": "alfågel",
    "alfåglarnas": "alfågel",
    "alfåglars": "alfågel",
    "alförrädar": "alförrädare",
    "alförrädaren": "alförrädare",
    "alförrädarens": "alförrädare",
    "alförrädares": "alförrädare",
    "alförrädarna": "alförrädare",
    "alförrädarnas": "alförrädare",
    "algebr": "algebra",
    "algebraiska": "algebraisk",
    "algebraiskare": "algebraisk",
    "algebraiskares": "algebraisk",
    "algebraiskas": "algebraisk",
    "algebraiskast": "algebraisk",
    "algebraiskaste": "algebraisk",
    "algebraiskastes": "algebraisk",
    "algebraiskasts": "algebraisk",
    "algebraiske": "algebraisk",
    "algebraiskes": "algebraisk",
    "algebraisks": "algebraisk",
    "algebraiskt": "algebraisk",
    "algebraiskts": "algebraisk",
    "algebran": "algebra",
    "algebrans": "algebra",
    "algebras": "algebra",
    "algebre": "algebra",
    "algebror": "algebra",
    "algebrorna": "algebra",
    "algebrornas": "algebra",
    "algebrors": "algebra",
    "algebrs": "algebra",
    "algen": "alg",
    "algens": "alg",
    "alger": "alg",
    "algeriern": "algerier",
    "algerierna": "algerier",
    "algeriernas": "algerier",
    "algerierns": "algerier",
    "algeriers": "algerier",
    "algeriska": "algerisk",
    "algeriskan": "algeriska",
    "algeriskans": "algeriska",
    "algeriskare": "algerisk",
    "algeriskares": "algerisk",
    "algeriskas": "algeriska",
    "algeriskast": "algerisk",
    "algeriskaste": "algerisk",
    "algeriskastes": "algerisk",
    "algeriskasts": "algerisk",
    "algeriske": "algeriska",
    "algeriskes": "algerisk",
    "algeriskor": "algeriska",
    "algeriskorna": "algeriska",
    "algeriskornas": "algeriska",
    "algeriskors": "algeriska",
    "algerisks": "algerisk",
    "algeriskt": "algerisk",
    "algeriskts": "algerisk",
    "algerna": "alg",
    "algernas": "alg",
    "algers": "alg",
    "algmatt": "algmatta",
    "algmattan": "algmatta",
    "algmattans": "algmatta",
    "algmattas": "algmatta",
    "algmatte": "algmatta",
    "algmattor": "algmatta",
    "algmattorna": "algmatta",
    "algmattornas": "algmatta",
    "algmattors": "algmatta",
    "algmatts": "algmatta",
    "algologen": "algolog",
    "algologens": "algolog",
    "algologer": "algolog",
    "algologerna": "algolog",
    "algologernas": "algolog",
    "algologers": "algolog",
    "algologien": "algologi",
    "algologiens": "algologi",
    "algologin": "algologi",
    "algologins": "algologi",
    "algologis": "algologi",
    "algologs": "algolog",
    "algonken": "algonk",
    "algonkens": "algonk",
    "algonker": "algonk",
    "algonkerna": "algonk",
    "algonkernas": "algonk",
    "algonkers": "algonk",
    "algonks": "algonk",
    "algoritmen": "algoritm",
    "algoritmens": "algoritm",
    "algoritmer": "algoritm",
    "algoritmerna": "algoritm",
    "algoritmernas": "algoritm",
    "algoritmers": "algoritm",
    "algoritms": "algoritm",
    "algs": "alg",
    "algtvättar": "algtvätt",
    "algtvättarna": "algtvätt",
    "algtvättarnas": "algtvätt",
    "algtvättars": "algtvätt",
    "algtvätten": "algtvätt",
    "algtvättens": "algtvätt",
    "algtvätts": "algtvätt",
    "alibin": "alibi",
    "alibina": "alibi",
    "alibinas": "alibi",
    "alibins": "alibi",
    "alibis": "alibi",
    "alibistiska": "alibistisk",
    "alibistiskas": "alibistisk",
    "alibistiske": "alibistisk",
    "alibistiskes": "alibistisk",
    "alibistisks": "alibistisk",
    "alibistiskt": "alibistisk",
    "alibistiskts": "alibistisk",
    "alibit": "alibi",
    "alibits": "alibi",
    "alienationen": "alienation",
    "alienationens": "alienation",
    "alienationer": "alienation",
    "alienationerna": "alienation",
    "alienationernas": "alienation",
    "alienationers": "alienation",
    "alienations": "alienation",
    "alienationsupplevelsen": "alienationsupplevelse",
    "alienationsupplevelsens": "alienationsupplevelse",
    "alienationsupplevelser": "alienationsupplevelse",
    "alienationsupplevelserna": "alienationsupplevelse",
    "alienationsupplevelsernas": "alienationsupplevelse",
    "alienationsupplevelsers": "alienationsupplevelse",
    "alienationsupplevelses": "alienationsupplevelse",
    "alienerad": "alienera",
    "alienerade": "alienera",
    "alienerades": "alienera",
    "alienerads": "alienera",
    "alienerande": "alienera",
    "alieneranden": "alienerande",
    "alienerandena": "alienerande",
    "alienerandenas": "alienerande",
    "alienerandens": "alienerande",
    "alienerandes": "alienerande",
    "alienerandet": "alienerande",
    "alienerandets": "alienerande",
    "alienerar": "alienera",
    "alieneras": "alienera",
    "alienerat": "alienera",
    "alienerats": "alienera",
    "alienerbara": "alienerbar",
    "alienerbarare": "alienerbar",
    "alienerbarares": "alienerbar",
    "alienerbaras": "alienerbar",
    "alienerbarast": "alienerbar",
    "alienerbaraste": "alienerbar",
    "alienerbarastes": "alienerbar",
    "alienerbarasts": "alienerbar",
    "alienerbare": "alienerbar",
    "alienerbares": "alienerbar",
    "alienerbarheten": "alienerbarhet",
    "alienerbarhetens": "alienerbarhet",
    "alienerbarhets": "alienerbarhet",
    "alienerbars": "alienerbar",
    "alienerbart": "alienerbar",
    "alienerbarts": "alienerbar",
    "alieneringar": "alienering",
    "alieneringarna": "alienering",
    "alieneringarnas": "alienering",
    "alieneringars": "alienering",
    "alieneringen": "alienering",
    "alieneringens": "alienering",
    "alienerings": "alienering",
    "alifatiska": "alifatisk",
    "alifatiskare": "alifatisk",
    "alifatiskares": "alifatisk",
    "alifatiskas": "alifatisk",
    "alifatiskast": "alifatisk",
    "alifatiskaste": "alifatisk",
    "alifatiskastes": "alifatisk",
    "alifatiskasts": "alifatisk",
    "alifatiske": "alifatisk",
    "alifatiskes": "alifatisk",
    "alifatisks": "alifatisk",
    "alifatiskt": "alifatisk",
    "alifatiskts": "alifatisk",
    "alik": "alika",
    "alikan": "alika",
    "alikans": "alika",
    "alikas": "alika",
    "alike": "alika",
    "alikor": "alika",
    "alikorna": "alika",
    "alikornas": "alika",
    "alikors": "alika",
    "aliks": "alika",
    "alimentära": "alimentär",
    "alimentärare": "alimentär",
    "alimentärares": "alimentär",
    "alimentäras": "alimentär",
    "alimentärast": "alimentär",
    "alimentäraste": "alimentär",
    "alimentärastes": "alimentär",
    "alimentärasts": "alimentär",
    "alimentäre": "alimentär",
    "alimentäres": "alimentär",
    "alimentärs": "alimentär",
    "alimentärt": "alimentär",
    "alimentärts": "alimentär",
    "alisarinen": "alisarin",
    "alisarinens": "alisarin",
    "alisarinet": "alisarin",
    "alisarinets": "alisarin",
    "alisarins": "alisarin",
    "alk": "alka",
    "alkaiska": "alkaisk",
    "alkaiskare": "alkaisk",
    "alkaiskares": "alkaisk",
    "alkaiskas": "alkaisk",
    "alkaiskast": "alkaisk",
    "alkaiskaste": "alkaisk",
    "alkaiskastes": "alkaisk",
    "alkaiskasts": "alkaisk",
    "alkaiske": "alkaisk",
    "alkaiskes": "alkaisk",
    "alkaisks": "alkaisk",
    "alkaiskt": "alkaisk",
    "alkaiskts": "alkaisk",
    "alkaliblåtts": "alkaliblått",
    "alkalier": "alkali",
    "alkalierna": "alkali",
    "alkaliernas": "alkali",
    "alkaliers": "alkali",
    "alkalimetallen": "alkalimetall",
    "alkalimetallens": "alkalimetall",
    "alkalimetaller": "alkalimetall",
    "alkalimetallerna": "alkalimetall",
    "alkalimetallernas": "alkalimetall",
    "alkalimetallers": "alkalimetall",
    "alkalimetalls": "alkalimetall",
    "alkalis": "alkali",
    "alkaliska": "alkalisk",
    "alkaliskare": "alkalisk",
    "alkaliskares": "alkalisk",
    "alkaliskas": "alkalisk",
    "alkaliskast": "alkalisk",
    "alkaliskaste": "alkalisk",
    "alkaliskastes": "alkalisk",
    "alkaliskasts": "alkalisk",
    "alkaliske": "alkalisk",
    "alkaliskes": "alkalisk",
    "alkalisks": "alkalisk",
    "alkaliskt": "alkalisk",
    "alkaliskts": "alkalisk",
    "alkalit": "alkali",
    "alkalits": "alkali",
    "alkaloiden": "alkaloid",
    "alkaloidens": "alkaloid",
    "alkaloider": "alkaloid",
    "alkaloiderna": "alkaloid",
    "alkaloidernas": "alkaloid",
    "alkaloiders": "alkaloid",
    "alkaloids": "alkaloid",
    "alkan": "alka",
    "alkanen": "alkan",
    "alkanens": "alkan",
    "alkaner": "alkan",
    "alkanerna": "alkan",
    "alkanernas": "alkan",
    "alkaners": "alkan",
    "alkannan": "alkanna",
    "alkannans": "alkanna",
    "alkannas": "alkanna",
    "alkanne": "alkanna",
    "alkannor": "alkanna",
    "alkannorna": "alkanna",
    "alkannornas": "alkanna",
    "alkannors": "alkanna",
    "alkanolen": "alkanol",
    "alkanolens": "alkanol",
    "alkanoler": "alkanol",
    "alkanolerna": "alkanol",
    "alkanolernas": "alkanol",
    "alkanolers": "alkanol",
    "alkanols": "alkanol",
    "alkans": "alkan",
    "alkas": "alka",
    "alke": "alka",
    "alkekungar": "alkekung",
    "alkekungarna": "alkekung",
    "alkekungarnas": "alkekung",
    "alkekungars": "alkekung",
    "alkekungen": "alkekung",
    "alkekungens": "alkekung",
    "alkekungs": "alkekung",
    "alkemien": "alkemi",
    "alkemiens": "alkemi",
    "alkemin": "alkemi",
    "alkemins": "alkemi",
    "alkemis": "alkemi",
    "alkemisten": "alkemist",
    "alkemistens": "alkemist",
    "alkemister": "alkemist",
    "alkemisterna": "alkemist",
    "alkemisternas": "alkemist",
    "alkemisters": "alkemist",
    "alkemistiska": "alkemistisk",
    "alkemistiskas": "alkemistisk",
    "alkemistiske": "alkemistisk",
    "alkemistiskes": "alkemistisk",
    "alkemistisks": "alkemistisk",
    "alkemistiskt": "alkemistisk",
    "alkemistiskts": "alkemistisk",
    "alkemists": "alkemist",
    "alkfågeln": "alkfågel",
    "alkfågelns": "alkfågel",
    "alkfågels": "alkfågel",
    "alkfåglar": "alkfågel",
    "alkfåglarna": "alkfågel",
    "alkfåglarnas": "alkfågel",
    "alkfåglars": "alkfågel",
    "alkoholen": "alkohol",
    "alkoholens": "alkohol",
    "alkoholer": "alkohol",
    "alkoholerna": "alkohol",
    "alkoholernas": "alkohol",
    "alkoholers": "alkohol",
    "alkoholförtäringar": "alkoholförtäring",
    "alkoholförtäringarna": "alkoholförtäring",
    "alkoholförtäringarnas": "alkoholförtäring",
    "alkoholförtäringars": "alkoholförtäring",
    "alkoholförtäringen": "alkoholförtäring",
    "alkoholförtäringens": "alkoholförtäring",
    "alkoholförtärings": "alkoholförtäring",
    "alkoholhalten": "alkoholhalt",
    "alkoholhaltens": "alkoholhalt",
    "alkoholhalter": "alkoholhalt",
    "alkoholhalterna": "alkoholhalt",
    "alkoholhalternas": "alkoholhalt",
    "alkoholhalters": "alkoholhalt",
    "alkoholhaltiga": "alkoholhaltig",
    "alkoholhaltigare": "alkoholhaltig",
    "alkoholhaltigares": "alkoholhaltig",
    "alkoholhaltigas": "alkoholhaltig",
    "alkoholhaltigast": "alkoholhaltig",
    "alkoholhaltigaste": "alkoholhaltig",
    "alkoholhaltigastes": "alkoholhaltig",
    "alkoholhaltigasts": "alkoholhaltig",
    "alkoholhaltige": "alkoholhaltig",
    "alkoholhaltiges": "alkoholhaltig",
    "alkoholhaltigs": "alkoholhaltig",
    "alkoholhaltigt": "alkoholhaltig",
    "alkoholhaltigts": "alkoholhaltig",
    "alkoholhalts": "alkoholhalt",
    "alkoholiserade": "alkoholiserad",
    "alkoholiserades": "alkoholiserad",
    "alkoholiserads": "alkoholiserad",
    "alkoholiserat": "alkoholiserad",
    "alkoholiserats": "alkoholiserad",
    "alkoholiska": "alkoholisk",
    "alkoholiskare": "alkoholisk",
    "alkoholiskares": "alkoholisk",
    "alkoholiskas": "alkoholisk",
    "alkoholiskast": "alkoholisk",
    "alkoholiskaste": "alkoholisk",
    "alkoholiskastes": "alkoholisk",
    "alkoholiskasts": "alkoholisk",
    "alkoholiske": "alkoholisk",
    "alkoholiskes": "alkoholisk",
    "alkoholisks": "alkoholisk",
    "alkoholiskt": "alkoholisk",
    "alkoholiskts": "alkoholisk",
    "alkoholismen": "alkoholism",
    "alkoholismens": "alkoholism",
    "alkoholismer": "alkoholism",
    "alkoholismerna": "alkoholism",
    "alkoholismernas": "alkoholism",
    "alkoholismers": "alkoholism",
    "alkoholisms": "alkoholism",
    "alkoholistanstalten": "alkoholistanstalt",
    "alkoholistanstaltens": "alkoholistanstalt",
    "alkoholistanstalter": "alkoholistanstalt",
    "alkoholistanstalterna": "alkoholistanstalt",
    "alkoholistanstalternas": "alkoholistanstalt",
    "alkoholistanstalters": "alkoholistanstalt",
    "alkoholistanstalts": "alkoholistanstalt",
    "alkoholisten": "alkoholist",
    "alkoholistens": "alkoholist",
    "alkoholister": "alkoholist",
    "alkoholisterna": "alkoholist",
    "alkoholisternas": "alkoholist",
    "alkoholisters": "alkoholist",
    "alkoholistiska": "alkoholistisk",
    "alkoholistiskas": "alkoholistisk",
    "alkoholistiske": "alkoholistisk",
    "alkoholistiskes": "alkoholistisk",
    "alkoholistisks": "alkoholistisk",
    "alkoholistiskt": "alkoholistisk",
    "alkoholistiskts": "alkoholistisk",
    "alkoholists": "alkoholist",
    "alkoholkonsumtionen": "alkoholkonsumtion",
    "alkoholkonsumtionens": "alkoholkonsumtion",
    "alkoholkonsumtioner": "alkoholkonsumtion",
    "alkoholkonsumtionerna": "alkoholkonsumtion",
    "alkoholkonsumtionernas": "alkoholkonsumtion",
    "alkoholkonsumtioners": "alkoholkonsumtion",
    "alkoholkonsumtions": "alkoholkonsumtion",
    "alkoholmissbrukandes": "alkoholmissbrukande",
    "alkoholmissbrukandet": "alkoholmissbrukande",
    "alkoholmissbrukandets": "alkoholmissbrukande",
    "alkoholmissbrukar": "alkoholmissbrukare",
    "alkoholmissbrukaren": "alkoholmissbrukare",
    "alkoholmissbrukarens": "alkoholmissbrukare",
    "alkoholmissbrukares": "alkoholmissbrukare",
    "alkoholmissbrukarna": "alkoholmissbrukare",
    "alkoholmissbrukarnas": "alkoholmissbrukare",
    "alkoholmissbruket": "alkoholmissbruk",
    "alkoholmissbrukets": "alkoholmissbruk",
    "alkoholmissbruks": "alkoholmissbruk",
    "alkoholometern": "alkoholometer",
    "alkoholometerns": "alkoholometer",
    "alkoholometers": "alkoholometer",
    "alkoholometrar": "alkoholometer",
    "alkoholometrarna": "alkoholometer",
    "alkoholometrarnas": "alkoholometer",
    "alkoholometrars": "alkoholometer",
    "alkoholpolicier": "alkoholpolicy",
    "alkoholpolicierna": "alkoholpolicy",
    "alkoholpoliciernas": "alkoholpolicy",
    "alkoholpoliciers": "alkoholpolicy",
    "alkoholpolicies": "alkoholpolicy",
    "alkoholpoliciesarna": "alkoholpolicy",
    "alkoholpoliciesarnas": "alkoholpolicy",
    "alkoholpolicyer": "alkoholpolicy",
    "alkoholpolicyerna": "alkoholpolicy",
    "alkoholpolicyernas": "alkoholpolicy",
    "alkoholpolicyers": "alkoholpolicy",
    "alkoholpolicyn": "alkoholpolicy",
    "alkoholpolicyns": "alkoholpolicy",
    "alkoholpolicys": "alkoholpolicy",
    "alkoholpolicysar": "alkoholpolicy",
    "alkoholpolicysarna": "alkoholpolicy",
    "alkoholpolicysarnas": "alkoholpolicy",
    "alkoholpolicysars": "alkoholpolicy",
    "alkoholpolitiken": "alkoholpolitik",
    "alkoholpolitikens": "alkoholpolitik",
    "alkoholpolitiks": "alkoholpolitik",
    "alkoholpolitiska": "alkoholpolitisk",
    "alkoholpolitiskas": "alkoholpolitisk",
    "alkoholpolitiske": "alkoholpolitisk",
    "alkoholpolitiskes": "alkoholpolitisk",
    "alkoholpolitisks": "alkoholpolitisk",
    "alkoholpolitiskt": "alkoholpolitisk",
    "alkoholpolitiskts": "alkoholpolitisk",
    "alkoholpsykosen": "alkoholpsykos",
    "alkoholpsykosens": "alkoholpsykos",
    "alkoholpsykoser": "alkoholpsykos",
    "alkoholpsykoserna": "alkoholpsykos",
    "alkoholpsykosernas": "alkoholpsykos",
    "alkoholpsykosers": "alkoholpsykos",
    "alkoholpåverkade": "alkoholpåverkad",
    "alkoholpåverkades": "alkoholpåverkad",
    "alkoholpåverkads": "alkoholpåverkad",
    "alkoholpåverkat": "alkoholpåverkad",
    "alkoholpåverkats": "alkoholpåverkad",
    "alkoholrelaterade": "alkoholrelaterad",
    "alkoholrelaterades": "alkoholrelaterad",
    "alkoholrelaterads": "alkoholrelaterad",
    "alkoholrelaterat": "alkoholrelaterad",
    "alkoholrelaterats": "alkoholrelaterad",
    "alkohols": "alkohol",
    "alkoholsvaga": "alkoholsvag",
    "alkoholsvagare": "alkoholsvag",
    "alkoholsvagares": "alkoholsvag",
    "alkoholsvagas": "alkoholsvag",
    "alkoholsvagast": "alkoholsvag",
    "alkoholsvagaste": "alkoholsvag",
    "alkoholsvagastes": "alkoholsvag",
    "alkoholsvagasts": "alkoholsvag",
    "alkoholsvage": "alkoholsvag",
    "alkoholsvages": "alkoholsvag",
    "alkoholsvagheten": "alkoholsvaghet",
    "alkoholsvaghetens": "alkoholsvaghet",
    "alkoholsvaghets": "alkoholsvaghet",
    "alkoholsvags": "alkoholsvag",
    "alkoholsvagt": "alkoholsvag",
    "alkoholsvagts": "alkoholsvag",
    "alkoholtesten": "alkoholtest",
    "alkoholtestens": "alkoholtest",
    "alkoholtester": "alkoholtest",
    "alkoholtesterna": "alkoholtest",
    "alkoholtesternas": "alkoholtest",
    "alkoholtesters": "alkoholtest",
    "alkoholtestet": "alkoholtest",
    "alkoholtestets": "alkoholtest",
    "alkoholtests": "alkoholtest",
    "alkor": "alka",
    "alkorna": "alka",
    "alkornas": "alka",
    "alkors": "alka",
    "alkotesten": "alkotest",
    "alkotestens": "alkotest",
    "alkotester": "alkotest",
    "alkotesterna": "alkotest",
    "alkotesternas": "alkotest",
    "alkotesters": "alkotest",
    "alkotestet": "alkotest",
    "alkotestets": "alkotest",
    "alkotests": "alkotest",
    "alkott": "alkotte",
    "alkottar": "alkotte",
    "alkottarna": "alkotte",
    "alkottarnas": "alkotte",
    "alkottars": "alkotte",
    "alkotten": "alkotte",
    "alkottens": "alkotte",
    "alkottes": "alkotte",
    "alkotts": "alkotte",
    "alkoven": "alkov",
    "alkovens": "alkov",
    "alkover": "alkov",
    "alkoverna": "alkov",
    "alkovernas": "alkov",
    "alkovers": "alkov",
    "alkovs": "alkov",
    "alks": "alka",
    "alkyden": "alkyd",
    "alkydens": "alkyd",
    "alkyder": "alkyd",
    "alkyderna": "alkyd",
    "alkydernas": "alkyd",
    "alkyders": "alkyd",
    "alkyds": "alkyd",
    "alkylen": "alkyl",
    "alkylens": "alkyl",
    "alkyler": "alkyl",
    "alkylerna": "alkyl",
    "alkylernas": "alkyl",
    "alkylers": "alkyl",
    "alkyls": "alkyl",
    "alkynen": "alkyn",
    "alkynens": "alkyn",
    "alkyner": "alkyn",
    "alkynerna": "alkyn",
    "alkynernas": "alkyn",
    "alkyners": "alkyn",
    "alkyns": "alkyn",
    "all": "alla",
    "alla": "all",
    "allan": "alla",
    "allans": "alla",
    "allas": "alla",
    "allativen": "allativ",
    "allativens": "allativ",
    "allativer": "allativ",
    "allativerna": "allativ",
    "allativernas": "allativ",
    "allativers": "allativ",
    "allativs": "allativ",
    "allbekanta": "allbekant",
    "allbekantare": "allbekant",
    "allbekantares": "allbekant",
    "allbekantas": "allbekant",
    "allbekantast": "allbekant",
    "allbekantaste": "allbekant",
    "allbekantastes": "allbekant",
    "allbekantasts": "allbekant",
    "allbekante": "allbekant",
    "allbekantes": "allbekant",
    "allbekants": "allbekant",
    "alldagliga": "alldaglig",
    "alldagligare": "alldaglig",
    "alldagligares": "alldaglig",
    "alldagligas": "alldaglig",
    "alldagligast": "alldaglig",
    "alldagligaste": "alldaglig",
    "alldagligastes": "alldaglig",
    "alldagligasts": "alldaglig",
    "alldaglige": "alldaglig",
    "alldagliges": "alldaglig",
    "alldagligheten": "alldaglighet",
    "alldaglighetens": "alldaglighet",
    "alldaglighets": "alldaglighet",
    "alldagligs": "alldaglig",
    "alldagligt": "alldaglig",
    "alldagligts": "alldaglig",
    "alle": "alla",
    "allegaten": "allegat",
    "allegatens": "allegat",
    "allegatet": "allegat",
    "allegatets": "allegat",
    "allegats": "allegat",
    "allegorien": "allegori",
    "allegoriens": "allegori",
    "allegorier": "allegori",
    "allegorierna": "allegori",
    "allegoriernas": "allegori",
    "allegoriers": "allegori",
    "allegorin": "allegori",
    "allegorins": "allegori",
    "allegoris": "allegori",
    "allegoriserad": "allegorisera",
    "allegoriserade": "allegorisera",
    "allegoriserades": "allegorisera",
    "allegoriserads": "allegorisera",
    "allegoriserande": "allegorisera",
    "allegoriseranden": "allegoriserande",
    "allegoriserandena": "allegoriserande",
    "allegoriserandenas": "allegoriserande",
    "allegoriserandens": "allegoriserande",
    "allegoriserandes": "allegoriserande",
    "allegoriserandet": "allegoriserande",
    "allegoriserandets": "allegoriserande",
    "allegoriserar": "allegorisera",
    "allegoriseras": "allegorisera",
    "allegoriserat": "allegorisera",
    "allegoriserats": "allegorisera",
    "allegoriserbara": "allegoriserbar",
    "allegoriserbarare": "allegoriserbar",
    "allegoriserbarares": "allegoriserbar",
    "allegoriserbaras": "allegoriserbar",
    "allegoriserbarast": "allegoriserbar",
    "allegoriserbaraste": "allegoriserbar",
    "allegoriserbarastes": "allegoriserbar",
    "allegoriserbarasts": "allegoriserbar",
    "allegoriserbare": "allegoriserbar",
    "allegoriserbares": "allegoriserbar",
    "allegoriserbarheten": "allegoriserbarhet",
    "allegoriserbarhetens": "allegoriserbarhet",
    "allegoriserbarhets": "allegoriserbarhet",
    "allegoriserbars": "allegoriserbar",
    "allegoriserbart": "allegoriserbar",
    "allegoriserbarts": "allegoriserbar",
    "allegoriseringar": "allegorisering",
    "allegoriseringarna": "allegorisering",
    "allegoriseringarnas": "allegorisering",
    "allegoriseringars": "allegorisering",
    "allegoriseringen": "allegorisering",
    "allegoriseringens": "allegorisering",
    "allegoriserings": "allegorisering",
    "allegoriska": "allegorisk",
    "allegoriskare": "allegorisk",
    "allegoriskares": "allegorisk",
    "allegoriskas": "allegorisk",
    "allegoriskast": "allegorisk",
    "allegoriskaste": "allegorisk",
    "allegoriskastes": "allegorisk",
    "allegoriskasts": "allegorisk",
    "allegoriske": "allegorisk",
    "allegoriskes": "allegorisk",
    "allegorisks": "allegorisk",
    "allegoriskt": "allegorisk",
    "allegoriskts": "allegorisk",
    "allegretton": "allegretto",
    "allegrettona": "allegretto",
    "allegrettonas": "allegretto",
    "allegrettons": "allegretto",
    "allegrettos": "allegretto",
    "allegrettot": "allegretto",
    "allegrettots": "allegretto",
    "allegron": "allegro",
    "allegrona": "allegro",
    "allegronas": "allegro",
    "allegrons": "allegro",
    "allegros": "allegro",
    "allegrot": "allegro",
    "allegrots": "allegro",
    "allemansfonden": "allemansfond",
    "allemansfondens": "allemansfond",
    "allemansfonder": "allemansfond",
    "allemansfonderna": "allemansfond",
    "allemansfondernas": "allemansfond",
    "allemansfonders": "allemansfond",
    "allemansfonds": "allemansfond",
    "allemansrätten": "allemansrätt",
    "allemansrättens": "allemansrätt",
    "allemansrätts": "allemansrätt",
    "allergena": "allergen",
    "allergenare": "allergen",
    "allergenares": "allergen",
    "allergenas": "allergen",
    "allergenast": "allergen",
    "allergenaste": "allergen",
    "allergenastes": "allergen",
    "allergenasts": "allergen",
    "allergene": "allergen",
    "allergenen": "allergen",
    "allergenens": "allergen",
    "allergener": "allergen",
    "allergenerna": "allergen",
    "allergenernas": "allergen",
    "allergeners": "allergen",
    "allergenes": "allergen",
    "allergenet": "allergen",
    "allergenets": "allergen",
    "allergens": "allergen",
    "allergent": "allergen",
    "allergents": "allergen",
    "allergien": "allergi",
    "allergiens": "allergi",
    "allergier": "allergi",
    "allergierna": "allergi",
    "allergiernas": "allergi",
    "allergiers": "allergi",
    "allergikern": "allergiker",
    "allergikerna": "allergiker",
    "allergikernas": "allergiker",
    "allergikerns": "allergiker",
    "allergikers": "allergiker",
    "allergimedicinen": "allergimedicin",
    "allergimedicinens": "allergimedicin",
    "allergimediciner": "allergimedicin",
    "allergimedicinerna": "allergimedicin",
    "allergimedicinernas": "allergimedicin",
    "allergimediciners": "allergimedicin",
    "allergimedicins": "allergimedicin",
    "allergin": "allergi",
    "allergins": "allergi",
    "allergis": "allergi",
    "allergiska": "allergisk",
    "allergiskare": "allergisk",
    "allergiskares": "allergisk",
    "allergiskas": "allergisk",
    "allergiskast": "allergisk",
    "allergiskaste": "allergisk",
    "allergiskastes": "allergisk",
    "allergiskasts": "allergisk",
    "allergiske": "allergisk",
    "allergiskes": "allergisk",
    "allergisks": "allergisk",
    "allergiskt": "allergisk",
    "allergiskts": "allergisk",
    "allergologen": "allergolog",
    "allergologens": "allergolog",
    "allergologer": "allergolog",
    "allergologerna": "allergolog",
    "allergologernas": "allergolog",
    "allergologers": "allergolog",
    "allergologien": "allergologi",
    "allergologiens": "allergologi",
    "allergologin": "allergologi",
    "allergologins": "allergologi",
    "allergologis": "allergologi",
    "allergologs": "allergolog",
    "allernådigstes": "allernådigste",
    "allfadern": "allfader",
    "allfaderns": "allfader",
    "allfaders": "allfader",
    "allfarvägar": "allfarväg",
    "allfarvägarna": "allfarväg",
    "allfarvägarnas": "allfarväg",
    "allfarvägars": "allfarväg",
    "allfarvägen": "allfarväg",
    "allfarvägens": "allfarväg",
    "allfarvägs": "allfarväg",
    "allhelgonadagar": "allhelgonadag",
    "allhelgonadagarna": "allhelgonadag",
    "allhelgonadagarnas": "allhelgonadag",
    "allhelgonadagars": "allhelgonadag",
    "allhelgonadagen": "allhelgonadag",
    "allhelgonadagens": "allhelgonadag",
    "allhelgonadags": "allhelgonadag",
    "allhelgonamäss": "allhelgonamässa",
    "allhelgonamässan": "allhelgonamässa",
    "allhelgonamässans": "allhelgonamässa",
    "allhelgonamässas": "allhelgonamässa",
    "allhelgonamässe": "allhelgonamässa",
    "allhelgonamässor": "allhelgonamässa",
    "allhelgonamässorna": "allhelgonamässa",
    "allhelgonamässornas": "allhelgonamässa",
    "allhelgonamässors": "allhelgonamässa",
    "alliansen": "allians",
    "alliansens": "allians",
    "allianser": "allians",
    "allianserna": "allians",
    "alliansernas": "allians",
    "alliansers": "allians",
    "alliansfria": "alliansfri",
    "alliansfriare": "alliansfri",
    "alliansfriares": "alliansfri",
    "alliansfrias": "alliansfri",
    "alliansfriast": "alliansfri",
    "alliansfriaste": "alliansfri",
    "alliansfriastes": "alliansfri",
    "alliansfriasts": "alliansfri",
    "alliansfrie": "alliansfri",
    "alliansfries": "alliansfri",
    "alliansfris": "alliansfri",
    "alliansfritt": "alliansfri",
    "alliansfritts": "alliansfri",
    "allianskollegan": "allianskollega",
    "allianskollegans": "allianskollega",
    "allianskollegas": "allianskollega",
    "allianskolleger": "allianskollega",
    "allianskollegerna": "allianskollega",
    "allianskollegernas": "allianskollega",
    "allianskollegers": "allianskollega",
    "allianskollegor": "allianskollega",
    "allianskollegorna": "allianskollega",
    "allianskollegornas": "allianskollega",
    "allianskollegors": "allianskollega",
    "allianspartier": "alliansparti",
    "allianspartierna": "alliansparti",
    "allianspartiernas": "alliansparti",
    "allianspartiers": "alliansparti",
    "allianspartiet": "alliansparti",
    "allianspartiets": "alliansparti",
    "allianspartis": "alliansparti",
    "allianspartit": "alliansparti",
    "allianspartits": "alliansparti",
    "alliansringar": "alliansring",
    "alliansringarna": "alliansring",
    "alliansringarnas": "alliansring",
    "alliansringars": "alliansring",
    "alliansringen": "alliansring",
    "alliansringens": "alliansring",
    "alliansrings": "alliansring",
    "allierad": "alliera",
    "allierade": "allierad",
    "allierades": "allierad",
    "allierads": "allierad",
    "allierande": "alliera",
    "allieranden": "allierande",
    "allierandena": "allierande",
    "allierandenas": "allierande",
    "allierandens": "allierande",
    "allierandes": "allierande",
    "allierandet": "allierande",
    "allierandets": "allierande",
    "allierar": "alliera",
    "allieras": "alliera",
    "allierat": "allierad",
    "allierats": "allierad",
    "allierbara": "allierbar",
    "allierbarare": "allierbar",
    "allierbarares": "allierbar",
    "allierbaras": "allierbar",
    "allierbarast": "allierbar",
    "allierbaraste": "allierbar",
    "allierbarastes": "allierbar",
    "allierbarasts": "allierbar",
    "allierbare": "allierbar",
    "allierbares": "allierbar",
    "allierbarheten": "allierbarhet",
    "allierbarhetens": "allierbarhet",
    "allierbarhets": "allierbarhet",
    "allierbars": "allierbar",
    "allierbart": "allierbar",
    "allierbarts": "allierbar",
    "allieringar": "alliering",
    "allieringarna": "alliering",
    "allieringarnas": "alliering",
    "allieringars": "alliering",
    "allieringen": "alliering",
    "allieringens": "alliering",
    "allierings": "alliering",
    "alligatorer": "alligator",
    "alligatorerna": "alligator",
    "alligatorernas": "alligator",
    "alligatorers": "alligator",
    "alligatorn": "alligator",
    "alligatorns": "alligator",
    "alligators": "alligator",
    "allihops": "allihop",
    "allitterationen": "allitteration",
    "allitterationens": "allitteration",
    "allitterationer": "allitteration",
    "allitterationerna": "allitteration",
    "allitterationernas": "allitteration",
    "allitterationers": "allitteration",
    "allitterations": "allitteration",
    "allittererad": "allitterera",
    "allittererade": "allitterera",
    "allittererades": "allitterera",
    "allittererads": "allitterera",
    "allittererande": "allitterera",
    "allittereranden": "allittererande",
    "allittererandena": "allittererande",
    "allittererandenas": "allittererande",
    "allittererandens": "allittererande",
    "allittererandes": "allittererande",
    "allittererandet": "allittererande",
    "allittererandets": "allittererande",
    "allittererar": "allitterera",
    "allittereras": "allitterera",
    "allittererat": "allitterera",
    "allittererats": "allitterera",
    "allittererbara": "allittererbar",
    "allittererbarare": "allittererbar",
    "allittererbarares": "allittererbar",
    "allittererbaras": "allittererbar",
    "allittererbarast": "allittererbar",
    "allittererbaraste": "allittererbar",
    "allittererbarastes": "allittererbar",
    "allittererbarasts": "allittererbar",
    "allittererbare": "allittererbar",
    "allittererbares": "allittererbar",
    "allittererbarheten": "allittererbarhet",
    "allittererbarhetens": "allittererbarhet",
    "allittererbarhets": "allittererbarhet",
    "allittererbars": "allittererbar",
    "allittererbart": "allittererbar",
    "allittererbarts": "allittererbar",
    "allittereringar": "allitterering",
    "allittereringarna": "allitterering",
    "allittereringarnas": "allitterering",
    "allittereringars": "allitterering",
    "allittereringen": "allitterering",
    "allittereringens": "allitterering",
    "allittererings": "allitterering",
    "allkonstnären": "allkonstnär",
    "allkonstnärens": "allkonstnär",
    "allkonstnärer": "allkonstnär",
    "allkonstnärerna": "allkonstnär",
    "allkonstnärernas": "allkonstnär",
    "allkonstnärers": "allkonstnär",
    "allkonstnärs": "allkonstnär",
    "allkonstverken": "allkonstverk",
    "allkonstverkens": "allkonstverk",
    "allkonstverket": "allkonstverk",
    "allkonstverkets": "allkonstverk",
    "allkonstverks": "allkonstverk",
    "allmakten": "allmakt",
    "allmaktens": "allmakt",
    "allmakts": "allmakt",
    "allmogeblåa": "allmogeblå",
    "allmogeblåare": "allmogeblå",
    "allmogeblåares": "allmogeblå",
    "allmogeblåas": "allmogeblå",
    "allmogeblåast": "allmogeblå",
    "allmogeblåaste": "allmogeblå",
    "allmogeblåastes": "allmogeblå",
    "allmogeblåasts": "allmogeblå",
    "allmogeblåe": "allmogeblå",
    "allmogeblåes": "allmogeblå",
    "allmogeblås": "allmogeblå",
    "allmogeblått": "allmogeblå",
    "allmogeblåtts": "allmogeblå",
    "allmogedräkten": "allmogedräkt",
    "allmogedräktens": "allmogedräkt",
    "allmogedräkter": "allmogedräkt",
    "allmogedräkterna": "allmogedräkt",
    "allmogedräkternas": "allmogedräkt",
    "allmogedräkters": "allmogedräkt",
    "allmogedräkts": "allmogedräkt",
    "allmogekulturen": "allmogekultur",
    "allmogekulturens": "allmogekultur",
    "allmogekulturer": "allmogekultur",
    "allmogekulturerna": "allmogekultur",
    "allmogekulturernas": "allmogekultur",
    "allmogekulturers": "allmogekultur",
    "allmogekulturs": "allmogekultur",
    "allmogen": "allmoge",
    "allmogens": "allmoge",
    "allmoges": "allmoge",
    "allmogevävnaden": "allmogevävnad",
    "allmogevävnadens": "allmogevävnad",
    "allmogevävnader": "allmogevävnad",
    "allmogevävnaderna": "allmogevävnad",
    "allmogevävnadernas": "allmogevävnad",
    "allmogevävnaders": "allmogevävnad",
    "allmogevävnads": "allmogevävnad",
    "allmos": "allmosa",
    "allmosan": "allmosa",
    "allmosans": "allmosa",
    "allmosas": "allmosa",
    "allmose": "allmosa",
    "allmosor": "allmosa",
    "allmosorna": "allmosa",
    "allmosornas": "allmosa",
    "allmosors": "allmosa",
    "allmänandan": "allmänanda",
    "allmänandans": "allmänanda",
    "allmänandas": "allmänanda",
    "allmänbegreppen": "allmänbegrepp",
    "allmänbegreppens": "allmänbegrepp",
    "allmänbegreppet": "allmänbegrepp",
    "allmänbegreppets": "allmänbegrepp",
    "allmänbegrepps": "allmänbegrepp",
    "allmänbegåvningar": "allmänbegåvning",
    "allmänbegåvningarna": "allmänbegåvning",
    "allmänbegåvningarnas": "allmänbegåvning",
    "allmänbegåvningars": "allmänbegåvning",
    "allmänbegåvningen": "allmänbegåvning",
    "allmänbegåvningens": "allmänbegåvning",
    "allmänbegåvnings": "allmänbegåvning",
    "allmänbild": "allmänbilda",
    "allmänbildad": "allmänbilda",
    "allmänbildade": "allmänbildad",
    "allmänbildades": "allmänbildad",
    "allmänbildads": "allmänbildad",
    "allmänbildande": "allmänbilda",
    "allmänbildanden": "allmänbildande",
    "allmänbildandena": "allmänbildande",
    "allmänbildandenas": "allmänbildande",
    "allmänbildandens": "allmänbildande",
    "allmänbildandes": "allmänbildande",
    "allmänbildandet": "allmänbildande",
    "allmänbildandets": "allmänbildande",
    "allmänbildar": "allmänbilda",
    "allmänbildas": "allmänbilda",
    "allmänbildat": "allmänbildad",
    "allmänbildats": "allmänbildad",
    "allmänbildningar": "allmänbildning",
    "allmänbildningarna": "allmänbildning",
    "allmänbildningarnas": "allmänbildning",
    "allmänbildningars": "allmänbildning",
    "allmänbildningen": "allmänbildning",
    "allmänbildningens": "allmänbildning",
    "allmänbildnings": "allmänbildning",
    "allmänfarliga": "allmänfarlig",
    "allmänfarligare": "allmänfarlig",
    "allmänfarligares": "allmänfarlig",
    "allmänfarligas": "allmänfarlig",
    "allmänfarligast": "allmänfarlig",
    "allmänfarligaste": "allmänfarlig",
    "allmänfarligastes": "allmänfarlig",
    "allmänfarligasts": "allmänfarlig",
    "allmänfarlige": "allmänfarlig",
    "allmänfarliges": "allmänfarlig",
    "allmänfarligheten": "allmänfarlighet",
    "allmänfarlighetens": "allmänfarlighet",
    "allmänfarlighets": "allmänfarlighet",
    "allmänfarligs": "allmänfarlig",
    "allmänfarligt": "allmänfarlig",
    "allmänfarligts": "allmänfarlig",
    "allmängiltiga": "allmängiltig",
    "allmängiltigare": "allmängiltig",
    "allmängiltigares": "allmängiltig",
    "allmängiltigas": "allmängiltig",
    "allmängiltigast": "allmängiltig",
    "allmängiltigaste": "allmängiltig",
    "allmängiltigastes": "allmängiltig",
    "allmängiltigasts": "allmängiltig",
    "allmängiltige": "allmängiltig",
    "allmängiltiges": "allmängiltig",
    "allmängiltigheten": "allmängiltighet",
    "allmängiltighetens": "allmängiltighet",
    "allmängiltigheter": "allmängiltighet",
    "allmängiltigheterna": "allmängiltighet",
    "allmängiltigheternas": "allmängiltighet",
    "allmängiltigheters": "allmängiltighet",
    "allmängiltighets": "allmängiltighet",
    "allmängiltigs": "allmängiltig",
    "allmängiltigt": "allmängiltig",
    "allmängiltigts": "allmängiltig",
    "allmängodset": "allmängods",
    "allmängodsets": "allmängods",
    "allmänheten": "allmänhet",
    "allmänhetens": "allmänhet",
    "allmänheter": "allmänhet",
    "allmänheterna": "allmänhet",
    "allmänheternas": "allmänhet",
    "allmänheters": "allmänhet",
    "allmänhets": "allmänhet",
    "allmänhumanistiska": "allmänhumanistisk",
    "allmänhumanistiskas": "allmänhumanistisk",
    "allmänhumanistiske": "allmänhumanistisk",
    "allmänhumanistiskes": "allmänhumanistisk",
    "allmänhumanistisks": "allmänhumanistisk",
    "allmänhumanistiskt": "allmänhumanistisk",
    "allmänhumanistiskts": "allmänhumanistisk",
    "allmänläkar": "allmänläkare",
    "allmänläkaren": "allmänläkare",
    "allmänläkarens": "allmänläkare",
    "allmänläkares": "allmänläkare",
    "allmänläkarna": "allmänläkare",
    "allmänläkarnas": "allmänläkare",
    "allmänmodernistiska": "allmänmodernistisk",
    "allmänmodernistiskas": "allmänmodernistisk",
    "allmänmodernistiske": "allmänmodernistisk",
    "allmänmodernistiskes": "allmänmodernistisk",
    "allmänmodernistisks": "allmänmodernistisk",
    "allmänmodernistiskt": "allmänmodernistisk",
    "allmänmodernistiskts": "allmänmodernistisk",
    "allmänmänskliga": "allmänmänsklig",
    "allmänmänskligare": "allmänmänsklig",
    "allmänmänskligares": "allmänmänsklig",
    "allmänmänskligas": "allmänmänsklig",
    "allmänmänskligast": "allmänmänsklig",
    "allmänmänskligaste": "allmänmänsklig",
    "allmänmänskligastes": "allmänmänsklig",
    "allmänmänskligasts": "allmänmänsklig",
    "allmänmänsklige": "allmänmänsklig",
    "allmänmänskliges": "allmänmänsklig",
    "allmänmänskligheten": "allmänmänsklighet",
    "allmänmänsklighetens": "allmänmänsklighet",
    "allmänmänsklighets": "allmänmänsklighet",
    "allmänmänskligs": "allmänmänsklig",
    "allmänmänskligt": "allmänmänsklig",
    "allmänmänskligts": "allmänmänsklig",
    "allmänna": "allmän",
    "allmännare": "allmän",
    "allmännares": "allmän",
    "allmännas": "allmän",
    "allmännast": "allmän",
    "allmännaste": "allmän",
    "allmännastes": "allmän",
    "allmännasts": "allmän",
    "allmänne": "allmän",
    "allmänneliga": "allmännelig",
    "allmänneligare": "allmännelig",
    "allmänneligares": "allmännelig",
    "allmänneligas": "allmännelig",
    "allmänneligast": "allmännelig",
    "allmänneligaste": "allmännelig",
    "allmänneligastes": "allmännelig",
    "allmänneligasts": "allmännelig",
    "allmännelige": "allmännelig",
    "allmänneliges": "allmännelig",
    "allmänneligheten": "allmännelighet",
    "allmännelighetens": "allmännelighet",
    "allmännelighets": "allmännelighet",
    "allmänneligs": "allmännelig",
    "allmänneligt": "allmännelig",
    "allmänneligts": "allmännelig",
    "allmännes": "allmän",
    "allmänningar": "allmänning",
    "allmänningarna": "allmänning",
    "allmänningarnas": "allmänning",
    "allmänningars": "allmänning",
    "allmänningen": "allmänning",
    "allmänningens": "allmänning",
    "allmännings": "allmänning",
    "allmännyttiga": "allmännyttig",
    "allmännyttigare": "allmännyttig",
    "allmännyttigares": "allmännyttig",
    "allmännyttigas": "allmännyttig",
    "allmännyttigast": "allmännyttig",
    "allmännyttigaste": "allmännyttig",
    "allmännyttigastes": "allmännyttig",
    "allmännyttigasts": "allmännyttig",
    "allmännyttige": "allmännyttig",
    "allmännyttiges": "allmännyttig",
    "allmännyttigheten": "allmännyttighet",
    "allmännyttighetens": "allmännyttighet",
    "allmännyttighets": "allmännyttighet",
    "allmännyttigs": "allmännyttig",
    "allmännyttigt": "allmännyttig",
    "allmännyttigts": "allmännyttig",
    "allmänpolitiska": "allmänpolitisk",
    "allmänpolitiskare": "allmänpolitisk",
    "allmänpolitiskares": "allmänpolitisk",
    "allmänpolitiskas": "allmänpolitisk",
    "allmänpolitiskast": "allmänpolitisk",
    "allmänpolitiskaste": "allmänpolitisk",
    "allmänpolitiskastes": "allmänpolitisk",
    "allmänpolitiskasts": "allmänpolitisk",
    "allmänpolitiske": "allmänpolitisk",
    "allmänpolitiskes": "allmänpolitisk",
    "allmänpolitisks": "allmänpolitisk",
    "allmänpolitiskt": "allmänpolitisk",
    "allmänpolitiskts": "allmänpolitisk",
    "allmänpraktikern": "allmänpraktiker",
    "allmänpraktikerna": "allmänpraktiker",
    "allmänpraktikernas": "allmänpraktiker",
    "allmänpraktikerns": "allmänpraktiker",
    "allmänpraktikers": "allmänpraktiker",
    "allmänpreventionen": "allmänprevention",
    "allmänpreventionens": "allmänprevention",
    "allmänpreventioner": "allmänprevention",
    "allmänpreventionerna": "allmänprevention",
    "allmänpreventionernas": "allmänprevention",
    "allmänpreventioners": "allmänprevention",
    "allmänpreventions": "allmänprevention",
    "allmänpreventiva": "allmänpreventiv",
    "allmänpreventivare": "allmänpreventiv",
    "allmänpreventivares": "allmänpreventiv",
    "allmänpreventivas": "allmänpreventiv",
    "allmänpreventivast": "allmänpreventiv",
    "allmänpreventivaste": "allmänpreventiv",
    "allmänpreventivastes": "allmänpreventiv",
    "allmänpreventivasts": "allmänpreventiv",
    "allmänpreventive": "allmänpreventiv",
    "allmänpreventives": "allmänpreventiv",
    "allmänpreventivs": "allmänpreventiv",
    "allmänpreventivt": "allmänpreventiv",
    "allmänpreventivts": "allmänpreventiv",
    "allmäns": "allmän",
    "allmänt": "allmän",
    "allmäntjänstgöringar": "allmäntjänstgöring",
    "allmäntjänstgöringarna": "allmäntjänstgöring",
    "allmäntjänstgöringarnas": "allmäntjänstgöring",
    "allmäntjänstgöringars": "allmäntjänstgöring",
    "allmäntjänstgöringen": "allmäntjänstgöring",
    "allmäntjänstgöringens": "allmäntjänstgöring",
    "allmäntjänstgörings": "allmäntjänstgöring",
    "allmänts": "allmän",
    "allnationella": "allnationell",
    "allnationellare": "allnationell",
    "allnationellares": "allnationell",
    "allnationellas": "allnationell",
    "allnationellast": "allnationell",
    "allnationellaste": "allnationell",
    "allnationellastes": "allnationell",
    "allnationellasts": "allnationell",
    "allnationelle": "allnationell",
    "allnationelles": "allnationell",
    "allnationells": "allnationell",
    "allnationellt": "allnationell",
    "allnationellts": "allnationell",
    "alloder": "allod",
    "alloderna": "allod",
    "allodernas": "allod",
    "alloders": "allod",
    "allodet": "allod",
    "allodets": "allod",
    "allodiala": "allodial",
    "allodialare": "allodial",
    "allodialares": "allodial",
    "allodialas": "allodial",
    "allodialast": "allodial",
    "allodialaste": "allodial",
    "allodialastes": "allodial",
    "allodialasts": "allodial",
    "allodiale": "allodial",
    "allodiales": "allodial",
    "allodials": "allodial",
    "allodialt": "allodial",
    "allodialts": "allodial",
    "allodie": "allodium",
    "allodier": "allodium",
    "allodierna": "allodium",
    "allodiernas": "allodium",
    "allodiers": "allodium",
    "allodiet": "allodium",
    "allodiets": "allodium",
    "allodiums": "allodium",
    "allods": "allod",
    "allofonen": "allofon",
    "allofonens": "allofon",
    "allofoner": "allofon",
    "allofonerna": "allofon",
    "allofonernas": "allofon",
    "allofoners": "allofon",
    "allofons": "allofon",
    "allografen": "allograf",
    "allografens": "allograf",
    "allografer": "allograf",
    "allograferna": "allograf",
    "allografernas": "allograf",
    "allografers": "allograf",
    "allografs": "allograf",
    "allokerad": "allokera",
    "allokerade": "allokera",
    "allokerades": "allokera",
    "allokerads": "allokera",
    "allokerande": "allokera",
    "allokeranden": "allokerande",
    "allokerandena": "allokerande",
    "allokerandenas": "allokerande",
    "allokerandens": "allokerande",
    "allokerandes": "allokerande",
    "allokerandet": "allokerande",
    "allokerandets": "allokerande",
    "allokerar": "allokera",
    "allokeras": "allokera",
    "allokerat": "allokera",
    "allokerats": "allokera",
    "allokerbara": "allokerbar",
    "allokerbarare": "allokerbar",
    "allokerbarares": "allokerbar",
    "allokerbaras": "allokerbar",
    "allokerbarast": "allokerbar",
    "allokerbaraste": "allokerbar",
    "allokerbarastes": "allokerbar",
    "allokerbarasts": "allokerbar",
    "allokerbare": "allokerbar",
    "allokerbares": "allokerbar",
    "allokerbarheten": "allokerbarhet",
    "allokerbarhetens": "allokerbarhet",
    "allokerbarhets": "allokerbarhet",
    "allokerbars": "allokerbar",
    "allokerbart": "allokerbar",
    "allokerbarts": "allokerbar",
    "allokeringar": "allokering",
    "allokeringarna": "allokering",
    "allokeringarnas": "allokering",
    "allokeringars": "allokering",
    "allokeringen": "allokering",
    "allokeringens": "allokering",
    "allokerings": "allokering",
    "alloktona": "allokton",
    "alloktonare": "allokton",
    "alloktonares": "allokton",
    "alloktonas": "allokton",
    "alloktonast": "allokton",
    "alloktonaste": "allokton",
    "alloktonastes": "allokton",
    "alloktonasts": "allokton",
    "alloktone": "allokton",
    "alloktones": "allokton",
    "alloktons": "allokton",
    "alloktont": "allokton",
    "alloktonts": "allokton",
    "allokutionen": "allokution",
    "allokutionens": "allokution",
    "allokutioner": "allokution",
    "allokutionerna": "allokution",
    "allokutionernas": "allokution",
    "allokutioners": "allokution",
    "allokutions": "allokution",
    "allomorfa": "allomorf",
    "allomorfare": "allomorf",
    "allomorfares": "allomorf",
    "allomorfas": "allomorf",
    "allomorfast": "allomorf",
    "allomorfaste": "allomorf",
    "allomorfastes": "allomorf",
    "allomorfasts": "allomorf",
    "allomorfe": "allomorf",
    "allomorfen": "allomorf",
    "allomorfens": "allomorf",
    "allomorfer": "allomorf",
    "allomorferna": "allomorf",
    "allomorfernas": "allomorf",
    "allomorfers": "allomorf",
    "allomorfes": "allomorf",
    "allomorfs": "allomorf",
    "allomorft": "allomorf",
    "allomorfts": "allomorf",
    "allongeperuken": "allongeperuk",
    "allongeperukens": "allongeperuk",
    "allongeperuker": "allongeperuk",
    "allongeperukerna": "allongeperuk",
    "allongeperukernas": "allongeperuk",
    "allongeperukers": "allongeperuk",
    "allongeperuks": "allongeperuk",
    "allopatien": "allopati",
    "allopatiens": "allopati",
    "allopatin": "allopati",
    "allopatins": "allopati",
    "allopatis": "allopati",
    "allor": "alla",
    "allorna": "alla",
    "allornas": "alla",
    "allors": "alla",
    "allriskförsäkringar": "allriskförsäkring",
    "allriskförsäkringarna": "allriskförsäkring",
    "allriskförsäkringarnas": "allriskförsäkring",
    "allriskförsäkringars": "allriskförsäkring",
    "allriskförsäkringen": "allriskförsäkring",
    "allriskförsäkringens": "allriskförsäkring",
    "allriskförsäkrings": "allriskförsäkring",
    "allroundsågar": "allroundsåg",
    "allroundsågarna": "allroundsåg",
    "allroundsågarnas": "allroundsåg",
    "allroundsågars": "allroundsåg",
    "allroundsågen": "allroundsåg",
    "allroundsågens": "allroundsåg",
    "allroundsågs": "allroundsåg",
    "allrummen": "allrum",
    "allrummens": "allrum",
    "allrummet": "allrum",
    "allrummets": "allrum",
    "allrums": "allrum",
    "alls": "alla",
    "allshärjartingen": "allshärjarting",
    "allshärjartingens": "allshärjarting",
    "allshärjartinget": "allshärjarting",
    "allshärjartingets": "allshärjarting",
    "allshärjartings": "allshärjarting",
    "allsidiga": "allsidig",
    "allsidigare": "allsidig",
    "allsidigares": "allsidig",
    "allsidigas": "allsidig",
    "allsidigast": "allsidig",
    "allsidigaste": "allsidig",
    "allsidigastes": "allsidig",
    "allsidigasts": "allsidig",
    "allsidige": "allsidig",
    "allsidiges": "allsidig",
    "allsidigheten": "allsidighet",
    "allsidighetens": "allsidighet",
    "allsidighets": "allsidighet",
    "allsidigs": "allsidig",
    "allsidigt": "allsidig",
    "allsidigts": "allsidig",
    "allsmäktiga": "allsmäktig",
    "allsmäktigare": "allsmäktig",
    "allsmäktigares": "allsmäktig",
    "allsmäktigas": "allsmäktig",
    "allsmäktigast": "allsmäktig",
    "allsmäktigaste": "allsmäktig",
    "allsmäktigastes": "allsmäktig",
    "allsmäktigasts": "allsmäktig",
    "allsmäktige": "allsmäktig",
    "allsmäktiges": "allsmäktig",
    "allsmäktigheten": "allsmäktighet",
    "allsmäktighetens": "allsmäktighet",
    "allsmäktighets": "allsmäktighet",
    "allsmäktigs": "allsmäktig",
    "allsmäktigt": "allsmäktig",
    "allsmäktigts": "allsmäktig",
    "allströmsapparaten": "allströmsapparat",
    "allströmsapparatens": "allströmsapparat",
    "allströmsapparater": "allströmsapparat",
    "allströmsapparaterna": "allströmsapparat",
    "allströmsapparaternas": "allströmsapparat",
    "allströmsapparaters": "allströmsapparat",
    "allströmsapparats": "allströmsapparat",
    "allsvenska": "allsvensk",
    "allsvenskan": "allsvenska",
    "allsvenskans": "allsvenska",
    "allsvenskare": "allsvensk",
    "allsvenskares": "allsvensk",
    "allsvenskas": "allsvenska",
    "allsvenskast": "allsvensk",
    "allsvenskaste": "allsvensk",
    "allsvenskastes": "allsvensk",
    "allsvenskasts": "allsvensk",
    "allsvenske": "allsvensk",
    "allsvenskes": "allsvensk",
    "allsvenskor": "allsvenska",
    "allsvenskorna": "allsvenska",
    "allsvenskornas": "allsvenska",
    "allsvenskors": "allsvenska",
    "allsvensks": "allsvensk",
    "allsvenskt": "allsvensk",
    "allsvenskts": "allsvensk",
    "allsvåldiga": "allsvåldig",
    "allsvåldigare": "allsvåldig",
    "allsvåldigares": "allsvåldig",
    "allsvåldigas": "allsvåldig",
    "allsvåldigast": "allsvåldig",
    "allsvåldigaste": "allsvåldig",
    "allsvåldigastes": "allsvåldig",
    "allsvåldigasts": "allsvåldig",
    "allsvåldige": "allsvåldig",
    "allsvåldiges": "allsvåldig",
    "allsvåldigheten": "allsvåldighet",
    "allsvåldighetens": "allsvåldighet",
    "allsvåldighets": "allsvåldighet",
    "allsvåldigs": "allsvåldig",
    "allsvåldigt": "allsvåldig",
    "allsvåldigts": "allsvåldig",
    "allsången": "allsång",
    "allsångens": "allsång",
    "allsånger": "allsång",
    "allsångerna": "allsång",
    "allsångernas": "allsång",
    "allsångers": "allsång",
    "allsångs": "allsång",
    "allt": "all",
    "alltet": "allt",
    "alltets": "allt",
    "alltiallon": "alltiallo",
    "alltiallona": "alltiallo",
    "alltiallonas": "alltiallo",
    "alltiallons": "alltiallo",
    "alltiallor": "alltiallo",
    "alltiallorna": "alltiallo",
    "alltiallornas": "alltiallo",
    "alltiallors": "alltiallo",
    "alltiallos": "alltiallo",
    "alltiallot": "alltiallo",
    "alltiallots": "alltiallo",
    "alltihops": "alltihop",
    "alltingen": "allting",
    "alltingens": "allting",
    "alltinget": "allting",
    "alltingets": "allting",
    "alltings": "allting",
    "allts": "allt",
    "alluderad": "alludera",
    "alluderade": "alludera",
    "alluderades": "alludera",
    "alluderads": "alludera",
    "alluderande": "alludera",
    "alluderanden": "alluderande",
    "alluderandena": "alluderande",
    "alluderandenas": "alluderande",
    "alluderandens": "alluderande",
    "alluderandes": "alluderande",
    "alluderandet": "alluderande",
    "alluderandets": "alluderande",
    "alluderar": "alludera",
    "alluderas": "alludera",
    "alluderat": "alludera",
    "alluderats": "alludera",
    "alluderbara": "alluderbar",
    "alluderbarare": "alluderbar",
    "alluderbarares": "alluderbar",
    "alluderbaras": "alluderbar",
    "alluderbarast": "alluderbar",
    "alluderbaraste": "alluderbar",
    "alluderbarastes": "alluderbar",
    "alluderbarasts": "alluderbar",
    "alluderbare": "alluderbar",
    "alluderbares": "alluderbar",
    "alluderbarheten": "alluderbarhet",
    "alluderbarhetens": "alluderbarhet",
    "alluderbarhets": "alluderbarhet",
    "alluderbars": "alluderbar",
    "alluderbart": "alluderbar",
    "alluderbarts": "alluderbar",
    "alluderingar": "alludering",
    "alluderingarna": "alludering",
    "alluderingarnas": "alludering",
    "alluderingars": "alludering",
    "alluderingen": "alludering",
    "alluderingens": "alludering",
    "alluderings": "alludering",
    "allusionen": "allusion",
    "allusionens": "allusion",
    "allusioner": "allusion",
    "allusionerna": "allusion",
    "allusionernas": "allusion",
    "allusioners": "allusion",
    "allusions": "allusion",
    "alluviala": "alluvial",
    "alluvialare": "alluvial",
    "alluvialares": "alluvial",
    "alluvialas": "alluvial",
    "alluvialast": "alluvial",
    "alluvialaste": "alluvial",
    "alluvialastes": "alluvial",
    "alluvialasts": "alluvial",
    "alluviale": "alluvial",
    "alluviales": "alluvial",
    "alluvials": "alluvial",
    "alluvialt": "alluvial",
    "alluvialts": "alluvial",
    "alluvier": "alluvium",
    "alluvierna": "alluvium",
    "alluviernas": "alluvium",
    "alluviers": "alluvium",
    "alluviet": "alluvium",
    "alluviets": "alluvium",
    "alluviumet": "alluvium",
    "alluviumets": "alluvium",
    "alluviums": "alluvium",
    "allvaret": "allvar",
    "allvarets": "allvar",
    "allvarliga": "allvarlig",
    "allvarligare": "allvarlig",
    "allvarligares": "allvarlig",
    "allvarligas": "allvarlig",
    "allvarligast": "allvarlig",
    "allvarligaste": "allvarlig",
    "allvarligastes": "allvarlig",
    "allvarligasts": "allvarlig",
    "allvarlige": "allvarlig",
    "allvarliges": "allvarlig",
    "allvarligheten": "allvarlighet",
    "allvarlighetens": "allvarlighet",
    "allvarlighets": "allvarlighet",
    "allvarligs": "allvarlig",
    "allvarligt": "allvarlig",
    "allvarligts": "allvarlig",
    "allvars": "allvar",
    "allvarsamheten": "allvarsamhet",
    "allvarsamhetens": "allvarsamhet",
    "allvarsamheter": "allvarsamhet",
    "allvarsamheterna": "allvarsamhet",
    "allvarsamheternas": "allvarsamhet",
    "allvarsamheters": "allvarsamhet",
    "allvarsamhets": "allvarsamhet",
    "allvarsamma": "allvarsam",
    "allvarsammare": "allvarsam",
    "allvarsammares": "allvarsam",
    "allvarsammas": "allvarsam",
    "allvarsammast": "allvarsam",
    "allvarsammaste": "allvarsam",
    "allvarsammastes": "allvarsam",
    "allvarsammasts": "allvarsam",
    "allvarsamme": "allvarsam",
    "allvarsammes": "allvarsam",
    "allvarsams": "allvarsam",
    "allvarsamt": "allvarsam",
    "allvarsamts": "allvarsam",
    "allvarsorden": "allvarsord",
    "allvarsordens": "allvarsord",
    "allvarsordet": "allvarsord",
    "allvarsordets": "allvarsord",
    "allvarsords": "allvarsord",
    "allvarstyngda": "allvarstyngd",
    "allvarstyngdare": "allvarstyngd",
    "allvarstyngdares": "allvarstyngd",
    "allvarstyngdas": "allvarstyngd",
    "allvarstyngdast": "allvarstyngd",
    "allvarstyngdaste": "allvarstyngd",
    "allvarstyngdastes": "allvarstyngd",
    "allvarstyngdasts": "allvarstyngd",
    "allvarstyngde": "allvarstyngd",
    "allvarstyngdes": "allvarstyngd",
    "allvarstyngdheten": "allvarstyngdhet",
    "allvarstyngdhetens": "allvarstyngdhet",
    "allvarstyngdhets": "allvarstyngdhet",
    "allvarstyngds": "allvarstyngd",
    "allvarstyngt": "allvarstyngd",
    "allvarstyngts": "allvarstyngd",
    "allvetar": "allvetare",
    "allvetaren": "allvetare",
    "allvetarens": "allvetare",
    "allvetares": "allvetare",
    "allvetarna": "allvetare",
    "allvetarnas": "allvetare",
    "allvisa": "allvis",
    "allvisare": "allvis",
    "allvisares": "allvis",
    "allvisas": "allvis",
    "allvisast": "allvis",
    "allvisaste": "allvis",
    "allvisastes": "allvis",
    "allvisasts": "allvis",
    "allvise": "allvis",
    "allvises": "allvis",
    "allvisheten": "allvishet",
    "allvishetens": "allvishet",
    "allvishets": "allvishet",
    "allvist": "allvis",
    "allvists": "allvis",
    "allvädersskydden": "allvädersskydd",
    "allvädersskyddens": "allvädersskydd",
    "allvädersskyddet": "allvädersskydd",
    "allvädersskyddets": "allvädersskydd",
    "allvädersskydds": "allvädersskydd",
    "allvädersstöveln": "allvädersstövel",
    "allvädersstövelns": "allvädersstövel",
    "allvädersstövels": "allvädersstövel",
    "allvädersstövlar": "allvädersstövel",
    "allvädersstövlarna": "allvädersstövel",
    "allvädersstövlarnas": "allvädersstövel",
    "allvädersstövlars": "allvädersstövel",
    "allätar": "allätare",
    "allätaren": "allätare",
    "allätarens": "allätare",
    "allätares": "allätare",
    "allätarna": "allätare",
    "allätarnas": "allätare",
    "alléer": "allé",
    "alléerna": "allé",
    "alléernas": "allé",
    "alléers": "allé",
    "allén": "allé",
    "alléns": "allé",
    "allés": "allé",
    "almanack": "almanacka",
    "almanackan": "almanacka",
    "almanackans": "almanacka",
    "almanackas": "almanacka",
    "almanacke": "almanacka",
    "almanacken": "almanack",
    "almanackens": "almanack",
    "almanacker": "almanack",
    "almanackerna": "almanack",
    "almanackernas": "almanack",
    "almanackers": "almanack",
    "almanackor": "almanacka",
    "almanackorna": "almanacka",
    "almanackornas": "almanacka",
    "almanackors": "almanacka",
    "almanacks": "almanacka",
    "almanacksbladen": "almanacksblad",
    "almanacksbladens": "almanacksblad",
    "almanacksbladet": "almanacksblad",
    "almanacksbladets": "almanacksblad",
    "almanacksblads": "almanacksblad",
    "almar": "alm",
    "almarna": "alm",
    "almarnas": "alm",
    "almars": "alm",
    "almen": "alm",
    "almens": "alm",
    "almes": "alme",
    "almet": "alme",
    "almets": "alme",
    "alms": "alm",
    "almsaven": "almsav",
    "almsavens": "almsav",
    "almsavs": "almsav",
    "almsjukan": "almsjuka",
    "almsjukans": "almsjuka",
    "almsjukas": "almsjuka",
    "almsjuke": "almsjuka",
    "almsjuks": "almsjuka",
    "alnar": "aln",
    "alnarna": "aln",
    "alnarnas": "aln",
    "alnars": "aln",
    "alnen": "aln",
    "alnens": "aln",
    "alns": "aln",
    "aloebaserade": "aloebaserad",
    "aloebaserades": "aloebaserad",
    "aloebaserads": "aloebaserad",
    "aloebaserat": "aloebaserad",
    "aloebaserats": "aloebaserad",
    "aloen": "aloe",
    "aloens": "aloe",
    "aloer": "aloe",
    "aloerna": "aloe",
    "aloernas": "aloe",
    "aloers": "aloe",
    "aloes": "aloe",
    "alpack": "alpacka",
    "alpackan": "alpacka",
    "alpackans": "alpacka",
    "alpackas": "alpacka",
    "alpacke": "alpacka",
    "alpackor": "alpacka",
    "alpackorna": "alpacka",
    "alpackornas": "alpacka",
    "alpackors": "alpacka",
    "alpacks": "alpacka",
    "alpen": "alp",
    "alpens": "alp",
    "alper": "alp",
    "alperna": "alp",
    "alpernas": "alp",
    "alpers": "alp",
    "alpgeten": "alpget",
    "alpgetens": "alpget",
    "alpgets": "alpget",
    "alpgetter": "alpget",
    "alpgetterna": "alpget",
    "alpgetternas": "alpget",
    "alpgetters": "alpget",
    "alphornen": "alphorn",
    "alphornens": "alphorn",
    "alphornet": "alphorn",
    "alphornets": "alphorn",
    "alphorns": "alphorn",
    "alpidyllen": "alpidyll",
    "alpidyllens": "alpidyll",
    "alpidyller": "alpidyll",
    "alpidyllerna": "alpidyll",
    "alpidyllernas": "alpidyll",
    "alpidyllers": "alpidyll",
    "alpidylls": "alpidyll",
    "alpina": "alpin",
    "alpinare": "alpin",
    "alpinares": "alpin",
    "alpinas": "alpin",
    "alpinast": "alpin",
    "alpinaste": "alpin",
    "alpinastes": "alpin",
    "alpinasts": "alpin",
    "alpine": "alpin",
    "alpines": "alpin",
    "alpinismen": "alpinism",
    "alpinismens": "alpinism",
    "alpinismer": "alpinism",
    "alpinismerna": "alpinism",
    "alpinismernas": "alpinism",
    "alpinismers": "alpinism",
    "alpinisms": "alpinism",
    "alpinisten": "alpinist",
    "alpinistens": "alpinist",
    "alpinister": "alpinist",
    "alpinisterna": "alpinist",
    "alpinisternas": "alpinist",
    "alpinisters": "alpinist",
    "alpinists": "alpinist",
    "alpins": "alpin",
    "alpinska": "alpinsk",
    "alpinskare": "alpinsk",
    "alpinskares": "alpinsk",
    "alpinskas": "alpinsk",
    "alpinskast": "alpinsk",
    "alpinskaste": "alpinsk",
    "alpinskastes": "alpinsk",
    "alpinskasts": "alpinsk",
    "alpinske": "alpinsk",
    "alpinskes": "alpinsk",
    "alpinsks": "alpinsk",
    "alpinskt": "alpinsk",
    "alpinskts": "alpinsk",
    "alpint": "alpin",
    "alpints": "alpin",
    "alpjägar": "alpjägare",
    "alpjägaren": "alpjägare",
    "alpjägarens": "alpjägare",
    "alpjägares": "alpjägare",
    "alpjägarna": "alpjägare",
    "alpjägarnas": "alpjägare",
    "alprosen": "alpros",
    "alprosens": "alpros",
    "alprosor": "alpros",
    "alprosorna": "alpros",
    "alprosornas": "alpros",
    "alprosors": "alpros",
    "alps": "alp",
    "alpviolen": "alpviol",
    "alpviolens": "alpviol",
    "alpvioler": "alpviol",
    "alpviolerna": "alpviol",
    "alpviolernas": "alpviol",
    "alpviolers": "alpviol",
    "alpviols": "alpviol",
    "alrun": "alruna",
    "alrunan": "alruna",
    "alrunans": "alruna",
    "alrunas": "alruna",
    "alrune": "alruna",
    "alrunor": "alruna",
    "alrunorna": "alruna",
    "alrunornas": "alruna",
    "alrunors": "alruna",
    "alruns": "alruna",
    "als": "al",
    "als-s": "als",
    "alsikeklövern": "alsikeklöver",
    "alsikeklöverns": "alsikeklöver",
    "alsikeklövers": "alsikeklöver",
    "alspånen": "alspån",
    "alspånens": "alspån",
    "alspånet": "alspån",
    "alspånets": "alspån",
    "alspåns": "alspån",
    "alss": "als",
    "alster": "alstra",
    "alsterna": "alster",
    "alsternas": "alster",
    "alsters": "alster",
    "alstrad": "alstra",
    "alstrade": "alstra",
    "alstrades": "alstra",
    "alstrads": "alstra",
    "alstrande": "alstra",
    "alstranden": "alstrande",
    "alstrandena": "alstrande",
    "alstrandenas": "alstrande",
    "alstrandens": "alstrande",
    "alstrandes": "alstrande",
    "alstrandet": "alstrande",
    "alstrandets": "alstrande",
    "alstrar": "alstra",
    "alstras": "alstra",
    "alstrat": "alstra",
    "alstrats": "alstra",
    "alstren": "alster",
    "alstrens": "alster",
    "alstret": "alster",
    "alstrets": "alster",
    "alstringar": "alstring",
    "alstringarna": "alstring",
    "alstringarnas": "alstring",
    "alstringars": "alstring",
    "alstringen": "alstring",
    "alstringens": "alstring",
    "alstrings": "alstring",
    "altandörrar": "altandörr",
    "altandörrarna": "altandörr",
    "altandörrarnas": "altandörr",
    "altandörrars": "altandörr",
    "altandörren": "altandörr",
    "altandörrens": "altandörr",
    "altandörrs": "altandörr",
    "altanen": "altan",
    "altanens": "altan",
    "altaner": "altan",
    "altanerna": "altan",
    "altanernas": "altan",
    "altaners": "altan",
    "altanfäst": "altanfäste",
    "altanfästen": "altanfäste",
    "altanfästena": "altanfäste",
    "altanfästenas": "altanfäste",
    "altanfästens": "altanfäste",
    "altanfästes": "altanfäste",
    "altanfästet": "altanfäste",
    "altanfästets": "altanfäste",
    "altans": "altan",
    "altar": "altare",
    "altarbrunen": "altarbrun",
    "altarbrunens": "altarbrun",
    "altarbrunet": "altarbrun",
    "altarbrunets": "altarbrun",
    "altarbruns": "altarbrun",
    "altaren": "altare",
    "altarens": "altare",
    "altares": "altare",
    "altaret": "altare",
    "altarets": "altare",
    "altargångar": "altargång",
    "altargångarna": "altargång",
    "altargångarnas": "altargång",
    "altargångars": "altargång",
    "altargången": "altargång",
    "altargångens": "altargång",
    "altargångs": "altargång",
    "altarkorsen": "altarkors",
    "altarkorsens": "altarkors",
    "altarkorset": "altarkors",
    "altarkorsets": "altarkors",
    "altarlykt": "altarlykta",
    "altarlyktan": "altarlykta",
    "altarlyktans": "altarlykta",
    "altarlyktas": "altarlykta",
    "altarlykte": "altarlykta",
    "altarlyktor": "altarlykta",
    "altarlyktorna": "altarlykta",
    "altarlyktornas": "altarlykta",
    "altarlyktors": "altarlykta",
    "altarlykts": "altarlykta",
    "altarna": "altare",
    "altarnas": "altare",
    "altarprydnaden": "altarprydnad",
    "altarprydnadens": "altarprydnad",
    "altarprydnader": "altarprydnad",
    "altarprydnaderna": "altarprydnad",
    "altarprydnadernas": "altarprydnad",
    "altarprydnaders": "altarprydnad",
    "altarprydnads": "altarprydnad",
    "altarringar": "altarring",
    "altarringarna": "altarring",
    "altarringarnas": "altarring",
    "altarringars": "altarring",
    "altarringen": "altarring",
    "altarringens": "altarring",
    "altarrings": "altarring",
    "altarrunden": "altarrund",
    "altarrundens": "altarrund",
    "altarrunder": "altarrund",
    "altarrunderna": "altarrund",
    "altarrundernas": "altarrund",
    "altarrunders": "altarrund",
    "altarrunds": "altarrund",
    "altars": "alt",
    "altarskåpen": "altarskåp",
    "altarskåpens": "altarskåp",
    "altarskåpet": "altarskåp",
    "altarskåpets": "altarskåp",
    "altarskåps": "altarskåp",
    "altartavel": "altartavla",
    "altartavlan": "altartavla",
    "altartavlans": "altartavla",
    "altartavlas": "altartavla",
    "altartavle": "altartavla",
    "altartavlor": "altartavla",
    "altartavlorna": "altartavla",
    "altartavlornas": "altartavla",
    "altartavlors": "altartavla",
    "altartjänsten": "altartjänst",
    "altartjänstens": "altartjänst",
    "altartjänster": "altartjänst",
    "altartjänsterna": "altartjänst",
    "altartjänsternas": "altartjänst",
    "altartjänsters": "altartjänst",
    "altartjänsts": "altartjänst",
    "alte": "altea",
    "altean": "altea",
    "alteans": "altea",
    "alteas": "altea",
    "alteasirapen": "alteasirap",
    "alteasirapens": "alteasirap",
    "alteasiraps": "alteasirap",
    "altee": "altea",
    "alten": "alt",
    "altens": "alt",
    "alteor": "altea",
    "alteorna": "altea",
    "alteornas": "altea",
    "alteors": "altea",
    "alterationen": "alteration",
    "alterationens": "alteration",
    "alterationer": "alteration",
    "alterationerna": "alteration",
    "alterationernas": "alteration",
    "alterationers": "alteration",
    "alterations": "alteration",
    "altererade": "altererad",
    "altererades": "altererad",
    "altererads": "altererad",
    "altererat": "altererad",
    "altererats": "altererad",
    "alternativa": "alternativ",
    "alternativare": "alternativ",
    "alternativares": "alternativ",
    "alternativas": "alternativ",
    "alternativast": "alternativ",
    "alternativaste": "alternativ",
    "alternativastes": "alternativ",
    "alternativasts": "alternativ",
    "alternative": "alternativ",
    "alternativen": "alternativ",
    "alternativens": "alternativ",
    "alternatives": "alternativ",
    "alternativet": "alternativ",
    "alternativets": "alternativ",
    "alternativfrågan": "alternativfråga",
    "alternativfrågans": "alternativfråga",
    "alternativfrågas": "alternativfråga",
    "alternativfråge": "alternativfråga",
    "alternativfrågor": "alternativfråga",
    "alternativfrågorna": "alternativfråga",
    "alternativfrågornas": "alternativfråga",
    "alternativfrågors": "alternativfråga",
    "alternativkursen": "alternativkurs",
    "alternativkursens": "alternativkurs",
    "alternativkurser": "alternativkurs",
    "alternativkurserna": "alternativkurs",
    "alternativkursernas": "alternativkurs",
    "alternativkursers": "alternativkurs",
    "alternativs": "alternativ",
    "alternativt": "alternativ",
    "alternativts": "alternativ",
    "alternatvinkeln": "alternatvinkel",
    "alternatvinkelns": "alternatvinkel",
    "alternatvinkels": "alternatvinkel",
    "alternatvinklar": "alternatvinkel",
    "alternatvinklarna": "alternatvinkel",
    "alternatvinklarnas": "alternatvinkel",
    "alternatvinklars": "alternatvinkel",
    "alternerad": "alternera",
    "alternerade": "alternera",
    "alternerades": "alternera",
    "alternerads": "alternera",
    "alternerande": "alternera",
    "alterneranden": "alternerande",
    "alternerandena": "alternerande",
    "alternerandenas": "alternerande",
    "alternerandens": "alternerande",
    "alternerandes": "alternerande",
    "alternerandet": "alternerande",
    "alternerandets": "alternerande",
    "alternerar": "alternera",
    "alterneras": "alternera",
    "alternerat": "alternera",
    "alternerats": "alternera",
    "alternerbara": "alternerbar",
    "alternerbarare": "alternerbar",
    "alternerbarares": "alternerbar",
    "alternerbaras": "alternerbar",
    "alternerbarast": "alternerbar",
    "alternerbaraste": "alternerbar",
    "alternerbarastes": "alternerbar",
    "alternerbarasts": "alternerbar",
    "alternerbare": "alternerbar",
    "alternerbares": "alternerbar",
    "alternerbarheten": "alternerbarhet",
    "alternerbarhetens": "alternerbarhet",
    "alternerbarhets": "alternerbarhet",
    "alternerbars": "alternerbar",
    "alternerbart": "alternerbar",
    "alternerbarts": "alternerbar",
    "alterneringar": "alternering",
    "alterneringarna": "alternering",
    "alterneringarnas": "alternering",
    "alterneringars": "alternering",
    "alterneringen": "alternering",
    "alterneringens": "alternering",
    "alternerings": "alternering",
    "altes": "altea",
    "altfiolen": "altfiol",
    "altfiolens": "altfiol",
    "altfioler": "altfiol",
    "altfiolerna": "altfiol",
    "altfiolernas": "altfiol",
    "altfiolers": "altfiol",
    "altfiols": "altfiol",
    "altit": "altita",
    "altitan": "altita",
    "altitans": "altita",
    "altitas": "altita",
    "altite": "altita",
    "altitor": "altita",
    "altitorna": "altita",
    "altitornas": "altita",
    "altitors": "altita",
    "altits": "altita",
    "altituden": "altitud",
    "altitudens": "altitud",
    "altituder": "altitud",
    "altituderna": "altitud",
    "altitudernas": "altitud",
    "altituders": "altitud",
    "altituds": "altitud",
    "altruismen": "altruism",
    "altruismens": "altruism",
    "altruismer": "altruism",
    "altruismerna": "altruism",
    "altruismernas": "altruism",
    "altruismers": "altruism",
    "altruisms": "altruism",
    "altruisten": "altruist",
    "altruistens": "altruist",
    "altruister": "altruist",
    "altruisterna": "altruist",
    "altruisternas": "altruist",
    "altruisters": "altruist",
    "altruistiska": "altruistisk",
    "altruistiskare": "altruistisk",
    "altruistiskares": "altruistisk",
    "altruistiskas": "altruistisk",
    "altruistiskast": "altruistisk",
    "altruistiskaste": "altruistisk",
    "altruistiskastes": "altruistisk",
    "altruistiskasts": "altruistisk",
    "altruistiske": "altruistisk",
    "altruistiskes": "altruistisk",
    "altruistisks": "altruistisk",
    "altruistiskt": "altruistisk",
    "altruistiskts": "altruistisk",
    "altruists": "altruist",
    "alts": "alt",
    "altstämman": "altstämma",
    "altstämmans": "altstämma",
    "altstämmas": "altstämma",
    "altstämme": "altstämma",
    "altstämmo": "altstämma",
    "altstämmor": "altstämma",
    "altstämmorna": "altstämma",
    "altstämmornas": "altstämma",
    "altstämmors": "altstämma",
    "altviolinen": "altviolin",
    "altviolinens": "altviolin",
    "altvioliner": "altviolin",
    "altviolinerna": "altviolin",
    "altviolinernas": "altviolin",
    "altvioliners": "altviolin",
    "altviolins": "altviolin",
    "aluminerad": "aluminera",
    "aluminerade": "aluminera",
    "aluminerades": "aluminera",
    "aluminerads": "aluminera",
    "aluminerande": "aluminera",
    "alumineranden": "aluminerande",
    "aluminerandena": "aluminerande",
    "aluminerandenas": "aluminerande",
    "aluminerandens": "aluminerande",
    "aluminerandes": "aluminerande",
    "aluminerandet": "aluminerande",
    "aluminerandets": "aluminerande",
    "aluminerar": "aluminera",
    "alumineras": "aluminera",
    "aluminerat": "aluminera",
    "aluminerats": "aluminera",
    "aluminerbara": "aluminerbar",
    "aluminerbarare": "aluminerbar",
    "aluminerbarares": "aluminerbar",
    "aluminerbaras": "aluminerbar",
    "aluminerbarast": "aluminerbar",
    "aluminerbaraste": "aluminerbar",
    "aluminerbarastes": "aluminerbar",
    "aluminerbarasts": "aluminerbar",
    "aluminerbare": "aluminerbar",
    "aluminerbares": "aluminerbar",
    "aluminerbarheten": "aluminerbarhet",
    "aluminerbarhetens": "aluminerbarhet",
    "aluminerbarhets": "aluminerbarhet",
    "aluminerbars": "aluminerbar",
    "aluminerbart": "aluminerbar",
    "aluminerbarts": "aluminerbar",
    "alumineringar": "aluminering",
    "alumineringarna": "aluminering",
    "alumineringarnas": "aluminering",
    "alumineringars": "aluminering",
    "alumineringen": "aluminering",
    "alumineringens": "aluminering",
    "aluminerings": "aluminering",
    "aluminiet": "aluminium",
    "aluminiets": "aluminium",
    "aluminiumet": "aluminium",
    "aluminiumets": "aluminium",
    "aluminiumfabriken": "aluminiumfabrik",
    "aluminiumfabrikens": "aluminiumfabrik",
    "aluminiumfabriker": "aluminiumfabrik",
    "aluminiumfabrikerna": "aluminiumfabrik",
    "aluminiumfabrikernas": "aluminiumfabrik",
    "aluminiumfabrikers": "aluminiumfabrik",
    "aluminiumfabriks": "aluminiumfabrik",
    "aluminiumjonen": "aluminiumjon",
    "aluminiumjonens": "aluminiumjon",
    "aluminiumjoner": "aluminiumjon",
    "aluminiumjonerna": "aluminiumjon",
    "aluminiumjonernas": "aluminiumjon",
    "aluminiumjoners": "aluminiumjon",
    "aluminiumjons": "aluminiumjon",
    "aluminiumlinjalen": "aluminiumlinjal",
    "aluminiumlinjalens": "aluminiumlinjal",
    "aluminiumlinjaler": "aluminiumlinjal",
    "aluminiumlinjalerna": "aluminiumlinjal",
    "aluminiumlinjalernas": "aluminiumlinjal",
    "aluminiumlinjalers": "aluminiumlinjal",
    "aluminiumlinjals": "aluminiumlinjal",
    "aluminiumnäten": "aluminiumnät",
    "aluminiumnätens": "aluminiumnät",
    "aluminiumnätet": "aluminiumnät",
    "aluminiumnätets": "aluminiumnät",
    "aluminiumnäts": "aluminiumnät",
    "aluminiumpulverna": "aluminiumpulver",
    "aluminiumpulvernas": "aluminiumpulver",
    "aluminiumpulvers": "aluminiumpulver",
    "aluminiumpulvren": "aluminiumpulver",
    "aluminiumpulvrens": "aluminiumpulver",
    "aluminiumpulvret": "aluminiumpulver",
    "aluminiumpulvrets": "aluminiumpulver",
    "aluminiums": "aluminium",
    "aluminiumsmältverken": "aluminiumsmältverk",
    "aluminiumsmältverkens": "aluminiumsmältverk",
    "aluminiumsmältverket": "aluminiumsmältverk",
    "aluminiumsmältverkets": "aluminiumsmältverk",
    "aluminiumsmältverks": "aluminiumsmältverk",
    "alumnen": "alumn",
    "alumnens": "alumn",
    "alumner": "alumn",
    "alumnerna": "alumn",
    "alumnernas": "alumn",
    "alumners": "alumn",
    "alumns": "alumn",
    "alunen": "alun",
    "alunens": "alun",
    "alunet": "alun",
    "alunets": "alun",
    "aluniten": "alunit",
    "alunitens": "alunit",
    "alunits": "alunit",
    "aluns": "alun",
    "alunskiffern": "alunskiffer",
    "alunskifferns": "alunskiffer",
    "alunskiffers": "alunskiffer",
    "alunskiffrar": "alunskiffer",
    "alunskiffrarna": "alunskiffer",
    "alunskiffrarnas": "alunskiffer",
    "alunskiffrars": "alunskiffer",
    "alvaren": "alvar",
    "alvarens": "alvar",
    "alvaret": "alvar",
    "alvarets": "alvar",
    "alvars": "alvar",
    "alvarsmarken": "alvarsmark",
    "alvarsmarkens": "alvarsmark",
    "alvarsmarker": "alvarsmark",
    "alvarsmarkerna": "alvarsmark",
    "alvarsmarkernas": "alvarsmark",
    "alvarsmarkers": "alvarsmark",
    "alvarsmarks": "alvarsmark",
    "alven": "alv",
    "alvens": "alv",
    "alveolara": "alveolar",
    "alveolarare": "alveolar",
    "alveolarares": "alveolar",
    "alveolaras": "alveolar",
    "alveolarast": "alveolar",
    "alveolaraste": "alveolar",
    "alveolarastes": "alveolar",
    "alveolarasts": "alveolar",
    "alveolare": "alveolar",
    "alveolaren": "alveolar",
    "alveolarens": "alveolar",
    "alveolarer": "alveolar",
    "alveolarerna": "alveolar",
    "alveolarernas": "alveolar",
    "alveolarers": "alveolar",
    "alveolares": "alveolar",
    "alveolars": "alveolar",
    "alveolart": "alveolar",
    "alveolarts": "alveolar",
    "alveolen": "alveol",
    "alveolens": "alveol",
    "alveoler": "alveol",
    "alveolerna": "alveol",
    "alveolernas": "alveol",
    "alveolers": "alveol",
    "alveols": "alveol",
    "alver": "alv",
    "alverna": "alv",
    "alvernas": "alv",
    "alvers": "alv",
    "alvluckrad": "alvluckra",
    "alvluckrade": "alvluckra",
    "alvluckrades": "alvluckra",
    "alvluckrads": "alvluckra",
    "alvluckrande": "alvluckra",
    "alvluckranden": "alvluckrande",
    "alvluckrandena": "alvluckrande",
    "alvluckrandenas": "alvluckrande",
    "alvluckrandens": "alvluckrande",
    "alvluckrandes": "alvluckrande",
    "alvluckrandet": "alvluckrande",
    "alvluckrandets": "alvluckrande",
    "alvluckrar": "alvluckra",
    "alvluckras": "alvluckra",
    "alvluckrat": "alvluckra",
    "alvluckrats": "alvluckra",
    "alvplogar": "alvplog",
    "alvplogarna": "alvplog",
    "alvplogarnas": "alvplog",
    "alvplogars": "alvplog",
    "alvplogen": "alvplog",
    "alvplogens": "alvplog",
    "alvplogs": "alvplog",
    "alvs": "alv",
    "am": "amma",
    "amalgamen": "amalgam",
    "amalgamens": "amalgam",
    "amalgamer": "amalgam",
    "amalgamerad": "amalgamera",
    "amalgamerade": "amalgamera",
    "amalgamerades": "amalgamera",
    "amalgamerads": "amalgamera",
    "amalgamerande": "amalgamera",
    "amalgameranden": "amalgamerande",
    "amalgamerandena": "amalgamerande",
    "amalgamerandenas": "amalgamerande",
    "amalgamerandens": "amalgamerande",
    "amalgamerandes": "amalgamerande",
    "amalgamerandet": "amalgamerande",
    "amalgamerandets": "amalgamerande",
    "amalgamerar": "amalgamera",
    "amalgameras": "amalgamera",
    "amalgamerat": "amalgamera",
    "amalgamerats": "amalgamera",
    "amalgamerbara": "amalgamerbar",
    "amalgamerbarare": "amalgamerbar",
    "amalgamerbarares": "amalgamerbar",
    "amalgamerbaras": "amalgamerbar",
    "amalgamerbarast": "amalgamerbar",
    "amalgamerbaraste": "amalgamerbar",
    "amalgamerbarastes": "amalgamerbar",
    "amalgamerbarasts": "amalgamerbar",
    "amalgamerbare": "amalgamerbar",
    "amalgamerbares": "amalgamerbar",
    "amalgamerbarheten": "amalgamerbarhet",
    "amalgamerbarhetens": "amalgamerbarhet",
    "amalgamerbarhets": "amalgamerbarhet",
    "amalgamerbars": "amalgamerbar",
    "amalgamerbart": "amalgamerbar",
    "amalgamerbarts": "amalgamerbar",
    "amalgameringar": "amalgamering",
    "amalgameringarna": "amalgamering",
    "amalgameringarnas": "amalgamering",
    "amalgameringars": "amalgamering",
    "amalgameringen": "amalgamering",
    "amalgameringens": "amalgamering",
    "amalgamerings": "amalgamering",
    "amalgamerna": "amalgam",
    "amalgamernas": "amalgam",
    "amalgamers": "amalgam",
    "amalgamet": "amalgam",
    "amalgamets": "amalgam",
    "amalgams": "amalgam",
    "amanuensen": "amanuens",
    "amanuensens": "amanuens",
    "amanuenser": "amanuens",
    "amanuenserna": "amanuens",
    "amanuensernas": "amanuens",
    "amanuensers": "amanuens",
    "amaranten": "amarant",
    "amarantens": "amarant",
    "amaranter": "amarant",
    "amaranterna": "amarant",
    "amaranternas": "amarant",
    "amaranters": "amarant",
    "amarants": "amarant",
    "amaryller": "amaryllis",
    "amaryllerna": "amaryllis",
    "amaryllernas": "amaryllis",
    "amaryllers": "amaryllis",
    "amaryllisar": "amaryllis",
    "amaryllisarna": "amaryllis",
    "amaryllisarnas": "amaryllis",
    "amaryllisars": "amaryllis",
    "amaryllisen": "amaryllis",
    "amaryllisens": "amaryllis",
    "amasonen": "amason",
    "amasonens": "amason",
    "amasoner": "amason",
    "amasonerna": "amason",
    "amasonernas": "amason",
    "amasoners": "amason",
    "amasons": "amason",
    "amatörbestämmelsen": "amatörbestämmelse",
    "amatörbestämmelsens": "amatörbestämmelse",
    "amatörbestämmelser": "amatörbestämmelse",
    "amatörbestämmelserna": "amatörbestämmelse",
    "amatörbestämmelsernas": "amatörbestämmelse",
    "amatörbestämmelsers": "amatörbestämmelse",
    "amatörbestämmelses": "amatörbestämmelse",
    "amatören": "amatör",
    "amatörens": "amatör",
    "amatörer": "amatör",
    "amatörerna": "amatör",
    "amatörernas": "amatör",
    "amatörers": "amatör",
    "amatörforskar": "amatörforskare",
    "amatörforskaren": "amatörforskare",
    "amatörforskarens": "amatörforskare",
    "amatörforskares": "amatörforskare",
    "amatörforskarna": "amatörforskare",
    "amatörforskarnas": "amatörforskare",
    "amatöridrotten": "amatöridrott",
    "amatöridrottens": "amatöridrott",
    "amatöridrotter": "amatöridrott",
    "amatöridrotterna": "amatöridrott",
    "amatöridrotternas": "amatöridrott",
    "amatöridrotters": "amatöridrott",
    "amatöridrotts": "amatöridrott",
    "amatörismen": "amatörism",
    "amatörismens": "amatörism",
    "amatörismer": "amatörism",
    "amatörismerna": "amatörism",
    "amatörismernas": "amatörism",
    "amatörismers": "amatörism",
    "amatörisms": "amatörism",
    "amatöristiska": "amatöristisk",
    "amatöristiskas": "amatöristisk",
    "amatöristiske": "amatöristisk",
    "amatöristiskes": "amatöristisk",
    "amatöristisks": "amatöristisk",
    "amatöristiskt": "amatöristisk",
    "amatöristiskts": "amatöristisk",
    "amatörmässiga": "amatörmässig",
    "amatörmässigare": "amatörmässig",
    "amatörmässigares": "amatörmässig",
    "amatörmässigas": "amatörmässig",
    "amatörmässigast": "amatörmässig",
    "amatörmässigaste": "amatörmässig",
    "amatörmässigastes": "amatörmässig",
    "amatörmässigasts": "amatörmässig",
    "amatörmässige": "amatörmässig",
    "amatörmässiges": "amatörmässig",
    "amatörmässigheten": "amatörmässighet",
    "amatörmässighetens": "amatörmässighet",
    "amatörmässighets": "amatörmässighet",
    "amatörmässigs": "amatörmässig",
    "amatörmässigt": "amatörmässig",
    "amatörmässigts": "amatörmässig",
    "amatörregeln": "amatörregel",
    "amatörregelns": "amatörregel",
    "amatörregels": "amatörregel",
    "amatörregler": "amatörregel",
    "amatörreglerna": "amatörregel",
    "amatörreglernas": "amatörregel",
    "amatörreglers": "amatörregel",
    "amatörs": "amatör",
    "amatörsändar": "amatörsändare",
    "amatörsändaren": "amatörsändare",
    "amatörsändarens": "amatörsändare",
    "amatörsändares": "amatörsändare",
    "amatörsändarna": "amatörsändare",
    "amatörsändarnas": "amatörsändare",
    "amatörteleskopen": "amatörteleskop",
    "amatörteleskopens": "amatörteleskop",
    "amatörteleskopet": "amatörteleskop",
    "amatörteleskopets": "amatörteleskop",
    "amatörteleskops": "amatörteleskop",
    "amazonen": "amazon",
    "amazonens": "amazon",
    "amazoner": "amazon",
    "amazonerna": "amazon",
    "amazonernas": "amazon",
    "amazoners": "amazon",
    "amazons": "amazon",
    "ambassaden": "ambassad",
    "ambassadens": "ambassad",
    "ambassader": "ambassad",
    "ambassaderna": "ambassad",
    "ambassadernas": "ambassad",
    "ambassaders": "ambassad",
    "ambassadråden": "ambassadråd",
    "ambassadrådens": "ambassadråd",
    "ambassadrådet": "ambassadråd",
    "ambassadrådets": "ambassadråd",
    "ambassadråds": "ambassadråd",
    "ambassads": "ambassad",
    "ambassadören": "ambassadör",
    "ambassadörens": "ambassadör",
    "ambassadörer": "ambassadör",
    "ambassadörerna": "ambassadör",
    "ambassadörernas": "ambassadör",
    "ambassadörers": "ambassadör",
    "ambassadörn": "ambassadör",
    "ambassadörns": "ambassadör",
    "ambassadörs": "ambassadör",
    "ambassadörsmässiga": "ambassadörsmässig",
    "ambassadörsmässigare": "ambassadörsmässig",
    "ambassadörsmässigares": "ambassadörsmässig",
    "ambassadörsmässigas": "ambassadörsmässig",
    "ambassadörsmässigast": "ambassadörsmässig",
    "ambassadörsmässigaste": "ambassadörsmässig",
    "ambassadörsmässigastes": "ambassadörsmässig",
    "ambassadörsmässigasts": "ambassadörsmässig",
    "ambassadörsmässige": "ambassadörsmässig",
    "ambassadörsmässiges": "ambassadörsmässig",
    "ambassadörsmässigs": "ambassadörsmässig",
    "ambassadörsmässigt": "ambassadörsmässig",
    "ambassadörsmässigts": "ambassadörsmässig",
    "ambidexteritets": "ambidexteritet",
    "ambidexters": "ambidexter",
    "ambidextert": "ambidexter",
    "ambidexterts": "ambidexter",
    "ambidextra": "ambidexter",
    "ambidextrare": "ambidexter",
    "ambidextrares": "ambidexter",
    "ambidextras": "ambidexter",
    "ambidextrast": "ambidexter",
    "ambidextraste": "ambidexter",
    "ambidextrastes": "ambidexter",
    "ambidextrasts": "ambidexter",
    "ambidextre": "ambidexter",
    "ambidextres": "ambidexter",
    "ambidextrien": "ambidextri",
    "ambidextriens": "ambidextri",
    "ambidextrin": "ambidextri",
    "ambidextrins": "ambidextri",
    "ambidextris": "ambidextri",
    "ambiguiteten": "ambiguitet",
    "ambiguitetens": "ambiguitet",
    "ambiguiteter": "ambiguitet",
    "ambiguiteterna": "ambiguitet",
    "ambiguiteternas": "ambiguitet",
    "ambiguiteters": "ambiguitet",
    "ambiguitets": "ambiguitet",
    "ambiofonien": "ambiofoni",
    "ambiofoniens": "ambiofoni",
    "ambiofonin": "ambiofoni",
    "ambiofonins": "ambiofoni",
    "ambiofonis": "ambiofoni",
    "ambitionen": "ambition",
    "ambitionens": "ambition",
    "ambitioner": "ambition",
    "ambitionerna": "ambition",
    "ambitionernas": "ambition",
    "ambitioners": "ambition",
    "ambitions": "ambition",
    "ambitionssaken": "ambitionssak",
    "ambitionssakens": "ambitionssak",
    "ambitionssaker": "ambitionssak",
    "ambitionssakerna": "ambitionssak",
    "ambitionssakernas": "ambitionssak",
    "ambitionssakers": "ambitionssak",
    "ambitionssaks": "ambitionssak",
    "ambitiösa": "ambitiös",
    "ambitiösare": "ambitiös",
    "ambitiösares": "ambitiös",
    "ambitiösas": "ambitiös",
    "ambitiösast": "ambitiös",
    "ambitiösaste": "ambitiös",
    "ambitiösastes": "ambitiös",
    "ambitiösasts": "ambitiös",
    "ambitiöse": "ambitiös",
    "ambitiöses": "ambitiös",
    "ambitiöst": "ambitiös",
    "ambitiösts": "ambitiös",
    "ambivalensen": "ambivalens",
    "ambivalensens": "ambivalens",
    "ambivalenta": "ambivalent",
    "ambivalentare": "ambivalent",
    "ambivalentares": "ambivalent",
    "ambivalentas": "ambivalent",
    "ambivalentast": "ambivalent",
    "ambivalentaste": "ambivalent",
    "ambivalentastes": "ambivalent",
    "ambivalentasts": "ambivalent",
    "ambivalente": "ambivalent",
    "ambivalentes": "ambivalent",
    "ambivalents": "ambivalent",
    "ambran": "ambra",
    "ambrans": "ambra",
    "ambras": "ambra",
    "ambrosian": "ambrosia",
    "ambrosians": "ambrosia",
    "ambrosias": "ambrosia",
    "ambrosiska": "ambrosisk",
    "ambrosiskare": "ambrosisk",
    "ambrosiskares": "ambrosisk",
    "ambrosiskas": "ambrosisk",
    "ambrosiskast": "ambrosisk",
    "ambrosiskaste": "ambrosisk",
    "ambrosiskastes": "ambrosisk",
    "ambrosiskasts": "ambrosisk",
    "ambrosiske": "ambrosisk",
    "ambrosiskes": "ambrosisk",
    "ambrosisks": "ambrosisk",
    "ambrosiskt": "ambrosisk",
    "ambrosiskts": "ambrosisk",
    "ambulansen": "ambulans",
    "ambulansens": "ambulans",
    "ambulanser": "ambulans",
    "ambulanserna": "ambulans",
    "ambulansernas": "ambulans",
    "ambulansers": "ambulans",
    "ambulansflygen": "ambulansflyg",
    "ambulansflygens": "ambulansflyg",
    "ambulansflyget": "ambulansflyg",
    "ambulansflygets": "ambulansflyg",
    "ambulansflygs": "ambulansflyg",
    "ambulansförar": "ambulansförare",
    "ambulansföraren": "ambulansförare",
    "ambulansförarens": "ambulansförare",
    "ambulansförares": "ambulansförare",
    "ambulansförarna": "ambulansförare",
    "ambulansförarnas": "ambulansförare",
    "ambulanshelikoptern": "ambulanshelikopter",
    "ambulanshelikopterns": "ambulanshelikopter",
    "ambulanshelikopters": "ambulanshelikopter",
    "ambulanshelikoptrar": "ambulanshelikopter",
    "ambulanshelikoptrarna": "ambulanshelikopter",
    "ambulanshelikoptrarnas": "ambulanshelikopter",
    "ambulanshelikoptrars": "ambulanshelikopter",
    "ambulanssjukvårdar": "ambulanssjukvårdare",
    "ambulanssjukvårdaren": "ambulanssjukvårdare",
    "ambulanssjukvårdarens": "ambulanssjukvårdare",
    "ambulanssjukvårdares": "ambulanssjukvårdare",
    "ambulanssjukvårdarna": "ambulanssjukvårdare",
    "ambulanssjukvårdarnas": "ambulanssjukvårdare",
    "ambulatoriska": "ambulatorisk",
    "ambulatoriskare": "ambulatorisk",
    "ambulatoriskares": "ambulatorisk",
    "ambulatoriskas": "ambulatorisk",
    "ambulatoriskast": "ambulatorisk",
    "ambulatoriskaste": "ambulatorisk",
    "ambulatoriskastes": "ambulatorisk",
    "ambulatoriskasts": "ambulatorisk",
    "ambulatoriske": "ambulatorisk",
    "ambulatoriskes": "ambulatorisk",
    "ambulatorisks": "ambulatorisk",
    "ambulatoriskt": "ambulatorisk",
    "ambulatoriskts": "ambulatorisk",
    "ambulerad": "ambulera",
    "ambulerade": "ambulera",
    "ambulerades": "ambulera",
    "ambulerads": "ambulera",
    "ambulerande": "ambulera",
    "ambuleranden": "ambulerande",
    "ambulerandena": "ambulerande",
    "ambulerandenas": "ambulerande",
    "ambulerandens": "ambulerande",
    "ambulerandes": "ambulerande",
    "ambulerandet": "ambulerande",
    "ambulerandets": "ambulerande",
    "ambulerar": "ambulera",
    "ambuleras": "ambulera",
    "ambulerat": "ambulera",
    "ambulerats": "ambulera",
    "ambulerbara": "ambulerbar",
    "ambulerbarare": "ambulerbar",
    "ambulerbarares": "ambulerbar",
    "ambulerbaras": "ambulerbar",
    "ambulerbarast": "ambulerbar",
    "ambulerbaraste": "ambulerbar",
    "ambulerbarastes": "ambulerbar",
    "ambulerbarasts": "ambulerbar",
    "ambulerbare": "ambulerbar",
    "ambulerbares": "ambulerbar",
    "ambulerbarheten": "ambulerbarhet",
    "ambulerbarhetens": "ambulerbarhet",
    "ambulerbarhets": "ambulerbarhet",
    "ambulerbars": "ambulerbar",
    "ambulerbart": "ambulerbar",
    "ambulerbarts": "ambulerbar",
    "ambuleringar": "ambulering",
    "ambuleringarna": "ambulering",
    "ambuleringarnas": "ambulering",
    "ambuleringars": "ambulering",
    "ambuleringen": "ambulering",
    "ambuleringens": "ambulering",
    "ambulerings": "ambulering",
    "amendemangen": "amendemang",
    "amendemangens": "amendemang",
    "amendemanget": "amendemang",
    "amendemangets": "amendemang",
    "amendemangs": "amendemang",
    "americiet": "americium",
    "americiets": "americium",
    "americiumet": "americium",
    "americiumets": "americium",
    "americiums": "americium",
    "amerikabiljetten": "amerikabiljett",
    "amerikabiljettens": "amerikabiljett",
    "amerikabiljetter": "amerikabiljett",
    "amerikabiljetterna": "amerikabiljett",
    "amerikabiljetternas": "amerikabiljett",
    "amerikabiljetters": "amerikabiljett",
    "amerikabiljetts": "amerikabiljett",
    "amerikanar": "amerikanare",
    "amerikanaren": "amerikanare",
    "amerikanarens": "amerikanare",
    "amerikanares": "amerikanare",
    "amerikanarna": "amerikanare",
    "amerikanarnas": "amerikanare",
    "amerikanen": "amerikan",
    "amerikanens": "amerikan",
    "amerikaner": "amerikan",
    "amerikanerna": "amerikan",
    "amerikanernas": "amerikan",
    "amerikaners": "amerikan",
    "amerikaniserad": "amerikanisera",
    "amerikaniserade": "amerikanisera",
    "amerikaniserades": "amerikanisera",
    "amerikaniserads": "amerikanisera",
    "amerikaniserande": "amerikanisera",
    "amerikaniseranden": "amerikaniserande",
    "amerikaniserandena": "amerikaniserande",
    "amerikaniserandenas": "amerikaniserande",
    "amerikaniserandens": "amerikaniserande",
    "amerikaniserandes": "amerikaniserande",
    "amerikaniserandet": "amerikaniserande",
    "amerikaniserandets": "amerikaniserande",
    "amerikaniserar": "amerikanisera",
    "amerikaniseras": "amerikanisera",
    "amerikaniserat": "amerikanisera",
    "amerikaniserats": "amerikanisera",
    "amerikaniserbara": "amerikaniserbar",
    "amerikaniserbarare": "amerikaniserbar",
    "amerikaniserbarares": "amerikaniserbar",
    "amerikaniserbaras": "amerikaniserbar",
    "amerikaniserbarast": "amerikaniserbar",
    "amerikaniserbaraste": "amerikaniserbar",
    "amerikaniserbarastes": "amerikaniserbar",
    "amerikaniserbarasts": "amerikaniserbar",
    "amerikaniserbare": "amerikaniserbar",
    "amerikaniserbares": "amerikaniserbar",
    "amerikaniserbarheten": "amerikaniserbarhet",
    "amerikaniserbarhetens": "amerikaniserbarhet",
    "amerikaniserbarhets": "amerikaniserbarhet",
    "amerikaniserbars": "amerikaniserbar",
    "amerikaniserbart": "amerikaniserbar",
    "amerikaniserbarts": "amerikaniserbar",
    "amerikaniseringar": "amerikanisering",
    "amerikaniseringarna": "amerikanisering",
    "amerikaniseringarnas": "amerikanisering",
    "amerikaniseringars": "amerikanisering",
    "amerikaniseringen": "amerikanisering",
    "amerikaniseringens": "amerikanisering",
    "amerikaniserings": "amerikanisering",
    "amerikanismen": "amerikanism",
    "amerikanismens": "amerikanism",
    "amerikanismer": "amerikanism",
    "amerikanismerna": "amerikanism",
    "amerikanismernas": "amerikanism",
    "amerikanismers": "amerikanism",
    "amerikanisms": "amerikanism",
    "amerikans": "amerikan",
    "amerikansk": "amerikanska",
    "amerikanska": "amerikansk",
    "amerikanskan": "amerikanska",
    "amerikanskans": "amerikanska",
    "amerikanskare": "amerikansk",
    "amerikanskares": "amerikansk",
    "amerikanskas": "amerikanska",
    "amerikanskast": "amerikansk",
    "amerikanskaste": "amerikansk",
    "amerikanskastes": "amerikansk",
    "amerikanskasts": "amerikansk",
    "amerikanske": "amerikanska",
    "amerikanskes": "amerikansk",
    "amerikanskor": "amerikanska",
    "amerikanskorna": "amerikanska",
    "amerikanskornas": "amerikanska",
    "amerikanskors": "amerikanska",
    "amerikansks": "amerikansk",
    "amerikanskt": "amerikansk",
    "amerikansktillverkade": "amerikansktillverkad",
    "amerikansktillverkades": "amerikansktillverkad",
    "amerikansktillverkads": "amerikansktillverkad",
    "amerikansktillverkat": "amerikansktillverkad",
    "amerikansktillverkats": "amerikansktillverkad",
    "amerikanskts": "amerikansk",
    "ametisten": "ametist",
    "ametistens": "ametist",
    "ametister": "ametist",
    "ametisterna": "ametist",
    "ametisternas": "ametist",
    "ametisters": "ametist",
    "ametists": "ametist",
    "amfetaminen": "amfetamin",
    "amfetaminens": "amfetamin",
    "amfetaminer": "amfetamin",
    "amfetaminerna": "amfetamin",
    "amfetaminernas": "amfetamin",
    "amfetaminers": "amfetamin",
    "amfetaminet": "amfetamin",
    "amfetaminets": "amfetamin",
    "amfetamins": "amfetamin",
    "amfibien": "amfibie",
    "amfibiens": "amfibie",
    "amfibier": "amfibie",
    "amfibierna": "amfibie",
    "amfibiernas": "amfibie",
    "amfibiers": "amfibie",
    "amfibies": "amfibie",
    "amfibiska": "amfibisk",
    "amfibiskare": "amfibisk",
    "amfibiskares": "amfibisk",
    "amfibiskas": "amfibisk",
    "amfibiskast": "amfibisk",
    "amfibiskaste": "amfibisk",
    "amfibiskastes": "amfibisk",
    "amfibiskasts": "amfibisk",
    "amfibiske": "amfibisk",
    "amfibiskes": "amfibisk",
    "amfibisks": "amfibisk",
    "amfibiskt": "amfibisk",
    "amfibiskts": "amfibisk",
    "amfiboliten": "amfibolit",
    "amfibolitens": "amfibolit",
    "amfiboliter": "amfibolit",
    "amfiboliterna": "amfibolit",
    "amfiboliternas": "amfibolit",
    "amfiboliters": "amfibolit",
    "amfibolits": "amfibolit",
    "amfiteatern": "amfiteater",
    "amfiteaterns": "amfiteater",
    "amfiteaters": "amfiteater",
    "amfiteatraliska": "amfiteatralisk",
    "amfiteatraliskare": "amfiteatralisk",
    "amfiteatraliskares": "amfiteatralisk",
    "amfiteatraliskas": "amfiteatralisk",
    "amfiteatraliskast": "amfiteatralisk",
    "amfiteatraliskaste": "amfiteatralisk",
    "amfiteatraliskastes": "amfiteatralisk",
    "amfiteatraliskasts": "amfiteatralisk",
    "amfiteatraliske": "amfiteatralisk",
    "amfiteatraliskes": "amfiteatralisk",
    "amfiteatralisks": "amfiteatralisk",
    "amfiteatraliskt": "amfiteatralisk",
    "amfiteatraliskts": "amfiteatralisk",
    "amfiteatrar": "amfiteater",
    "amfiteatrarna": "amfiteater",
    "amfiteatrarnas": "amfiteater",
    "amfiteatrars": "amfiteater",
    "amfor": "amfora",
    "amforan": "amfora",
    "amforans": "amfora",
    "amforas": "amfora",
    "amfore": "amfora",
    "amforor": "amfora",
    "amfororna": "amfora",
    "amforornas": "amfora",
    "amforors": "amfora",
    "amfors": "amfora",
    "amiden": "amid",
    "amidens": "amid",
    "amider": "amid",
    "amiderna": "amid",
    "amidernas": "amid",
    "amiders": "amid",
    "amids": "amid",
    "amien": "ami",
    "amiens": "ami",
    "amier": "ami",
    "amierna": "ami",
    "amiernas": "ami",
    "amiers": "ami",
    "amin": "ami",
    "aminen": "amin",
    "aminens": "amin",
    "aminer": "amin",
    "aminerna": "amin",
    "aminernas": "amin",
    "aminers": "amin",
    "aminet": "amin",
    "aminets": "amin",
    "aminosyran": "aminosyra",
    "aminosyrans": "aminosyra",
    "aminosyras": "aminosyra",
    "aminosyre": "aminosyra",
    "aminosyror": "aminosyra",
    "aminosyrorna": "aminosyra",
    "aminosyrornas": "aminosyra",
    "aminosyrors": "aminosyra",
    "amins": "amin",
    "amiralen": "amiral",
    "amiralens": "amiral",
    "amiraler": "amiral",
    "amiralerna": "amiral",
    "amiralernas": "amiral",
    "amiralers": "amiral",
    "amiralitetet": "amiralitet",
    "amiralitetets": "amiralitet",
    "amiralitets": "amiralitet",
    "amirals": "amiral",
    "amiralspersonen": "amiralsperson",
    "amiralspersonens": "amiralsperson",
    "amiralspersoner": "amiralsperson",
    "amiralspersonerna": "amiralsperson",
    "amiralspersonernas": "amiralsperson",
    "amiralspersoners": "amiralsperson",
    "amiralspersons": "amiralsperson",
    "amis": "ami",
    "ammad": "amma",
    "ammade": "amma",
    "ammades": "amma",
    "ammads": "amma",
    "amman": "amma",
    "ammande": "amma",
    "ammanden": "ammande",
    "ammandena": "ammande",
    "ammandenas": "ammande",
    "ammandens": "ammande",
    "ammandes": "ammande",
    "ammandet": "ammande",
    "ammandets": "ammande",
    "ammans": "amma",
    "ammar": "amma",
    "ammas": "amma",
    "ammat": "amma",
    "ammats": "amma",
    "amme": "amma",
    "ammoniaken": "ammoniak",
    "ammoniakens": "ammoniak",
    "ammoniaks": "ammoniak",
    "ammoniet": "ammonium",
    "ammoniets": "ammonium",
    "ammoniten": "ammonit",
    "ammonitens": "ammonit",
    "ammoniter": "ammonit",
    "ammoniterna": "ammonit",
    "ammoniternas": "ammonit",
    "ammoniters": "ammonit",
    "ammonits": "ammonit",
    "ammoniumet": "ammonium",
    "ammoniumets": "ammonium",
    "ammoniumkloriden": "ammoniumklorid",
    "ammoniumkloridens": "ammoniumklorid",
    "ammoniumklorids": "ammoniumklorid",
    "ammoniumnitraten": "ammoniumnitrat",
    "ammoniumnitratens": "ammoniumnitrat",
    "ammoniumnitrater": "ammoniumnitrat",
    "ammoniumnitraterna": "ammoniumnitrat",
    "ammoniumnitraternas": "ammoniumnitrat",
    "ammoniumnitraters": "ammoniumnitrat",
    "ammoniumnitratet": "ammoniumnitrat",
    "ammoniumnitratets": "ammoniumnitrat",
    "ammoniumnitratlösningar": "ammoniumnitratlösning",
    "ammoniumnitratlösningarna": "ammoniumnitratlösning",
    "ammoniumnitratlösningarnas": "ammoniumnitratlösning",
    "ammoniumnitratlösningars": "ammoniumnitratlösning",
    "ammoniumnitratlösningen": "ammoniumnitratlösning",
    "ammoniumnitratlösningens": "ammoniumnitratlösning",
    "ammoniumnitratlösnings": "ammoniumnitratlösning",
    "ammoniumnitrats": "ammoniumnitrat",
    "ammoniums": "ammonium",
    "ammor": "amma",
    "ammorna": "amma",
    "ammornas": "amma",
    "ammors": "amma",
    "ammunitionen": "ammunition",
    "ammunitionens": "ammunition",
    "ammunitioner": "ammunition",
    "ammunitionerna": "ammunition",
    "ammunitionernas": "ammunition",
    "ammunitioners": "ammunition",
    "ammunitions": "ammunition",
    "ammunitionsväsk": "ammunitionsväska",
    "ammunitionsväskan": "ammunitionsväska",
    "ammunitionsväskans": "ammunitionsväska",
    "ammunitionsväskas": "ammunitionsväska",
    "ammunitionsväske": "ammunitionsväska",
    "ammunitionsväskor": "ammunitionsväska",
    "ammunitionsväskorna": "ammunitionsväska",
    "ammunitionsväskornas": "ammunitionsväska",
    "ammunitionsväskors": "ammunitionsväska",
    "amnesien": "amnesi",
    "amnesiens": "amnesi",
    "amnesier": "amnesi",
    "amnesierna": "amnesi",
    "amnesiernas": "amnesi",
    "amnesiers": "amnesi",
    "amnesin": "amnesi",
    "amnesins": "amnesi",
    "amnesis": "amnesi",
    "amnestien": "amnesti",
    "amnestiens": "amnesti",
    "amnestier": "amnesti",
    "amnestierna": "amnesti",
    "amnestiernas": "amnesti",
    "amnestiers": "amnesti",
    "amnestin": "amnesti",
    "amnestins": "amnesti",
    "amnestis": "amnesti",
    "amningen": "amning",
    "amningens": "amning",
    "amnings": "amning",
    "amningsföraktet": "amningsförakt",
    "amningsföraktets": "amningsförakt",
    "amningsförakts": "amningsförakt",
    "amoraliska": "amoralisk",
    "amoraliskare": "amoralisk",
    "amoraliskares": "amoralisk",
    "amoraliskas": "amoralisk",
    "amoraliskast": "amoralisk",
    "amoraliskaste": "amoralisk",
    "amoraliskastes": "amoralisk",
    "amoraliskasts": "amoralisk",
    "amoraliske": "amoralisk",
    "amoraliskes": "amoralisk",
    "amoralisks": "amoralisk",
    "amoraliskt": "amoralisk",
    "amoraliskts": "amoralisk",
    "amoralismen": "amoralism",
    "amoralismens": "amoralism",
    "amoralismer": "amoralism",
    "amoralismerna": "amoralism",
    "amoralismernas": "amoralism",
    "amoralismers": "amoralism",
    "amoralisms": "amoralism",
    "amoraliteten": "amoralitet",
    "amoralitetens": "amoralitet",
    "amoraliteter": "amoralitet",
    "amoraliteterna": "amoralitet",
    "amoraliteternas": "amoralitet",
    "amoraliteters": "amoralitet",
    "amoralitets": "amoralitet",
    "amorbåg": "amorbåge",
    "amorbågar": "amorbåge",
    "amorbågarna": "amorbåge",
    "amorbågarnas": "amorbåge",
    "amorbågars": "amorbåge",
    "amorbågen": "amorbåge",
    "amorbågens": "amorbåge",
    "amorbåges": "amorbåge",
    "amorbågs": "amorbåge",
    "amorfa": "amorf",
    "amorfare": "amorf",
    "amorfares": "amorf",
    "amorfas": "amorf",
    "amorfast": "amorf",
    "amorfaste": "amorf",
    "amorfastes": "amorf",
    "amorfasts": "amorf",
    "amorfe": "amorf",
    "amorfes": "amorf",
    "amorfismen": "amorfism",
    "amorfismens": "amorfism",
    "amorfismer": "amorfism",
    "amorfismerna": "amorfism",
    "amorfismernas": "amorfism",
    "amorfismers": "amorfism",
    "amorfisms": "amorfism",
    "amorfs": "amorf",
    "amorft": "amorf",
    "amorfts": "amorf",
    "amorinen": "amorin",
    "amorinens": "amorin",
    "amoriner": "amorin",
    "amorinerna": "amorin",
    "amorinernas": "amorin",
    "amoriners": "amorin",
    "amorins": "amorin",
    "amorterad": "amortera",
    "amorterade": "amortera",
    "amorterades": "amortera",
    "amorterads": "amortera",
    "amorterande": "amortera",
    "amorteranden": "amorterande",
    "amorterandena": "amorterande",
    "amorterandenas": "amorterande",
    "amorterandens": "amorterande",
    "amorterandes": "amorterande",
    "amorterandet": "amorterande",
    "amorterandets": "amorterande",
    "amorterar": "amortera",
    "amorteras": "amortera",
    "amorterat": "amortera",
    "amorterats": "amortera",
    "amorterbara": "amorterbar",
    "amorterbarare": "amorterbar",
    "amorterbarares": "amorterbar",
    "amorterbaras": "amorterbar",
    "amorterbarast": "amorterbar",
    "amorterbaraste": "amorterbar",
    "amorterbarastes": "amorterbar",
    "amorterbarasts": "amorterbar",
    "amorterbare": "amorterbar",
    "amorterbares": "amorterbar",
    "amorterbarheten": "amorterbarhet",
    "amorterbarhetens": "amorterbarhet",
    "amorterbarhets": "amorterbarhet",
    "amorterbars": "amorterbar",
    "amorterbart": "amorterbar",
    "amorterbarts": "amorterbar",
    "amorteringar": "amortering",
    "amorteringarna": "amortering",
    "amorteringarnas": "amortering",
    "amorteringars": "amortering",
    "amorteringen": "amortering",
    "amorteringens": "amortering",
    "amorterings": "amortering",
    "amorteringsfria": "amorteringsfri",
    "amorteringsfriare": "amorteringsfri",
    "amorteringsfriares": "amorteringsfri",
    "amorteringsfrias": "amorteringsfri",
    "amorteringsfriast": "amorteringsfri",
    "amorteringsfriaste": "amorteringsfri",
    "amorteringsfriastes": "amorteringsfri",
    "amorteringsfriasts": "amorteringsfri",
    "amorteringsfrie": "amorteringsfri",
    "amorteringsfries": "amorteringsfri",
    "amorteringsfris": "amorteringsfri",
    "amorteringsfritt": "amorteringsfri",
    "amorteringsfritts": "amorteringsfri",
    "amorteringsplane": "amorteringsplan",
    "amorteringsplanen": "amorteringsplan",
    "amorteringsplanens": "amorteringsplan",
    "amorteringsplaner": "amorteringsplan",
    "amorteringsplanerna": "amorteringsplan",
    "amorteringsplanernas": "amorteringsplan",
    "amorteringsplaners": "amorteringsplan",
    "amorteringsplans": "amorteringsplan",
    "amorösa": "amorös",
    "amorösare": "amorös",
    "amorösares": "amorös",
    "amorösas": "amorös",
    "amorösast": "amorös",
    "amorösaste": "amorös",
    "amorösastes": "amorös",
    "amorösasts": "amorös",
    "amoröse": "amorös",
    "amoröses": "amorös",
    "amoröst": "amorös",
    "amorösts": "amorös",
    "ampeln": "ampel",
    "ampelns": "ampel",
    "ampels": "ampel",
    "ampelt": "ampel",
    "ampelts": "ampel",
    "amperemetern": "amperemeter",
    "amperemeterns": "amperemeter",
    "amperemeters": "amperemeter",
    "amperemetrar": "amperemeter",
    "amperemetrarna": "amperemeter",
    "amperemetrarnas": "amperemeter",
    "amperemetrars": "amperemeter",
    "amperen": "ampere",
    "amperena": "ampere",
    "amperenas": "ampere",
    "amperens": "ampere",
    "amperes": "ampere",
    "amperesekunden": "amperesekund",
    "amperesekundens": "amperesekund",
    "amperesekunder": "amperesekund",
    "amperesekunderna": "amperesekund",
    "amperesekundernas": "amperesekund",
    "amperesekunders": "amperesekund",
    "amperesekunds": "amperesekund",
    "amperevarven": "amperevarv",
    "amperevarvens": "amperevarv",
    "amperevarvet": "amperevarv",
    "amperevarvets": "amperevarv",
    "amperevarvs": "amperevarv",
    "ampers": "amper",
    "ampert": "amper",
    "amperts": "amper",
    "ampla": "ampel",
    "amplar": "ampel",
    "amplare": "ampel",
    "amplares": "ampel",
    "amplarna": "ampel",
    "amplarnas": "ampel",
    "amplars": "ampel",
    "amplas": "ampel",
    "amplast": "ampel",
    "amplaste": "ampel",
    "amplastes": "ampel",
    "amplasts": "ampel",
    "ample": "ampel",
    "amples": "ampel",
    "amplifierad": "amplifiera",
    "amplifierade": "amplifiera",
    "amplifierades": "amplifiera",
    "amplifierads": "amplifiera",
    "amplifierande": "amplifiera",
    "amplifieranden": "amplifierande",
    "amplifierandena": "amplifierande",
    "amplifierandenas": "amplifierande",
    "amplifierandens": "amplifierande",
    "amplifierandes": "amplifierande",
    "amplifierandet": "amplifierande",
    "amplifierandets": "amplifierande",
    "amplifierar": "amplifiera",
    "amplifieras": "amplifiera",
    "amplifierat": "amplifiera",
    "amplifierats": "amplifiera",
    "amplifierbara": "amplifierbar",
    "amplifierbarare": "amplifierbar",
    "amplifierbarares": "amplifierbar",
    "amplifierbaras": "amplifierbar",
    "amplifierbarast": "amplifierbar",
    "amplifierbaraste": "amplifierbar",
    "amplifierbarastes": "amplifierbar",
    "amplifierbarasts": "amplifierbar",
    "amplifierbare": "amplifierbar",
    "amplifierbares": "amplifierbar",
    "amplifierbarheten": "amplifierbarhet",
    "amplifierbarhetens": "amplifierbarhet",
    "amplifierbarhets": "amplifierbarhet",
    "amplifierbars": "amplifierbar",
    "amplifierbart": "amplifierbar",
    "amplifierbarts": "amplifierbar",
    "amplifieringar": "amplifiering",
    "amplifieringarna": "amplifiering",
    "amplifieringarnas": "amplifiering",
    "amplifieringars": "amplifiering",
    "amplifieringen": "amplifiering",
    "amplifieringens": "amplifiering",
    "amplifierings": "amplifiering",
    "amplituden": "amplitud",
    "amplitudens": "amplitud",
    "amplituder": "amplitud",
    "amplituderna": "amplitud",
    "amplitudernas": "amplitud",
    "amplituders": "amplitud",
    "amplitudmodulerad": "amplitudmodulera",
    "amplitudmodulerade": "amplitudmodulera",
    "amplitudmodulerades": "amplitudmodulera",
    "amplitudmodulerads": "amplitudmodulera",
    "amplitudmodulerande": "amplitudmodulera",
    "amplitudmoduleranden": "amplitudmodulerande",
    "amplitudmodulerandena": "amplitudmodulerande",
    "amplitudmodulerandenas": "amplitudmodulerande",
    "amplitudmodulerandens": "amplitudmodulerande",
    "amplitudmodulerandes": "amplitudmodulerande",
    "amplitudmodulerandet": "amplitudmodulerande",
    "amplitudmodulerandets": "amplitudmodulerande",
    "amplitudmodulerar": "amplitudmodulera",
    "amplitudmoduleras": "amplitudmodulera",
    "amplitudmodulerat": "amplitudmodulera",
    "amplitudmodulerats": "amplitudmodulera",
    "amplitudmodulerbara": "amplitudmodulerbar",
    "amplitudmodulerbarare": "amplitudmodulerbar",
    "amplitudmodulerbarares": "amplitudmodulerbar",
    "amplitudmodulerbaras": "amplitudmodulerbar",
    "amplitudmodulerbarast": "amplitudmodulerbar",
    "amplitudmodulerbaraste": "amplitudmodulerbar",
    "amplitudmodulerbarastes": "amplitudmodulerbar",
    "amplitudmodulerbarasts": "amplitudmodulerbar",
    "amplitudmodulerbare": "amplitudmodulerbar",
    "amplitudmodulerbares": "amplitudmodulerbar",
    "amplitudmodulerbarheten": "amplitudmodulerbarhet",
    "amplitudmodulerbarhetens": "amplitudmodulerbarhet",
    "amplitudmodulerbarhets": "amplitudmodulerbarhet",
    "amplitudmodulerbars": "amplitudmodulerbar",
    "amplitudmodulerbart": "amplitudmodulerbar",
    "amplitudmodulerbarts": "amplitudmodulerbar",
    "amplitudmoduleringar": "amplitudmodulering",
    "amplitudmoduleringarna": "amplitudmodulering",
    "amplitudmoduleringarnas": "amplitudmodulering",
    "amplitudmoduleringars": "amplitudmodulering",
    "amplitudmoduleringen": "amplitudmodulering",
    "amplitudmoduleringens": "amplitudmodulering",
    "amplitudmodulerings": "amplitudmodulering",
    "amplituds": "amplitud",
    "ampra": "amper",
    "amprare": "amper",
    "amprares": "amper",
    "ampras": "amper",
    "amprast": "amper",
    "ampraste": "amper",
    "amprastes": "amper",
    "amprasts": "amper",
    "ampre": "amper",
    "ampres": "amper",
    "ampullen": "ampull",
    "ampullens": "ampull",
    "ampuller": "ampull",
    "ampullerna": "ampull",
    "ampullernas": "ampull",
    "ampullers": "ampull",
    "ampulls": "ampull",
    "amputationen": "amputation",
    "amputationens": "amputation",
    "amputationer": "amputation",
    "amputationerna": "amputation",
    "amputationernas": "amputation",
    "amputationers": "amputation",
    "amputations": "amputation",
    "amputerad": "amputera",
    "amputerade": "amputera",
    "amputerades": "amputera",
    "amputerads": "amputera",
    "amputerande": "amputera",
    "amputeranden": "amputerande",
    "amputerandena": "amputerande",
    "amputerandenas": "amputerande",
    "amputerandens": "amputerande",
    "amputerandes": "amputerande",
    "amputerandet": "amputerande",
    "amputerandets": "amputerande",
    "amputerar": "amputera",
    "amputeras": "amputera",
    "amputerat": "amputera",
    "amputerats": "amputera",
    "amputerbara": "amputerbar",
    "amputerbarare": "amputerbar",
    "amputerbarares": "amputerbar",
    "amputerbaras": "amputerbar",
    "amputerbarast": "amputerbar",
    "amputerbaraste": "amputerbar",
    "amputerbarastes": "amputerbar",
    "amputerbarasts": "amputerbar",
    "amputerbare": "amputerbar",
    "amputerbares": "amputerbar",
    "amputerbarheten": "amputerbarhet",
    "amputerbarhetens": "amputerbarhet",
    "amputerbarhets": "amputerbarhet",
    "amputerbars": "amputerbar",
    "amputerbart": "amputerbar",
    "amputerbarts": "amputerbar",
    "amputeringar": "amputering",
    "amputeringarna": "amputering",
    "amputeringarnas": "amputering",
    "amputeringars": "amputering",
    "amputeringen": "amputering",
    "amputeringens": "amputering",
    "amputerings": "amputering",
    "ams": "amma",
    "amsagan": "amsaga",
    "amsagans": "amsaga",
    "amsagas": "amsaga",
    "amsage": "amsaga",
    "amsago": "amsaga",
    "amsagor": "amsaga",
    "amsagorna": "amsaga",
    "amsagornas": "amsaga",
    "amsagors": "amsaga",
    "amten": "amt",
    "amtens": "amt",
    "amtet": "amt",
    "amtets": "amt",
    "amts": "amt",
    "amuletten": "amulett",
    "amulettens": "amulett",
    "amuletter": "amulett",
    "amuletterna": "amulett",
    "amuletternas": "amulett",
    "amuletters": "amulett",
    "amuletts": "amulett",
    "amylasen": "amylas",
    "amylasens": "amylas",
    "amylaser": "amylas",
    "amylaserna": "amylas",
    "amylasernas": "amylas",
    "amylasers": "amylas",
    "amyotrofien": "amyotrofi",
    "amyotrofiens": "amyotrofi",
    "amyotrofier": "amyotrofi",
    "amyotrofierna": "amyotrofi",
    "amyotrofiernas": "amyotrofi",
    "amyotrofiers": "amyotrofi",
    "amyotrofin": "amyotrofi",
    "amyotrofins": "amyotrofi",
    "amyotrofis": "amyotrofi",
    "amöb": "amöba",
    "amöban": "amöba",
    "amöbans": "amöba",
    "amöbas": "amöba",
    "amöbe": "amöba",
    "amöbor": "amöba",
    "amöborna": "amöba",
    "amöbornas": "amöba",
    "amöbors": "amöba",
    "amöbs": "amöba",
    "anabaptismen": "anabaptism",
    "anabaptismens": "anabaptism",
    "anabaptismer": "anabaptism",
    "anabaptismerna": "anabaptism",
    "anabaptismernas": "anabaptism",
    "anabaptismers": "anabaptism",
    "anabaptisms": "anabaptism",
    "anabaptisten": "anabaptist",
    "anabaptistens": "anabaptist",
    "anabaptister": "anabaptist",
    "anabaptisterna": "anabaptist",
    "anabaptisternas": "anabaptist",
    "anabaptisters": "anabaptist",
    "anabaptistiska": "anabaptistisk",
    "anabaptistiskas": "anabaptistisk",
    "anabaptistiske": "anabaptistisk",
    "anabaptistiskes": "anabaptistisk",
    "anabaptistisks": "anabaptistisk",
    "anabaptistiskt": "anabaptistisk",
    "anabaptistiskts": "anabaptistisk",
    "anabaptists": "anabaptist",
    "anabatiska": "anabatisk",
    "anabatiskare": "anabatisk",
    "anabatiskares": "anabatisk",
    "anabatiskas": "anabatisk",
    "anabatiskast": "anabatisk",
    "anabatiskaste": "anabatisk",
    "anabatiskastes": "anabatisk",
    "anabatiskasts": "anabatisk",
    "anabatiske": "anabatisk",
    "anabatiskes": "anabatisk",
    "anabatisks": "anabatisk",
    "anabatiskt": "anabatisk",
    "anabatiskts": "anabatisk",
    "anabola": "anabol",
    "anabolas": "anabol",
    "anabole": "anabol",
    "anabolen": "anabol",
    "anabolens": "anabol",
    "anaboler": "anabol",
    "anabolerna": "anabol",
    "anabolernas": "anabol",
    "anabolers": "anabol",
    "anaboles": "anabol",
    "anabols": "anabol",
    "anabolt": "anabol",
    "anabolts": "anabol",
    "anad": "ana",
    "anade": "ana",
    "anades": "ana",
    "anads": "ana",
    "anaeroba": "anaerob",
    "anaerobare": "anaerob",
    "anaerobares": "anaerob",
    "anaerobas": "anaerob",
    "anaerobast": "anaerob",
    "anaerobaste": "anaerob",
    "anaerobastes": "anaerob",
    "anaerobasts": "anaerob",
    "anaerobe": "anaerob",
    "anaerobes": "anaerob",
    "anaerobs": "anaerob",
    "anaerobt": "anaerob",
    "anaerobts": "anaerob",
    "anaforen": "anafor",
    "anaforens": "anafor",
    "anaforer": "anafor",
    "anaforerna": "anafor",
    "anaforernas": "anafor",
    "anaforers": "anafor",
    "anaforiska": "anaforisk",
    "anaforiskare": "anaforisk",
    "anaforiskares": "anaforisk",
    "anaforiskas": "anaforisk",
    "anaforiskast": "anaforisk",
    "anaforiskaste": "anaforisk",
    "anaforiskastes": "anaforisk",
    "anaforiskasts": "anaforisk",
    "anaforiske": "anaforisk",
    "anaforiskes": "anaforisk",
    "anaforisks": "anaforisk",
    "anaforiskt": "anaforisk",
    "anaforiskts": "anaforisk",
    "anafors": "anafor",
    "anagrammen": "anagram",
    "anagrammens": "anagram",
    "anagrammet": "anagram",
    "anagrammets": "anagram",
    "anagrams": "anagram",
    "anakoluten": "anakolut",
    "anakolutens": "anakolut",
    "anakoluter": "anakolut",
    "anakoluterna": "anakolut",
    "anakoluternas": "anakolut",
    "anakoluters": "anakolut",
    "anakoluts": "anakolut",
    "anakond": "anakonda",
    "anakondan": "anakonda",
    "anakondans": "anakonda",
    "anakondas": "anakonda",
    "anakonde": "anakonda",
    "anakondor": "anakonda",
    "anakondorna": "anakonda",
    "anakondornas": "anakonda",
    "anakondors": "anakonda",
    "anakonds": "anakonda",
    "anakoreten": "anakoret",
    "anakoretens": "anakoret",
    "anakoreter": "anakoret",
    "anakoreterna": "anakoret",
    "anakoreternas": "anakoret",
    "anakoreters": "anakoret",
    "anakorets": "anakoret",
    "anakreontiska": "anakreontisk",
    "anakreontiskare": "anakreontisk",
    "anakreontiskares": "anakreontisk",
    "anakreontiskas": "anakreontisk",
    "anakreontiskast": "anakreontisk",
    "anakreontiskaste": "anakreontisk",
    "anakreontiskastes": "anakreontisk",
    "anakreontiskasts": "anakreontisk",
    "anakreontiske": "anakreontisk",
    "anakreontiskes": "anakreontisk",
    "anakreontisks": "anakreontisk",
    "anakreontiskt": "anakreontisk",
    "anakreontiskts": "anakreontisk",
    "anakronismen": "anakronism",
    "anakronismens": "anakronism",
    "anakronismer": "anakronism",
    "anakronismerna": "anakronism",
    "anakronismernas": "anakronism",
    "anakronismers": "anakronism",
    "anakronisms": "anakronism",
    "anakronistiska": "anakronistisk",
    "anakronistiskas": "anakronistisk",
    "anakronistiske": "anakronistisk",
    "anakronistiskes": "anakronistisk",
    "anakronistisks": "anakronistisk",
    "anakronistiskt": "anakronistisk",
    "anakronistiskts": "anakronistisk",
    "anala": "anal",
    "analare": "anal",
    "analares": "anal",
    "analas": "anal",
    "analast": "anal",
    "analaste": "anal",
    "analastes": "anal",
    "analasts": "anal",
    "anale": "anal",
    "analeptiken": "analeptik",
    "analeptikens": "analeptik",
    "analeptiks": "analeptik",
    "anales": "anal",
    "analfabeten": "analfabet",
    "analfabetens": "analfabet",
    "analfabeter": "analfabet",
    "analfabeterna": "analfabet",
    "analfabeternas": "analfabet",
    "analfabeters": "analfabet",
    "analfabetismen": "analfabetism",
    "analfabetismens": "analfabetism",
    "analfabetismer": "analfabetism",
    "analfabetismerna": "analfabetism",
    "analfabetismernas": "analfabetism",
    "analfabetismers": "analfabetism",
    "analfabetisms": "analfabetism",
    "analfabets": "analfabet",
    "analfen": "analfena",
    "analfenan": "analfena",
    "analfenans": "analfena",
    "analfenas": "analfena",
    "analfene": "analfena",
    "analfenor": "analfena",
    "analfenorna": "analfena",
    "analfenornas": "analfena",
    "analfenors": "analfena",
    "analfens": "analfena",
    "analgetikan": "analgetika",
    "analgetikana": "analgetika",
    "analgetikanas": "analgetika",
    "analgetikans": "analgetika",
    "analgetikas": "analgetika",
    "analgetikat": "analgetika",
    "analgetikats": "analgetika",
    "analoga": "analog",
    "analogare": "analog",
    "analogares": "analog",
    "analogas": "analog",
    "analogast": "analog",
    "analogaste": "analog",
    "analogastes": "analog",
    "analogasts": "analog",
    "analoge": "analog",
    "analoges": "analog",
    "analogibevisen": "analogibevis",
    "analogibevisens": "analogibevis",
    "analogibeviset": "analogibevis",
    "analogibevisets": "analogibevis",
    "analogibildningar": "analogibildning",
    "analogibildningarna": "analogibildning",
    "analogibildningarnas": "analogibildning",
    "analogibildningars": "analogibildning",
    "analogibildningen": "analogibildning",
    "analogibildningens": "analogibildning",
    "analogibildnings": "analogibildning",
    "analogien": "analogi",
    "analogiens": "analogi",
    "analogier": "analogi",
    "analogierna": "analogi",
    "analogiernas": "analogi",
    "analogiers": "analogi",
    "analogin": "analogi",
    "analogins": "analogi",
    "analogis": "analogi",
    "analogiska": "analogisk",
    "analogiskare": "analogisk",
    "analogiskares": "analogisk",
    "analogiskas": "analogisk",
    "analogiskast": "analogisk",
    "analogiskaste": "analogisk",
    "analogiskastes": "analogisk",
    "analogiskasts": "analogisk",
    "analogiske": "analogisk",
    "analogiskes": "analogisk",
    "analogisks": "analogisk",
    "analogiskt": "analogisk",
    "analogiskts": "analogisk",
    "analogisluten": "analogislut",
    "analogislutens": "analogislut",
    "analogislutet": "analogislut",
    "analogislutets": "analogislut",
    "analogisluts": "analogislut",
    "analogs": "analog",
    "analogt": "analog",
    "analogts": "analog",
    "anals": "anal",
    "analsexet": "analsex",
    "analsexets": "analsex",
    "analt": "anal",
    "analts": "anal",
    "analysen": "analys",
    "analysens": "analys",
    "analyser": "analys",
    "analyserad": "analysera",
    "analyserade": "analysera",
    "analyserades": "analysera",
    "analyserads": "analysera",
    "analyserande": "analysera",
    "analyseranden": "analyserande",
    "analyserandena": "analyserande",
    "analyserandenas": "analyserande",
    "analyserandens": "analyserande",
    "analyserandes": "analyserande",
    "analyserandet": "analyserande",
    "analyserandets": "analyserande",
    "analyserar": "analysera",
    "analyseras": "analysera",
    "analyserat": "analysera",
    "analyserats": "analysera",
    "analyserbara": "analyserbar",
    "analyserbarare": "analyserbar",
    "analyserbarares": "analyserbar",
    "analyserbaras": "analyserbar",
    "analyserbarast": "analyserbar",
    "analyserbaraste": "analyserbar",
    "analyserbarastes": "analyserbar",
    "analyserbarasts": "analyserbar",
    "analyserbare": "analyserbar",
    "analyserbares": "analyserbar",
    "analyserbarheten": "analyserbarhet",
    "analyserbarhetens": "analyserbarhet",
    "analyserbarhets": "analyserbarhet",
    "analyserbars": "analyserbar",
    "analyserbart": "analyserbar",
    "analyserbarts": "analyserbar",
    "analyseringar": "analysering",
    "analyseringarna": "analysering",
    "analyseringarnas": "analysering",
    "analyseringars": "analysering",
    "analyseringen": "analysering",
    "analyseringens": "analysering",
    "analyserings": "analysering",
    "analyserna": "analys",
    "analysernas": "analys",
    "analysers": "analys",
    "analysmetodiken": "analysmetodik",
    "analysmetodikens": "analysmetodik",
    "analysmetodiker": "analysmetodik",
    "analysmetodikerna": "analysmetodik",
    "analysmetodikernas": "analysmetodik",
    "analysmetodikers": "analysmetodik",
    "analysmetodiks": "analysmetodik",
    "analytikern": "analytiker",
    "analytikerna": "analytiker",
    "analytikernas": "analytiker",
    "analytikerns": "analytiker",
    "analytikers": "analytiker",
    "analytiska": "analytisk",
    "analytiskare": "analytisk",
    "analytiskares": "analytisk",
    "analytiskas": "analytisk",
    "analytiskast": "analytisk",
    "analytiskaste": "analytisk",
    "analytiskastes": "analytisk",
    "analytiskasts": "analytisk",
    "analytiske": "analytisk",
    "analytiskes": "analytisk",
    "analytisks": "analytisk",
    "analytiskt": "analytisk",
    "analytiskts": "analytisk",
    "analöppningar": "analöppning",
    "analöppningarna": "analöppning",
    "analöppningarnas": "analöppning",
    "analöppningars": "analöppning",
    "analöppningen": "analöppning",
    "analöppningens": "analöppning",
    "analöppnings": "analöppning",
    "anammad": "anamma",
    "anammade": "anamma",
    "anammades": "anamma",
    "anammads": "anamma",
    "anammande": "anamma",
    "anammanden": "anammande",
    "anammandena": "anammande",
    "anammandenas": "anammande",
    "anammandens": "anammande",
    "anammandes": "anammande",
    "anammandet": "anammande",
    "anammandets": "anammande",
    "anammar": "anamma",
    "anammas": "anamma",
    "anammat": "anamma",
    "anammats": "anamma",
    "anamnesen": "anamnes",
    "anamnesens": "anamnes",
    "anamneser": "anamnes",
    "anamneserna": "anamnes",
    "anamnesernas": "anamnes",
    "anamnesers": "anamnes",
    "ananasar": "ananas",
    "ananasarna": "ananas",
    "ananasarnas": "ananas",
    "ananasars": "ananas",
    "ananasen": "ananas",
    "ananasens": "ananas",
    "ananaser": "ananas",
    "ananaserna": "ananas",
    "ananasernas": "ananas",
    "ananasers": "ananas",
    "ananassalladen": "ananassallad",
    "ananassalladens": "ananassallad",
    "ananassallader": "ananassallad",
    "ananassalladerna": "ananassallad",
    "ananassalladernas": "ananassallad",
    "ananassalladers": "ananassallad",
    "ananassallads": "ananassallad",
    "anande": "ana",
    "ananden": "anande",
    "anandena": "anande",
    "anandenas": "anande",
    "anandens": "anande",
    "anandes": "anande",
    "anandet": "anande",
    "anandets": "anande",
    "anapesten": "anapest",
    "anapestens": "anapest",
    "anapester": "anapest",
    "anapesterna": "anapest",
    "anapesternas": "anapest",
    "anapesters": "anapest",
    "anapests": "anapest",
    "anar": "ana",
    "anarkien": "anarki",
    "anarkiens": "anarki",
    "anarkin": "anarki",
    "anarkins": "anarki",
    "anarkis": "anarki",
    "anarkiska": "anarkisk",
    "anarkiskare": "anarkisk",
    "anarkiskares": "anarkisk",
    "anarkiskas": "anarkisk",
    "anarkiskast": "anarkisk",
    "anarkiskaste": "anarkisk",
    "anarkiskastes": "anarkisk",
    "anarkiskasts": "anarkisk",
    "anarkiske": "anarkisk",
    "anarkiskes": "anarkisk",
    "anarkisks": "anarkisk",
    "anarkiskt": "anarkisk",
    "anarkiskts": "anarkisk",
    "anarkismen": "anarkism",
    "anarkismens": "anarkism",
    "anarkismer": "anarkism",
    "anarkismerna": "anarkism",
    "anarkismernas": "anarkism",
    "anarkismers": "anarkism",
    "anarkisms": "anarkism",
    "anarkisten": "anarkist",
    "anarkistens": "anarkist",
    "anarkister": "anarkist",
    "anarkisterna": "anarkist",
    "anarkisternas": "anarkist",
    "anarkisters": "anarkist",
    "anarkistiska": "anarkistisk",
    "anarkistiskare": "anarkistisk",
    "anarkistiskares": "anarkistisk",
    "anarkistiskas": "anarkistisk",
    "anarkistiskast": "anarkistisk",
    "anarkistiskaste": "anarkistisk",
    "anarkistiskastes": "anarkistisk",
    "anarkistiskasts": "anarkistisk",
    "anarkistiske": "anarkistisk",
    "anarkistiskes": "anarkistisk",
    "anarkistisks": "anarkistisk",
    "anarkistiskt": "anarkistisk",
    "anarkistiskts": "anarkistisk",
    "anarkists": "anarkist",
    "anarkokapitalistiska": "anarkokapitalistisk",
    "anarkokapitalistiskas": "anarkokapitalistisk",
    "anarkokapitalistiske": "anarkokapitalistisk",
    "anarkokapitalistiskes": "anarkokapitalistisk",
    "anarkokapitalistisks": "anarkokapitalistisk",
    "anarkokapitalistiskt": "anarkokapitalistisk",
    "anarkokapitalistiskts": "anarkokapitalistisk",
    "anarkokommunistiska": "anarkokommunistisk",
    "anarkokommunistiskas": "anarkokommunistisk",
    "anarkokommunistiske": "anarkokommunistisk",
    "anarkokommunistiskes": "anarkokommunistisk",
    "anarkokommunistisks": "anarkokommunistisk",
    "anarkokommunistiskt": "anarkokommunistisk",
    "anarkokommunistiskts": "anarkokommunistisk",
    "anarkoprimitivistiska": "anarkoprimitivistisk",
    "anarkoprimitivistiskas": "anarkoprimitivistisk",
    "anarkoprimitivistiske": "anarkoprimitivistisk",
    "anarkoprimitivistiskes": "anarkoprimitivistisk",
    "anarkoprimitivistisks": "anarkoprimitivistisk",
    "anarkoprimitivistiskt": "anarkoprimitivistisk",
    "anarkoprimitivistiskts": "anarkoprimitivistisk",
    "anarkosyndikalismen": "anarkosyndikalism",
    "anarkosyndikalismens": "anarkosyndikalism",
    "anarkosyndikalismer": "anarkosyndikalism",
    "anarkosyndikalismerna": "anarkosyndikalism",
    "anarkosyndikalismernas": "anarkosyndikalism",
    "anarkosyndikalismers": "anarkosyndikalism",
    "anarkosyndikalisms": "anarkosyndikalism",
    "anarkosyndikalistiska": "anarkosyndikalistisk",
    "anarkosyndikalistiskas": "anarkosyndikalistisk",
    "anarkosyndikalistiske": "anarkosyndikalistisk",
    "anarkosyndikalistiskes": "anarkosyndikalistisk",
    "anarkosyndikalistisks": "anarkosyndikalistisk",
    "anarkosyndikalistiskt": "anarkosyndikalistisk",
    "anarkosyndikalistiskts": "anarkosyndikalistisk",
    "anas": "ana",
    "anastasen": "anastas",
    "anastasens": "anastas",
    "anastaser": "anastas",
    "anastaserna": "anastas",
    "anastasernas": "anastas",
    "anastasers": "anastas",
    "anastatiska": "anastatisk",
    "anastatiskare": "anastatisk",
    "anastatiskares": "anastatisk",
    "anastatiskas": "anastatisk",
    "anastatiskast": "anastatisk",
    "anastatiskaste": "anastatisk",
    "anastatiskastes": "anastatisk",
    "anastatiskasts": "anastatisk",
    "anastatiske": "anastatisk",
    "anastatiskes": "anastatisk",
    "anastatisks": "anastatisk",
    "anastatiskt": "anastatisk",
    "anastatiskts": "anastatisk",
    "anastigmatiska": "anastigmatisk",
    "anastigmatiskare": "anastigmatisk",
    "anastigmatiskares": "anastigmatisk",
    "anastigmatiskas": "anastigmatisk",
    "anastigmatiskast": "anastigmatisk",
    "anastigmatiskaste": "anastigmatisk",
    "anastigmatiskastes": "anastigmatisk",
    "anastigmatiskasts": "anastigmatisk",
    "anastigmatiske": "anastigmatisk",
    "anastigmatiskes": "anastigmatisk",
    "anastigmatisks": "anastigmatisk",
    "anastigmatiskt": "anastigmatisk",
    "anastigmatiskts": "anastigmatisk",
    "anat": "ana",
    "anateman": "anatema",
    "anatemana": "anatema",
    "anatemanas": "anatema",
    "anatemans": "anatema",
    "anatemas": "anatema",
    "anatemat": "anatema",
    "anatemats": "anatema",
    "anatemer": "anatema",
    "anatemerna": "anatema",
    "anatemernas": "anatema",
    "anatemers": "anatema",
    "anatomen": "anatom",
    "anatomens": "anatom",
    "anatomer": "anatom",
    "anatomerna": "anatom",
    "anatomernas": "anatom",
    "anatomers": "anatom",
    "anatomien": "anatomi",
    "anatomiens": "anatomi",
    "anatomin": "anatomi",
    "anatomins": "anatomi",
    "anatomis": "anatomi",
    "anatomiska": "anatomisk",
    "anatomiskare": "anatomisk",
    "anatomiskares": "anatomisk",
    "anatomiskas": "anatomisk",
    "anatomiskast": "anatomisk",
    "anatomiskaste": "anatomisk",
    "anatomiskastes": "anatomisk",
    "anatomiskasts": "anatomisk",
    "anatomiske": "anatomisk",
    "anatomiskes": "anatomisk",
    "anatomisks": "anatomisk",
    "anatomiskt": "anatomisk",
    "anatomiskts": "anatomisk",
    "anatoms": "anatom",
    "anats": "ana",
    "anbefall": "anbefalla",
    "anbefallande": "anbefalla",
    "anbefallanden": "anbefallande",
    "anbefallandena": "anbefallande",
    "anbefallandenas": "anbefallande",
    "anbefallandens": "anbefallande",
    "anbefallandes": "anbefallande",
    "anbefallandet": "anbefallande",
    "anbefallandets": "anbefallande",
    "anbefallas": "anbefalla",
    "anbefalld": "anbefalla",
    "anbefallda": "anbefalla",
    "anbefalldas": "anbefalla",
    "anbefallde": "anbefalla",
    "anbefalldes": "anbefalla",
    "anbefallds": "anbefalla",
    "anbefaller": "anbefalla",
    "anbefalles": "anbefalla",
    "anbefalls": "anbefalla",
    "anbefallt": "anbefalla",
    "anbefallts": "anbefalla",
    "anbelangade": "anbelanga",
    "anbelangades": "anbelanga",
    "anbelangande": "anbelanga",
    "anbelanganden": "anbelangande",
    "anbelangandena": "anbelangande",
    "anbelangandenas": "anbelangande",
    "anbelangandens": "anbelangande",
    "anbelangandes": "anbelangande",
    "anbelangandet": "anbelangande",
    "anbelangandets": "anbelangande",
    "anbelangar": "anbelanga",
    "anbelangas": "anbelanga",
    "anbelangat": "anbelanga",
    "anbelangats": "anbelanga",
    "anblickar": "anblick",
    "anblickarna": "anblick",
    "anblickarnas": "anblick",
    "anblickars": "anblick",
    "anblicken": "anblick",
    "anblickens": "anblick",
    "anblicks": "anblick",
    "anbragt": "anbringa",
    "anbragte": "anbringa",
    "anbragtes": "anbringa",
    "anbragts": "anbringa",
    "anbring": "anbringa",
    "anbringad": "anbringa",
    "anbringade": "anbringa",
    "anbringades": "anbringa",
    "anbringads": "anbringa",
    "anbringande": "anbringa",
    "anbringanden": "anbringande",
    "anbringandena": "anbringande",
    "anbringandenas": "anbringande",
    "anbringandens": "anbringande",
    "anbringandes": "anbringande",
    "anbringandet": "anbringande",
    "anbringandets": "anbringande",
    "anbringar": "anbringa",
    "anbringas": "anbringa",
    "anbringat": "anbringa",
    "anbringats": "anbringa",
    "anbrotten": "anbrott",
    "anbrottens": "anbrott",
    "anbrottet": "anbrott",
    "anbrottets": "anbrott",
    "anbrotts": "anbrott",
    "anbuden": "anbud",
    "anbudens": "anbud",
    "anbudet": "anbud",
    "anbudets": "anbud",
    "anbuds": "anbud",
    "ancienniteten": "anciennitet",
    "anciennitetens": "anciennitet",
    "ancienniteter": "anciennitet",
    "ancienniteterna": "anciennitet",
    "ancienniteternas": "anciennitet",
    "ancienniteters": "anciennitet",
    "anciennitets": "anciennitet",
    "andades": "andas",
    "andakten": "andakt",
    "andaktens": "andakt",
    "andakter": "andakt",
    "andakterna": "andakt",
    "andakternas": "andakt",
    "andakters": "andakt",
    "andakts": "andakt",
    "andaktsboken": "andaktsbok",
    "andaktsbokens": "andaktsbok",
    "andaktsboks": "andaktsbok",
    "andaktsböcker": "andaktsbok",
    "andaktsböckerna": "andaktsbok",
    "andaktsböckernas": "andaktsbok",
    "andaktsböckers": "andaktsbok",
    "andaktsfulla": "andaktsfull",
    "andaktsfullare": "andaktsfull",
    "andaktsfullares": "andaktsfull",
    "andaktsfullas": "andaktsfull",
    "andaktsfullast": "andaktsfull",
    "andaktsfullaste": "andaktsfull",
    "andaktsfullastes": "andaktsfull",
    "andaktsfullasts": "andaktsfull",
    "andaktsfulle": "andaktsfull",
    "andaktsfulles": "andaktsfull",
    "andaktsfullheten": "andaktsfullhet",
    "andaktsfullhetens": "andaktsfullhet",
    "andaktsfullhets": "andaktsfullhet",
    "andaktsfulls": "andaktsfull",
    "andaktsfullt": "andaktsfull",
    "andaktsfullts": "andaktsfull",
    "andaktslitteraturen": "andaktslitteratur",
    "andaktslitteraturens": "andaktslitteratur",
    "andaktslitteraturs": "andaktslitteratur",
    "andan": "anda",
    "andans": "anda",
    "andanten": "andante",
    "andantena": "andante",
    "andantenas": "andante",
    "andantens": "andante",
    "andantes": "andante",
    "andantet": "andante",
    "andantets": "andante",
    "andar": "ande",
    "andarna": "ande",
    "andarnas": "ande",
    "andars": "ande",
    "andas": "anda",
    "andats": "andas",
    "andebesvärjar": "andebesvärjare",
    "andebesvärjaren": "andebesvärjare",
    "andebesvärjarens": "andebesvärjare",
    "andebesvärjares": "andebesvärjare",
    "andebesvärjarna": "andebesvärjare",
    "andebesvärjarnas": "andebesvärjare",
    "andebesvärjelsen": "andebesvärjelse",
    "andebesvärjelsens": "andebesvärjelse",
    "andebesvärjelser": "andebesvärjelse",
    "andebesvärjelserna": "andebesvärjelse",
    "andebesvärjelsernas": "andebesvärjelse",
    "andebesvärjelsers": "andebesvärjelse",
    "andebesvärjelses": "andebesvärjelse",
    "andedragen": "andedrag",
    "andedragens": "andedrag",
    "andedraget": "andedrag",
    "andedragets": "andedrag",
    "andedrags": "andedrag",
    "andedräkten": "andedräkt",
    "andedräktens": "andedräkt",
    "andedräkter": "andedräkt",
    "andedräkterna": "andedräkt",
    "andedräkternas": "andedräkt",
    "andedräkters": "andedräkt",
    "andedräkts": "andedräkt",
    "andefattiga": "andefattig",
    "andefattigare": "andefattig",
    "andefattigares": "andefattig",
    "andefattigas": "andefattig",
    "andefattigast": "andefattig",
    "andefattigaste": "andefattig",
    "andefattigastes": "andefattig",
    "andefattigasts": "andefattig",
    "andefattigdomar": "andefattigdom",
    "andefattigdomarna": "andefattigdom",
    "andefattigdomarnas": "andefattigdom",
    "andefattigdomars": "andefattigdom",
    "andefattigdomen": "andefattigdom",
    "andefattigdomens": "andefattigdom",
    "andefattigdoms": "andefattigdom",
    "andefattige": "andefattig",
    "andefattiges": "andefattig",
    "andefattigheten": "andefattighet",
    "andefattighetens": "andefattighet",
    "andefattighets": "andefattighet",
    "andefattigs": "andefattig",
    "andefattigt": "andefattig",
    "andefattigts": "andefattig",
    "andelar": "andel",
    "andelarna": "andel",
    "andelarnas": "andel",
    "andelars": "andel",
    "andelen": "andel",
    "andelens": "andel",
    "andels": "andel",
    "andelsföreningar": "andelsförening",
    "andelsföreningarna": "andelsförening",
    "andelsföreningarnas": "andelsförening",
    "andelsföreningars": "andelsförening",
    "andelsföreningen": "andelsförening",
    "andelsföreningens": "andelsförening",
    "andelsförenings": "andelsförening",
    "andemeningar": "andemening",
    "andemeningarna": "andemening",
    "andemeningarnas": "andemening",
    "andemeningars": "andemening",
    "andemeningen": "andemening",
    "andemeningens": "andemening",
    "andemenings": "andemening",
    "anden": "ande",
    "andens": "ande",
    "andes": "ande",
    "andeskådar": "andeskådare",
    "andeskådaren": "andeskådare",
    "andeskådarens": "andeskådare",
    "andeskådares": "andeskådare",
    "andeskådarna": "andeskådare",
    "andeskådarnas": "andeskådare",
    "andetagen": "andetag",
    "andetagens": "andetag",
    "andetaget": "andetag",
    "andetagets": "andetag",
    "andetags": "andetag",
    "andeväsena": "andeväsen",
    "andeväsenas": "andeväsen",
    "andeväsendet": "andeväsen",
    "andeväsendets": "andeväsen",
    "andeväsens": "andeväsen",
    "andeögonen": "andeögon",
    "andeögonens": "andeögon",
    "andeögons": "andeögon",
    "andfiguren": "andfigur",
    "andfigurens": "andfigur",
    "andfigurer": "andfigur",
    "andfigurerna": "andfigur",
    "andfigurernas": "andfigur",
    "andfigurers": "andfigur",
    "andfigurs": "andfigur",
    "andfådda": "andfådd",
    "andfåddare": "andfådd",
    "andfåddares": "andfådd",
    "andfåddas": "andfådd",
    "andfåddast": "andfådd",
    "andfåddaste": "andfådd",
    "andfåddastes": "andfådd",
    "andfåddasts": "andfådd",
    "andfådde": "andfådd",
    "andfåddes": "andfådd",
    "andfåddheten": "andfåddhet",
    "andfåddhetens": "andfåddhet",
    "andfåddhets": "andfåddhet",
    "andfådds": "andfådd",
    "andfågeln": "andfågel",
    "andfågelns": "andfågel",
    "andfågels": "andfågel",
    "andfåglar": "andfågel",
    "andfåglarna": "andfågel",
    "andfåglarnas": "andfågel",
    "andfåglars": "andfågel",
    "andfått": "andfådd",
    "andfåtts": "andfådd",
    "andhämtningar": "andhämtning",
    "andhämtningarna": "andhämtning",
    "andhämtningarnas": "andhämtning",
    "andhämtningars": "andhämtning",
    "andhämtningen": "andhämtning",
    "andhämtningens": "andhämtning",
    "andhämtnings": "andhämtning",
    "andhämtningspausen": "andhämtningspaus",
    "andhämtningspausens": "andhämtningspaus",
    "andhämtningspauser": "andhämtningspaus",
    "andhämtningspauserna": "andhämtningspaus",
    "andhämtningspausernas": "andhämtningspaus",
    "andhämtningspausers": "andhämtningspaus",
    "andjakten": "andjakt",
    "andjaktens": "andjakt",
    "andjakter": "andjakt",
    "andjakterna": "andjakt",
    "andjakternas": "andjakt",
    "andjakters": "andjakt",
    "andjakts": "andjakt",
    "andliga": "andlig",
    "andligare": "andlig",
    "andligares": "andlig",
    "andligas": "andlig",
    "andligast": "andlig",
    "andligaste": "andlig",
    "andligastes": "andlig",
    "andligasts": "andlig",
    "andlige": "andlig",
    "andliges": "andlig",
    "andligheten": "andlighet",
    "andlighetens": "andlighet",
    "andlighets": "andlighet",
    "andligs": "andlig",
    "andligt": "andlig",
    "andligts": "andlig",
    "andlösa": "andlös",
    "andlösare": "andlös",
    "andlösares": "andlös",
    "andlösas": "andlös",
    "andlösast": "andlös",
    "andlösaste": "andlös",
    "andlösastes": "andlös",
    "andlösasts": "andlös",
    "andlöse": "andlös",
    "andlöses": "andlös",
    "andlösheten": "andlöshet",
    "andlöshetens": "andlöshet",
    "andlöshets": "andlöshet",
    "andlöst": "andlös",
    "andlösts": "andlös",
    "andmaten": "andmat",
    "andmatens": "andmat",
    "andmats": "andmat",
    "andningar": "andning",
    "andningarna": "andning",
    "andningarnas": "andning",
    "andningars": "andning",
    "andningen": "andning",
    "andningens": "andning",
    "andnings": "andning",
    "andningsapparaten": "andningsapparat",
    "andningsapparatens": "andningsapparat",
    "andningsapparater": "andningsapparat",
    "andningsapparaterna": "andningsapparat",
    "andningsapparaternas": "andningsapparat",
    "andningsapparaters": "andningsapparat",
    "andningsapparats": "andningsapparat",
    "andningsenzymen": "andningsenzym",
    "andningsenzymens": "andningsenzym",
    "andningsenzymer": "andningsenzym",
    "andningsenzymerna": "andningsenzym",
    "andningsenzymernas": "andningsenzym",
    "andningsenzymers": "andningsenzym",
    "andningsenzymet": "andningsenzym",
    "andningsenzymets": "andningsenzym",
    "andningsenzyms": "andningsenzym",
    "andningshålen": "andningshål",
    "andningshålens": "andningshål",
    "andningshålet": "andningshål",
    "andningshålets": "andningshål",
    "andningshåls": "andningshål",
    "andningsorganen": "andningsorgan",
    "andningsorganens": "andningsorgan",
    "andningsorganet": "andningsorgan",
    "andningsorganets": "andningsorgan",
    "andningsorgans": "andningsorgan",
    "andningspausen": "andningspaus",
    "andningspausens": "andningspaus",
    "andningspauser": "andningspaus",
    "andningspauserna": "andningspaus",
    "andningspausernas": "andningspaus",
    "andningspausers": "andningspaus",
    "andningsreaktionen": "andningsreaktion",
    "andningsreaktionens": "andningsreaktion",
    "andningsreaktioner": "andningsreaktion",
    "andningsreaktionerna": "andningsreaktion",
    "andningsreaktionernas": "andningsreaktion",
    "andningsreaktioners": "andningsreaktion",
    "andningsreaktions": "andningsreaktion",
    "andningsrören": "andningsrör",
    "andningsrörens": "andningsrör",
    "andningsröret": "andningsrör",
    "andningsrörets": "andningsrör",
    "andningsrörs": "andningsrör",
    "andningssvårigheten": "andningssvårighet",
    "andningssvårighetens": "andningssvårighet",
    "andningssvårigheter": "andningssvårighet",
    "andningssvårigheterna": "andningssvårighet",
    "andningssvårigheternas": "andningssvårighet",
    "andningssvårigheters": "andningssvårighet",
    "andningssvårighets": "andningssvårighet",
    "andningsuppehållen": "andningsuppehåll",
    "andningsuppehållens": "andningsuppehåll",
    "andningsuppehållet": "andningsuppehåll",
    "andningsuppehållets": "andningsuppehåll",
    "andningsuppehålls": "andningsuppehåll",
    "andningsvägarna": "andningsvägar",
    "andningsvägarnas": "andningsvägar",
    "andningsvägars": "andningsvägar",
    "andningsvägs": "andningsvägar",
    "andnöden": "andnöd",
    "andnödens": "andnöd",
    "andnöds": "andnöd",
    "andorranen": "andorran",
    "andorranens": "andorran",
    "andorraner": "andorran",
    "andorranerna": "andorran",
    "andorranernas": "andorran",
    "andorraners": "andorran",
    "andorrans": "andorran",
    "andorranska": "andorransk",
    "andorranskan": "andorranska",
    "andorranskans": "andorranska",
    "andorranskare": "andorransk",
    "andorranskares": "andorransk",
    "andorranskas": "andorranska",
    "andorranskast": "andorransk",
    "andorranskaste": "andorransk",
    "andorranskastes": "andorransk",
    "andorranskasts": "andorransk",
    "andorranske": "andorranska",
    "andorranskes": "andorransk",
    "andorranskor": "andorranska",
    "andorranskorna": "andorranska",
    "andorranskornas": "andorranska",
    "andorranskors": "andorranska",
    "andorransks": "andorransk",
    "andorranskt": "andorransk",
    "andorranskts": "andorransk",
    "andra": "två",
    "andrabasar": "andrabas",
    "andrabasarna": "andrabas",
    "andrabasarnas": "andrabas",
    "andrabasars": "andrabas",
    "andrabasen": "andrabas",
    "andrabasens": "andrabas",
    "andrabilar": "andrabil",
    "andrabilarna": "andrabil",
    "andrabilarnas": "andrabil",
    "andrabilars": "andrabil",
    "andrabilen": "andrabil",
    "andrabilens": "andrabil",
    "andrabils": "andrabil",
    "andraderivat": "andraderivata",
    "andraderivatan": "andraderivata",
    "andraderivatans": "andraderivata",
    "andraderivatas": "andraderivata",
    "andraderivate": "andraderivata",
    "andraderivator": "andraderivata",
    "andraderivatorna": "andraderivata",
    "andraderivatornas": "andraderivata",
    "andraderivators": "andraderivata",
    "andraderivats": "andraderivata",
    "andrag": "andra",
    "andraga": "andra",
    "andragande": "andra",
    "andraganden": "andragande",
    "andragandena": "andragande",
    "andragandenas": "andragande",
    "andragandens": "andragande",
    "andragandes": "andragande",
    "andragandet": "andragande",
    "andragandets": "andragande",
    "andragas": "andra",
    "andrage": "andra",
    "andragen": "andrag",
    "andragens": "andrag",
    "andrager": "andra",
    "andrages": "andra",
    "andraget": "andrag",
    "andragets": "andrag",
    "andragit": "andra",
    "andragits": "andra",
    "andragna": "andra",
    "andragnas": "andra",
    "andragne": "andra",
    "andragnes": "andra",
    "andragradsekvationen": "andragradsekvation",
    "andragradsekvationens": "andragradsekvation",
    "andragradsekvationer": "andragradsekvation",
    "andragradsekvationerna": "andragradsekvation",
    "andragradsekvationernas": "andragradsekvation",
    "andragradsekvationers": "andragradsekvation",
    "andragradsekvations": "andragradsekvation",
    "andrags": "andrag",
    "andrahandsbutiken": "andrahandsbutik",
    "andrahandsbutikens": "andrahandsbutik",
    "andrahandsbutiker": "andrahandsbutik",
    "andrahandsbutikerna": "andrahandsbutik",
    "andrahandsbutikernas": "andrahandsbutik",
    "andrahandsbutikers": "andrahandsbutik",
    "andrahandsbutiks": "andrahandsbutik",
    "andrahandsfaktoreren": "andrahandsfaktorer",
    "andrahandsfaktorerens": "andrahandsfaktorer",
    "andrahandsfaktorerer": "andrahandsfaktorer",
    "andrahandsfaktorererna": "andrahandsfaktorer",
    "andrahandsfaktorerernas": "andrahandsfaktorer",
    "andrahandsfaktorerers": "andrahandsfaktorer",
    "andrahandsfaktorers": "andrahandsfaktorer",
    "andrahandsföremålen": "andrahandsföremål",
    "andrahandsföremålens": "andrahandsföremål",
    "andrahandsföremålet": "andrahandsföremål",
    "andrahandsföremålets": "andrahandsföremål",
    "andrahandsföremåls": "andrahandsföremål",
    "andrahandsinformationen": "andrahandsinformation",
    "andrahandsinformationens": "andrahandsinformation",
    "andrahandsinformationer": "andrahandsinformation",
    "andrahandsinformationerna": "andrahandsinformation",
    "andrahandsinformationernas": "andrahandsinformation",
    "andrahandsinformationers": "andrahandsinformation",
    "andrahandsinformations": "andrahandsinformation",
    "andrahandskäll": "andrahandskälla",
    "andrahandskällan": "andrahandskälla",
    "andrahandskällans": "andrahandskälla",
    "andrahandskällas": "andrahandskälla",
    "andrahandskälle": "andrahandskälla",
    "andrahandskällor": "andrahandskälla",
    "andrahandskällorna": "andrahandskälla",
    "andrahandskällornas": "andrahandskälla",
    "andrahandskällors": "andrahandskälla",
    "andrahandskälls": "andrahandskälla",
    "andrahandsuppgiften": "andrahandsuppgift",
    "andrahandsuppgiftens": "andrahandsuppgift",
    "andrahandsuppgifter": "andrahandsuppgift",
    "andrahandsuppgifterna": "andrahandsuppgift",
    "andrahandsuppgifternas": "andrahandsuppgift",
    "andrahandsuppgifters": "andrahandsuppgift",
    "andrahandsuppgifts": "andrahandsuppgift",
    "andrahandsvalen": "andrahandsval",
    "andrahandsvalens": "andrahandsval",
    "andrahandsvalet": "andrahandsval",
    "andrahandsvalets": "andrahandsval",
    "andrahandsvals": "andrahandsval",
    "andrahandsvärden": "andrahandsvärde",
    "andrahandsvärdena": "andrahandsvärde",
    "andrahandsvärdenas": "andrahandsvärde",
    "andrahandsvärdens": "andrahandsvärde",
    "andrahandsvärdes": "andrahandsvärde",
    "andrahandsvärdet": "andrahandsvärde",
    "andrahandsvärdets": "andrahandsvärde",
    "andrak": "andrake",
    "andrakar": "andrake",
    "andrakarna": "andrake",
    "andrakarnas": "andrake",
    "andrakars": "andrake",
    "andraken": "andrake",
    "andrakens": "andrake",
    "andrakes": "andrake",
    "andraklassbiljetten": "andraklassbiljett",
    "andraklassbiljettens": "andraklassbiljett",
    "andraklassbiljetter": "andraklassbiljett",
    "andraklassbiljetterna": "andraklassbiljett",
    "andraklassbiljetternas": "andraklassbiljett",
    "andraklassbiljetters": "andraklassbiljett",
    "andraklassbiljetts": "andraklassbiljett",
    "andraklasspassagerar": "andraklasspassagerare",
    "andraklasspassageraren": "andraklasspassagerare",
    "andraklasspassagerarens": "andraklasspassagerare",
    "andraklasspassagerares": "andraklasspassagerare",
    "andraklasspassagerarna": "andraklasspassagerare",
    "andraklasspassagerarnas": "andraklasspassagerare",
    "andraks": "andrake",
    "andranamnen": "andranamn",
    "andranamnens": "andranamn",
    "andranamnet": "andranamn",
    "andranamnets": "andranamn",
    "andranamns": "andranamn",
    "andraplaceringar": "andraplacering",
    "andraplaceringarna": "andraplacering",
    "andraplaceringarnas": "andraplacering",
    "andraplaceringars": "andraplacering",
    "andraplaceringen": "andraplacering",
    "andraplaceringens": "andraplacering",
    "andraplacerings": "andraplacering",
    "andraplatsen": "andraplats",
    "andraplatsens": "andraplats",
    "andraplatser": "andraplats",
    "andraplatserna": "andraplats",
    "andraplatsernas": "andraplats",
    "andraplatsers": "andraplats",
    "andrar": "andur",
    "andrarna": "andur",
    "andrarnas": "andur",
    "andrars": "andur",
    "andras": "två",
    "andratenoren": "andratenor",
    "andratenorens": "andratenor",
    "andratenorer": "andratenor",
    "andratenorerna": "andratenor",
    "andratenorernas": "andratenor",
    "andratenorers": "andratenor",
    "andratenors": "andratenor",
    "andratidningar": "andratidning",
    "andratidningarna": "andratidning",
    "andratidningarnas": "andratidning",
    "andratidningars": "andratidning",
    "andratidningen": "andratidning",
    "andratidningens": "andratidning",
    "andratidnings": "andratidning",
    "andre": "två",
    "andreaskorsen": "andreaskors",
    "andreaskorsens": "andreaskors",
    "andreaskorset": "andreaskors",
    "andreaskorsets": "andreaskors",
    "andrebasar": "andrebas",
    "andrebasarna": "andrebas",
    "andrebasarnas": "andrebas",
    "andrebasars": "andrebas",
    "andrebasen": "andrebas",
    "andrebasens": "andrebas",
    "andrechefen": "andrechef",
    "andrechefens": "andrechef",
    "andrechefer": "andrechef",
    "andrecheferna": "andrechef",
    "andrechefernas": "andrechef",
    "andrechefers": "andrechef",
    "andrechefs": "andrechef",
    "andres": "två",
    "andretenoren": "andretenor",
    "andretenorens": "andretenor",
    "andretenorer": "andretenor",
    "andretenorerna": "andretenor",
    "andretenorernas": "andretenor",
    "andretenorers": "andretenor",
    "andretenors": "andretenor",
    "androfobien": "androfobi",
    "androfobiens": "androfobi",
    "androfobin": "androfobi",
    "androfobins": "androfobi",
    "androfobis": "androfobi",
    "androg": "andra",
    "androge": "andra",
    "androgen": "androgener",
    "androgenerna": "androgener",
    "androgenernas": "androgener",
    "androgeners": "androgener",
    "androges": "andra",
    "androgs": "andra",
    "androgyna": "androgyn",
    "androgynare": "androgyn",
    "androgynares": "androgyn",
    "androgynas": "androgyn",
    "androgynast": "androgyn",
    "androgynaste": "androgyn",
    "androgynastes": "androgyn",
    "androgynasts": "androgyn",
    "androgyne": "androgyn",
    "androgynen": "androgyn",
    "androgynens": "androgyn",
    "androgyner": "androgyn",
    "androgynerna": "androgyn",
    "androgynernas": "androgyn",
    "androgyners": "androgyn",
    "androgynes": "androgyn",
    "androgynheten": "androgynhet",
    "androgynhetens": "androgynhet",
    "androgynhets": "androgynhet",
    "androgyns": "androgyn",
    "androgynt": "androgyn",
    "androgynts": "androgyn",
    "androiden": "android",
    "androidens": "android",
    "androider": "android",
    "androiderna": "android",
    "androidernas": "android",
    "androiders": "android",
    "androids": "android",
    "andrummet": "andrum",
    "andrummets": "andrum",
    "andrums": "andrum",
    "andryga": "andryg",
    "andrygare": "andryg",
    "andrygares": "andryg",
    "andrygas": "andryg",
    "andrygast": "andryg",
    "andrygaste": "andryg",
    "andrygastes": "andryg",
    "andrygasts": "andryg",
    "andryge": "andryg",
    "andryges": "andryg",
    "andrygs": "andryg",
    "andrygt": "andryg",
    "andrygts": "andryg",
    "ands": "and",
    "andsträcken": "andsträck",
    "andsträckens": "andsträck",
    "andsträcket": "andsträck",
    "andsträckets": "andsträck",
    "andsträcks": "andsträck",
    "andtrutenheten": "andtrutenhet",
    "andtrutenhetens": "andtrutenhet",
    "andtrutenhets": "andtrutenhet",
    "andtrutens": "andtruten",
    "andtrutet": "andtruten",
    "andtrutets": "andtruten",
    "andtrutna": "andtruten",
    "andtrutnare": "andtruten",
    "andtrutnares": "andtruten",
    "andtrutnas": "andtruten",
    "andtrutnast": "andtruten",
    "andtrutnaste": "andtruten",
    "andtrutnastes": "andtruten",
    "andtrutnasts": "andtruten",
    "andtrutne": "andtruten",
    "andtrutnes": "andtruten",
    "andtäppan": "andtäppa",
    "andtäppans": "andtäppa",
    "andtäppas": "andtäppa",
    "andtäppta": "andtäppt",
    "andtäpptare": "andtäppt",
    "andtäpptares": "andtäppt",
    "andtäpptas": "andtäppt",
    "andtäpptast": "andtäppt",
    "andtäpptaste": "andtäppt",
    "andtäpptastes": "andtäppt",
    "andtäpptasts": "andtäppt",
    "andtäppte": "andtäppt",
    "andtäpptes": "andtäppt",
    "andtäppts": "andtäppt",
    "anduren": "andur",
    "andurens": "andur",
    "andurn": "andur",
    "andurns": "andur",
    "andurs": "andur",
    "andäktiga": "andäktig",
    "andäktigare": "andäktig",
    "andäktigares": "andäktig",
    "andäktigas": "andäktig",
    "andäktigast": "andäktig",
    "andäktigaste": "andäktig",
    "andäktigastes": "andäktig",
    "andäktigasts": "andäktig",
    "andäktige": "andäktig",
    "andäktiges": "andäktig",
    "andäktigheten": "andäktighet",
    "andäktighetens": "andäktighet",
    "andäktighets": "andäktighet",
    "andäktigs": "andäktig",
    "andäktigt": "andäktig",
    "andäktigts": "andäktig",
    "anekdoten": "anekdot",
    "anekdotens": "anekdot",
    "anekdoter": "anekdot",
    "anekdoterna": "anekdot",
    "anekdoternas": "anekdot",
    "anekdoters": "anekdot",
    "anekdotflor": "anekdotflora",
    "anekdotfloran": "anekdotflora",
    "anekdotflorans": "anekdotflora",
    "anekdotfloras": "anekdotflora",
    "anekdotflore": "anekdotflora",
    "anekdotfloror": "anekdotflora",
    "anekdotflororna": "anekdotflora",
    "anekdotflorornas": "anekdotflora",
    "anekdotflorors": "anekdotflora",
    "anekdotflors": "anekdotflora",
    "anekdotiska": "anekdotisk",
    "anekdotiskare": "anekdotisk",
    "anekdotiskares": "anekdotisk",
    "anekdotiskas": "anekdotisk",
    "anekdotiskast": "anekdotisk",
    "anekdotiskaste": "anekdotisk",
    "anekdotiskastes": "anekdotisk",
    "anekdotiskasts": "anekdotisk",
    "anekdotiske": "anekdotisk",
    "anekdotiskes": "anekdotisk",
    "anekdotisks": "anekdotisk",
    "anekdotiskt": "anekdotisk",
    "anekdotiskts": "anekdotisk",
    "anekdots": "anekdot",
    "anemien": "anemi",
    "anemiens": "anemi",
    "anemier": "anemi",
    "anemierna": "anemi",
    "anemiernas": "anemi",
    "anemiers": "anemi",
    "anemin": "anemi",
    "anemins": "anemi",
    "anemis": "anemi",
    "anemiska": "anemisk",
    "anemiskare": "anemisk",
    "anemiskares": "anemisk",
    "anemiskas": "anemisk",
    "anemiskast": "anemisk",
    "anemiskaste": "anemisk",
    "anemiskastes": "anemisk",
    "anemiskasts": "anemisk",
    "anemiske": "anemisk",
    "anemiskes": "anemisk",
    "anemisks": "anemisk",
    "anemiskt": "anemisk",
    "anemiskts": "anemisk",
    "anemometern": "anemometer",
    "anemometerns": "anemometer",
    "anemometers": "anemometer",
    "anemometrar": "anemometer",
    "anemometrarna": "anemometer",
    "anemometrarnas": "anemometer",
    "anemometrars": "anemometer",
    "anemonen": "anemon",
    "anemonens": "anemon",
    "anemoner": "anemon",
    "anemonerna": "anemon",
    "anemonernas": "anemon",
    "anemoners": "anemon",
    "anemons": "anemon",
    "aneroidbarometern": "aneroidbarometer",
    "aneroidbarometerns": "aneroidbarometer",
    "aneroidbarometers": "aneroidbarometer",
    "aneroidbarometrar": "aneroidbarometer",
    "aneroidbarometrarna": "aneroidbarometer",
    "aneroidbarometrarnas": "aneroidbarometer",
    "aneroidbarometrars": "aneroidbarometer",
    "anestesien": "anestesi",
    "anestesiens": "anestesi",
    "anestesier": "anestesi",
    "anestesierna": "anestesi",
    "anestesiernas": "anestesi",
    "anestesiers": "anestesi",
    "anestesin": "anestesi",
    "anestesins": "anestesi",
    "anestesiologen": "anestesiolog",
    "anestesiologens": "anestesiolog",
    "anestesiologer": "anestesiolog",
    "anestesiologerna": "anestesiolog",
    "anestesiologernas": "anestesiolog",
    "anestesiologers": "anestesiolog",
    "anestesiologien": "anestesiologi",
    "anestesiologiens": "anestesiologi",
    "anestesiologin": "anestesiologi",
    "anestesiologins": "anestesiologi",
    "anestesiologis": "anestesiologi",
    "anestesiologs": "anestesiolog",
    "anestesirummen": "anestesirum",
    "anestesirummens": "anestesirum",
    "anestesirummet": "anestesirum",
    "anestesirummets": "anestesirum",
    "anestesirums": "anestesirum",
    "anestesis": "anestesi",
    "anestetikan": "anestetika",
    "anestetikana": "anestetika",
    "anestetikanas": "anestetika",
    "anestetikans": "anestetika",
    "anestetikas": "anestetika",
    "anestetikat": "anestetika",
    "anestetikats": "anestetika",
    "anestetiska": "anestetisk",
    "anestetiskare": "anestetisk",
    "anestetiskares": "anestetisk",
    "anestetiskas": "anestetisk",
    "anestetiskast": "anestetisk",
    "anestetiskaste": "anestetisk",
    "anestetiskastes": "anestetisk",
    "anestetiskasts": "anestetisk",
    "anestetiske": "anestetisk",
    "anestetiskes": "anestetisk",
    "anestetisks": "anestetisk",
    "anestetiskt": "anestetisk",
    "anestetiskts": "anestetisk",
    "anfadern": "anfader",
    "anfaderns": "anfader",
    "anfaders": "anfader",
    "anfall": "anfalla",
    "anfallande": "anfalla",
    "anfallanden": "anfallande",
    "anfallandena": "anfallande",
    "anfallandenas": "anfallande",
    "anfallandens": "anfallande",
    "anfallandes": "anfallande",
    "anfallandet": "anfallande",
    "anfallandets": "anfallande",
    "anfallar": "anfallare",
    "anfallaren": "anfallare",
    "anfallarens": "anfallare",
    "anfallares": "anfallare",
    "anfallarna": "anfallare",
    "anfallarnas": "anfallare",
    "anfallas": "anfalla",
    "anfalle": "anfalla",
    "anfallen": "anfalla",
    "anfallens": "anfalla",
    "anfaller": "anfalla",
    "anfalles": "anfalla",
    "anfallet": "anfalla",
    "anfallets": "anfalla",
    "anfallit": "anfalla",
    "anfallits": "anfalla",
    "anfallna": "anfalla",
    "anfallnas": "anfalla",
    "anfallne": "anfalla",
    "anfallnes": "anfalla",
    "anfalls": "anfalla",
    "anfallsbasen": "anfallsbas",
    "anfallsbasens": "anfallsbas",
    "anfallsbaser": "anfallsbas",
    "anfallsbaserna": "anfallsbas",
    "anfallsbasernas": "anfallsbas",
    "anfallsbasers": "anfallsbas",
    "anfallsfronten": "anfallsfront",
    "anfallsfrontens": "anfallsfront",
    "anfallsfronter": "anfallsfront",
    "anfallsfronterna": "anfallsfront",
    "anfallsfronternas": "anfallsfront",
    "anfallsfronters": "anfallsfront",
    "anfallsfronts": "anfallsfront",
    "anfallskrigen": "anfallskrig",
    "anfallskrigens": "anfallskrig",
    "anfallskriget": "anfallskrig",
    "anfallskrigets": "anfallskrig",
    "anfallskrigs": "anfallskrig",
    "anfallslinjen": "anfallslinje",
    "anfallslinjens": "anfallslinje",
    "anfallslinjer": "anfallslinje",
    "anfallslinjerna": "anfallslinje",
    "anfallslinjernas": "anfallslinje",
    "anfallslinjers": "anfallslinje",
    "anfallslinjes": "anfallslinje",
    "anfallsmässiga": "anfallsmässig",
    "anfallsmässigare": "anfallsmässig",
    "anfallsmässigares": "anfallsmässig",
    "anfallsmässigas": "anfallsmässig",
    "anfallsmässigast": "anfallsmässig",
    "anfallsmässigaste": "anfallsmässig",
    "anfallsmässigastes": "anfallsmässig",
    "anfallsmässigasts": "anfallsmässig",
    "anfallsmässige": "anfallsmässig",
    "anfallsmässiges": "anfallsmässig",
    "anfallsmässigs": "anfallsmässig",
    "anfallsmässigt": "anfallsmässig",
    "anfallsmässigts": "anfallsmässig",
    "anfallsspelar": "anfallsspelare",
    "anfallsspelaren": "anfallsspelare",
    "anfallsspelarens": "anfallsspelare",
    "anfallsspelares": "anfallsspelare",
    "anfallsspelarna": "anfallsspelare",
    "anfallsspelarnas": "anfallsspelare",
    "anfallsspelen": "anfallsspel",
    "anfallsspelens": "anfallsspel",
    "anfallsspelet": "anfallsspel",
    "anfallsspelets": "anfallsspel",
    "anfallsspels": "anfallsspel",
    "anfallsvinkeln": "anfallsvinkel",
    "anfallsvinkelns": "anfallsvinkel",
    "anfallsvinkels": "anfallsvinkel",
    "anfallsvinklar": "anfallsvinkel",
    "anfallsvinklarna": "anfallsvinkel",
    "anfallsvinklarnas": "anfallsvinkel",
    "anfallsvinklars": "anfallsvinkel",
    "anfallsvågen": "anfallsvåg",
    "anfallsvågens": "anfallsvåg",
    "anfallsvågor": "anfallsvåg",
    "anfallsvågorna": "anfallsvåg",
    "anfallsvågornas": "anfallsvåg",
    "anfallsvågors": "anfallsvåg",
    "anfallsvågs": "anfallsvåg",
    "anfangen": "anfang",
    "anfangens": "anfang",
    "anfanger": "anfang",
    "anfangerna": "anfang",
    "anfangernas": "anfang",
    "anfangers": "anfang",
    "anfangs": "anfang",
    "anfarten": "anfart",
    "anfartens": "anfart",
    "anfarter": "anfart",
    "anfarterna": "anfart",
    "anfarternas": "anfart",
    "anfarters": "anfart",
    "anfarts": "anfart",
    "anflogen": "anflog",
    "anflogens": "anflog",
    "anfloget": "anflog",
    "anflogets": "anflog",
    "anflogs": "anflog",
    "anflygningar": "anflygning",
    "anflygningarna": "anflygning",
    "anflygningarnas": "anflygning",
    "anflygningars": "anflygning",
    "anflygningen": "anflygning",
    "anflygningens": "anflygning",
    "anflygnings": "anflygning",
    "anfordrans": "anfordran",
    "anfrät": "anfräta",
    "anfrätande": "anfräta",
    "anfrätanden": "anfrätande",
    "anfrätandena": "anfrätande",
    "anfrätandenas": "anfrätande",
    "anfrätandens": "anfrätande",
    "anfrätandes": "anfrätande",
    "anfrätandet": "anfrätande",
    "anfrätandets": "anfrätande",
    "anfrätas": "anfräta",
    "anfräter": "anfräta",
    "anfrätes": "anfräta",
    "anfräts": "anfräta",
    "anfrätt": "anfräta",
    "anfrätta": "anfräta",
    "anfrättas": "anfräta",
    "anfrätte": "anfräta",
    "anfrättes": "anfräta",
    "anfrätts": "anfräta",
    "anfäder": "anfader",
    "anfäderna": "anfader",
    "anfädernas": "anfader",
    "anfäders": "anfader",
    "anfäkt": "anfäkta",
    "anfäktad": "anfäkta",
    "anfäktade": "anfäktad",
    "anfäktades": "anfäktad",
    "anfäktads": "anfäktad",
    "anfäktande": "anfäkta",
    "anfäktanden": "anfäktande",
    "anfäktandena": "anfäktande",
    "anfäktandenas": "anfäktande",
    "anfäktandens": "anfäktande",
    "anfäktandes": "anfäktande",
    "anfäktandet": "anfäktande",
    "anfäktandets": "anfäktande",
    "anfäktar": "anfäkta",
    "anfäktas": "anfäkta",
    "anfäktat": "anfäktad",
    "anfäktats": "anfäktad",
    "anfäktelsen": "anfäktelse",
    "anfäktelsens": "anfäktelse",
    "anfäktelser": "anfäktelse",
    "anfäktelserna": "anfäktelse",
    "anfäktelsernas": "anfäktelse",
    "anfäktelsers": "anfäktelse",
    "anfäktelses": "anfäktelse",
    "anföll": "anfalla",
    "anfölle": "anfalla",
    "anfölles": "anfalla",
    "anfölls": "anfalla",
    "anför": "anföra",
    "anförande": "anföra",
    "anföranden": "anförande",
    "anförandena": "anförande",
    "anförandenas": "anförande",
    "anförandens": "anförande",
    "anförandes": "anförande",
    "anförandet": "anförande",
    "anförandets": "anförande",
    "anförar": "anförare",
    "anföraren": "anförare",
    "anförarens": "anförare",
    "anförares": "anförare",
    "anförarna": "anförare",
    "anförarnas": "anförare",
    "anföras": "anföra",
    "anförd": "anföra",
    "anförda": "anföra",
    "anfördas": "anföra",
    "anförde": "anföra",
    "anfördes": "anföra",
    "anförds": "anföra",
    "anföres": "anföra",
    "anföringar": "anföring",
    "anföringarna": "anföring",
    "anföringarnas": "anföring",
    "anföringars": "anföring",
    "anföringen": "anföring",
    "anföringens": "anföring",
    "anförings": "anföring",
    "anföringsteckens": "anföringstecken",
    "anföringstecknen": "anföringstecken",
    "anföringstecknens": "anföringstecken",
    "anföringstecknet": "anföringstecken",
    "anföringstecknets": "anföringstecken",
    "anföringsverben": "anföringsverb",
    "anföringsverbens": "anföringsverb",
    "anföringsverbet": "anföringsverb",
    "anföringsverbets": "anföringsverb",
    "anföringsverbs": "anföringsverb",
    "anförs": "anföra",
    "anfört": "anföra",
    "anförtrodd": "anförtro",
    "anförtrodda": "anförtro",
    "anförtroddas": "anförtro",
    "anförtrodde": "anförtro",
    "anförtroddes": "anförtro",
    "anförtrodds": "anförtro",
    "anförtroende": "anförtro",
    "anförtroenden": "anförtroende",
    "anförtroendena": "anförtroende",
    "anförtroendenas": "anförtroende",
    "anförtroendens": "anförtroende",
    "anförtroendes": "anförtroende",
    "anförtroendet": "anförtroende",
    "anförtroendets": "anförtroende",
    "anförtror": "anförtro",
    "anförtros": "anförtro",
    "anförtrott": "anförtro",
    "anförtrotts": "anförtro",
    "anförts": "anföra",
    "anförvanten": "anförvant",
    "anförvantens": "anförvant",
    "anförvanter": "anförvant",
    "anförvanterna": "anförvant",
    "anförvanternas": "anförvant",
    "anförvanters": "anförvant",
    "anförvants": "anförvant",
    "angav": "ange",
    "angavs": "ange",
    "angeende": "ange",
    "angeendes": "ange",
    "angel": "angla",
    "angeln": "angel",
    "angelns": "angel",
    "angels": "angel",
    "angelsachsar": "angelsachsare",
    "angelsachsaren": "angelsachsare",
    "angelsachsarens": "angelsachsare",
    "angelsachsares": "angelsachsare",
    "angelsachsarna": "angelsachsare",
    "angelsachsarnas": "angelsachsare",
    "angelsachsiska": "angelsachsisk",
    "angelsachsiskare": "angelsachsisk",
    "angelsachsiskares": "angelsachsisk",
    "angelsachsiskas": "angelsachsisk",
    "angelsachsiskast": "angelsachsisk",
    "angelsachsiskaste": "angelsachsisk",
    "angelsachsiskastes": "angelsachsisk",
    "angelsachsiskasts": "angelsachsisk",
    "angelsachsiske": "angelsachsisk",
    "angelsachsiskes": "angelsachsisk",
    "angelsachsisks": "angelsachsisk",
    "angelsachsiskt": "angelsachsisk",
    "angelsachsiskts": "angelsachsisk",
    "angelsaxar": "angelsaxare",
    "angelsaxaren": "angelsaxare",
    "angelsaxarens": "angelsaxare",
    "angelsaxares": "angelsaxare",
    "angelsaxarna": "angelsaxare",
    "angelsaxarnas": "angelsaxare",
    "angelsaxiska": "angelsaxisk",
    "angelsaxiskare": "angelsaxisk",
    "angelsaxiskares": "angelsaxisk",
    "angelsaxiskas": "angelsaxisk",
    "angelsaxiskast": "angelsaxisk",
    "angelsaxiskaste": "angelsaxisk",
    "angelsaxiskastes": "angelsaxisk",
    "angelsaxiskasts": "angelsaxisk",
    "angelsaxiske": "angelsaxisk",
    "angelsaxiskes": "angelsaxisk",
    "angelsaxisks": "angelsaxisk",
    "angelsaxiskt": "angelsaxisk",
    "angelsaxiskts": "angelsaxisk",
    "angelägenheten": "angelägenhet",
    "angelägenhetens": "angelägenhet",
    "angelägenheter": "angelägenhet",
    "angelägenheterna": "angelägenhet",
    "angelägenheternas": "angelägenhet",
    "angelägenheters": "angelägenhet",
    "angelägenhets": "angelägenhet",
    "angelägens": "angelägen",
    "angeläget": "angelägen",
    "angelägets": "angelägen",
    "angelägna": "angelägen",
    "angelägnare": "angelägen",
    "angelägnares": "angelägen",
    "angelägnas": "angelägen",
    "angelägnast": "angelägen",
    "angelägnaste": "angelägen",
    "angelägnastes": "angelägen",
    "angelägnasts": "angelägen",
    "angelägne": "angelägen",
    "angelägnes": "angelägen",
    "angenäma": "angenäm",
    "angenämare": "angenäm",
    "angenämares": "angenäm",
    "angenämas": "angenäm",
    "angenämast": "angenäm",
    "angenämaste": "angenäm",
    "angenämastes": "angenäm",
    "angenämasts": "angenäm",
    "angenäme": "angenäm",
    "angenämes": "angenäm",
    "angenämheten": "angenämhet",
    "angenämhetens": "angenämhet",
    "angenämhets": "angenämhet",
    "angenäms": "angenäm",
    "angenämt": "angenäm",
    "angenämts": "angenäm",
    "anger": "ange",
    "anges": "ange",
    "angett": "ange",
    "angetts": "ange",
    "angick": "angå",
    "angicks": "angå",
    "angin": "angina",
    "anginan": "angina",
    "anginans": "angina",
    "anginas": "angina",
    "angine": "angina",
    "anginge": "angå",
    "anginges": "angå",
    "anginor": "angina",
    "anginorna": "angina",
    "anginornas": "angina",
    "anginors": "angina",
    "angins": "angina",
    "angiografien": "angiografi",
    "angiografiens": "angiografi",
    "angiografin": "angiografi",
    "angiografins": "angiografi",
    "angiografis": "angiografi",
    "angiologien": "angiologi",
    "angiologiens": "angiologi",
    "angiologin": "angiologi",
    "angiologins": "angiologi",
    "angiologis": "angiologi",
    "angiospermen": "angiosperm",
    "angiospermens": "angiosperm",
    "angiospermer": "angiosperm",
    "angiospermerna": "angiosperm",
    "angiospermernas": "angiosperm",
    "angiospermers": "angiosperm",
    "angiosperms": "angiosperm",
    "angiv": "ange",
    "angiva": "ange",
    "angivande": "ange",
    "angivanden": "angivande",
    "angivandena": "angivande",
    "angivandenas": "angivande",
    "angivandens": "angivande",
    "angivandes": "angivande",
    "angivandet": "angivande",
    "angivandets": "angivande",
    "angivar": "angivare",
    "angivaren": "angivare",
    "angivarens": "angivare",
    "angivares": "angivare",
    "angivarna": "angivare",
    "angivarnas": "angivare",
    "angivas": "ange",
    "angive": "ange",
    "angivelsebrotten": "angivelsebrott",
    "angivelsebrottens": "angivelsebrott",
    "angivelsebrottet": "angivelsebrott",
    "angivelsebrottets": "angivelsebrott",
    "angivelsebrotts": "angivelsebrott",
    "angivelsen": "angivelse",
    "angivelsens": "angivelse",
    "angivelser": "angivelse",
    "angivelserna": "angivelse",
    "angivelsernas": "angivelse",
    "angivelsers": "angivelse",
    "angivelses": "angivelse",
    "angiven": "ange",
    "angivens": "ange",
    "angiver": "ange",
    "angiverier": "angiveri",
    "angiverierna": "angiveri",
    "angiveriernas": "angiveri",
    "angiveriers": "angiveri",
    "angiveriet": "angiveri",
    "angiveriets": "angiveri",
    "angiverilagen": "angiverilag",
    "angiverilagens": "angiverilag",
    "angiverilags": "angiverilag",
    "angiveris": "angiveri",
    "angiverit": "angiveri",
    "angiverits": "angiveri",
    "angives": "ange",
    "angivet": "ange",
    "angivets": "ange",
    "angivit": "ange",
    "angivits": "ange",
    "angivna": "ange",
    "angivnas": "ange",
    "angivne": "ange",
    "angivnes": "ange",
    "angivs": "ange",
    "angjord": "angöra",
    "angjorda": "angöra",
    "angjordas": "angöra",
    "angjorde": "angöra",
    "angjordes": "angöra",
    "angjords": "angöra",
    "angjort": "angöra",
    "angjorts": "angöra",
    "anglad": "angla",
    "anglade": "angla",
    "anglades": "angla",
    "anglads": "angla",
    "anglande": "angla",
    "anglanden": "anglande",
    "anglandena": "anglande",
    "anglandenas": "anglande",
    "anglandens": "anglande",
    "anglandes": "anglande",
    "anglandet": "anglande",
    "anglandets": "anglande",
    "anglar": "angla",
    "anglarna": "angel",
    "anglarnas": "angel",
    "anglars": "angel",
    "anglas": "angla",
    "anglat": "angla",
    "anglats": "angla",
    "anglicismen": "anglicism",
    "anglicismens": "anglicism",
    "anglicismer": "anglicism",
    "anglicismerna": "anglicism",
    "anglicismernas": "anglicism",
    "anglicismers": "anglicism",
    "anglicisms": "anglicism",
    "anglicistiska": "anglicistisk",
    "anglicistiskas": "anglicistisk",
    "anglicistiske": "anglicistisk",
    "anglicistiskes": "anglicistisk",
    "anglicistisks": "anglicistisk",
    "anglicistiskt": "anglicistisk",
    "anglicistiskts": "anglicistisk",
    "anglikanska": "anglikansk",
    "anglikanskare": "anglikansk",
    "anglikanskares": "anglikansk",
    "anglikanskas": "anglikansk",
    "anglikanskast": "anglikansk",
    "anglikanskaste": "anglikansk",
    "anglikanskastes": "anglikansk",
    "anglikanskasts": "anglikansk",
    "anglikanske": "anglikansk",
    "anglikanskes": "anglikansk",
    "anglikansks": "anglikansk",
    "anglikanskt": "anglikansk",
    "anglikanskts": "anglikansk",
    "angliserad": "anglisera",
    "angliserade": "anglisera",
    "angliserades": "anglisera",
    "angliserads": "anglisera",
    "angliserande": "anglisera",
    "angliseranden": "angliserande",
    "angliserandena": "angliserande",
    "angliserandenas": "angliserande",
    "angliserandens": "angliserande",
    "angliserandes": "angliserande",
    "angliserandet": "angliserande",
    "angliserandets": "angliserande",
    "angliserar": "anglisera",
    "angliseras": "anglisera",
    "angliserat": "anglisera",
    "angliserats": "anglisera",
    "angliserbara": "angliserbar",
    "angliserbarare": "angliserbar",
    "angliserbarares": "angliserbar",
    "angliserbaras": "angliserbar",
    "angliserbarast": "angliserbar",
    "angliserbaraste": "angliserbar",
    "angliserbarastes": "angliserbar",
    "angliserbarasts": "angliserbar",
    "angliserbare": "angliserbar",
    "angliserbares": "angliserbar",
    "angliserbarheten": "angliserbarhet",
    "angliserbarhetens": "angliserbarhet",
    "angliserbarhets": "angliserbarhet",
    "angliserbars": "angliserbar",
    "angliserbart": "angliserbar",
    "angliserbarts": "angliserbar",
    "angliseringar": "anglisering",
    "angliseringarna": "anglisering",
    "angliseringarnas": "anglisering",
    "angliseringars": "anglisering",
    "angliseringen": "anglisering",
    "angliseringens": "anglisering",
    "angliserings": "anglisering",
    "anglisten": "anglist",
    "anglistens": "anglist",
    "anglister": "anglist",
    "anglisterna": "anglist",
    "anglisternas": "anglist",
    "anglisters": "anglist",
    "anglists": "anglist",
    "anglosachsar": "anglosachsare",
    "anglosachsaren": "anglosachsare",
    "anglosachsarens": "anglosachsare",
    "anglosachsares": "anglosachsare",
    "anglosachsarna": "anglosachsare",
    "anglosachsarnas": "anglosachsare",
    "anglosachsiska": "anglosachsisk",
    "anglosachsiskare": "anglosachsisk",
    "anglosachsiskares": "anglosachsisk",
    "anglosachsiskas": "anglosachsisk",
    "anglosachsiskast": "anglosachsisk",
    "anglosachsiskaste": "anglosachsisk",
    "anglosachsiskastes": "anglosachsisk",
    "anglosachsiskasts": "anglosachsisk",
    "anglosachsiske": "anglosachsisk",
    "anglosachsiskes": "anglosachsisk",
    "anglosachsisks": "anglosachsisk",
    "anglosachsiskt": "anglosachsisk",
    "anglosachsiskts": "anglosachsisk",
    "anglosaxar": "anglosaxare",
    "anglosaxaren": "anglosaxare",
    "anglosaxarens": "anglosaxare",
    "anglosaxares": "anglosaxare",
    "anglosaxarna": "anglosaxare",
    "anglosaxarnas": "anglosaxare",
    "anglosaxiska": "anglosaxisk",
    "anglosaxiskare": "anglosaxisk",
    "anglosaxiskares": "anglosaxisk",
    "anglosaxiskas": "anglosaxisk",
    "anglosaxiskast": "anglosaxisk",
    "anglosaxiskaste": "anglosaxisk",
    "anglosaxiskastes": "anglosaxisk",
    "anglosaxiskasts": "anglosaxisk",
    "anglosaxiske": "anglosaxisk",
    "anglosaxiskes": "anglosaxisk",
    "anglosaxisks": "anglosaxisk",
    "anglosaxiskt": "anglosaxisk",
    "anglosaxiskts": "anglosaxisk",
    "angläsen": "angläs",
    "angläsens": "angläs",
    "angläser": "angläs",
    "angläserna": "angläs",
    "angläsernas": "angläs",
    "angläsers": "angläs",
    "angolanen": "angolan",
    "angolanens": "angolan",
    "angolaner": "angolan",
    "angolanerna": "angolan",
    "angolanernas": "angolan",
    "angolaners": "angolan",
    "angolans": "angolan",
    "angolanska": "angolansk",
    "angolanskan": "angolanska",
    "angolanskans": "angolanska",
    "angolanskare": "angolansk",
    "angolanskares": "angolansk",
    "angolanskas": "angolanska",
    "angolanskast": "angolansk",
    "angolanskaste": "angolansk",
    "angolanskastes": "angolansk",
    "angolanskasts": "angolansk",
    "angolanske": "angolanska",
    "angolanskes": "angolansk",
    "angolanskor": "angolanska",
    "angolanskorna": "angolanska",
    "angolanskornas": "angolanska",
    "angolanskors": "angolanska",
    "angolansks": "angolansk",
    "angolanskt": "angolansk",
    "angolanskts": "angolansk",
    "angoragarnet": "angoragarn",
    "angoragarnets": "angoragarn",
    "angoragarns": "angoragarn",
    "angorageten": "angoraget",
    "angoragetens": "angoraget",
    "angoragets": "angoraget",
    "angoragetter": "angoraget",
    "angoragetterna": "angoraget",
    "angoragetternas": "angoraget",
    "angoragetters": "angoraget",
    "angorakatten": "angorakatt",
    "angorakattens": "angorakatt",
    "angorakatter": "angorakatt",
    "angorakatterna": "angorakatt",
    "angorakatternas": "angorakatt",
    "angorakatters": "angorakatt",
    "angorakatts": "angorakatt",
    "angoraullen": "angoraull",
    "angoraullens": "angoraull",
    "angoraulls": "angoraull",
    "angosturan": "angostura",
    "angosturans": "angostura",
    "angosturas": "angostura",
    "angrep": "angripa",
    "angreppen": "angrepp",
    "angreppens": "angrepp",
    "angreppet": "angrepp",
    "angreppets": "angrepp",
    "angrepps": "angrepp",
    "angreppspunkten": "angreppspunkt",
    "angreppspunktens": "angreppspunkt",
    "angreppspunkter": "angreppspunkt",
    "angreppspunkterna": "angreppspunkt",
    "angreppspunkternas": "angreppspunkt",
    "angreppspunkters": "angreppspunkt",
    "angreppspunkts": "angreppspunkt",
    "angreppssätten": "angreppssätt",
    "angreppssättens": "angreppssätt",
    "angreppssättet": "angreppssätt",
    "angreppssättets": "angreppssätt",
    "angreppssätts": "angreppssätt",
    "angreps": "angripa",
    "angrip": "angripa",
    "angripande": "angripa",
    "angripanden": "angripande",
    "angripandena": "angripande",
    "angripandenas": "angripande",
    "angripandens": "angripande",
    "angripandes": "angripande",
    "angripandet": "angripande",
    "angripandets": "angripande",
    "angripar": "angripare",
    "angriparen": "angripare",
    "angriparens": "angripare",
    "angripares": "angripare",
    "angriparna": "angripare",
    "angriparnas": "angripare",
    "angripas": "angripa",
    "angripe": "angripa",
    "angripen": "angripa",
    "angripens": "angripa",
    "angriper": "angripa",
    "angripes": "angripa",
    "angripet": "angripa",
    "angripets": "angripa",
    "angripit": "angripa",
    "angripits": "angripa",
    "angripna": "angripa",
    "angripnas": "angripa",
    "angripne": "angripa",
    "angripnes": "angripa",
    "angrips": "angripa",
    "angräns": "angränsa",
    "angränsade": "angränsa",
    "angränsades": "angränsa",
    "angränsande": "angränsa",
    "angränsanden": "angränsande",
    "angränsandena": "angränsande",
    "angränsandenas": "angränsande",
    "angränsandens": "angränsande",
    "angränsandes": "angränsande",
    "angränsandet": "angränsande",
    "angränsandets": "angränsande",
    "angränsar": "angränsa",
    "angränsas": "angränsa",
    "angränsat": "angränsa",
    "angränsats": "angränsa",
    "angående": "angå",
    "angåendes": "angå",
    "angår": "angå",
    "angås": "angå",
    "angått": "angå",
    "angåtts": "angå",
    "angåve": "ange",
    "angåves": "ange",
    "angör": "angöra",
    "angörande": "angöra",
    "angöranden": "angörande",
    "angörandena": "angörande",
    "angörandenas": "angörande",
    "angörandens": "angörande",
    "angörandes": "angörande",
    "angörandet": "angörande",
    "angörandets": "angörande",
    "angöras": "angöra",
    "angöres": "angöra",
    "angörs": "angöra",
    "anhalten": "anhalt",
    "anhaltens": "anhalt",
    "anhalter": "anhalt",
    "anhalterna": "anhalt",
    "anhalternas": "anhalt",
    "anhalters": "anhalt",
    "anhalts": "anhalt",
    "anhangen": "anhang",
    "anhangens": "anhang",
    "anhanget": "anhang",
    "anhangets": "anhang",
    "anhangs": "anhang",
    "anhop": "anhopa",
    "anhopad": "anhopa",
    "anhopade": "anhopa",
    "anhopades": "anhopa",
    "anhopads": "anhopa",
    "anhopande": "anhopa",
    "anhopanden": "anhopande",
    "anhopandena": "anhopande",
    "anhopandenas": "anhopande",
    "anhopandens": "anhopande",
    "anhopandes": "anhopande",
    "anhopandet": "anhopande",
    "anhopandets": "anhopande",
    "anhopar": "anhopa",
    "anhopas": "anhopa",
    "anhopat": "anhopa",
    "anhopats": "anhopa",
    "anhopningar": "anhopning",
    "anhopningarna": "anhopning",
    "anhopningarnas": "anhopning",
    "anhopningars": "anhopning",
    "anhopningen": "anhopning",
    "anhopningens": "anhopning",
    "anhopnings": "anhopning",
    "anhängar": "anhängare",
    "anhängaren": "anhängare",
    "anhängarens": "anhängare",
    "anhängares": "anhängare",
    "anhängarna": "anhängare",
    "anhängarnas": "anhängare",
    "anhängiga": "anhängig",
    "anhängigare": "anhängig",
    "anhängigares": "anhängig",
    "anhängigas": "anhängig",
    "anhängigast": "anhängig",
    "anhängigaste": "anhängig",
    "anhängigastes": "anhängig",
    "anhängigasts": "anhängig",
    "anhängige": "anhängig",
    "anhängiges": "anhängig",
    "anhängigs": "anhängig",
    "anhängigt": "anhängig",
    "anhängigts": "anhängig",
    "anhåll": "anhålla",
    "anhållande": "anhålla",
    "anhållanden": "anhållande",
    "anhållandena": "anhållande",
    "anhållandenas": "anhållande",
    "anhållandens": "anhållande",
    "anhållandes": "anhållande",
    "anhållandet": "anhållande",
    "anhållandets": "anhållande",
    "anhållans": "anhållan",
    "anhållas": "anhålla",
    "anhålle": "anhålla",
    "anhållen": "anhålla",
    "anhållens": "anhålla",
    "anhåller": "anhålla",
    "anhålles": "anhålla",
    "anhållet": "anhålla",
    "anhållets": "anhålla",
    "anhållit": "anhålla",
    "anhållits": "anhålla",
    "anhållna": "anhålla",
    "anhållnas": "anhålla",
    "anhållne": "anhålla",
    "anhållnes": "anhålla",
    "anhålls": "anhålla",
    "anhöll": "anhålla",
    "anhölle": "anhålla",
    "anhölles": "anhålla",
    "anhölls": "anhålla",
    "anhöriga": "anhörig",
    "anhörigare": "anhörig",
    "anhörigares": "anhörig",
    "anhörigas": "anhörig",
    "anhörigast": "anhörig",
    "anhörigaste": "anhörig",
    "anhörigastes": "anhörig",
    "anhörigasts": "anhörig",
    "anhörige": "anhörig",
    "anhöriges": "anhörig",
    "anhöriginvandringen": "anhöriginvandring",
    "anhöriginvandringens": "anhöriginvandring",
    "anhöriginvandrings": "anhöriginvandring",
    "anhörigs": "anhörig",
    "anhörigt": "anhörig",
    "anhörigts": "anhörig",
    "anilinen": "anilin",
    "anilinens": "anilin",
    "anilinet": "anilin",
    "anilinets": "anilin",
    "anilinfärgen": "anilinfärg",
    "anilinfärgens": "anilinfärg",
    "anilinfärger": "anilinfärg",
    "anilinfärgerna": "anilinfärg",
    "anilinfärgernas": "anilinfärg",
    "anilinfärgers": "anilinfärg",
    "anilinfärgs": "anilinfärg",
    "anilins": "anilin",
    "animala": "animal",
    "animalare": "animal",
    "animalares": "animal",
    "animalas": "animal",
    "animalast": "animal",
    "animalaste": "animal",
    "animalastes": "animal",
    "animalasts": "animal",
    "animale": "animal",
    "animales": "animal",
    "animalie": "animalier",
    "animalierna": "animalier",
    "animaliernas": "animalier",
    "animaliers": "animalier",
    "animaliska": "animalisk",
    "animaliskare": "animalisk",
    "animaliskares": "animalisk",
    "animaliskas": "animalisk",
    "animaliskast": "animalisk",
    "animaliskaste": "animalisk",
    "animaliskastes": "animalisk",
    "animaliskasts": "animalisk",
    "animaliske": "animalisk",
    "animaliskes": "animalisk",
    "animalisks": "animalisk",
    "animaliskt": "animalisk",
    "animaliskts": "animalisk",
    "animals": "animal",
    "animalt": "animal",
    "animalts": "animal",
    "animationen": "animation",
    "animationens": "animation",
    "animationer": "animation",
    "animationerna": "animation",
    "animationernas": "animation",
    "animationers": "animation",
    "animations": "animation",
    "animatören": "animatör",
    "animatörens": "animatör",
    "animatörer": "animatör",
    "animatörerna": "animatör",
    "animatörernas": "animatör",
    "animatörers": "animatör",
    "animatörs": "animatör",
    "animerad": "animera",
    "animerade": "animerad",
    "animerades": "animerad",
    "animerads": "animerad",
    "animerande": "animera",
    "animeranden": "animerande",
    "animerandena": "animerande",
    "animerandenas": "animerande",
    "animerandens": "animerande",
    "animerandes": "animerande",
    "animerandet": "animerande",
    "animerandets": "animerande",
    "animerar": "animera",
    "animeras": "animera",
    "animerat": "animerad",
    "animerats": "animerad",
    "animerbara": "animerbar",
    "animerbarare": "animerbar",
    "animerbarares": "animerbar",
    "animerbaras": "animerbar",
    "animerbarast": "animerbar",
    "animerbaraste": "animerbar",
    "animerbarastes": "animerbar",
    "animerbarasts": "animerbar",
    "animerbare": "animerbar",
    "animerbares": "animerbar",
    "animerbarheten": "animerbarhet",
    "animerbarhetens": "animerbarhet",
    "animerbarhets": "animerbarhet",
    "animerbars": "animerbar",
    "animerbart": "animerbar",
    "animerbarts": "animerbar",
    "animeringar": "animering",
    "animeringarna": "animering",
    "animeringarnas": "animering",
    "animeringars": "animering",
    "animeringen": "animering",
    "animeringens": "animering",
    "animerings": "animering",
    "animismen": "animism",
    "animismens": "animism",
    "animismer": "animism",
    "animismerna": "animism",
    "animismernas": "animism",
    "animismers": "animism",
    "animisms": "animism",
    "animistiska": "animistisk",
    "animistiskare": "animistisk",
    "animistiskares": "animistisk",
    "animistiskas": "animistisk",
    "animistiskast": "animistisk",
    "animistiskaste": "animistisk",
    "animistiskastes": "animistisk",
    "animistiskasts": "animistisk",
    "animistiske": "animistisk",
    "animistiskes": "animistisk",
    "animistisks": "animistisk",
    "animistiskt": "animistisk",
    "animistiskts": "animistisk",
    "animositeten": "animositet",
    "animositetens": "animositet",
    "animositeter": "animositet",
    "animositeterna": "animositet",
    "animositeternas": "animositet",
    "animositeters": "animositet",
    "animositets": "animositet",
    "aningar": "aning",
    "aningarna": "aning",
    "aningarnas": "aning",
    "aningars": "aning",
    "aningen": "aning",
    "aningens": "aning",
    "anings": "aning",
    "aningslösa": "aningslös",
    "aningslösare": "aningslös",
    "aningslösares": "aningslös",
    "aningslösas": "aningslös",
    "aningslösast": "aningslös",
    "aningslösaste": "aningslös",
    "aningslösastes": "aningslös",
    "aningslösasts": "aningslös",
    "aningslöse": "aningslös",
    "aningslöses": "aningslös",
    "aningslösheten": "aningslöshet",
    "aningslöshetens": "aningslöshet",
    "aningslösheter": "aningslöshet",
    "aningslösheterna": "aningslöshet",
    "aningslösheternas": "aningslöshet",
    "aningslösheters": "aningslöshet",
    "aningslöshets": "aningslöshet",
    "aningslöst": "aningslös",
    "aningslösts": "aningslös",
    "anisen": "anis",
    "anisens": "anis",
    "anisetten": "anisett",
    "anisettens": "anisett",
    "anisetter": "anisett",
    "anisetterna": "anisett",
    "anisetternas": "anisett",
    "anisetters": "anisett",
    "anisetts": "anisett",
    "anjonen": "anjon",
    "anjonens": "anjon",
    "anjoner": "anjon",
    "anjonerna": "anjon",
    "anjonernas": "anjon",
    "anjoners": "anjon",
    "anjons": "anjon",
    "ank": "anka",
    "ankan": "anka",
    "ankans": "anka",
    "ankar": "ankare",
    "ankarbojar": "ankarboj",
    "ankarbojarna": "ankarboj",
    "ankarbojarnas": "ankarboj",
    "ankarbojars": "ankarboj",
    "ankarbojen": "ankarboj",
    "ankarbojens": "ankarboj",
    "ankarbojs": "ankarboj",
    "ankaren": "ankare",
    "ankarens": "ankare",
    "ankares": "ankare",
    "ankaret": "ankare",
    "ankarets": "ankare",
    "ankarflyen": "ankarfly",
    "ankarflyens": "ankarfly",
    "ankarflyet": "ankarfly",
    "ankarflyets": "ankarfly",
    "ankarflyn": "ankarfly",
    "ankarflyna": "ankarfly",
    "ankarflynas": "ankarfly",
    "ankarflyns": "ankarfly",
    "ankarflys": "ankarfly",
    "ankarflyt": "ankarfly",
    "ankarflyts": "ankarfly",
    "ankarfäst": "ankarfäste",
    "ankarfästen": "ankarfäste",
    "ankarfästena": "ankarfäste",
    "ankarfästenas": "ankarfäste",
    "ankarfästens": "ankarfäste",
    "ankarfästes": "ankarfäste",
    "ankarfästet": "ankarfäste",
    "ankarfästets": "ankarfäste",
    "ankargrunden": "ankargrund",
    "ankargrundens": "ankargrund",
    "ankargrunder": "ankargrund",
    "ankargrunderna": "ankargrund",
    "ankargrundernas": "ankargrund",
    "ankargrunders": "ankargrund",
    "ankargrunds": "ankargrund",
    "ankarjärnen": "ankarjärn",
    "ankarjärnens": "ankarjärn",
    "ankarjärnet": "ankarjärn",
    "ankarjärnets": "ankarjärn",
    "ankarjärns": "ankarjärn",
    "ankarkabeln": "ankarkabel",
    "ankarkabelns": "ankarkabel",
    "ankarkabels": "ankarkabel",
    "ankarkablar": "ankarkabel",
    "ankarkablarna": "ankarkabel",
    "ankarkablarnas": "ankarkabel",
    "ankarkablars": "ankarkabel",
    "ankarkättingar": "ankarkätting",
    "ankarkättingarna": "ankarkätting",
    "ankarkättingarnas": "ankarkätting",
    "ankarkättingars": "ankarkätting",
    "ankarkättingen": "ankarkätting",
    "ankarkättingens": "ankarkätting",
    "ankarkättings": "ankarkätting",
    "ankarlindningar": "ankarlindning",
    "ankarlindningarna": "ankarlindning",
    "ankarlindningarnas": "ankarlindning",
    "ankarlindningars": "ankarlindning",
    "ankarlindningen": "ankarlindning",
    "ankarlindningens": "ankarlindning",
    "ankarlindnings": "ankarlindning",
    "ankarna": "ankare",
    "ankarnas": "ankare",
    "ankars": "ankar",
    "ankarsluten": "ankarslut",
    "ankarslutens": "ankarslut",
    "ankarslutet": "ankarslut",
    "ankarslutets": "ankarslut",
    "ankarsluts": "ankarslut",
    "ankarspelen": "ankarspel",
    "ankarspelens": "ankarspel",
    "ankarspelet": "ankarspel",
    "ankarspelets": "ankarspel",
    "ankarspels": "ankarspel",
    "ankarstockar": "ankarstock",
    "ankarstockarna": "ankarstock",
    "ankarstockarnas": "ankarstock",
    "ankarstockars": "ankarstock",
    "ankarstocken": "ankarstock",
    "ankarstockens": "ankarstock",
    "ankarstocks": "ankarstock",
    "ankas": "anka",
    "ankbond": "ankbonde",
    "ankbonden": "ankbonde",
    "ankbondens": "ankbonde",
    "ankbondes": "ankbonde",
    "ankbonds": "ankbonde",
    "ankbönder": "ankbonde",
    "ankbönderna": "ankbonde",
    "ankböndernas": "ankbonde",
    "ankbönders": "ankbonde",
    "ankdammar": "ankdamm",
    "ankdammarna": "ankdamm",
    "ankdammarnas": "ankdamm",
    "ankdammars": "ankdamm",
    "ankdammen": "ankdamm",
    "ankdammens": "ankdamm",
    "ankdamms": "ankdamm",
    "anke": "anka",
    "ankellånga": "ankellång",
    "ankellångare": "ankellång",
    "ankellångares": "ankellång",
    "ankellångas": "ankellång",
    "ankellångast": "ankellång",
    "ankellångaste": "ankellång",
    "ankellångastes": "ankellång",
    "ankellångasts": "ankellång",
    "ankellånge": "ankellång",
    "ankellånges": "ankellång",
    "ankellångs": "ankellång",
    "ankellångt": "ankellång",
    "ankellångts": "ankellång",
    "ankeln": "ankel",
    "ankelns": "ankel",
    "ankels": "ankel",
    "ankelsock": "ankelsocka",
    "ankelsockan": "ankelsocka",
    "ankelsockans": "ankelsocka",
    "ankelsockas": "ankelsocka",
    "ankelsocke": "ankelsocka",
    "ankelsockor": "ankelsocka",
    "ankelsockorna": "ankelsocka",
    "ankelsockornas": "ankelsocka",
    "ankelsockors": "ankelsocka",
    "ankelsocks": "ankelsocka",
    "ankismen": "ankism",
    "ankismens": "ankism",
    "ankisms": "ankism",
    "ankistiska": "ankistisk",
    "ankistiskas": "ankistisk",
    "ankistiske": "ankistisk",
    "ankistiskes": "ankistisk",
    "ankistisks": "ankistisk",
    "ankistiskt": "ankistisk",
    "ankistiskts": "ankistisk",
    "anklagad": "anklaga",
    "anklagade": "anklaga",
    "anklagades": "anklaga",
    "anklagads": "anklaga",
    "anklagande": "anklaga",
    "anklaganden": "anklagande",
    "anklagandena": "anklagande",
    "anklagandenas": "anklagande",
    "anklagandens": "anklagande",
    "anklagandes": "anklagande",
    "anklagandet": "anklagande",
    "anklagandets": "anklagande",
    "anklagar": "anklaga",
    "anklagas": "anklaga",
    "anklagat": "anklaga",
    "anklagats": "anklaga",
    "anklagelseakten": "anklagelseakt",
    "anklagelseaktens": "anklagelseakt",
    "anklagelseakter": "anklagelseakt",
    "anklagelseakterna": "anklagelseakt",
    "anklagelseakternas": "anklagelseakt",
    "anklagelseakters": "anklagelseakt",
    "anklagelseakts": "anklagelseakt",
    "anklagelsen": "anklagelse",
    "anklagelsens": "anklagelse",
    "anklagelsepunkten": "anklagelsepunkt",
    "anklagelsepunktens": "anklagelsepunkt",
    "anklagelsepunkter": "anklagelsepunkt",
    "anklagelsepunkterna": "anklagelsepunkt",
    "anklagelsepunkternas": "anklagelsepunkt",
    "anklagelsepunkters": "anklagelsepunkt",
    "anklagelsepunkts": "anklagelsepunkt",
    "anklagelser": "anklagelse",
    "anklagelserna": "anklagelse",
    "anklagelsernas": "anklagelse",
    "anklagelsers": "anklagelse",
    "anklagelses": "anklagelse",
    "anklangen": "anklang",
    "anklangens": "anklang",
    "anklanger": "anklang",
    "anklangerna": "anklang",
    "anklangernas": "anklang",
    "anklangers": "anklang",
    "anklangs": "anklang",
    "anklar": "ankel",
    "anklarna": "ankel",
    "anklarnas": "ankel",
    "anklars": "ankel",
    "anknuten": "anknyta",
    "anknutens": "anknyta",
    "anknutet": "anknyta",
    "anknutets": "anknyta",
    "anknutit": "anknyta",
    "anknutits": "anknyta",
    "anknutna": "anknyta",
    "anknutnas": "anknyta",
    "anknutne": "anknyta",
    "anknutnes": "anknyta",
    "anknyt": "anknyta",
    "anknytande": "anknyta",
    "anknytanden": "anknytande",
    "anknytandena": "anknytande",
    "anknytandenas": "anknytande",
    "anknytandens": "anknytande",
    "anknytandes": "anknytande",
    "anknytandet": "anknytande",
    "anknytandets": "anknytande",
    "anknytas": "anknyta",
    "anknyte": "anknyta",
    "anknyter": "anknyta",
    "anknytes": "anknyta",
    "anknytningar": "anknytning",
    "anknytningarna": "anknytning",
    "anknytningarnas": "anknytning",
    "anknytningars": "anknytning",
    "anknytningen": "anknytning",
    "anknytningens": "anknytning",
    "anknytnings": "anknytning",
    "anknyts": "anknyta",
    "anknöt": "anknyta",
    "anknöte": "anknyta",
    "anknötes": "anknyta",
    "anknöts": "anknyta",
    "ankom": "ankomma",
    "ankomet": "ankomma",
    "ankomets": "ankomma",
    "ankommande": "ankomma",
    "ankommanden": "ankommande",
    "ankommandena": "ankommande",
    "ankommandenas": "ankommande",
    "ankommandens": "ankommande",
    "ankommandes": "ankommande",
    "ankommandet": "ankommande",
    "ankommandets": "ankommande",
    "ankommas": "ankomma",
    "ankomme": "ankomma",
    "ankommen": "ankomma",
    "ankommenheten": "ankommenhet",
    "ankommenhetens": "ankommenhet",
    "ankommenhets": "ankommenhet",
    "ankommens": "ankommen",
    "ankommer": "ankomma",
    "ankommes": "ankomma",
    "ankommet": "ankommen",
    "ankommets": "ankommen",
    "ankommit": "ankomma",
    "ankommits": "ankomma",
    "ankomna": "ankommen",
    "ankomnare": "ankommen",
    "ankomnares": "ankommen",
    "ankomnas": "ankommen",
    "ankomnast": "ankommen",
    "ankomnaste": "ankommen",
    "ankomnastes": "ankommen",
    "ankomnasts": "ankommen",
    "ankomne": "ankommen",
    "ankomnes": "ankommen",
    "ankoms": "ankomma",
    "ankomsten": "ankomst",
    "ankomstens": "ankomst",
    "ankomster": "ankomst",
    "ankomsterna": "ankomst",
    "ankomsternas": "ankomst",
    "ankomsters": "ankomst",
    "ankomsthallar": "ankomsthall",
    "ankomsthallarna": "ankomsthall",
    "ankomsthallarnas": "ankomsthall",
    "ankomsthallars": "ankomsthall",
    "ankomsthallen": "ankomsthall",
    "ankomsthallens": "ankomsthall",
    "ankomsthalls": "ankomsthall",
    "ankomstkommunen": "ankomstkommun",
    "ankomstkommunens": "ankomstkommun",
    "ankomstkommuner": "ankomstkommun",
    "ankomstkommunerna": "ankomstkommun",
    "ankomstkommunernas": "ankomstkommun",
    "ankomstkommuners": "ankomstkommun",
    "ankomstkommuns": "ankomstkommun",
    "ankomsts": "ankomst",
    "ankor": "anka",
    "ankorna": "anka",
    "ankornas": "anka",
    "ankors": "anka",
    "ankrad": "ankra",
    "ankrade": "ankra",
    "ankrades": "ankra",
    "ankrads": "ankra",
    "ankrande": "ankra",
    "ankranden": "ankrande",
    "ankrandena": "ankrande",
    "ankrandenas": "ankrande",
    "ankrandens": "ankrande",
    "ankrandes": "ankrande",
    "ankrandet": "ankrande",
    "ankrandets": "ankrande",
    "ankrar": "ankra",
    "ankras": "ankra",
    "ankrat": "ankra",
    "ankrats": "ankra",
    "ankringar": "ankring",
    "ankringarna": "ankring",
    "ankringarnas": "ankring",
    "ankringars": "ankring",
    "ankringen": "ankring",
    "ankringens": "ankring",
    "ankrings": "ankring",
    "anks": "anka",
    "ankungar": "ankunge",
    "ankungarna": "ankunge",
    "ankungarnas": "ankunge",
    "ankungars": "ankunge",
    "ankungen": "ankunge",
    "ankungens": "ankunge",
    "ankunges": "ankunge",
    "ankäggen": "ankägg",
    "ankäggens": "ankägg",
    "ankägget": "ankägg",
    "ankäggets": "ankägg",
    "ankäggs": "ankägg",
    "anla": "anlägga",
    "anlade": "anlägga",
    "anlades": "anlägga",
    "anlagd": "anlägga",
    "anlagda": "anlägga",
    "anlagdas": "anlägga",
    "anlagde": "anlägga",
    "anlagdes": "anlägga",
    "anlagds": "anlägga",
    "anlagen": "anlag",
    "anlagens": "anlag",
    "anlaget": "anlag",
    "anlagets": "anlag",
    "anlags": "anlag",
    "anlagsbärar": "anlagsbärare",
    "anlagsbäraren": "anlagsbärare",
    "anlagsbärarens": "anlagsbärare",
    "anlagsbärares": "anlagsbärare",
    "anlagsbärarna": "anlagsbärare",
    "anlagsbärarnas": "anlagsbärare",
    "anlagstesten": "anlagstest",
    "anlagstestens": "anlagstest",
    "anlagstester": "anlagstest",
    "anlagstesterna": "anlagstest",
    "anlagstesternas": "anlagstest",
    "anlagstesters": "anlagstest",
    "anlagstestet": "anlagstest",
    "anlagstestets": "anlagstest",
    "anlagstests": "anlagstest",
    "anlagt": "anlägga",
    "anlagts": "anlägga",
    "anlas": "anlägga",
    "anledningar": "anledning",
    "anledningarna": "anledning",
    "anledningarnas": "anledning",
    "anledningars": "anledning",
    "anledningen": "anledning",
    "anledningens": "anledning",
    "anlednings": "anledning",
    "anlegat": "anligga",
    "anlegats": "anligga",
    "anleten": "anlete",
    "anletena": "anlete",
    "anletenas": "anlete",
    "anletens": "anlete",
    "anletes": "anlete",
    "anletet": "anlete",
    "anletets": "anlete",
    "anlets": "anlete",
    "anletsdragen": "anletsdrag",
    "anletsdragens": "anletsdrag",
    "anletsdraget": "anletsdrag",
    "anletsdragets": "anletsdrag",
    "anletsdrags": "anletsdrag",
    "anligg": "anligga",
    "anliggande": "anligga",
    "anligganden": "anliggande",
    "anliggandena": "anliggande",
    "anliggandenas": "anliggande",
    "anliggandens": "anliggande",
    "anliggandes": "anliggande",
    "anliggandet": "anliggande",
    "anliggandets": "anliggande",
    "anliggas": "anligga",
    "anligge": "anligga",
    "anligger": "anligga",
    "anligges": "anligga",
    "anliggningsytan": "anliggningsyta",
    "anliggningsytans": "anliggningsyta",
    "anliggningsytas": "anliggningsyta",
    "anliggningsyte": "anliggningsyta",
    "anliggningsytor": "anliggningsyta",
    "anliggningsytorna": "anliggningsyta",
    "anliggningsytornas": "anliggningsyta",
    "anliggningsytors": "anliggningsyta",
    "anliggs": "anligga",
    "anlitad": "anlita",
    "anlitade": "anlita",
    "anlitades": "anlita",
    "anlitads": "anlita",
    "anlitande": "anlita",
    "anlitanden": "anlitande",
    "anlitandena": "anlitande",
    "anlitandenas": "anlitande",
    "anlitandens": "anlitande",
    "anlitandes": "anlitande",
    "anlitandet": "anlitande",
    "anlitandets": "anlitande",
    "anlitar": "anlita",
    "anlitas": "anlita",
    "anlitat": "anlita",
    "anlitats": "anlita",
    "anloppen": "anlopp",
    "anloppens": "anlopp",
    "anloppet": "anlopp",
    "anloppets": "anlopp",
    "anlopps": "anlopp",
    "anloppshamnar": "anloppshamn",
    "anloppshamnarna": "anloppshamn",
    "anloppshamnarnas": "anloppshamn",
    "anloppshamnars": "anloppshamn",
    "anloppshamnen": "anloppshamn",
    "anloppshamnens": "anloppshamn",
    "anloppshamns": "anloppshamn",
    "anlupenheten": "anlupenhet",
    "anlupenhetens": "anlupenhet",
    "anlupenhets": "anlupenhet",
    "anlupens": "anlupen",
    "anlupet": "anlupen",
    "anlupets": "anlupen",
    "anlupna": "anlupen",
    "anlupnare": "anlupen",
    "anlupnares": "anlupen",
    "anlupnas": "anlupen",
    "anlupnast": "anlupen",
    "anlupnaste": "anlupen",
    "anlupnastes": "anlupen",
    "anlupnasts": "anlupen",
    "anlupne": "anlupen",
    "anlupnes": "anlupen",
    "anlägg": "anlägga",
    "anläggande": "anlägga",
    "anlägganden": "anläggande",
    "anläggandena": "anläggande",
    "anläggandenas": "anläggande",
    "anläggandens": "anläggande",
    "anläggandes": "anläggande",
    "anläggandet": "anläggande",
    "anläggandets": "anläggande",
    "anläggar": "anläggare",
    "anläggaren": "anläggare",
    "anläggarens": "anläggare",
    "anläggares": "anläggare",
    "anläggarna": "anläggare",
    "anläggarnas": "anläggare",
    "anläggas": "anlägga",
    "anlägger": "anlägga",
    "anlägges": "anlägga",
    "anläggningar": "anläggning",
    "anläggningarna": "anläggning",
    "anläggningarnas": "anläggning",
    "anläggningars": "anläggning",
    "anläggningen": "anläggning",
    "anläggningens": "anläggning",
    "anläggnings": "anläggning",
    "anläggningsarbetar": "anläggningsarbetare",
    "anläggningsarbetaren": "anläggningsarbetare",
    "anläggningsarbetarens": "anläggningsarbetare",
    "anläggningsarbetares": "anläggningsarbetare",
    "anläggningsarbetarna": "anläggningsarbetare",
    "anläggningsarbetarnas": "anläggningsarbetare",
    "anläggningskostnaden": "anläggningskostnad",
    "anläggningskostnadens": "anläggningskostnad",
    "anläggningskostnader": "anläggningskostnad",
    "anläggningskostnaderna": "anläggningskostnad",
    "anläggningskostnadernas": "anläggningskostnad",
    "anläggningskostnaders": "anläggningskostnad",
    "anläggningskostnads": "anläggningskostnad",
    "anläggningsplatsen": "anläggningsplats",
    "anläggningsplatsens": "anläggningsplats",
    "anläggningsplatser": "anläggningsplats",
    "anläggningsplatserna": "anläggningsplats",
    "anläggningsplatsernas": "anläggningsplats",
    "anläggningsplatsers": "anläggningsplats",
    "anläggningstillgångar": "anläggningstillgång",
    "anläggningstillgångarna": "anläggningstillgång",
    "anläggningstillgångarnas": "anläggningstillgång",
    "anläggningstillgångars": "anläggningstillgång",
    "anläggningstillgången": "anläggningstillgång",
    "anläggningstillgångens": "anläggningstillgång",
    "anläggningstillgångs": "anläggningstillgång",
    "anläggningsytan": "anläggningsyta",
    "anläggningsytans": "anläggningsyta",
    "anläggningsytas": "anläggningsyta",
    "anläggningsyte": "anläggningsyta",
    "anläggningsytor": "anläggningsyta",
    "anläggningsytorna": "anläggningsyta",
    "anläggningsytornas": "anläggningsyta",
    "anläggningsytors": "anläggningsyta",
    "anläggs": "anlägga",
    "anländ": "anlända",
    "anländande": "anlända",
    "anländanden": "anländande",
    "anländandena": "anländande",
    "anländandenas": "anländande",
    "anländandens": "anländande",
    "anländandes": "anländande",
    "anländandet": "anländande",
    "anländandets": "anländande",
    "anländas": "anlända",
    "anlände": "anlända",
    "anländer": "anlända",
    "anländes": "anlända",
    "anländs": "anlända",
    "anlänt": "anlända",
    "anlänts": "anlända",
    "anlåg": "anligga",
    "anlågge": "anligga",
    "anlågges": "anligga",
    "anlågs": "anligga",
    "anlöp": "anlöpa",
    "anlöpande": "anlöpa",
    "anlöpanden": "anlöpande",
    "anlöpandena": "anlöpande",
    "anlöpandenas": "anlöpande",
    "anlöpandens": "anlöpande",
    "anlöpandes": "anlöpande",
    "anlöpandet": "anlöpande",
    "anlöpandets": "anlöpande",
    "anlöpas": "anlöpa",
    "anlöper": "anlöpa",
    "anlöpes": "anlöpa",
    "anlöps": "anlöpa",
    "anlöpt": "anlöpa",
    "anlöpta": "anlöpa",
    "anlöptas": "anlöpa",
    "anlöpte": "anlöpa",
    "anlöptes": "anlöpa",
    "anlöpts": "anlöpa",
    "anmanad": "anmana",
    "anmanade": "anmana",
    "anmanades": "anmana",
    "anmanads": "anmana",
    "anmanande": "anmana",
    "anmananden": "anmanande",
    "anmanandena": "anmanande",
    "anmanandenas": "anmanande",
    "anmanandens": "anmanande",
    "anmanandes": "anmanande",
    "anmanandet": "anmanande",
    "anmanandets": "anmanande",
    "anmanar": "anmana",
    "anmanas": "anmana",
    "anmanat": "anmana",
    "anmanats": "anmana",
    "anmodad": "anmoda",
    "anmodade": "anmoda",
    "anmodades": "anmoda",
    "anmodads": "anmoda",
    "anmodande": "anmoda",
    "anmodanden": "anmodande",
    "anmodandena": "anmodande",
    "anmodandenas": "anmodande",
    "anmodandens": "anmodande",
    "anmodandes": "anmodande",
    "anmodandet": "anmodande",
    "anmodandets": "anmodande",
    "anmodans": "anmodan",
    "anmodar": "anmoda",
    "anmodas": "anmoda",
    "anmodat": "anmoda",
    "anmodats": "anmoda",
    "anmodern": "anmoder",
    "anmoderns": "anmoder",
    "anmoders": "anmoder",
    "anmäl": "anmäla",
    "anmälande": "anmäla",
    "anmälanden": "anmälande",
    "anmälandena": "anmälande",
    "anmälandenas": "anmälande",
    "anmälandens": "anmälande",
    "anmälandes": "anmälande",
    "anmälandet": "anmälande",
    "anmälandets": "anmälande",
    "anmälans": "anmälan",
    "anmälar": "anmälare",
    "anmälaren": "anmälare",
    "anmälarens": "anmälare",
    "anmälares": "anmälare",
    "anmälarna": "anmälare",
    "anmälarnas": "anmälare",
    "anmälas": "anmäla",
    "anmäld": "anmäla",
    "anmälda": "anmäla",
    "anmäldas": "anmäla",
    "anmälde": "anmäla",
    "anmäldes": "anmäla",
    "anmälds": "anmäla",
    "anmäler": "anmäla",
    "anmäles": "anmäla",
    "anmälningar": "anmälning",
    "anmälningarna": "anmälning",
    "anmälningarnas": "anmälning",
    "anmälningars": "anmälning",
    "anmälningen": "anmälning",
    "anmälningens": "anmälning",
    "anmälnings": "anmälning",
    "anmälningstiden": "anmälningstid",
    "anmälningstidens": "anmälningstid",
    "anmälningstider": "anmälningstid",
    "anmälningstiderna": "anmälningstid",
    "anmälningstidernas": "anmälningstid",
    "anmälningstiders": "anmälningstid",
    "anmälningstids": "anmälningstid",
    "anmäls": "anmäla",
    "anmält": "anmäla",
    "anmälts": "anmäla",
    "anmärk": "anmärka",
    "anmärkande": "anmärka",
    "anmärkanden": "anmärkande",
    "anmärkandena": "anmärkande",
    "anmärkandenas": "anmärkande",
    "anmärkandens": "anmärkande",
    "anmärkandes": "anmärkande",
    "anmärkandet": "anmärkande",
    "anmärkandets": "anmärkande",
    "anmärkas": "anmärka",
    "anmärker": "anmärka",
    "anmärkes": "anmärka",
    "anmärkningar": "anmärkning",
    "anmärkningarna": "anmärkning",
    "anmärkningarnas": "anmärkning",
    "anmärkningars": "anmärkning",
    "anmärkningen": "anmärkning",
    "anmärkningens": "anmärkning",
    "anmärknings": "anmärkning",
    "anmärkningsvärda": "anmärkningsvärd",
    "anmärkningsvärdare": "anmärkningsvärd",
    "anmärkningsvärdares": "anmärkningsvärd",
    "anmärkningsvärdas": "anmärkningsvärd",
    "anmärkningsvärdast": "anmärkningsvärd",
    "anmärkningsvärdaste": "anmärkningsvärd",
    "anmärkningsvärdastes": "anmärkningsvärd",
    "anmärkningsvärdasts": "anmärkningsvärd",
    "anmärkningsvärde": "anmärkningsvärd",
    "anmärkningsvärdes": "anmärkningsvärd",
    "anmärkningsvärdheten": "anmärkningsvärdhet",
    "anmärkningsvärdhetens": "anmärkningsvärdhet",
    "anmärkningsvärdhets": "anmärkningsvärdhet",
    "anmärkningsvärds": "anmärkningsvärd",
    "anmärkningsvärt": "anmärkningsvärd",
    "anmärkningsvärts": "anmärkningsvärd",
    "anmärks": "anmärka",
    "anmärkt": "anmärka",
    "anmärkte": "anmärka",
    "anmärktes": "anmärka",
    "anmärkts": "anmärka",
    "anmödrar": "anmoder",
    "anmödrarna": "anmoder",
    "anmödrarnas": "anmoder",
    "anmödrars": "anmoder",
    "annal": "annaler",
    "annalerna": "annaler",
    "annalernas": "annaler",
    "annalers": "annaler",
    "annalisten": "annalist",
    "annalistens": "annalist",
    "annalister": "annalist",
    "annalisterna": "annalist",
    "annalisternas": "annalist",
    "annalisters": "annalist",
    "annalists": "annalist",
    "annalkandes": "annalkande",
    "annalkandet": "annalkande",
    "annalkandets": "annalkande",
    "annals": "annaler",
    "annandagar": "annandag",
    "annandagarna": "annandag",
    "annandagarnas": "annandag",
    "annandagars": "annandag",
    "annandagen": "annandag",
    "annandagens": "annandag",
    "annandags": "annandag",
    "annans": "annan",
    "annat": "annan",
    "annats": "annan",
    "annatton": "annatto",
    "annattons": "annatto",
    "annattos": "annatto",
    "annekterad": "annektera",
    "annekterade": "annektera",
    "annekterades": "annektera",
    "annekterads": "annektera",
    "annekterande": "annektera",
    "annekteranden": "annekterande",
    "annekterandena": "annekterande",
    "annekterandenas": "annekterande",
    "annekterandens": "annekterande",
    "annekterandes": "annekterande",
    "annekterandet": "annekterande",
    "annekterandets": "annekterande",
    "annekterar": "annektera",
    "annekteras": "annektera",
    "annekterat": "annektera",
    "annekterats": "annektera",
    "annekterbara": "annekterbar",
    "annekterbarare": "annekterbar",
    "annekterbarares": "annekterbar",
    "annekterbaras": "annekterbar",
    "annekterbarast": "annekterbar",
    "annekterbaraste": "annekterbar",
    "annekterbarastes": "annekterbar",
    "annekterbarasts": "annekterbar",
    "annekterbare": "annekterbar",
    "annekterbares": "annekterbar",
    "annekterbarheten": "annekterbarhet",
    "annekterbarhetens": "annekterbarhet",
    "annekterbarhets": "annekterbarhet",
    "annekterbars": "annekterbar",
    "annekterbart": "annekterbar",
    "annekterbarts": "annekterbar",
    "annekteringar": "annektering",
    "annekteringarna": "annektering",
    "annekteringarnas": "annektering",
    "annekteringars": "annektering",
    "annekteringen": "annektering",
    "annekteringens": "annektering",
    "annekterings": "annektering",
    "annektionen": "annektion",
    "annektionens": "annektion",
    "annektioner": "annektion",
    "annektionerna": "annektion",
    "annektionernas": "annektion",
    "annektioners": "annektion",
    "annektions": "annektion",
    "annexen": "annex",
    "annexens": "annex",
    "annexet": "annex",
    "annexets": "annex",
    "annexförsamlingar": "annexförsamling",
    "annexförsamlingarna": "annexförsamling",
    "annexförsamlingarnas": "annexförsamling",
    "annexförsamlingars": "annexförsamling",
    "annexförsamlingen": "annexförsamling",
    "annexförsamlingens": "annexförsamling",
    "annexförsamlings": "annexförsamling",
    "annexionen": "annexion",
    "annexionens": "annexion",
    "annexioner": "annexion",
    "annexionerna": "annexion",
    "annexionernas": "annexion",
    "annexioners": "annexion",
    "annexions": "annexion",
    "annihilationen": "annihilation",
    "annihilationens": "annihilation",
    "annihilationer": "annihilation",
    "annihilationerna": "annihilation",
    "annihilationernas": "annihilation",
    "annihilationers": "annihilation",
    "annihilations": "annihilation",
    "annihilerad": "annihilera",
    "annihilerade": "annihilera",
    "annihilerades": "annihilera",
    "annihilerads": "annihilera",
    "annihilerande": "annihilera",
    "annihileranden": "annihilerande",
    "annihilerandena": "annihilerande",
    "annihilerandenas": "annihilerande",
    "annihilerandens": "annihilerande",
    "annihilerandes": "annihilerande",
    "annihilerandet": "annihilerande",
    "annihilerandets": "annihilerande",
    "annihilerar": "annihilera",
    "annihileras": "annihilera",
    "annihilerat": "annihilera",
    "annihilerats": "annihilera",
    "annihilerbara": "annihilerbar",
    "annihilerbarare": "annihilerbar",
    "annihilerbarares": "annihilerbar",
    "annihilerbaras": "annihilerbar",
    "annihilerbarast": "annihilerbar",
    "annihilerbaraste": "annihilerbar",
    "annihilerbarastes": "annihilerbar",
    "annihilerbarasts": "annihilerbar",
    "annihilerbare": "annihilerbar",
    "annihilerbares": "annihilerbar",
    "annihilerbarheten": "annihilerbarhet",
    "annihilerbarhetens": "annihilerbarhet",
    "annihilerbarhets": "annihilerbarhet",
    "annihilerbars": "annihilerbar",
    "annihilerbart": "annihilerbar",
    "annihilerbarts": "annihilerbar",
    "annihileringar": "annihilering",
    "annihileringarna": "annihilering",
    "annihileringarnas": "annihilering",
    "annihileringars": "annihilering",
    "annihileringen": "annihilering",
    "annihileringens": "annihilering",
    "annihilerings": "annihilering",
    "annonsbojkotten": "annonsbojkott",
    "annonsbojkottens": "annonsbojkott",
    "annonsbojkotter": "annonsbojkott",
    "annonsbojkotterna": "annonsbojkott",
    "annonsbojkotternas": "annonsbojkott",
    "annonsbojkotters": "annonsbojkott",
    "annonsbojkotts": "annonsbojkott",
    "annonsbyråer": "annonsbyrå",
    "annonsbyråerna": "annonsbyrå",
    "annonsbyråernas": "annonsbyrå",
    "annonsbyråers": "annonsbyrå",
    "annonsbyrån": "annonsbyrå",
    "annonsbyråns": "annonsbyrå",
    "annonsbyrås": "annonsbyrå",
    "annonsen": "annons",
    "annonsens": "annons",
    "annonser": "annons",
    "annonserad": "annonsera",
    "annonserade": "annonsera",
    "annonserades": "annonsera",
    "annonserads": "annonsera",
    "annonserande": "annonsera",
    "annonseranden": "annonserande",
    "annonserandena": "annonserande",
    "annonserandenas": "annonserande",
    "annonserandens": "annonserande",
    "annonserandes": "annonserande",
    "annonserandet": "annonserande",
    "annonserandets": "annonserande",
    "annonserar": "annonsera",
    "annonseras": "annonsera",
    "annonserat": "annonsera",
    "annonserats": "annonsera",
    "annonserbara": "annonserbar",
    "annonserbarare": "annonserbar",
    "annonserbarares": "annonserbar",
    "annonserbaras": "annonserbar",
    "annonserbarast": "annonserbar",
    "annonserbaraste": "annonserbar",
    "annonserbarastes": "annonserbar",
    "annonserbarasts": "annonserbar",
    "annonserbare": "annonserbar",
    "annonserbares": "annonserbar",
    "annonserbarheten": "annonserbarhet",
    "annonserbarhetens": "annonserbarhet",
    "annonserbarhets": "annonserbarhet",
    "annonserbars": "annonserbar",
    "annonserbart": "annonserbar",
    "annonserbarts": "annonserbar",
    "annonseringar": "annonsering",
    "annonseringarna": "annonsering",
    "annonseringarnas": "annonsering",
    "annonseringars": "annonsering",
    "annonseringen": "annonsering",
    "annonseringens": "annonsering",
    "annonserings": "annonsering",
    "annonserna": "annons",
    "annonsernas": "annons",
    "annonsers": "annons",
    "annonskampanjen": "annonskampanj",
    "annonskampanjens": "annonskampanj",
    "annonskampanjer": "annonskampanj",
    "annonskampanjerna": "annonskampanj",
    "annonskampanjernas": "annonskampanj",
    "annonskampanjers": "annonskampanj",
    "annonskampanjs": "annonskampanj",
    "annonspelar": "annonspelare",
    "annonspelaren": "annonspelare",
    "annonspelarens": "annonspelare",
    "annonspelares": "annonspelare",
    "annonspelarna": "annonspelare",
    "annonspelarnas": "annonspelare",
    "annonsplatsen": "annonsplats",
    "annonsplatsens": "annonsplats",
    "annonsplatser": "annonsplats",
    "annonsplatserna": "annonsplats",
    "annonsplatsernas": "annonsplats",
    "annonsplatsers": "annonsplats",
    "annonssvaren": "annonssvar",
    "annonssvarens": "annonssvar",
    "annonssvaret": "annonssvar",
    "annonssvarets": "annonssvar",
    "annonssvars": "annonssvar",
    "annonstavel": "annonstavla",
    "annonstavlan": "annonstavla",
    "annonstavlans": "annonstavla",
    "annonstavlas": "annonstavla",
    "annonstavle": "annonstavla",
    "annonstavlor": "annonstavla",
    "annonstavlorna": "annonstavla",
    "annonstavlornas": "annonstavla",
    "annonstavlors": "annonstavla",
    "annonsören": "annonsör",
    "annonsörens": "annonsör",
    "annonsörer": "annonsör",
    "annonsörerna": "annonsör",
    "annonsörernas": "annonsör",
    "annonsörers": "annonsör",
    "annonsörs": "annonsör",
    "annos": "anno",
    "annotationen": "annotation",
    "annotationens": "annotation",
    "annotationer": "annotation",
    "annotationerna": "annotation",
    "annotationernas": "annotation",
    "annotationers": "annotation",
    "annotations": "annotation",
    "annoterad": "annotera",
    "annoterade": "annotera",
    "annoterades": "annotera",
    "annoterads": "annotera",
    "annoterande": "annotera",
    "annoteranden": "annoterande",
    "annoterandena": "annoterande",
    "annoterandenas": "annoterande",
    "annoterandens": "annoterande",
    "annoterandes": "annoterande",
    "annoterandet": "annoterande",
    "annoterandets": "annoterande",
    "annoterar": "annotera",
    "annoteras": "annotera",
    "annoterat": "annotera",
    "annoterats": "annotera",
    "annoterbara": "annoterbar",
    "annoterbarare": "annoterbar",
    "annoterbarares": "annoterbar",
    "annoterbaras": "annoterbar",
    "annoterbarast": "annoterbar",
    "annoterbaraste": "annoterbar",
    "annoterbarastes": "annoterbar",
    "annoterbarasts": "annoterbar",
    "annoterbare": "annoterbar",
    "annoterbares": "annoterbar",
    "annoterbarheten": "annoterbarhet",
    "annoterbarhetens": "annoterbarhet",
    "annoterbarhets": "annoterbarhet",
    "annoterbars": "annoterbar",
    "annoterbart": "annoterbar",
    "annoterbarts": "annoterbar",
    "annoteringar": "annotering",
    "annoteringarna": "annotering",
    "annoteringarnas": "annotering",
    "annoteringars": "annotering",
    "annoteringen": "annotering",
    "annoteringens": "annotering",
    "annoterings": "annotering",
    "anns": "ann",
    "annuella": "annuell",
    "annuellare": "annuell",
    "annuellares": "annuell",
    "annuellas": "annuell",
    "annuellast": "annuell",
    "annuellaste": "annuell",
    "annuellastes": "annuell",
    "annuellasts": "annuell",
    "annuelle": "annuell",
    "annuelles": "annuell",
    "annuells": "annuell",
    "annuellt": "annuell",
    "annuellts": "annuell",
    "annuiteten": "annuitet",
    "annuitetens": "annuitet",
    "annuiteter": "annuitet",
    "annuiteterna": "annuitet",
    "annuiteternas": "annuitet",
    "annuiteters": "annuitet",
    "annuitets": "annuitet",
    "annuitetslånen": "annuitetslån",
    "annuitetslånens": "annuitetslån",
    "annuitetslånet": "annuitetslån",
    "annuitetslånets": "annuitetslån",
    "annuitetslåns": "annuitetslån",
    "annullerad": "annullera",
    "annullerade": "annullera",
    "annullerades": "annullera",
    "annullerads": "annullera",
    "annullerande": "annullera",
    "annulleranden": "annullerande",
    "annullerandena": "annullerande",
    "annullerandenas": "annullerande",
    "annullerandens": "annullerande",
    "annullerandes": "annullerande",
    "annullerandet": "annullerande",
    "annullerandets": "annullerande",
    "annullerar": "annullera",
    "annulleras": "annullera",
    "annullerat": "annullera",
    "annullerats": "annullera",
    "annullerbara": "annullerbar",
    "annullerbarare": "annullerbar",
    "annullerbarares": "annullerbar",
    "annullerbaras": "annullerbar",
    "annullerbarast": "annullerbar",
    "annullerbaraste": "annullerbar",
    "annullerbarastes": "annullerbar",
    "annullerbarasts": "annullerbar",
    "annullerbare": "annullerbar",
    "annullerbares": "annullerbar",
    "annullerbarheten": "annullerbarhet",
    "annullerbarhetens": "annullerbarhet",
    "annullerbarhets": "annullerbarhet",
    "annullerbars": "annullerbar",
    "annullerbart": "annullerbar",
    "annullerbarts": "annullerbar",
    "annulleringar": "annullering",
    "annulleringarna": "annullering",
    "annulleringarnas": "annullering",
    "annulleringars": "annullering",
    "annulleringen": "annullering",
    "annulleringens": "annullering",
    "annullerings": "annullering",
    "anoden": "anod",
    "anodens": "anod",
    "anoder": "anod",
    "anoderna": "anod",
    "anodernas": "anod",
    "anoders": "anod",
    "anodiserad": "anodisera",
    "anodiserade": "anodisera",
    "anodiserades": "anodisera",
    "anodiserads": "anodisera",
    "anodiserande": "anodisera",
    "anodiseranden": "anodiserande",
    "anodiserandena": "anodiserande",
    "anodiserandenas": "anodiserande",
    "anodiserandens": "anodiserande",
    "anodiserandes": "anodiserande",
    "anodiserandet": "anodiserande",
    "anodiserandets": "anodiserande",
    "anodiserar": "anodisera",
    "anodiseras": "anodisera",
    "anodiserat": "anodisera",
    "anodiserats": "anodisera",
    "anodiserbara": "anodiserbar",
    "anodiserbarare": "anodiserbar",
    "anodiserbarares": "anodiserbar",
    "anodiserbaras": "anodiserbar",
    "anodiserbarast": "anodiserbar",
    "anodiserbaraste": "anodiserbar",
    "anodiserbarastes": "anodiserbar",
    "anodiserbarasts": "anodiserbar",
    "anodiserbare": "anodiserbar",
    "anodiserbares": "anodiserbar",
    "anodiserbarheten": "anodiserbarhet",
    "anodiserbarhetens": "anodiserbarhet",
    "anodiserbarhets": "anodiserbarhet",
    "anodiserbars": "anodiserbar",
    "anodiserbart": "anodiserbar",
    "anodiserbarts": "anodiserbar",
    "anodiseringar": "anodisering",
    "anodiseringarna": "anodisering",
    "anodiseringarnas": "anodisering",
    "anodiseringars": "anodisering",
    "anodiseringen": "anodisering",
    "anodiseringens": "anodisering",
    "anodiserings": "anodisering",
    "anods": "anod",
    "anomalien": "anomali",
    "anomaliens": "anomali",
    "anomalier": "anomali",
    "anomalierna": "anomali",
    "anomaliernas": "anomali",
    "anomaliers": "anomali",
    "anomalin": "anomali",
    "anomalins": "anomali",
    "anomalis": "anomali",
    "anomalistiska": "anomalistisk",
    "anomalistiskas": "anomalistisk",
    "anomalistiske": "anomalistisk",
    "anomalistiskes": "anomalistisk",
    "anomalistisks": "anomalistisk",
    "anomalistiskt": "anomalistisk",
    "anomalistiskts": "anomalistisk",
    "anomien": "anomi",
    "anomiens": "anomi",
    "anomier": "anomi",
    "anomierna": "anomi",
    "anomiernas": "anomi",
    "anomiers": "anomi",
    "anomin": "anomi",
    "anomins": "anomi",
    "anomis": "anomi",
    "anonyma": "anonym",
    "anonymare": "anonym",
    "anonymares": "anonym",
    "anonymas": "anonym",
    "anonymast": "anonym",
    "anonymaste": "anonym",
    "anonymastes": "anonym",
    "anonymasts": "anonym",
    "anonyme": "anonym",
    "anonymes": "anonym",
    "anonymheten": "anonymhet",
    "anonymhetens": "anonymhet",
    "anonymhets": "anonymhet",
    "anonymiserad": "anonymisera",
    "anonymiserade": "anonymisera",
    "anonymiserades": "anonymisera",
    "anonymiserads": "anonymisera",
    "anonymiserande": "anonymisera",
    "anonymiseranden": "anonymiserande",
    "anonymiserandena": "anonymiserande",
    "anonymiserandenas": "anonymiserande",
    "anonymiserandens": "anonymiserande",
    "anonymiserandes": "anonymiserande",
    "anonymiserandet": "anonymiserande",
    "anonymiserandets": "anonymiserande",
    "anonymiserar": "anonymisera",
    "anonymiseras": "anonymisera",
    "anonymiserat": "anonymisera",
    "anonymiserats": "anonymisera",
    "anonymiserbara": "anonymiserbar",
    "anonymiserbarare": "anonymiserbar",
    "anonymiserbarares": "anonymiserbar",
    "anonymiserbaras": "anonymiserbar",
    "anonymiserbarast": "anonymiserbar",
    "anonymiserbaraste": "anonymiserbar",
    "anonymiserbarastes": "anonymiserbar",
    "anonymiserbarasts": "anonymiserbar",
    "anonymiserbare": "anonymiserbar",
    "anonymiserbares": "anonymiserbar",
    "anonymiserbarheten": "anonymiserbarhet",
    "anonymiserbarhetens": "anonymiserbarhet",
    "anonymiserbarhets": "anonymiserbarhet",
    "anonymiserbars": "anonymiserbar",
    "anonymiserbart": "anonymiserbar",
    "anonymiserbarts": "anonymiserbar",
    "anonymiseringar": "anonymisering",
    "anonymiseringarna": "anonymisering",
    "anonymiseringarnas": "anonymisering",
    "anonymiseringars": "anonymisering",
    "anonymiseringen": "anonymisering",
    "anonymiseringens": "anonymisering",
    "anonymiserings": "anonymisering",
    "anonymiseringsverktygen": "anonymiseringsverktyg",
    "anonymiseringsverktygens": "anonymiseringsverktyg",
    "anonymiseringsverktyget": "anonymiseringsverktyg",
    "anonymiseringsverktygets": "anonymiseringsverktyg",
    "anonymiseringsverktygs": "anonymiseringsverktyg",
    "anonymiteten": "anonymitet",
    "anonymitetens": "anonymitet",
    "anonymiteter": "anonymitet",
    "anonymiteterna": "anonymitet",
    "anonymiteternas": "anonymitet",
    "anonymiteters": "anonymitet",
    "anonymitets": "anonymitet",
    "anonyms": "anonym",
    "anonymt": "anonym",
    "anonymts": "anonym",
    "anoraken": "anorak",
    "anorakens": "anorak",
    "anoraker": "anorak",
    "anorakerna": "anorak",
    "anorakernas": "anorak",
    "anorakers": "anorak",
    "anoraks": "anorak",
    "anordnad": "anordna",
    "anordnade": "anordna",
    "anordnades": "anordna",
    "anordnads": "anordna",
    "anordnande": "anordna",
    "anordnanden": "anordnande",
    "anordnandena": "anordnande",
    "anordnandenas": "anordnande",
    "anordnandens": "anordnande",
    "anordnandes": "anordnande",
    "anordnandet": "anordnande",
    "anordnandets": "anordnande",
    "anordnar": "anordna",
    "anordnas": "anordna",
    "anordnat": "anordna",
    "anordnats": "anordna",
    "anordningar": "anordning",
    "anordningarna": "anordning",
    "anordningarnas": "anordning",
    "anordningars": "anordning",
    "anordningen": "anordning",
    "anordningens": "anordning",
    "anordnings": "anordning",
    "anorexien": "anorexi",
    "anorexiens": "anorexi",
    "anorexier": "anorexi",
    "anorexierna": "anorexi",
    "anorexiernas": "anorexi",
    "anorexiers": "anorexi",
    "anorexin": "anorexi",
    "anorexins": "anorexi",
    "anorexis": "anorexi",
    "anormala": "anormal",
    "anormalare": "anormal",
    "anormalares": "anormal",
    "anormalas": "anormal",
    "anormalast": "anormal",
    "anormalaste": "anormal",
    "anormalastes": "anormal",
    "anormalasts": "anormal",
    "anormale": "anormal",
    "anormales": "anormal",
    "anormals": "anormal",
    "anormalt": "anormal",
    "anormalts": "anormal",
    "anorna": "anor",
    "anornas": "anor",
    "anors": "anor",
    "anparten": "anpart",
    "anpartens": "anpart",
    "anparts": "anpart",
    "anpassad": "anpassa",
    "anpassade": "anpassa",
    "anpassades": "anpassa",
    "anpassads": "anpassa",
    "anpassande": "anpassa",
    "anpassanden": "anpassande",
    "anpassandena": "anpassande",
    "anpassandenas": "anpassande",
    "anpassandens": "anpassande",
    "anpassandes": "anpassande",
    "anpassandet": "anpassande",
    "anpassandets": "anpassande",
    "anpassar": "anpassa",
    "anpassas": "anpassa",
    "anpassat": "anpassa",
    "anpassats": "anpassa",
    "anpassbara": "anpassbar",
    "anpassbarare": "anpassbar",
    "anpassbarares": "anpassbar",
    "anpassbaras": "anpassbar",
    "anpassbarast": "anpassbar",
    "anpassbaraste": "anpassbar",
    "anpassbarastes": "anpassbar",
    "anpassbarasts": "anpassbar",
    "anpassbare": "anpassbar",
    "anpassbares": "anpassbar",
    "anpassbarheten": "anpassbarhet",
    "anpassbarhetens": "anpassbarhet",
    "anpassbarhets": "anpassbarhet",
    "anpassbars": "anpassbar",
    "anpassbart": "anpassbar",
    "anpassbarts": "anpassbar",
    "anpassliga": "anpasslig",
    "anpassligare": "anpasslig",
    "anpassligares": "anpasslig",
    "anpassligas": "anpasslig",
    "anpassligast": "anpasslig",
    "anpassligaste": "anpasslig",
    "anpassligastes": "anpasslig",
    "anpassligasts": "anpasslig",
    "anpasslige": "anpasslig",
    "anpassliges": "anpasslig",
    "anpassligheten": "anpasslighet",
    "anpasslighetens": "anpasslighet",
    "anpasslighets": "anpasslighet",
    "anpassligs": "anpasslig",
    "anpassligt": "anpasslig",
    "anpassligts": "anpasslig",
    "anpasslingar": "anpassling",
    "anpasslingarna": "anpassling",
    "anpasslingarnas": "anpassling",
    "anpasslingars": "anpassling",
    "anpasslingen": "anpassling",
    "anpasslingens": "anpassling",
    "anpasslings": "anpassling",
    "anpassningar": "anpassning",
    "anpassningarna": "anpassning",
    "anpassningarnas": "anpassning",
    "anpassningars": "anpassning",
    "anpassningen": "anpassning",
    "anpassningens": "anpassning",
    "anpassnings": "anpassning",
    "anpassningsgruppen": "anpassningsgrupp",
    "anpassningsgruppens": "anpassningsgrupp",
    "anpassningsgrupper": "anpassningsgrupp",
    "anpassningsgrupperna": "anpassningsgrupp",
    "anpassningsgruppernas": "anpassningsgrupp",
    "anpassningsgruppers": "anpassningsgrupp",
    "anpassningsgrupps": "anpassningsgrupp",
    "anpassningskliniken": "anpassningsklinik",
    "anpassningsklinikens": "anpassningsklinik",
    "anpassningskliniker": "anpassningsklinik",
    "anpassningsklinikerna": "anpassningsklinik",
    "anpassningsklinikernas": "anpassningsklinik",
    "anpassningsklinikers": "anpassningsklinik",
    "anpassningskliniks": "anpassningsklinik",
    "anrik": "anrika",
    "anrika": "anrik",
    "anrikad": "anrika",
    "anrikade": "anrika",
    "anrikades": "anrika",
    "anrikads": "anrika",
    "anrikande": "anrika",
    "anrikanden": "anrikande",
    "anrikandena": "anrikande",
    "anrikandenas": "anrikande",
    "anrikandens": "anrikande",
    "anrikandes": "anrikande",
    "anrikandet": "anrikande",
    "anrikandets": "anrikande",
    "anrikar": "anrika",
    "anrikare": "anrik",
    "anrikares": "anrik",
    "anrikas": "anrika",
    "anrikast": "anrik",
    "anrikaste": "anrik",
    "anrikastes": "anrik",
    "anrikasts": "anrik",
    "anrikat": "anrika",
    "anrikats": "anrika",
    "anrike": "anrik",
    "anrikes": "anrik",
    "anrikheten": "anrikhet",
    "anrikhetens": "anrikhet",
    "anrikhets": "anrikhet",
    "anrikningar": "anrikning",
    "anrikningarna": "anrikning",
    "anrikningarnas": "anrikning",
    "anrikningars": "anrikning",
    "anrikningen": "anrikning",
    "anrikningens": "anrikning",
    "anriknings": "anrikning",
    "anrikningsanläggningar": "anrikningsanläggning",
    "anrikningsanläggningarna": "anrikningsanläggning",
    "anrikningsanläggningarnas": "anrikningsanläggning",
    "anrikningsanläggningars": "anrikningsanläggning",
    "anrikningsanläggningen": "anrikningsanläggning",
    "anrikningsanläggningens": "anrikningsanläggning",
    "anrikningsanläggnings": "anrikningsanläggning",
    "anriks": "anrik",
    "anrikt": "anrik",
    "anrikts": "anrik",
    "anrop": "anropa",
    "anropad": "anropa",
    "anropade": "anropa",
    "anropades": "anropa",
    "anropads": "anropa",
    "anropande": "anropa",
    "anropanden": "anropande",
    "anropandena": "anropande",
    "anropandenas": "anropande",
    "anropandens": "anropande",
    "anropandes": "anropande",
    "anropandet": "anropande",
    "anropandets": "anropande",
    "anropar": "anropa",
    "anropas": "anropa",
    "anropat": "anropa",
    "anropats": "anropa",
    "anropen": "anrop",
    "anropens": "anrop",
    "anropet": "anrop",
    "anropets": "anrop",
    "anrops": "anrop",
    "anropsknappar": "anropsknapp",
    "anropsknapparna": "anropsknapp",
    "anropsknapparnas": "anropsknapp",
    "anropsknappars": "anropsknapp",
    "anropsknappen": "anropsknapp",
    "anropsknappens": "anropsknapp",
    "anropsknapps": "anropsknapp",
    "anropsnummerna": "anropsnummer",
    "anropsnummernas": "anropsnummer",
    "anropsnummers": "anropsnummer",
    "anropsnumren": "anropsnummer",
    "anropsnumrens": "anropsnummer",
    "anropsnumret": "anropsnummer",
    "anropsnumrets": "anropsnummer",
    "anrätt": "anrätta",
    "anrättad": "anrätta",
    "anrättade": "anrätta",
    "anrättades": "anrätta",
    "anrättads": "anrätta",
    "anrättande": "anrätta",
    "anrättanden": "anrättande",
    "anrättandena": "anrättande",
    "anrättandenas": "anrättande",
    "anrättandens": "anrättande",
    "anrättandes": "anrättande",
    "anrättandet": "anrättande",
    "anrättandets": "anrättande",
    "anrättar": "anrätta",
    "anrättas": "anrätta",
    "anrättat": "anrätta",
    "anrättats": "anrätta",
    "anrättningar": "anrättning",
    "anrättningarna": "anrättning",
    "anrättningarnas": "anrättning",
    "anrättningars": "anrättning",
    "anrättningen": "anrättning",
    "anrättningens": "anrättning",
    "anrättnings": "anrättning",
    "ans": "ansa",
    "ansad": "ansa",
    "ansade": "ansa",
    "ansades": "ansa",
    "ansads": "ansa",
    "ansamlad": "ansamla",
    "ansamlade": "ansamla",
    "ansamlades": "ansamla",
    "ansamlads": "ansamla",
    "ansamlande": "ansamla",
    "ansamlanden": "ansamlande",
    "ansamlandena": "ansamlande",
    "ansamlandenas": "ansamlande",
    "ansamlandens": "ansamlande",
    "ansamlandes": "ansamlande",
    "ansamlandet": "ansamlande",
    "ansamlandets": "ansamlande",
    "ansamlar": "ansamla",
    "ansamlas": "ansamla",
    "ansamlat": "ansamla",
    "ansamlats": "ansamla",
    "ansamlingar": "ansamling",
    "ansamlingarna": "ansamling",
    "ansamlingarnas": "ansamling",
    "ansamlingars": "ansamling",
    "ansamlingen": "ansamling",
    "ansamlingens": "ansamling",
    "ansamlings": "ansamling",
    "ansande": "ansa",
    "ansanden": "ansande",
    "ansandena": "ansande",
    "ansandenas": "ansande",
    "ansandens": "ansande",
    "ansandes": "ansande",
    "ansandet": "ansande",
    "ansandets": "ansande",
    "ansar": "ansa",
    "ansas": "ansa",
    "ansat": "ansa",
    "ansats": "ansa",
    "ansatsbanan": "ansatsbana",
    "ansatsbanans": "ansatsbana",
    "ansatsbanas": "ansatsbana",
    "ansatsbane": "ansatsbana",
    "ansatsbanor": "ansatsbana",
    "ansatsbanorna": "ansatsbana",
    "ansatsbanornas": "ansatsbana",
    "ansatsbanors": "ansatsbana",
    "ansatsen": "ansats",
    "ansatsens": "ansats",
    "ansatser": "ansats",
    "ansatserna": "ansats",
    "ansatsernas": "ansats",
    "ansatsers": "ansats",
    "ansatt": "ansätta",
    "ansatta": "ansätta",
    "ansattas": "ansätta",
    "ansatte": "ansätta",
    "ansattes": "ansätta",
    "ansatts": "ansätta",
    "ansedd": "anse",
    "ansedda": "ansedd",
    "anseddare": "ansedd",
    "anseddares": "ansedd",
    "anseddas": "ansedd",
    "anseddast": "ansedd",
    "anseddaste": "ansedd",
    "anseddastes": "ansedd",
    "anseddasts": "ansedd",
    "ansedde": "ansedd",
    "anseddes": "ansedd",
    "anseddheten": "anseddhet",
    "anseddhetens": "anseddhet",
    "anseddhets": "anseddhet",
    "ansedds": "ansedd",
    "anseende": "anse",
    "anseenden": "anseende",
    "anseendena": "anseende",
    "anseendenas": "anseende",
    "anseendens": "anseende",
    "anseendes": "anseende",
    "anseendet": "anseende",
    "anseendets": "anseende",
    "ansen": "ans",
    "ansenliga": "ansenlig",
    "ansenligare": "ansenlig",
    "ansenligares": "ansenlig",
    "ansenligas": "ansenlig",
    "ansenligast": "ansenlig",
    "ansenligaste": "ansenlig",
    "ansenligastes": "ansenlig",
    "ansenligasts": "ansenlig",
    "ansenlige": "ansenlig",
    "ansenliges": "ansenlig",
    "ansenligheten": "ansenlighet",
    "ansenlighetens": "ansenlighet",
    "ansenlighets": "ansenlighet",
    "ansenligs": "ansenlig",
    "ansenligt": "ansenlig",
    "ansenligts": "ansenlig",
    "ansens": "ans",
    "anser": "anse",
    "anses": "anse",
    "ansett": "ansedd",
    "ansetts": "ansedd",
    "ansikten": "ansikte",
    "ansiktena": "ansikte",
    "ansiktenas": "ansikte",
    "ansiktens": "ansikte",
    "ansiktes": "ansikte",
    "ansiktet": "ansikte",
    "ansiktets": "ansikte",
    "ansikts": "ansikte",
    "ansiktsbjudningar": "ansiktsbjudning",
    "ansiktsbjudningarna": "ansiktsbjudning",
    "ansiktsbjudningarnas": "ansiktsbjudning",
    "ansiktsbjudningars": "ansiktsbjudning",
    "ansiktsbjudningen": "ansiktsbjudning",
    "ansiktsbjudningens": "ansiktsbjudning",
    "ansiktsbjudnings": "ansiktsbjudning",
    "ansiktsdragen": "ansiktsdrag",
    "ansiktsdragens": "ansiktsdrag",
    "ansiktsdraget": "ansiktsdrag",
    "ansiktsdragets": "ansiktsdrag",
    "ansiktsdrags": "ansiktsdrag",
    "ansiktsfärgen": "ansiktsfärg",
    "ansiktsfärgens": "ansiktsfärg",
    "ansiktsfärger": "ansiktsfärg",
    "ansiktsfärgerna": "ansiktsfärg",
    "ansiktsfärgernas": "ansiktsfärg",
    "ansiktsfärgers": "ansiktsfärg",
    "ansiktsfärgs": "ansiktsfärg",
    "ansiktsförlamningar": "ansiktsförlamning",
    "ansiktsförlamningarna": "ansiktsförlamning",
    "ansiktsförlamningarnas": "ansiktsförlamning",
    "ansiktsförlamningars": "ansiktsförlamning",
    "ansiktsförlamningen": "ansiktsförlamning",
    "ansiktsförlamningens": "ansiktsförlamning",
    "ansiktsförlamnings": "ansiktsförlamning",
    "ansiktskrämen": "ansiktskräm",
    "ansiktskrämens": "ansiktskräm",
    "ansiktskrämer": "ansiktskräm",
    "ansiktskrämerna": "ansiktskräm",
    "ansiktskrämernas": "ansiktskräm",
    "ansiktskrämers": "ansiktskräm",
    "ansiktskräms": "ansiktskräm",
    "ansiktslyften": "ansiktslyft",
    "ansiktslyftens": "ansiktslyft",
    "ansiktslyftet": "ansiktslyft",
    "ansiktslyftets": "ansiktslyft",
    "ansiktslyftningar": "ansiktslyftning",
    "ansiktslyftningarna": "ansiktslyftning",
    "ansiktslyftningarnas": "ansiktslyftning",
    "ansiktslyftningars": "ansiktslyftning",
    "ansiktslyftningen": "ansiktslyftning",
    "ansiktslyftningens": "ansiktslyftning",
    "ansiktslyftnings": "ansiktslyftning",
    "ansiktslyfts": "ansiktslyft",
    "ansiktsmasken": "ansiktsmask",
    "ansiktsmaskens": "ansiktsmask",
    "ansiktsmasker": "ansiktsmask",
    "ansiktsmaskerna": "ansiktsmask",
    "ansiktsmaskernas": "ansiktsmask",
    "ansiktsmaskers": "ansiktsmask",
    "ansiktsmasks": "ansiktsmask",
    "ansiktsmuskeln": "ansiktsmuskel",
    "ansiktsmuskelns": "ansiktsmuskel",
    "ansiktsmuskels": "ansiktsmuskel",
    "ansiktsmuskler": "ansiktsmuskel",
    "ansiktsmusklerna": "ansiktsmuskel",
    "ansiktsmusklernas": "ansiktsmuskel",
    "ansiktsmusklers": "ansiktsmuskel",
    "ansiktsnerven": "ansiktsnerv",
    "ansiktsnervens": "ansiktsnerv",
    "ansiktsnerver": "ansiktsnerv",
    "ansiktsnerverna": "ansiktsnerv",
    "ansiktsnervernas": "ansiktsnerv",
    "ansiktsnervers": "ansiktsnerv",
    "ansiktsnervs": "ansiktsnerv",
    "ansiktsskadan": "ansiktsskada",
    "ansiktsskadans": "ansiktsskada",
    "ansiktsskadas": "ansiktsskada",
    "ansiktsskade": "ansiktsskada",
    "ansiktsskador": "ansiktsskada",
    "ansiktsskadorna": "ansiktsskada",
    "ansiktsskadornas": "ansiktsskada",
    "ansiktsskadors": "ansiktsskada",
    "ansiktsskydden": "ansiktsskydd",
    "ansiktsskyddens": "ansiktsskydd",
    "ansiktsskyddet": "ansiktsskydd",
    "ansiktsskyddets": "ansiktsskydd",
    "ansiktsskydds": "ansiktsskydd",
    "ansiktsuttrycken": "ansiktsuttryck",
    "ansiktsuttryckens": "ansiktsuttryck",
    "ansiktsuttrycket": "ansiktsuttryck",
    "ansiktsuttryckets": "ansiktsuttryck",
    "ansiktsuttrycks": "ansiktsuttryck",
    "ansjovisar": "ansjovis",
    "ansjovisarna": "ansjovis",
    "ansjovisarnas": "ansjovis",
    "ansjovisars": "ansjovis",
    "ansjovisen": "ansjovis",
    "ansjovisens": "ansjovis",
    "anskaff": "anskaffa",
    "anskaffad": "anskaffa",
    "anskaffade": "anskaffa",
    "anskaffades": "anskaffa",
    "anskaffads": "anskaffa",
    "anskaffande": "anskaffa",
    "anskaffanden": "anskaffande",
    "anskaffandena": "anskaffande",
    "anskaffandenas": "anskaffande",
    "anskaffandens": "anskaffande",
    "anskaffandes": "anskaffande",
    "anskaffandet": "anskaffande",
    "anskaffandets": "anskaffande",
    "anskaffar": "anskaffa",
    "anskaffas": "anskaffa",
    "anskaffat": "anskaffa",
    "anskaffats": "anskaffa",
    "anskaffningar": "anskaffning",
    "anskaffningarna": "anskaffning",
    "anskaffningarnas": "anskaffning",
    "anskaffningars": "anskaffning",
    "anskaffningen": "anskaffning",
    "anskaffningens": "anskaffning",
    "anskaffnings": "anskaffning",
    "anskrien": "anskri",
    "anskriens": "anskri",
    "anskriet": "anskri",
    "anskriets": "anskri",
    "anskrin": "anskri",
    "anskrina": "anskri",
    "anskrinas": "anskri",
    "anskrins": "anskri",
    "anskris": "anskri",
    "anskrit": "anskri",
    "anskrits": "anskri",
    "anskrivens": "anskriven",
    "anskrivet": "anskriven",
    "anskrivets": "anskriven",
    "anskrivna": "anskriven",
    "anskrivnare": "anskriven",
    "anskrivnares": "anskriven",
    "anskrivnas": "anskriven",
    "anskrivnast": "anskriven",
    "anskrivnaste": "anskriven",
    "anskrivnastes": "anskriven",
    "anskrivnasts": "anskriven",
    "anskrivne": "anskriven",
    "anskrivnes": "anskriven",
    "anskrämliga": "anskrämlig",
    "anskrämligare": "anskrämlig",
    "anskrämligares": "anskrämlig",
    "anskrämligas": "anskrämlig",
    "anskrämligast": "anskrämlig",
    "anskrämligaste": "anskrämlig",
    "anskrämligastes": "anskrämlig",
    "anskrämligasts": "anskrämlig",
    "anskrämlige": "anskrämlig",
    "anskrämliges": "anskrämlig",
    "anskrämligheten": "anskrämlighet",
    "anskrämlighetens": "anskrämlighet",
    "anskrämligheter": "anskrämlighet",
    "anskrämligheterna": "anskrämlighet",
    "anskrämligheternas": "anskrämlighet",
    "anskrämligheters": "anskrämlighet",
    "anskrämlighets": "anskrämlighet",
    "anskrämligs": "anskrämlig",
    "anskrämligt": "anskrämlig",
    "anskrämligts": "anskrämlig",
    "anslagen": "anslag",
    "anslagens": "anslag",
    "anslaget": "anslag",
    "anslagets": "anslag",
    "anslagit": "anslå",
    "anslagits": "anslå",
    "anslagna": "anslå",
    "anslagnas": "anslå",
    "anslagne": "anslå",
    "anslagnes": "anslå",
    "anslags": "anslag",
    "anslagsframställningar": "anslagsframställning",
    "anslagsframställningarna": "anslagsframställning",
    "anslagsframställningarnas": "anslagsframställning",
    "anslagsframställningars": "anslagsframställning",
    "anslagsframställningen": "anslagsframställning",
    "anslagsframställningens": "anslagsframställning",
    "anslagsframställnings": "anslagsframställning",
    "anslagsmässiga": "anslagsmässig",
    "anslagsmässigare": "anslagsmässig",
    "anslagsmässigares": "anslagsmässig",
    "anslagsmässigas": "anslagsmässig",
    "anslagsmässigast": "anslagsmässig",
    "anslagsmässigaste": "anslagsmässig",
    "anslagsmässigastes": "anslagsmässig",
    "anslagsmässigasts": "anslagsmässig",
    "anslagsmässige": "anslagsmässig",
    "anslagsmässiges": "anslagsmässig",
    "anslagsmässigs": "anslagsmässig",
    "anslagsmässigt": "anslagsmässig",
    "anslagsmässigts": "anslagsmässig",
    "anslagstavel": "anslagstavla",
    "anslagstavlan": "anslagstavla",
    "anslagstavlans": "anslagstavla",
    "anslagstavlas": "anslagstavla",
    "anslagstavle": "anslagstavla",
    "anslagstavlor": "anslagstavla",
    "anslagstavlorna": "anslagstavla",
    "anslagstavlornas": "anslagstavla",
    "anslagstavlors": "anslagstavla",
    "anslagsäskanden": "anslagsäskande",
    "anslagsäskandena": "anslagsäskande",
    "anslagsäskandenas": "anslagsäskande",
    "anslagsäskandens": "anslagsäskande",
    "anslagsäskandes": "anslagsäskande",
    "anslagsäskandet": "anslagsäskande",
    "anslagsäskandets": "anslagsäskande",
    "anslog": "anslå",
    "ansloge": "anslå",
    "ansloges": "anslå",
    "anslogs": "anslå",
    "anslut": "ansluta",
    "anslutande": "ansluta",
    "anslutanden": "anslutande",
    "anslutandena": "anslutande",
    "anslutandenas": "anslutande",
    "anslutandens": "anslutande",
    "anslutandes": "anslutande",
    "anslutandet": "anslutande",
    "anslutandets": "anslutande",
    "anslutas": "ansluta",
    "anslute": "ansluta",
    "ansluten": "ansluta",
    "anslutens": "ansluta",
    "ansluter": "ansluta",
    "anslutes": "ansluta",
    "anslutet": "ansluta",
    "anslutets": "ansluta",
    "anslutit": "ansluta",
    "anslutits": "ansluta",
    "anslutna": "ansluta",
    "anslutnas": "ansluta",
    "anslutne": "ansluta",
    "anslutnes": "ansluta",
    "anslutningar": "anslutning",
    "anslutningarna": "anslutning",
    "anslutningarnas": "anslutning",
    "anslutningars": "anslutning",
    "anslutningen": "anslutning",
    "anslutningens": "anslutning",
    "anslutnings": "anslutning",
    "anslutningsavtalen": "anslutningsavtal",
    "anslutningsavtalens": "anslutningsavtal",
    "anslutningsavtalet": "anslutningsavtal",
    "anslutningsavtalets": "anslutningsavtal",
    "anslutningsavtals": "anslutningsavtal",
    "anslutningsboxar": "anslutningsbox",
    "anslutningsboxarna": "anslutningsbox",
    "anslutningsboxarnas": "anslutningsbox",
    "anslutningsboxars": "anslutningsbox",
    "anslutningsboxen": "anslutningsbox",
    "anslutningsboxens": "anslutningsbox",
    "anslutningskabeln": "anslutningskabel",
    "anslutningskabelns": "anslutningskabel",
    "anslutningskabels": "anslutningskabel",
    "anslutningskablar": "anslutningskabel",
    "anslutningskablarna": "anslutningskabel",
    "anslutningskablarnas": "anslutningskabel",
    "anslutningskablars": "anslutningskabel",
    "anslutningskontakten": "anslutningskontakt",
    "anslutningskontaktens": "anslutningskontakt",
    "anslutningskontakter": "anslutningskontakt",
    "anslutningskontakterna": "anslutningskontakt",
    "anslutningskontakternas": "anslutningskontakt",
    "anslutningskontakters": "anslutningskontakt",
    "anslutningskontakts": "anslutningskontakt",
    "anslutningssladdar": "anslutningssladd",
    "anslutningssladdarna": "anslutningssladd",
    "anslutningssladdarnas": "anslutningssladd",
    "anslutningssladdars": "anslutningssladd",
    "anslutningssladden": "anslutningssladd",
    "anslutningssladdens": "anslutningssladd",
    "anslutningssladds": "anslutningssladd",
    "ansluts": "ansluta",
    "anslående": "anslå",
    "anslåenden": "anslående",
    "anslåendena": "anslående",
    "anslåendenas": "anslående",
    "anslåendens": "anslående",
    "anslåendes": "anslående",
    "anslåendet": "anslående",
    "anslåendets": "anslående",
    "anslår": "anslå",
    "anslås": "anslå",
    "anslöt": "ansluta",
    "anslöte": "ansluta",
    "anslötes": "ansluta",
    "anslöts": "ansluta",
    "anspannen": "anspann",
    "anspannens": "anspann",
    "anspannet": "anspann",
    "anspannets": "anspann",
    "anspanns": "anspann",
    "anspelad": "anspela",
    "anspelade": "anspela",
    "anspelades": "anspela",
    "anspelads": "anspela",
    "anspelande": "anspela",
    "anspelanden": "anspelande",
    "anspelandena": "anspelande",
    "anspelandenas": "anspelande",
    "anspelandens": "anspelande",
    "anspelandes": "anspelande",
    "anspelandet": "anspelande",
    "anspelandets": "anspelande",
    "anspelar": "anspela",
    "anspelas": "anspela",
    "anspelat": "anspela",
    "anspelats": "anspela",
    "anspelningar": "anspelning",
    "anspelningarna": "anspelning",
    "anspelningarnas": "anspelning",
    "anspelningars": "anspelning",
    "anspelningen": "anspelning",
    "anspelningens": "anspelning",
    "anspelnings": "anspelning",
    "anspråken": "anspråk",
    "anspråkens": "anspråk",
    "anspråket": "anspråk",
    "anspråkets": "anspråk",
    "anspråks": "anspråk",
    "anspråksfulla": "anspråksfull",
    "anspråksfullare": "anspråksfull",
    "anspråksfullares": "anspråksfull",
    "anspråksfullas": "anspråksfull",
    "anspråksfullast": "anspråksfull",
    "anspråksfullaste": "anspråksfull",
    "anspråksfullastes": "anspråksfull",
    "anspråksfullasts": "anspråksfull",
    "anspråksfulle": "anspråksfull",
    "anspråksfulles": "anspråksfull",
    "anspråksfullheten": "anspråksfullhet",
    "anspråksfullhetens": "anspråksfullhet",
    "anspråksfullhets": "anspråksfullhet",
    "anspråksfulls": "anspråksfull",
    "anspråksfullt": "anspråksfull",
    "anspråksfullts": "anspråksfull",
    "anspråkslösa": "anspråkslös",
    "anspråkslösare": "anspråkslös",
    "anspråkslösares": "anspråkslös",
    "anspråkslösas": "anspråkslös",
    "anspråkslösast": "anspråkslös",
    "anspråkslösaste": "anspråkslös",
    "anspråkslösastes": "anspråkslös",
    "anspråkslösasts": "anspråkslös",
    "anspråkslöse": "anspråkslös",
    "anspråkslöses": "anspråkslös",
    "anspråkslösheten": "anspråkslöshet",
    "anspråkslöshetens": "anspråkslöshet",
    "anspråkslösheter": "anspråkslöshet",
    "anspråkslösheterna": "anspråkslöshet",
    "anspråkslösheternas": "anspråkslöshet",
    "anspråkslösheters": "anspråkslöshet",
    "anspråkslöshets": "anspråkslöshet",
    "anspråkslöst": "anspråkslös",
    "anspråkslösts": "anspråkslös",
    "anspända": "anspänd",
    "anspändare": "anspänd",
    "anspändares": "anspänd",
    "anspändas": "anspänd",
    "anspändast": "anspänd",
    "anspändaste": "anspänd",
    "anspändastes": "anspänd",
    "anspändasts": "anspänd",
    "anspände": "anspänd",
    "anspändes": "anspänd",
    "anspändheten": "anspändhet",
    "anspändhetens": "anspändhet",
    "anspändhets": "anspändhet",
    "anspänds": "anspänd",
    "anspänningar": "anspänning",
    "anspänningarna": "anspänning",
    "anspänningarnas": "anspänning",
    "anspänningars": "anspänning",
    "anspänningen": "anspänning",
    "anspänningens": "anspänning",
    "anspännings": "anspänning",
    "anspänt": "anspänd",
    "anspänts": "anspänd",
    "anstalten": "anstalt",
    "anstaltens": "anstalt",
    "anstalter": "anstalt",
    "anstalterna": "anstalt",
    "anstalternas": "anstalt",
    "anstalters": "anstalt",
    "anstalts": "anstalt",
    "anstaltsvården": "anstaltsvård",
    "anstaltsvårdens": "anstaltsvård",
    "anstaltsvårds": "anstaltsvård",
    "anstift": "anstifta",
    "anstiftad": "anstifta",
    "anstiftade": "anstifta",
    "anstiftades": "anstifta",
    "anstiftads": "anstifta",
    "anstiftande": "anstifta",
    "anstiftanden": "anstiftande",
    "anstiftandena": "anstiftande",
    "anstiftandenas": "anstiftande",
    "anstiftandens": "anstiftande",
    "anstiftandes": "anstiftande",
    "anstiftandet": "anstiftande",
    "anstiftandets": "anstiftande",
    "anstiftans": "anstiftan",
    "anstiftar": "anstiftare",
    "anstiftaren": "anstiftare",
    "anstiftarens": "anstiftare",
    "anstiftares": "anstiftare",
    "anstiftarna": "anstiftare",
    "anstiftarnas": "anstiftare",
    "anstiftas": "anstifta",
    "anstiftat": "anstifta",
    "anstiftats": "anstifta",
    "anstiftelsen": "anstiftelse",
    "anstiftelsens": "anstiftelse",
    "anstiftelses": "anstiftelse",
    "anstod": "anstå",
    "anstode": "anstå",
    "anstodes": "anstå",
    "anstods": "anstå",
    "anstorm": "anstorma",
    "anstormad": "anstorma",
    "anstormade": "anstorma",
    "anstormades": "anstorma",
    "anstormads": "anstorma",
    "anstormande": "anstorma",
    "anstormanden": "anstormande",
    "anstormandena": "anstormande",
    "anstormandenas": "anstormande",
    "anstormandens": "anstormande",
    "anstormandes": "anstormande",
    "anstormandet": "anstormande",
    "anstormandets": "anstormande",
    "anstormar": "anstorma",
    "anstormas": "anstorma",
    "anstormat": "anstorma",
    "anstormats": "anstorma",
    "anstormningar": "anstormning",
    "anstormningarna": "anstormning",
    "anstormningarnas": "anstormning",
    "anstormningars": "anstormning",
    "anstormningen": "anstormning",
    "anstormningens": "anstormning",
    "anstormnings": "anstormning",
    "anstruken": "anstryka",
    "anstrukenheten": "anstrukenhet",
    "anstrukenhetens": "anstrukenhet",
    "anstrukenhets": "anstrukenhet",
    "anstrukens": "anstryka",
    "anstruket": "anstryka",
    "anstrukets": "anstryka",
    "anstrukit": "anstryka",
    "anstrukits": "anstryka",
    "anstrukna": "anstryka",
    "anstruknare": "anstruken",
    "anstruknares": "anstruken",
    "anstruknas": "anstryka",
    "anstruknast": "anstruken",
    "anstruknaste": "anstruken",
    "anstruknastes": "anstruken",
    "anstruknasts": "anstruken",
    "anstrukne": "anstryka",
    "anstruknes": "anstryka",
    "anstryk": "anstryka",
    "anstrykande": "anstryka",
    "anstrykanden": "anstrykande",
    "anstrykandena": "anstrykande",
    "anstrykandenas": "anstrykande",
    "anstrykandens": "anstrykande",
    "anstrykandes": "anstrykande",
    "anstrykandet": "anstrykande",
    "anstrykandets": "anstrykande",
    "anstrykar": "anstrykare",
    "anstrykaren": "anstrykare",
    "anstrykarens": "anstrykare",
    "anstrykares": "anstrykare",
    "anstrykarna": "anstrykare",
    "anstrykarnas": "anstrykare",
    "anstrykas": "anstryka",
    "anstryke": "anstryka",
    "anstryker": "anstryka",
    "anstrykes": "anstryka",
    "anstrykningar": "anstrykning",
    "anstrykningarna": "anstrykning",
    "anstrykningarnas": "anstrykning",
    "anstrykningars": "anstrykning",
    "anstrykningen": "anstrykning",
    "anstrykningens": "anstrykning",
    "anstryknings": "anstrykning",
    "anstryks": "anstryka",
    "ansträng": "anstränga",
    "ansträngande": "anstränga",
    "anstränganden": "ansträngande",
    "ansträngandena": "ansträngande",
    "ansträngandenas": "ansträngande",
    "ansträngandens": "ansträngande",
    "ansträngandes": "ansträngande",
    "ansträngandet": "ansträngande",
    "ansträngandets": "ansträngande",
    "ansträngas": "anstränga",
    "ansträngd": "anstränga",
    "ansträngda": "ansträngd",
    "ansträngdare": "ansträngd",
    "ansträngdares": "ansträngd",
    "ansträngdas": "ansträngd",
    "ansträngdast": "ansträngd",
    "ansträngdaste": "ansträngd",
    "ansträngdastes": "ansträngd",
    "ansträngdasts": "ansträngd",
    "ansträngde": "ansträngd",
    "ansträngdes": "ansträngd",
    "ansträngdheten": "ansträngdhet",
    "ansträngdhetens": "ansträngdhet",
    "ansträngdhets": "ansträngdhet",
    "ansträngds": "ansträngd",
    "anstränger": "anstränga",
    "anstränges": "anstränga",
    "ansträngningar": "ansträngning",
    "ansträngningarna": "ansträngning",
    "ansträngningarnas": "ansträngning",
    "ansträngningars": "ansträngning",
    "ansträngningen": "ansträngning",
    "ansträngningens": "ansträngning",
    "ansträngnings": "ansträngning",
    "ansträngs": "anstränga",
    "ansträngt": "ansträngd",
    "ansträngts": "ansträngd",
    "anströk": "anstryka",
    "anströke": "anstryka",
    "anströkes": "anstryka",
    "anströks": "anstryka",
    "anstuckenheten": "anstuckenhet",
    "anstuckenhetens": "anstuckenhet",
    "anstuckenhets": "anstuckenhet",
    "anstuckens": "anstucken",
    "anstucket": "anstucken",
    "anstuckets": "anstucken",
    "anstuckna": "anstucken",
    "anstucknare": "anstucken",
    "anstucknares": "anstucken",
    "anstucknas": "anstucken",
    "anstucknast": "anstucken",
    "anstucknaste": "anstucken",
    "anstucknastes": "anstucken",
    "anstucknasts": "anstucken",
    "anstuckne": "anstucken",
    "anstucknes": "anstucken",
    "anställ": "anställa",
    "anställande": "anställa",
    "anställanden": "anställande",
    "anställandena": "anställande",
    "anställandenas": "anställande",
    "anställandens": "anställande",
    "anställandes": "anställande",
    "anställandet": "anställande",
    "anställandets": "anställande",
    "anställas": "anställa",
    "anställd": "anställa",
    "anställda": "anställa",
    "anställdas": "anställa",
    "anställde": "anställd",
    "anställdes": "anställd",
    "anställds": "anställd",
    "anställer": "anställa",
    "anställes": "anställa",
    "anställningar": "anställning",
    "anställningarna": "anställning",
    "anställningarnas": "anställning",
    "anställningars": "anställning",
    "anställningen": "anställning",
    "anställningens": "anställning",
    "anställnings": "anställning",
    "anställningsavtalen": "anställningsavtal",
    "anställningsavtalens": "anställningsavtal",
    "anställningsavtalet": "anställningsavtal",
    "anställningsavtalets": "anställningsavtal",
    "anställningsavtals": "anställningsavtal",
    "anställningsintervjuer": "anställningsintervju",
    "anställningsintervjuerna": "anställningsintervju",
    "anställningsintervjuernas": "anställningsintervju",
    "anställningsintervjuers": "anställningsintervju",
    "anställningsintervjun": "anställningsintervju",
    "anställningsintervjuns": "anställningsintervju",
    "anställningsintervjus": "anställningsintervju",
    "anställningskommittéer": "anställningskommitté",
    "anställningskommittéerna": "anställningskommitté",
    "anställningskommittéernas": "anställningskommitté",
    "anställningskommittéers": "anställningskommitté",
    "anställningskommittén": "anställningskommitté",
    "anställningskommitténs": "anställningskommitté",
    "anställningskommittés": "anställningskommitté",
    "anställningskontrakten": "anställningskontrakt",
    "anställningskontraktens": "anställningskontrakt",
    "anställningskontraktet": "anställningskontrakt",
    "anställningskontraktets": "anställningskontrakt",
    "anställningskontrakts": "anställningskontrakt",
    "anställningsrättigheten": "anställningsrättighet",
    "anställningsrättighetens": "anställningsrättighet",
    "anställningsrättigheter": "anställningsrättighet",
    "anställningsrättigheterna": "anställningsrättighet",
    "anställningsrättigheternas": "anställningsrättighet",
    "anställningsrättigheters": "anställningsrättighet",
    "anställningsrättighets": "anställningsrättighet",
    "anställningsskydden": "anställningsskydd",
    "anställningsskyddens": "anställningsskydd",
    "anställningsskyddet": "anställningsskydd",
    "anställningsskyddets": "anställningsskydd",
    "anställningsskydds": "anställningsskydd",
    "anställningstiden": "anställningstid",
    "anställningstidens": "anställningstid",
    "anställningstider": "anställningstid",
    "anställningstiderna": "anställningstid",
    "anställningstidernas": "anställningstid",
    "anställningstiders": "anställningstid",
    "anställningstids": "anställningstid",
    "anställningstryggheten": "anställningstrygghet",
    "anställningstrygghetens": "anställningstrygghet",
    "anställningstrygghets": "anställningstrygghet",
    "anställs": "anställa",
    "anställt": "anställd",
    "anställts": "anställd",
    "anständiga": "anständig",
    "anständigare": "anständig",
    "anständigares": "anständig",
    "anständigas": "anständig",
    "anständigast": "anständig",
    "anständigaste": "anständig",
    "anständigastes": "anständig",
    "anständigasts": "anständig",
    "anständige": "anständig",
    "anständiges": "anständig",
    "anständigheten": "anständighet",
    "anständighetens": "anständighet",
    "anständigheter": "anständighet",
    "anständigheterna": "anständighet",
    "anständigheternas": "anständighet",
    "anständigheters": "anständighet",
    "anständighets": "anständighet",
    "anständigs": "anständig",
    "anständigt": "anständig",
    "anständigts": "anständig",
    "anstående": "anstå",
    "anståenden": "anstående",
    "anståendena": "anstående",
    "anståendenas": "anstående",
    "anståendens": "anstående",
    "anståendes": "anstående",
    "anståendet": "anstående",
    "anståendets": "anstående",
    "anstånden": "anstånd",
    "anståndens": "anstånd",
    "anståndet": "anstånd",
    "anståndets": "anstånd",
    "anstånds": "anstånd",
    "anstår": "anstå",
    "anstås": "anstå",
    "anstått": "anstå",
    "anståtts": "anstå",
    "anstöten": "anstöt",
    "anstötens": "anstöt",
    "anstötliga": "anstötlig",
    "anstötligare": "anstötlig",
    "anstötligares": "anstötlig",
    "anstötligas": "anstötlig",
    "anstötligast": "anstötlig",
    "anstötligaste": "anstötlig",
    "anstötligastes": "anstötlig",
    "anstötligasts": "anstötlig",
    "anstötlige": "anstötlig",
    "anstötliges": "anstötlig",
    "anstötligheten": "anstötlighet",
    "anstötlighetens": "anstötlighet",
    "anstötligheter": "anstötlighet",
    "anstötligheterna": "anstötlighet",
    "anstötligheternas": "anstötlighet",
    "anstötligheters": "anstötlighet",
    "anstötlighets": "anstötlighet",
    "anstötligs": "anstötlig",
    "anstötligt": "anstötlig",
    "anstötligts": "anstötlig",
    "anstöts": "anstöt",
    "ansvarade": "ansvara",
    "ansvarades": "ansvara",
    "ansvarande": "ansvara",
    "ansvaranden": "ansvarande",
    "ansvarandena": "ansvarande",
    "ansvarandenas": "ansvarande",
    "ansvarandens": "ansvarande",
    "ansvarandes": "ansvarande",
    "ansvarandet": "ansvarande",
    "ansvarandets": "ansvarande",
    "ansvarar": "ansvara",
    "ansvaras": "ansvara",
    "ansvarat": "ansvara",
    "ansvarats": "ansvara",
    "ansvaret": "ansvar",
    "ansvarets": "ansvar",
    "ansvariga": "ansvarig",
    "ansvarigare": "ansvarig",
    "ansvarigares": "ansvarig",
    "ansvarigas": "ansvarig",
    "ansvarigast": "ansvarig",
    "ansvarigaste": "ansvarig",
    "ansvarigastes": "ansvarig",
    "ansvarigasts": "ansvarig",
    "ansvarige": "ansvarig",
    "ansvariges": "ansvarig",
    "ansvarigheten": "ansvarighet",
    "ansvarighetens": "ansvarighet",
    "ansvarighets": "ansvarighet",
    "ansvarighetsförsäkringar": "ansvarighetsförsäkring",
    "ansvarighetsförsäkringarna": "ansvarighetsförsäkring",
    "ansvarighetsförsäkringarnas": "ansvarighetsförsäkring",
    "ansvarighetsförsäkringars": "ansvarighetsförsäkring",
    "ansvarighetsförsäkringen": "ansvarighetsförsäkring",
    "ansvarighetsförsäkringens": "ansvarighetsförsäkring",
    "ansvarighetsförsäkrings": "ansvarighetsförsäkring",
    "ansvarigs": "ansvarig",
    "ansvarigt": "ansvarig",
    "ansvarigts": "ansvarig",
    "ansvaringar": "ansvaring",
    "ansvaringarna": "ansvaring",
    "ansvaringarnas": "ansvaring",
    "ansvaringars": "ansvaring",
    "ansvaringen": "ansvaring",
    "ansvaringens": "ansvaring",
    "ansvarings": "ansvaring",
    "ansvars": "ansvar",
    "ansvarsfriheten": "ansvarsfrihet",
    "ansvarsfrihetens": "ansvarsfrihet",
    "ansvarsfriheter": "ansvarsfrihet",
    "ansvarsfriheterna": "ansvarsfrihet",
    "ansvarsfriheternas": "ansvarsfrihet",
    "ansvarsfriheters": "ansvarsfrihet",
    "ansvarsfrihets": "ansvarsfrihet",
    "ansvarsfulla": "ansvarsfull",
    "ansvarsfullare": "ansvarsfull",
    "ansvarsfullares": "ansvarsfull",
    "ansvarsfullas": "ansvarsfull",
    "ansvarsfullast": "ansvarsfull",
    "ansvarsfullaste": "ansvarsfull",
    "ansvarsfullastes": "ansvarsfull",
    "ansvarsfullasts": "ansvarsfull",
    "ansvarsfulle": "ansvarsfull",
    "ansvarsfulles": "ansvarsfull",
    "ansvarsfullheten": "ansvarsfullhet",
    "ansvarsfullhetens": "ansvarsfullhet",
    "ansvarsfullhets": "ansvarsfullhet",
    "ansvarsfulls": "ansvarsfull",
    "ansvarsfullt": "ansvarsfull",
    "ansvarsfullts": "ansvarsfull",
    "ansvarsförsäkringar": "ansvarsförsäkring",
    "ansvarsförsäkringarna": "ansvarsförsäkring",
    "ansvarsförsäkringarnas": "ansvarsförsäkring",
    "ansvarsförsäkringars": "ansvarsförsäkring",
    "ansvarsförsäkringen": "ansvarsförsäkring",
    "ansvarsförsäkringens": "ansvarsförsäkring",
    "ansvarsförsäkrings": "ansvarsförsäkring",
    "ansvarskännandes": "ansvarskännande",
    "ansvarskännandet": "ansvarskännande",
    "ansvarskännandets": "ansvarskännande",
    "ansvarskänslan": "ansvarskänsla",
    "ansvarskänslans": "ansvarskänsla",
    "ansvarskänslas": "ansvarskänsla",
    "ansvarskänsle": "ansvarskänsla",
    "ansvarskänslo": "ansvarskänsla",
    "ansvarslösa": "ansvarslös",
    "ansvarslösare": "ansvarslös",
    "ansvarslösares": "ansvarslös",
    "ansvarslösas": "ansvarslös",
    "ansvarslösast": "ansvarslös",
    "ansvarslösaste": "ansvarslös",
    "ansvarslösastes": "ansvarslös",
    "ansvarslösasts": "ansvarslös",
    "ansvarslöse": "ansvarslös",
    "ansvarslöses": "ansvarslös",
    "ansvarslösheten": "ansvarslöshet",
    "ansvarslöshetens": "ansvarslöshet",
    "ansvarslöshets": "ansvarslöshet",
    "ansvarslöst": "ansvarslös",
    "ansvarslösts": "ansvarslös",
    "ansvarsnämnden": "ansvarsnämnd",
    "ansvarsnämndens": "ansvarsnämnd",
    "ansvarsnämnder": "ansvarsnämnd",
    "ansvarsnämnderna": "ansvarsnämnd",
    "ansvarsnämndernas": "ansvarsnämnd",
    "ansvarsnämnders": "ansvarsnämnd",
    "ansvarsnämnds": "ansvarsnämnd",
    "ansvarstagandes": "ansvarstagande",
    "ansvarstagandet": "ansvarstagande",
    "ansvarstagandets": "ansvarstagande",
    "ansväll": "ansvälla",
    "ansvällande": "ansvälla",
    "ansvällanden": "ansvällande",
    "ansvällandena": "ansvällande",
    "ansvällandenas": "ansvällande",
    "ansvällandens": "ansvällande",
    "ansvällandes": "ansvällande",
    "ansvällandet": "ansvällande",
    "ansvällandets": "ansvällande",
    "ansvällas": "ansvälla",
    "ansvälld": "ansvälla",
    "ansvällda": "ansvälld",
    "ansvälldare": "ansvälld",
    "ansvälldares": "ansvälld",
    "ansvälldas": "ansvälld",
    "ansvälldast": "ansvälld",
    "ansvälldaste": "ansvälld",
    "ansvälldastes": "ansvälld",
    "ansvälldasts": "ansvälld",
    "ansvällde": "ansvälld",
    "ansvälldes": "ansvälld",
    "ansvälldheten": "ansvälldhet",
    "ansvälldhetens": "ansvälldhet",
    "ansvälldhets": "ansvälldhet",
    "ansvällds": "ansvälld",
    "ansväller": "ansvälla",
    "ansvälles": "ansvälla",
    "ansvällningar": "ansvällning",
    "ansvällningarna": "ansvällning",
    "ansvällningarnas": "ansvällning",
    "ansvällningars": "ansvällning",
    "ansvällningen": "ansvällning",
    "ansvällningens": "ansvällning",
    "ansvällnings": "ansvällning",
    "ansvälls": "ansvälla",
    "ansvällt": "ansvälld",
    "ansvällts": "ansvälld",
    "ansätt": "ansätta",
    "ansättande": "ansätta",
    "ansättanden": "ansättande",
    "ansättandena": "ansättande",
    "ansättandenas": "ansättande",
    "ansättandens": "ansättande",
    "ansättandes": "ansättande",
    "ansättandet": "ansättande",
    "ansättandets": "ansättande",
    "ansättas": "ansätta",
    "ansätter": "ansätta",
    "ansättes": "ansätta",
    "ansättningsskruvar": "ansättningsskruv",
    "ansättningsskruvarna": "ansättningsskruv",
    "ansättningsskruvarnas": "ansättningsskruv",
    "ansättningsskruvars": "ansättningsskruv",
    "ansättningsskruven": "ansättningsskruv",
    "ansättningsskruvens": "ansättningsskruv",
    "ansättningsskruvs": "ansättningsskruv",
    "ansätts": "ansätta",
    "ansåg": "anse",
    "ansåge": "anse",
    "ansåges": "anse",
    "ansågs": "anse",
    "ansök": "ansöka",
    "ansökande": "ansöka",
    "ansökanden": "ansökande",
    "ansökandena": "ansökande",
    "ansökandenas": "ansökande",
    "ansökandens": "ansökande",
    "ansökandes": "ansökande",
    "ansökandet": "ansökande",
    "ansökandets": "ansökande",
    "ansökans": "ansökan",
    "ansökas": "ansöka",
    "ansöker": "ansöka",
    "ansökes": "ansöka",
    "ansökningar": "ansökning",
    "ansökningarna": "ansökning",
    "ansökningarnas": "ansökning",
    "ansökningars": "ansökning",
    "ansökningen": "ansökning",
    "ansökningens": "ansökning",
    "ansöknings": "ansökning",
    "ansökningshandlingar": "ansökningshandling",
    "ansökningshandlingarna": "ansökningshandling",
    "ansökningshandlingarnas": "ansökningshandling",
    "ansökningshandlingars": "ansökningshandling",
    "ansökningshandlingen": "ansökningshandling",
    "ansökningshandlingens": "ansökningshandling",
    "ansökningshandlings": "ansökningshandling",
    "ansökningstiden": "ansökningstid",
    "ansökningstidens": "ansökningstid",
    "ansökningstider": "ansökningstid",
    "ansökningstiderna": "ansökningstid",
    "ansökningstidernas": "ansökningstid",
    "ansökningstiders": "ansökningstid",
    "ansökningstids": "ansökningstid",
    "ansöks": "ansöka",
    "ansökt": "ansöka",
    "ansökta": "ansöka",
    "ansöktas": "ansöka",
    "ansökte": "ansöka",
    "ansöktes": "ansöka",
    "ansökts": "ansöka",
    "antabusen": "antabus",
    "antabusens": "antabus",
    "antag": "anta",
    "antaga": "anta",
    "antagande": "anta",
    "antaganden": "antagande",
    "antagandena": "antagande",
    "antagandenas": "antagande",
    "antagandens": "antagande",
    "antagandes": "antagande",
    "antagandet": "antagande",
    "antagandets": "antagande",
    "antagas": "anta",
    "antage": "anta",
    "antagen": "anta",
    "antagens": "anta",
    "antager": "anta",
    "antages": "anta",
    "antaget": "anta",
    "antagets": "anta",
    "antagit": "anta",
    "antagits": "anta",
    "antagliga": "antaglig",
    "antagligare": "antaglig",
    "antagligares": "antaglig",
    "antagligas": "antaglig",
    "antagligast": "antaglig",
    "antagligaste": "antaglig",
    "antagligastes": "antaglig",
    "antagligasts": "antaglig",
    "antaglige": "antaglig",
    "antagliges": "antaglig",
    "antagligs": "antaglig",
    "antagligt": "antaglig",
    "antagligts": "antaglig",
    "antagna": "anta",
    "antagnas": "anta",
    "antagne": "anta",
    "antagnes": "anta",
    "antagningar": "antagning",
    "antagningarna": "antagning",
    "antagningarnas": "antagning",
    "antagningars": "antagning",
    "antagningen": "antagning",
    "antagningens": "antagning",
    "antagnings": "antagning",
    "antagonismen": "antagonism",
    "antagonismens": "antagonism",
    "antagonismer": "antagonism",
    "antagonismerna": "antagonism",
    "antagonismernas": "antagonism",
    "antagonismers": "antagonism",
    "antagonisms": "antagonism",
    "antagonisten": "antagonist",
    "antagonistens": "antagonist",
    "antagonister": "antagonist",
    "antagonisterna": "antagonist",
    "antagonisternas": "antagonist",
    "antagonisters": "antagonist",
    "antagonistiska": "antagonistisk",
    "antagonistiskare": "antagonistisk",
    "antagonistiskares": "antagonistisk",
    "antagonistiskas": "antagonistisk",
    "antagonistiskast": "antagonistisk",
    "antagonistiskaste": "antagonistisk",
    "antagonistiskastes": "antagonistisk",
    "antagonistiskasts": "antagonistisk",
    "antagonistiske": "antagonistisk",
    "antagonistiskes": "antagonistisk",
    "antagonistisks": "antagonistisk",
    "antagonistiskt": "antagonistisk",
    "antagonistiskts": "antagonistisk",
    "antagonists": "antagonist",
    "antags": "anta",
    "antalen": "antal",
    "antalens": "antal",
    "antalet": "antal",
    "antalets": "antal",
    "antals": "antal",
    "antalsmässiga": "antalsmässig",
    "antalsmässigare": "antalsmässig",
    "antalsmässigares": "antalsmässig",
    "antalsmässigas": "antalsmässig",
    "antalsmässigast": "antalsmässig",
    "antalsmässigaste": "antalsmässig",
    "antalsmässigastes": "antalsmässig",
    "antalsmässigasts": "antalsmässig",
    "antalsmässige": "antalsmässig",
    "antalsmässiges": "antalsmässig",
    "antalsmässigs": "antalsmässig",
    "antalsmässigt": "antalsmässig",
    "antalsmässigts": "antalsmässig",
    "antar": "anta",
    "antarktiska": "antarktisk",
    "antarktiskare": "antarktisk",
    "antarktiskares": "antarktisk",
    "antarktiskas": "antarktisk",
    "antarktiskast": "antarktisk",
    "antarktiskaste": "antarktisk",
    "antarktiskastes": "antarktisk",
    "antarktiskasts": "antarktisk",
    "antarktiske": "antarktisk",
    "antarktiskes": "antarktisk",
    "antarktisks": "antarktisk",
    "antarktiskt": "antarktisk",
    "antarktiskts": "antarktisk",
    "antas": "anta",
    "antast": "antasta",
    "antastad": "antasta",
    "antastade": "antasta",
    "antastades": "antasta",
    "antastads": "antasta",
    "antastande": "antasta",
    "antastanden": "antastande",
    "antastandena": "antastande",
    "antastandenas": "antastande",
    "antastandens": "antastande",
    "antastandes": "antastande",
    "antastandet": "antastande",
    "antastandets": "antastande",
    "antastar": "antasta",
    "antastas": "antasta",
    "antastat": "antasta",
    "antastats": "antasta",
    "antecedentian": "antecedentia",
    "antecedentiana": "antecedentia",
    "antecedentianas": "antecedentia",
    "antecedentians": "antecedentia",
    "antecedentias": "antecedentia",
    "antecedentiat": "antecedentia",
    "antecedentiats": "antecedentia",
    "antecedentie": "antecedentier",
    "antecedentierna": "antecedentier",
    "antecedentiernas": "antecedentier",
    "antecedentiers": "antecedentier",
    "antecipationen": "antecipation",
    "antecipationens": "antecipation",
    "antecipationer": "antecipation",
    "antecipationerna": "antecipation",
    "antecipationernas": "antecipation",
    "antecipationers": "antecipation",
    "antecipations": "antecipation",
    "antecipativa": "antecipativ",
    "antecipativare": "antecipativ",
    "antecipativares": "antecipativ",
    "antecipativas": "antecipativ",
    "antecipativast": "antecipativ",
    "antecipativaste": "antecipativ",
    "antecipativastes": "antecipativ",
    "antecipativasts": "antecipativ",
    "antecipative": "antecipativ",
    "antecipatives": "antecipativ",
    "antecipativs": "antecipativ",
    "antecipativt": "antecipativ",
    "antecipativts": "antecipativ",
    "anteciperad": "antecipera",
    "anteciperade": "antecipera",
    "anteciperades": "antecipera",
    "anteciperads": "antecipera",
    "anteciperande": "antecipera",
    "anteciperanden": "anteciperande",
    "anteciperandena": "anteciperande",
    "anteciperandenas": "anteciperande",
    "anteciperandens": "anteciperande",
    "anteciperandes": "anteciperande",
    "anteciperandet": "anteciperande",
    "anteciperandets": "anteciperande",
    "anteciperar": "antecipera",
    "anteciperas": "antecipera",
    "anteciperat": "antecipera",
    "anteciperats": "antecipera",
    "anteciperbara": "anteciperbar",
    "anteciperbarare": "anteciperbar",
    "anteciperbarares": "anteciperbar",
    "anteciperbaras": "anteciperbar",
    "anteciperbarast": "anteciperbar",
    "anteciperbaraste": "anteciperbar",
    "anteciperbarastes": "anteciperbar",
    "anteciperbarasts": "anteciperbar",
    "anteciperbare": "anteciperbar",
    "anteciperbares": "anteciperbar",
    "anteciperbarheten": "anteciperbarhet",
    "anteciperbarhetens": "anteciperbarhet",
    "anteciperbarhets": "anteciperbarhet",
    "anteciperbars": "anteciperbar",
    "anteciperbart": "anteciperbar",
    "anteciperbarts": "anteciperbar",
    "anteciperingar": "antecipering",
    "anteciperingarna": "antecipering",
    "anteciperingarnas": "antecipering",
    "anteciperingars": "antecipering",
    "anteciperingen": "antecipering",
    "anteciperingens": "antecipering",
    "anteciperings": "antecipering",
    "antecknad": "anteckna",
    "antecknade": "anteckna",
    "antecknades": "anteckna",
    "antecknads": "anteckna",
    "antecknande": "anteckna",
    "antecknanden": "antecknande",
    "antecknandena": "antecknande",
    "antecknandenas": "antecknande",
    "antecknandens": "antecknande",
    "antecknandes": "antecknande",
    "antecknandet": "antecknande",
    "antecknandets": "antecknande",
    "antecknar": "anteckna",
    "antecknas": "anteckna",
    "antecknat": "anteckna",
    "antecknats": "anteckna",
    "anteckningar": "anteckning",
    "anteckningarna": "anteckning",
    "anteckningarnas": "anteckning",
    "anteckningars": "anteckning",
    "anteckningen": "anteckning",
    "anteckningens": "anteckning",
    "antecknings": "anteckning",
    "anteckningsblocken": "anteckningsblock",
    "anteckningsblockens": "anteckningsblock",
    "anteckningsblocket": "anteckningsblock",
    "anteckningsblockets": "anteckningsblock",
    "anteckningsblocks": "anteckningsblock",
    "anteckningsboken": "anteckningsbok",
    "anteckningsbokens": "anteckningsbok",
    "anteckningsboks": "anteckningsbok",
    "anteckningsböcker": "anteckningsbok",
    "anteckningsböckerna": "anteckningsbok",
    "anteckningsböckernas": "anteckningsbok",
    "anteckningsböckers": "anteckningsbok",
    "antedaterad": "antedatera",
    "antedaterade": "antedatera",
    "antedaterades": "antedatera",
    "antedaterads": "antedatera",
    "antedaterande": "antedatera",
    "antedateranden": "antedaterande",
    "antedaterandena": "antedaterande",
    "antedaterandenas": "antedaterande",
    "antedaterandens": "antedaterande",
    "antedaterandes": "antedaterande",
    "antedaterandet": "antedaterande",
    "antedaterandets": "antedaterande",
    "antedaterar": "antedatera",
    "antedateras": "antedatera",
    "antedaterat": "antedatera",
    "antedaterats": "antedatera",
    "antedaterbara": "antedaterbar",
    "antedaterbarare": "antedaterbar",
    "antedaterbarares": "antedaterbar",
    "antedaterbaras": "antedaterbar",
    "antedaterbarast": "antedaterbar",
    "antedaterbaraste": "antedaterbar",
    "antedaterbarastes": "antedaterbar",
    "antedaterbarasts": "antedaterbar",
    "antedaterbare": "antedaterbar",
    "antedaterbares": "antedaterbar",
    "antedaterbarheten": "antedaterbarhet",
    "antedaterbarhetens": "antedaterbarhet",
    "antedaterbarhets": "antedaterbarhet",
    "antedaterbars": "antedaterbar",
    "antedaterbart": "antedaterbar",
    "antedaterbarts": "antedaterbar",
    "antedateringar": "antedatering",
    "antedateringarna": "antedatering",
    "antedateringarnas": "antedatering",
    "antedateringars": "antedatering",
    "antedateringen": "antedatering",
    "antedateringens": "antedatering",
    "antedaterings": "antedatering",
    "antediluvianska": "antediluviansk",
    "antediluvianskare": "antediluviansk",
    "antediluvianskares": "antediluviansk",
    "antediluvianskas": "antediluviansk",
    "antediluvianskast": "antediluviansk",
    "antediluvianskaste": "antediluviansk",
    "antediluvianskastes": "antediluviansk",
    "antediluvianskasts": "antediluviansk",
    "antediluvianske": "antediluviansk",
    "antediluvianskes": "antediluviansk",
    "antediluviansks": "antediluviansk",
    "antediluvianskt": "antediluviansk",
    "antediluvianskts": "antediluviansk",
    "antennen": "antenn",
    "antennens": "antenn",
    "antenner": "antenn",
    "antennerna": "antenn",
    "antennernas": "antenn",
    "antenners": "antenn",
    "antennkabeln": "antennkabel",
    "antennkabelns": "antennkabel",
    "antennkabels": "antennkabel",
    "antennkablar": "antennkabel",
    "antennkablarna": "antennkabel",
    "antennkablarnas": "antennkabel",
    "antennkablars": "antennkabel",
    "antennkörteln": "antennkörtel",
    "antennkörtelns": "antennkörtel",
    "antennkörtels": "antennkörtel",
    "antennkörtlar": "antennkörtel",
    "antennkörtlarna": "antennkörtel",
    "antennkörtlarnas": "antennkörtel",
    "antennkörtlars": "antennkörtel",
    "antenns": "antenn",
    "antependie": "antependium",
    "antependier": "antependium",
    "antependierna": "antependium",
    "antependiernas": "antependium",
    "antependiers": "antependium",
    "antependiet": "antependium",
    "antependiets": "antependium",
    "antependiums": "antependium",
    "antepenultiman": "antepenultima",
    "antepenultimans": "antepenultima",
    "antepenultimas": "antepenultima",
    "antepenultimor": "antepenultima",
    "antepenultimorna": "antepenultima",
    "antepenultimornas": "antepenultima",
    "antepenultimors": "antepenultima",
    "antiabortlagen": "antiabortlag",
    "antiabortlagens": "antiabortlag",
    "antiabortlaget": "antiabortlag",
    "antiabortlagets": "antiabortlag",
    "antiabortlags": "antiabortlag",
    "antibarbarusar": "antibarbarus",
    "antibarbarusarna": "antibarbarus",
    "antibarbarusarnas": "antibarbarus",
    "antibarbarusars": "antibarbarus",
    "antibarbarusen": "antibarbarus",
    "antibarbarusens": "antibarbarus",
    "antibiotika": "antibiotikum",
    "antibiotikan": "antibiotika",
    "antibiotikana": "antibiotikum",
    "antibiotikanas": "antibiotikum",
    "antibiotikans": "antibiotika",
    "antibiotikas": "antibiotikum",
    "antibiotikat": "antibiotika",
    "antibiotikats": "antibiotika",
    "antibiotikor": "antibiotika",
    "antibiotikorna": "antibiotika",
    "antibiotikornas": "antibiotika",
    "antibiotikors": "antibiotika",
    "antibiotikumet": "antibiotikum",
    "antibiotikumets": "antibiotikum",
    "antibiotikums": "antibiotikum",
    "antibiotiska": "antibiotisk",
    "antibiotiskare": "antibiotisk",
    "antibiotiskares": "antibiotisk",
    "antibiotiskas": "antibiotisk",
    "antibiotiskast": "antibiotisk",
    "antibiotiskaste": "antibiotisk",
    "antibiotiskastes": "antibiotisk",
    "antibiotiskasts": "antibiotisk",
    "antibiotiske": "antibiotisk",
    "antibiotiskes": "antibiotisk",
    "antibiotisks": "antibiotisk",
    "antibiotiskt": "antibiotisk",
    "antibiotiskts": "antibiotisk",
    "antichambrerad": "antichambrera",
    "antichambrerade": "antichambrera",
    "antichambrerades": "antichambrera",
    "antichambrerads": "antichambrera",
    "antichambrerande": "antichambrera",
    "antichambreranden": "antichambrerande",
    "antichambrerandena": "antichambrerande",
    "antichambrerandenas": "antichambrerande",
    "antichambrerandens": "antichambrerande",
    "antichambrerandes": "antichambrerande",
    "antichambrerandet": "antichambrerande",
    "antichambrerandets": "antichambrerande",
    "antichambrerar": "antichambrera",
    "antichambreras": "antichambrera",
    "antichambrerat": "antichambrera",
    "antichambrerats": "antichambrera",
    "antichambrerbara": "antichambrerbar",
    "antichambrerbarare": "antichambrerbar",
    "antichambrerbarares": "antichambrerbar",
    "antichambrerbaras": "antichambrerbar",
    "antichambrerbarast": "antichambrerbar",
    "antichambrerbaraste": "antichambrerbar",
    "antichambrerbarastes": "antichambrerbar",
    "antichambrerbarasts": "antichambrerbar",
    "antichambrerbare": "antichambrerbar",
    "antichambrerbares": "antichambrerbar",
    "antichambrerbarheten": "antichambrerbarhet",
    "antichambrerbarhetens": "antichambrerbarhet",
    "antichambrerbarhets": "antichambrerbarhet",
    "antichambrerbars": "antichambrerbar",
    "antichambrerbart": "antichambrerbar",
    "antichambrerbarts": "antichambrerbar",
    "antichambreringar": "antichambrering",
    "antichambreringarna": "antichambrering",
    "antichambreringarnas": "antichambrering",
    "antichambreringars": "antichambrering",
    "antichambreringen": "antichambrering",
    "antichambreringens": "antichambrering",
    "antichambrerings": "antichambrering",
    "anticyklonen": "anticyklon",
    "anticyklonens": "anticyklon",
    "anticykloner": "anticyklon",
    "anticyklonerna": "anticyklon",
    "anticyklonernas": "anticyklon",
    "anticykloners": "anticyklon",
    "anticyklons": "anticyklon",
    "antidemokratiska": "antidemokratisk",
    "antidemokratiskare": "antidemokratisk",
    "antidemokratiskares": "antidemokratisk",
    "antidemokratiskas": "antidemokratisk",
    "antidemokratiskast": "antidemokratisk",
    "antidemokratiskaste": "antidemokratisk",
    "antidemokratiskastes": "antidemokratisk",
    "antidemokratiskasts": "antidemokratisk",
    "antidemokratiske": "antidemokratisk",
    "antidemokratiskes": "antidemokratisk",
    "antidemokratisks": "antidemokratisk",
    "antidemokratiskt": "antidemokratisk",
    "antidemokratiskts": "antidemokratisk",
    "antidepressiva": "antidepressiv",
    "antidepressivare": "antidepressiv",
    "antidepressivares": "antidepressiv",
    "antidepressivas": "antidepressiv",
    "antidepressivast": "antidepressiv",
    "antidepressivaste": "antidepressiv",
    "antidepressivastes": "antidepressiv",
    "antidepressivasts": "antidepressiv",
    "antidepressive": "antidepressiv",
    "antidepressives": "antidepressiv",
    "antidepressivs": "antidepressiv",
    "antidepressivt": "antidepressiv",
    "antidepressivts": "antidepressiv",
    "antidiskrimineringsbyråer": "antidiskrimineringsbyrå",
    "antidiskrimineringsbyråerna": "antidiskrimineringsbyrå",
    "antidiskrimineringsbyråernas": "antidiskrimineringsbyrå",
    "antidiskrimineringsbyråers": "antidiskrimineringsbyrå",
    "antidiskrimineringsbyrån": "antidiskrimineringsbyrå",
    "antidiskrimineringsbyråns": "antidiskrimineringsbyrå",
    "antidiskrimineringsbyrås": "antidiskrimineringsbyrå",
    "antidoter": "antidot",
    "antidoterna": "antidot",
    "antidoternas": "antidot",
    "antidoters": "antidot",
    "antidotet": "antidot",
    "antidotets": "antidot",
    "antidots": "antidot",
    "antielitistiska": "antielitistisk",
    "antielitistiskas": "antielitistisk",
    "antielitistiske": "antielitistisk",
    "antielitistiskes": "antielitistisk",
    "antielitistisks": "antielitistisk",
    "antielitistiskt": "antielitistisk",
    "antielitistiskts": "antielitistisk",
    "antiexpressionistiska": "antiexpressionistisk",
    "antiexpressionistiskas": "antiexpressionistisk",
    "antiexpressionistiske": "antiexpressionistisk",
    "antiexpressionistiskes": "antiexpressionistisk",
    "antiexpressionistisks": "antiexpressionistisk",
    "antiexpressionistiskt": "antiexpressionistisk",
    "antiexpressionistiskts": "antiexpressionistisk",
    "antifonien": "antifoni",
    "antifoniens": "antifoni",
    "antifonier": "antifoni",
    "antifonierna": "antifoni",
    "antifoniernas": "antifoni",
    "antifoniers": "antifoni",
    "antifonin": "antifoni",
    "antifonins": "antifoni",
    "antifonis": "antifoni",
    "antifundamentalistiska": "antifundamentalistisk",
    "antifundamentalistiskas": "antifundamentalistisk",
    "antifundamentalistiske": "antifundamentalistisk",
    "antifundamentalistiskes": "antifundamentalistisk",
    "antifundamentalistisks": "antifundamentalistisk",
    "antifundamentalistiskt": "antifundamentalistisk",
    "antifundamentalistiskts": "antifundamentalistisk",
    "antigenen": "antigen",
    "antigenens": "antigen",
    "antigener": "antigen",
    "antigenerna": "antigen",
    "antigenernas": "antigen",
    "antigeners": "antigen",
    "antigens": "antigen",
    "antiguanen": "antiguan",
    "antiguanens": "antiguan",
    "antiguaner": "antiguan",
    "antiguanerna": "antiguan",
    "antiguanernas": "antiguan",
    "antiguaners": "antiguan",
    "antiguans": "antiguan",
    "antiguanska": "antiguansk",
    "antiguanskan": "antiguanska",
    "antiguanskans": "antiguanska",
    "antiguanskare": "antiguansk",
    "antiguanskares": "antiguansk",
    "antiguanskas": "antiguanska",
    "antiguanskast": "antiguansk",
    "antiguanskaste": "antiguansk",
    "antiguanskastes": "antiguansk",
    "antiguanskasts": "antiguansk",
    "antiguanske": "antiguanska",
    "antiguanskes": "antiguansk",
    "antiguanskor": "antiguanska",
    "antiguanskorna": "antiguanska",
    "antiguanskornas": "antiguanska",
    "antiguanskors": "antiguanska",
    "antiguansks": "antiguansk",
    "antiguanskt": "antiguansk",
    "antiguanskts": "antiguansk",
    "antihistaminer": "antihistamin",
    "antihistaminerna": "antihistamin",
    "antihistaminernas": "antihistamin",
    "antihistaminers": "antihistamin",
    "antihistaminet": "antihistamin",
    "antihistaminets": "antihistamin",
    "antihistamins": "antihistamin",
    "antihjältar": "antihjälte",
    "antihjältarna": "antihjälte",
    "antihjältarnas": "antihjälte",
    "antihjältars": "antihjälte",
    "antihjälten": "antihjälte",
    "antihjältens": "antihjälte",
    "antihjältes": "antihjälte",
    "antihumanistiska": "antihumanistisk",
    "antihumanistiskas": "antihumanistisk",
    "antihumanistiske": "antihumanistisk",
    "antihumanistiskes": "antihumanistisk",
    "antihumanistisks": "antihumanistisk",
    "antihumanistiskt": "antihumanistisk",
    "antihumanistiskts": "antihumanistisk",
    "antiidealistiska": "antiidealistisk",
    "antiidealistiskas": "antiidealistisk",
    "antiidealistiske": "antiidealistisk",
    "antiidealistiskes": "antiidealistisk",
    "antiidealistisks": "antiidealistisk",
    "antiidealistiskt": "antiidealistisk",
    "antiidealistiskts": "antiidealistisk",
    "antiimperialistiska": "antiimperialistisk",
    "antiimperialistiskas": "antiimperialistisk",
    "antiimperialistiske": "antiimperialistisk",
    "antiimperialistiskes": "antiimperialistisk",
    "antiimperialistisks": "antiimperialistisk",
    "antiimperialistiskt": "antiimperialistisk",
    "antiimperialistiskts": "antiimperialistisk",
    "antiindividualistiska": "antiindividualistisk",
    "antiindividualistiskas": "antiindividualistisk",
    "antiindividualistiske": "antiindividualistisk",
    "antiindividualistiskes": "antiindividualistisk",
    "antiindividualistisks": "antiindividualistisk",
    "antiindividualistiskt": "antiindividualistisk",
    "antiindividualistiskts": "antiindividualistisk",
    "antiintellektualismen": "antiintellektualism",
    "antiintellektualismens": "antiintellektualism",
    "antiintellektualismer": "antiintellektualism",
    "antiintellektualismerna": "antiintellektualism",
    "antiintellektualismernas": "antiintellektualism",
    "antiintellektualismers": "antiintellektualism",
    "antiintellektualisms": "antiintellektualism",
    "antiintellektualistiska": "antiintellektualistisk",
    "antiintellektualistiskas": "antiintellektualistisk",
    "antiintellektualistiske": "antiintellektualistisk",
    "antiintellektualistiskes": "antiintellektualistisk",
    "antiintellektualistisks": "antiintellektualistisk",
    "antiintellektualistiskt": "antiintellektualistisk",
    "antiintellektualistiskts": "antiintellektualistisk",
    "antiintellektuella": "antiintellektuell",
    "antiintellektuellare": "antiintellektuell",
    "antiintellektuellares": "antiintellektuell",
    "antiintellektuellas": "antiintellektuell",
    "antiintellektuellast": "antiintellektuell",
    "antiintellektuellaste": "antiintellektuell",
    "antiintellektuellastes": "antiintellektuell",
    "antiintellektuellasts": "antiintellektuell",
    "antiintellektuelle": "antiintellektuell",
    "antiintellektuelles": "antiintellektuell",
    "antiintellektuells": "antiintellektuell",
    "antiintellektuellt": "antiintellektuell",
    "antiintellektuellts": "antiintellektuell",
    "antiislamistiska": "antiislamistisk",
    "antiislamistiskas": "antiislamistisk",
    "antiislamistiske": "antiislamistisk",
    "antiislamistiskes": "antiislamistisk",
    "antiislamistisks": "antiislamistisk",
    "antiislamistiskt": "antiislamistisk",
    "antiislamistiskts": "antiislamistisk",
    "antika": "antik",
    "antikare": "antik",
    "antikares": "antik",
    "antikas": "antik",
    "antikast": "antik",
    "antikaste": "antik",
    "antikastes": "antik",
    "antikasts": "antik",
    "antikbehandlad": "antikbehandla",
    "antikbehandlade": "antikbehandla",
    "antikbehandlades": "antikbehandla",
    "antikbehandlads": "antikbehandla",
    "antikbehandlande": "antikbehandla",
    "antikbehandlanden": "antikbehandlande",
    "antikbehandlandena": "antikbehandlande",
    "antikbehandlandenas": "antikbehandlande",
    "antikbehandlandens": "antikbehandlande",
    "antikbehandlandes": "antikbehandlande",
    "antikbehandlandet": "antikbehandlande",
    "antikbehandlandets": "antikbehandlande",
    "antikbehandlar": "antikbehandla",
    "antikbehandlas": "antikbehandla",
    "antikbehandlat": "antikbehandla",
    "antikbehandlats": "antikbehandla",
    "antike": "antik",
    "antiken": "antik",
    "antikens": "antik",
    "antikes": "antik",
    "antikfyndad": "antikfynda",
    "antikfyndade": "antikfynda",
    "antikfyndades": "antikfynda",
    "antikfyndads": "antikfynda",
    "antikfyndande": "antikfynda",
    "antikfyndanden": "antikfyndande",
    "antikfyndandena": "antikfyndande",
    "antikfyndandenas": "antikfyndande",
    "antikfyndandens": "antikfyndande",
    "antikfyndandes": "antikfyndande",
    "antikfyndandet": "antikfyndande",
    "antikfyndandets": "antikfyndande",
    "antikfyndar": "antikfynda",
    "antikfyndas": "antikfynda",
    "antikfyndat": "antikfynda",
    "antikfyndats": "antikfynda",
    "antikiserad": "antikisera",
    "antikiserade": "antikisera",
    "antikiserades": "antikisera",
    "antikiserads": "antikisera",
    "antikiserande": "antikisera",
    "antikiseranden": "antikiserande",
    "antikiserandena": "antikiserande",
    "antikiserandenas": "antikiserande",
    "antikiserandens": "antikiserande",
    "antikiserandes": "antikiserande",
    "antikiserandet": "antikiserande",
    "antikiserandets": "antikiserande",
    "antikiserar": "antikisera",
    "antikiseras": "antikisera",
    "antikiserat": "antikisera",
    "antikiserats": "antikisera",
    "antikiserbara": "antikiserbar",
    "antikiserbarare": "antikiserbar",
    "antikiserbarares": "antikiserbar",
    "antikiserbaras": "antikiserbar",
    "antikiserbarast": "antikiserbar",
    "antikiserbaraste": "antikiserbar",
    "antikiserbarastes": "antikiserbar",
    "antikiserbarasts": "antikiserbar",
    "antikiserbare": "antikiserbar",
    "antikiserbares": "antikiserbar",
    "antikiserbarheten": "antikiserbarhet",
    "antikiserbarhetens": "antikiserbarhet",
    "antikiserbarhets": "antikiserbarhet",
    "antikiserbars": "antikiserbar",
    "antikiserbart": "antikiserbar",
    "antikiserbarts": "antikiserbar",
    "antikiseringar": "antikisering",
    "antikiseringarna": "antikisering",
    "antikiseringarnas": "antikisering",
    "antikiseringars": "antikisering",
    "antikiseringen": "antikisering",
    "antikiseringens": "antikisering",
    "antikiserings": "antikisering",
    "antiklerikala": "antiklerikal",
    "antiklerikalare": "antiklerikal",
    "antiklerikalares": "antiklerikal",
    "antiklerikalas": "antiklerikal",
    "antiklerikalast": "antiklerikal",
    "antiklerikalaste": "antiklerikal",
    "antiklerikalastes": "antiklerikal",
    "antiklerikalasts": "antiklerikal",
    "antiklerikale": "antiklerikal",
    "antiklerikales": "antiklerikal",
    "antiklerikals": "antiklerikal",
    "antiklerikalt": "antiklerikal",
    "antiklerikalts": "antiklerikal",
    "antiklimaxar": "antiklimax",
    "antiklimaxarna": "antiklimax",
    "antiklimaxarnas": "antiklimax",
    "antiklimaxars": "antiklimax",
    "antiklimaxen": "antiklimax",
    "antiklimaxens": "antiklimax",
    "antiklinalen": "antiklinal",
    "antiklinalens": "antiklinal",
    "antiklinaler": "antiklinal",
    "antiklinalerna": "antiklinal",
    "antiklinalernas": "antiklinal",
    "antiklinalers": "antiklinal",
    "antiklinals": "antiklinal",
    "antikljusen": "antikljus",
    "antikljusens": "antikljus",
    "antikljuset": "antikljus",
    "antikljusets": "antikljus",
    "antikommunismen": "antikommunism",
    "antikommunismens": "antikommunism",
    "antikommunismer": "antikommunism",
    "antikommunismerna": "antikommunism",
    "antikommunismernas": "antikommunism",
    "antikommunismers": "antikommunism",
    "antikommunisms": "antikommunism",
    "antikommunistiska": "antikommunistisk",
    "antikommunistiskare": "antikommunistisk",
    "antikommunistiskares": "antikommunistisk",
    "antikommunistiskas": "antikommunistisk",
    "antikommunistiskast": "antikommunistisk",
    "antikommunistiskaste": "antikommunistisk",
    "antikommunistiskastes": "antikommunistisk",
    "antikommunistiskasts": "antikommunistisk",
    "antikommunistiske": "antikommunistisk",
    "antikommunistiskes": "antikommunistisk",
    "antikommunistisks": "antikommunistisk",
    "antikommunistiskt": "antikommunistisk",
    "antikommunistiskts": "antikommunistisk",
    "antikonceptionella": "antikonceptionell",
    "antikonceptionellare": "antikonceptionell",
    "antikonceptionellares": "antikonceptionell",
    "antikonceptionellas": "antikonceptionell",
    "antikonceptionellast": "antikonceptionell",
    "antikonceptionellaste": "antikonceptionell",
    "antikonceptionellastes": "antikonceptionell",
    "antikonceptionellasts": "antikonceptionell",
    "antikonceptionelle": "antikonceptionell",
    "antikonceptionelles": "antikonceptionell",
    "antikonceptionells": "antikonceptionell",
    "antikonceptionellt": "antikonceptionell",
    "antikonceptionellts": "antikonceptionell",
    "antikorruptionskonferensen": "antikorruptionskonferens",
    "antikorruptionskonferensens": "antikorruptionskonferens",
    "antikorruptionskonferenser": "antikorruptionskonferens",
    "antikorruptionskonferenserna": "antikorruptionskonferens",
    "antikorruptionskonferensernas": "antikorruptionskonferens",
    "antikorruptionskonferensers": "antikorruptionskonferens",
    "antikroppar": "antikropp",
    "antikropparna": "antikropp",
    "antikropparnas": "antikropp",
    "antikroppars": "antikropp",
    "antikroppen": "antikropp",
    "antikroppens": "antikropp",
    "antikropps": "antikropp",
    "antiks": "antik",
    "antikt": "antik",
    "antikts": "antik",
    "antikvan": "antikva",
    "antikvans": "antikva",
    "antikvariaten": "antikvariat",
    "antikvariatens": "antikvariat",
    "antikvariatet": "antikvariat",
    "antikvariatets": "antikvariat",
    "antikvariats": "antikvariat",
    "antikvarien": "antikvarie",
    "antikvariens": "antikvarie",
    "antikvarier": "antikvarie",
    "antikvarierna": "antikvarie",
    "antikvariernas": "antikvarie",
    "antikvariers": "antikvarie",
    "antikvaries": "antikvarie",
    "antikvariska": "antikvarisk",
    "antikvariskare": "antikvarisk",
    "antikvariskares": "antikvarisk",
    "antikvariskas": "antikvarisk",
    "antikvariskast": "antikvarisk",
    "antikvariskaste": "antikvarisk",
    "antikvariskastes": "antikvarisk",
    "antikvariskasts": "antikvarisk",
    "antikvariske": "antikvarisk",
    "antikvariskes": "antikvarisk",
    "antikvarisks": "antikvarisk",
    "antikvariskt": "antikvarisk",
    "antikvariskts": "antikvarisk",
    "antikvas": "antikva",
    "antikverade": "antikverad",
    "antikverades": "antikverad",
    "antikverads": "antikverad",
    "antikverat": "antikverad",
    "antikverats": "antikverad",
    "antikviteten": "antikvitet",
    "antikvitetens": "antikvitet",
    "antikviteter": "antikvitet",
    "antikviteterna": "antikvitet",
    "antikviteternas": "antikvitet",
    "antikviteters": "antikvitet",
    "antikvitets": "antikvitet",
    "antikvärdes": "antikvärde",
    "antikvärdet": "antikvärde",
    "antikvärdets": "antikvärde",
    "antilopen": "antilop",
    "antilopens": "antilop",
    "antiloper": "antilop",
    "antiloperna": "antilop",
    "antilopernas": "antilop",
    "antilopers": "antilop",
    "antilops": "antilop",
    "antimakassen": "antimakass",
    "antimakassens": "antimakass",
    "antimakasser": "antimakass",
    "antimakasserna": "antimakass",
    "antimakassernas": "antimakass",
    "antimakassers": "antimakass",
    "antimaterian": "antimateria",
    "antimaterians": "antimateria",
    "antimaterias": "antimateria",
    "antimaterien": "antimateria",
    "antimateriens": "antimateria",
    "antimilitarismen": "antimilitarism",
    "antimilitarismens": "antimilitarism",
    "antimilitarismer": "antimilitarism",
    "antimilitarismerna": "antimilitarism",
    "antimilitarismernas": "antimilitarism",
    "antimilitarismers": "antimilitarism",
    "antimilitarisms": "antimilitarism",
    "antimilitaristen": "antimilitarist",
    "antimilitaristens": "antimilitarist",
    "antimilitarister": "antimilitarist",
    "antimilitaristerna": "antimilitarist",
    "antimilitaristernas": "antimilitarist",
    "antimilitaristers": "antimilitarist",
    "antimilitaristiska": "antimilitaristisk",
    "antimilitaristiskare": "antimilitaristisk",
    "antimilitaristiskares": "antimilitaristisk",
    "antimilitaristiskas": "antimilitaristisk",
    "antimilitaristiskast": "antimilitaristisk",
    "antimilitaristiskaste": "antimilitaristisk",
    "antimilitaristiskastes": "antimilitaristisk",
    "antimilitaristiskasts": "antimilitaristisk",
    "antimilitaristiske": "antimilitaristisk",
    "antimilitaristiskes": "antimilitaristisk",
    "antimilitaristisks": "antimilitaristisk",
    "antimilitaristiskt": "antimilitaristisk",
    "antimilitaristiskts": "antimilitaristisk",
    "antimilitarists": "antimilitarist",
    "antimonen": "antimon",
    "antimonens": "antimon",
    "antimonet": "antimon",
    "antimonets": "antimon",
    "antimonglansen": "antimonglans",
    "antimonglansens": "antimonglans",
    "antimons": "antimon",
    "antimögelbehandlade": "antimögelbehandlad",
    "antimögelbehandlades": "antimögelbehandlad",
    "antimögelbehandlads": "antimögelbehandlad",
    "antimögelbehandlat": "antimögelbehandlad",
    "antimögelbehandlats": "antimögelbehandlad",
    "antinomien": "antinomi",
    "antinomiens": "antinomi",
    "antinomier": "antinomi",
    "antinomierna": "antinomi",
    "antinomiernas": "antinomi",
    "antinomiers": "antinomi",
    "antinomin": "antinomi",
    "antinomins": "antinomi",
    "antinomis": "antinomi",
    "antioxidanten": "antioxidant",
    "antioxidantens": "antioxidant",
    "antioxidanter": "antioxidant",
    "antioxidanterna": "antioxidant",
    "antioxidanternas": "antioxidant",
    "antioxidanters": "antioxidant",
    "antioxidants": "antioxidant",
    "antioxidationsmedels": "antioxidationsmedel",
    "antioxidationsmedlen": "antioxidationsmedel",
    "antioxidationsmedlens": "antioxidationsmedel",
    "antioxidationsmedlet": "antioxidationsmedel",
    "antioxidationsmedlets": "antioxidationsmedel",
    "antipartikeln": "antipartikel",
    "antipartikelns": "antipartikel",
    "antipartikels": "antipartikel",
    "antipartiklar": "antipartikel",
    "antipartiklarna": "antipartikel",
    "antipartiklarnas": "antipartikel",
    "antipartiklars": "antipartikel",
    "antipassaden": "antipassad",
    "antipassadens": "antipassad",
    "antipassader": "antipassad",
    "antipassaderna": "antipassad",
    "antipassadernas": "antipassad",
    "antipassaders": "antipassad",
    "antipassads": "antipassad",
    "antipatien": "antipati",
    "antipatiens": "antipati",
    "antipatier": "antipati",
    "antipatierna": "antipati",
    "antipatiernas": "antipati",
    "antipatiers": "antipati",
    "antipatin": "antipati",
    "antipatins": "antipati",
    "antipatis": "antipati",
    "antipoden": "antipod",
    "antipodens": "antipod",
    "antipoder": "antipod",
    "antipoderna": "antipod",
    "antipodernas": "antipod",
    "antipoders": "antipod",
    "antipods": "antipod",
    "antipolitiska": "antipolitisk",
    "antipolitiskas": "antipolitisk",
    "antipolitiske": "antipolitisk",
    "antipolitiskes": "antipolitisk",
    "antipolitisks": "antipolitisk",
    "antipolitiskt": "antipolitisk",
    "antipolitiskts": "antipolitisk",
    "antipsykiatrien": "antipsykiatri",
    "antipsykiatriens": "antipsykiatri",
    "antipsykiatrin": "antipsykiatri",
    "antipsykiatrins": "antipsykiatri",
    "antipsykiatris": "antipsykiatri",
    "antireflexbehandlad": "antireflexbehandla",
    "antireflexbehandlade": "antireflexbehandla",
    "antireflexbehandlades": "antireflexbehandla",
    "antireflexbehandlads": "antireflexbehandla",
    "antireflexbehandlande": "antireflexbehandla",
    "antireflexbehandlandes": "antireflexbehandla",
    "antireflexbehandlar": "antireflexbehandla",
    "antireflexbehandlas": "antireflexbehandla",
    "antireflexbehandlat": "antireflexbehandla",
    "antireflexbehandlats": "antireflexbehandla",
    "antirynkkrämen": "antirynkkräm",
    "antirynkkrämens": "antirynkkräm",
    "antirynkkrämer": "antirynkkräm",
    "antirynkkrämerna": "antirynkkräm",
    "antirynkkrämernas": "antirynkkräm",
    "antirynkkrämers": "antirynkkräm",
    "antirynkkräms": "antirynkkräm",
    "antisemiten": "antisemit",
    "antisemitens": "antisemit",
    "antisemiter": "antisemit",
    "antisemiterna": "antisemit",
    "antisemiternas": "antisemit",
    "antisemiters": "antisemit",
    "antisemitiska": "antisemitisk",
    "antisemitiskare": "antisemitisk",
    "antisemitiskares": "antisemitisk",
    "antisemitiskas": "antisemitisk",
    "antisemitiskast": "antisemitisk",
    "antisemitiskaste": "antisemitisk",
    "antisemitiskastes": "antisemitisk",
    "antisemitiskasts": "antisemitisk",
    "antisemitiske": "antisemitisk",
    "antisemitiskes": "antisemitisk",
    "antisemitisks": "antisemitisk",
    "antisemitiskt": "antisemitisk",
    "antisemitiskts": "antisemitisk",
    "antisemitismen": "antisemitism",
    "antisemitismens": "antisemitism",
    "antisemitismer": "antisemitism",
    "antisemitismerna": "antisemitism",
    "antisemitismernas": "antisemitism",
    "antisemitismers": "antisemitism",
    "antisemitisms": "antisemitism",
    "antisemits": "antisemit",
    "antiseptikan": "antiseptika",
    "antiseptikana": "antiseptika",
    "antiseptikanas": "antiseptika",
    "antiseptikans": "antiseptika",
    "antiseptikas": "antiseptika",
    "antiseptikat": "antiseptika",
    "antiseptikats": "antiseptika",
    "antiseptiken": "antiseptik",
    "antiseptikens": "antiseptik",
    "antiseptiks": "antiseptik",
    "antiseptiska": "antiseptisk",
    "antiseptiskare": "antiseptisk",
    "antiseptiskares": "antiseptisk",
    "antiseptiskas": "antiseptisk",
    "antiseptiskast": "antiseptisk",
    "antiseptiskaste": "antiseptisk",
    "antiseptiskastes": "antiseptisk",
    "antiseptiskasts": "antiseptisk",
    "antiseptiske": "antiseptisk",
    "antiseptiskes": "antiseptisk",
    "antiseptisks": "antiseptisk",
    "antiseptiskt": "antiseptisk",
    "antiseptiskts": "antiseptisk",
    "antisionismen": "antisionism",
    "antisionismens": "antisionism",
    "antisionismer": "antisionism",
    "antisionismerna": "antisionism",
    "antisionismernas": "antisionism",
    "antisionismers": "antisionism",
    "antisionisms": "antisionism",
    "antisionistiska": "antisionistisk",
    "antisionistiskare": "antisionistisk",
    "antisionistiskares": "antisionistisk",
    "antisionistiskas": "antisionistisk",
    "antisionistiskast": "antisionistisk",
    "antisionistiskaste": "antisionistisk",
    "antisionistiskastes": "antisionistisk",
    "antisionistiskasts": "antisionistisk",
    "antisionistiske": "antisionistisk",
    "antisionistiskes": "antisionistisk",
    "antisionistisks": "antisionistisk",
    "antisionistiskt": "antisionistisk",
    "antisionistiskts": "antisionistisk",
    "antiskatingar": "antiskating",
    "antiskatingarna": "antiskating",
    "antiskatingarnas": "antiskating",
    "antiskatingars": "antiskating",
    "antiskatingen": "antiskating",
    "antiskatingens": "antiskating",
    "antiskatings": "antiskating",
    "antistatiska": "antistatisk",
    "antistatiskare": "antistatisk",
    "antistatiskares": "antistatisk",
    "antistatiskas": "antistatisk",
    "antistatiskast": "antistatisk",
    "antistatiskaste": "antistatisk",
    "antistatiskastes": "antistatisk",
    "antistatiskasts": "antistatisk",
    "antistatiske": "antistatisk",
    "antistatiskes": "antistatisk",
    "antistatisks": "antistatisk",
    "antistatiskt": "antistatisk",
    "antistatiskts": "antistatisk",
    "antistatmedels": "antistatmedel",
    "antistatmedlen": "antistatmedel",
    "antistatmedlens": "antistatmedel",
    "antistatmedlet": "antistatmedel",
    "antistatmedlets": "antistatmedel",
    "antitesen": "antites",
    "antitesens": "antites",
    "antiteser": "antites",
    "antiteserna": "antites",
    "antitesernas": "antites",
    "antitesers": "antites",
    "antitetiska": "antitetisk",
    "antitetiskare": "antitetisk",
    "antitetiskares": "antitetisk",
    "antitetiskas": "antitetisk",
    "antitetiskast": "antitetisk",
    "antitetiskaste": "antitetisk",
    "antitetiskastes": "antitetisk",
    "antitetiskasts": "antitetisk",
    "antitetiske": "antitetisk",
    "antitetiskes": "antitetisk",
    "antitetisks": "antitetisk",
    "antitetiskt": "antitetisk",
    "antitetiskts": "antitetisk",
    "antitoxinen": "antitoxin",
    "antitoxinens": "antitoxin",
    "antitoxiner": "antitoxin",
    "antitoxinerna": "antitoxin",
    "antitoxinernas": "antitoxin",
    "antitoxiners": "antitoxin",
    "antitoxinet": "antitoxin",
    "antitoxinets": "antitoxin",
    "antitoxins": "antitoxin",
    "antivibrationshandtagen": "antivibrationshandtag",
    "antivibrationshandtagens": "antivibrationshandtag",
    "antivibrationshandtaget": "antivibrationshandtag",
    "antivibrationshandtagets": "antivibrationshandtag",
    "antivibrationshandtags": "antivibrationshandtag",
    "antivirusexperten": "antivirusexpert",
    "antivirusexpertens": "antivirusexpert",
    "antivirusexperter": "antivirusexpert",
    "antivirusexperterna": "antivirusexpert",
    "antivirusexperternas": "antivirusexpert",
    "antivirusexperters": "antivirusexpert",
    "antivirusexperts": "antivirusexpert",
    "antivirusprogrammen": "antivirusprogram",
    "antivirusprogrammens": "antivirusprogram",
    "antivirusprogrammet": "antivirusprogram",
    "antivirusprogrammets": "antivirusprogram",
    "antivirusprograms": "antivirusprogram",
    "antog": "anta",
    "antoge": "anta",
    "antoges": "anta",
    "antogs": "anta",
    "antologien": "antologi",
    "antologiens": "antologi",
    "antologier": "antologi",
    "antologierna": "antologi",
    "antologiernas": "antologi",
    "antologiers": "antologi",
    "antologin": "antologi",
    "antologins": "antologi",
    "antologis": "antologi",
    "antonyma": "antonym",
    "antonymare": "antonym",
    "antonymares": "antonym",
    "antonymas": "antonym",
    "antonymast": "antonym",
    "antonymaste": "antonym",
    "antonymastes": "antonym",
    "antonymasts": "antonym",
    "antonyme": "antonym",
    "antonymen": "antonym",
    "antonymens": "antonym",
    "antonymer": "antonym",
    "antonymerna": "antonym",
    "antonymernas": "antonym",
    "antonymers": "antonym",
    "antonymes": "antonym",
    "antonyms": "antonym",
    "antonymt": "antonym",
    "antonymts": "antonym",
    "antraciten": "antracit",
    "antracitens": "antracit",
    "antracits": "antracit",
    "antropiska": "antropisk",
    "antropiskare": "antropisk",
    "antropiskares": "antropisk",
    "antropiskas": "antropisk",
    "antropiskast": "antropisk",
    "antropiskaste": "antropisk",
    "antropiskastes": "antropisk",
    "antropiskasts": "antropisk",
    "antropiske": "antropisk",
    "antropiskes": "antropisk",
    "antropisks": "antropisk",
    "antropiskt": "antropisk",
    "antropiskts": "antropisk",
    "antropocentriska": "antropocentrisk",
    "antropocentriskare": "antropocentrisk",
    "antropocentriskares": "antropocentrisk",
    "antropocentriskas": "antropocentrisk",
    "antropocentriskast": "antropocentrisk",
    "antropocentriskaste": "antropocentrisk",
    "antropocentriskastes": "antropocentrisk",
    "antropocentriskasts": "antropocentrisk",
    "antropocentriske": "antropocentrisk",
    "antropocentriskes": "antropocentrisk",
    "antropocentrisks": "antropocentrisk",
    "antropocentriskt": "antropocentrisk",
    "antropocentriskts": "antropocentrisk",
    "antropofagen": "antropofag",
    "antropofagens": "antropofag",
    "antropofager": "antropofag",
    "antropofagerna": "antropofag",
    "antropofagernas": "antropofag",
    "antropofagers": "antropofag",
    "antropofags": "antropofag",
    "antropoiden": "antropoid",
    "antropoidens": "antropoid",
    "antropoider": "antropoid",
    "antropoiderna": "antropoid",
    "antropoidernas": "antropoid",
    "antropoiders": "antropoid",
    "antropoids": "antropoid",
    "antropologen": "antropolog",
    "antropologens": "antropolog",
    "antropologer": "antropolog",
    "antropologerna": "antropolog",
    "antropologernas": "antropolog",
    "antropologers": "antropolog",
    "antropologien": "antropologi",
    "antropologiens": "antropologi",
    "antropologin": "antropologi",
    "antropologins": "antropologi",
    "antropologis": "antropologi",
    "antropologiska": "antropologisk",
    "antropologiskare": "antropologisk",
    "antropologiskares": "antropologisk",
    "antropologiskas": "antropologisk",
    "antropologiskast": "antropologisk",
    "antropologiskaste": "antropologisk",
    "antropologiskastes": "antropologisk",
    "antropologiskasts": "antropologisk",
    "antropologiske": "antropologisk",
    "antropologiskes": "antropologisk",
    "antropologisks": "antropologisk",
    "antropologiskt": "antropologisk",
    "antropologiskts": "antropologisk",
    "antropologs": "antropolog",
    "antropomorfa": "antropomorf",
    "antropomorfare": "antropomorf",
    "antropomorfares": "antropomorf",
    "antropomorfas": "antropomorf",
    "antropomorfast": "antropomorf",
    "antropomorfaste": "antropomorf",
    "antropomorfastes": "antropomorf",
    "antropomorfasts": "antropomorf",
    "antropomorfe": "antropomorf",
    "antropomorfes": "antropomorf",
    "antropomorfismen": "antropomorfism",
    "antropomorfismens": "antropomorfism",
    "antropomorfismer": "antropomorfism",
    "antropomorfismerna": "antropomorfism",
    "antropomorfismernas": "antropomorfism",
    "antropomorfismers": "antropomorfism",
    "antropomorfisms": "antropomorfism",
    "antropomorfistiska": "antropomorfistisk",
    "antropomorfistiskas": "antropomorfistisk",
    "antropomorfistiske": "antropomorfistisk",
    "antropomorfistiskes": "antropomorfistisk",
    "antropomorfistisks": "antropomorfistisk",
    "antropomorfistiskt": "antropomorfistisk",
    "antropomorfistiskts": "antropomorfistisk",
    "antropomorfs": "antropomorf",
    "antropomorft": "antropomorf",
    "antropomorfts": "antropomorf",
    "antroposofen": "antroposof",
    "antroposofens": "antroposof",
    "antroposofer": "antroposof",
    "antroposoferna": "antroposof",
    "antroposofernas": "antroposof",
    "antroposofers": "antroposof",
    "antroposofien": "antroposofi",
    "antroposofiens": "antroposofi",
    "antroposofin": "antroposofi",
    "antroposofins": "antroposofi",
    "antroposofis": "antroposofi",
    "antroposofiska": "antroposofisk",
    "antroposofiskare": "antroposofisk",
    "antroposofiskares": "antroposofisk",
    "antroposofiskas": "antroposofisk",
    "antroposofiskast": "antroposofisk",
    "antroposofiskaste": "antroposofisk",
    "antroposofiskastes": "antroposofisk",
    "antroposofiskasts": "antroposofisk",
    "antroposofiske": "antroposofisk",
    "antroposofiskes": "antroposofisk",
    "antroposofisks": "antroposofisk",
    "antroposofiskt": "antroposofisk",
    "antroposofiskts": "antroposofisk",
    "antroposofs": "antroposof",
    "anträd": "anträda",
    "anträdande": "anträda",
    "anträdanden": "anträdande",
    "anträdandena": "anträdande",
    "anträdandenas": "anträdande",
    "anträdandens": "anträdande",
    "anträdandes": "anträdande",
    "anträdandet": "anträdande",
    "anträdandets": "anträdande",
    "anträdas": "anträda",
    "anträdd": "anträda",
    "anträdda": "anträda",
    "anträddas": "anträda",
    "anträdde": "anträda",
    "anträddes": "anträda",
    "anträdds": "anträda",
    "anträder": "anträda",
    "anträdes": "anträda",
    "anträds": "anträda",
    "anträff": "anträffa",
    "anträffad": "anträffa",
    "anträffade": "anträffa",
    "anträffades": "anträffa",
    "anträffads": "anträffa",
    "anträffande": "anträffa",
    "anträffanden": "anträffande",
    "anträffandena": "anträffande",
    "anträffandenas": "anträffande",
    "anträffandens": "anträffande",
    "anträffandes": "anträffande",
    "anträffandet": "anträffande",
    "anträffandets": "anträffande",
    "anträffar": "anträffa",
    "anträffas": "anträffa",
    "anträffat": "anträffa",
    "anträffats": "anträffa",
    "anträffbara": "anträffbar",
    "anträffbarare": "anträffbar",
    "anträffbarares": "anträffbar",
    "anträffbaras": "anträffbar",
    "anträffbarast": "anträffbar",
    "anträffbaraste": "anträffbar",
    "anträffbarastes": "anträffbar",
    "anträffbarasts": "anträffbar",
    "anträffbare": "anträffbar",
    "anträffbares": "anträffbar",
    "anträffbarheten": "anträffbarhet",
    "anträffbarhetens": "anträffbarhet",
    "anträffbarhets": "anträffbarhet",
    "anträffbars": "anträffbar",
    "anträffbart": "anträffbar",
    "anträffbarts": "anträffbar",
    "anträtt": "anträda",
    "anträtts": "anträda",
    "antvard": "antvarda",
    "antvardad": "antvarda",
    "antvardade": "antvarda",
    "antvardades": "antvarda",
    "antvardads": "antvarda",
    "antvardande": "antvarda",
    "antvardanden": "antvardande",
    "antvardandena": "antvardande",
    "antvardandenas": "antvardande",
    "antvardandens": "antvardande",
    "antvardandes": "antvardande",
    "antvardandet": "antvardande",
    "antvardandets": "antvardande",
    "antvardar": "antvarda",
    "antvardas": "antvarda",
    "antvardat": "antvarda",
    "antvardats": "antvarda",
    "antyd": "antyda",
    "antydande": "antyda",
    "antydanden": "antydande",
    "antydandena": "antydande",
    "antydandenas": "antydande",
    "antydandens": "antydande",
    "antydandes": "antydande",
    "antydandet": "antydande",
    "antydandets": "antydande",
    "antydans": "antydan",
    "antydas": "antyda",
    "antydd": "antyda",
    "antydda": "antyda",
    "antyddas": "antyda",
    "antydde": "antyda",
    "antyddes": "antyda",
    "antydds": "antyda",
    "antyder": "antyda",
    "antydes": "antyda",
    "antydningar": "antydning",
    "antydningarna": "antydning",
    "antydningarnas": "antydning",
    "antydningars": "antydning",
    "antydningen": "antydning",
    "antydningens": "antydning",
    "antydnings": "antydning",
    "antyds": "antyda",
    "antytt": "antyda",
    "antytts": "antyda",
    "antänd": "antända",
    "antändande": "antända",
    "antändanden": "antändande",
    "antändandena": "antändande",
    "antändandenas": "antändande",
    "antändandens": "antändande",
    "antändandes": "antändande",
    "antändandet": "antändande",
    "antändandets": "antändande",
    "antändas": "antända",
    "antände": "antända",
    "antänder": "antända",
    "antändes": "antända",
    "antändningar": "antändning",
    "antändningarna": "antändning",
    "antändningarnas": "antändning",
    "antändningars": "antändning",
    "antändningen": "antändning",
    "antändningens": "antändning",
    "antändnings": "antändning",
    "antänds": "antända",
    "antänt": "antända",
    "antänts": "antända",
    "antåg": "antåga",
    "antågad": "antåga",
    "antågade": "antåga",
    "antågades": "antåga",
    "antågads": "antåga",
    "antågande": "antåga",
    "antåganden": "antågande",
    "antågandena": "antågande",
    "antågandenas": "antågande",
    "antågandens": "antågande",
    "antågandes": "antågande",
    "antågandet": "antågande",
    "antågandets": "antågande",
    "antågar": "antåga",
    "antågas": "antåga",
    "antågat": "antåga",
    "antågats": "antåga",
    "antågen": "antåg",
    "antågens": "antåg",
    "antåget": "antåg",
    "antågets": "antåg",
    "antågs": "antåg",
    "anusen": "anus",
    "anusens": "anus",
    "anvisad": "anvisa",
    "anvisade": "anvisa",
    "anvisades": "anvisa",
    "anvisads": "anvisa",
    "anvisande": "anvisa",
    "anvisanden": "anvisande",
    "anvisandena": "anvisande",
    "anvisandenas": "anvisande",
    "anvisandens": "anvisande",
    "anvisandes": "anvisande",
    "anvisandet": "anvisande",
    "anvisandets": "anvisande",
    "anvisar": "anvisa",
    "anvisas": "anvisa",
    "anvisat": "anvisa",
    "anvisats": "anvisa",
    "anvisningar": "anvisning",
    "anvisningarna": "anvisning",
    "anvisningarnas": "anvisning",
    "anvisningars": "anvisning",
    "anvisningen": "anvisning",
    "anvisningens": "anvisning",
    "anvisnings": "anvisning",
    "anvisningskommunen": "anvisningskommun",
    "anvisningskommunens": "anvisningskommun",
    "anvisningskommuner": "anvisningskommun",
    "anvisningskommunerna": "anvisningskommun",
    "anvisningskommunernas": "anvisningskommun",
    "anvisningskommuners": "anvisningskommun",
    "anvisningskommuns": "anvisningskommun",
    "anvisningsläkar": "anvisningsläkare",
    "anvisningsläkaren": "anvisningsläkare",
    "anvisningsläkarens": "anvisningsläkare",
    "anvisningsläkares": "anvisningsläkare",
    "anvisningsläkarna": "anvisningsläkare",
    "anvisningsläkarnas": "anvisningsläkare",
    "använd": "använda",
    "användande": "använda",
    "användanden": "användande",
    "användandena": "användande",
    "användandenas": "användande",
    "användandens": "användande",
    "användandes": "användande",
    "användandet": "användande",
    "användandets": "användande",
    "användar": "användare",
    "användaren": "användare",
    "användarens": "användare",
    "användares": "användare",
    "användarna": "användare",
    "användarnas": "användare",
    "användarvänliga": "användarvänlig",
    "användarvänligare": "användarvänlig",
    "användarvänligares": "användarvänlig",
    "användarvänligas": "användarvänlig",
    "användarvänligast": "användarvänlig",
    "användarvänligaste": "användarvänlig",
    "användarvänligastes": "användarvänlig",
    "användarvänligasts": "användarvänlig",
    "användarvänlige": "användarvänlig",
    "användarvänliges": "användarvänlig",
    "användarvänligheten": "användarvänlighet",
    "användarvänlighetens": "användarvänlighet",
    "användarvänlighets": "användarvänlighet",
    "användarvänligs": "användarvänlig",
    "användarvänligt": "användarvänlig",
    "användarvänligts": "användarvänlig",
    "användas": "använda",
    "användbara": "användbar",
    "användbarare": "användbar",
    "användbarares": "användbar",
    "användbaras": "användbar",
    "användbarast": "användbar",
    "användbaraste": "användbar",
    "användbarastes": "användbar",
    "användbarasts": "användbar",
    "användbare": "användbar",
    "användbares": "användbar",
    "användbarheten": "användbarhet",
    "användbarhetens": "användbarhet",
    "användbarheter": "användbarhet",
    "användbarheterna": "användbarhet",
    "användbarheternas": "användbarhet",
    "användbarheters": "användbarhet",
    "användbarhets": "användbarhet",
    "användbars": "användbar",
    "användbart": "användbar",
    "användbarts": "användbar",
    "använde": "använda",
    "använder": "använda",
    "användes": "använda",
    "användningar": "användning",
    "användningarna": "användning",
    "användningarnas": "användning",
    "användningars": "användning",
    "användningen": "användning",
    "användningens": "användning",
    "användnings": "användning",
    "användningslösningar": "användningslösning",
    "användningslösningarna": "användningslösning",
    "användningslösningarnas": "användningslösning",
    "användningslösningars": "användningslösning",
    "användningslösningen": "användningslösning",
    "användningslösningens": "användningslösning",
    "användningslösnings": "användningslösning",
    "användningsmöjligheten": "användningsmöjlighet",
    "användningsmöjlighetens": "användningsmöjlighet",
    "användningsmöjligheter": "användningsmöjlighet",
    "användningsmöjligheterna": "användningsmöjlighet",
    "användningsmöjligheternas": "användningsmöjlighet",
    "användningsmöjligheters": "användningsmöjlighet",
    "användningsmöjlighets": "användningsmöjlighet",
    "användningsområden": "användningsområde",
    "användningsområdena": "användningsområde",
    "användningsområdenas": "användningsområde",
    "användningsområdens": "användningsområde",
    "användningsområdes": "användningsområde",
    "användningsområdet": "användningsområde",
    "användningsområdets": "användningsområde",
    "används": "använda",
    "använt": "använda",
    "använts": "använda",
    "aoristen": "aorist",
    "aoristens": "aorist",
    "aorister": "aorist",
    "aoristerna": "aorist",
    "aoristernas": "aorist",
    "aoristers": "aorist",
    "aorists": "aorist",
    "aortabåg": "aortabåge",
    "aortabågar": "aortabåge",
    "aortabågarna": "aortabåge",
    "aortabågarnas": "aortabåge",
    "aortabågars": "aortabåge",
    "aortabågen": "aortabåge",
    "aortabågens": "aortabåge",
    "aortabåges": "aortabåge",
    "aortabågs": "aortabåge",
    "aortaklaffar": "aortaklaff",
    "aortaklaffarna": "aortaklaff",
    "aortaklaffarnas": "aortaklaff",
    "aortaklaffars": "aortaklaff",
    "aortaklaffen": "aortaklaff",
    "aortaklaffens": "aortaklaff",
    "aortaklaffs": "aortaklaff",
    "aortan": "aorta",
    "aortans": "aorta",
    "aortas": "aorta",
    "ap": "apa",
    "apachen": "apache",
    "apachens": "apache",
    "apacher": "apache",
    "apacherna": "apache",
    "apachernas": "apache",
    "apachers": "apache",
    "apaches": "apache",
    "apan": "apa",
    "apanagen": "apanage",
    "apanagens": "apanage",
    "apanages": "apanage",
    "apanaget": "apanage",
    "apanagets": "apanage",
    "apans": "apa",
    "aparta": "apart",
    "apartare": "apart",
    "apartares": "apart",
    "apartas": "apart",
    "apartast": "apart",
    "apartaste": "apart",
    "apartastes": "apart",
    "apartasts": "apart",
    "aparte": "apart",
    "aparten": "apart",
    "apartens": "apart",
    "aparter": "apart",
    "aparterna": "apart",
    "aparternas": "apart",
    "aparters": "apart",
    "apartes": "apart",
    "apartheiden": "apartheid",
    "apartheidens": "apartheid",
    "apartheidregimen": "apartheidregim",
    "apartheidregimens": "apartheidregim",
    "apartheidregimer": "apartheidregim",
    "apartheidregimerna": "apartheidregim",
    "apartheidregimernas": "apartheidregim",
    "apartheidregimers": "apartheidregim",
    "apartheidregims": "apartheidregim",
    "apartheids": "apartheid",
    "aparts": "apart",
    "apas": "apa",
    "apatien": "apati",
    "apatiens": "apati",
    "apatier": "apati",
    "apatierna": "apati",
    "apatiernas": "apati",
    "apatiers": "apati",
    "apatin": "apati",
    "apatins": "apati",
    "apatis": "apati",
    "apatiska": "apatisk",
    "apatiskare": "apatisk",
    "apatiskares": "apatisk",
    "apatiskas": "apatisk",
    "apatiskast": "apatisk",
    "apatiskaste": "apatisk",
    "apatiskastes": "apatisk",
    "apatiskasts": "apatisk",
    "apatiske": "apatisk",
    "apatiskes": "apatisk",
    "apatisks": "apatisk",
    "apatiskt": "apatisk",
    "apatiskts": "apatisk",
    "apatiten": "apatit",
    "apatitens": "apatit",
    "apatits": "apatit",
    "apbrödsträden": "apbrödsträd",
    "apbrödsträdens": "apbrödsträd",
    "apbrödsträdet": "apbrödsträd",
    "apbrödsträdets": "apbrödsträd",
    "apbrödsträds": "apbrödsträd",
    "ape": "apa",
    "apekatten": "apekatt",
    "apekattens": "apekatt",
    "apekatter": "apekatt",
    "apekatterna": "apekatt",
    "apekatternas": "apekatt",
    "apekatters": "apekatt",
    "apekatts": "apekatt",
    "apelgråa": "apelgrå",
    "apelgråare": "apelgrå",
    "apelgråares": "apelgrå",
    "apelgråas": "apelgrå",
    "apelgråast": "apelgrå",
    "apelgråaste": "apelgrå",
    "apelgråastes": "apelgrå",
    "apelgråasts": "apelgrå",
    "apelgråe": "apelgrå",
    "apelgråes": "apelgrå",
    "apelgrås": "apelgrå",
    "apelgrått": "apelgrå",
    "apelgråtts": "apelgrå",
    "apelkastade": "apelkastad",
    "apelkastades": "apelkastad",
    "apelkastads": "apelkastad",
    "apelkastat": "apelkastad",
    "apelkastats": "apelkastad",
    "apeln": "apel",
    "apelns": "apel",
    "apels": "apel",
    "apelsinen": "apelsin",
    "apelsinens": "apelsin",
    "apelsiner": "apelsin",
    "apelsinerna": "apelsin",
    "apelsinernas": "apelsin",
    "apelsiners": "apelsin",
    "apelsinmoussen": "apelsinmousse",
    "apelsinmoussens": "apelsinmousse",
    "apelsinmousser": "apelsinmousse",
    "apelsinmousserna": "apelsinmousse",
    "apelsinmoussernas": "apelsinmousse",
    "apelsinmoussers": "apelsinmousse",
    "apelsinmousses": "apelsinmousse",
    "apelsinmoussetårt": "apelsinmoussetårta",
    "apelsinmoussetårtan": "apelsinmoussetårta",
    "apelsinmoussetårtans": "apelsinmoussetårta",
    "apelsinmoussetårtas": "apelsinmoussetårta",
    "apelsinmoussetårte": "apelsinmoussetårta",
    "apelsinmoussetårtor": "apelsinmoussetårta",
    "apelsinmoussetårtorna": "apelsinmoussetårta",
    "apelsinmoussetårtornas": "apelsinmoussetårta",
    "apelsinmoussetårtors": "apelsinmoussetårta",
    "apelsinmoussetårts": "apelsinmoussetårta",
    "apelsins": "apelsin",
    "apelsinskalen": "apelsinskal",
    "apelsinskalens": "apelsinskal",
    "apelsinskalet": "apelsinskal",
    "apelsinskalets": "apelsinskal",
    "apelsinskals": "apelsinskal",
    "aperitifen": "aperitif",
    "aperitifens": "aperitif",
    "aperitifer": "aperitif",
    "aperitiferna": "aperitif",
    "aperitifernas": "aperitif",
    "aperitifers": "aperitif",
    "aperitifs": "aperitif",
    "aperturen": "apertur",
    "aperturens": "apertur",
    "aperturer": "apertur",
    "aperturerna": "apertur",
    "aperturernas": "apertur",
    "aperturers": "apertur",
    "aperturs": "apertur",
    "apetidinen": "apetidin",
    "apetidinens": "apetidin",
    "apetidiner": "apetidin",
    "apetidinerna": "apetidin",
    "apetidinernas": "apetidin",
    "apetidiners": "apetidin",
    "apetidinet": "apetidin",
    "apetidinets": "apetidin",
    "apetidins": "apetidin",
    "apexet": "apex",
    "apexets": "apex",
    "aphelie": "aphelium",
    "aphelier": "aphelium",
    "aphelierna": "aphelium",
    "apheliernas": "aphelium",
    "apheliers": "aphelium",
    "apheliet": "aphelium",
    "apheliets": "aphelium",
    "apheliums": "aphelium",
    "aplar": "apel",
    "aplarna": "apel",
    "aplarnas": "apel",
    "aplars": "apel",
    "aplomben": "aplomb",
    "aplombens": "aplomb",
    "aplombs": "aplomb",
    "apmänniskan": "apmänniska",
    "apmänniskans": "apmänniska",
    "apmänniskas": "apmänniska",
    "apmännisko": "apmänniska",
    "apmänniskor": "apmänniska",
    "apmänniskorna": "apmänniska",
    "apmänniskornas": "apmänniska",
    "apmänniskors": "apmänniska",
    "apodiktiska": "apodiktisk",
    "apodiktiskare": "apodiktisk",
    "apodiktiskares": "apodiktisk",
    "apodiktiskas": "apodiktisk",
    "apodiktiskast": "apodiktisk",
    "apodiktiskaste": "apodiktisk",
    "apodiktiskastes": "apodiktisk",
    "apodiktiskasts": "apodiktisk",
    "apodiktiske": "apodiktisk",
    "apodiktiskes": "apodiktisk",
    "apodiktisks": "apodiktisk",
    "apodiktiskt": "apodiktisk",
    "apodiktiskts": "apodiktisk",
    "apokalypsen": "apokalyps",
    "apokalypsens": "apokalyps",
    "apokalypser": "apokalyps",
    "apokalypserna": "apokalyps",
    "apokalypsernas": "apokalyps",
    "apokalypsers": "apokalyps",
    "apokalyptiska": "apokalyptisk",
    "apokalyptiskare": "apokalyptisk",
    "apokalyptiskares": "apokalyptisk",
    "apokalyptiskas": "apokalyptisk",
    "apokalyptiskast": "apokalyptisk",
    "apokalyptiskaste": "apokalyptisk",
    "apokalyptiskastes": "apokalyptisk",
    "apokalyptiskasts": "apokalyptisk",
    "apokalyptiske": "apokalyptisk",
    "apokalyptiskes": "apokalyptisk",
    "apokalyptisks": "apokalyptisk",
    "apokalyptiskt": "apokalyptisk",
    "apokalyptiskts": "apokalyptisk",
    "apokopen": "apokope",
    "apokopens": "apokope",
    "apokopes": "apokope",
    "apokryfernas": "apokryferna",
    "apokryfiska": "apokryfisk",
    "apokryfiskare": "apokryfisk",
    "apokryfiskares": "apokryfisk",
    "apokryfiskas": "apokryfisk",
    "apokryfiskast": "apokryfisk",
    "apokryfiskaste": "apokryfisk",
    "apokryfiskastes": "apokryfisk",
    "apokryfiskasts": "apokryfisk",
    "apokryfiske": "apokryfisk",
    "apokryfiskes": "apokryfisk",
    "apokryfisks": "apokryfisk",
    "apokryfiskt": "apokryfisk",
    "apokryfiskts": "apokryfisk",
    "apolitiska": "apolitisk",
    "apolitiskas": "apolitisk",
    "apolitiske": "apolitisk",
    "apolitiskes": "apolitisk",
    "apolitisks": "apolitisk",
    "apolitiskt": "apolitisk",
    "apolitiskts": "apolitisk",
    "apolliniska": "apollinisk",
    "apolliniskare": "apollinisk",
    "apolliniskares": "apollinisk",
    "apolliniskas": "apollinisk",
    "apolliniskast": "apollinisk",
    "apolliniskaste": "apollinisk",
    "apolliniskastes": "apollinisk",
    "apolliniskasts": "apollinisk",
    "apolliniske": "apollinisk",
    "apolliniskes": "apollinisk",
    "apollinisks": "apollinisk",
    "apolliniskt": "apollinisk",
    "apolliniskts": "apollinisk",
    "apollinska": "apollinsk",
    "apollinskare": "apollinsk",
    "apollinskares": "apollinsk",
    "apollinskas": "apollinsk",
    "apollinskast": "apollinsk",
    "apollinskaste": "apollinsk",
    "apollinskastes": "apollinsk",
    "apollinskasts": "apollinsk",
    "apollinske": "apollinsk",
    "apollinskes": "apollinsk",
    "apollinsks": "apollinsk",
    "apollinskt": "apollinsk",
    "apollinskts": "apollinsk",
    "apollofjärilar": "apollofjäril",
    "apollofjärilarna": "apollofjäril",
    "apollofjärilarnas": "apollofjäril",
    "apollofjärilars": "apollofjäril",
    "apollofjärilen": "apollofjäril",
    "apollofjärilens": "apollofjäril",
    "apollofjäriln": "apollofjäril",
    "apollofjärilns": "apollofjäril",
    "apollofjärils": "apollofjäril",
    "apologeten": "apologet",
    "apologetens": "apologet",
    "apologeter": "apologet",
    "apologeterna": "apologet",
    "apologeternas": "apologet",
    "apologeters": "apologet",
    "apologetiken": "apologetik",
    "apologetikens": "apologetik",
    "apologetiks": "apologetik",
    "apologetiska": "apologetisk",
    "apologetiskare": "apologetisk",
    "apologetiskares": "apologetisk",
    "apologetiskas": "apologetisk",
    "apologetiskast": "apologetisk",
    "apologetiskaste": "apologetisk",
    "apologetiskastes": "apologetisk",
    "apologetiskasts": "apologetisk",
    "apologetiske": "apologetisk",
    "apologetiskes": "apologetisk",
    "apologetisks": "apologetisk",
    "apologetiskt": "apologetisk",
    "apologetiskts": "apologetisk",
    "apologets": "apologet",
    "apologien": "apologi",
    "apologiens": "apologi",
    "apologier": "apologi",
    "apologierna": "apologi",
    "apologiernas": "apologi",
    "apologiers": "apologi",
    "apologin": "apologi",
    "apologins": "apologi",
    "apologis": "apologi",
    "apoplektiska": "apoplektisk",
    "apoplektiskare": "apoplektisk",
    "apoplektiskares": "apoplektisk",
    "apoplektiskas": "apoplektisk",
    "apoplektiskast": "apoplektisk",
    "apoplektiskaste": "apoplektisk",
    "apoplektiskastes": "apoplektisk",
    "apoplektiskasts": "apoplektisk",
    "apoplektiske": "apoplektisk",
    "apoplektiskes": "apoplektisk",
    "apoplektisks": "apoplektisk",
    "apoplektiskt": "apoplektisk",
    "apoplektiskts": "apoplektisk",
    "apoplexien": "apoplexi",
    "apoplexiens": "apoplexi",
    "apoplexier": "apoplexi",
    "apoplexierna": "apoplexi",
    "apoplexiernas": "apoplexi",
    "apoplexiers": "apoplexi",
    "apoplexin": "apoplexi",
    "apoplexins": "apoplexi",
    "apoplexis": "apoplexi",
    "apor": "apa",
    "aporna": "apa",
    "apornas": "apa",
    "apors": "apa",
    "aposteln": "apostel",
    "apostelns": "apostel",
    "apostels": "apostel",
    "aposterioriska": "aposteriorisk",
    "aposterioriskare": "aposteriorisk",
    "aposterioriskares": "aposteriorisk",
    "aposterioriskas": "aposteriorisk",
    "aposterioriskast": "aposteriorisk",
    "aposterioriskaste": "aposteriorisk",
    "aposterioriskastes": "aposteriorisk",
    "aposterioriskasts": "aposteriorisk",
    "aposterioriske": "aposteriorisk",
    "aposterioriskes": "aposteriorisk",
    "aposteriorisks": "aposteriorisk",
    "aposterioriskt": "aposteriorisk",
    "aposterioriskts": "aposteriorisk",
    "apostlahäst": "apostlahästar",
    "apostlahästarna": "apostlahästar",
    "apostlahästarnas": "apostlahästar",
    "apostlahästars": "apostlahästar",
    "apostlar": "apostel",
    "apostlarna": "apostel",
    "apostlarnas": "apostel",
    "apostlars": "apostel",
    "apostoliska": "apostolisk",
    "apostoliskare": "apostolisk",
    "apostoliskares": "apostolisk",
    "apostoliskas": "apostolisk",
    "apostoliskast": "apostolisk",
    "apostoliskaste": "apostolisk",
    "apostoliskastes": "apostolisk",
    "apostoliskasts": "apostolisk",
    "apostoliske": "apostolisk",
    "apostoliskes": "apostolisk",
    "apostolisks": "apostolisk",
    "apostoliskt": "apostolisk",
    "apostoliskts": "apostolisk",
    "apostrofen": "apostrof",
    "apostrofens": "apostrof",
    "apostrofer": "apostrof",
    "apostroferad": "apostrofera",
    "apostroferade": "apostrofera",
    "apostroferades": "apostrofera",
    "apostroferads": "apostrofera",
    "apostroferande": "apostrofera",
    "apostroferanden": "apostroferande",
    "apostroferandena": "apostroferande",
    "apostroferandenas": "apostroferande",
    "apostroferandens": "apostroferande",
    "apostroferandes": "apostroferande",
    "apostroferandet": "apostroferande",
    "apostroferandets": "apostroferande",
    "apostroferar": "apostrofera",
    "apostroferas": "apostrofera",
    "apostroferat": "apostrofera",
    "apostroferats": "apostrofera",
    "apostroferbara": "apostroferbar",
    "apostroferbarare": "apostroferbar",
    "apostroferbarares": "apostroferbar",
    "apostroferbaras": "apostroferbar",
    "apostroferbarast": "apostroferbar",
    "apostroferbaraste": "apostroferbar",
    "apostroferbarastes": "apostroferbar",
    "apostroferbarasts": "apostroferbar",
    "apostroferbare": "apostroferbar",
    "apostroferbares": "apostroferbar",
    "apostroferbarheten": "apostroferbarhet",
    "apostroferbarhetens": "apostroferbarhet",
    "apostroferbarhets": "apostroferbarhet",
    "apostroferbars": "apostroferbar",
    "apostroferbart": "apostroferbar",
    "apostroferbarts": "apostroferbar",
    "apostroferingar": "apostrofering",
    "apostroferingarna": "apostrofering",
    "apostroferingarnas": "apostrofering",
    "apostroferingars": "apostrofering",
    "apostroferingen": "apostrofering",
    "apostroferingens": "apostrofering",
    "apostroferings": "apostrofering",
    "apostroferna": "apostrof",
    "apostrofernas": "apostrof",
    "apostrofers": "apostrof",
    "apostrofs": "apostrof",
    "apotekar": "apotekare",
    "apotekaren": "apotekare",
    "apotekarens": "apotekare",
    "apotekares": "apotekare",
    "apotekarna": "apotekare",
    "apotekarnas": "apotekare",
    "apoteken": "apotek",
    "apotekens": "apotek",
    "apoteket": "apotek",
    "apotekets": "apotek",
    "apoteks": "apotek",
    "apoteksköer": "apotekskö",
    "apoteksköerna": "apotekskö",
    "apoteksköernas": "apotekskö",
    "apoteksköers": "apotekskö",
    "apotekskön": "apotekskö",
    "apoteksköns": "apotekskö",
    "apotekskös": "apotekskö",
    "apoteksväxten": "apoteksväxt",
    "apoteksväxtens": "apoteksväxt",
    "apoteksväxter": "apoteksväxt",
    "apoteksväxterna": "apoteksväxt",
    "apoteksväxternas": "apoteksväxt",
    "apoteksväxters": "apoteksväxt",
    "apoteksväxts": "apoteksväxt",
    "apoteosen": "apoteos",
    "apoteosens": "apoteos",
    "apoteoser": "apoteos",
    "apoteoserna": "apoteos",
    "apoteosernas": "apoteos",
    "apoteosers": "apoteos",
    "appar": "app",
    "apparansen": "apparans",
    "apparansens": "apparans",
    "apparanser": "apparans",
    "apparanserna": "apparans",
    "apparansernas": "apparans",
    "apparansers": "apparans",
    "apparaten": "apparat",
    "apparatens": "apparat",
    "apparater": "apparat",
    "apparaterna": "apparat",
    "apparaternas": "apparat",
    "apparaters": "apparat",
    "apparats": "apparat",
    "apparaturen": "apparatur",
    "apparaturens": "apparatur",
    "apparaturer": "apparatur",
    "apparaturerna": "apparatur",
    "apparaturernas": "apparatur",
    "apparaturers": "apparatur",
    "apparaturs": "apparatur",
    "apparitionen": "apparition",
    "apparitionens": "apparition",
    "apparitioner": "apparition",
    "apparitionerna": "apparition",
    "apparitionernas": "apparition",
    "apparitioners": "apparition",
    "apparitions": "apparition",
    "apparna": "app",
    "apparnas": "app",
    "appars": "app",
    "appellanten": "appellant",
    "appellantens": "appellant",
    "appellanter": "appellant",
    "appellanterna": "appellant",
    "appellanternas": "appellant",
    "appellanters": "appellant",
    "appellants": "appellant",
    "appellationsdomstolar": "appellationsdomstol",
    "appellationsdomstolarna": "appellationsdomstol",
    "appellationsdomstolarnas": "appellationsdomstol",
    "appellationsdomstolars": "appellationsdomstol",
    "appellationsdomstolen": "appellationsdomstol",
    "appellationsdomstolens": "appellationsdomstol",
    "appellationsdomstols": "appellationsdomstol",
    "appellativen": "appellativ",
    "appellativens": "appellativ",
    "appellativer": "appellativ",
    "appellativerna": "appellativ",
    "appellativernas": "appellativ",
    "appellativers": "appellativ",
    "appellativet": "appellativ",
    "appellativets": "appellativ",
    "appellativs": "appellativ",
    "appellen": "appell",
    "appellens": "appell",
    "appeller": "appell",
    "appellerad": "appellera",
    "appellerade": "appellera",
    "appellerades": "appellera",
    "appellerads": "appellera",
    "appellerande": "appellera",
    "appelleranden": "appellerande",
    "appellerandena": "appellerande",
    "appellerandenas": "appellerande",
    "appellerandens": "appellerande",
    "appellerandes": "appellerande",
    "appellerandet": "appellerande",
    "appellerandets": "appellerande",
    "appellerar": "appellera",
    "appelleras": "appellera",
    "appellerat": "appellera",
    "appellerats": "appellera",
    "appellerbara": "appellerbar",
    "appellerbarare": "appellerbar",
    "appellerbarares": "appellerbar",
    "appellerbaras": "appellerbar",
    "appellerbarast": "appellerbar",
    "appellerbaraste": "appellerbar",
    "appellerbarastes": "appellerbar",
    "appellerbarasts": "appellerbar",
    "appellerbare": "appellerbar",
    "appellerbares": "appellerbar",
    "appellerbarheten": "appellerbarhet",
    "appellerbarhetens": "appellerbarhet",
    "appellerbarhets": "appellerbarhet",
    "appellerbars": "appellerbar",
    "appellerbart": "appellerbar",
    "appellerbarts": "appellerbar",
    "appelleringar": "appellering",
    "appelleringarna": "appellering",
    "appelleringarnas": "appellering",
    "appelleringars": "appellering",
    "appelleringen": "appellering",
    "appelleringens": "appellering",
    "appellerings": "appellering",
    "appellerna": "appell",
    "appellernas": "appell",
    "appellers": "appell",
    "appells": "appell",
    "appen": "app",
    "appendiciten": "appendicit",
    "appendicitens": "appendicit",
    "appendiciter": "appendicit",
    "appendiciterna": "appendicit",
    "appendiciternas": "appendicit",
    "appendiciters": "appendicit",
    "appendicits": "appendicit",
    "appendixen": "appendix",
    "appendixens": "appendix",
    "appendixet": "appendix",
    "appendixets": "appendix",
    "appens": "app",
    "apperceptionen": "apperception",
    "apperceptionens": "apperception",
    "apperceptioner": "apperception",
    "apperceptionerna": "apperception",
    "apperceptionernas": "apperception",
    "apperceptioners": "apperception",
    "apperceptions": "apperception",
    "applicerad": "applicera",
    "applicerade": "applicera",
    "applicerades": "applicera",
    "applicerads": "applicera",
    "applicerande": "applicera",
    "appliceranden": "applicerande",
    "applicerandena": "applicerande",
    "applicerandenas": "applicerande",
    "applicerandens": "applicerande",
    "applicerandes": "applicerande",
    "applicerandet": "applicerande",
    "applicerandets": "applicerande",
    "applicerar": "applicera",
    "appliceras": "applicera",
    "applicerat": "applicera",
    "applicerats": "applicera",
    "applicerbara": "applicerbar",
    "applicerbarare": "applicerbar",
    "applicerbarares": "applicerbar",
    "applicerbaras": "applicerbar",
    "applicerbarast": "applicerbar",
    "applicerbaraste": "applicerbar",
    "applicerbarastes": "applicerbar",
    "applicerbarasts": "applicerbar",
    "applicerbare": "applicerbar",
    "applicerbares": "applicerbar",
    "applicerbarheten": "applicerbarhet",
    "applicerbarhetens": "applicerbarhet",
    "applicerbarhets": "applicerbarhet",
    "applicerbars": "applicerbar",
    "applicerbart": "applicerbar",
    "applicerbarts": "applicerbar",
    "appliceringar": "applicering",
    "appliceringarna": "applicering",
    "appliceringarnas": "applicering",
    "appliceringars": "applicering",
    "appliceringen": "applicering",
    "appliceringens": "applicering",
    "applicerings": "applicering",
    "applikationen": "applikation",
    "applikationens": "applikation",
    "applikationer": "applikation",
    "applikationerna": "applikation",
    "applikationernas": "applikation",
    "applikationers": "applikation",
    "applikations": "applikation",
    "applikatoriska": "applikatorisk",
    "applikatoriskare": "applikatorisk",
    "applikatoriskares": "applikatorisk",
    "applikatoriskas": "applikatorisk",
    "applikatoriskast": "applikatorisk",
    "applikatoriskaste": "applikatorisk",
    "applikatoriskastes": "applikatorisk",
    "applikatoriskasts": "applikatorisk",
    "applikatoriske": "applikatorisk",
    "applikatoriskes": "applikatorisk",
    "applikatorisks": "applikatorisk",
    "applikatoriskt": "applikatorisk",
    "applikatoriskts": "applikatorisk",
    "applikaturen": "applikatur",
    "applikaturens": "applikatur",
    "applikaturer": "applikatur",
    "applikaturerna": "applikatur",
    "applikaturernas": "applikatur",
    "applikaturers": "applikatur",
    "applikaturs": "applikatur",
    "applåden": "applåd",
    "applådens": "applåd",
    "applåder": "applåd",
    "applåderad": "applådera",
    "applåderade": "applådera",
    "applåderades": "applådera",
    "applåderads": "applådera",
    "applåderande": "applådera",
    "applåderanden": "applåderande",
    "applåderandena": "applåderande",
    "applåderandenas": "applåderande",
    "applåderandens": "applåderande",
    "applåderandes": "applåderande",
    "applåderandet": "applåderande",
    "applåderandets": "applåderande",
    "applåderar": "applådera",
    "applåderas": "applådera",
    "applåderat": "applådera",
    "applåderats": "applådera",
    "applåderbara": "applåderbar",
    "applåderbarare": "applåderbar",
    "applåderbarares": "applåderbar",
    "applåderbaras": "applåderbar",
    "applåderbarast": "applåderbar",
    "applåderbaraste": "applåderbar",
    "applåderbarastes": "applåderbar",
    "applåderbarasts": "applåderbar",
    "applåderbare": "applåderbar",
    "applåderbares": "applåderbar",
    "applåderbarheten": "applåderbarhet",
    "applåderbarhetens": "applåderbarhet",
    "applåderbarhets": "applåderbarhet",
    "applåderbars": "applåderbar",
    "applåderbart": "applåderbar",
    "applåderbarts": "applåderbar",
    "applåderingar": "applådering",
    "applåderingarna": "applådering",
    "applåderingarnas": "applådering",
    "applåderingars": "applådering",
    "applåderingen": "applådering",
    "applåderingens": "applådering",
    "applåderings": "applådering",
    "applåderna": "applåd",
    "applådernas": "applåd",
    "applåders": "applåd",
    "applåds": "applåd",
    "apporten": "apport",
    "apportens": "apport",
    "apporter": "apport",
    "apporterad": "apportera",
    "apporterade": "apportera",
    "apporterades": "apportera",
    "apporterads": "apportera",
    "apporterande": "apportera",
    "apporteranden": "apporterande",
    "apporterandena": "apporterande",
    "apporterandenas": "apporterande",
    "apporterandens": "apporterande",
    "apporterandes": "apporterande",
    "apporterandet": "apporterande",
    "apporterandets": "apporterande",
    "apporterar": "apportera",
    "apporteras": "apportera",
    "apporterat": "apportera",
    "apporterats": "apportera",
    "apporterbara": "apporterbar",
    "apporterbarare": "apporterbar",
    "apporterbarares": "apporterbar",
    "apporterbaras": "apporterbar",
    "apporterbarast": "apporterbar",
    "apporterbaraste": "apporterbar",
    "apporterbarastes": "apporterbar",
    "apporterbarasts": "apporterbar",
    "apporterbare": "apporterbar",
    "apporterbares": "apporterbar",
    "apporterbarheten": "apporterbarhet",
    "apporterbarhetens": "apporterbarhet",
    "apporterbarhets": "apporterbarhet",
    "apporterbars": "apporterbar",
    "apporterbart": "apporterbar",
    "apporterbarts": "apporterbar",
    "apporteringar": "apportering",
    "apporteringarna": "apportering",
    "apporteringarnas": "apportering",
    "apporteringars": "apportering",
    "apporteringen": "apportering",
    "apporteringens": "apportering",
    "apporterings": "apportering",
    "apporterna": "apport",
    "apporternas": "apport",
    "apporters": "apport",
    "apports": "apport",
    "appositionen": "apposition",
    "appositionens": "apposition",
    "appositioner": "apposition",
    "appositionerna": "apposition",
    "appositionernas": "apposition",
    "appositioners": "apposition",
    "appositions": "apposition",
    "apprecierad": "appreciera",
    "apprecierade": "appreciera",
    "apprecierades": "appreciera",
    "apprecierads": "appreciera",
    "apprecierande": "appreciera",
    "apprecieranden": "apprecierande",
    "apprecierandena": "apprecierande",
    "apprecierandenas": "apprecierande",
    "apprecierandens": "apprecierande",
    "apprecierandes": "apprecierande",
    "apprecierandet": "apprecierande",
    "apprecierandets": "apprecierande",
    "apprecierar": "appreciera",
    "apprecieras": "appreciera",
    "apprecierat": "appreciera",
    "apprecierats": "appreciera",
    "apprecierbara": "apprecierbar",
    "apprecierbarare": "apprecierbar",
    "apprecierbarares": "apprecierbar",
    "apprecierbaras": "apprecierbar",
    "apprecierbarast": "apprecierbar",
    "apprecierbaraste": "apprecierbar",
    "apprecierbarastes": "apprecierbar",
    "apprecierbarasts": "apprecierbar",
    "apprecierbare": "apprecierbar",
    "apprecierbares": "apprecierbar",
    "apprecierbarheten": "apprecierbarhet",
    "apprecierbarhetens": "apprecierbarhet",
    "apprecierbarhets": "apprecierbarhet",
    "apprecierbars": "apprecierbar",
    "apprecierbart": "apprecierbar",
    "apprecierbarts": "apprecierbar",
    "apprecieringar": "appreciering",
    "apprecieringarna": "appreciering",
    "apprecieringarnas": "appreciering",
    "apprecieringars": "appreciering",
    "apprecieringen": "appreciering",
    "apprecieringens": "appreciering",
    "apprecierings": "appreciering",
    "appreterad": "appretera",
    "appreterade": "appretera",
    "appreterades": "appretera",
    "appreterads": "appretera",
    "appreterande": "appretera",
    "appreteranden": "appreterande",
    "appreterandena": "appreterande",
    "appreterandenas": "appreterande",
    "appreterandens": "appreterande",
    "appreterandes": "appreterande",
    "appreterandet": "appreterande",
    "appreterandets": "appreterande",
    "appreterar": "appretera",
    "appreteras": "appretera",
    "appreterat": "appretera",
    "appreterats": "appretera",
    "appreterbara": "appreterbar",
    "appreterbarare": "appreterbar",
    "appreterbarares": "appreterbar",
    "appreterbaras": "appreterbar",
    "appreterbarast": "appreterbar",
    "appreterbaraste": "appreterbar",
    "appreterbarastes": "appreterbar",
    "appreterbarasts": "appreterbar",
    "appreterbare": "appreterbar",
    "appreterbares": "appreterbar",
    "appreterbarheten": "appreterbarhet",
    "appreterbarhetens": "appreterbarhet",
    "appreterbarhets": "appreterbarhet",
    "appreterbars": "appreterbar",
    "appreterbart": "appreterbar",
    "appreterbarts": "appreterbar",
    "appreteringar": "appretering",
    "appreteringarna": "appretering",
    "appreteringarnas": "appretering",
    "appreteringars": "appretering",
    "appreteringen": "appretering",
    "appreteringens": "appretering",
    "appreterings": "appretering",
    "appreturen": "appretur",
    "appreturens": "appretur",
    "appreturer": "appretur",
    "appreturerna": "appretur",
    "appreturernas": "appretur",
    "appreturers": "appretur",
    "appreturs": "appretur",
    "appretyren": "appretyr",
    "appretyrens": "appretyr",
    "appretyrer": "appretyr",
    "appretyrerna": "appretyr",
    "appretyrernas": "appretyr",
    "appretyrers": "appretyr",
    "appretyrs": "appretyr",
    "approachen": "approach",
    "approachens": "approach",
    "approacher": "approach",
    "approacherna": "approach",
    "approachernas": "approach",
    "approachers": "approach",
    "approachs": "approach",
    "approbabels": "approbabel",
    "approbabelt": "approbabel",
    "approbabelts": "approbabel",
    "approbabla": "approbabel",
    "approbablare": "approbabel",
    "approbablares": "approbabel",
    "approbablas": "approbabel",
    "approbablast": "approbabel",
    "approbablaste": "approbabel",
    "approbablastes": "approbabel",
    "approbablasts": "approbabel",
    "approbable": "approbabel",
    "approbables": "approbabel",
    "approbatren": "approbatur",
    "approbatrens": "approbatur",
    "approbatret": "approbatur",
    "approbatrets": "approbatur",
    "approbaturen": "approbatur",
    "approbaturens": "approbatur",
    "approbaturet": "approbatur",
    "approbaturets": "approbatur",
    "approbaturs": "approbatur",
    "approcherad": "approchera",
    "approcherade": "approchera",
    "approcherades": "approchera",
    "approcherads": "approchera",
    "approcherande": "approchera",
    "approcheranden": "approcherande",
    "approcherandena": "approcherande",
    "approcherandenas": "approcherande",
    "approcherandens": "approcherande",
    "approcherandes": "approcherande",
    "approcherandet": "approcherande",
    "approcherandets": "approcherande",
    "approcherar": "approchera",
    "approcheras": "approchera",
    "approcherat": "approchera",
    "approcherats": "approchera",
    "approcherbara": "approcherbar",
    "approcherbarare": "approcherbar",
    "approcherbarares": "approcherbar",
    "approcherbaras": "approcherbar",
    "approcherbarast": "approcherbar",
    "approcherbaraste": "approcherbar",
    "approcherbarastes": "approcherbar",
    "approcherbarasts": "approcherbar",
    "approcherbare": "approcherbar",
    "approcherbares": "approcherbar",
    "approcherbarheten": "approcherbarhet",
    "approcherbarhetens": "approcherbarhet",
    "approcherbarhets": "approcherbarhet",
    "approcherbars": "approcherbar",
    "approcherbart": "approcherbar",
    "approcherbarts": "approcherbar",
    "approcheringar": "approchering",
    "approcheringarna": "approchering",
    "approcheringarnas": "approchering",
    "approcheringars": "approchering",
    "approcheringen": "approchering",
    "approcheringens": "approchering",
    "approcherings": "approchering",
    "approximationen": "approximation",
    "approximationens": "approximation",
    "approximationer": "approximation",
    "approximationerna": "approximation",
    "approximationernas": "approximation",
    "approximationers": "approximation",
    "approximations": "approximation",
    "approximationsteorien": "approximationsteori",
    "approximationsteoriens": "approximationsteori",
    "approximationsteorier": "approximationsteori",
    "approximationsteorierna": "approximationsteori",
    "approximationsteoriernas": "approximationsteori",
    "approximationsteoriers": "approximationsteori",
    "approximationsteorin": "approximationsteori",
    "approximationsteorins": "approximationsteori",
    "approximationsteoris": "approximationsteori",
    "approximativa": "approximativ",
    "approximativare": "approximativ",
    "approximativares": "approximativ",
    "approximativas": "approximativ",
    "approximativast": "approximativ",
    "approximativaste": "approximativ",
    "approximativastes": "approximativ",
    "approximativasts": "approximativ",
    "approximative": "approximativ",
    "approximatives": "approximativ",
    "approximativs": "approximativ",
    "approximativt": "approximativ",
    "approximativts": "approximativ",
    "approximerad": "approximera",
    "approximerade": "approximera",
    "approximerades": "approximera",
    "approximerads": "approximera",
    "approximerande": "approximera",
    "approximeranden": "approximerande",
    "approximerandena": "approximerande",
    "approximerandenas": "approximerande",
    "approximerandens": "approximerande",
    "approximerandes": "approximerande",
    "approximerandet": "approximerande",
    "approximerandets": "approximerande",
    "approximerar": "approximera",
    "approximeras": "approximera",
    "approximerat": "approximera",
    "approximerats": "approximera",
    "approximerbara": "approximerbar",
    "approximerbarare": "approximerbar",
    "approximerbarares": "approximerbar",
    "approximerbaras": "approximerbar",
    "approximerbarast": "approximerbar",
    "approximerbaraste": "approximerbar",
    "approximerbarastes": "approximerbar",
    "approximerbarasts": "approximerbar",
    "approximerbare": "approximerbar",
    "approximerbares": "approximerbar",
    "approximerbarheten": "approximerbarhet",
    "approximerbarhetens": "approximerbarhet",
    "approximerbarhets": "approximerbarhet",
    "approximerbars": "approximerbar",
    "approximerbart": "approximerbar",
    "approximerbarts": "approximerbar",
    "approximeringar": "approximering",
    "approximeringarna": "approximering",
    "approximeringarnas": "approximering",
    "approximeringars": "approximering",
    "approximeringen": "approximering",
    "approximeringens": "approximering",
    "approximerings": "approximering",
    "apps": "app",
    "apraka": "aprak",
    "aprakare": "aprak",
    "aprakares": "aprak",
    "aprakas": "aprak",
    "aprakast": "aprak",
    "aprakaste": "aprak",
    "aprakastes": "aprak",
    "aprakasts": "aprak",
    "aprake": "aprak",
    "aprakes": "aprak",
    "apraks": "aprak",
    "aprakt": "aprak",
    "aprakts": "aprak",
    "aprikosen": "aprikos",
    "aprikosens": "aprikos",
    "aprikoser": "aprikos",
    "aprikoserna": "aprikos",
    "aprikosernas": "aprikos",
    "aprikosers": "aprikos",
    "aprildagar": "aprildag",
    "aprildagarna": "aprildag",
    "aprildagarnas": "aprildag",
    "aprildagars": "aprildag",
    "aprildagen": "aprildag",
    "aprildagens": "aprildag",
    "aprildags": "aprildag",
    "aprildan": "aprildag",
    "aprildans": "aprildag",
    "aprildar": "aprildag",
    "aprildarna": "aprildag",
    "aprildarnas": "aprildag",
    "aprildars": "aprildag",
    "aprils": "april",
    "aprilskämten": "aprilskämt",
    "aprilskämtens": "aprilskämt",
    "aprilskämtet": "aprilskämt",
    "aprilskämtets": "aprilskämt",
    "aprilskämts": "aprilskämt",
    "aprilväderna": "aprilväder",
    "aprilvädernas": "aprilväder",
    "aprilväders": "aprilväder",
    "aprilvädren": "aprilväder",
    "aprilvädrens": "aprilväder",
    "aprilvädret": "aprilväder",
    "aprilvädrets": "aprilväder",
    "aprioriska": "apriorisk",
    "aprioriskare": "apriorisk",
    "aprioriskares": "apriorisk",
    "aprioriskas": "apriorisk",
    "aprioriskast": "apriorisk",
    "aprioriskaste": "apriorisk",
    "aprioriskastes": "apriorisk",
    "aprioriskasts": "apriorisk",
    "aprioriske": "apriorisk",
    "aprioriskes": "apriorisk",
    "apriorisks": "apriorisk",
    "aprioriskt": "apriorisk",
    "aprioriskts": "apriorisk",
    "apropåer": "apropå",
    "apropåerna": "apropå",
    "apropåernas": "apropå",
    "apropåers": "apropå",
    "apropån": "apropå",
    "apropåna": "apropå",
    "apropånas": "apropå",
    "apropåns": "apropå",
    "apropås": "apropå",
    "apropåt": "apropå",
    "apropåts": "apropå",
    "aps": "apa",
    "apsorten": "apsort",
    "apsortens": "apsort",
    "apsorter": "apsort",
    "apsorterna": "apsort",
    "apsorternas": "apsort",
    "apsorters": "apsort",
    "apsorts": "apsort",
    "apspelen": "apspel",
    "apspelens": "apspel",
    "apspelet": "apspel",
    "apspelets": "apspel",
    "apspels": "apspel",
    "apterad": "aptera",
    "apterade": "aptera",
    "apterades": "aptera",
    "apterads": "aptera",
    "apterande": "aptera",
    "apteranden": "apterande",
    "apterandena": "apterande",
    "apterandenas": "apterande",
    "apterandens": "apterande",
    "apterandes": "apterande",
    "apterandet": "apterande",
    "apterandets": "apterande",
    "apterar": "aptera",
    "apteras": "aptera",
    "apterat": "aptera",
    "apterats": "aptera",
    "apterbara": "apterbar",
    "apterbarare": "apterbar",
    "apterbarares": "apterbar",
    "apterbaras": "apterbar",
    "apterbarast": "apterbar",
    "apterbaraste": "apterbar",
    "apterbarastes": "apterbar",
    "apterbarasts": "apterbar",
    "apterbare": "apterbar",
    "apterbares": "apterbar",
    "apterbarheten": "apterbarhet",
    "apterbarhetens": "apterbarhet",
    "apterbarhets": "apterbarhet",
    "apterbars": "apterbar",
    "apterbart": "apterbar",
    "apterbarts": "apterbar",
    "apteringar": "aptering",
    "apteringarna": "aptering",
    "apteringarnas": "aptering",
    "apteringars": "aptering",
    "apteringen": "aptering",
    "apteringens": "aptering",
    "apterings": "aptering",
    "aptiten": "aptit",
    "aptitens": "aptit",
    "aptitliga": "aptitlig",
    "aptitligare": "aptitlig",
    "aptitligares": "aptitlig",
    "aptitligas": "aptitlig",
    "aptitligast": "aptitlig",
    "aptitligaste": "aptitlig",
    "aptitligastes": "aptitlig",
    "aptitligasts": "aptitlig",
    "aptitlige": "aptitlig",
    "aptitliges": "aptitlig",
    "aptitligheten": "aptitlighet",
    "aptitlighetens": "aptitlighet",
    "aptitligheter": "aptitlighet",
    "aptitligheterna": "aptitlighet",
    "aptitligheternas": "aptitlighet",
    "aptitligheters": "aptitlighet",
    "aptitlighets": "aptitlighet",
    "aptitligs": "aptitlig",
    "aptitligt": "aptitlig",
    "aptitligts": "aptitlig",
    "aptitlösheten": "aptitlöshet",
    "aptitlöshetens": "aptitlöshet",
    "aptitlösheter": "aptitlöshet",
    "aptitlösheterna": "aptitlöshet",
    "aptitlösheternas": "aptitlöshet",
    "aptitlösheters": "aptitlöshet",
    "aptitlöshets": "aptitlöshet",
    "aptitretar": "aptitretare",
    "aptitretaren": "aptitretare",
    "aptitretarens": "aptitretare",
    "aptitretares": "aptitretare",
    "aptitretarna": "aptitretare",
    "aptitretarnas": "aptitretare",
    "aptits": "aptit",
    "araben": "arab",
    "arabens": "arab",
    "araber": "arab",
    "araberna": "arab",
    "arabernas": "arab",
    "arabers": "arab",
    "arabesken": "arabesk",
    "arabeskens": "arabesk",
    "arabesker": "arabesk",
    "arabeskerna": "arabesk",
    "arabeskernas": "arabesk",
    "arabeskers": "arabesk",
    "arabesks": "arabesk",
    "arabisk": "arabiska",
    "arabiska": "arabisk",
    "arabiskan": "arabiska",
    "arabiskans": "arabiska",
    "arabiskare": "arabisk",
    "arabiskares": "arabisk",
    "arabiskas": "arabiska",
    "arabiskast": "arabisk",
    "arabiskaste": "arabisk",
    "arabiskastes": "arabisk",
    "arabiskasts": "arabisk",
    "arabiske": "arabiska",
    "arabiskes": "arabisk",
    "arabiskor": "arabiska",
    "arabiskorna": "arabiska",
    "arabiskornas": "arabiska",
    "arabiskors": "arabiska",
    "arabisks": "arabisk",
    "arabiskt": "arabisk",
    "arabiskts": "arabisk",
    "arabisten": "arabist",
    "arabistens": "arabist",
    "arabister": "arabist",
    "arabisterna": "arabist",
    "arabisternas": "arabist",
    "arabisters": "arabist",
    "arabists": "arabist",
    "arabs": "arab",
    "arabvärlden": "arabvärld",
    "arabvärldens": "arabvärld",
    "arabvärlds": "arabvärld",
    "arali": "aralia",
    "aralian": "aralia",
    "aralians": "aralia",
    "aralias": "aralia",
    "aralie": "aralia",
    "aralior": "aralia",
    "araliorna": "aralia",
    "araliornas": "aralia",
    "araliors": "aralia",
    "aralis": "aralia",
    "arameisk": "arameiska",
    "arameiskan": "arameiska",
    "arameiskans": "arameiska",
    "arameiskas": "arameiska",
    "aramiden": "aramid",
    "aramidens": "aramid",
    "aramider": "aramid",
    "aramiderna": "aramid",
    "aramidernas": "aramid",
    "aramiders": "aramid",
    "aramids": "aramid",
    "aran": "ara",
    "arans": "ara",
    "aras": "ara",
    "arbetad": "arbeta",
    "arbetade": "arbeta",
    "arbetades": "arbeta",
    "arbetads": "arbeta",
    "arbetande": "arbeta",
    "arbetanden": "arbetande",
    "arbetandena": "arbetande",
    "arbetandenas": "arbetande",
    "arbetandens": "arbetande",
    "arbetandes": "arbetande",
    "arbetandet": "arbetande",
    "arbetandets": "arbetande",
    "arbetar": "arbetare",
    "arbetarbostaden": "arbetarbostad",
    "arbetarbostadens": "arbetarbostad",
    "arbetarbostads": "arbetarbostad",
    "arbetarbostan": "arbetarbostad",
    "arbetarbostans": "arbetarbostad",
    "arbetarbostäder": "arbetarbostad",
    "arbetarbostäderna": "arbetarbostad",
    "arbetarbostädernas": "arbetarbostad",
    "arbetarbostäders": "arbetarbostad",
    "arbetaren": "arbetare",
    "arbetarens": "arbetare",
    "arbetares": "arbetare",
    "arbetarföreningar": "arbetarförening",
    "arbetarföreningarna": "arbetarförening",
    "arbetarföreningarnas": "arbetarförening",
    "arbetarföreningars": "arbetarförening",
    "arbetarföreningen": "arbetarförening",
    "arbetarföreningens": "arbetarförening",
    "arbetarförenings": "arbetarförening",
    "arbetargruppen": "arbetargrupp",
    "arbetargruppens": "arbetargrupp",
    "arbetargrupper": "arbetargrupp",
    "arbetargrupperna": "arbetargrupp",
    "arbetargruppernas": "arbetargrupp",
    "arbetargruppers": "arbetargrupp",
    "arbetargrupps": "arbetargrupp",
    "arbetarklassen": "arbetarklass",
    "arbetarklassens": "arbetarklass",
    "arbetarklasser": "arbetarklass",
    "arbetarklasserna": "arbetarklass",
    "arbetarklassernas": "arbetarklass",
    "arbetarklassers": "arbetarklass",
    "arbetarkommunen": "arbetarkommun",
    "arbetarkommunens": "arbetarkommun",
    "arbetarkommuner": "arbetarkommun",
    "arbetarkommunerna": "arbetarkommun",
    "arbetarkommunernas": "arbetarkommun",
    "arbetarkommuners": "arbetarkommun",
    "arbetarkommuns": "arbetarkommun",
    "arbetarna": "arbetare",
    "arbetarnas": "arbetare",
    "arbetarpartier": "arbetarparti",
    "arbetarpartierna": "arbetarparti",
    "arbetarpartiernas": "arbetarparti",
    "arbetarpartiers": "arbetarparti",
    "arbetarpartiet": "arbetarparti",
    "arbetarpartiets": "arbetarparti",
    "arbetarpartis": "arbetarparti",
    "arbetarpartit": "arbetarparti",
    "arbetarpartits": "arbetarparti",
    "arbetarregeringar": "arbetarregering",
    "arbetarregeringarna": "arbetarregering",
    "arbetarregeringarnas": "arbetarregering",
    "arbetarregeringars": "arbetarregering",
    "arbetarregeringen": "arbetarregering",
    "arbetarregeringens": "arbetarregering",
    "arbetarregerings": "arbetarregering",
    "arbetarråden": "arbetarråd",
    "arbetarrådens": "arbetarråd",
    "arbetarrådet": "arbetarråd",
    "arbetarrådets": "arbetarråd",
    "arbetarråds": "arbetarråd",
    "arbetarrörelsen": "arbetarrörelse",
    "arbetarrörelsens": "arbetarrörelse",
    "arbetarrörelser": "arbetarrörelse",
    "arbetarrörelserna": "arbetarrörelse",
    "arbetarrörelsernas": "arbetarrörelse",
    "arbetarrörelsers": "arbetarrörelse",
    "arbetarrörelses": "arbetarrörelse",
    "arbetarskyddet": "arbetarskydd",
    "arbetarskyddets": "arbetarskydd",
    "arbetarskydds": "arbetarskydd",
    "arbetarsången": "arbetarsång",
    "arbetarsångens": "arbetarsång",
    "arbetarsånger": "arbetarsång",
    "arbetarsångerna": "arbetarsång",
    "arbetarsångernas": "arbetarsång",
    "arbetarsångers": "arbetarsång",
    "arbetarsångs": "arbetarsång",
    "arbetarupproren": "arbetaruppror",
    "arbetarupprorens": "arbetaruppror",
    "arbetarupproret": "arbetaruppror",
    "arbetarupprorets": "arbetaruppror",
    "arbetarupprors": "arbetaruppror",
    "arbetarväljar": "arbetarväljare",
    "arbetarväljaren": "arbetarväljare",
    "arbetarväljarens": "arbetarväljare",
    "arbetarväljares": "arbetarväljare",
    "arbetarväljarna": "arbetarväljare",
    "arbetarväljarnas": "arbetarväljare",
    "arbetas": "arbeta",
    "arbetat": "arbeta",
    "arbetats": "arbeta",
    "arbeten": "arbete",
    "arbetena": "arbete",
    "arbetenas": "arbete",
    "arbetens": "arbete",
    "arbetes": "arbete",
    "arbetet": "arbete",
    "arbetets": "arbete",
    "arbets": "arbete",
    "arbetsamheten": "arbetsamhet",
    "arbetsamhetens": "arbetsamhet",
    "arbetsamhets": "arbetsamhet",
    "arbetsamma": "arbetsam",
    "arbetsammare": "arbetsam",
    "arbetsammares": "arbetsam",
    "arbetsammas": "arbetsam",
    "arbetsammast": "arbetsam",
    "arbetsammaste": "arbetsam",
    "arbetsammastes": "arbetsam",
    "arbetsammasts": "arbetsam",
    "arbetsamme": "arbetsam",
    "arbetsammes": "arbetsam",
    "arbetsams": "arbetsam",
    "arbetsamt": "arbetsam",
    "arbetsamts": "arbetsam",
    "arbetsanstalten": "arbetsanstalt",
    "arbetsanstaltens": "arbetsanstalt",
    "arbetsanstalter": "arbetsanstalt",
    "arbetsanstalterna": "arbetsanstalt",
    "arbetsanstalternas": "arbetsanstalt",
    "arbetsanstalters": "arbetsanstalt",
    "arbetsanstalts": "arbetsanstalt",
    "arbetsavtalen": "arbetsavtal",
    "arbetsavtalens": "arbetsavtal",
    "arbetsavtalet": "arbetsavtal",
    "arbetsavtalets": "arbetsavtal",
    "arbetsavtals": "arbetsavtal",
    "arbetsbelastningar": "arbetsbelastning",
    "arbetsbelastningarna": "arbetsbelastning",
    "arbetsbelastningarnas": "arbetsbelastning",
    "arbetsbelastningars": "arbetsbelastning",
    "arbetsbelastningen": "arbetsbelastning",
    "arbetsbelastningens": "arbetsbelastning",
    "arbetsbelastnings": "arbetsbelastning",
    "arbetsbelysningar": "arbetsbelysning",
    "arbetsbelysningarna": "arbetsbelysning",
    "arbetsbelysningarnas": "arbetsbelysning",
    "arbetsbelysningars": "arbetsbelysning",
    "arbetsbelysningen": "arbetsbelysning",
    "arbetsbelysningens": "arbetsbelysning",
    "arbetsbelysnings": "arbetsbelysning",
    "arbetsbeskrivningar": "arbetsbeskrivning",
    "arbetsbeskrivningarna": "arbetsbeskrivning",
    "arbetsbeskrivningarnas": "arbetsbeskrivning",
    "arbetsbeskrivningars": "arbetsbeskrivning",
    "arbetsbeskrivningen": "arbetsbeskrivning",
    "arbetsbeskrivningens": "arbetsbeskrivning",
    "arbetsbeskrivnings": "arbetsbeskrivning",
    "arbetsbien": "arbetsbi",
    "arbetsbiens": "arbetsbi",
    "arbetsbiet": "arbetsbi",
    "arbetsbiets": "arbetsbi",
    "arbetsbin": "arbetsbi",
    "arbetsbina": "arbetsbi",
    "arbetsbinas": "arbetsbi",
    "arbetsbins": "arbetsbi",
    "arbetsbis": "arbetsbi",
    "arbetsbit": "arbetsbi",
    "arbetsbits": "arbetsbi",
    "arbetsboken": "arbetsbok",
    "arbetsbokens": "arbetsbok",
    "arbetsboks": "arbetsbok",
    "arbetsborden": "arbetsbord",
    "arbetsbordens": "arbetsbord",
    "arbetsbordet": "arbetsbord",
    "arbetsbordets": "arbetsbord",
    "arbetsbords": "arbetsbord",
    "arbetsbredden": "arbetsbredd",
    "arbetsbreddens": "arbetsbredd",
    "arbetsbredder": "arbetsbredd",
    "arbetsbredderna": "arbetsbredd",
    "arbetsbreddernas": "arbetsbredd",
    "arbetsbredders": "arbetsbredd",
    "arbetsbredds": "arbetsbredd",
    "arbetsbyten": "arbetsbyte",
    "arbetsbytena": "arbetsbyte",
    "arbetsbytenas": "arbetsbyte",
    "arbetsbytens": "arbetsbyte",
    "arbetsbytes": "arbetsbyte",
    "arbetsbytet": "arbetsbyte",
    "arbetsbytets": "arbetsbyte",
    "arbetsböcker": "arbetsbok",
    "arbetsböckerna": "arbetsbok",
    "arbetsböckernas": "arbetsbok",
    "arbetsböckers": "arbetsbok",
    "arbetsbördan": "arbetsbörda",
    "arbetsbördans": "arbetsbörda",
    "arbetsbördas": "arbetsbörda",
    "arbetsbörde": "arbetsbörda",
    "arbetsbördor": "arbetsbörda",
    "arbetsbördorna": "arbetsbörda",
    "arbetsbördornas": "arbetsbörda",
    "arbetsbördors": "arbetsbörda",
    "arbetsdagar": "arbetsdag",
    "arbetsdagarna": "arbetsdag",
    "arbetsdagarnas": "arbetsdag",
    "arbetsdagars": "arbetsdag",
    "arbetsdagen": "arbetsdag",
    "arbetsdagens": "arbetsdag",
    "arbetsdags": "arbetsdag",
    "arbetsdelningar": "arbetsdelning",
    "arbetsdelningarna": "arbetsdelning",
    "arbetsdelningarnas": "arbetsdelning",
    "arbetsdelningars": "arbetsdelning",
    "arbetsdelningen": "arbetsdelning",
    "arbetsdelningens": "arbetsdelning",
    "arbetsdelnings": "arbetsdelning",
    "arbetsdomstolar": "arbetsdomstol",
    "arbetsdomstolarna": "arbetsdomstol",
    "arbetsdomstolarnas": "arbetsdomstol",
    "arbetsdomstolars": "arbetsdomstol",
    "arbetsdomstolen": "arbetsdomstol",
    "arbetsdomstolens": "arbetsdomstol",
    "arbetsdomstols": "arbetsdomstol",
    "arbetsdugliga": "arbetsduglig",
    "arbetsdugligare": "arbetsduglig",
    "arbetsdugligares": "arbetsduglig",
    "arbetsdugligas": "arbetsduglig",
    "arbetsdugligast": "arbetsduglig",
    "arbetsdugligaste": "arbetsduglig",
    "arbetsdugligastes": "arbetsduglig",
    "arbetsdugligasts": "arbetsduglig",
    "arbetsduglige": "arbetsduglig",
    "arbetsdugliges": "arbetsduglig",
    "arbetsdugligheten": "arbetsduglighet",
    "arbetsduglighetens": "arbetsduglighet",
    "arbetsduglighets": "arbetsduglighet",
    "arbetsdugligs": "arbetsduglig",
    "arbetsdugligt": "arbetsduglig",
    "arbetsdugligts": "arbetsduglig",
    "arbetsformen": "arbetsform",
    "arbetsformens": "arbetsform",
    "arbetsforms": "arbetsform",
    "arbetsfreden": "arbetsfred",
    "arbetsfredens": "arbetsfred",
    "arbetsfreds": "arbetsfred",
    "arbetsfria": "arbetsfri",
    "arbetsfriare": "arbetsfri",
    "arbetsfriares": "arbetsfri",
    "arbetsfrias": "arbetsfri",
    "arbetsfriast": "arbetsfri",
    "arbetsfriaste": "arbetsfri",
    "arbetsfriastes": "arbetsfri",
    "arbetsfriasts": "arbetsfri",
    "arbetsfrie": "arbetsfri",
    "arbetsfries": "arbetsfri",
    "arbetsfris": "arbetsfri",
    "arbetsfritt": "arbetsfri",
    "arbetsfritts": "arbetsfri",
    "arbetsfälten": "arbetsfält",
    "arbetsfältens": "arbetsfält",
    "arbetsfältet": "arbetsfält",
    "arbetsfältets": "arbetsfält",
    "arbetsfälts": "arbetsfält",
    "arbetsföra": "arbetsför",
    "arbetsförare": "arbetsför",
    "arbetsförares": "arbetsför",
    "arbetsföras": "arbetsför",
    "arbetsförast": "arbetsför",
    "arbetsföraste": "arbetsför",
    "arbetsförastes": "arbetsför",
    "arbetsförasts": "arbetsför",
    "arbetsfördelningen": "arbetsfördelning",
    "arbetsfördelningens": "arbetsfördelning",
    "arbetsfördelnings": "arbetsfördelning",
    "arbetsföre": "arbetsför",
    "arbetsföres": "arbetsför",
    "arbetsförheten": "arbetsförhet",
    "arbetsförhetens": "arbetsförhet",
    "arbetsförhets": "arbetsförhet",
    "arbetsförhållanden": "arbetsförhållande",
    "arbetsförhållandena": "arbetsförhållande",
    "arbetsförhållandenas": "arbetsförhållande",
    "arbetsförhållandens": "arbetsförhållande",
    "arbetsförhållandes": "arbetsförhållande",
    "arbetsförhållandet": "arbetsförhållande",
    "arbetsförhållandets": "arbetsförhållande",
    "arbetsförmedlar": "arbetsförmedlare",
    "arbetsförmedlaren": "arbetsförmedlare",
    "arbetsförmedlarens": "arbetsförmedlare",
    "arbetsförmedlares": "arbetsförmedlare",
    "arbetsförmedlarna": "arbetsförmedlare",
    "arbetsförmedlarnas": "arbetsförmedlare",
    "arbetsförmedlingar": "arbetsförmedling",
    "arbetsförmedlingarna": "arbetsförmedling",
    "arbetsförmedlingarnas": "arbetsförmedling",
    "arbetsförmedlingars": "arbetsförmedling",
    "arbetsförmedlingen": "arbetsförmedling",
    "arbetsförmedlingens": "arbetsförmedling",
    "arbetsförmedlings": "arbetsförmedling",
    "arbetsförmågan": "arbetsförmåga",
    "arbetsförmågans": "arbetsförmåga",
    "arbetsförmågas": "arbetsförmåga",
    "arbetsförmåge": "arbetsförmåga",
    "arbetsförmågeutrednine": "arbetsförmågeutredning",
    "arbetsförmågeutredningn": "arbetsförmågeutredning",
    "arbetsförmågeutredningns": "arbetsförmågeutredning",
    "arbetsförmågeutrednings": "arbetsförmågeutredning",
    "arbetsförmågeutredninor": "arbetsförmågeutredning",
    "arbetsförmågeutredninorna": "arbetsförmågeutredning",
    "arbetsförmågeutredninornas": "arbetsförmågeutredning",
    "arbetsförmågeutredninors": "arbetsförmågeutredning",
    "arbetsförmågor": "arbetsförmåga",
    "arbetsförmågorna": "arbetsförmåga",
    "arbetsförmågornas": "arbetsförmåga",
    "arbetsförmågors": "arbetsförmåga",
    "arbetsförs": "arbetsför",
    "arbetsfört": "arbetsför",
    "arbetsförtjänsten": "arbetsförtjänst",
    "arbetsförtjänstens": "arbetsförtjänst",
    "arbetsförtjänster": "arbetsförtjänst",
    "arbetsförtjänsterna": "arbetsförtjänst",
    "arbetsförtjänsternas": "arbetsförtjänst",
    "arbetsförtjänsters": "arbetsförtjänst",
    "arbetsförtjänsts": "arbetsförtjänst",
    "arbetsförts": "arbetsför",
    "arbetsgivar": "arbetsgivare",
    "arbetsgivaravgiften": "arbetsgivaravgift",
    "arbetsgivaravgiftens": "arbetsgivaravgift",
    "arbetsgivaravgifter": "arbetsgivaravgift",
    "arbetsgivaravgifterna": "arbetsgivaravgift",
    "arbetsgivaravgifternas": "arbetsgivaravgift",
    "arbetsgivaravgifters": "arbetsgivaravgift",
    "arbetsgivaravgifts": "arbetsgivaravgift",
    "arbetsgivareföreningar": "arbetsgivareförening",
    "arbetsgivareföreningarna": "arbetsgivareförening",
    "arbetsgivareföreningarnas": "arbetsgivareförening",
    "arbetsgivareföreningars": "arbetsgivareförening",
    "arbetsgivareföreningen": "arbetsgivareförening",
    "arbetsgivareföreningens": "arbetsgivareförening",
    "arbetsgivareförenings": "arbetsgivareförening",
    "arbetsgivaren": "arbetsgivare",
    "arbetsgivarens": "arbetsgivare",
    "arbetsgivares": "arbetsgivare",
    "arbetsgivarföreningar": "arbetsgivarförening",
    "arbetsgivarföreningarna": "arbetsgivarförening",
    "arbetsgivarföreningarnas": "arbetsgivarförening",
    "arbetsgivarföreningars": "arbetsgivarförening",
    "arbetsgivarföreningen": "arbetsgivarförening",
    "arbetsgivarföreningens": "arbetsgivarförening",
    "arbetsgivarförenings": "arbetsgivarförening",
    "arbetsgivarinträden": "arbetsgivarinträde",
    "arbetsgivarinträdena": "arbetsgivarinträde",
    "arbetsgivarinträdenas": "arbetsgivarinträde",
    "arbetsgivarinträdens": "arbetsgivarinträde",
    "arbetsgivarinträdes": "arbetsgivarinträde",
    "arbetsgivarinträdet": "arbetsgivarinträde",
    "arbetsgivarinträdets": "arbetsgivarinträde",
    "arbetsgivarna": "arbetsgivare",
    "arbetsgivarnas": "arbetsgivare",
    "arbetsglädjen": "arbetsglädje",
    "arbetsglädjens": "arbetsglädje",
    "arbetsglädjes": "arbetsglädje",
    "arbetsgruppen": "arbetsgrupp",
    "arbetsgruppens": "arbetsgrupp",
    "arbetsgrupper": "arbetsgrupp",
    "arbetsgrupperna": "arbetsgrupp",
    "arbetsgruppernas": "arbetsgrupp",
    "arbetsgruppers": "arbetsgrupp",
    "arbetsgrupps": "arbetsgrupp",
    "arbetshandsk": "arbetshandske",
    "arbetshandskar": "arbetshandske",
    "arbetshandskarna": "arbetshandske",
    "arbetshandskarnas": "arbetshandske",
    "arbetshandskars": "arbetshandske",
    "arbetshandsken": "arbetshandske",
    "arbetshandskens": "arbetshandske",
    "arbetshandskes": "arbetshandske",
    "arbetshypotesen": "arbetshypotes",
    "arbetshypotesens": "arbetshypotes",
    "arbetshypoteser": "arbetshypotes",
    "arbetshypoteserna": "arbetshypotes",
    "arbetshypotesernas": "arbetshypotes",
    "arbetshypotesers": "arbetshypotes",
    "arbetsinkomsten": "arbetsinkomst",
    "arbetsinkomstens": "arbetsinkomst",
    "arbetsinkomster": "arbetsinkomst",
    "arbetsinkomsterna": "arbetsinkomst",
    "arbetsinkomsternas": "arbetsinkomst",
    "arbetsinkomsters": "arbetsinkomst",
    "arbetsinkomsts": "arbetsinkomst",
    "arbetsinsatsen": "arbetsinsats",
    "arbetsinsatsens": "arbetsinsats",
    "arbetsinsatser": "arbetsinsats",
    "arbetsinsatserna": "arbetsinsats",
    "arbetsinsatsernas": "arbetsinsats",
    "arbetsinsatsers": "arbetsinsats",
    "arbetsinställelsen": "arbetsinställelse",
    "arbetsinställelsens": "arbetsinställelse",
    "arbetsinställelser": "arbetsinställelse",
    "arbetsinställelserna": "arbetsinställelse",
    "arbetsinställelsernas": "arbetsinställelse",
    "arbetsinställelsers": "arbetsinställelse",
    "arbetsinställelses": "arbetsinställelse",
    "arbetsintensiteten": "arbetsintensitet",
    "arbetsintensitetens": "arbetsintensitet",
    "arbetsintensitets": "arbetsintensitet",
    "arbetsintensiva": "arbetsintensiv",
    "arbetsintensivare": "arbetsintensiv",
    "arbetsintensivares": "arbetsintensiv",
    "arbetsintensivas": "arbetsintensiv",
    "arbetsintensivast": "arbetsintensiv",
    "arbetsintensivaste": "arbetsintensiv",
    "arbetsintensivastes": "arbetsintensiv",
    "arbetsintensivasts": "arbetsintensiv",
    "arbetsintensive": "arbetsintensiv",
    "arbetsintensives": "arbetsintensiv",
    "arbetsintensivs": "arbetsintensiv",
    "arbetsintensivt": "arbetsintensiv",
    "arbetsintensivts": "arbetsintensiv",
    "arbetsintervjuer": "arbetsintervju",
    "arbetsintervjuerna": "arbetsintervju",
    "arbetsintervjuernas": "arbetsintervju",
    "arbetsintervjuers": "arbetsintervju",
    "arbetsintervjun": "arbetsintervju",
    "arbetsintervjuns": "arbetsintervju",
    "arbetsintervjus": "arbetsintervju",
    "arbetsjack": "arbetsjacka",
    "arbetsjackan": "arbetsjacka",
    "arbetsjackans": "arbetsjacka",
    "arbetsjackas": "arbetsjacka",
    "arbetsjacke": "arbetsjacka",
    "arbetsjackor": "arbetsjacka",
    "arbetsjackorna": "arbetsjacka",
    "arbetsjackornas": "arbetsjacka",
    "arbetsjackors": "arbetsjacka",
    "arbetsjacks": "arbetsjacka",
    "arbetskamraten": "arbetskamrat",
    "arbetskamratens": "arbetskamrat",
    "arbetskamrater": "arbetskamrat",
    "arbetskamraterna": "arbetskamrat",
    "arbetskamraternas": "arbetskamrat",
    "arbetskamraters": "arbetskamrat",
    "arbetskamrats": "arbetskamrat",
    "arbetskarlar": "arbetskarl",
    "arbetskarlarna": "arbetskarl",
    "arbetskarlarnas": "arbetskarl",
    "arbetskarlars": "arbetskarl",
    "arbetskarlen": "arbetskarl",
    "arbetskarlens": "arbetskarl",
    "arbetskarls": "arbetskarl",
    "arbetskläderna": "arbetskläder",
    "arbetsklädernas": "arbetskläder",
    "arbetskläders": "arbetskläder",
    "arbetsklädes": "arbetskläder",
    "arbetskläds": "arbetskläder",
    "arbetskonflikten": "arbetskonflikt",
    "arbetskonfliktens": "arbetskonflikt",
    "arbetskonflikter": "arbetskonflikt",
    "arbetskonflikterna": "arbetskonflikt",
    "arbetskonflikternas": "arbetskonflikt",
    "arbetskonflikters": "arbetskonflikt",
    "arbetskonflikts": "arbetskonflikt",
    "arbetskraften": "arbetskraft",
    "arbetskraftens": "arbetskraft",
    "arbetskrafts": "arbetskraft",
    "arbetskraftsinvandrar": "arbetskraftsinvandrare",
    "arbetskraftsinvandraren": "arbetskraftsinvandrare",
    "arbetskraftsinvandrarens": "arbetskraftsinvandrare",
    "arbetskraftsinvandrares": "arbetskraftsinvandrare",
    "arbetskraftsinvandrarna": "arbetskraftsinvandrare",
    "arbetskraftsinvandrarnas": "arbetskraftsinvandrare",
    "arbetskraftsinvandringen": "arbetskraftsinvandring",
    "arbetskraftsinvandringens": "arbetskraftsinvandring",
    "arbetskraftsinvandrings": "arbetskraftsinvandring",
    "arbetsköpar": "arbetsköpare",
    "arbetsköparen": "arbetsköpare",
    "arbetsköparens": "arbetsköpare",
    "arbetsköpares": "arbetsköpare",
    "arbetsköparna": "arbetsköpare",
    "arbetsköparnas": "arbetsköpare",
    "arbetslagen": "arbetslag",
    "arbetslagens": "arbetslag",
    "arbetslaget": "arbetslag",
    "arbetslagets": "arbetslag",
    "arbetslags": "arbetslag",
    "arbetsledar": "arbetsledare",
    "arbetsledaren": "arbetsledare",
    "arbetsledarens": "arbetsledare",
    "arbetsledares": "arbetsledare",
    "arbetsledarna": "arbetsledare",
    "arbetsledarnas": "arbetsledare",
    "arbetslivet": "arbetsliv",
    "arbetslivets": "arbetsliv",
    "arbetslivs": "arbetsliv",
    "arbetslivserfarenheten": "arbetslivserfarenhet",
    "arbetslivserfarenhetens": "arbetslivserfarenhet",
    "arbetslivserfarenheter": "arbetslivserfarenhet",
    "arbetslivserfarenheterna": "arbetslivserfarenhet",
    "arbetslivserfarenheternas": "arbetslivserfarenhet",
    "arbetslivserfarenheters": "arbetslivserfarenhet",
    "arbetslivserfarenhets": "arbetslivserfarenhet",
    "arbetslivsfonden": "arbetslivsfond",
    "arbetslivsfondens": "arbetslivsfond",
    "arbetslivsfonder": "arbetslivsfond",
    "arbetslivsfonderna": "arbetslivsfond",
    "arbetslivsfondernas": "arbetslivsfond",
    "arbetslivsfonders": "arbetslivsfond",
    "arbetslivsfonds": "arbetslivsfond",
    "arbetslusten": "arbetslust",
    "arbetslustens": "arbetslust",
    "arbetslusts": "arbetslust",
    "arbetslägerna": "arbetsläger",
    "arbetslägernas": "arbetsläger",
    "arbetslägers": "arbetsläger",
    "arbetslägren": "arbetsläger",
    "arbetslägrens": "arbetsläger",
    "arbetslägret": "arbetsläger",
    "arbetslägrets": "arbetsläger",
    "arbetslängden": "arbetslängd",
    "arbetslängdens": "arbetslängd",
    "arbetslängder": "arbetslängd",
    "arbetslängderna": "arbetslängd",
    "arbetslängdernas": "arbetslängd",
    "arbetslängders": "arbetslängd",
    "arbetslängds": "arbetslängd",
    "arbetslösa": "arbetslös",
    "arbetslösare": "arbetslös",
    "arbetslösares": "arbetslös",
    "arbetslösas": "arbetslös",
    "arbetslösast": "arbetslös",
    "arbetslösaste": "arbetslös",
    "arbetslösastes": "arbetslös",
    "arbetslösasts": "arbetslös",
    "arbetslöse": "arbetslös",
    "arbetslöses": "arbetslös",
    "arbetslösheten": "arbetslöshet",
    "arbetslöshetens": "arbetslöshet",
    "arbetslösheter": "arbetslöshet",
    "arbetslösheterna": "arbetslöshet",
    "arbetslösheternas": "arbetslöshet",
    "arbetslösheters": "arbetslöshet",
    "arbetslöshets": "arbetslöshet",
    "arbetslöshetsperioden": "arbetslöshetsperiod",
    "arbetslöshetsperiodens": "arbetslöshetsperiod",
    "arbetslöshetsperioder": "arbetslöshetsperiod",
    "arbetslöshetsperioderna": "arbetslöshetsperiod",
    "arbetslöshetsperiodernas": "arbetslöshetsperiod",
    "arbetslöshetsperioders": "arbetslöshetsperiod",
    "arbetslöshetsperiods": "arbetslöshetsperiod",
    "arbetslöst": "arbetslös",
    "arbetslösts": "arbetslös",
    "arbetsmarknaden": "arbetsmarknad",
    "arbetsmarknadens": "arbetsmarknad",
    "arbetsmarknader": "arbetsmarknad",
    "arbetsmarknaderna": "arbetsmarknad",
    "arbetsmarknadernas": "arbetsmarknad",
    "arbetsmarknaders": "arbetsmarknad",
    "arbetsmarknads": "arbetsmarknad",
    "arbetsmarknadskonflikten": "arbetsmarknadskonflikt",
    "arbetsmarknadskonfliktens": "arbetsmarknadskonflikt",
    "arbetsmarknadskonflikter": "arbetsmarknadskonflikt",
    "arbetsmarknadskonflikterna": "arbetsmarknadskonflikt",
    "arbetsmarknadskonflikternas": "arbetsmarknadskonflikt",
    "arbetsmarknadskonflikters": "arbetsmarknadskonflikt",
    "arbetsmarknadskonflikts": "arbetsmarknadskonflikt",
    "arbetsmarknadsministern": "arbetsmarknadsminister",
    "arbetsmarknadsministerns": "arbetsmarknadsminister",
    "arbetsmarknadsministers": "arbetsmarknadsminister",
    "arbetsmarknadsministrar": "arbetsmarknadsminister",
    "arbetsmarknadsministrarna": "arbetsmarknadsminister",
    "arbetsmarknadsministrarnas": "arbetsmarknadsminister",
    "arbetsmarknadsministrars": "arbetsmarknadsminister",
    "arbetsmarknadsmässiga": "arbetsmarknadsmässig",
    "arbetsmarknadsmässigare": "arbetsmarknadsmässig",
    "arbetsmarknadsmässigares": "arbetsmarknadsmässig",
    "arbetsmarknadsmässigas": "arbetsmarknadsmässig",
    "arbetsmarknadsmässigast": "arbetsmarknadsmässig",
    "arbetsmarknadsmässigaste": "arbetsmarknadsmässig",
    "arbetsmarknadsmässigastes": "arbetsmarknadsmässig",
    "arbetsmarknadsmässigasts": "arbetsmarknadsmässig",
    "arbetsmarknadsmässige": "arbetsmarknadsmässig",
    "arbetsmarknadsmässiges": "arbetsmarknadsmässig",
    "arbetsmarknadsmässigs": "arbetsmarknadsmässig",
    "arbetsmarknadsmässigt": "arbetsmarknadsmässig",
    "arbetsmarknadsmässigts": "arbetsmarknadsmässig",
    "arbetsmarknadspolitiken": "arbetsmarknadspolitik",
    "arbetsmarknadspolitikens": "arbetsmarknadspolitik",
    "arbetsmarknadspolitiker": "arbetsmarknadspolitik",
    "arbetsmarknadspolitikerna": "arbetsmarknadspolitik",
    "arbetsmarknadspolitikernas": "arbetsmarknadspolitik",
    "arbetsmarknadspolitikers": "arbetsmarknadspolitik",
    "arbetsmarknadspolitiks": "arbetsmarknadspolitik",
    "arbetsmarknadspolitiska": "arbetsmarknadspolitisk",
    "arbetsmarknadspolitiskare": "arbetsmarknadspolitisk",
    "arbetsmarknadspolitiskares": "arbetsmarknadspolitisk",
    "arbetsmarknadspolitiskas": "arbetsmarknadspolitisk",
    "arbetsmarknadspolitiskast": "arbetsmarknadspolitisk",
    "arbetsmarknadspolitiskaste": "arbetsmarknadspolitisk",
    "arbetsmarknadspolitiskastes": "arbetsmarknadspolitisk",
    "arbetsmarknadspolitiskasts": "arbetsmarknadspolitisk",
    "arbetsmarknadspolitiske": "arbetsmarknadspolitisk",
    "arbetsmarknadspolitiskes": "arbetsmarknadspolitisk",
    "arbetsmarknadspolitisks": "arbetsmarknadspolitisk",
    "arbetsmarknadspolitiskt": "arbetsmarknadspolitisk",
    "arbetsmarknadspolitiskts": "arbetsmarknadspolitisk",
    "arbetsmarknadsstyrelsen": "arbetsmarknadsstyrelse",
    "arbetsmarknadsstyrelsens": "arbetsmarknadsstyrelse",
    "arbetsmarknadsstyrelses": "arbetsmarknadsstyrelse",
    "arbetsmarknadsutbildningar": "arbetsmarknadsutbildning",
    "arbetsmarknadsutbildningarna": "arbetsmarknadsutbildning",
    "arbetsmarknadsutbildningarnas": "arbetsmarknadsutbildning",
    "arbetsmarknadsutbildningars": "arbetsmarknadsutbildning",
    "arbetsmarknadsutbildningen": "arbetsmarknadsutbildning",
    "arbetsmarknadsutbildningens": "arbetsmarknadsutbildning",
    "arbetsmarknadsutbildnings": "arbetsmarknadsutbildning",
    "arbetsmarknadsåtgärden": "arbetsmarknadsåtgärd",
    "arbetsmarknadsåtgärdens": "arbetsmarknadsåtgärd",
    "arbetsmarknadsåtgärder": "arbetsmarknadsåtgärd",
    "arbetsmarknadsåtgärderna": "arbetsmarknadsåtgärd",
    "arbetsmarknadsåtgärdernas": "arbetsmarknadsåtgärd",
    "arbetsmarknadsåtgärders": "arbetsmarknadsåtgärd",
    "arbetsmarknadsåtgärds": "arbetsmarknadsåtgärd",
    "arbetsmaskinen": "arbetsmaskin",
    "arbetsmaskinens": "arbetsmaskin",
    "arbetsmaskiner": "arbetsmaskin",
    "arbetsmaskinerna": "arbetsmaskin",
    "arbetsmaskinernas": "arbetsmaskin",
    "arbetsmaskiners": "arbetsmaskin",
    "arbetsmaskins": "arbetsmaskin",
    "arbetsmaterialen": "arbetsmaterial",
    "arbetsmaterialens": "arbetsmaterial",
    "arbetsmaterialet": "arbetsmaterial",
    "arbetsmaterialets": "arbetsmaterial",
    "arbetsmaterials": "arbetsmaterial",
    "arbetsmiljöbrotten": "arbetsmiljöbrott",
    "arbetsmiljöbrottens": "arbetsmiljöbrott",
    "arbetsmiljöbrottet": "arbetsmiljöbrott",
    "arbetsmiljöbrottets": "arbetsmiljöbrott",
    "arbetsmiljöbrotts": "arbetsmiljöbrott",
    "arbetsmiljöer": "arbetsmiljö",
    "arbetsmiljöerna": "arbetsmiljö",
    "arbetsmiljöernas": "arbetsmiljö",
    "arbetsmiljöers": "arbetsmiljö",
    "arbetsmiljömässiga": "arbetsmiljömässig",
    "arbetsmiljömässigare": "arbetsmiljömässig",
    "arbetsmiljömässigares": "arbetsmiljömässig",
    "arbetsmiljömässigas": "arbetsmiljömässig",
    "arbetsmiljömässigast": "arbetsmiljömässig",
    "arbetsmiljömässigaste": "arbetsmiljömässig",
    "arbetsmiljömässigastes": "arbetsmiljömässig",
    "arbetsmiljömässigasts": "arbetsmiljömässig",
    "arbetsmiljömässige": "arbetsmiljömässig",
    "arbetsmiljömässiges": "arbetsmiljömässig",
    "arbetsmiljömässigs": "arbetsmiljömässig",
    "arbetsmiljömässigt": "arbetsmiljömässig",
    "arbetsmiljömässigts": "arbetsmiljömässig",
    "arbetsmiljömålen": "arbetsmiljömål",
    "arbetsmiljömålens": "arbetsmiljömål",
    "arbetsmiljömålet": "arbetsmiljömål",
    "arbetsmiljömålets": "arbetsmiljömål",
    "arbetsmiljömåls": "arbetsmiljömål",
    "arbetsmiljön": "arbetsmiljö",
    "arbetsmiljöns": "arbetsmiljö",
    "arbetsmiljös": "arbetsmiljö",
    "arbetsminnen": "arbetsminne",
    "arbetsminnena": "arbetsminne",
    "arbetsminnenas": "arbetsminne",
    "arbetsminnens": "arbetsminne",
    "arbetsminnes": "arbetsminne",
    "arbetsminnestesten": "arbetsminnestest",
    "arbetsminnestestens": "arbetsminnestest",
    "arbetsminnestester": "arbetsminnestest",
    "arbetsminnestesterna": "arbetsminnestest",
    "arbetsminnestesternas": "arbetsminnestest",
    "arbetsminnestesters": "arbetsminnestest",
    "arbetsminnestestet": "arbetsminnestest",
    "arbetsminnestestets": "arbetsminnestest",
    "arbetsminnestests": "arbetsminnestest",
    "arbetsminnet": "arbetsminne",
    "arbetsminnets": "arbetsminne",
    "arbetsmomenten": "arbetsmoment",
    "arbetsmomentens": "arbetsmoment",
    "arbetsmomentet": "arbetsmoment",
    "arbetsmomentets": "arbetsmoment",
    "arbetsmoments": "arbetsmoment",
    "arbetsmoralen": "arbetsmoral",
    "arbetsmoralens": "arbetsmoral",
    "arbetsmoraler": "arbetsmoral",
    "arbetsmoralerna": "arbetsmoral",
    "arbetsmoralernas": "arbetsmoral",
    "arbetsmoralers": "arbetsmoral",
    "arbetsmorals": "arbetsmoral",
    "arbetsmyr": "arbetsmyra",
    "arbetsmyran": "arbetsmyra",
    "arbetsmyrans": "arbetsmyra",
    "arbetsmyras": "arbetsmyra",
    "arbetsmyre": "arbetsmyra",
    "arbetsmyror": "arbetsmyra",
    "arbetsmyrorna": "arbetsmyra",
    "arbetsmyrornas": "arbetsmyra",
    "arbetsmyrors": "arbetsmyra",
    "arbetsmyrs": "arbetsmyra",
    "arbetsmängden": "arbetsmängd",
    "arbetsmängdens": "arbetsmängd",
    "arbetsmängder": "arbetsmängd",
    "arbetsmängderna": "arbetsmängd",
    "arbetsmängdernas": "arbetsmängd",
    "arbetsmängders": "arbetsmängd",
    "arbetsmängds": "arbetsmängd",
    "arbetsmässiga": "arbetsmässig",
    "arbetsmässigare": "arbetsmässig",
    "arbetsmässigares": "arbetsmässig",
    "arbetsmässigas": "arbetsmässig",
    "arbetsmässigast": "arbetsmässig",
    "arbetsmässigaste": "arbetsmässig",
    "arbetsmässigastes": "arbetsmässig",
    "arbetsmässigasts": "arbetsmässig",
    "arbetsmässige": "arbetsmässig",
    "arbetsmässiges": "arbetsmässig",
    "arbetsmässigs": "arbetsmässig",
    "arbetsmässigt": "arbetsmässig",
    "arbetsmässigts": "arbetsmässig",
    "arbetsmätningar": "arbetsmätning",
    "arbetsmätningarna": "arbetsmätning",
    "arbetsmätningarnas": "arbetsmätning",
    "arbetsmätningars": "arbetsmätning",
    "arbetsmätningen": "arbetsmätning",
    "arbetsmätningens": "arbetsmätning",
    "arbetsmätnings": "arbetsmätning",
    "arbetsnamnen": "arbetsnamn",
    "arbetsnamnens": "arbetsnamn",
    "arbetsnamnet": "arbetsnamn",
    "arbetsnamnets": "arbetsnamn",
    "arbetsnamns": "arbetsnamn",
    "arbetsnarkomanen": "arbetsnarkoman",
    "arbetsnarkomanens": "arbetsnarkoman",
    "arbetsnarkomaner": "arbetsnarkoman",
    "arbetsnarkomanerna": "arbetsnarkoman",
    "arbetsnarkomanernas": "arbetsnarkoman",
    "arbetsnarkomaners": "arbetsnarkoman",
    "arbetsnarkomans": "arbetsnarkoman",
    "arbetsnedläggelsen": "arbetsnedläggelse",
    "arbetsnedläggelsens": "arbetsnedläggelse",
    "arbetsnedläggelser": "arbetsnedläggelse",
    "arbetsnedläggelserna": "arbetsnedläggelse",
    "arbetsnedläggelsernas": "arbetsnedläggelse",
    "arbetsnedläggelsers": "arbetsnedläggelse",
    "arbetsnedläggelses": "arbetsnedläggelse",
    "arbetsnämnden": "arbetsnämnd",
    "arbetsnämndens": "arbetsnämnd",
    "arbetsnämnder": "arbetsnämnd",
    "arbetsnämnderna": "arbetsnämnd",
    "arbetsnämndernas": "arbetsnämnd",
    "arbetsnämnders": "arbetsnämnd",
    "arbetsnämnds": "arbetsnämnd",
    "arbetsområden": "arbetsområde",
    "arbetsområdena": "arbetsområde",
    "arbetsområdenas": "arbetsområde",
    "arbetsområdens": "arbetsområde",
    "arbetsområdes": "arbetsområde",
    "arbetsområdet": "arbetsområde",
    "arbetsområdets": "arbetsområde",
    "arbetsordningar": "arbetsordning",
    "arbetsordningarna": "arbetsordning",
    "arbetsordningarnas": "arbetsordning",
    "arbetsordningars": "arbetsordning",
    "arbetsordningen": "arbetsordning",
    "arbetsordningens": "arbetsordning",
    "arbetsordnings": "arbetsordning",
    "arbetsorganisationen": "arbetsorganisation",
    "arbetsorganisationens": "arbetsorganisation",
    "arbetsorganisations": "arbetsorganisation",
    "arbetspassen": "arbetspass",
    "arbetspassens": "arbetspass",
    "arbetspasset": "arbetspass",
    "arbetspassets": "arbetspass",
    "arbetspendlad": "arbetspendla",
    "arbetspendlade": "arbetspendla",
    "arbetspendlades": "arbetspendla",
    "arbetspendlads": "arbetspendla",
    "arbetspendlande": "arbetspendla",
    "arbetspendlanden": "arbetspendlande",
    "arbetspendlandena": "arbetspendlande",
    "arbetspendlandenas": "arbetspendlande",
    "arbetspendlandens": "arbetspendlande",
    "arbetspendlandes": "arbetspendlande",
    "arbetspendlandet": "arbetspendlande",
    "arbetspendlandets": "arbetspendlande",
    "arbetspendlar": "arbetspendla",
    "arbetspendlas": "arbetspendla",
    "arbetspendlat": "arbetspendla",
    "arbetspendlats": "arbetspendla",
    "arbetsplatsen": "arbetsplats",
    "arbetsplatsens": "arbetsplats",
    "arbetsplatser": "arbetsplats",
    "arbetsplatserna": "arbetsplats",
    "arbetsplatsernas": "arbetsplats",
    "arbetsplatsers": "arbetsplats",
    "arbetsplatsolyck": "arbetsplatsolycka",
    "arbetsplatsolyckan": "arbetsplatsolycka",
    "arbetsplatsolyckans": "arbetsplatsolycka",
    "arbetsplatsolyckas": "arbetsplatsolycka",
    "arbetsplatsolycke": "arbetsplatsolycka",
    "arbetsplatsolyckor": "arbetsplatsolycka",
    "arbetsplatsolyckorna": "arbetsplatsolycka",
    "arbetsplatsolyckornas": "arbetsplatsolycka",
    "arbetsplatsolyckors": "arbetsplatsolycka",
    "arbetsplatsolycks": "arbetsplatsolycka",
    "arbetsplena": "arbetsplenum",
    "arbetsplenana": "arbetsplenum",
    "arbetsplenanas": "arbetsplenum",
    "arbetsplenas": "arbetsplenum",
    "arbetsplenumen": "arbetsplenum",
    "arbetsplenumens": "arbetsplenum",
    "arbetsplenumet": "arbetsplenum",
    "arbetsplenumets": "arbetsplenum",
    "arbetsplenums": "arbetsplenum",
    "arbetsproven": "arbetsprov",
    "arbetsprovens": "arbetsprov",
    "arbetsprover": "arbetsprov",
    "arbetsproverna": "arbetsprov",
    "arbetsprovernas": "arbetsprov",
    "arbetsprovers": "arbetsprov",
    "arbetsprovet": "arbetsprov",
    "arbetsprovets": "arbetsprov",
    "arbetsprovs": "arbetsprov",
    "arbetsredskapen": "arbetsredskap",
    "arbetsredskapens": "arbetsredskap",
    "arbetsredskapet": "arbetsredskap",
    "arbetsredskapets": "arbetsredskap",
    "arbetsredskaps": "arbetsredskap",
    "arbetsrelationen": "arbetsrelation",
    "arbetsrelationens": "arbetsrelation",
    "arbetsrelationer": "arbetsrelation",
    "arbetsrelationerna": "arbetsrelation",
    "arbetsrelationernas": "arbetsrelation",
    "arbetsrelationers": "arbetsrelation",
    "arbetsrelations": "arbetsrelation",
    "arbetsron": "arbetsro",
    "arbetsrons": "arbetsro",
    "arbetsros": "arbetsro",
    "arbetsrummen": "arbetsrum",
    "arbetsrummens": "arbetsrum",
    "arbetsrummet": "arbetsrum",
    "arbetsrummets": "arbetsrum",
    "arbetsrums": "arbetsrum",
    "arbetsrätten": "arbetsrätt",
    "arbetsrättens": "arbetsrätt",
    "arbetsrätts": "arbetsrätt",
    "arbetsrättsliga": "arbetsrättslig",
    "arbetsrättsligas": "arbetsrättslig",
    "arbetsrättslige": "arbetsrättslig",
    "arbetsrättsliges": "arbetsrättslig",
    "arbetsrättsligs": "arbetsrättslig",
    "arbetsrättsligt": "arbetsrättslig",
    "arbetsrättsligts": "arbetsrättslig",
    "arbetsscheman": "arbetsschema",
    "arbetsschemana": "arbetsschema",
    "arbetsschemanas": "arbetsschema",
    "arbetsschemans": "arbetsschema",
    "arbetsschemas": "arbetsschema",
    "arbetsschemat": "arbetsschema",
    "arbetsschemats": "arbetsschema",
    "arbetssegern": "arbetsseger",
    "arbetssegerns": "arbetsseger",
    "arbetssegers": "arbetsseger",
    "arbetssegrar": "arbetsseger",
    "arbetssegrarna": "arbetsseger",
    "arbetssegrarnas": "arbetsseger",
    "arbetssegrars": "arbetsseger",
    "arbetsskadan": "arbetsskada",
    "arbetsskadans": "arbetsskada",
    "arbetsskadas": "arbetsskada",
    "arbetsskade": "arbetsskada",
    "arbetsskador": "arbetsskada",
    "arbetsskadorna": "arbetsskada",
    "arbetsskadornas": "arbetsskada",
    "arbetsskadors": "arbetsskada",
    "arbetsskygga": "arbetsskygg",
    "arbetsskyggare": "arbetsskygg",
    "arbetsskyggares": "arbetsskygg",
    "arbetsskyggas": "arbetsskygg",
    "arbetsskyggast": "arbetsskygg",
    "arbetsskyggaste": "arbetsskygg",
    "arbetsskyggastes": "arbetsskygg",
    "arbetsskyggasts": "arbetsskygg",
    "arbetsskygge": "arbetsskygg",
    "arbetsskygges": "arbetsskygg",
    "arbetsskyggheten": "arbetsskygghet",
    "arbetsskygghetens": "arbetsskygghet",
    "arbetsskygghets": "arbetsskygghet",
    "arbetsskyggs": "arbetsskygg",
    "arbetsskyggt": "arbetsskygg",
    "arbetsskyggts": "arbetsskygg",
    "arbetsstudie": "arbetsstudier",
    "arbetsstudiemannen": "arbetsstudieman",
    "arbetsstudiemannens": "arbetsstudieman",
    "arbetsstudiemans": "arbetsstudieman",
    "arbetsstudiemän": "arbetsstudieman",
    "arbetsstudiemännen": "arbetsstudieman",
    "arbetsstudiemännens": "arbetsstudieman",
    "arbetsstudiemäns": "arbetsstudieman",
    "arbetsstudierna": "arbetsstudier",
    "arbetsstudiernas": "arbetsstudier",
    "arbetsstudiers": "arbetsstudier",
    "arbetsstycken": "arbetsstycke",
    "arbetsstyckena": "arbetsstycke",
    "arbetsstyckenas": "arbetsstycke",
    "arbetsstyckens": "arbetsstycke",
    "arbetsstyckes": "arbetsstycke",
    "arbetsstycket": "arbetsstycke",
    "arbetsstyckets": "arbetsstycke",
    "arbetsstycks": "arbetsstycke",
    "arbetsstyrkan": "arbetsstyrka",
    "arbetsstyrkans": "arbetsstyrka",
    "arbetsstyrkas": "arbetsstyrka",
    "arbetsstyrke": "arbetsstyrka",
    "arbetssätten": "arbetssätt",
    "arbetssättens": "arbetssätt",
    "arbetssättet": "arbetssätt",
    "arbetssättets": "arbetssätt",
    "arbetssätts": "arbetssätt",
    "arbetssången": "arbetssång",
    "arbetssångens": "arbetssång",
    "arbetssånger": "arbetssång",
    "arbetssångerna": "arbetssång",
    "arbetssångernas": "arbetssång",
    "arbetssångers": "arbetssång",
    "arbetssångs": "arbetssång",
    "arbetssökanden": "arbetssökande",
    "arbetssökandena": "arbetssökande",
    "arbetssökandenas": "arbetssökande",
    "arbetssökandens": "arbetssökande",
    "arbetssökandes": "arbetssökande",
    "arbetstagar": "arbetstagare",
    "arbetstagaren": "arbetstagare",
    "arbetstagarens": "arbetstagare",
    "arbetstagares": "arbetstagare",
    "arbetstagarna": "arbetstagare",
    "arbetstagarnas": "arbetstagare",
    "arbetstakten": "arbetstakt",
    "arbetstaktens": "arbetstakt",
    "arbetstakts": "arbetstakt",
    "arbetstemperaturen": "arbetstemperatur",
    "arbetstemperaturens": "arbetstemperatur",
    "arbetstemperaturer": "arbetstemperatur",
    "arbetstemperaturerna": "arbetstemperatur",
    "arbetstemperaturernas": "arbetstemperatur",
    "arbetstemperaturers": "arbetstemperatur",
    "arbetstemperaturs": "arbetstemperatur",
    "arbetsterapeuten": "arbetsterapeut",
    "arbetsterapeutens": "arbetsterapeut",
    "arbetsterapeuter": "arbetsterapeut",
    "arbetsterapeuterna": "arbetsterapeut",
    "arbetsterapeuternas": "arbetsterapeut",
    "arbetsterapeuters": "arbetsterapeut",
    "arbetsterapeuts": "arbetsterapeut",
    "arbetsterapien": "arbetsterapi",
    "arbetsterapiens": "arbetsterapi",
    "arbetsterapin": "arbetsterapi",
    "arbetsterapins": "arbetsterapi",
    "arbetsterapis": "arbetsterapi",
    "arbetstiden": "arbetstid",
    "arbetstidens": "arbetstid",
    "arbetstider": "arbetstid",
    "arbetstiderna": "arbetstid",
    "arbetstidernas": "arbetstid",
    "arbetstiders": "arbetstid",
    "arbetstids": "arbetstid",
    "arbetstidsregeln": "arbetstidsregel",
    "arbetstidsregelns": "arbetstidsregel",
    "arbetstidsregels": "arbetstidsregel",
    "arbetstidsregler": "arbetstidsregel",
    "arbetstidsregleringar": "arbetstidsreglering",
    "arbetstidsregleringarna": "arbetstidsreglering",
    "arbetstidsregleringarnas": "arbetstidsreglering",
    "arbetstidsregleringars": "arbetstidsreglering",
    "arbetstidsregleringen": "arbetstidsreglering",
    "arbetstidsregleringens": "arbetstidsreglering",
    "arbetstidsreglerings": "arbetstidsreglering",
    "arbetstidsreglerna": "arbetstidsregel",
    "arbetstidsreglernas": "arbetstidsregel",
    "arbetstidsreglers": "arbetstidsregel",
    "arbetstillfällen": "arbetstillfälle",
    "arbetstillfällena": "arbetstillfälle",
    "arbetstillfällenas": "arbetstillfälle",
    "arbetstillfällens": "arbetstillfälle",
    "arbetstillfälles": "arbetstillfälle",
    "arbetstillfället": "arbetstillfälle",
    "arbetstillfällets": "arbetstillfälle",
    "arbetstillstånden": "arbetstillstånd",
    "arbetstillståndens": "arbetstillstånd",
    "arbetstillståndet": "arbetstillstånd",
    "arbetstillståndets": "arbetstillstånd",
    "arbetstillstånds": "arbetstillstånd",
    "arbetsträningar": "arbetsträning",
    "arbetsträningarna": "arbetsträning",
    "arbetsträningarnas": "arbetsträning",
    "arbetsträningars": "arbetsträning",
    "arbetsträningen": "arbetsträning",
    "arbetsträningens": "arbetsträning",
    "arbetstränings": "arbetsträning",
    "arbetstvisten": "arbetstvist",
    "arbetstvistens": "arbetstvist",
    "arbetstvister": "arbetstvist",
    "arbetstvisterna": "arbetstvist",
    "arbetstvisternas": "arbetstvist",
    "arbetstvisters": "arbetstvist",
    "arbetstvists": "arbetstvist",
    "arbetsuppgiften": "arbetsuppgift",
    "arbetsuppgiftens": "arbetsuppgift",
    "arbetsuppgifter": "arbetsuppgift",
    "arbetsuppgifterna": "arbetsuppgift",
    "arbetsuppgifternas": "arbetsuppgift",
    "arbetsuppgifters": "arbetsuppgift",
    "arbetsuppgifts": "arbetsuppgift",
    "arbetsutskotten": "arbetsutskott",
    "arbetsutskottens": "arbetsutskott",
    "arbetsutskottet": "arbetsutskott",
    "arbetsutskottets": "arbetsutskott",
    "arbetsutskotts": "arbetsutskott",
    "arbetsveck": "arbetsvecka",
    "arbetsveckan": "arbetsvecka",
    "arbetsveckans": "arbetsvecka",
    "arbetsveckas": "arbetsvecka",
    "arbetsvecke": "arbetsvecka",
    "arbetsvecko": "arbetsvecka",
    "arbetsveckor": "arbetsvecka",
    "arbetsveckorna": "arbetsvecka",
    "arbetsveckornas": "arbetsvecka",
    "arbetsveckors": "arbetsvecka",
    "arbetsvecks": "arbetsvecka",
    "arbetsviljan": "arbetsvilja",
    "arbetsviljans": "arbetsvilja",
    "arbetsviljas": "arbetsvilja",
    "arbetsvilje": "arbetsvilja",
    "arbetsviljor": "arbetsvilja",
    "arbetsviljorna": "arbetsvilja",
    "arbetsviljornas": "arbetsvilja",
    "arbetsviljors": "arbetsvilja",
    "arbetsvilliga": "arbetsvillig",
    "arbetsvilligare": "arbetsvillig",
    "arbetsvilligares": "arbetsvillig",
    "arbetsvilligas": "arbetsvillig",
    "arbetsvilligast": "arbetsvillig",
    "arbetsvilligaste": "arbetsvillig",
    "arbetsvilligastes": "arbetsvillig",
    "arbetsvilligasts": "arbetsvillig",
    "arbetsvillige": "arbetsvillig",
    "arbetsvilliges": "arbetsvillig",
    "arbetsvilligheten": "arbetsvillighet",
    "arbetsvillighetens": "arbetsvillighet",
    "arbetsvillighets": "arbetsvillighet",
    "arbetsvilligs": "arbetsvillig",
    "arbetsvilligt": "arbetsvillig",
    "arbetsvilligts": "arbetsvillig",
    "arbetsvillkoren": "arbetsvillkor",
    "arbetsvillkorens": "arbetsvillkor",
    "arbetsvillkoret": "arbetsvillkor",
    "arbetsvillkorets": "arbetsvillkor",
    "arbetsvillkors": "arbetsvillkor",
    "arbetsvärderingar": "arbetsvärdering",
    "arbetsvärderingarna": "arbetsvärdering",
    "arbetsvärderingarnas": "arbetsvärdering",
    "arbetsvärderingars": "arbetsvärdering",
    "arbetsvärderingen": "arbetsvärdering",
    "arbetsvärderingens": "arbetsvärdering",
    "arbetsvärderings": "arbetsvärdering",
    "arbetsvården": "arbetsvård",
    "arbetsvårdens": "arbetsvård",
    "arbetsvårds": "arbetsvård",
    "arbetsåren": "arbetsår",
    "arbetsårens": "arbetsår",
    "arbetsåret": "arbetsår",
    "arbetsårets": "arbetsår",
    "arbetsårs": "arbetsår",
    "arbitrages": "arbitrage",
    "arbitraget": "arbitrage",
    "arbitragets": "arbitrage",
    "arbiträra": "arbiträr",
    "arbiträrare": "arbiträr",
    "arbiträrares": "arbiträr",
    "arbiträras": "arbiträr",
    "arbiträrast": "arbiträr",
    "arbiträraste": "arbiträr",
    "arbiträrastes": "arbiträr",
    "arbiträrasts": "arbiträr",
    "arbiträre": "arbiträr",
    "arbiträres": "arbiträr",
    "arbiträrs": "arbiträr",
    "arbiträrt": "arbiträr",
    "arbiträrts": "arbiträr",
    "arboreta": "arboretum",
    "arboretana": "arboretum",
    "arboretanas": "arboretum",
    "arboretas": "arboretum",
    "arboretumen": "arboretum",
    "arboretumens": "arboretum",
    "arboretumet": "arboretum",
    "arboretumets": "arboretum",
    "arboretums": "arboretum",
    "arborrad": "arborra",
    "arborrade": "arborra",
    "arborrades": "arborra",
    "arborrads": "arborra",
    "arborrande": "arborra",
    "arborranden": "arborrande",
    "arborrandena": "arborrande",
    "arborrandenas": "arborrande",
    "arborrandens": "arborrande",
    "arborrandes": "arborrande",
    "arborrandet": "arborrande",
    "arborrandets": "arborrande",
    "arborrar": "arborra",
    "arborrarna": "arborr",
    "arborrarnas": "arborr",
    "arborrars": "arborr",
    "arborras": "arborra",
    "arborrat": "arborra",
    "arborrats": "arborra",
    "arborren": "arborr",
    "arborrens": "arborr",
    "arborrs": "arborr",
    "ardennern": "ardenner",
    "ardennerna": "ardenner",
    "ardennernas": "ardenner",
    "ardennerns": "ardenner",
    "ardenners": "ardenner",
    "are": "area",
    "arealen": "areal",
    "arealens": "areal",
    "arealer": "areal",
    "arealerna": "areal",
    "arealernas": "areal",
    "arealers": "areal",
    "arealmässiga": "arealmässig",
    "arealmässigare": "arealmässig",
    "arealmässigares": "arealmässig",
    "arealmässigas": "arealmässig",
    "arealmässigast": "arealmässig",
    "arealmässigaste": "arealmässig",
    "arealmässigastes": "arealmässig",
    "arealmässigasts": "arealmässig",
    "arealmässige": "arealmässig",
    "arealmässiges": "arealmässig",
    "arealmässigs": "arealmässig",
    "arealmässigt": "arealmässig",
    "arealmässigts": "arealmässig",
    "areals": "areal",
    "arean": "area",
    "areans": "area",
    "areas": "area",
    "aree": "area",
    "aren": "ar",
    "arenabyggen": "arenabygge",
    "arenabyggena": "arenabygge",
    "arenabyggenas": "arenabygge",
    "arenabyggens": "arenabygge",
    "arenabygges": "arenabygge",
    "arenabygget": "arenabygge",
    "arenabyggets": "arenabygge",
    "arenan": "arena",
    "arenans": "arena",
    "arenas": "arena",
    "arenateatern": "arenateater",
    "arenateaterns": "arenateater",
    "arenateaters": "arenateater",
    "arenateatrar": "arenateater",
    "arenateatrarna": "arenateater",
    "arenateatrarnas": "arenateater",
    "arenateatrars": "arenateater",
    "arenor": "arena",
    "arenorna": "arena",
    "arenornas": "arena",
    "arenors": "arena",
    "arens": "ar",
    "areometern": "areometer",
    "areometerns": "areometer",
    "areometers": "areometer",
    "areometrar": "areometer",
    "areometrarna": "areometer",
    "areometrarnas": "areometer",
    "areometrars": "areometer",
    "areopagen": "areopag",
    "areopagens": "areopag",
    "areopager": "areopag",
    "areopagerna": "areopag",
    "areopagernas": "areopag",
    "areopagers": "areopag",
    "areopags": "areopag",
    "areor": "area",
    "areorna": "area",
    "areornas": "area",
    "areors": "area",
    "ares": "area",
    "aret": "ar",
    "arets": "ar",
    "arga": "arg",
    "argare": "arg",
    "argares": "arg",
    "argas": "arg",
    "argast": "arg",
    "argaste": "arg",
    "argastes": "arg",
    "argasts": "arg",
    "argbigg": "argbigga",
    "argbiggan": "argbigga",
    "argbiggans": "argbigga",
    "argbiggas": "argbigga",
    "argbigge": "argbigga",
    "argbiggor": "argbigga",
    "argbiggorna": "argbigga",
    "argbiggornas": "argbigga",
    "argbiggors": "argbigga",
    "argbiggs": "argbigga",
    "arge": "arg",
    "argentinar": "argentinare",
    "argentinaren": "argentinare",
    "argentinarens": "argentinare",
    "argentinares": "argentinare",
    "argentinarna": "argentinare",
    "argentinarnas": "argentinare",
    "argentinska": "argentinsk",
    "argentinskan": "argentinska",
    "argentinskans": "argentinska",
    "argentinskare": "argentinsk",
    "argentinskares": "argentinsk",
    "argentinskas": "argentinska",
    "argentinskast": "argentinsk",
    "argentinskaste": "argentinsk",
    "argentinskastes": "argentinsk",
    "argentinskasts": "argentinsk",
    "argentinske": "argentinska",
    "argentinskes": "argentinsk",
    "argentinskor": "argentinska",
    "argentinskorna": "argentinska",
    "argentinskornas": "argentinska",
    "argentinskors": "argentinska",
    "argentinsks": "argentinsk",
    "argentinskt": "argentinsk",
    "argentinskts": "argentinsk",
    "arges": "arg",
    "argheten": "arghet",
    "arghetens": "arghet",
    "arghets": "arghet",
    "argonen": "argon",
    "argonens": "argon",
    "argonet": "argon",
    "argonets": "argon",
    "argons": "argon",
    "argoten": "argot",
    "argotens": "argot",
    "argots": "argot",
    "args": "arg",
    "argsinta": "argsint",
    "argsintare": "argsint",
    "argsintares": "argsint",
    "argsintas": "argsint",
    "argsintast": "argsint",
    "argsintaste": "argsint",
    "argsintastes": "argsint",
    "argsintasts": "argsint",
    "argsinte": "argsint",
    "argsintes": "argsint",
    "argsintheten": "argsinthet",
    "argsinthetens": "argsinthet",
    "argsinthets": "argsinthet",
    "argsints": "argsint",
    "argt": "arg",
    "argts": "arg",
    "argumentationen": "argumentation",
    "argumentationens": "argumentation",
    "argumentationer": "argumentation",
    "argumentationerna": "argumentation",
    "argumentationernas": "argumentation",
    "argumentationers": "argumentation",
    "argumentations": "argumentation",
    "argumenten": "argument",
    "argumentens": "argument",
    "argumenterad": "argumentera",
    "argumenterade": "argumentera",
    "argumenterades": "argumentera",
    "argumenterads": "argumentera",
    "argumenterande": "argumentera",
    "argumenteranden": "argumenterande",
    "argumenterandena": "argumenterande",
    "argumenterandenas": "argumenterande",
    "argumenterandens": "argumenterande",
    "argumenterandes": "argumenterande",
    "argumenterandet": "argumenterande",
    "argumenterandets": "argumenterande",
    "argumenterar": "argumentera",
    "argumenteras": "argumentera",
    "argumenterat": "argumentera",
    "argumenterats": "argumentera",
    "argumenterbara": "argumenterbar",
    "argumenterbarare": "argumenterbar",
    "argumenterbarares": "argumenterbar",
    "argumenterbaras": "argumenterbar",
    "argumenterbarast": "argumenterbar",
    "argumenterbaraste": "argumenterbar",
    "argumenterbarastes": "argumenterbar",
    "argumenterbarasts": "argumenterbar",
    "argumenterbare": "argumenterbar",
    "argumenterbares": "argumenterbar",
    "argumenterbarheten": "argumenterbarhet",
    "argumenterbarhetens": "argumenterbarhet",
    "argumenterbarhets": "argumenterbarhet",
    "argumenterbars": "argumenterbar",
    "argumenterbart": "argumenterbar",
    "argumenterbarts": "argumenterbar",
    "argumenteringar": "argumentering",
    "argumenteringarna": "argumentering",
    "argumenteringarnas": "argumentering",
    "argumenteringars": "argumentering",
    "argumenteringen": "argumentering",
    "argumenteringens": "argumentering",
    "argumenterings": "argumentering",
    "argumentet": "argument",
    "argumentets": "argument",
    "arguments": "argument",
    "argusögas": "argusöga",
    "argusögat": "argusöga",
    "argusögats": "argusöga",
    "argusögon": "argusöga",
    "argusögonen": "argusöga",
    "argusögonens": "argusöga",
    "argusögons": "argusöga",
    "ari": "aria",
    "ariadnetrådar": "ariadnetråd",
    "ariadnetrådarna": "ariadnetråd",
    "ariadnetrådarnas": "ariadnetråd",
    "ariadnetrådars": "ariadnetråd",
    "ariadnetråden": "ariadnetråd",
    "ariadnetrådens": "ariadnetråd",
    "ariadnetråds": "ariadnetråd",
    "arian": "aria",
    "arianen": "arian",
    "arianens": "arian",
    "arianer": "arian",
    "arianerna": "arian",
    "arianernas": "arian",
    "arianers": "arian",
    "arianismen": "arianism",
    "arianismens": "arianism",
    "arianismer": "arianism",
    "arianismerna": "arianism",
    "arianismernas": "arianism",
    "arianismers": "arianism",
    "arianisms": "arianism",
    "arians": "arian",
    "arianska": "ariansk",
    "arianskare": "ariansk",
    "arianskares": "ariansk",
    "arianskas": "ariansk",
    "arianskast": "ariansk",
    "arianskaste": "ariansk",
    "arianskastes": "ariansk",
    "arianskasts": "ariansk",
    "arianske": "ariansk",
    "arianskes": "ariansk",
    "ariansks": "ariansk",
    "arianskt": "ariansk",
    "arianskts": "ariansk",
    "arias": "aria",
    "arida": "arid",
    "aridare": "arid",
    "aridares": "arid",
    "aridas": "arid",
    "aridast": "arid",
    "aridaste": "arid",
    "aridastes": "arid",
    "aridasts": "arid",
    "aride": "arid",
    "arides": "arid",
    "arids": "arid",
    "arie": "aria",
    "ariern": "arier",
    "arierna": "arier",
    "ariernas": "arier",
    "arierns": "arier",
    "ariers": "arier",
    "arior": "aria",
    "ariorna": "aria",
    "ariornas": "aria",
    "ariors": "aria",
    "arioson": "arioso",
    "ariosona": "arioso",
    "ariosonas": "arioso",
    "ariosons": "arioso",
    "ariosos": "arioso",
    "ariosot": "arioso",
    "ariosots": "arioso",
    "aris": "aria",
    "ariska": "arisk",
    "ariskare": "arisk",
    "ariskares": "arisk",
    "ariskas": "arisk",
    "ariskast": "arisk",
    "ariskaste": "arisk",
    "ariskastes": "arisk",
    "ariskasts": "arisk",
    "ariske": "arisk",
    "ariskes": "arisk",
    "arisks": "arisk",
    "ariskt": "arisk",
    "ariskts": "arisk",
    "aristokraten": "aristokrat",
    "aristokratens": "aristokrat",
    "aristokrater": "aristokrat",
    "aristokraterna": "aristokrat",
    "aristokraternas": "aristokrat",
    "aristokraters": "aristokrat",
    "aristokratien": "aristokrati",
    "aristokratiens": "aristokrati",
    "aristokratier": "aristokrati",
    "aristokratierna": "aristokrati",
    "aristokratiernas": "aristokrati",
    "aristokratiers": "aristokrati",
    "aristokratin": "aristokrati",
    "aristokratins": "aristokrati",
    "aristokratis": "aristokrati",
    "aristokratiska": "aristokratisk",
    "aristokratiskare": "aristokratisk",
    "aristokratiskares": "aristokratisk",
    "aristokratiskas": "aristokratisk",
    "aristokratiskast": "aristokratisk",
    "aristokratiskaste": "aristokratisk",
    "aristokratiskastes": "aristokratisk",
    "aristokratiskasts": "aristokratisk",
    "aristokratiske": "aristokratisk",
    "aristokratiskes": "aristokratisk",
    "aristokratisks": "aristokratisk",
    "aristokratiskt": "aristokratisk",
    "aristokratiskts": "aristokratisk",
    "aristokrats": "aristokrat",
    "aritmetiken": "aritmetik",
    "aritmetikens": "aritmetik",
    "aritmetiks": "aritmetik",
    "aritmetiska": "aritmetisk",
    "aritmetiskare": "aritmetisk",
    "aritmetiskares": "aritmetisk",
    "aritmetiskas": "aritmetisk",
    "aritmetiskast": "aritmetisk",
    "aritmetiskaste": "aritmetisk",
    "aritmetiskastes": "aritmetisk",
    "aritmetiskasts": "aritmetisk",
    "aritmetiske": "aritmetisk",
    "aritmetiskes": "aritmetisk",
    "aritmetisks": "aritmetisk",
    "aritmetiskt": "aritmetisk",
    "aritmetiskts": "aritmetisk",
    "arkaden": "arkad",
    "arkadens": "arkad",
    "arkader": "arkad",
    "arkaderna": "arkad",
    "arkadernas": "arkad",
    "arkaders": "arkad",
    "arkadiska": "arkadisk",
    "arkadiskare": "arkadisk",
    "arkadiskares": "arkadisk",
    "arkadiskas": "arkadisk",
    "arkadiskast": "arkadisk",
    "arkadiskaste": "arkadisk",
    "arkadiskastes": "arkadisk",
    "arkadiskasts": "arkadisk",
    "arkadiske": "arkadisk",
    "arkadiskes": "arkadisk",
    "arkadisks": "arkadisk",
    "arkadiskt": "arkadisk",
    "arkadiskts": "arkadisk",
    "arkads": "arkad",
    "arkadspelen": "arkadspel",
    "arkadspelens": "arkadspel",
    "arkadspelet": "arkadspel",
    "arkadspelets": "arkadspel",
    "arkadspels": "arkadspel",
    "arkaiserad": "arkaisera",
    "arkaiserade": "arkaisera",
    "arkaiserades": "arkaisera",
    "arkaiserads": "arkaisera",
    "arkaiserande": "arkaisera",
    "arkaiseranden": "arkaiserande",
    "arkaiserandena": "arkaiserande",
    "arkaiserandenas": "arkaiserande",
    "arkaiserandens": "arkaiserande",
    "arkaiserandes": "arkaiserande",
    "arkaiserandet": "arkaiserande",
    "arkaiserandets": "arkaiserande",
    "arkaiserar": "arkaisera",
    "arkaiseras": "arkaisera",
    "arkaiserat": "arkaisera",
    "arkaiserats": "arkaisera",
    "arkaiserbara": "arkaiserbar",
    "arkaiserbarare": "arkaiserbar",
    "arkaiserbarares": "arkaiserbar",
    "arkaiserbaras": "arkaiserbar",
    "arkaiserbarast": "arkaiserbar",
    "arkaiserbaraste": "arkaiserbar",
    "arkaiserbarastes": "arkaiserbar",
    "arkaiserbarasts": "arkaiserbar",
    "arkaiserbare": "arkaiserbar",
    "arkaiserbares": "arkaiserbar",
    "arkaiserbarheten": "arkaiserbarhet",
    "arkaiserbarhetens": "arkaiserbarhet",
    "arkaiserbarhets": "arkaiserbarhet",
    "arkaiserbars": "arkaiserbar",
    "arkaiserbart": "arkaiserbar",
    "arkaiserbarts": "arkaiserbar",
    "arkaiseringar": "arkaisering",
    "arkaiseringarna": "arkaisering",
    "arkaiseringarnas": "arkaisering",
    "arkaiseringars": "arkaisering",
    "arkaiseringen": "arkaisering",
    "arkaiseringens": "arkaisering",
    "arkaiserings": "arkaisering",
    "arkaiska": "arkaisk",
    "arkaiskare": "arkaisk",
    "arkaiskares": "arkaisk",
    "arkaiskas": "arkaisk",
    "arkaiskast": "arkaisk",
    "arkaiskaste": "arkaisk",
    "arkaiskastes": "arkaisk",
    "arkaiskasts": "arkaisk",
    "arkaiske": "arkaisk",
    "arkaiskes": "arkaisk",
    "arkaisks": "arkaisk",
    "arkaiskt": "arkaisk",
    "arkaiskts": "arkaisk",
    "arkaismen": "arkaism",
    "arkaismens": "arkaism",
    "arkaismer": "arkaism",
    "arkaismerna": "arkaism",
    "arkaismernas": "arkaism",
    "arkaismers": "arkaism",
    "arkaisms": "arkaism",
    "arkaistiska": "arkaistisk",
    "arkaistiskare": "arkaistisk",
    "arkaistiskares": "arkaistisk",
    "arkaistiskas": "arkaistisk",
    "arkaistiskast": "arkaistisk",
    "arkaistiskaste": "arkaistisk",
    "arkaistiskastes": "arkaistisk",
    "arkaistiskasts": "arkaistisk",
    "arkaistiske": "arkaistisk",
    "arkaistiskes": "arkaistisk",
    "arkaistisks": "arkaistisk",
    "arkaistiskt": "arkaistisk",
    "arkaistiskts": "arkaistisk",
    "arkebuserad": "arkebusera",
    "arkebuserade": "arkebusera",
    "arkebuserades": "arkebusera",
    "arkebuserads": "arkebusera",
    "arkebuserande": "arkebusera",
    "arkebuseranden": "arkebuserande",
    "arkebuserandena": "arkebuserande",
    "arkebuserandenas": "arkebuserande",
    "arkebuserandens": "arkebuserande",
    "arkebuserandes": "arkebuserande",
    "arkebuserandet": "arkebuserande",
    "arkebuserandets": "arkebuserande",
    "arkebuserar": "arkebusera",
    "arkebuseras": "arkebusera",
    "arkebuserat": "arkebusera",
    "arkebuserats": "arkebusera",
    "arkebuserbara": "arkebuserbar",
    "arkebuserbarare": "arkebuserbar",
    "arkebuserbarares": "arkebuserbar",
    "arkebuserbaras": "arkebuserbar",
    "arkebuserbarast": "arkebuserbar",
    "arkebuserbaraste": "arkebuserbar",
    "arkebuserbarastes": "arkebuserbar",
    "arkebuserbarasts": "arkebuserbar",
    "arkebuserbare": "arkebuserbar",
    "arkebuserbares": "arkebuserbar",
    "arkebuserbarheten": "arkebuserbarhet",
    "arkebuserbarhetens": "arkebuserbarhet",
    "arkebuserbarhets": "arkebuserbarhet",
    "arkebuserbars": "arkebuserbar",
    "arkebuserbart": "arkebuserbar",
    "arkebuserbarts": "arkebuserbar",
    "arkebuseringar": "arkebusering",
    "arkebuseringarna": "arkebusering",
    "arkebuseringarnas": "arkebusering",
    "arkebuseringars": "arkebusering",
    "arkebuseringen": "arkebusering",
    "arkebuseringens": "arkebusering",
    "arkebuserings": "arkebusering",
    "arkeikums": "arkeikum",
    "arken": "ark",
    "arkens": "ark",
    "arkeologen": "arkeolog",
    "arkeologens": "arkeolog",
    "arkeologer": "arkeolog",
    "arkeologerna": "arkeolog",
    "arkeologernas": "arkeolog",
    "arkeologers": "arkeolog",
    "arkeologien": "arkeologi",
    "arkeologiens": "arkeologi",
    "arkeologin": "arkeologi",
    "arkeologins": "arkeologi",
    "arkeologis": "arkeologi",
    "arkeologiska": "arkeologisk",
    "arkeologiskare": "arkeologisk",
    "arkeologiskares": "arkeologisk",
    "arkeologiskas": "arkeologisk",
    "arkeologiskast": "arkeologisk",
    "arkeologiskaste": "arkeologisk",
    "arkeologiskastes": "arkeologisk",
    "arkeologiskasts": "arkeologisk",
    "arkeologiske": "arkeologisk",
    "arkeologiskes": "arkeologisk",
    "arkeologisks": "arkeologisk",
    "arkeologiskt": "arkeologisk",
    "arkeologiskts": "arkeologisk",
    "arkeologs": "arkeolog",
    "arket": "ark",
    "arkets": "ark",
    "arketypen": "arketyp",
    "arketypens": "arketyp",
    "arketyper": "arketyp",
    "arketyperna": "arketyp",
    "arketypernas": "arketyp",
    "arketypers": "arketyp",
    "arketypiska": "arketypisk",
    "arketypiskare": "arketypisk",
    "arketypiskares": "arketypisk",
    "arketypiskas": "arketypisk",
    "arketypiskast": "arketypisk",
    "arketypiskaste": "arketypisk",
    "arketypiskastes": "arketypisk",
    "arketypiskasts": "arketypisk",
    "arketypiske": "arketypisk",
    "arketypiskes": "arketypisk",
    "arketypisks": "arketypisk",
    "arketypiskt": "arketypisk",
    "arketypiskts": "arketypisk",
    "arketyps": "arketyp",
    "arkiatern": "arkiater",
    "arkiaterns": "arkiater",
    "arkiaters": "arkiater",
    "arkiatrer": "arkiater",
    "arkiatrerna": "arkiater",
    "arkiatrernas": "arkiater",
    "arkiatrers": "arkiater",
    "arkipelagen": "arkipelag",
    "arkipelagens": "arkipelag",
    "arkipelager": "arkipelag",
    "arkipelagerna": "arkipelag",
    "arkipelagernas": "arkipelag",
    "arkipelagers": "arkipelag",
    "arkipelags": "arkipelag",
    "arkitekten": "arkitekt",
    "arkitektens": "arkitekt",
    "arkitekter": "arkitekt",
    "arkitekterna": "arkitekt",
    "arkitekternas": "arkitekt",
    "arkitekters": "arkitekt",
    "arkitektoniken": "arkitektonik",
    "arkitektonikens": "arkitektonik",
    "arkitektoniks": "arkitektonik",
    "arkitektoniska": "arkitektonisk",
    "arkitektoniskare": "arkitektonisk",
    "arkitektoniskares": "arkitektonisk",
    "arkitektoniskas": "arkitektonisk",
    "arkitektoniskast": "arkitektonisk",
    "arkitektoniskaste": "arkitektonisk",
    "arkitektoniskastes": "arkitektonisk",
    "arkitektoniskasts": "arkitektonisk",
    "arkitektoniske": "arkitektonisk",
    "arkitektoniskes": "arkitektonisk",
    "arkitektonisks": "arkitektonisk",
    "arkitektoniskt": "arkitektonisk",
    "arkitektoniskts": "arkitektonisk",
    "arkitekts": "arkitekt",
    "arkitekturen": "arkitektur",
    "arkitekturens": "arkitektur",
    "arkitekturer": "arkitektur",
    "arkitekturerna": "arkitektur",
    "arkitekturernas": "arkitektur",
    "arkitekturers": "arkitektur",
    "arkitekturpolitiken": "arkitekturpolitik",
    "arkitekturpolitikens": "arkitekturpolitik",
    "arkitekturpolitiks": "arkitekturpolitik",
    "arkitekturpolitiska": "arkitekturpolitisk",
    "arkitekturpolitiskas": "arkitekturpolitisk",
    "arkitekturpolitiske": "arkitekturpolitisk",
    "arkitekturpolitiskes": "arkitekturpolitisk",
    "arkitekturpolitisks": "arkitekturpolitisk",
    "arkitekturpolitiskt": "arkitekturpolitisk",
    "arkitekturpolitiskts": "arkitekturpolitisk",
    "arkitekturs": "arkitektur",
    "arkitraven": "arkitrav",
    "arkitravens": "arkitrav",
    "arkitraver": "arkitrav",
    "arkitraverna": "arkitrav",
    "arkitravernas": "arkitrav",
    "arkitravers": "arkitrav",
    "arkitravs": "arkitrav",
    "arkivalie": "arkivalier",
    "arkivalierna": "arkivalier",
    "arkivaliernas": "arkivalier",
    "arkivaliers": "arkivalier",
    "arkivaliska": "arkivalisk",
    "arkivaliskare": "arkivalisk",
    "arkivaliskares": "arkivalisk",
    "arkivaliskas": "arkivalisk",
    "arkivaliskast": "arkivalisk",
    "arkivaliskaste": "arkivalisk",
    "arkivaliskastes": "arkivalisk",
    "arkivaliskasts": "arkivalisk",
    "arkivaliske": "arkivalisk",
    "arkivaliskes": "arkivalisk",
    "arkivalisks": "arkivalisk",
    "arkivaliskt": "arkivalisk",
    "arkivaliskts": "arkivalisk",
    "arkivarbetar": "arkivarbetare",
    "arkivarbetaren": "arkivarbetare",
    "arkivarbetarens": "arkivarbetare",
    "arkivarbetares": "arkivarbetare",
    "arkivarbetarna": "arkivarbetare",
    "arkivarbetarnas": "arkivarbetare",
    "arkivarbeten": "arkivarbete",
    "arkivarbetena": "arkivarbete",
    "arkivarbetenas": "arkivarbete",
    "arkivarbetens": "arkivarbete",
    "arkivarbetes": "arkivarbete",
    "arkivarbetet": "arkivarbete",
    "arkivarbetets": "arkivarbete",
    "arkivarbets": "arkivarbete",
    "arkivarien": "arkivarie",
    "arkivariens": "arkivarie",
    "arkivarier": "arkivarie",
    "arkivarierna": "arkivarie",
    "arkivariernas": "arkivarie",
    "arkivariers": "arkivarie",
    "arkivaries": "arkivarie",
    "arkiven": "arkiv",
    "arkivens": "arkiv",
    "arkiverad": "arkivera",
    "arkiverade": "arkivera",
    "arkiverades": "arkivera",
    "arkiverads": "arkivera",
    "arkiverande": "arkivera",
    "arkiveranden": "arkiverande",
    "arkiverandena": "arkiverande",
    "arkiverandenas": "arkiverande",
    "arkiverandens": "arkiverande",
    "arkiverandes": "arkiverande",
    "arkiverandet": "arkiverande",
    "arkiverandets": "arkiverande",
    "arkiverar": "arkivera",
    "arkiveras": "arkivera",
    "arkiverat": "arkivera",
    "arkiverats": "arkivera",
    "arkiverbara": "arkiverbar",
    "arkiverbarare": "arkiverbar",
    "arkiverbarares": "arkiverbar",
    "arkiverbaras": "arkiverbar",
    "arkiverbarast": "arkiverbar",
    "arkiverbaraste": "arkiverbar",
    "arkiverbarastes": "arkiverbar",
    "arkiverbarasts": "arkiverbar",
    "arkiverbare": "arkiverbar",
    "arkiverbares": "arkiverbar",
    "arkiverbarheten": "arkiverbarhet",
    "arkiverbarhetens": "arkiverbarhet",
    "arkiverbarhets": "arkiverbarhet",
    "arkiverbars": "arkiverbar",
    "arkiverbart": "arkiverbar",
    "arkiverbarts": "arkiverbar",
    "arkiveringar": "arkivering",
    "arkiveringarna": "arkivering",
    "arkiveringarnas": "arkivering",
    "arkiveringars": "arkivering",
    "arkiveringen": "arkivering",
    "arkiveringens": "arkivering",
    "arkiverings": "arkivering",
    "arkivet": "arkiv",
    "arkivets": "arkiv",
    "arkivexemplaren": "arkivexemplar",
    "arkivexemplarens": "arkivexemplar",
    "arkivexemplaret": "arkivexemplar",
    "arkivexemplarets": "arkivexemplar",
    "arkivexemplars": "arkivexemplar",
    "arkivs": "arkiv",
    "arkivsamlingar": "arkivsamling",
    "arkivsamlingarna": "arkivsamling",
    "arkivsamlingarnas": "arkivsamling",
    "arkivsamlingars": "arkivsamling",
    "arkivsamlingen": "arkivsamling",
    "arkivsamlingens": "arkivsamling",
    "arkivsamlings": "arkivsamling",
    "arks": "ark",
    "arksignaturen": "arksignatur",
    "arksignaturens": "arksignatur",
    "arksignaturer": "arksignatur",
    "arksignaturerna": "arksignatur",
    "arksignaturernas": "arksignatur",
    "arksignaturers": "arksignatur",
    "arksignaturs": "arksignatur",
    "arktiska": "arktisk",
    "arktiskare": "arktisk",
    "arktiskares": "arktisk",
    "arktiskas": "arktisk",
    "arktiskast": "arktisk",
    "arktiskaste": "arktisk",
    "arktiskastes": "arktisk",
    "arktiskasts": "arktisk",
    "arktiske": "arktisk",
    "arktiskes": "arktisk",
    "arktisks": "arktisk",
    "arktiskt": "arktisk",
    "arktiskts": "arktisk",
    "arma": "arm",
    "armad": "armada",
    "armadan": "armada",
    "armadans": "armada",
    "armadas": "armada",
    "armade": "armada",
    "armades": "armad",
    "armador": "armada",
    "armadorna": "armada",
    "armadornas": "armada",
    "armadors": "armada",
    "armads": "armada",
    "armagnacen": "armagnac",
    "armagnacens": "armagnac",
    "armagnacs": "armagnac",
    "armar": "arm",
    "armare": "arm",
    "armares": "arm",
    "armarna": "arm",
    "armarnas": "arm",
    "armars": "arm",
    "armas": "arm",
    "armast": "arm",
    "armaste": "arm",
    "armastes": "arm",
    "armasts": "arm",
    "armat": "armad",
    "armats": "armad",
    "armaturen": "armatur",
    "armaturens": "armatur",
    "armaturer": "armatur",
    "armaturerna": "armatur",
    "armaturernas": "armatur",
    "armaturers": "armatur",
    "armaturs": "armatur",
    "armbanden": "armband",
    "armbandens": "armband",
    "armbandet": "armband",
    "armbandets": "armband",
    "armbands": "armband",
    "armbandsuren": "armbandsur",
    "armbandsurens": "armbandsur",
    "armbandsuret": "armbandsur",
    "armbandsurets": "armbandsur",
    "armbandsurs": "armbandsur",
    "armbindeln": "armbindel",
    "armbindelns": "armbindel",
    "armbindels": "armbindel",
    "armbindlar": "armbindel",
    "armbindlarna": "armbindel",
    "armbindlarnas": "armbindel",
    "armbindlars": "armbindel",
    "armborsten": "armborst",
    "armborstens": "armborst",
    "armborstet": "armborst",
    "armborstets": "armborst",
    "armborstpilar": "armborstpil",
    "armborstpilarna": "armborstpil",
    "armborstpilarnas": "armborstpil",
    "armborstpilars": "armborstpil",
    "armborstpilen": "armborstpil",
    "armborstpilens": "armborstpil",
    "armborstpils": "armborstpil",
    "armborsts": "armborst",
    "armbrotten": "armbrott",
    "armbrottens": "armbrott",
    "armbrottet": "armbrott",
    "armbrottets": "armbrott",
    "armbrotts": "armbrott",
    "armbrytningar": "armbrytning",
    "armbrytningarna": "armbrytning",
    "armbrytningarnas": "armbrytning",
    "armbrytningars": "armbrytning",
    "armbrytningen": "armbrytning",
    "armbrytningens": "armbrytning",
    "armbrytnings": "armbrytning",
    "armbåg": "armbåge",
    "armbågar": "armbåge",
    "armbågarna": "armbåge",
    "armbågarnas": "armbåge",
    "armbågars": "armbåge",
    "armbågen": "armbåge",
    "armbågens": "armbåge",
    "armbåges": "armbåge",
    "armbågs": "armbåge",
    "armbågsbenen": "armbågsben",
    "armbågsbenens": "armbågsben",
    "armbågsbenet": "armbågsben",
    "armbågsbenets": "armbågsben",
    "armbågsbens": "armbågsben",
    "armbågsleden": "armbågsled",
    "armbågsledens": "armbågsled",
    "armbågsleder": "armbågsled",
    "armbågslederna": "armbågsled",
    "armbågsledernas": "armbågsled",
    "armbågsleders": "armbågsled",
    "armbågsleds": "armbågsled",
    "armbågsnerven": "armbågsnerv",
    "armbågsnervens": "armbågsnerv",
    "armbågsnerver": "armbågsnerv",
    "armbågsnerverna": "armbågsnerv",
    "armbågsnervernas": "armbågsnerv",
    "armbågsnervers": "armbågsnerv",
    "armbågsnervs": "armbågsnerv",
    "armbågsrummet": "armbågsrum",
    "armbågsrummets": "armbågsrum",
    "armbågsrums": "armbågsrum",
    "armböjningar": "armböjning",
    "armböjningarna": "armböjning",
    "armböjningarnas": "armböjning",
    "armböjningars": "armböjning",
    "armböjningen": "armböjning",
    "armböjningens": "armböjning",
    "armböjnings": "armböjning",
    "arme": "arm",
    "armen": "arm",
    "armeniern": "armenier",
    "armenierna": "armenier",
    "armeniernas": "armenier",
    "armenierns": "armenier",
    "armeniers": "armenier",
    "armenisk": "armeniska",
    "armeniska": "armenisk",
    "armeniskan": "armeniska",
    "armeniskans": "armeniska",
    "armeniskare": "armenisk",
    "armeniskares": "armenisk",
    "armeniskas": "armeniska",
    "armeniskast": "armenisk",
    "armeniskaste": "armenisk",
    "armeniskastes": "armenisk",
    "armeniskasts": "armenisk",
    "armeniske": "armeniska",
    "armeniskes": "armenisk",
    "armeniskor": "armeniska",
    "armeniskorna": "armeniska",
    "armeniskornas": "armeniska",
    "armeniskors": "armeniska",
    "armenisks": "armenisk",
    "armeniskt": "armenisk",
    "armeniskts": "armenisk",
    "armens": "arm",
    "armerad": "armera",
    "armerade": "armera",
    "armerades": "armera",
    "armerads": "armera",
    "armerande": "armera",
    "armeranden": "armerande",
    "armerandena": "armerande",
    "armerandenas": "armerande",
    "armerandens": "armerande",
    "armerandes": "armerande",
    "armerandet": "armerande",
    "armerandets": "armerande",
    "armerar": "armera",
    "armeras": "armera",
    "armerat": "armera",
    "armerats": "armera",
    "armerbara": "armerbar",
    "armerbarare": "armerbar",
    "armerbarares": "armerbar",
    "armerbaras": "armerbar",
    "armerbarast": "armerbar",
    "armerbaraste": "armerbar",
    "armerbarastes": "armerbar",
    "armerbarasts": "armerbar",
    "armerbare": "armerbar",
    "armerbares": "armerbar",
    "armerbarheten": "armerbarhet",
    "armerbarhetens": "armerbarhet",
    "armerbarhets": "armerbarhet",
    "armerbars": "armerbar",
    "armerbart": "armerbar",
    "armerbarts": "armerbar",
    "armeringar": "armering",
    "armeringarna": "armering",
    "armeringarnas": "armering",
    "armeringars": "armering",
    "armeringen": "armering",
    "armeringens": "armering",
    "armerings": "armering",
    "armeringsjärnen": "armeringsjärn",
    "armeringsjärnens": "armeringsjärn",
    "armeringsjärnet": "armeringsjärn",
    "armeringsjärnets": "armeringsjärn",
    "armeringsjärns": "armeringsjärn",
    "armes": "arm",
    "armfotingar": "armfoting",
    "armfotingarna": "armfoting",
    "armfotingarnas": "armfoting",
    "armfotingars": "armfoting",
    "armfotingen": "armfoting",
    "armfotingens": "armfoting",
    "armfotings": "armfoting",
    "armföringar": "armföring",
    "armföringarna": "armföring",
    "armföringarnas": "armföring",
    "armföringars": "armföring",
    "armföringen": "armföring",
    "armföringens": "armföring",
    "armförings": "armföring",
    "armgången": "armgång",
    "armgångens": "armgång",
    "armgångs": "armgång",
    "armheten": "armhet",
    "armhetens": "armhet",
    "armhets": "armhet",
    "armhävningar": "armhävning",
    "armhävningarna": "armhävning",
    "armhävningarnas": "armhävning",
    "armhävningars": "armhävning",
    "armhävningen": "armhävning",
    "armhävningens": "armhävning",
    "armhävnings": "armhävning",
    "armhål": "armhåla",
    "armhålan": "armhåla",
    "armhålans": "armhåla",
    "armhålas": "armhåla",
    "armhåle": "armhåla",
    "armhålor": "armhåla",
    "armhålorna": "armhåla",
    "armhålornas": "armhåla",
    "armhålors": "armhåla",
    "armhåls": "armhåla",
    "armkrokar": "armkrok",
    "armkrokarna": "armkrok",
    "armkrokarnas": "armkrok",
    "armkrokars": "armkrok",
    "armkroken": "armkrok",
    "armkrokens": "armkrok",
    "armkroks": "armkrok",
    "armleden": "armled",
    "armledens": "armled",
    "armleder": "armled",
    "armlederna": "armled",
    "armledernas": "armled",
    "armleders": "armled",
    "armleds": "armled",
    "armlängden": "armlängd",
    "armlängdens": "armlängd",
    "armlängder": "armlängd",
    "armlängderna": "armlängd",
    "armlängdernas": "armlängd",
    "armlängders": "armlängd",
    "armlängds": "armlängd",
    "armmuskeln": "armmuskel",
    "armmuskelns": "armmuskel",
    "armmuskels": "armmuskel",
    "armmuskler": "armmuskel",
    "armmusklerna": "armmuskel",
    "armmusklernas": "armmuskel",
    "armmusklers": "armmuskel",
    "armodet": "armod",
    "armodets": "armod",
    "armods": "armod",
    "armpolypen": "armpolyp",
    "armpolypens": "armpolyp",
    "armpolyper": "armpolyp",
    "armpolyperna": "armpolyp",
    "armpolypernas": "armpolyp",
    "armpolypers": "armpolyp",
    "armpolyps": "armpolyp",
    "arms": "arm",
    "armskadan": "armskada",
    "armskadans": "armskada",
    "armskadas": "armskada",
    "armskade": "armskada",
    "armskador": "armskada",
    "armskadorna": "armskada",
    "armskadornas": "armskada",
    "armskadors": "armskada",
    "armslängden": "armslängd",
    "armslängdens": "armslängd",
    "armslängder": "armslängd",
    "armslängderna": "armslängd",
    "armslängdernas": "armslängd",
    "armslängders": "armslängd",
    "armslängds": "armslängd",
    "armstumpar": "armstump",
    "armstumparna": "armstump",
    "armstumparnas": "armstump",
    "armstumpars": "armstump",
    "armstumpen": "armstump",
    "armstumpens": "armstump",
    "armstumps": "armstump",
    "armstyrkan": "armstyrka",
    "armstyrkans": "armstyrka",
    "armstyrkas": "armstyrka",
    "armstyrke": "armstyrka",
    "armstyrkor": "armstyrka",
    "armstyrkorna": "armstyrka",
    "armstyrkornas": "armstyrka",
    "armstyrkors": "armstyrka",
    "armstöden": "armstöd",
    "armstödens": "armstöd",
    "armstödet": "armstöd",
    "armstödets": "armstöd",
    "armstöds": "armstöd",
    "armsvetten": "armsvett",
    "armsvettens": "armsvett",
    "armsvetts": "armsvett",
    "armt": "arm",
    "armtrakten": "armtrakt",
    "armtraktens": "armtrakt",
    "armtrakter": "armtrakt",
    "armtrakterna": "armtrakt",
    "armtrakternas": "armtrakt",
    "armtrakters": "armtrakt",
    "armtrakts": "armtrakt",
    "armts": "arm",
    "armvecken": "armveck",
    "armveckens": "armveck",
    "armvecket": "armveck",
    "armveckets": "armveck",
    "armvecks": "armveck",
    "arméattachéer": "arméattaché",
    "arméattachéerna": "arméattaché",
    "arméattachéernas": "arméattaché",
    "arméattachéers": "arméattaché",
    "arméattachén": "arméattaché",
    "arméattachéns": "arméattaché",
    "arméattachés": "arméattaché",
    "arméchefen": "arméchef",
    "arméchefens": "arméchef",
    "arméchefer": "arméchef",
    "armécheferna": "arméchef",
    "arméchefernas": "arméchef",
    "arméchefers": "arméchef",
    "arméchefs": "arméchef",
    "arméer": "armé",
    "arméerna": "armé",
    "arméernas": "armé",
    "arméers": "armé",
    "arméförbanden": "arméförband",
    "arméförbandens": "arméförband",
    "arméförbandet": "arméförband",
    "arméförbandets": "arméförband",
    "arméförbands": "arméförband",
    "armégeneralen": "armégeneral",
    "armégeneralens": "armégeneral",
    "armégeneraler": "armégeneral",
    "armégeneralerna": "armégeneral",
    "armégeneralernas": "armégeneral",
    "armégeneralers": "armégeneral",
    "armégenerals": "armégeneral",
    "armégevären": "armégevär",
    "armégevärens": "armégevär",
    "armégeväret": "armégevär",
    "armégevärets": "armégevär",
    "armégevärs": "armégevär",
    "arméhelikoptern": "arméhelikopter",
    "arméhelikopterns": "arméhelikopter",
    "arméhelikopters": "arméhelikopter",
    "arméhelikoptrar": "arméhelikopter",
    "arméhelikoptrarna": "arméhelikopter",
    "arméhelikoptrarnas": "arméhelikopter",
    "arméhelikoptrars": "arméhelikopter",
    "arméhästar": "arméhäst",
    "arméhästarna": "arméhäst",
    "arméhästarnas": "arméhäst",
    "arméhästars": "arméhäst",
    "arméhästen": "arméhäst",
    "arméhästens": "arméhäst",
    "arméhästs": "arméhäst",
    "armékåren": "armékår",
    "armékårens": "armékår",
    "armékårer": "armékår",
    "armékårerna": "armékår",
    "armékårernas": "armékår",
    "armékårers": "armékår",
    "armékårs": "armékår",
    "armén": "armé",
    "arméns": "armé",
    "armés": "armé",
    "arméunderstödet": "arméunderstöd",
    "arméunderstödets": "arméunderstöd",
    "arméunderstöds": "arméunderstöd",
    "aromatiska": "aromatisk",
    "aromatiskare": "aromatisk",
    "aromatiskares": "aromatisk",
    "aromatiskas": "aromatisk",
    "aromatiskast": "aromatisk",
    "aromatiskaste": "aromatisk",
    "aromatiskastes": "aromatisk",
    "aromatiskasts": "aromatisk",
    "aromatiske": "aromatisk",
    "aromatiskes": "aromatisk",
    "aromatisks": "aromatisk",
    "aromatiskt": "aromatisk",
    "aromatiskts": "aromatisk",
    "aromen": "arom",
    "aromens": "arom",
    "aromer": "arom",
    "aromerna": "arom",
    "aromernas": "arom",
    "aromers": "arom",
    "aromglasen": "aromglas",
    "aromglasens": "aromglas",
    "aromglaset": "aromglas",
    "aromglasets": "aromglas",
    "aromkup": "aromkupa",
    "aromkupan": "aromkupa",
    "aromkupans": "aromkupa",
    "aromkupas": "aromkupa",
    "aromkupe": "aromkupa",
    "aromkupor": "aromkupa",
    "aromkuporna": "aromkupa",
    "aromkupornas": "aromkupa",
    "aromkupors": "aromkupa",
    "aromkups": "aromkupa",
    "aroms": "arom",
    "aror": "ara",
    "arorna": "ara",
    "arornas": "ara",
    "arors": "ara",
    "arpeggion": "arpeggio",
    "arpeggiona": "arpeggio",
    "arpeggionas": "arpeggio",
    "arpeggions": "arpeggio",
    "arpeggios": "arpeggio",
    "arpeggiot": "arpeggio",
    "arpeggiots": "arpeggio",
    "arrad": "arra",
    "arrade": "arra",
    "arrades": "arra",
    "arrads": "arra",
    "arraken": "arrak",
    "arrakens": "arrak",
    "arrakpunchen": "arrakpunch",
    "arrakpunchens": "arrakpunch",
    "arrakpunchs": "arrakpunch",
    "arrakpunschen": "arrakpunsch",
    "arrakpunschens": "arrakpunsch",
    "arrakpunschs": "arrakpunsch",
    "arraks": "arrak",
    "arrande": "arra",
    "arrandes": "arra",
    "arrangemangen": "arrangemang",
    "arrangemangens": "arrangemang",
    "arrangemanget": "arrangemang",
    "arrangemangets": "arrangemang",
    "arrangemangs": "arrangemang",
    "arrangemangsmässiga": "arrangemangsmässig",
    "arrangemangsmässigare": "arrangemangsmässig",
    "arrangemangsmässigares": "arrangemangsmässig",
    "arrangemangsmässigas": "arrangemangsmässig",
    "arrangemangsmässigast": "arrangemangsmässig",
    "arrangemangsmässigaste": "arrangemangsmässig",
    "arrangemangsmässigastes": "arrangemangsmässig",
    "arrangemangsmässigasts": "arrangemangsmässig",
    "arrangemangsmässige": "arrangemangsmässig",
    "arrangemangsmässiges": "arrangemangsmässig",
    "arrangemangsmässigs": "arrangemangsmässig",
    "arrangemangsmässigt": "arrangemangsmässig",
    "arrangemangsmässigts": "arrangemangsmässig",
    "arrangerad": "arrangera",
    "arrangerade": "arrangera",
    "arrangerades": "arrangera",
    "arrangerads": "arrangera",
    "arrangerande": "arrangera",
    "arrangeranden": "arrangerande",
    "arrangerandena": "arrangerande",
    "arrangerandenas": "arrangerande",
    "arrangerandens": "arrangerande",
    "arrangerandes": "arrangerande",
    "arrangerandet": "arrangerande",
    "arrangerandets": "arrangerande",
    "arrangerar": "arrangera",
    "arrangeras": "arrangera",
    "arrangerat": "arrangera",
    "arrangerats": "arrangera",
    "arrangerbara": "arrangerbar",
    "arrangerbarare": "arrangerbar",
    "arrangerbarares": "arrangerbar",
    "arrangerbaras": "arrangerbar",
    "arrangerbarast": "arrangerbar",
    "arrangerbaraste": "arrangerbar",
    "arrangerbarastes": "arrangerbar",
    "arrangerbarasts": "arrangerbar",
    "arrangerbare": "arrangerbar",
    "arrangerbares": "arrangerbar",
    "arrangerbarheten": "arrangerbarhet",
    "arrangerbarhetens": "arrangerbarhet",
    "arrangerbarhets": "arrangerbarhet",
    "arrangerbars": "arrangerbar",
    "arrangerbart": "arrangerbar",
    "arrangerbarts": "arrangerbar",
    "arrangeringar": "arrangering",
    "arrangeringarna": "arrangering",
    "arrangeringarnas": "arrangering",
    "arrangeringars": "arrangering",
    "arrangeringen": "arrangering",
    "arrangeringens": "arrangering",
    "arrangerings": "arrangering",
    "arrangören": "arrangör",
    "arrangörens": "arrangör",
    "arrangörer": "arrangör",
    "arrangörerna": "arrangör",
    "arrangörernas": "arrangör",
    "arrangörers": "arrangör",
    "arrangörs": "arrangör",
    "arrangörsmässiga": "arrangörsmässig",
    "arrangörsmässigare": "arrangörsmässig",
    "arrangörsmässigares": "arrangörsmässig",
    "arrangörsmässigas": "arrangörsmässig",
    "arrangörsmässigast": "arrangörsmässig",
    "arrangörsmässigaste": "arrangörsmässig",
    "arrangörsmässigastes": "arrangörsmässig",
    "arrangörsmässigasts": "arrangörsmässig",
    "arrangörsmässige": "arrangörsmässig",
    "arrangörsmässiges": "arrangörsmässig",
    "arrangörsmässigs": "arrangörsmässig",
    "arrangörsmässigt": "arrangörsmässig",
    "arrangörsmässigts": "arrangörsmässig",
    "arrar": "arra",
    "arras": "arra",
    "arrat": "arra",
    "arrats": "arra",
    "arren": "arr",
    "arrendatorer": "arrendator",
    "arrendatorerna": "arrendator",
    "arrendatorernas": "arrendator",
    "arrendatorers": "arrendator",
    "arrendatorn": "arrendator",
    "arrendatorns": "arrendator",
    "arrendators": "arrendator",
    "arrenden": "arrende",
    "arrendena": "arrende",
    "arrendenas": "arrende",
    "arrendens": "arrende",
    "arrenderad": "arrendera",
    "arrenderade": "arrendera",
    "arrenderades": "arrendera",
    "arrenderads": "arrendera",
    "arrenderande": "arrendera",
    "arrenderanden": "arrenderande",
    "arrenderandena": "arrenderande",
    "arrenderandenas": "arrenderande",
    "arrenderandens": "arrenderande",
    "arrenderandes": "arrenderande",
    "arrenderandet": "arrenderande",
    "arrenderandets": "arrenderande",
    "arrenderar": "arrendera",
    "arrenderas": "arrendera",
    "arrenderat": "arrendera",
    "arrenderats": "arrendera",
    "arrenderbara": "arrenderbar",
    "arrenderbarare": "arrenderbar",
    "arrenderbarares": "arrenderbar",
    "arrenderbaras": "arrenderbar",
    "arrenderbarast": "arrenderbar",
    "arrenderbaraste": "arrenderbar",
    "arrenderbarastes": "arrenderbar",
    "arrenderbarasts": "arrenderbar",
    "arrenderbare": "arrenderbar",
    "arrenderbares": "arrenderbar",
    "arrenderbarheten": "arrenderbarhet",
    "arrenderbarhetens": "arrenderbarhet",
    "arrenderbarhets": "arrenderbarhet",
    "arrenderbars": "arrenderbar",
    "arrenderbart": "arrenderbar",
    "arrenderbarts": "arrenderbar",
    "arrenderingar": "arrendering",
    "arrenderingarna": "arrendering",
    "arrenderingarnas": "arrendering",
    "arrenderingars": "arrendering",
    "arrenderingen": "arrendering",
    "arrenderingens": "arrendering",
    "arrenderings": "arrendering",
    "arrendes": "arrende",
    "arrendet": "arrende",
    "arrendets": "arrende",
    "arrens": "arr",
    "arrestanten": "arrestant",
    "arrestantens": "arrestant",
    "arrestanter": "arrestant",
    "arrestanterna": "arrestant",
    "arrestanternas": "arrestant",
    "arrestanters": "arrestant",
    "arrestants": "arrestant",
    "arrestavdelningar": "arrestavdelning",
    "arrestavdelningarna": "arrestavdelning",
    "arrestavdelningarnas": "arrestavdelning",
    "arrestavdelningars": "arrestavdelning",
    "arrestavdelningen": "arrestavdelning",
    "arrestavdelningens": "arrestavdelning",
    "arrestavdelnings": "arrestavdelning",
    "arresten": "arrest",
    "arrestens": "arrest",
    "arrester": "arrest",
    "arresterad": "arrestera",
    "arresterade": "arrestera",
    "arresterades": "arrestera",
    "arresterads": "arrestera",
    "arresterande": "arrestera",
    "arresteranden": "arresterande",
    "arresterandena": "arresterande",
    "arresterandenas": "arresterande",
    "arresterandens": "arresterande",
    "arresterandes": "arresterande",
    "arresterandet": "arresterande",
    "arresterandets": "arresterande",
    "arresterar": "arrestera",
    "arresteras": "arrestera",
    "arresterat": "arrestera",
    "arresterats": "arrestera",
    "arresterbara": "arresterbar",
    "arresterbarare": "arresterbar",
    "arresterbarares": "arresterbar",
    "arresterbaras": "arresterbar",
    "arresterbarast": "arresterbar",
    "arresterbaraste": "arresterbar",
    "arresterbarastes": "arresterbar",
    "arresterbarasts": "arresterbar",
    "arresterbare": "arresterbar",
    "arresterbares": "arresterbar",
    "arresterbarheten": "arresterbarhet",
    "arresterbarhetens": "arresterbarhet",
    "arresterbarhets": "arresterbarhet",
    "arresterbars": "arresterbar",
    "arresterbart": "arresterbar",
    "arresterbarts": "arresterbar",
    "arresteringar": "arrestering",
    "arresteringarna": "arrestering",
    "arresteringarnas": "arrestering",
    "arresteringars": "arrestering",
    "arresteringen": "arrestering",
    "arresteringens": "arrestering",
    "arresterings": "arrestering",
    "arresterna": "arrest",
    "arresternas": "arrest",
    "arresters": "arrest",
    "arrests": "arrest",
    "arret": "arr",
    "arrets": "arr",
    "arriverade": "arriverad",
    "arriverades": "arriverad",
    "arriverads": "arriverad",
    "arriverat": "arriverad",
    "arriverats": "arriverad",
    "arrivisten": "arrivist",
    "arrivistens": "arrivist",
    "arrivister": "arrivist",
    "arrivisterna": "arrivist",
    "arrivisternas": "arrivist",
    "arrivisters": "arrivist",
    "arrivists": "arrivist",
    "arriärgarden": "arriärgarde",
    "arriärgardena": "arriärgarde",
    "arriärgardenas": "arriärgarde",
    "arriärgardens": "arriärgarde",
    "arriärgardes": "arriärgarde",
    "arriärgardet": "arriärgarde",
    "arriärgardets": "arriärgarde",
    "arrogansen": "arrogans",
    "arrogansens": "arrogans",
    "arroganta": "arrogant",
    "arrogantare": "arrogant",
    "arrogantares": "arrogant",
    "arrogantas": "arrogant",
    "arrogantast": "arrogant",
    "arrogantaste": "arrogant",
    "arrogantastes": "arrogant",
    "arrogantasts": "arrogant",
    "arrogante": "arrogant",
    "arrogantes": "arrogant",
    "arrogants": "arrogant",
    "arronderad": "arrondera",
    "arronderade": "arrondera",
    "arronderades": "arrondera",
    "arronderads": "arrondera",
    "arronderande": "arrondera",
    "arronderanden": "arronderande",
    "arronderandena": "arronderande",
    "arronderandenas": "arronderande",
    "arronderandens": "arronderande",
    "arronderandes": "arronderande",
    "arronderandet": "arronderande",
    "arronderandets": "arronderande",
    "arronderar": "arrondera",
    "arronderas": "arrondera",
    "arronderat": "arrondera",
    "arronderats": "arrondera",
    "arronderbara": "arronderbar",
    "arronderbarare": "arronderbar",
    "arronderbarares": "arronderbar",
    "arronderbaras": "arronderbar",
    "arronderbarast": "arronderbar",
    "arronderbaraste": "arronderbar",
    "arronderbarastes": "arronderbar",
    "arronderbarasts": "arronderbar",
    "arronderbare": "arronderbar",
    "arronderbares": "arronderbar",
    "arronderbarheten": "arronderbarhet",
    "arronderbarhetens": "arronderbarhet",
    "arronderbarhets": "arronderbarhet",
    "arronderbars": "arronderbar",
    "arronderbart": "arronderbar",
    "arronderbarts": "arronderbar",
    "arronderingar": "arrondering",
    "arronderingarna": "arrondering",
    "arronderingarnas": "arrondering",
    "arronderingars": "arrondering",
    "arronderingen": "arrondering",
    "arronderingens": "arrondering",
    "arronderings": "arrondering",
    "arrowroten": "arrowrot",
    "arrowrotens": "arrowrot",
    "arrowrots": "arrowrot",
    "arrowrötter": "arrowrot",
    "arrowrötterna": "arrowrot",
    "arrowrötternas": "arrowrot",
    "arrowrötters": "arrowrot",
    "arrs": "arr",
    "ars": "ar",
    "arsels": "arsel",
    "arsenalen": "arsenal",
    "arsenalens": "arsenal",
    "arsenaler": "arsenal",
    "arsenalerna": "arsenal",
    "arsenalernas": "arsenal",
    "arsenalers": "arsenal",
    "arsenals": "arsenal",
    "arseniken": "arsenik",
    "arsenikens": "arsenik",
    "arsenikhalten": "arsenikhalt",
    "arsenikhaltens": "arsenikhalt",
    "arsenikhalter": "arsenikhalt",
    "arsenikhalterna": "arsenikhalt",
    "arsenikhalternas": "arsenikhalt",
    "arsenikhalters": "arsenikhalt",
    "arsenikhaltiga": "arsenikhaltig",
    "arsenikhaltigare": "arsenikhaltig",
    "arsenikhaltigares": "arsenikhaltig",
    "arsenikhaltigas": "arsenikhaltig",
    "arsenikhaltigast": "arsenikhaltig",
    "arsenikhaltigaste": "arsenikhaltig",
    "arsenikhaltigastes": "arsenikhaltig",
    "arsenikhaltigasts": "arsenikhaltig",
    "arsenikhaltige": "arsenikhaltig",
    "arsenikhaltiges": "arsenikhaltig",
    "arsenikhaltigs": "arsenikhaltig",
    "arsenikhaltigt": "arsenikhaltig",
    "arsenikhaltigts": "arsenikhaltig",
    "arsenikhalts": "arsenikhalt",
    "arsenikkisen": "arsenikkis",
    "arsenikkisens": "arsenikkis",
    "arsenikkiser": "arsenikkis",
    "arsenikkiserna": "arsenikkis",
    "arsenikkisernas": "arsenikkis",
    "arsenikkisers": "arsenikkis",
    "arseniks": "arsenik",
    "arsenikvätes": "arsenikväte",
    "arsenikvätet": "arsenikväte",
    "arsenikvätets": "arsenikväte",
    "arsin": "arsiner",
    "arsinerna": "arsiner",
    "arsinernas": "arsiner",
    "arsiners": "arsiner",
    "arsins": "arsiner",
    "arslen": "arsle",
    "arslena": "arsle",
    "arslenas": "arsle",
    "arslens": "arsle",
    "arsles": "arsle",
    "arslet": "arsle",
    "arslets": "arsle",
    "artade": "artad",
    "artades": "artas",
    "artads": "artad",
    "artat": "artad",
    "artats": "artas",
    "artbanken": "artbank",
    "artbankens": "artbank",
    "artbanker": "artbank",
    "artbankerna": "artbank",
    "artbankernas": "artbank",
    "artbankers": "artbank",
    "artbanks": "artbank",
    "artbildningar": "artbildning",
    "artbildningarna": "artbildning",
    "artbildningarnas": "artbildning",
    "artbildningars": "artbildning",
    "artbildningen": "artbildning",
    "artbildningens": "artbildning",
    "artbildnings": "artbildning",
    "artbildningsteorien": "artbildningsteori",
    "artbildningsteoriens": "artbildningsteori",
    "artbildningsteorier": "artbildningsteori",
    "artbildningsteorierna": "artbildningsteori",
    "artbildningsteoriernas": "artbildningsteori",
    "artbildningsteoriers": "artbildningsteori",
    "artbildningsteorin": "artbildningsteori",
    "artbildningsteorins": "artbildningsteori",
    "artbildningsteoris": "artbildningsteori",
    "artefakten": "artefakt",
    "artefaktens": "artefakt",
    "artefakter": "artefakt",
    "artefakterna": "artefakt",
    "artefakternas": "artefakt",
    "artefakters": "artefakt",
    "artefakts": "artefakt",
    "artegenheten": "artegenhet",
    "artegenhetens": "artegenhet",
    "artegenhets": "artegenhet",
    "artegens": "artegen",
    "arteget": "artegen",
    "artegets": "artegen",
    "artegna": "artegen",
    "artegnare": "artegen",
    "artegnares": "artegen",
    "artegnas": "artegen",
    "artegnast": "artegen",
    "artegnaste": "artegen",
    "artegnastes": "artegen",
    "artegnasts": "artegen",
    "artegne": "artegen",
    "artegnes": "artegen",
    "arten": "art",
    "artens": "art",
    "arter": "art",
    "arteriella": "arteriell",
    "arteriellare": "arteriell",
    "arteriellares": "arteriell",
    "arteriellas": "arteriell",
    "arteriellast": "arteriell",
    "arteriellaste": "arteriell",
    "arteriellastes": "arteriell",
    "arteriellasts": "arteriell",
    "arterielle": "arteriell",
    "arterielles": "arteriell",
    "arteriells": "arteriell",
    "arteriellt": "arteriell",
    "arteriellts": "arteriell",
    "arteriosklerosen": "arterioskleros",
    "arteriosklerosens": "arterioskleros",
    "arterioskleroser": "arterioskleros",
    "arterioskleroserna": "arterioskleros",
    "arteriosklerosernas": "arterioskleros",
    "arteriosklerosers": "arterioskleros",
    "arterna": "art",
    "arternas": "art",
    "arters": "art",
    "artesiska": "artesisk",
    "artesiskare": "artesisk",
    "artesiskares": "artesisk",
    "artesiskas": "artesisk",
    "artesiskast": "artesisk",
    "artesiskaste": "artesisk",
    "artesiskastes": "artesisk",
    "artesiskasts": "artesisk",
    "artesiske": "artesisk",
    "artesiskes": "artesisk",
    "artesisks": "artesisk",
    "artesiskt": "artesisk",
    "artesiskts": "artesisk",
    "artfränden": "artfrände",
    "artfrändens": "artfrände",
    "artfränder": "artfrände",
    "artfränderna": "artfrände",
    "artfrändernas": "artfrände",
    "artfränders": "artfrände",
    "artfrändes": "artfrände",
    "artificiella": "artificiell",
    "artificiellare": "artificiell",
    "artificiellares": "artificiell",
    "artificiellas": "artificiell",
    "artificiellast": "artificiell",
    "artificiellaste": "artificiell",
    "artificiellastes": "artificiell",
    "artificiellasts": "artificiell",
    "artificielle": "artificiell",
    "artificielles": "artificiell",
    "artificiells": "artificiell",
    "artificiellt": "artificiell",
    "artificiellts": "artificiell",
    "artiga": "artig",
    "artigare": "artig",
    "artigares": "artig",
    "artigas": "artig",
    "artigast": "artig",
    "artigaste": "artig",
    "artigastes": "artig",
    "artigasts": "artig",
    "artige": "artig",
    "artiges": "artig",
    "artigheten": "artighet",
    "artighetens": "artighet",
    "artigheter": "artighet",
    "artigheterna": "artighet",
    "artigheternas": "artighet",
    "artigheters": "artighet",
    "artighets": "artighet",
    "artighetsbetygelsen": "artighetsbetygelse",
    "artighetsbetygelsens": "artighetsbetygelse",
    "artighetsbetygelser": "artighetsbetygelse",
    "artighetsbetygelserna": "artighetsbetygelse",
    "artighetsbetygelsernas": "artighetsbetygelse",
    "artighetsbetygelsers": "artighetsbetygelse",
    "artighetsbetygelses": "artighetsbetygelse",
    "artighetsfrasen": "artighetsfras",
    "artighetsfrasens": "artighetsfras",
    "artighetsfraser": "artighetsfras",
    "artighetsfraserna": "artighetsfras",
    "artighetsfrasernas": "artighetsfras",
    "artighetsfrasers": "artighetsfras",
    "artighetsvisiten": "artighetsvisit",
    "artighetsvisitens": "artighetsvisit",
    "artighetsvisiter": "artighetsvisit",
    "artighetsvisiterna": "artighetsvisit",
    "artighetsvisiternas": "artighetsvisit",
    "artighetsvisiters": "artighetsvisit",
    "artighetsvisits": "artighetsvisit",
    "artigs": "artig",
    "artigt": "artig",
    "artigts": "artig",
    "artikelförfattar": "artikelförfattare",
    "artikelförfattaren": "artikelförfattare",
    "artikelförfattarens": "artikelförfattare",
    "artikelförfattares": "artikelförfattare",
    "artikelförfattarna": "artikelförfattare",
    "artikelförfattarnas": "artikelförfattare",
    "artikeln": "artikel",
    "artikelns": "artikel",
    "artikels": "artikel",
    "artikelserien": "artikelserie",
    "artikelseriens": "artikelserie",
    "artikelserier": "artikelserie",
    "artikelserierna": "artikelserie",
    "artikelseriernas": "artikelserie",
    "artikelseriers": "artikelserie",
    "artikelseries": "artikelserie",
    "artiklar": "artikel",
    "artiklarna": "artikel",
    "artiklarnas": "artikel",
    "artiklars": "artikel",
    "artikulationen": "artikulation",
    "artikulationens": "artikulation",
    "artikulationer": "artikulation",
    "artikulationerna": "artikulation",
    "artikulationernas": "artikulation",
    "artikulationers": "artikulation",
    "artikulations": "artikulation",
    "artikulationsbasen": "artikulationsbas",
    "artikulationsbasens": "artikulationsbas",
    "artikulationsbaser": "artikulationsbas",
    "artikulationsbaserna": "artikulationsbas",
    "artikulationsbasernas": "artikulationsbas",
    "artikulationsbasers": "artikulationsbas",
    "artikulationsställen": "artikulationsställe",
    "artikulationsställena": "artikulationsställe",
    "artikulationsställenas": "artikulationsställe",
    "artikulationsställens": "artikulationsställe",
    "artikulationsställes": "artikulationsställe",
    "artikulationsstället": "artikulationsställe",
    "artikulationsställets": "artikulationsställe",
    "artikulerad": "artikulera",
    "artikulerade": "artikulera",
    "artikulerades": "artikulera",
    "artikulerads": "artikulera",
    "artikulerande": "artikulera",
    "artikuleranden": "artikulerande",
    "artikulerandena": "artikulerande",
    "artikulerandenas": "artikulerande",
    "artikulerandens": "artikulerande",
    "artikulerandes": "artikulerande",
    "artikulerandet": "artikulerande",
    "artikulerandets": "artikulerande",
    "artikulerar": "artikulera",
    "artikuleras": "artikulera",
    "artikulerat": "artikulera",
    "artikulerats": "artikulera",
    "artikulerbara": "artikulerbar",
    "artikulerbarare": "artikulerbar",
    "artikulerbarares": "artikulerbar",
    "artikulerbaras": "artikulerbar",
    "artikulerbarast": "artikulerbar",
    "artikulerbaraste": "artikulerbar",
    "artikulerbarastes": "artikulerbar",
    "artikulerbarasts": "artikulerbar",
    "artikulerbare": "artikulerbar",
    "artikulerbares": "artikulerbar",
    "artikulerbarheten": "artikulerbarhet",
    "artikulerbarhetens": "artikulerbarhet",
    "artikulerbarhets": "artikulerbarhet",
    "artikulerbars": "artikulerbar",
    "artikulerbart": "artikulerbar",
    "artikulerbarts": "artikulerbar",
    "artikuleringar": "artikulering",
    "artikuleringarna": "artikulering",
    "artikuleringarnas": "artikulering",
    "artikuleringars": "artikulering",
    "artikuleringen": "artikulering",
    "artikuleringens": "artikulering",
    "artikulerings": "artikulering",
    "artilleribeskjutningar": "artilleribeskjutning",
    "artilleribeskjutningarna": "artilleribeskjutning",
    "artilleribeskjutningarnas": "artilleribeskjutning",
    "artilleribeskjutningars": "artilleribeskjutning",
    "artilleribeskjutningen": "artilleribeskjutning",
    "artilleribeskjutningens": "artilleribeskjutning",
    "artilleribeskjutnings": "artilleribeskjutning",
    "artillerielden": "artillerield",
    "artillerieldens": "artillerield",
    "artillerields": "artillerield",
    "artilleriet": "artilleri",
    "artilleriets": "artilleri",
    "artilleriförbanden": "artilleriförband",
    "artilleriförbandens": "artilleriförband",
    "artilleriförbandet": "artilleriförband",
    "artilleriförbandets": "artilleriförband",
    "artilleriförbands": "artilleriförband",
    "artillerigranaten": "artillerigranat",
    "artillerigranatens": "artillerigranat",
    "artillerigranater": "artillerigranat",
    "artillerigranaterna": "artillerigranat",
    "artillerigranaternas": "artillerigranat",
    "artillerigranaters": "artillerigranat",
    "artillerigranats": "artillerigranat",
    "artillerimanskapen": "artillerimanskap",
    "artillerimanskapens": "artillerimanskap",
    "artillerimanskapet": "artillerimanskap",
    "artillerimanskapets": "artillerimanskap",
    "artillerimanskaps": "artillerimanskap",
    "artilleripjäsen": "artilleripjäs",
    "artilleripjäsens": "artilleripjäs",
    "artilleripjäser": "artilleripjäs",
    "artilleripjäserna": "artilleripjäs",
    "artilleripjäsernas": "artilleripjäs",
    "artilleripjäsers": "artilleripjäs",
    "artilleriregementen": "artilleriregemente",
    "artilleriregementena": "artilleriregemente",
    "artilleriregementenas": "artilleriregemente",
    "artilleriregementens": "artilleriregemente",
    "artilleriregementes": "artilleriregemente",
    "artilleriregementet": "artilleriregemente",
    "artilleriregementets": "artilleriregemente",
    "artilleris": "artilleri",
    "artilleristen": "artillerist",
    "artilleristens": "artillerist",
    "artillerister": "artillerist",
    "artilleristerna": "artillerist",
    "artilleristernas": "artillerist",
    "artilleristers": "artillerist",
    "artillerists": "artillerist",
    "artillerit": "artilleri",
    "artillerits": "artilleri",
    "artillerivapens": "artillerivapen",
    "artillerivapnen": "artillerivapen",
    "artillerivapnens": "artillerivapen",
    "artillerivapnet": "artillerivapen",
    "artillerivapnets": "artillerivapen",
    "artisten": "artist",
    "artistens": "artist",
    "artister": "artist",
    "artisteriet": "artisteri",
    "artisteriets": "artisteri",
    "artisteris": "artisteri",
    "artisterit": "artisteri",
    "artisterits": "artisteri",
    "artisterna": "artist",
    "artisternas": "artist",
    "artisters": "artist",
    "artistframträdanden": "artistframträdande",
    "artistframträdandena": "artistframträdande",
    "artistframträdandenas": "artistframträdande",
    "artistframträdandens": "artistframträdande",
    "artistframträdandes": "artistframträdande",
    "artistframträdandet": "artistframträdande",
    "artistframträdandets": "artistframträdande",
    "artistiska": "artistisk",
    "artistiskare": "artistisk",
    "artistiskares": "artistisk",
    "artistiskas": "artistisk",
    "artistiskast": "artistisk",
    "artistiskaste": "artistisk",
    "artistiskastes": "artistisk",
    "artistiskasts": "artistisk",
    "artistiske": "artistisk",
    "artistiskes": "artistisk",
    "artistisks": "artistisk",
    "artistiskt": "artistisk",
    "artistiskts": "artistisk",
    "artistnamnen": "artistnamn",
    "artistnamnens": "artistnamn",
    "artistnamnet": "artistnamn",
    "artistnamnets": "artistnamn",
    "artistnamns": "artistnamn",
    "artists": "artist",
    "artnamnen": "artnamn",
    "artnamnens": "artnamn",
    "artnamnet": "artnamn",
    "artnamnets": "artnamn",
    "artnamns": "artnamn",
    "artonde": "arton",
    "artondes": "arton",
    "artonhundranittiotalet": "artonhundranittiotal",
    "artonhundranittiotalets": "artonhundranittiotal",
    "artonhundranittiotals": "artonhundranittiotal",
    "artonhundrasjuttiotalet": "artonhundrasjuttiotal",
    "artonhundrasjuttiotalets": "artonhundrasjuttiotal",
    "artonhundrasjuttiotals": "artonhundrasjuttiotal",
    "artonhundratalet": "artonhundratal",
    "artonhundratalets": "artonhundratal",
    "artonhundratals": "artonhundratal",
    "artonhundratalsmoden": "artonhundratalsmode",
    "artonhundratalsmodena": "artonhundratalsmode",
    "artonhundratalsmodenas": "artonhundratalsmode",
    "artonhundratalsmodens": "artonhundratalsmode",
    "artonhundratalsmodes": "artonhundratalsmode",
    "artonhundratalsmodet": "artonhundratalsmode",
    "artonhundratalsmodets": "artonhundratalsmode",
    "artonhundraåttiotalet": "artonhundraåttiotal",
    "artonhundraåttiotalets": "artonhundraåttiotal",
    "artonhundraåttiotals": "artonhundraåttiotal",
    "artons": "arton",
    "artonsnårets": "artonsnåret",
    "artonåriga": "artonårig",
    "artonårigas": "artonårig",
    "artonårige": "artonårig",
    "artonåriges": "artonårig",
    "artonårigs": "artonårig",
    "artonårigt": "artonårig",
    "artonårigts": "artonårig",
    "artonåringar": "artonåring",
    "artonåringarna": "artonåring",
    "artonåringarnas": "artonåring",
    "artonåringars": "artonåring",
    "artonåringen": "artonåring",
    "artonåringens": "artonåring",
    "artonårings": "artonåring",
    "artonårsdagar": "artonårsdag",
    "artonårsdagarna": "artonårsdag",
    "artonårsdagarnas": "artonårsdag",
    "artonårsdagars": "artonårsdag",
    "artonårsdagen": "artonårsdag",
    "artonårsdagens": "artonårsdag",
    "artonårsdags": "artonårsdag",
    "artonårsmyndigheten": "artonårsmyndighet",
    "artonårsmyndighetens": "artonårsmyndighet",
    "artonårsmyndighets": "artonårsmyndighet",
    "artoteken": "artotek",
    "artotekens": "artotek",
    "artoteket": "artotek",
    "artotekets": "artotek",
    "artoteks": "artotek",
    "artrika": "artrik",
    "artrikare": "artrik",
    "artrikares": "artrik",
    "artrikas": "artrik",
    "artrikast": "artrik",
    "artrikaste": "artrik",
    "artrikastes": "artrik",
    "artrikasts": "artrik",
    "artrike": "artrik",
    "artrikes": "artrik",
    "artrikheten": "artrikhet",
    "artrikhetens": "artrikhet",
    "artrikhets": "artrikhet",
    "artriks": "artrik",
    "artrikt": "artrik",
    "artrikts": "artrik",
    "artriten": "artrit",
    "artritens": "artrit",
    "artriter": "artrit",
    "artriterna": "artrit",
    "artriternas": "artrit",
    "artriters": "artrit",
    "artrits": "artrit",
    "artrosen": "artros",
    "artrosens": "artros",
    "artroser": "artros",
    "artroserna": "artros",
    "artrosernas": "artros",
    "artrosers": "artros",
    "arts": "art",
    "artskilda": "artskild",
    "artskildare": "artskild",
    "artskildares": "artskild",
    "artskildas": "artskild",
    "artskildast": "artskild",
    "artskildaste": "artskild",
    "artskildastes": "artskild",
    "artskildasts": "artskild",
    "artskilde": "artskild",
    "artskildes": "artskild",
    "artskildheten": "artskildhet",
    "artskildhetens": "artskildhet",
    "artskildhets": "artskildhet",
    "artskilds": "artskild",
    "artskillnaden": "artskillnad",
    "artskillnadens": "artskillnad",
    "artskillnader": "artskillnad",
    "artskillnaderna": "artskillnad",
    "artskillnadernas": "artskillnad",
    "artskillnaders": "artskillnad",
    "artskillnads": "artskillnad",
    "artskilt": "artskild",
    "artskilts": "artskild",
    "artären": "artär",
    "artärens": "artär",
    "artärer": "artär",
    "artärerna": "artär",
    "artärernas": "artär",
    "artärers": "artär",
    "artärs": "artär",
    "arv": "arve",
    "arvar": "arve",
    "arvarna": "arve",
    "arvarnas": "arve",
    "arvars": "arve",
    "arvedelar": "arvedel",
    "arvedelarna": "arvedel",
    "arvedelarnas": "arvedel",
    "arvedelars": "arvedel",
    "arvedelen": "arvedel",
    "arvedelens": "arvedel",
    "arvedels": "arvedel",
    "arvegodset": "arvegods",
    "arvegodsets": "arvegods",
    "arven": "arve",
    "arvens": "arve",
    "arves": "arve",
    "arvet": "arv",
    "arvets": "arv",
    "arvfienden": "arvfiende",
    "arvfiendens": "arvfiende",
    "arvfiender": "arvfiende",
    "arvfienderna": "arvfiende",
    "arvfiendernas": "arvfiende",
    "arvfienders": "arvfiende",
    "arvfiendes": "arvfiende",
    "arvfurstar": "arvfurste",
    "arvfurstarna": "arvfurste",
    "arvfurstarnas": "arvfurste",
    "arvfurstars": "arvfurste",
    "arvfursten": "arvfurste",
    "arvfurstens": "arvfurste",
    "arvfurstes": "arvfurste",
    "arvföljden": "arvföljd",
    "arvföljdens": "arvföljd",
    "arvföljder": "arvföljd",
    "arvföljderna": "arvföljd",
    "arvföljdernas": "arvföljd",
    "arvföljders": "arvföljd",
    "arvföljds": "arvföljd",
    "arvingar": "arvinge",
    "arvingarna": "arvinge",
    "arvingarnas": "arvinge",
    "arvingars": "arvinge",
    "arvingen": "arvinge",
    "arvingens": "arvinge",
    "arvinges": "arvinge",
    "arvlåtar": "arvlåtare",
    "arvlåtaren": "arvlåtare",
    "arvlåtarens": "arvlåtare",
    "arvlåtares": "arvlåtare",
    "arvlåtarna": "arvlåtare",
    "arvlåtarnas": "arvlåtare",
    "arvlösa": "arvlös",
    "arvlösare": "arvlös",
    "arvlösares": "arvlös",
    "arvlösas": "arvlös",
    "arvlösast": "arvlös",
    "arvlösaste": "arvlös",
    "arvlösastes": "arvlös",
    "arvlösasts": "arvlös",
    "arvlöse": "arvlös",
    "arvlöses": "arvlös",
    "arvlösheten": "arvlöshet",
    "arvlöshetens": "arvlöshet",
    "arvlöshets": "arvlöshet",
    "arvlöst": "arvlös",
    "arvlösts": "arvlös",
    "arvoden": "arvode",
    "arvodena": "arvode",
    "arvodenas": "arvode",
    "arvodens": "arvode",
    "arvoderad": "arvodera",
    "arvoderade": "arvodera",
    "arvoderades": "arvodera",
    "arvoderads": "arvodera",
    "arvoderande": "arvodera",
    "arvoderanden": "arvoderande",
    "arvoderandena": "arvoderande",
    "arvoderandenas": "arvoderande",
    "arvoderandens": "arvoderande",
    "arvoderandes": "arvoderande",
    "arvoderandet": "arvoderande",
    "arvoderandets": "arvoderande",
    "arvoderar": "arvodera",
    "arvoderas": "arvodera",
    "arvoderat": "arvodera",
    "arvoderats": "arvodera",
    "arvoderbara": "arvoderbar",
    "arvoderbarare": "arvoderbar",
    "arvoderbarares": "arvoderbar",
    "arvoderbaras": "arvoderbar",
    "arvoderbarast": "arvoderbar",
    "arvoderbaraste": "arvoderbar",
    "arvoderbarastes": "arvoderbar",
    "arvoderbarasts": "arvoderbar",
    "arvoderbare": "arvoderbar",
    "arvoderbares": "arvoderbar",
    "arvoderbarheten": "arvoderbarhet",
    "arvoderbarhetens": "arvoderbarhet",
    "arvoderbarhets": "arvoderbarhet",
    "arvoderbars": "arvoderbar",
    "arvoderbart": "arvoderbar",
    "arvoderbarts": "arvoderbar",
    "arvoderingar": "arvodering",
    "arvoderingarna": "arvodering",
    "arvoderingarnas": "arvodering",
    "arvoderingars": "arvodering",
    "arvoderingen": "arvodering",
    "arvoderingens": "arvodering",
    "arvoderings": "arvodering",
    "arvodes": "arvode",
    "arvodet": "arvode",
    "arvodets": "arvode",
    "arvorden": "arvord",
    "arvordens": "arvord",
    "arvordet": "arvord",
    "arvordets": "arvord",
    "arvords": "arvord",
    "arvriken": "arvrike",
    "arvrikena": "arvrike",
    "arvrikenas": "arvrike",
    "arvrikens": "arvrike",
    "arvrikes": "arvrike",
    "arvriket": "arvrike",
    "arvrikets": "arvrike",
    "arvs": "arve",
    "arvsanlagen": "arvsanlag",
    "arvsanlagens": "arvsanlag",
    "arvsanlaget": "arvsanlag",
    "arvsanlagets": "arvsanlag",
    "arvsanlags": "arvsanlag",
    "arvsberättigade": "arvsberättigad",
    "arvsberättigades": "arvsberättigad",
    "arvsberättigads": "arvsberättigad",
    "arvsberättigat": "arvsberättigad",
    "arvsberättigats": "arvsberättigad",
    "arvsfaktorer": "arvsfaktor",
    "arvsfaktorerna": "arvsfaktor",
    "arvsfaktorernas": "arvsfaktor",
    "arvsfaktorers": "arvsfaktor",
    "arvsfaktorn": "arvsfaktor",
    "arvsfaktorns": "arvsfaktor",
    "arvsfaktors": "arvsfaktor",
    "arvsfonden": "arvsfond",
    "arvsfondens": "arvsfond",
    "arvsfonder": "arvsfond",
    "arvsfonderna": "arvsfond",
    "arvsfondernas": "arvsfond",
    "arvsfonders": "arvsfond",
    "arvsfonds": "arvsfond",
    "arvsföljden": "arvsföljd",
    "arvsföljdens": "arvsföljd",
    "arvsföljder": "arvsföljd",
    "arvsföljderna": "arvsföljd",
    "arvsföljdernas": "arvsföljd",
    "arvsföljders": "arvsföljd",
    "arvsföljds": "arvsföljd",
    "arvshygienen": "arvshygien",
    "arvshygienens": "arvshygien",
    "arvshygiens": "arvshygien",
    "arvskatten": "arvskatt",
    "arvskattens": "arvskatt",
    "arvskatter": "arvskatt",
    "arvskatterna": "arvskatt",
    "arvskatternas": "arvskatt",
    "arvskatters": "arvskatt",
    "arvskatts": "arvskatt",
    "arvskiften": "arvskifte",
    "arvskiftena": "arvskifte",
    "arvskiftenas": "arvskifte",
    "arvskiftens": "arvskifte",
    "arvskiftes": "arvskifte",
    "arvskiftet": "arvskifte",
    "arvskiftets": "arvskifte",
    "arvslotten": "arvslott",
    "arvslottens": "arvslott",
    "arvslotter": "arvslott",
    "arvslotterna": "arvslott",
    "arvslotternas": "arvslott",
    "arvslotters": "arvslott",
    "arvslotts": "arvslott",
    "arvsmassan": "arvsmassa",
    "arvsmassans": "arvsmassa",
    "arvsmassas": "arvsmassa",
    "arvsmasse": "arvsmassa",
    "arvsmolekylen": "arvsmolekyl",
    "arvsmolekylens": "arvsmolekyl",
    "arvsmolekyler": "arvsmolekyl",
    "arvsmolekylerna": "arvsmolekyl",
    "arvsmolekylernas": "arvsmolekyl",
    "arvsmolekylers": "arvsmolekyl",
    "arvsmolekyls": "arvsmolekyl",
    "arvsmässiga": "arvsmässig",
    "arvsmässigare": "arvsmässig",
    "arvsmässigares": "arvsmässig",
    "arvsmässigas": "arvsmässig",
    "arvsmässigast": "arvsmässig",
    "arvsmässigaste": "arvsmässig",
    "arvsmässigastes": "arvsmässig",
    "arvsmässigasts": "arvsmässig",
    "arvsmässige": "arvsmässig",
    "arvsmässiges": "arvsmässig",
    "arvsmässigs": "arvsmässig",
    "arvsmässigt": "arvsmässig",
    "arvsmässigts": "arvsmässig",
    "arvsrätten": "arvsrätt",
    "arvsrättens": "arvsrätt",
    "arvsrätter": "arvsrätt",
    "arvsrätterna": "arvsrätt",
    "arvsrätternas": "arvsrätt",
    "arvsrätters": "arvsrätt",
    "arvsrätts": "arvsrätt",
    "arvsskatten": "arvsskatt",
    "arvsskattens": "arvsskatt",
    "arvsskatter": "arvsskatt",
    "arvsskatterna": "arvsskatt",
    "arvsskatternas": "arvsskatt",
    "arvsskatters": "arvsskatt",
    "arvsskatts": "arvsskatt",
    "arvstvisten": "arvstvist",
    "arvstvistens": "arvstvist",
    "arvstvister": "arvstvist",
    "arvstvisterna": "arvstvist",
    "arvstvisternas": "arvstvist",
    "arvstvisters": "arvstvist",
    "arvstvists": "arvstvist",
    "arvsynden": "arvsynd",
    "arvsyndens": "arvsynd",
    "arvsynder": "arvsynd",
    "arvsynderna": "arvsynd",
    "arvsyndernas": "arvsynd",
    "arvsynders": "arvsynd",
    "arvsynds": "arvsynd",
    "arvtagar": "arvtagare",
    "arvtagaren": "arvtagare",
    "arvtagarens": "arvtagare",
    "arvtagares": "arvtagare",
    "arvtagarna": "arvtagare",
    "arvtagarnas": "arvtagare",
    "arvtanten": "arvtant",
    "arvtantens": "arvtant",
    "arvtanter": "arvtant",
    "arvtanterna": "arvtant",
    "arvtanternas": "arvtant",
    "arvtanters": "arvtant",
    "arvtants": "arvtant",
    "arytmien": "arytmi",
    "arytmiens": "arytmi",
    "arytmier": "arytmi",
    "arytmierna": "arytmi",
    "arytmiernas": "arytmi",
    "arytmiers": "arytmi",
    "arytmin": "arytmi",
    "arytmins": "arytmi",
    "arytmis": "arytmi",
    "asade": "asa",
    "asades": "asa",
    "asagudar": "asagud",
    "asagudarna": "asagud",
    "asagudarnas": "asagud",
    "asagudars": "asagud",
    "asaguden": "asagud",
    "asagudens": "asagud",
    "asaguds": "asagud",
    "asande": "asa",
    "asanden": "asande",
    "asandena": "asande",
    "asandenas": "asande",
    "asandens": "asande",
    "asandes": "asande",
    "asandet": "asande",
    "asandets": "asande",
    "asar": "asa",
    "asarna": "as",
    "asarnas": "as",
    "asars": "as",
    "asas": "asa",
    "asat": "asa",
    "asatron": "asatro",
    "asatrons": "asatro",
    "asatros": "asatro",
    "asats": "asa",
    "asbagg": "asbagge",
    "asbaggar": "asbagge",
    "asbaggarna": "asbagge",
    "asbaggarnas": "asbagge",
    "asbaggars": "asbagge",
    "asbaggen": "asbagge",
    "asbaggens": "asbagge",
    "asbagges": "asbagge",
    "asbaggs": "asbagge",
    "asberusade": "asberusad",
    "asberusades": "asberusad",
    "asberusads": "asberusad",
    "asberusat": "asberusad",
    "asberusats": "asberusad",
    "asbestarbetar": "asbestarbetare",
    "asbestarbetaren": "asbestarbetare",
    "asbestarbetarens": "asbestarbetare",
    "asbestarbetares": "asbestarbetare",
    "asbestarbetarna": "asbestarbetare",
    "asbestarbetarnas": "asbestarbetare",
    "asbestcementen": "asbestcement",
    "asbestcementens": "asbestcement",
    "asbestcementet": "asbestcement",
    "asbestcementets": "asbestcement",
    "asbestcements": "asbestcement",
    "asbesten": "asbest",
    "asbestens": "asbest",
    "asbestosen": "asbestos",
    "asbestosens": "asbestos",
    "asbestplatt": "asbestplatta",
    "asbestplattan": "asbestplatta",
    "asbestplattans": "asbestplatta",
    "asbestplattas": "asbestplatta",
    "asbestplatte": "asbestplatta",
    "asbestplattor": "asbestplatta",
    "asbestplattorna": "asbestplatta",
    "asbestplattornas": "asbestplatta",
    "asbestplattors": "asbestplatta",
    "asbestplatts": "asbestplatta",
    "asbests": "asbest",
    "asbestsaneringar": "asbestsanering",
    "asbestsaneringarna": "asbestsanering",
    "asbestsaneringarnas": "asbestsanering",
    "asbestsaneringars": "asbestsanering",
    "asbestsaneringen": "asbestsanering",
    "asbestsaneringens": "asbestsanering",
    "asbestsanerings": "asbestsanering",
    "asen": "as",
    "asens": "as",
    "aseptiken": "aseptik",
    "aseptikens": "aseptik",
    "aseptiks": "aseptik",
    "aseptiska": "aseptisk",
    "aseptiskare": "aseptisk",
    "aseptiskares": "aseptisk",
    "aseptiskas": "aseptisk",
    "aseptiskast": "aseptisk",
    "aseptiskaste": "aseptisk",
    "aseptiskastes": "aseptisk",
    "aseptiskasts": "aseptisk",
    "aseptiske": "aseptisk",
    "aseptiskes": "aseptisk",
    "aseptisks": "aseptisk",
    "aseptiskt": "aseptisk",
    "aseptiskts": "aseptisk",
    "aset": "as",
    "asets": "as",
    "asexuella": "asexuell",
    "asexuellare": "asexuell",
    "asexuellares": "asexuell",
    "asexuellas": "asexuell",
    "asexuellast": "asexuell",
    "asexuellaste": "asexuell",
    "asexuellastes": "asexuell",
    "asexuellasts": "asexuell",
    "asexuelle": "asexuell",
    "asexuelles": "asexuell",
    "asexuells": "asexuell",
    "asexuellt": "asexuell",
    "asexuellts": "asexuell",
    "asfaltemulsionen": "asfaltemulsion",
    "asfaltemulsionens": "asfaltemulsion",
    "asfaltemulsioner": "asfaltemulsion",
    "asfaltemulsionerna": "asfaltemulsion",
    "asfaltemulsionernas": "asfaltemulsion",
    "asfaltemulsioners": "asfaltemulsion",
    "asfaltemulsions": "asfaltemulsion",
    "asfalten": "asfalt",
    "asfaltens": "asfalt",
    "asfalter": "asfalt",
    "asfalterad": "asfaltera",
    "asfalterade": "asfaltera",
    "asfalterades": "asfaltera",
    "asfalterads": "asfaltera",
    "asfalterande": "asfaltera",
    "asfalteranden": "asfalterande",
    "asfalterandena": "asfalterande",
    "asfalterandenas": "asfalterande",
    "asfalterandens": "asfalterande",
    "asfalterandes": "asfalterande",
    "asfalterandet": "asfalterande",
    "asfalterandets": "asfalterande",
    "asfalterar": "asfaltera",
    "asfalteras": "asfaltera",
    "asfalterat": "asfaltera",
    "asfalterats": "asfaltera",
    "asfalterbara": "asfalterbar",
    "asfalterbarare": "asfalterbar",
    "asfalterbarares": "asfalterbar",
    "asfalterbaras": "asfalterbar",
    "asfalterbarast": "asfalterbar",
    "asfalterbaraste": "asfalterbar",
    "asfalterbarastes": "asfalterbar",
    "asfalterbarasts": "asfalterbar",
    "asfalterbare": "asfalterbar",
    "asfalterbares": "asfalterbar",
    "asfalterbarheten": "asfalterbarhet",
    "asfalterbarhetens": "asfalterbarhet",
    "asfalterbarhets": "asfalterbarhet",
    "asfalterbars": "asfalterbar",
    "asfalterbart": "asfalterbar",
    "asfalterbarts": "asfalterbar",
    "asfalteringar": "asfaltering",
    "asfalteringarna": "asfaltering",
    "asfalteringarnas": "asfaltering",
    "asfalteringars": "asfaltering",
    "asfalteringen": "asfaltering",
    "asfalteringens": "asfaltering",
    "asfalterings": "asfaltering",
    "asfalterna": "asfalt",
    "asfalternas": "asfalt",
    "asfalters": "asfalt",
    "asfaltlacken": "asfaltlack",
    "asfaltlackens": "asfaltlack",
    "asfaltlacker": "asfaltlack",
    "asfaltlackerna": "asfaltlack",
    "asfaltlackernas": "asfaltlack",
    "asfaltlackers": "asfaltlack",
    "asfaltlacket": "asfaltlack",
    "asfaltlackets": "asfaltlack",
    "asfaltlacks": "asfaltlack",
    "asfaltmopeden": "asfaltmoped",
    "asfaltmopedens": "asfaltmoped",
    "asfaltmopeder": "asfaltmoped",
    "asfaltmopederna": "asfaltmoped",
    "asfaltmopedernas": "asfaltmoped",
    "asfaltmopeders": "asfaltmoped",
    "asfaltmopeds": "asfaltmoped",
    "asfaltplatt": "asfaltplatta",
    "asfaltplattan": "asfaltplatta",
    "asfaltplattans": "asfaltplatta",
    "asfaltplattas": "asfaltplatta",
    "asfaltplatte": "asfaltplatta",
    "asfaltplattor": "asfaltplatta",
    "asfaltplattorna": "asfaltplatta",
    "asfaltplattornas": "asfaltplatta",
    "asfaltplattors": "asfaltplatta",
    "asfaltplatts": "asfaltplatta",
    "asfalts": "asfalt",
    "asfulla": "asfull",
    "asfullare": "asfull",
    "asfullares": "asfull",
    "asfullas": "asfull",
    "asfullast": "asfull",
    "asfullaste": "asfull",
    "asfullastes": "asfull",
    "asfullasts": "asfull",
    "asfulle": "asfull",
    "asfulles": "asfull",
    "asfulls": "asfull",
    "asfullt": "asfull",
    "asfullts": "asfull",
    "asfyxiskadan": "asfyxiskada",
    "asfyxiskadans": "asfyxiskada",
    "asfyxiskadas": "asfyxiskada",
    "asfyxiskade": "asfyxiskada",
    "asfyxiskador": "asfyxiskada",
    "asfyxiskadorna": "asfyxiskada",
    "asfyxiskadornas": "asfyxiskada",
    "asfyxiskadors": "asfyxiskada",
    "asfågeln": "asfågel",
    "asfågelns": "asfågel",
    "asfågels": "asfågel",
    "asfåglar": "asfågel",
    "asfåglarna": "asfågel",
    "asfåglarnas": "asfågel",
    "asfåglars": "asfågel",
    "asförbannade": "asförbannad",
    "asförbannades": "asförbannad",
    "asförbannads": "asförbannad",
    "asförbannat": "asförbannad",
    "asförbannats": "asförbannad",
    "asgamar": "asgam",
    "asgamarna": "asgam",
    "asgamarnas": "asgam",
    "asgamars": "asgam",
    "asgamen": "asgam",
    "asgamens": "asgam",
    "asgams": "asgam",
    "asgarvade": "asgarva",
    "asgarvades": "asgarva",
    "asgarvande": "asgarva",
    "asgarvandes": "asgarva",
    "asgarvar": "asgarva",
    "asgarvas": "asgarva",
    "asgarvat": "asgarva",
    "asgarvats": "asgarva",
    "asiaten": "asiat",
    "asiatens": "asiat",
    "asiater": "asiat",
    "asiaterna": "asiat",
    "asiaternas": "asiat",
    "asiaters": "asiat",
    "asiatiska": "asiatisk",
    "asiatiskan": "asiatiska",
    "asiatiskans": "asiatiska",
    "asiatiskare": "asiatisk",
    "asiatiskares": "asiatisk",
    "asiatiskas": "asiatiska",
    "asiatiskast": "asiatisk",
    "asiatiskaste": "asiatisk",
    "asiatiskastes": "asiatisk",
    "asiatiskasts": "asiatisk",
    "asiatiske": "asiatiska",
    "asiatiskes": "asiatisk",
    "asiatiskor": "asiatiska",
    "asiatiskorna": "asiatiska",
    "asiatiskornas": "asiatiska",
    "asiatiskors": "asiatiska",
    "asiatisks": "asiatisk",
    "asiatiskt": "asiatisk",
    "asiatiskts": "asiatisk",
    "asiats": "asiat",
    "asimuten": "asimut",
    "asimutens": "asimut",
    "asimuter": "asimut",
    "asimuterna": "asimut",
    "asimuternas": "asimut",
    "asimuters": "asimut",
    "asimuts": "asimut",
    "ask": "aska",
    "askad": "aska",
    "askade": "aska",
    "askades": "aska",
    "askads": "aska",
    "askan": "aska",
    "askande": "aska",
    "askanden": "askande",
    "askandena": "askande",
    "askandenas": "askande",
    "askandens": "askande",
    "askandes": "askande",
    "askandet": "askande",
    "askandets": "askande",
    "askans": "aska",
    "askar": "aska",
    "askarna": "ask",
    "askarnas": "ask",
    "askars": "ask",
    "askas": "aska",
    "askat": "aska",
    "askats": "aska",
    "askblonda": "askblond",
    "askblondare": "askblond",
    "askblondares": "askblond",
    "askblondas": "askblond",
    "askblondast": "askblond",
    "askblondaste": "askblond",
    "askblondastes": "askblond",
    "askblondasts": "askblond",
    "askblonde": "askblond",
    "askblondes": "askblond",
    "askblonds": "askblond",
    "askblont": "askblond",
    "askblonts": "askblond",
    "asken": "ask",
    "askenasen": "askenas",
    "askenasens": "askenas",
    "askenaser": "askenas",
    "askenaserna": "askenas",
    "askenasernas": "askenas",
    "askenasers": "askenas",
    "askens": "ask",
    "askeruptionen": "askeruption",
    "askeruptionens": "askeruption",
    "askeruptioner": "askeruption",
    "askeruptionerna": "askeruption",
    "askeruptionernas": "askeruption",
    "askeruptioners": "askeruption",
    "askeruptions": "askeruption",
    "askes": "aske",
    "askesen": "askes",
    "askesens": "askes",
    "asket": "aske",
    "asketen": "asket",
    "asketens": "asket",
    "asketer": "asket",
    "asketerna": "asket",
    "asketernas": "asket",
    "asketers": "asket",
    "asketiska": "asketisk",
    "asketiskare": "asketisk",
    "asketiskares": "asketisk",
    "asketiskas": "asketisk",
    "asketiskast": "asketisk",
    "asketiskaste": "asketisk",
    "asketiskastes": "asketisk",
    "asketiskasts": "asketisk",
    "asketiske": "asketisk",
    "asketiskes": "asketisk",
    "asketisks": "asketisk",
    "asketiskt": "asketisk",
    "asketiskts": "asketisk",
    "asketismen": "asketism",
    "asketismens": "asketism",
    "asketismer": "asketism",
    "asketismerna": "asketism",
    "asketismernas": "asketism",
    "asketismers": "asketism",
    "asketisms": "asketism",
    "askets": "asket",
    "askexplosionen": "askexplosion",
    "askexplosionens": "askexplosion",
    "askexplosioner": "askexplosion",
    "askexplosionerna": "askexplosion",
    "askexplosionernas": "askexplosion",
    "askexplosioners": "askexplosion",
    "askexplosions": "askexplosion",
    "askfaten": "askfat",
    "askfatens": "askfat",
    "askfatet": "askfat",
    "askfatets": "askfat",
    "askfats": "askfat",
    "askgråa": "askgrå",
    "askgråare": "askgrå",
    "askgråares": "askgrå",
    "askgråas": "askgrå",
    "askgråast": "askgrå",
    "askgråaste": "askgrå",
    "askgråastes": "askgrå",
    "askgråasts": "askgrå",
    "askgråe": "askgrå",
    "askgråes": "askgrå",
    "askgrås": "askgrå",
    "askgrått": "askgrå",
    "askgråtts": "askgrå",
    "askhoten": "askhot",
    "askhotens": "askhot",
    "askhotet": "askhot",
    "askhotets": "askhot",
    "askhots": "askhot",
    "askhögar": "askhög",
    "askhögarna": "askhög",
    "askhögarnas": "askhög",
    "askhögars": "askhög",
    "askhögen": "askhög",
    "askhögens": "askhög",
    "askhögs": "askhög",
    "askkoncentrationen": "askkoncentration",
    "askkoncentrationens": "askkoncentration",
    "askkoncentrationer": "askkoncentration",
    "askkoncentrationerna": "askkoncentration",
    "askkoncentrationernas": "askkoncentration",
    "askkoncentrationers": "askkoncentration",
    "askkoncentrations": "askkoncentration",
    "askkoppar": "askkopp",
    "askkopparna": "askkopp",
    "askkopparnas": "askkopp",
    "askkoppars": "askkopp",
    "askkoppen": "askkopp",
    "askkoppens": "askkopp",
    "askkopps": "askkopp",
    "askmolnen": "askmoln",
    "askmolnens": "askmoln",
    "askmolnet": "askmoln",
    "askmolnets": "askmoln",
    "askmolns": "askmoln",
    "askonsdagar": "askonsdag",
    "askonsdagarna": "askonsdag",
    "askonsdagarnas": "askonsdag",
    "askonsdagars": "askonsdag",
    "askonsdagen": "askonsdag",
    "askonsdagens": "askonsdag",
    "askonsdags": "askonsdag",
    "askorbinsyran": "askorbinsyra",
    "askorbinsyrans": "askorbinsyra",
    "askorbinsyras": "askorbinsyra",
    "askorbinsyre": "askorbinsyra",
    "askorbinsyror": "askorbinsyra",
    "askorbinsyrorna": "askorbinsyra",
    "askorbinsyrornas": "askorbinsyra",
    "askorbinsyrors": "askorbinsyra",
    "askpartikeln": "askpartikel",
    "askpartikelns": "askpartikel",
    "askpartikels": "askpartikel",
    "askpartiklar": "askpartikel",
    "askpartiklarna": "askpartikel",
    "askpartiklarnas": "askpartikel",
    "askpartiklars": "askpartikel",
    "askträet": "askträ",
    "askträets": "askträ",
    "askträs": "askträ",
    "askträt": "askträ",
    "askträts": "askträ",
    "askungar": "askunge",
    "askungarna": "askunge",
    "askungarnas": "askunge",
    "askungars": "askunge",
    "askungen": "askunge",
    "askungens": "askunge",
    "askunges": "askunge",
    "asociala": "asocial",
    "asocialare": "asocial",
    "asocialares": "asocial",
    "asocialas": "asocial",
    "asocialast": "asocial",
    "asocialaste": "asocial",
    "asocialastes": "asocial",
    "asocialasts": "asocial",
    "asociale": "asocial",
    "asociales": "asocial",
    "asocialiteten": "asocialitet",
    "asocialitetens": "asocialitet",
    "asocialiteter": "asocialitet",
    "asocialiteterna": "asocialitet",
    "asocialiteternas": "asocialitet",
    "asocialiteters": "asocialitet",
    "asocialitets": "asocialitet",
    "asocials": "asocial",
    "asocialt": "asocial",
    "asocialts": "asocial",
    "aspackade": "aspackad",
    "aspackades": "aspackad",
    "aspackads": "aspackad",
    "aspackat": "aspackad",
    "aspackats": "aspackad",
    "aspar": "asp",
    "asparna": "asp",
    "asparnas": "asp",
    "aspars": "asp",
    "aspbarken": "aspbark",
    "aspbarkens": "aspbark",
    "aspbarks": "aspbark",
    "aspdungar": "aspdunge",
    "aspdungarna": "aspdunge",
    "aspdungarnas": "aspdunge",
    "aspdungars": "aspdunge",
    "aspdungen": "aspdunge",
    "aspdungens": "aspdunge",
    "aspdunges": "aspdunge",
    "aspekten": "aspekt",
    "aspektens": "aspekt",
    "aspekter": "aspekt",
    "aspekterna": "aspekt",
    "aspekternas": "aspekt",
    "aspekters": "aspekt",
    "aspekts": "aspekt",
    "aspen": "asp",
    "aspens": "asp",
    "aspes": "aspe",
    "aspet": "aspe",
    "aspets": "aspe",
    "aspiranten": "aspirant",
    "aspirantens": "aspirant",
    "aspiranter": "aspirant",
    "aspiranterna": "aspirant",
    "aspiranternas": "aspirant",
    "aspiranters": "aspirant",
    "aspirants": "aspirant",
    "aspirationen": "aspiration",
    "aspirationens": "aspiration",
    "aspirationer": "aspiration",
    "aspirationerna": "aspiration",
    "aspirationernas": "aspiration",
    "aspirationers": "aspiration",
    "aspirations": "aspiration",
    "aspirerad": "aspirera",
    "aspirerade": "aspirera",
    "aspirerades": "aspirera",
    "aspirerads": "aspirera",
    "aspirerande": "aspirera",
    "aspireranden": "aspirerande",
    "aspirerandena": "aspirerande",
    "aspirerandenas": "aspirerande",
    "aspirerandens": "aspirerande",
    "aspirerandes": "aspirerande",
    "aspirerandet": "aspirerande",
    "aspirerandets": "aspirerande",
    "aspirerar": "aspirera",
    "aspireras": "aspirera",
    "aspirerat": "aspirera",
    "aspirerats": "aspirera",
    "aspirerbara": "aspirerbar",
    "aspirerbarare": "aspirerbar",
    "aspirerbarares": "aspirerbar",
    "aspirerbaras": "aspirerbar",
    "aspirerbarast": "aspirerbar",
    "aspirerbaraste": "aspirerbar",
    "aspirerbarastes": "aspirerbar",
    "aspirerbarasts": "aspirerbar",
    "aspirerbare": "aspirerbar",
    "aspirerbares": "aspirerbar",
    "aspirerbarheten": "aspirerbarhet",
    "aspirerbarhetens": "aspirerbarhet",
    "aspirerbarhets": "aspirerbarhet",
    "aspirerbars": "aspirerbar",
    "aspirerbart": "aspirerbar",
    "aspirerbarts": "aspirerbar",
    "aspireringar": "aspirering",
    "aspireringarna": "aspirering",
    "aspireringarnas": "aspirering",
    "aspireringars": "aspirering",
    "aspireringen": "aspirering",
    "aspireringens": "aspirering",
    "aspirerings": "aspirering",
    "aspirinen": "aspirin",
    "aspirinens": "aspirin",
    "aspiriner": "aspirin",
    "aspirinerna": "aspirin",
    "aspirinernas": "aspirin",
    "aspiriners": "aspirin",
    "aspirinet": "aspirin",
    "aspirinets": "aspirin",
    "aspirins": "aspirin",
    "asplöven": "asplöv",
    "asplövens": "asplöv",
    "asplövet": "asplöv",
    "asplövets": "asplöv",
    "asplövs": "asplöv",
    "asps": "asp",
    "assegajen": "assegaj",
    "assegajens": "assegaj",
    "assegajer": "assegaj",
    "assegajerna": "assegaj",
    "assegajernas": "assegaj",
    "assegajers": "assegaj",
    "assegajs": "assegaj",
    "assen": "ass",
    "assens": "ass",
    "assessorer": "assessor",
    "assessorerna": "assessor",
    "assessorernas": "assessor",
    "assessorers": "assessor",
    "assessorn": "assessor",
    "assessorns": "assessor",
    "assessors": "assessor",
    "asset": "ass",
    "assets": "ass",
    "assietten": "assiett",
    "assiettens": "assiett",
    "assietter": "assiett",
    "assietterna": "assiett",
    "assietternas": "assiett",
    "assietters": "assiett",
    "assietts": "assiett",
    "assignanten": "assignant",
    "assignantens": "assignant",
    "assignanter": "assignant",
    "assignanterna": "assignant",
    "assignanternas": "assignant",
    "assignanters": "assignant",
    "assignants": "assignant",
    "assignationen": "assignation",
    "assignationens": "assignation",
    "assignationer": "assignation",
    "assignationerna": "assignation",
    "assignationernas": "assignation",
    "assignationers": "assignation",
    "assignations": "assignation",
    "assignerad": "assignera",
    "assignerade": "assignera",
    "assignerades": "assignera",
    "assignerads": "assignera",
    "assignerande": "assignera",
    "assigneranden": "assignerande",
    "assignerandena": "assignerande",
    "assignerandenas": "assignerande",
    "assignerandens": "assignerande",
    "assignerandes": "assignerande",
    "assignerandet": "assignerande",
    "assignerandets": "assignerande",
    "assignerar": "assignera",
    "assigneras": "assignera",
    "assignerat": "assignera",
    "assignerats": "assignera",
    "assignerbara": "assignerbar",
    "assignerbarare": "assignerbar",
    "assignerbarares": "assignerbar",
    "assignerbaras": "assignerbar",
    "assignerbarast": "assignerbar",
    "assignerbaraste": "assignerbar",
    "assignerbarastes": "assignerbar",
    "assignerbarasts": "assignerbar",
    "assignerbare": "assignerbar",
    "assignerbares": "assignerbar",
    "assignerbarheten": "assignerbarhet",
    "assignerbarhetens": "assignerbarhet",
    "assignerbarhets": "assignerbarhet",
    "assignerbars": "assignerbar",
    "assignerbart": "assignerbar",
    "assignerbarts": "assignerbar",
    "assigneringar": "assignering",
    "assigneringarna": "assignering",
    "assigneringarnas": "assignering",
    "assigneringars": "assignering",
    "assigneringen": "assignering",
    "assigneringens": "assignering",
    "assignerings": "assignering",
    "assimilationen": "assimilation",
    "assimilationens": "assimilation",
    "assimilationer": "assimilation",
    "assimilationerna": "assimilation",
    "assimilationernas": "assimilation",
    "assimilationers": "assimilation",
    "assimilations": "assimilation",
    "assimilerad": "assimilera",
    "assimilerade": "assimilera",
    "assimilerades": "assimilera",
    "assimilerads": "assimilera",
    "assimilerande": "assimilera",
    "assimileranden": "assimilerande",
    "assimilerandena": "assimilerande",
    "assimilerandenas": "assimilerande",
    "assimilerandens": "assimilerande",
    "assimilerandes": "assimilerande",
    "assimilerandet": "assimilerande",
    "assimilerandets": "assimilerande",
    "assimilerar": "assimilera",
    "assimileras": "assimilera",
    "assimilerat": "assimilera",
    "assimilerats": "assimilera",
    "assimilerbara": "assimilerbar",
    "assimilerbarare": "assimilerbar",
    "assimilerbarares": "assimilerbar",
    "assimilerbaras": "assimilerbar",
    "assimilerbarast": "assimilerbar",
    "assimilerbaraste": "assimilerbar",
    "assimilerbarastes": "assimilerbar",
    "assimilerbarasts": "assimilerbar",
    "assimilerbare": "assimilerbar",
    "assimilerbares": "assimilerbar",
    "assimilerbarheten": "assimilerbarhet",
    "assimilerbarhetens": "assimilerbarhet",
    "assimilerbarhets": "assimilerbarhet",
    "assimilerbars": "assimilerbar",
    "assimilerbart": "assimilerbar",
    "assimilerbarts": "assimilerbar",
    "assimileringar": "assimilering",
    "assimileringarna": "assimilering",
    "assimileringarnas": "assimilering",
    "assimileringars": "assimilering",
    "assimileringen": "assimilering",
    "assimileringens": "assimilering",
    "assimilerings": "assimilering",
    "assistansen": "assistans",
    "assistansens": "assistans",
    "assistanser": "assistans",
    "assistanserna": "assistans",
    "assistansernas": "assistans",
    "assistansers": "assistans",
    "assisten": "assist",
    "assistens": "assist",
    "assistenten": "assistent",
    "assistentens": "assistent",
    "assistenter": "assistent",
    "assistenterna": "assistent",
    "assistenternas": "assistent",
    "assistenters": "assistent",
    "assistents": "assistent",
    "assister": "assist",
    "assisterad": "assistera",
    "assisterade": "assistera",
    "assisterades": "assistera",
    "assisterads": "assistera",
    "assisterande": "assistera",
    "assisteranden": "assisterande",
    "assisterandena": "assisterande",
    "assisterandenas": "assisterande",
    "assisterandens": "assisterande",
    "assisterandes": "assisterande",
    "assisterandet": "assisterande",
    "assisterandets": "assisterande",
    "assisterar": "assistera",
    "assisteras": "assistera",
    "assisterat": "assistera",
    "assisterats": "assistera",
    "assisterbara": "assisterbar",
    "assisterbarare": "assisterbar",
    "assisterbarares": "assisterbar",
    "assisterbaras": "assisterbar",
    "assisterbarast": "assisterbar",
    "assisterbaraste": "assisterbar",
    "assisterbarastes": "assisterbar",
    "assisterbarasts": "assisterbar",
    "assisterbare": "assisterbar",
    "assisterbares": "assisterbar",
    "assisterbarheten": "assisterbarhet",
    "assisterbarhetens": "assisterbarhet",
    "assisterbarhets": "assisterbarhet",
    "assisterbars": "assisterbar",
    "assisterbart": "assisterbar",
    "assisterbarts": "assisterbar",
    "assisteringar": "assistering",
    "assisteringarna": "assistering",
    "assisteringarnas": "assistering",
    "assisteringars": "assistering",
    "assisteringen": "assistering",
    "assisteringens": "assistering",
    "assisterings": "assistering",
    "assisterna": "assist",
    "assisternas": "assist",
    "assisters": "assist",
    "assists": "assist",
    "associationen": "association",
    "associationens": "association",
    "associationer": "association",
    "associationerna": "association",
    "associationernas": "association",
    "associationers": "association",
    "associations": "association",
    "associationsbanan": "associationsbana",
    "associationsbanans": "associationsbana",
    "associationsbanas": "associationsbana",
    "associationsbane": "associationsbana",
    "associationsbanor": "associationsbana",
    "associationsbanorna": "associationsbana",
    "associationsbanornas": "associationsbana",
    "associationsbanors": "associationsbana",
    "associationskedjan": "associationskedja",
    "associationskedjans": "associationskedja",
    "associationskedjas": "associationskedja",
    "associationskedje": "associationskedja",
    "associationskedjor": "associationskedja",
    "associationskedjorna": "associationskedja",
    "associationskedjornas": "associationskedja",
    "associationskedjors": "associationskedja",
    "associationslexika": "associationslexikon",
    "associationslexikas": "associationslexikon",
    "associationslexikonen": "associationslexikon",
    "associationslexikonens": "associationslexikon",
    "associationslexikonet": "associationslexikon",
    "associationslexikonets": "associationslexikon",
    "associationslexikons": "associationslexikon",
    "associationspsykologien": "associationspsykologi",
    "associationspsykologiens": "associationspsykologi",
    "associationspsykologin": "associationspsykologi",
    "associationspsykologins": "associationspsykologi",
    "associationspsykologis": "associationspsykologi",
    "associativa": "associativ",
    "associativare": "associativ",
    "associativares": "associativ",
    "associativas": "associativ",
    "associativast": "associativ",
    "associativaste": "associativ",
    "associativastes": "associativ",
    "associativasts": "associativ",
    "associative": "associativ",
    "associatives": "associativ",
    "associativs": "associativ",
    "associativt": "associativ",
    "associativts": "associativ",
    "associerad": "associera",
    "associerade": "associera",
    "associerades": "associera",
    "associerads": "associera",
    "associerande": "associera",
    "associeranden": "associerande",
    "associerandena": "associerande",
    "associerandenas": "associerande",
    "associerandens": "associerande",
    "associerandes": "associerande",
    "associerandet": "associerande",
    "associerandets": "associerande",
    "associerar": "associera",
    "associeras": "associera",
    "associerat": "associera",
    "associerats": "associera",
    "associerbara": "associerbar",
    "associerbarare": "associerbar",
    "associerbarares": "associerbar",
    "associerbaras": "associerbar",
    "associerbarast": "associerbar",
    "associerbaraste": "associerbar",
    "associerbarastes": "associerbar",
    "associerbarasts": "associerbar",
    "associerbare": "associerbar",
    "associerbares": "associerbar",
    "associerbarheten": "associerbarhet",
    "associerbarhetens": "associerbarhet",
    "associerbarhets": "associerbarhet",
    "associerbars": "associerbar",
    "associerbart": "associerbar",
    "associerbarts": "associerbar",
    "associeringar": "associering",
    "associeringarna": "associering",
    "associeringarnas": "associering",
    "associeringars": "associering",
    "associeringen": "associering",
    "associeringens": "associering",
    "associerings": "associering",
    "assonansen": "assonans",
    "assonansens": "assonans",
    "assonanser": "assonans",
    "assonanserna": "assonans",
    "assonansernas": "assonans",
    "assonansers": "assonans",
    "assuradören": "assuradör",
    "assuradörens": "assuradör",
    "assuradörer": "assuradör",
    "assuradörerna": "assuradör",
    "assuradörernas": "assuradör",
    "assuradörers": "assuradör",
    "assuradörs": "assuradör",
    "assuransen": "assurans",
    "assuransens": "assurans",
    "assuranser": "assurans",
    "assuranserna": "assurans",
    "assuransernas": "assurans",
    "assuransers": "assurans",
    "assuranssprut": "assuransspruta",
    "assuranssprutan": "assuransspruta",
    "assuranssprutans": "assuransspruta",
    "assuranssprutas": "assuransspruta",
    "assuranssprute": "assuransspruta",
    "assuranssprutor": "assuransspruta",
    "assuranssprutorna": "assuransspruta",
    "assuranssprutornas": "assuransspruta",
    "assuranssprutors": "assuransspruta",
    "assuransspruts": "assuransspruta",
    "assurerad": "assurera",
    "assurerade": "assurera",
    "assurerades": "assurera",
    "assurerads": "assurera",
    "assurerande": "assurera",
    "assureranden": "assurerande",
    "assurerandena": "assurerande",
    "assurerandenas": "assurerande",
    "assurerandens": "assurerande",
    "assurerandes": "assurerande",
    "assurerandet": "assurerande",
    "assurerandets": "assurerande",
    "assurerar": "assurera",
    "assureras": "assurera",
    "assurerat": "assurera",
    "assurerats": "assurera",
    "assurerbara": "assurerbar",
    "assurerbarare": "assurerbar",
    "assurerbarares": "assurerbar",
    "assurerbaras": "assurerbar",
    "assurerbarast": "assurerbar",
    "assurerbaraste": "assurerbar",
    "assurerbarastes": "assurerbar",
    "assurerbarasts": "assurerbar",
    "assurerbare": "assurerbar",
    "assurerbares": "assurerbar",
    "assurerbarheten": "assurerbarhet",
    "assurerbarhetens": "assurerbarhet",
    "assurerbarhets": "assurerbarhet",
    "assurerbars": "assurerbar",
    "assurerbart": "assurerbar",
    "assurerbarts": "assurerbar",
    "assureringar": "assurering",
    "assureringarna": "assurering",
    "assureringarnas": "assurering",
    "assureringars": "assurering",
    "assureringen": "assurering",
    "assureringens": "assurering",
    "assurerings": "assurering",
    "assyriern": "assyrier",
    "assyrierna": "assyrier",
    "assyriernas": "assyrier",
    "assyrierns": "assyrier",
    "assyriers": "assyrier",
    "assyrisk": "assyriska",
    "assyriska": "assyrisk",
    "assyriskan": "assyriska",
    "assyriskans": "assyriska",
    "assyriskare": "assyrisk",
    "assyriskares": "assyrisk",
    "assyriskas": "assyriska",
    "assyriskast": "assyrisk",
    "assyriskaste": "assyrisk",
    "assyriskastes": "assyrisk",
    "assyriskasts": "assyrisk",
    "assyriske": "assyriska",
    "assyriskes": "assyrisk",
    "assyriskor": "assyriska",
    "assyriskorna": "assyriska",
    "assyriskornas": "assyriska",
    "assyriskors": "assyriska",
    "assyrisks": "assyrisk",
    "assyriskt": "assyrisk",
    "assyriskts": "assyrisk",
    "astaten": "astat",
    "astatens": "astat",
    "astats": "astat",
    "astenien": "asteni",
    "asteniens": "asteni",
    "astenier": "asteni",
    "astenierna": "asteni",
    "asteniernas": "asteni",
    "asteniers": "asteni",
    "astenikern": "asteniker",
    "astenikerna": "asteniker",
    "astenikernas": "asteniker",
    "astenikerns": "asteniker",
    "astenikers": "asteniker",
    "astenin": "asteni",
    "astenins": "asteni",
    "astenis": "asteni",
    "asteniska": "astenisk",
    "asteniskare": "astenisk",
    "asteniskares": "astenisk",
    "asteniskas": "astenisk",
    "asteniskast": "astenisk",
    "asteniskaste": "astenisk",
    "asteniskastes": "astenisk",
    "asteniskasts": "astenisk",
    "asteniske": "astenisk",
    "asteniskes": "astenisk",
    "astenisks": "astenisk",
    "asteniskt": "astenisk",
    "asteniskts": "astenisk",
    "asterisken": "asterisk",
    "asteriskens": "asterisk",
    "asterisker": "asterisk",
    "asteriskerna": "asterisk",
    "asteriskernas": "asterisk",
    "asteriskers": "asterisk",
    "asterisks": "asterisk",
    "astern": "aster",
    "asterns": "aster",
    "asteroiden": "asteroid",
    "asteroidens": "asteroid",
    "asteroider": "asteroid",
    "asteroiderna": "asteroid",
    "asteroidernas": "asteroid",
    "asteroiders": "asteroid",
    "asteroidnedfallen": "asteroidnedfall",
    "asteroidnedfallens": "asteroidnedfall",
    "asteroidnedfallet": "asteroidnedfall",
    "asteroidnedfallets": "asteroidnedfall",
    "asteroidnedfalls": "asteroidnedfall",
    "asteroids": "asteroid",
    "asters": "aster",
    "astigmatikern": "astigmatiker",
    "astigmatikerna": "astigmatiker",
    "astigmatikernas": "astigmatiker",
    "astigmatikerns": "astigmatiker",
    "astigmatikers": "astigmatiker",
    "astigmatiska": "astigmatisk",
    "astigmatiskare": "astigmatisk",
    "astigmatiskares": "astigmatisk",
    "astigmatiskas": "astigmatisk",
    "astigmatiskast": "astigmatisk",
    "astigmatiskaste": "astigmatisk",
    "astigmatiskastes": "astigmatisk",
    "astigmatiskasts": "astigmatisk",
    "astigmatiske": "astigmatisk",
    "astigmatiskes": "astigmatisk",
    "astigmatisks": "astigmatisk",
    "astigmatiskt": "astigmatisk",
    "astigmatiskts": "astigmatisk",
    "astigmatismen": "astigmatism",
    "astigmatismens": "astigmatism",
    "astigmatismer": "astigmatism",
    "astigmatismerna": "astigmatism",
    "astigmatismernas": "astigmatism",
    "astigmatismers": "astigmatism",
    "astigmatisms": "astigmatism",
    "astman": "astma",
    "astmans": "astma",
    "astmas": "astma",
    "astmatikern": "astmatiker",
    "astmatikerna": "astmatiker",
    "astmatikernas": "astmatiker",
    "astmatikerns": "astmatiker",
    "astmatikers": "astmatiker",
    "astmatiska": "astmatisk",
    "astmatiskare": "astmatisk",
    "astmatiskares": "astmatisk",
    "astmatiskas": "astmatisk",
    "astmatiskast": "astmatisk",
    "astmatiskaste": "astmatisk",
    "astmatiskastes": "astmatisk",
    "astmatiskasts": "astmatisk",
    "astmatiske": "astmatisk",
    "astmatiskes": "astmatisk",
    "astmatisks": "astmatisk",
    "astmatiskt": "astmatisk",
    "astmatiskts": "astmatisk",
    "astrakanen": "astrakan",
    "astrakanens": "astrakan",
    "astrakaner": "astrakan",
    "astrakanerna": "astrakan",
    "astrakanernas": "astrakan",
    "astrakaners": "astrakan",
    "astrakanet": "astrakan",
    "astrakanets": "astrakan",
    "astrakans": "astrakan",
    "astrala": "astral",
    "astralare": "astral",
    "astralares": "astral",
    "astralas": "astral",
    "astralast": "astral",
    "astralaste": "astral",
    "astralastes": "astral",
    "astralasts": "astral",
    "astrale": "astral",
    "astrales": "astral",
    "astralkroppar": "astralkropp",
    "astralkropparna": "astralkropp",
    "astralkropparnas": "astralkropp",
    "astralkroppars": "astralkropp",
    "astralkroppen": "astralkropp",
    "astralkroppens": "astralkropp",
    "astralkropps": "astralkropp",
    "astrals": "astral",
    "astralt": "astral",
    "astralts": "astral",
    "astrar": "aster",
    "astrarna": "aster",
    "astrarnas": "aster",
    "astrars": "aster",
    "astrofysiken": "astrofysik",
    "astrofysikens": "astrofysik",
    "astrofysikern": "astrofysiker",
    "astrofysikerna": "astrofysiker",
    "astrofysikernas": "astrofysiker",
    "astrofysikerns": "astrofysiker",
    "astrofysikers": "astrofysiker",
    "astrofysiks": "astrofysik",
    "astrologen": "astrolog",
    "astrologens": "astrolog",
    "astrologer": "astrolog",
    "astrologerna": "astrolog",
    "astrologernas": "astrolog",
    "astrologers": "astrolog",
    "astrologien": "astrologi",
    "astrologiens": "astrologi",
    "astrologin": "astrologi",
    "astrologins": "astrologi",
    "astrologis": "astrologi",
    "astrologs": "astrolog",
    "astronauten": "astronaut",
    "astronautens": "astronaut",
    "astronauter": "astronaut",
    "astronauterna": "astronaut",
    "astronauternas": "astronaut",
    "astronauters": "astronaut",
    "astronautiken": "astronautik",
    "astronautikens": "astronautik",
    "astronautiker": "astronautik",
    "astronautikerna": "astronautik",
    "astronautikernas": "astronautik",
    "astronautikers": "astronautik",
    "astronautiks": "astronautik",
    "astronauts": "astronaut",
    "astronomen": "astronom",
    "astronomens": "astronom",
    "astronomer": "astronom",
    "astronomerna": "astronom",
    "astronomernas": "astronom",
    "astronomers": "astronom",
    "astronomien": "astronomi",
    "astronomiens": "astronomi",
    "astronomin": "astronomi",
    "astronomins": "astronomi",
    "astronomis": "astronomi",
    "astronomiska": "astronomisk",
    "astronomiskare": "astronomisk",
    "astronomiskares": "astronomisk",
    "astronomiskas": "astronomisk",
    "astronomiskast": "astronomisk",
    "astronomiskaste": "astronomisk",
    "astronomiskastes": "astronomisk",
    "astronomiskasts": "astronomisk",
    "astronomiske": "astronomisk",
    "astronomiskes": "astronomisk",
    "astronomisks": "astronomisk",
    "astronomiskt": "astronomisk",
    "astronomiskts": "astronomisk",
    "astronoms": "astronom",
    "asylen": "asyl",
    "asylens": "asyl",
    "asyler": "asyl",
    "asylerna": "asyl",
    "asylernas": "asyl",
    "asylers": "asyl",
    "asylmottagningar": "asylmottagning",
    "asylmottagningarna": "asylmottagning",
    "asylmottagningarnas": "asylmottagning",
    "asylmottagningars": "asylmottagning",
    "asylmottagningen": "asylmottagning",
    "asylmottagningens": "asylmottagning",
    "asylmottagnings": "asylmottagning",
    "asyls": "asyl",
    "asylsökanden": "asylsökande",
    "asylsökandena": "asylsökande",
    "asylsökandenas": "asylsökande",
    "asylsökandens": "asylsökande",
    "asylsökandes": "asylsökande",
    "asymmetrien": "asymmetri",
    "asymmetriens": "asymmetri",
    "asymmetrier": "asymmetri",
    "asymmetrierna": "asymmetri",
    "asymmetriernas": "asymmetri",
    "asymmetriers": "asymmetri",
    "asymmetrin": "asymmetri",
    "asymmetrins": "asymmetri",
    "asymmetris": "asymmetri",
    "asymmetriska": "asymmetrisk",
    "asymmetriskare": "asymmetrisk",
    "asymmetriskares": "asymmetrisk",
    "asymmetriskas": "asymmetrisk",
    "asymmetriskast": "asymmetrisk",
    "asymmetriskaste": "asymmetrisk",
    "asymmetriskastes": "asymmetrisk",
    "asymmetriskasts": "asymmetrisk",
    "asymmetriske": "asymmetrisk",
    "asymmetriskes": "asymmetrisk",
    "asymmetrisks": "asymmetrisk",
    "asymmetriskt": "asymmetrisk",
    "asymmetriskts": "asymmetrisk",
    "asymptoten": "asymptot",
    "asymptotens": "asymptot",
    "asymptoter": "asymptot",
    "asymptoterna": "asymptot",
    "asymptoternas": "asymptot",
    "asymptoters": "asymptot",
    "asymptots": "asymptot",
    "asyndesen": "asyndes",
    "asyndesens": "asyndes",
    "asyndeser": "asyndes",
    "asyndeserna": "asyndes",
    "asyndesernas": "asyndes",
    "asyndesers": "asyndes",
    "asyndetiska": "asyndetisk",
    "asyndetiskare": "asyndetisk",
    "asyndetiskares": "asyndetisk",
    "asyndetiskas": "asyndetisk",
    "asyndetiskast": "asyndetisk",
    "asyndetiskaste": "asyndetisk",
    "asyndetiskastes": "asyndetisk",
    "asyndetiskasts": "asyndetisk",
    "asyndetiske": "asyndetisk",
    "asyndetiskes": "asyndetisk",
    "asyndetisks": "asyndetisk",
    "asyndetiskt": "asyndetisk",
    "asyndetiskts": "asyndetisk",
    "asyndetonen": "asyndeton",
    "asyndetonens": "asyndeton",
    "asyndetons": "asyndeton",
    "asynjan": "asynja",
    "asynjans": "asynja",
    "asynjas": "asynja",
    "asynje": "asynja",
    "asynjor": "asynja",
    "asynjorna": "asynja",
    "asynjornas": "asynja",
    "asynjors": "asynja",
    "asynkrona": "asynkron",
    "asynkronare": "asynkron",
    "asynkronares": "asynkron",
    "asynkronas": "asynkron",
    "asynkronast": "asynkron",
    "asynkronaste": "asynkron",
    "asynkronastes": "asynkron",
    "asynkronasts": "asynkron",
    "asynkrone": "asynkron",
    "asynkrones": "asynkron",
    "asynkrons": "asynkron",
    "asynkront": "asynkron",
    "asynkronts": "asynkron",
    "asätar": "asätare",
    "asätaren": "asätare",
    "asätarens": "asätare",
    "asätares": "asätare",
    "asätarna": "asätare",
    "asätarnas": "asätare",
    "ataktiska": "ataktisk",
    "ataktiskare": "ataktisk",
    "ataktiskares": "ataktisk",
    "ataktiskas": "ataktisk",
    "ataktiskast": "ataktisk",
    "ataktiskaste": "ataktisk",
    "ataktiskastes": "ataktisk",
    "ataktiskasts": "ataktisk",
    "ataktiske": "ataktisk",
    "ataktiskes": "ataktisk",
    "ataktisks": "ataktisk",
    "ataktiskt": "ataktisk",
    "ataktiskts": "ataktisk",
    "ataraktikan": "ataraktika",
    "ataraktikana": "ataraktika",
    "ataraktikanas": "ataraktika",
    "ataraktikans": "ataraktika",
    "ataraktikas": "ataraktika",
    "ataraktikat": "ataraktika",
    "ataraktikats": "ataraktika",
    "ataraxien": "ataraxi",
    "ataraxiens": "ataraxi",
    "ataraxin": "ataraxi",
    "ataraxins": "ataraxi",
    "ataraxis": "ataraxi",
    "atavismen": "atavism",
    "atavismens": "atavism",
    "atavismer": "atavism",
    "atavismerna": "atavism",
    "atavismernas": "atavism",
    "atavismers": "atavism",
    "atavisms": "atavism",
    "atavistiska": "atavistisk",
    "atavistiskare": "atavistisk",
    "atavistiskares": "atavistisk",
    "atavistiskas": "atavistisk",
    "atavistiskast": "atavistisk",
    "atavistiskaste": "atavistisk",
    "atavistiskastes": "atavistisk",
    "atavistiskasts": "atavistisk",
    "atavistiske": "atavistisk",
    "atavistiskes": "atavistisk",
    "atavistisks": "atavistisk",
    "atavistiskt": "atavistisk",
    "atavistiskts": "atavistisk",
    "ataxien": "ataxi",
    "ataxiens": "ataxi",
    "ataxier": "ataxi",
    "ataxierna": "ataxi",
    "ataxiernas": "ataxi",
    "ataxiers": "ataxi",
    "ataxin": "ataxi",
    "ataxins": "ataxi",
    "ataxis": "ataxi",
    "ateismen": "ateism",
    "ateismens": "ateism",
    "ateismer": "ateism",
    "ateismerna": "ateism",
    "ateismernas": "ateism",
    "ateismers": "ateism",
    "ateisms": "ateism",
    "ateisten": "ateist",
    "ateistens": "ateist",
    "ateister": "ateist",
    "ateisterna": "ateist",
    "ateisternas": "ateist",
    "ateisters": "ateist",
    "ateistiska": "ateistisk",
    "ateistiskare": "ateistisk",
    "ateistiskares": "ateistisk",
    "ateistiskas": "ateistisk",
    "ateistiskast": "ateistisk",
    "ateistiskaste": "ateistisk",
    "ateistiskastes": "ateistisk",
    "ateistiskasts": "ateistisk",
    "ateistiske": "ateistisk",
    "ateistiskes": "ateistisk",
    "ateistisks": "ateistisk",
    "ateistiskt": "ateistisk",
    "ateistiskts": "ateistisk",
    "ateists": "ateist",
    "ateljébilden": "ateljébild",
    "ateljébildens": "ateljébild",
    "ateljébilder": "ateljébild",
    "ateljébilderna": "ateljébild",
    "ateljébildernas": "ateljébild",
    "ateljébilders": "ateljébild",
    "ateljébilds": "ateljébild",
    "ateljéer": "ateljé",
    "ateljéerna": "ateljé",
    "ateljéernas": "ateljé",
    "ateljéers": "ateljé",
    "ateljéfönsterna": "ateljéfönster",
    "ateljéfönsternas": "ateljéfönster",
    "ateljéfönsters": "ateljéfönster",
    "ateljéfönstren": "ateljéfönster",
    "ateljéfönstrens": "ateljéfönster",
    "ateljéfönstret": "ateljéfönster",
    "ateljéfönstrets": "ateljéfönster",
    "ateljén": "ateljé",
    "ateljéns": "ateljé",
    "ateljés": "ateljé",
    "ateljévåningar": "ateljévåning",
    "ateljévåningarna": "ateljévåning",
    "ateljévåningarnas": "ateljévåning",
    "ateljévåningars": "ateljévåning",
    "ateljévåningen": "ateljévåning",
    "ateljévåningens": "ateljévåning",
    "ateljévånings": "ateljévåning",
    "atemin": "atemi",
    "atemins": "atemi",
    "atemis": "atemi",
    "atemit": "atemi",
    "atemits": "atemi",
    "ateniennen": "atenienn",
    "ateniennens": "atenienn",
    "atenienner": "atenienn",
    "ateniennerna": "atenienn",
    "ateniennernas": "atenienn",
    "atenienners": "atenienn",
    "atenienns": "atenienn",
    "aterosklerosen": "ateroskleros",
    "aterosklerosens": "ateroskleros",
    "ateroskleroser": "ateroskleros",
    "ateroskleroserna": "ateroskleros",
    "aterosklerosernas": "ateroskleros",
    "aterosklerosers": "ateroskleros",
    "atlantiska": "atlantisk",
    "atlantiskare": "atlantisk",
    "atlantiskares": "atlantisk",
    "atlantiskas": "atlantisk",
    "atlantiskast": "atlantisk",
    "atlantiskaste": "atlantisk",
    "atlantiskastes": "atlantisk",
    "atlantiskasts": "atlantisk",
    "atlantiske": "atlantisk",
    "atlantiskes": "atlantisk",
    "atlantisks": "atlantisk",
    "atlantiskt": "atlantisk",
    "atlantiskts": "atlantisk",
    "atlasbindningar": "atlasbindning",
    "atlasbindningarna": "atlasbindning",
    "atlasbindningarnas": "atlasbindning",
    "atlasbindningars": "atlasbindning",
    "atlasbindningen": "atlasbindning",
    "atlasbindningens": "atlasbindning",
    "atlasbindnings": "atlasbindning",
    "atlasen": "atlas",
    "atlasens": "atlas",
    "atlaser": "atlas",
    "atlaserna": "atlas",
    "atlasernas": "atlas",
    "atlasers": "atlas",
    "atlaset": "atlas",
    "atlasets": "atlas",
    "atlaskot": "atlaskota",
    "atlaskotan": "atlaskota",
    "atlaskotans": "atlaskota",
    "atlaskotas": "atlaskota",
    "atlaskote": "atlaskota",
    "atlaskotor": "atlaskota",
    "atlaskotorna": "atlaskota",
    "atlaskotornas": "atlaskota",
    "atlaskotors": "atlaskota",
    "atlaskots": "atlaskota",
    "atlasspinnar": "atlasspinnare",
    "atlasspinnaren": "atlasspinnare",
    "atlasspinnarens": "atlasspinnare",
    "atlasspinnares": "atlasspinnare",
    "atlasspinnarna": "atlasspinnare",
    "atlasspinnarnas": "atlasspinnare",
    "atleten": "atlet",
    "atletens": "atlet",
    "atleter": "atlet",
    "atleterna": "atlet",
    "atleternas": "atlet",
    "atleters": "atlet",
    "atletiska": "atletisk",
    "atletiskare": "atletisk",
    "atletiskares": "atletisk",
    "atletiskas": "atletisk",
    "atletiskast": "atletisk",
    "atletiskaste": "atletisk",
    "atletiskastes": "atletisk",
    "atletiskasts": "atletisk",
    "atletiske": "atletisk",
    "atletiskes": "atletisk",
    "atletisks": "atletisk",
    "atletiskt": "atletisk",
    "atletiskts": "atletisk",
    "atlets": "atlet",
    "atmosfären": "atmosfär",
    "atmosfärens": "atmosfär",
    "atmosfärer": "atmosfär",
    "atmosfärerna": "atmosfär",
    "atmosfärernas": "atmosfär",
    "atmosfärers": "atmosfär",
    "atmosfärforskar": "atmosfärforskare",
    "atmosfärforskaren": "atmosfärforskare",
    "atmosfärforskarens": "atmosfärforskare",
    "atmosfärforskares": "atmosfärforskare",
    "atmosfärforskarna": "atmosfärforskare",
    "atmosfärforskarnas": "atmosfärforskare",
    "atmosfäriska": "atmosfärisk",
    "atmosfäriskare": "atmosfärisk",
    "atmosfäriskares": "atmosfärisk",
    "atmosfäriskas": "atmosfärisk",
    "atmosfäriskast": "atmosfärisk",
    "atmosfäriskaste": "atmosfärisk",
    "atmosfäriskastes": "atmosfärisk",
    "atmosfäriskasts": "atmosfärisk",
    "atmosfäriske": "atmosfärisk",
    "atmosfäriskes": "atmosfärisk",
    "atmosfärisks": "atmosfärisk",
    "atmosfäriskt": "atmosfärisk",
    "atmosfäriskts": "atmosfärisk",
    "atmosfärkemisten": "atmosfärkemist",
    "atmosfärkemistens": "atmosfärkemist",
    "atmosfärkemister": "atmosfärkemist",
    "atmosfärkemisterna": "atmosfärkemist",
    "atmosfärkemisternas": "atmosfärkemist",
    "atmosfärkemisters": "atmosfärkemist",
    "atmosfärkemists": "atmosfärkemist",
    "atmosfärs": "atmosfär",
    "atmosfärslagerna": "atmosfärslager",
    "atmosfärslagernas": "atmosfärslager",
    "atmosfärslagers": "atmosfärslager",
    "atmosfärslagren": "atmosfärslager",
    "atmosfärslagrens": "atmosfärslager",
    "atmosfärslagret": "atmosfärslager",
    "atmosfärslagrets": "atmosfärslager",
    "atmosfärstrycken": "atmosfärstryck",
    "atmosfärstryckens": "atmosfärstryck",
    "atmosfärstrycket": "atmosfärstryck",
    "atmosfärstryckets": "atmosfärstryck",
    "atmosfärstrycks": "atmosfärstryck",
    "atollen": "atoll",
    "atollens": "atoll",
    "atoller": "atoll",
    "atollerna": "atoll",
    "atollernas": "atoll",
    "atollers": "atoll",
    "atolls": "atoll",
    "atombombad": "atombomba",
    "atombombade": "atombomba",
    "atombombades": "atombomba",
    "atombombads": "atombomba",
    "atombombande": "atombomba",
    "atombombanden": "atombombande",
    "atombombandena": "atombombande",
    "atombombandenas": "atombombande",
    "atombombandens": "atombombande",
    "atombombandes": "atombombande",
    "atombombandet": "atombombande",
    "atombombandets": "atombombande",
    "atombombar": "atombomba",
    "atombombas": "atombomba",
    "atombombat": "atombomba",
    "atombombats": "atombomba",
    "atombomben": "atombomb",
    "atombombens": "atombomb",
    "atombomber": "atombomb",
    "atombomberna": "atombomb",
    "atombombernas": "atombomb",
    "atombombers": "atombomb",
    "atombombs": "atombomb",
    "atombombsfällningar": "atombombsfällning",
    "atombombsfällningarna": "atombombsfällning",
    "atombombsfällningarnas": "atombombsfällning",
    "atombombsfällningars": "atombombsfällning",
    "atombombsfällningen": "atombombsfällning",
    "atombombsfällningens": "atombombsfällning",
    "atombombsfällnings": "atombombsfällning",
    "atombrygg": "atombrygga",
    "atombryggan": "atombrygga",
    "atombryggans": "atombrygga",
    "atombryggas": "atombrygga",
    "atombrygge": "atombrygga",
    "atombryggor": "atombrygga",
    "atombryggorna": "atombrygga",
    "atombryggornas": "atombrygga",
    "atombryggors": "atombrygga",
    "atombryggs": "atombrygga",
    "atomdrivens": "atomdriven",
    "atomdrivet": "atomdriven",
    "atomdrivets": "atomdriven",
    "atomdrivna": "atomdriven",
    "atomdrivnare": "atomdriven",
    "atomdrivnares": "atomdriven",
    "atomdrivnas": "atomdriven",
    "atomdrivnast": "atomdriven",
    "atomdrivnaste": "atomdriven",
    "atomdrivnastes": "atomdriven",
    "atomdrivnasts": "atomdriven",
    "atomdrivne": "atomdriven",
    "atomdrivnes": "atomdriven",
    "atomen": "atom",
    "atomenergien": "atomenergi",
    "atomenergiens": "atomenergi",
    "atomenergin": "atomenergi",
    "atomenergins": "atomenergi",
    "atomenergiorganen": "atomenergiorgan",
    "atomenergiorganens": "atomenergiorgan",
    "atomenergiorganet": "atomenergiorgan",
    "atomenergiorganets": "atomenergiorgan",
    "atomenergiorganisationen": "atomenergiorganisation",
    "atomenergiorganisationens": "atomenergiorganisation",
    "atomenergiorganisationer": "atomenergiorganisation",
    "atomenergiorganisationerna": "atomenergiorganisation",
    "atomenergiorganisationernas": "atomenergiorganisation",
    "atomenergiorganisationers": "atomenergiorganisation",
    "atomenergiorganisations": "atomenergiorganisation",
    "atomenergiorgans": "atomenergiorgan",
    "atomens": "atom",
    "atomer": "atom",
    "atomerna": "atom",
    "atomernas": "atom",
    "atomers": "atom",
    "atomfysiken": "atomfysik",
    "atomfysikens": "atomfysik",
    "atomfysiks": "atomfysik",
    "atomgruppen": "atomgrupp",
    "atomgruppens": "atomgrupp",
    "atomgrupper": "atomgrupp",
    "atomgrupperna": "atomgrupp",
    "atomgruppernas": "atomgrupp",
    "atomgruppers": "atomgrupp",
    "atomgrupps": "atomgrupp",
    "atomismen": "atomism",
    "atomismens": "atomism",
    "atomismer": "atomism",
    "atomismerna": "atomism",
    "atomismernas": "atomism",
    "atomismers": "atomism",
    "atomisms": "atomism",
    "atomistiska": "atomistisk",
    "atomistiskare": "atomistisk",
    "atomistiskares": "atomistisk",
    "atomistiskas": "atomistisk",
    "atomistiskast": "atomistisk",
    "atomistiskaste": "atomistisk",
    "atomistiskastes": "atomistisk",
    "atomistiskasts": "atomistisk",
    "atomistiske": "atomistisk",
    "atomistiskes": "atomistisk",
    "atomistisks": "atomistisk",
    "atomistiskt": "atomistisk",
    "atomistiskts": "atomistisk",
    "atomjonen": "atomjon",
    "atomjonens": "atomjon",
    "atomjoner": "atomjon",
    "atomjonerna": "atomjon",
    "atomjonernas": "atomjon",
    "atomjoners": "atomjon",
    "atomjons": "atomjon",
    "atomklock": "atomklocka",
    "atomklockan": "atomklocka",
    "atomklockans": "atomklocka",
    "atomklockas": "atomklocka",
    "atomklocke": "atomklocka",
    "atomklockor": "atomklocka",
    "atomklockorna": "atomklocka",
    "atomklockornas": "atomklocka",
    "atomklockors": "atomklocka",
    "atomklocks": "atomklocka",
    "atomkraften": "atomkraft",
    "atomkraftens": "atomkraft",
    "atomkraftmikroskopen": "atomkraftmikroskop",
    "atomkraftmikroskopens": "atomkraftmikroskop",
    "atomkraftmikroskopet": "atomkraftmikroskop",
    "atomkraftmikroskopets": "atomkraftmikroskop",
    "atomkraftmikroskops": "atomkraftmikroskop",
    "atomkrafts": "atomkraft",
    "atomkärn": "atomkärna",
    "atomkärnan": "atomkärna",
    "atomkärnans": "atomkärna",
    "atomkärnas": "atomkärna",
    "atomkärne": "atomkärna",
    "atomkärnor": "atomkärna",
    "atomkärnorna": "atomkärna",
    "atomkärnornas": "atomkärna",
    "atomkärnors": "atomkärna",
    "atomkärns": "atomkärna",
    "atommassan": "atommassa",
    "atommassans": "atommassa",
    "atommassas": "atommassa",
    "atommasse": "atommassa",
    "atommassor": "atommassa",
    "atommassorna": "atommassa",
    "atommassornas": "atommassa",
    "atommassors": "atommassa",
    "atommodellen": "atommodell",
    "atommodellens": "atommodell",
    "atommodeller": "atommodell",
    "atommodellerna": "atommodell",
    "atommodellernas": "atommodell",
    "atommodellers": "atommodell",
    "atommodells": "atommodell",
    "atomnummerna": "atomnummer",
    "atomnummernas": "atomnummer",
    "atomnummers": "atomnummer",
    "atomnumren": "atomnummer",
    "atomnumrens": "atomnummer",
    "atomnumret": "atomnummer",
    "atomnumrets": "atomnummer",
    "atomreaktorer": "atomreaktor",
    "atomreaktorerna": "atomreaktor",
    "atomreaktorernas": "atomreaktor",
    "atomreaktorers": "atomreaktor",
    "atomreaktorn": "atomreaktor",
    "atomreaktorns": "atomreaktor",
    "atomreaktors": "atomreaktor",
    "atoms": "atom",
    "atomspektra": "atomspektrum",
    "atomspektrana": "atomspektrum",
    "atomspektranas": "atomspektrum",
    "atomspektras": "atomspektrum",
    "atomspektrena": "atomspektrum",
    "atomspektrenas": "atomspektrum",
    "atomspektrer": "atomspektrum",
    "atomspektrers": "atomspektrum",
    "atomspektret": "atomspektrum",
    "atomspektrets": "atomspektrum",
    "atomspektrumen": "atomspektrum",
    "atomspektrumens": "atomspektrum",
    "atomspektrumet": "atomspektrum",
    "atomspektrumets": "atomspektrum",
    "atomspektrums": "atomspektrum",
    "atomubåtar": "atomubåt",
    "atomubåtarna": "atomubåt",
    "atomubåtarnas": "atomubåt",
    "atomubåtars": "atomubåt",
    "atomubåten": "atomubåt",
    "atomubåtens": "atomubåt",
    "atomubåts": "atomubåt",
    "atomuren": "atomur",
    "atomurens": "atomur",
    "atomuret": "atomur",
    "atomurets": "atomur",
    "atomurs": "atomur",
    "atomvapens": "atomvapen",
    "atomvapnen": "atomvapen",
    "atomvapnens": "atomvapen",
    "atomvapnet": "atomvapen",
    "atomvapnets": "atomvapen",
    "atomvikten": "atomvikt",
    "atomviktens": "atomvikt",
    "atomvikter": "atomvikt",
    "atomvikterna": "atomvikt",
    "atomvikternas": "atomvikt",
    "atomvikters": "atomvikt",
    "atomvikts": "atomvikt",
    "atomvintern": "atomvinter",
    "atomvinterns": "atomvinter",
    "atomvinters": "atomvinter",
    "atomvintrar": "atomvinter",
    "atomvintrarna": "atomvinter",
    "atomvintrarnas": "atomvinter",
    "atomvintrars": "atomvinter",
    "atomära": "atomär",
    "atomärare": "atomär",
    "atomärares": "atomär",
    "atomäras": "atomär",
    "atomärast": "atomär",
    "atomäraste": "atomär",
    "atomärastes": "atomär",
    "atomärasts": "atomär",
    "atomäre": "atomär",
    "atomäres": "atomär",
    "atomärs": "atomär",
    "atomärt": "atomär",
    "atomärts": "atomär",
    "atonala": "atonal",
    "atonalare": "atonal",
    "atonalares": "atonal",
    "atonalas": "atonal",
    "atonalast": "atonal",
    "atonalaste": "atonal",
    "atonalastes": "atonal",
    "atonalasts": "atonal",
    "atonale": "atonal",
    "atonales": "atonal",
    "atonals": "atonal",
    "atonalt": "atonal",
    "atonalts": "atonal",
    "atonien": "atoni",
    "atoniens": "atoni",
    "atonier": "atoni",
    "atonierna": "atoni",
    "atoniernas": "atoni",
    "atoniers": "atoni",
    "atonin": "atoni",
    "atonins": "atoni",
    "atonis": "atoni",
    "atrie": "atrium",
    "atrier": "atrium",
    "atrierna": "atrium",
    "atriernas": "atrium",
    "atriers": "atrium",
    "atriet": "atrium",
    "atriets": "atrium",
    "atriums": "atrium",
    "atrofien": "atrofi",
    "atrofiens": "atrofi",
    "atrofier": "atrofi",
    "atrofierad": "atrofiera",
    "atrofierade": "atrofiera",
    "atrofierades": "atrofiera",
    "atrofierads": "atrofiera",
    "atrofierande": "atrofiera",
    "atrofieranden": "atrofierande",
    "atrofierandena": "atrofierande",
    "atrofierandenas": "atrofierande",
    "atrofierandens": "atrofierande",
    "atrofierandes": "atrofierande",
    "atrofierandet": "atrofierande",
    "atrofierandets": "atrofierande",
    "atrofierar": "atrofiera",
    "atrofieras": "atrofiera",
    "atrofierat": "atrofiera",
    "atrofierats": "atrofiera",
    "atrofierbara": "atrofierbar",
    "atrofierbarare": "atrofierbar",
    "atrofierbarares": "atrofierbar",
    "atrofierbaras": "atrofierbar",
    "atrofierbarast": "atrofierbar",
    "atrofierbaraste": "atrofierbar",
    "atrofierbarastes": "atrofierbar",
    "atrofierbarasts": "atrofierbar",
    "atrofierbare": "atrofierbar",
    "atrofierbares": "atrofierbar",
    "atrofierbarheten": "atrofierbarhet",
    "atrofierbarhetens": "atrofierbarhet",
    "atrofierbarhets": "atrofierbarhet",
    "atrofierbars": "atrofierbar",
    "atrofierbart": "atrofierbar",
    "atrofierbarts": "atrofierbar",
    "atrofieringar": "atrofiering",
    "atrofieringarna": "atrofiering",
    "atrofieringarnas": "atrofiering",
    "atrofieringars": "atrofiering",
    "atrofieringen": "atrofiering",
    "atrofieringens": "atrofiering",
    "atrofierings": "atrofiering",
    "atrofierna": "atrofi",
    "atrofiernas": "atrofi",
    "atrofiers": "atrofi",
    "atrofin": "atrofi",
    "atrofins": "atrofi",
    "atrofis": "atrofi",
    "atrofiska": "atrofisk",
    "atrofiskare": "atrofisk",
    "atrofiskares": "atrofisk",
    "atrofiskas": "atrofisk",
    "atrofiskast": "atrofisk",
    "atrofiskaste": "atrofisk",
    "atrofiskastes": "atrofisk",
    "atrofiskasts": "atrofisk",
    "atrofiske": "atrofisk",
    "atrofiskes": "atrofisk",
    "atrofisks": "atrofisk",
    "atrofiskt": "atrofisk",
    "atrofiskts": "atrofisk",
    "atropinen": "atropin",
    "atropinens": "atropin",
    "atropinet": "atropin",
    "atropinets": "atropin",
    "atropins": "atropin",
    "att-satsen": "att-sats",
    "att-satsens": "att-sats",
    "att-satser": "att-sats",
    "att-satserna": "att-sats",
    "att-satsernas": "att-sats",
    "att-satsers": "att-sats",
    "attachéer": "attaché",
    "attachéerna": "attaché",
    "attachéernas": "attaché",
    "attachéers": "attaché",
    "attachén": "attaché",
    "attachéns": "attaché",
    "attachés": "attaché",
    "attachéväsk": "attachéväska",
    "attachéväskan": "attachéväska",
    "attachéväskans": "attachéväska",
    "attachéväskas": "attachéväska",
    "attachéväske": "attachéväska",
    "attachéväskor": "attachéväska",
    "attachéväskorna": "attachéväska",
    "attachéväskornas": "attachéväska",
    "attachéväskors": "attachéväska",
    "attackdykar": "attackdykare",
    "attackdykaren": "attackdykare",
    "attackdykarens": "attackdykare",
    "attackdykares": "attackdykare",
    "attackdykarna": "attackdykare",
    "attackdykarnas": "attackdykare",
    "attacken": "attack",
    "attackens": "attack",
    "attacker": "attack",
    "attackerad": "attackera",
    "attackerade": "attackera",
    "attackerades": "attackera",
    "attackerads": "attackera",
    "attackerande": "attackera",
    "attackeranden": "attackerande",
    "attackerandena": "attackerande",
    "attackerandenas": "attackerande",
    "attackerandens": "attackerande",
    "attackerandes": "attackerande",
    "attackerandet": "attackerande",
    "attackerandets": "attackerande",
    "attackerar": "attackera",
    "attackeras": "attackera",
    "attackerat": "attackera",
    "attackerats": "attackera",
    "attackerbara": "attackerbar",
    "attackerbarare": "attackerbar",
    "attackerbarares": "attackerbar",
    "attackerbaras": "attackerbar",
    "attackerbarast": "attackerbar",
    "attackerbaraste": "attackerbar",
    "attackerbarastes": "attackerbar",
    "attackerbarasts": "attackerbar",
    "attackerbare": "attackerbar",
    "attackerbares": "attackerbar",
    "attackerbarheten": "attackerbarhet",
    "attackerbarhetens": "attackerbarhet",
    "attackerbarhets": "attackerbarhet",
    "attackerbars": "attackerbar",
    "attackerbart": "attackerbar",
    "attackerbarts": "attackerbar",
    "attackeringar": "attackering",
    "attackeringarna": "attackering",
    "attackeringarnas": "attackering",
    "attackeringars": "attackering",
    "attackeringen": "attackering",
    "attackeringens": "attackering",
    "attackerings": "attackering",
    "attackerna": "attack",
    "attackernas": "attack",
    "attackers": "attack",
    "attackflygen": "attackflyg",
    "attackflygens": "attackflyg",
    "attackflyget": "attackflyg",
    "attackflygets": "attackflyg",
    "attackflygs": "attackflyg",
    "attackförmågan": "attackförmåga",
    "attackförmågans": "attackförmåga",
    "attackförmågas": "attackförmåga",
    "attackförmåge": "attackförmåga",
    "attackförmågor": "attackförmåga",
    "attackförmågorna": "attackförmåga",
    "attackförmågornas": "attackförmåga",
    "attackförmågors": "attackförmåga",
    "attackplanen": "attackplan",
    "attackplanens": "attackplan",
    "attackplanet": "attackplan",
    "attackplanets": "attackplan",
    "attackplans": "attackplan",
    "attacks": "attack",
    "attans": "attan",
    "attentaten": "attentat",
    "attentatens": "attentat",
    "attentatet": "attentat",
    "attentatets": "attentat",
    "attentatorer": "attentator",
    "attentatorerna": "attentator",
    "attentatorernas": "attentator",
    "attentatorers": "attentator",
    "attentatorn": "attentator",
    "attentatorns": "attentator",
    "attentators": "attentator",
    "attentats": "attentat",
    "attentatsmannen": "attentatsman",
    "attentatsmannens": "attentatsman",
    "attentatsmans": "attentatsman",
    "attentatsmän": "attentatsman",
    "attentatsmännen": "attentatsman",
    "attentatsmännens": "attentatsman",
    "attentatsmäns": "attentatsman",
    "attesten": "attest",
    "attestens": "attest",
    "attester": "attest",
    "attesterad": "attestera",
    "attesterade": "attestera",
    "attesterades": "attestera",
    "attesterads": "attestera",
    "attesterande": "attestera",
    "attesteranden": "attesterande",
    "attesterandena": "attesterande",
    "attesterandenas": "attesterande",
    "attesterandens": "attesterande",
    "attesterandes": "attesterande",
    "attesterandet": "attesterande",
    "attesterandets": "attesterande",
    "attesterar": "attestera",
    "attesteras": "attestera",
    "attesterat": "attestera",
    "attesterats": "attestera",
    "attesterbara": "attesterbar",
    "attesterbarare": "attesterbar",
    "attesterbarares": "attesterbar",
    "attesterbaras": "attesterbar",
    "attesterbarast": "attesterbar",
    "attesterbaraste": "attesterbar",
    "attesterbarastes": "attesterbar",
    "attesterbarasts": "attesterbar",
    "attesterbare": "attesterbar",
    "attesterbares": "attesterbar",
    "attesterbarheten": "attesterbarhet",
    "attesterbarhetens": "attesterbarhet",
    "attesterbarhets": "attesterbarhet",
    "attesterbars": "attesterbar",
    "attesterbart": "attesterbar",
    "attesterbarts": "attesterbar",
    "attesteringar": "attestering",
    "attesteringarna": "attestering",
    "attesteringarnas": "attestering",
    "attesteringars": "attestering",
    "attesteringen": "attestering",
    "attesteringens": "attestering",
    "attesterings": "attestering",
    "attesterna": "attest",
    "attesternas": "attest",
    "attesters": "attest",
    "attests": "attest",
    "attik": "attika",
    "attikan": "attika",
    "attikans": "attika",
    "attikas": "attika",
    "attike": "attika",
    "attikor": "attika",
    "attikorna": "attika",
    "attikornas": "attika",
    "attikors": "attika",
    "attiks": "attika",
    "attil": "attila",
    "attilan": "attila",
    "attilans": "attila",
    "attilas": "attila",
    "attile": "attila",
    "attilor": "attila",
    "attilorna": "attila",
    "attilornas": "attila",
    "attilors": "attila",
    "attils": "attila",
    "attiraljen": "attiralj",
    "attiraljens": "attiralj",
    "attiraljer": "attiralj",
    "attiraljerna": "attiralj",
    "attiraljernas": "attiralj",
    "attiraljers": "attiralj",
    "attiraljs": "attiralj",
    "attiska": "attisk",
    "attiskare": "attisk",
    "attiskares": "attisk",
    "attiskas": "attisk",
    "attiskast": "attisk",
    "attiskaste": "attisk",
    "attiskastes": "attisk",
    "attiskasts": "attisk",
    "attiske": "attisk",
    "attiskes": "attisk",
    "attisks": "attisk",
    "attiskt": "attisk",
    "attiskts": "attisk",
    "attityden": "attityd",
    "attitydens": "attityd",
    "attityder": "attityd",
    "attityderna": "attityd",
    "attitydernas": "attityd",
    "attityders": "attityd",
    "attitydförändringar": "attitydförändring",
    "attitydförändringarna": "attitydförändring",
    "attitydförändringarnas": "attitydförändring",
    "attitydförändringars": "attitydförändring",
    "attitydförändringen": "attitydförändring",
    "attitydförändringens": "attitydförändring",
    "attitydförändrings": "attitydförändring",
    "attitydmässiga": "attitydmässig",
    "attitydmässigare": "attitydmässig",
    "attitydmässigares": "attitydmässig",
    "attitydmässigas": "attitydmässig",
    "attitydmässigast": "attitydmässig",
    "attitydmässigaste": "attitydmässig",
    "attitydmässigastes": "attitydmässig",
    "attitydmässigasts": "attitydmässig",
    "attitydmässige": "attitydmässig",
    "attitydmässiges": "attitydmässig",
    "attitydmässigs": "attitydmässig",
    "attitydmässigt": "attitydmässig",
    "attitydmässigts": "attitydmässig",
    "attitydpåverkans": "attitydpåverkan",
    "attityds": "attityd",
    "attitydundersökningar": "attitydundersökning",
    "attitydundersökningarna": "attitydundersökning",
    "attitydundersökningarnas": "attitydundersökning",
    "attitydundersökningars": "attitydundersökning",
    "attitydundersökningen": "attitydundersökning",
    "attitydundersökningens": "attitydundersökning",
    "attitydundersöknings": "attitydundersökning",
    "attraherad": "attrahera",
    "attraherade": "attrahera",
    "attraherades": "attrahera",
    "attraherads": "attrahera",
    "attraherande": "attrahera",
    "attraheranden": "attraherande",
    "attraherandena": "attraherande",
    "attraherandenas": "attraherande",
    "attraherandens": "attraherande",
    "attraherandes": "attraherande",
    "attraherandet": "attraherande",
    "attraherandets": "attraherande",
    "attraherar": "attrahera",
    "attraheras": "attrahera",
    "attraherat": "attrahera",
    "attraherats": "attrahera",
    "attraherbara": "attraherbar",
    "attraherbarare": "attraherbar",
    "attraherbarares": "attraherbar",
    "attraherbaras": "attraherbar",
    "attraherbarast": "attraherbar",
    "attraherbaraste": "attraherbar",
    "attraherbarastes": "attraherbar",
    "attraherbarasts": "attraherbar",
    "attraherbare": "attraherbar",
    "attraherbares": "attraherbar",
    "attraherbarheten": "attraherbarhet",
    "attraherbarhetens": "attraherbarhet",
    "attraherbarhets": "attraherbarhet",
    "attraherbars": "attraherbar",
    "attraherbart": "attraherbar",
    "attraherbarts": "attraherbar",
    "attraheringar": "attrahering",
    "attraheringarna": "attrahering",
    "attraheringarnas": "attrahering",
    "attraheringars": "attrahering",
    "attraheringen": "attrahering",
    "attraheringens": "attrahering",
    "attraherings": "attrahering",
    "attraktionen": "attraktion",
    "attraktionens": "attraktion",
    "attraktioner": "attraktion",
    "attraktionerna": "attraktion",
    "attraktionernas": "attraktion",
    "attraktioners": "attraktion",
    "attraktions": "attraktion",
    "attraktiva": "attraktiv",
    "attraktivare": "attraktiv",
    "attraktivares": "attraktiv",
    "attraktivas": "attraktiv",
    "attraktivast": "attraktiv",
    "attraktivaste": "attraktiv",
    "attraktivastes": "attraktiv",
    "attraktivasts": "attraktiv",
    "attraktive": "attraktiv",
    "attraktives": "attraktiv",
    "attraktivs": "attraktiv",
    "attraktivt": "attraktiv",
    "attraktivts": "attraktiv",
    "attrappen": "attrapp",
    "attrappens": "attrapp",
    "attrapper": "attrapp",
    "attrapperad": "attrappera",
    "attrapperade": "attrappera",
    "attrapperades": "attrappera",
    "attrapperads": "attrappera",
    "attrapperande": "attrappera",
    "attrapperanden": "attrapperande",
    "attrapperandena": "attrapperande",
    "attrapperandenas": "attrapperande",
    "attrapperandens": "attrapperande",
    "attrapperandes": "attrapperande",
    "attrapperandet": "attrapperande",
    "attrapperandets": "attrapperande",
    "attrapperar": "attrappera",
    "attrapperas": "attrappera",
    "attrapperat": "attrappera",
    "attrapperats": "attrappera",
    "attrapperbara": "attrapperbar",
    "attrapperbarare": "attrapperbar",
    "attrapperbarares": "attrapperbar",
    "attrapperbaras": "attrapperbar",
    "attrapperbarast": "attrapperbar",
    "attrapperbaraste": "attrapperbar",
    "attrapperbarastes": "attrapperbar",
    "attrapperbarasts": "attrapperbar",
    "attrapperbare": "attrapperbar",
    "attrapperbares": "attrapperbar",
    "attrapperbarheten": "attrapperbarhet",
    "attrapperbarhetens": "attrapperbarhet",
    "attrapperbarhets": "attrapperbarhet",
    "attrapperbars": "attrapperbar",
    "attrapperbart": "attrapperbar",
    "attrapperbarts": "attrapperbar",
    "attrapperingar": "attrappering",
    "attrapperingarna": "attrappering",
    "attrapperingarnas": "attrappering",
    "attrapperingars": "attrappering",
    "attrapperingen": "attrappering",
    "attrapperingens": "attrappering",
    "attrapperings": "attrappering",
    "attrapperna": "attrapp",
    "attrappernas": "attrapp",
    "attrappers": "attrapp",
    "attrapps": "attrapp",
    "attribuerad": "attribuera",
    "attribuerade": "attribuera",
    "attribuerades": "attribuera",
    "attribuerads": "attribuera",
    "attribuerande": "attribuera",
    "attribueranden": "attribuerande",
    "attribuerandena": "attribuerande",
    "attribuerandenas": "attribuerande",
    "attribuerandens": "attribuerande",
    "attribuerandes": "attribuerande",
    "attribuerandet": "attribuerande",
    "attribuerandets": "attribuerande",
    "attribuerar": "attribuera",
    "attribueras": "attribuera",
    "attribuerat": "attribuera",
    "attribuerats": "attribuera",
    "attribuerbara": "attribuerbar",
    "attribuerbarare": "attribuerbar",
    "attribuerbarares": "attribuerbar",
    "attribuerbaras": "attribuerbar",
    "attribuerbarast": "attribuerbar",
    "attribuerbaraste": "attribuerbar",
    "attribuerbarastes": "attribuerbar",
    "attribuerbarasts": "attribuerbar",
    "attribuerbare": "attribuerbar",
    "attribuerbares": "attribuerbar",
    "attribuerbarheten": "attribuerbarhet",
    "attribuerbarhetens": "attribuerbarhet",
    "attribuerbarhets": "attribuerbarhet",
    "attribuerbars": "attribuerbar",
    "attribuerbart": "attribuerbar",
    "attribuerbarts": "attribuerbar",
    "attribueringar": "attribuering",
    "attribueringarna": "attribuering",
    "attribueringarnas": "attribuering",
    "attribueringars": "attribuering",
    "attribueringen": "attribuering",
    "attribueringens": "attribuering",
    "attribuerings": "attribuering",
    "attributen": "attribut",
    "attributens": "attribut",
    "attributet": "attribut",
    "attributets": "attribut",
    "attributionen": "attribution",
    "attributionens": "attribution",
    "attributioner": "attribution",
    "attributionerna": "attribution",
    "attributionernas": "attribution",
    "attributioners": "attribution",
    "attributions": "attribution",
    "attributiva": "attributiv",
    "attributivare": "attributiv",
    "attributivares": "attributiv",
    "attributivas": "attributiv",
    "attributivast": "attributiv",
    "attributivaste": "attributiv",
    "attributivastes": "attributiv",
    "attributivasts": "attributiv",
    "attributive": "attributiv",
    "attributives": "attributiv",
    "attributivs": "attributiv",
    "attributivt": "attributiv",
    "attributivts": "attributiv",
    "attributs": "attribut",
    "attributsamlingar": "attributsamling",
    "attributsamlingarna": "attributsamling",
    "attributsamlingarnas": "attributsamling",
    "attributsamlingars": "attributsamling",
    "attributsamlingen": "attributsamling",
    "attributsamlingens": "attributsamling",
    "attributsamlings": "attributsamling",
    "atypien": "atypi",
    "atypiens": "atypi",
    "atypier": "atypi",
    "atypierna": "atypi",
    "atypiernas": "atypi",
    "atypiers": "atypi",
    "atypin": "atypi",
    "atypins": "atypi",
    "atypis": "atypi",
    "atypiska": "atypisk",
    "atypiskare": "atypisk",
    "atypiskares": "atypisk",
    "atypiskas": "atypisk",
    "atypiskast": "atypisk",
    "atypiskaste": "atypisk",
    "atypiskastes": "atypisk",
    "atypiskasts": "atypisk",
    "atypiske": "atypisk",
    "atypiskes": "atypisk",
    "atypisks": "atypisk",
    "atypiskt": "atypisk",
    "atypiskts": "atypisk",
    "au-pair-flick": "au-pair-flicka",
    "au-pair-flickan": "au-pair-flicka",
    "au-pair-flickans": "au-pair-flicka",
    "au-pair-flickas": "au-pair-flicka",
    "au-pair-flicke": "au-pair-flicka",
    "au-pair-flickor": "au-pair-flicka",
    "au-pair-flickorna": "au-pair-flicka",
    "au-pair-flickornas": "au-pair-flicka",
    "au-pair-flickors": "au-pair-flicka",
    "au-pair-flicks": "au-pair-flicka",
    "au-pairen": "au-pair",
    "au-pairens": "au-pair",
    "au-pairer": "au-pair",
    "au-pairerna": "au-pair",
    "au-pairernas": "au-pair",
    "au-pairers": "au-pair",
    "au-pairs": "au-pair",
    "auberginen": "aubergine",
    "auberginens": "aubergine",
    "auberginer": "aubergine",
    "auberginerna": "aubergine",
    "auberginernas": "aubergine",
    "auberginers": "aubergine",
    "aubergines": "aubergine",
    "aubergins": "aubergin",
    "audiensen": "audiens",
    "audiensens": "audiens",
    "audienser": "audiens",
    "audienserna": "audiens",
    "audiensernas": "audiens",
    "audiensers": "audiens",
    "audiogrammen": "audiogram",
    "audiogrammens": "audiogram",
    "audiogrammet": "audiogram",
    "audiogrammets": "audiogram",
    "audiograms": "audiogram",
    "audiologien": "audiologi",
    "audiologiens": "audiologi",
    "audiologin": "audiologi",
    "audiologins": "audiologi",
    "audiologis": "audiologi",
    "audiometern": "audiometer",
    "audiometerns": "audiometer",
    "audiometers": "audiometer",
    "audiometrar": "audiometer",
    "audiometrarna": "audiometer",
    "audiometrarnas": "audiometer",
    "audiometrars": "audiometer",
    "audiovisuella": "audiovisuell",
    "audiovisuellare": "audiovisuell",
    "audiovisuellares": "audiovisuell",
    "audiovisuellas": "audiovisuell",
    "audiovisuellast": "audiovisuell",
    "audiovisuellaste": "audiovisuell",
    "audiovisuellastes": "audiovisuell",
    "audiovisuellasts": "audiovisuell",
    "audiovisuelle": "audiovisuell",
    "audiovisuelles": "audiovisuell",
    "audiovisuells": "audiovisuell",
    "audiovisuellt": "audiovisuell",
    "audiovisuellts": "audiovisuell",
    "auditar": "audit",
    "auditarna": "audit",
    "auditarnas": "audit",
    "auditars": "audit",
    "auditen": "audit",
    "auditens": "audit",
    "auditiva": "auditiv",
    "auditivare": "auditiv",
    "auditivares": "auditiv",
    "auditivas": "auditiv",
    "auditivast": "auditiv",
    "auditivaste": "auditiv",
    "auditivastes": "auditiv",
    "auditivasts": "auditiv",
    "auditive": "auditiv",
    "auditives": "auditiv",
    "auditivs": "auditiv",
    "auditivt": "auditiv",
    "auditivts": "auditiv",
    "auditorie": "auditorium",
    "auditorier": "auditorium",
    "auditorierna": "auditorium",
    "auditoriernas": "auditorium",
    "auditoriers": "auditorium",
    "auditoriet": "auditorium",
    "auditoriets": "auditorium",
    "auditoriums": "auditorium",
    "audits": "audit",
    "auditören": "auditör",
    "auditörens": "auditör",
    "auditörer": "auditör",
    "auditörerna": "auditör",
    "auditörernas": "auditör",
    "auditörers": "auditör",
    "auditörn": "auditör",
    "auditörns": "auditör",
    "auditörs": "auditör",
    "audivisuella": "audivisuell",
    "audivisuellare": "audivisuell",
    "audivisuellares": "audivisuell",
    "audivisuellas": "audivisuell",
    "audivisuellast": "audivisuell",
    "audivisuellaste": "audivisuell",
    "audivisuellastes": "audivisuell",
    "audivisuellasts": "audivisuell",
    "audivisuelle": "audivisuell",
    "audivisuelles": "audivisuell",
    "audivisuells": "audivisuell",
    "audivisuellt": "audivisuell",
    "audivisuellts": "audivisuell",
    "auerlamp": "auerlampa",
    "auerlampan": "auerlampa",
    "auerlampans": "auerlampa",
    "auerlampas": "auerlampa",
    "auerlampe": "auerlampa",
    "auerlampor": "auerlampa",
    "auerlamporna": "auerlampa",
    "auerlampornas": "auerlampa",
    "auerlampors": "auerlampa",
    "auerlamps": "auerlampa",
    "auerstrump": "auerstrumpa",
    "auerstrumpan": "auerstrumpa",
    "auerstrumpans": "auerstrumpa",
    "auerstrumpas": "auerstrumpa",
    "auerstrumpe": "auerstrumpa",
    "auerstrumpor": "auerstrumpa",
    "auerstrumporna": "auerstrumpa",
    "auerstrumpornas": "auerstrumpa",
    "auerstrumpors": "auerstrumpa",
    "auerstrumps": "auerstrumpa",
    "augiasstallen": "augiasstall",
    "augiasstallens": "augiasstall",
    "augiasstallet": "augiasstall",
    "augiasstallets": "augiasstall",
    "augiasstalls": "augiasstall",
    "augmenten": "augment",
    "augmentens": "augment",
    "augmentet": "augment",
    "augmentets": "augment",
    "augments": "augment",
    "auguren": "augur",
    "augurens": "augur",
    "augurer": "augur",
    "augurerna": "augur",
    "augurernas": "augur",
    "augurers": "augur",
    "augurs": "augur",
    "augustimånskenet": "augustimånsken",
    "augustimånskenets": "augustimånsken",
    "augustimånskens": "augustimånsken",
    "augustipäronen": "augustipäron",
    "augustipäronens": "augustipäron",
    "augustipäronet": "augustipäron",
    "augustipäronets": "augustipäron",
    "augustipärons": "augustipäron",
    "augustis": "augusti",
    "augustisolar": "augustisol",
    "augustisolarna": "augustisol",
    "augustisolarnas": "augustisol",
    "augustisolars": "augustisol",
    "augustisolen": "augustisol",
    "augustisolens": "augustisol",
    "augustisols": "augustisol",
    "augustnominerade": "augustnominerad",
    "augustnominerades": "augustnominerad",
    "augustnominerads": "augustnominerad",
    "augustnominerat": "augustnominerad",
    "augustnominerats": "augustnominerad",
    "auktionen": "auktion",
    "auktionens": "auktion",
    "auktioner": "auktion",
    "auktionerad": "auktionera",
    "auktionerade": "auktionera",
    "auktionerades": "auktionera",
    "auktionerads": "auktionera",
    "auktionerande": "auktionera",
    "auktioneranden": "auktionerande",
    "auktionerandena": "auktionerande",
    "auktionerandenas": "auktionerande",
    "auktionerandens": "auktionerande",
    "auktionerandes": "auktionerande",
    "auktionerandet": "auktionerande",
    "auktionerandets": "auktionerande",
    "auktionerar": "auktionera",
    "auktioneras": "auktionera",
    "auktionerat": "auktionera",
    "auktionerats": "auktionera",
    "auktionerbara": "auktionerbar",
    "auktionerbarare": "auktionerbar",
    "auktionerbarares": "auktionerbar",
    "auktionerbaras": "auktionerbar",
    "auktionerbarast": "auktionerbar",
    "auktionerbaraste": "auktionerbar",
    "auktionerbarastes": "auktionerbar",
    "auktionerbarasts": "auktionerbar",
    "auktionerbare": "auktionerbar",
    "auktionerbares": "auktionerbar",
    "auktionerbarheten": "auktionerbarhet",
    "auktionerbarhetens": "auktionerbarhet",
    "auktionerbarhets": "auktionerbarhet",
    "auktionerbars": "auktionerbar",
    "auktionerbart": "auktionerbar",
    "auktionerbarts": "auktionerbar",
    "auktioneringar": "auktionering",
    "auktioneringarna": "auktionering",
    "auktioneringarnas": "auktionering",
    "auktioneringars": "auktionering",
    "auktioneringen": "auktionering",
    "auktioneringens": "auktionering",
    "auktionerings": "auktionering",
    "auktionerna": "auktion",
    "auktionernas": "auktion",
    "auktioners": "auktion",
    "auktionisten": "auktionist",
    "auktionistens": "auktionist",
    "auktionister": "auktionist",
    "auktionisterna": "auktionist",
    "auktionisternas": "auktionist",
    "auktionisters": "auktionist",
    "auktionists": "auktionist",
    "auktions": "auktion",
    "auktionsbridgen": "auktionsbridge",
    "auktionsbridgens": "auktionsbridge",
    "auktionsbridges": "auktionsbridge",
    "auktionsförrättar": "auktionsförrättare",
    "auktionsförrättaren": "auktionsförrättare",
    "auktionsförrättarens": "auktionsförrättare",
    "auktionsförrättares": "auktionsförrättare",
    "auktionsförrättarna": "auktionsförrättare",
    "auktionsförrättarnas": "auktionsförrättare",
    "auktionskammar": "auktionskammare",
    "auktionskammaren": "auktionskammare",
    "auktionskammarens": "auktionskammare",
    "auktionskammares": "auktionskammare",
    "auktionskamrar": "auktionskammare",
    "auktionskamrarna": "auktionskammare",
    "auktionskamrarnas": "auktionskammare",
    "auktionskamrars": "auktionskammare",
    "auktionsutropar": "auktionsutropare",
    "auktionsutroparen": "auktionsutropare",
    "auktionsutroparens": "auktionsutropare",
    "auktionsutropares": "auktionsutropare",
    "auktionsutroparna": "auktionsutropare",
    "auktionsutroparnas": "auktionsutropare",
    "auktionsverken": "auktionsverk",
    "auktionsverkens": "auktionsverk",
    "auktionsverket": "auktionsverk",
    "auktionsverkets": "auktionsverk",
    "auktionsverks": "auktionsverk",
    "auktorer": "auktor",
    "auktorerna": "auktor",
    "auktorernas": "auktor",
    "auktorers": "auktor",
    "auktorisationen": "auktorisation",
    "auktorisationens": "auktorisation",
    "auktorisationer": "auktorisation",
    "auktorisationerna": "auktorisation",
    "auktorisationernas": "auktorisation",
    "auktorisationers": "auktorisation",
    "auktorisations": "auktorisation",
    "auktoriserad": "auktorisera",
    "auktoriserade": "auktorisera",
    "auktoriserades": "auktorisera",
    "auktoriserads": "auktorisera",
    "auktoriserande": "auktorisera",
    "auktoriseranden": "auktoriserande",
    "auktoriserandena": "auktoriserande",
    "auktoriserandenas": "auktoriserande",
    "auktoriserandens": "auktoriserande",
    "auktoriserandes": "auktoriserande",
    "auktoriserandet": "auktoriserande",
    "auktoriserandets": "auktoriserande",
    "auktoriserar": "auktorisera",
    "auktoriseras": "auktorisera",
    "auktoriserat": "auktorisera",
    "auktoriserats": "auktorisera",
    "auktoriserbara": "auktoriserbar",
    "auktoriserbarare": "auktoriserbar",
    "auktoriserbarares": "auktoriserbar",
    "auktoriserbaras": "auktoriserbar",
    "auktoriserbarast": "auktoriserbar",
    "auktoriserbaraste": "auktoriserbar",
    "auktoriserbarastes": "auktoriserbar",
    "auktoriserbarasts": "auktoriserbar",
    "auktoriserbare": "auktoriserbar",
    "auktoriserbares": "auktoriserbar",
    "auktoriserbarheten": "auktoriserbarhet",
    "auktoriserbarhetens": "auktoriserbarhet",
    "auktoriserbarhets": "auktoriserbarhet",
    "auktoriserbars": "auktoriserbar",
    "auktoriserbart": "auktoriserbar",
    "auktoriserbarts": "auktoriserbar",
    "auktoriseringar": "auktorisering",
    "auktoriseringarna": "auktorisering",
    "auktoriseringarnas": "auktorisering",
    "auktoriseringars": "auktorisering",
    "auktoriseringen": "auktorisering",
    "auktoriseringens": "auktorisering",
    "auktoriserings": "auktorisering",
    "auktoritativa": "auktoritativ",
    "auktoritativare": "auktoritativ",
    "auktoritativares": "auktoritativ",
    "auktoritativas": "auktoritativ",
    "auktoritativast": "auktoritativ",
    "auktoritativaste": "auktoritativ",
    "auktoritativastes": "auktoritativ",
    "auktoritativasts": "auktoritativ",
    "auktoritative": "auktoritativ",
    "auktoritatives": "auktoritativ",
    "auktoritativs": "auktoritativ",
    "auktoritativt": "auktoritativ",
    "auktoritativts": "auktoritativ",
    "auktoriteten": "auktoritet",
    "auktoritetens": "auktoritet",
    "auktoriteter": "auktoritet",
    "auktoriteterna": "auktoritet",
    "auktoriteternas": "auktoritet",
    "auktoriteters": "auktoritet",
    "auktoritets": "auktoritet",
    "auktoritetsbundenheten": "auktoritetsbundenhet",
    "auktoritetsbundenhetens": "auktoritetsbundenhet",
    "auktoritetsbundenhets": "auktoritetsbundenhet",
    "auktoritetsbundens": "auktoritetsbunden",
    "auktoritetsbundet": "auktoritetsbunden",
    "auktoritetsbundets": "auktoritetsbunden",
    "auktoritetsbundna": "auktoritetsbunden",
    "auktoritetsbundnare": "auktoritetsbunden",
    "auktoritetsbundnares": "auktoritetsbunden",
    "auktoritetsbundnas": "auktoritetsbunden",
    "auktoritetsbundnast": "auktoritetsbunden",
    "auktoritetsbundnaste": "auktoritetsbunden",
    "auktoritetsbundnastes": "auktoritetsbunden",
    "auktoritetsbundnasts": "auktoritetsbunden",
    "auktoritetsbundne": "auktoritetsbunden",
    "auktoritetsbundnes": "auktoritetsbunden",
    "auktoritetstron": "auktoritetstro",
    "auktoritetstrons": "auktoritetstro",
    "auktoritetstros": "auktoritetstro",
    "auktoritära": "auktoritär",
    "auktoritärare": "auktoritär",
    "auktoritärares": "auktoritär",
    "auktoritäras": "auktoritär",
    "auktoritärast": "auktoritär",
    "auktoritäraste": "auktoritär",
    "auktoritärastes": "auktoritär",
    "auktoritärasts": "auktoritär",
    "auktoritäre": "auktoritär",
    "auktoritäres": "auktoritär",
    "auktoritärs": "auktoritär",
    "auktoritärt": "auktoritär",
    "auktoritärts": "auktoritär",
    "auktorn": "auktor",
    "auktorns": "auktor",
    "auktorrätten": "auktorrätt",
    "auktorrättens": "auktorrätt",
    "auktorrätts": "auktorrätt",
    "auktors": "auktor",
    "auktorsrätten": "auktorsrätt",
    "auktorsrättens": "auktorsrätt",
    "auktorsrätts": "auktorsrätt",
    "aul": "aula",
    "aulan": "aula",
    "aulans": "aula",
    "aulas": "aula",
    "aule": "aula",
    "aulor": "aula",
    "aulorna": "aula",
    "aulornas": "aula",
    "aulors": "aula",
    "auls": "aula",
    "auran": "aura",
    "aurans": "aura",
    "auras": "aura",
    "auskultanten": "auskultant",
    "auskultantens": "auskultant",
    "auskultanter": "auskultant",
    "auskultanterna": "auskultant",
    "auskultanternas": "auskultant",
    "auskultanters": "auskultant",
    "auskultants": "auskultant",
    "auskultationen": "auskultation",
    "auskultationens": "auskultation",
    "auskultationer": "auskultation",
    "auskultationerna": "auskultation",
    "auskultationernas": "auskultation",
    "auskultationers": "auskultation",
    "auskultations": "auskultation",
    "auskulterad": "auskultera",
    "auskulterade": "auskultera",
    "auskulterades": "auskultera",
    "auskulterads": "auskultera",
    "auskulterande": "auskultera",
    "auskulteranden": "auskulterande",
    "auskulterandena": "auskulterande",
    "auskulterandenas": "auskulterande",
    "auskulterandens": "auskulterande",
    "auskulterandes": "auskulterande",
    "auskulterandet": "auskulterande",
    "auskulterandets": "auskulterande",
    "auskulterar": "auskultera",
    "auskulteras": "auskultera",
    "auskulterat": "auskultera",
    "auskulterats": "auskultera",
    "auskulterbara": "auskulterbar",
    "auskulterbarare": "auskulterbar",
    "auskulterbarares": "auskulterbar",
    "auskulterbaras": "auskulterbar",
    "auskulterbarast": "auskulterbar",
    "auskulterbaraste": "auskulterbar",
    "auskulterbarastes": "auskulterbar",
    "auskulterbarasts": "auskulterbar",
    "auskulterbare": "auskulterbar",
    "auskulterbares": "auskulterbar",
    "auskulterbarheten": "auskulterbarhet",
    "auskulterbarhetens": "auskulterbarhet",
    "auskulterbarhets": "auskulterbarhet",
    "auskulterbars": "auskulterbar",
    "auskulterbart": "auskulterbar",
    "auskulterbarts": "auskulterbar",
    "auskulteringar": "auskultering",
    "auskulteringarna": "auskultering",
    "auskulteringarnas": "auskultering",
    "auskulteringars": "auskultering",
    "auskulteringen": "auskultering",
    "auskulteringens": "auskultering",
    "auskulterings": "auskultering",
    "auspicie": "auspicier",
    "auspicierna": "auspicier",
    "auspiciernas": "auspicier",
    "auspiciers": "auspicier",
    "australiensar": "australiensare",
    "australiensaren": "australiensare",
    "australiensarens": "australiensare",
    "australiensares": "australiensare",
    "australiensarna": "australiensare",
    "australiensarnas": "australiensare",
    "australiensiska": "australiensisk",
    "australiensiskare": "australiensisk",
    "australiensiskares": "australiensisk",
    "australiensiskas": "australiensisk",
    "australiensiskast": "australiensisk",
    "australiensiskaste": "australiensisk",
    "australiensiskastes": "australiensisk",
    "australiensiskasts": "australiensisk",
    "australiensiske": "australiensisk",
    "australiensiskes": "australiensisk",
    "australiensisks": "australiensisk",
    "australiensiskt": "australiensisk",
    "australiensiskts": "australiensisk",
    "australiern": "australier",
    "australierna": "australier",
    "australiernas": "australier",
    "australierns": "australier",
    "australiers": "australier",
    "australiska": "australisk",
    "australiskan": "australiska",
    "australiskans": "australiska",
    "australiskare": "australisk",
    "australiskares": "australisk",
    "australiskas": "australiska",
    "australiskast": "australisk",
    "australiskaste": "australisk",
    "australiskastes": "australisk",
    "australiskasts": "australisk",
    "australiske": "australiska",
    "australiskes": "australisk",
    "australiskor": "australiska",
    "australiskorna": "australiska",
    "australiskornas": "australiska",
    "australiskors": "australiska",
    "australisks": "australisk",
    "australiskt": "australisk",
    "australiskts": "australisk",
    "autarkien": "autarki",
    "autarkiens": "autarki",
    "autarkier": "autarki",
    "autarkierna": "autarki",
    "autarkiernas": "autarki",
    "autarkiers": "autarki",
    "autarkin": "autarki",
    "autarkins": "autarki",
    "autarkis": "autarki",
    "autenciteten": "autencitet",
    "autencitetens": "autencitet",
    "autenciteter": "autencitet",
    "autenciteterna": "autencitet",
    "autenciteternas": "autencitet",
    "autenciteters": "autencitet",
    "autencitets": "autencitet",
    "autenticerad": "autenticera",
    "autenticerade": "autenticera",
    "autenticerades": "autenticera",
    "autenticerads": "autenticera",
    "autenticerande": "autenticera",
    "autenticeranden": "autenticerande",
    "autenticerandena": "autenticerande",
    "autenticerandenas": "autenticerande",
    "autenticerandens": "autenticerande",
    "autenticerandes": "autenticerande",
    "autenticerandet": "autenticerande",
    "autenticerandets": "autenticerande",
    "autenticerar": "autenticera",
    "autenticeras": "autenticera",
    "autenticerat": "autenticera",
    "autenticerats": "autenticera",
    "autenticerbara": "autenticerbar",
    "autenticerbarare": "autenticerbar",
    "autenticerbarares": "autenticerbar",
    "autenticerbaras": "autenticerbar",
    "autenticerbarast": "autenticerbar",
    "autenticerbaraste": "autenticerbar",
    "autenticerbarastes": "autenticerbar",
    "autenticerbarasts": "autenticerbar",
    "autenticerbare": "autenticerbar",
    "autenticerbares": "autenticerbar",
    "autenticerbarheten": "autenticerbarhet",
    "autenticerbarhetens": "autenticerbarhet",
    "autenticerbarhets": "autenticerbarhet",
    "autenticerbars": "autenticerbar",
    "autenticerbart": "autenticerbar",
    "autenticerbarts": "autenticerbar",
    "autenticeringar": "autenticering",
    "autenticeringarna": "autenticering",
    "autenticeringarnas": "autenticering",
    "autenticeringars": "autenticering",
    "autenticeringen": "autenticering",
    "autenticeringens": "autenticering",
    "autenticerings": "autenticering",
    "autenticiteten": "autenticitet",
    "autenticitetens": "autenticitet",
    "autenticiteter": "autenticitet",
    "autenticiteterna": "autenticitet",
    "autenticiteternas": "autenticitet",
    "autenticiteters": "autenticitet",
    "autenticitets": "autenticitet",
    "autentifierad": "autentifiera",
    "autentifierade": "autentifiera",
    "autentifierades": "autentifiera",
    "autentifierads": "autentifiera",
    "autentifierande": "autentifiera",
    "autentifieranden": "autentifierande",
    "autentifierandena": "autentifierande",
    "autentifierandenas": "autentifierande",
    "autentifierandens": "autentifierande",
    "autentifierandes": "autentifierande",
    "autentifierandet": "autentifierande",
    "autentifierandets": "autentifierande",
    "autentifierar": "autentifiera",
    "autentifieras": "autentifiera",
    "autentifierat": "autentifiera",
    "autentifierats": "autentifiera",
    "autentifierbara": "autentifierbar",
    "autentifierbarare": "autentifierbar",
    "autentifierbarares": "autentifierbar",
    "autentifierbaras": "autentifierbar",
    "autentifierbarast": "autentifierbar",
    "autentifierbaraste": "autentifierbar",
    "autentifierbarastes": "autentifierbar",
    "autentifierbarasts": "autentifierbar",
    "autentifierbare": "autentifierbar",
    "autentifierbares": "autentifierbar",
    "autentifierbarheten": "autentifierbarhet",
    "autentifierbarhetens": "autentifierbarhet",
    "autentifierbarhets": "autentifierbarhet",
    "autentifierbars": "autentifierbar",
    "autentifierbart": "autentifierbar",
    "autentifierbarts": "autentifierbar",
    "autentifieringar": "autentifiering",
    "autentifieringarna": "autentifiering",
    "autentifieringarnas": "autentifiering",
    "autentifieringars": "autentifiering",
    "autentifieringen": "autentifiering",
    "autentifieringens": "autentifiering",
    "autentifierings": "autentifiering",
    "autentiserad": "autentisera",
    "autentiserade": "autentisera",
    "autentiserades": "autentisera",
    "autentiserads": "autentisera",
    "autentiserande": "autentisera",
    "autentiseranden": "autentiserande",
    "autentiserandena": "autentiserande",
    "autentiserandenas": "autentiserande",
    "autentiserandens": "autentiserande",
    "autentiserandes": "autentiserande",
    "autentiserandet": "autentiserande",
    "autentiserandets": "autentiserande",
    "autentiserar": "autentisera",
    "autentiseras": "autentisera",
    "autentiserat": "autentisera",
    "autentiserats": "autentisera",
    "autentiserbara": "autentiserbar",
    "autentiserbarare": "autentiserbar",
    "autentiserbarares": "autentiserbar",
    "autentiserbaras": "autentiserbar",
    "autentiserbarast": "autentiserbar",
    "autentiserbaraste": "autentiserbar",
    "autentiserbarastes": "autentiserbar",
    "autentiserbarasts": "autentiserbar",
    "autentiserbare": "autentiserbar",
    "autentiserbares": "autentiserbar",
    "autentiserbarheten": "autentiserbarhet",
    "autentiserbarhetens": "autentiserbarhet",
    "autentiserbarhets": "autentiserbarhet",
    "autentiserbars": "autentiserbar",
    "autentiserbart": "autentiserbar",
    "autentiserbarts": "autentiserbar",
    "autentiseringar": "autentisering",
    "autentiseringarna": "autentisering",
    "autentiseringarnas": "autentisering",
    "autentiseringars": "autentisering",
    "autentiseringen": "autentisering",
    "autentiseringens": "autentisering",
    "autentiserings": "autentisering",
    "autentiska": "autentisk",
    "autentiskare": "autentisk",
    "autentiskares": "autentisk",
    "autentiskas": "autentisk",
    "autentiskast": "autentisk",
    "autentiskaste": "autentisk",
    "autentiskastes": "autentisk",
    "autentiskasts": "autentisk",
    "autentiske": "autentisk",
    "autentiskes": "autentisk",
    "autentisks": "autentisk",
    "autentiskt": "autentisk",
    "autentiskts": "autentisk",
    "auteuren": "auteur",
    "auteurens": "auteur",
    "auteurer": "auteur",
    "auteurerna": "auteur",
    "auteurernas": "auteur",
    "auteurers": "auteur",
    "auteurs": "auteur",
    "autismen": "autism",
    "autismens": "autism",
    "autismer": "autism",
    "autismerna": "autism",
    "autismernas": "autism",
    "autismers": "autism",
    "autisms": "autism",
    "autisten": "autist",
    "autistens": "autist",
    "autister": "autist",
    "autisterna": "autist",
    "autisternas": "autist",
    "autisters": "autist",
    "autistiska": "autistisk",
    "autistiskare": "autistisk",
    "autistiskares": "autistisk",
    "autistiskas": "autistisk",
    "autistiskast": "autistisk",
    "autistiskaste": "autistisk",
    "autistiskastes": "autistisk",
    "autistiskasts": "autistisk",
    "autistiske": "autistisk",
    "autistiskes": "autistisk",
    "autistisks": "autistisk",
    "autistiskt": "autistisk",
    "autistiskts": "autistisk",
    "autists": "autist",
    "autodaféer": "autodafé",
    "autodaféerna": "autodafé",
    "autodaféernas": "autodafé",
    "autodaféers": "autodafé",
    "autodafén": "autodafé",
    "autodaféns": "autodafé",
    "autodafés": "autodafé",
    "autodidakten": "autodidakt",
    "autodidaktens": "autodidakt",
    "autodidakter": "autodidakt",
    "autodidakterna": "autodidakt",
    "autodidakternas": "autodidakt",
    "autodidakters": "autodidakt",
    "autodidakts": "autodidakt",
    "autodromen": "autodrom",
    "autodromens": "autodrom",
    "autodromer": "autodrom",
    "autodromerna": "autodrom",
    "autodromernas": "autodrom",
    "autodromers": "autodrom",
    "autodroms": "autodrom",
    "autografen": "autograf",
    "autografens": "autograf",
    "autografer": "autograf",
    "autograferna": "autograf",
    "autografernas": "autograf",
    "autografers": "autograf",
    "autografjägar": "autografjägare",
    "autografjägaren": "autografjägare",
    "autografjägarens": "autografjägare",
    "autografjägares": "autografjägare",
    "autografjägarna": "autografjägare",
    "autografjägarnas": "autografjägare",
    "autografs": "autograf",
    "autoklaven": "autoklav",
    "autoklavens": "autoklav",
    "autoklaver": "autoklav",
    "autoklaverna": "autoklav",
    "autoklavernas": "autoklav",
    "autoklavers": "autoklav",
    "autoklavs": "autoklav",
    "autokraten": "autokrat",
    "autokratens": "autokrat",
    "autokrater": "autokrat",
    "autokraterna": "autokrat",
    "autokraternas": "autokrat",
    "autokraters": "autokrat",
    "autokrats": "autokrat",
    "autoktona": "autokton",
    "autoktonare": "autokton",
    "autoktonares": "autokton",
    "autoktonas": "autokton",
    "autoktonast": "autokton",
    "autoktonaste": "autokton",
    "autoktonastes": "autokton",
    "autoktonasts": "autokton",
    "autoktone": "autokton",
    "autoktones": "autokton",
    "autoktons": "autokton",
    "autoktont": "autokton",
    "autoktonts": "autokton",
    "automagiska": "automagisk",
    "automagiskare": "automagisk",
    "automagiskares": "automagisk",
    "automagiskas": "automagisk",
    "automagiskast": "automagisk",
    "automagiskaste": "automagisk",
    "automagiskastes": "automagisk",
    "automagiskasts": "automagisk",
    "automagiske": "automagisk",
    "automagiskes": "automagisk",
    "automagisks": "automagisk",
    "automagiskt": "automagisk",
    "automagiskts": "automagisk",
    "automatateorien": "automatateori",
    "automatateoriens": "automatateori",
    "automatateorin": "automatateori",
    "automatateorins": "automatateori",
    "automatateoris": "automatateori",
    "automaten": "automat",
    "automatens": "automat",
    "automater": "automat",
    "automaterna": "automat",
    "automaternas": "automat",
    "automaters": "automat",
    "automatgevären": "automatgevär",
    "automatgevärens": "automatgevär",
    "automatgeväret": "automatgevär",
    "automatgevärets": "automatgevär",
    "automatgevärs": "automatgevär",
    "automatiken": "automatik",
    "automatikens": "automatik",
    "automatiks": "automatik",
    "automationen": "automation",
    "automationens": "automation",
    "automationer": "automation",
    "automationerna": "automation",
    "automationernas": "automation",
    "automationers": "automation",
    "automations": "automation",
    "automatiserad": "automatisera",
    "automatiserade": "automatisera",
    "automatiserades": "automatisera",
    "automatiserads": "automatisera",
    "automatiserande": "automatisera",
    "automatiseranden": "automatiserande",
    "automatiserandena": "automatiserande",
    "automatiserandenas": "automatiserande",
    "automatiserandens": "automatiserande",
    "automatiserandes": "automatiserande",
    "automatiserandet": "automatiserande",
    "automatiserandets": "automatiserande",
    "automatiserar": "automatisera",
    "automatiseras": "automatisera",
    "automatiserat": "automatisera",
    "automatiserats": "automatisera",
    "automatiserbara": "automatiserbar",
    "automatiserbarare": "automatiserbar",
    "automatiserbarares": "automatiserbar",
    "automatiserbaras": "automatiserbar",
    "automatiserbarast": "automatiserbar",
    "automatiserbaraste": "automatiserbar",
    "automatiserbarastes": "automatiserbar",
    "automatiserbarasts": "automatiserbar",
    "automatiserbare": "automatiserbar",
    "automatiserbares": "automatiserbar",
    "automatiserbarheten": "automatiserbarhet",
    "automatiserbarhetens": "automatiserbarhet",
    "automatiserbarhets": "automatiserbarhet",
    "automatiserbars": "automatiserbar",
    "automatiserbart": "automatiserbar",
    "automatiserbarts": "automatiserbar",
    "automatiseringar": "automatisering",
    "automatiseringarna": "automatisering",
    "automatiseringarnas": "automatisering",
    "automatiseringars": "automatisering",
    "automatiseringen": "automatisering",
    "automatiseringens": "automatisering",
    "automatiserings": "automatisering",
    "automatiska": "automatisk",
    "automatiskare": "automatisk",
    "automatiskares": "automatisk",
    "automatiskas": "automatisk",
    "automatiskast": "automatisk",
    "automatiskaste": "automatisk",
    "automatiskastes": "automatisk",
    "automatiskasts": "automatisk",
    "automatiske": "automatisk",
    "automatiskes": "automatisk",
    "automatisks": "automatisk",
    "automatiskt": "automatisk",
    "automatiskts": "automatisk",
    "automatkarbinen": "automatkarbin",
    "automatkarbinens": "automatkarbin",
    "automatkarbiner": "automatkarbin",
    "automatkarbinerna": "automatkarbin",
    "automatkarbinernas": "automatkarbin",
    "automatkarbiners": "automatkarbin",
    "automatkarbins": "automatkarbin",
    "automats": "automat",
    "automatsäkringar": "automatsäkring",
    "automatsäkringarna": "automatsäkring",
    "automatsäkringarnas": "automatsäkring",
    "automatsäkringars": "automatsäkring",
    "automatsäkringen": "automatsäkring",
    "automatsäkringens": "automatsäkring",
    "automatsäkrings": "automatsäkring",
    "automatteorien": "automatteori",
    "automatteoriens": "automatteori",
    "automatteorin": "automatteori",
    "automatteorins": "automatteori",
    "automatteoris": "automatteori",
    "automatvapens": "automatvapen",
    "automatvapnen": "automatvapen",
    "automatvapnens": "automatvapen",
    "automatvapnet": "automatvapen",
    "automatvapnets": "automatvapen",
    "automobilen": "automobil",
    "automobilens": "automobil",
    "automobiler": "automobil",
    "automobilerna": "automobil",
    "automobilernas": "automobil",
    "automobilers": "automobil",
    "automobils": "automobil",
    "autonoma": "autonom",
    "autonomare": "autonom",
    "autonomares": "autonom",
    "autonomas": "autonom",
    "autonomast": "autonom",
    "autonomaste": "autonom",
    "autonomastes": "autonom",
    "autonomasts": "autonom",
    "autonome": "autonom",
    "autonomes": "autonom",
    "autonomien": "autonomi",
    "autonomiens": "autonomi",
    "autonomin": "autonomi",
    "autonomins": "autonomi",
    "autonomis": "autonomi",
    "autonoms": "autonom",
    "autonomt": "autonom",
    "autonomts": "autonom",
    "autopiloten": "autopilot",
    "autopilotens": "autopilot",
    "autopiloter": "autopilot",
    "autopiloterna": "autopilot",
    "autopiloternas": "autopilot",
    "autopiloters": "autopilot",
    "autopilots": "autopilot",
    "autopsien": "autopsi",
    "autopsiens": "autopsi",
    "autopsier": "autopsi",
    "autopsierna": "autopsi",
    "autopsiernas": "autopsi",
    "autopsiers": "autopsi",
    "autopsin": "autopsi",
    "autopsins": "autopsi",
    "autopsis": "autopsi",
    "autostrad": "autostrada",
    "autostradan": "autostrada",
    "autostradans": "autostrada",
    "autostradas": "autostrada",
    "autostrade": "autostrada",
    "autostrador": "autostrada",
    "autostradorna": "autostrada",
    "autostradornas": "autostrada",
    "autostradors": "autostrada",
    "autostrads": "autostrada",
    "autotypien": "autotypi",
    "autotypiens": "autotypi",
    "autotypier": "autotypi",
    "autotypierna": "autotypi",
    "autotypiernas": "autotypi",
    "autotypiers": "autotypi",
    "autotypin": "autotypi",
    "autotypins": "autotypi",
    "autotypis": "autotypi",
    "avad": "ava",
    "avade": "ava",
    "avades": "ava",
    "avads": "ava",
    "avan": "ava",
    "avancemangen": "avancemang",
    "avancemangens": "avancemang",
    "avancemanget": "avancemang",
    "avancemangets": "avancemang",
    "avancemangs": "avancemang",
    "avancerad": "avancera",
    "avancerade": "avancerad",
    "avancerades": "avancerad",
    "avancerads": "avancerad",
    "avancerande": "avancera",
    "avanceranden": "avancerande",
    "avancerandena": "avancerande",
    "avancerandenas": "avancerande",
    "avancerandens": "avancerande",
    "avancerandes": "avancerande",
    "avancerandet": "avancerande",
    "avancerandets": "avancerande",
    "avancerar": "avancera",
    "avanceras": "avancera",
    "avancerat": "avancerad",
    "avancerats": "avancerad",
    "avancerbara": "avancerbar",
    "avancerbarare": "avancerbar",
    "avancerbarares": "avancerbar",
    "avancerbaras": "avancerbar",
    "avancerbarast": "avancerbar",
    "avancerbaraste": "avancerbar",
    "avancerbarastes": "avancerbar",
    "avancerbarasts": "avancerbar",
    "avancerbare": "avancerbar",
    "avancerbares": "avancerbar",
    "avancerbarheten": "avancerbarhet",
    "avancerbarhetens": "avancerbarhet",
    "avancerbarhets": "avancerbarhet",
    "avancerbars": "avancerbar",
    "avancerbart": "avancerbar",
    "avancerbarts": "avancerbar",
    "avanceringar": "avancering",
    "avanceringarna": "avancering",
    "avanceringarnas": "avancering",
    "avanceringars": "avancering",
    "avanceringen": "avancering",
    "avanceringens": "avancering",
    "avancerings": "avancering",
    "avande": "ava",
    "avanden": "avande",
    "avandena": "avande",
    "avandenas": "avande",
    "avandens": "avande",
    "avandes": "avande",
    "avandet": "avande",
    "avandets": "avande",
    "avannonsen": "avannons",
    "avannonsens": "avannons",
    "avannonser": "avannons",
    "avannonserad": "avannonsera",
    "avannonserade": "avannonsera",
    "avannonserades": "avannonsera",
    "avannonserads": "avannonsera",
    "avannonserande": "avannonsera",
    "avannonseranden": "avannonserande",
    "avannonserandena": "avannonserande",
    "avannonserandenas": "avannonserande",
    "avannonserandens": "avannonserande",
    "avannonserandes": "avannonserande",
    "avannonserandet": "avannonserande",
    "avannonserandets": "avannonserande",
    "avannonserar": "avannonsera",
    "avannonseras": "avannonsera",
    "avannonserat": "avannonsera",
    "avannonserats": "avannonsera",
    "avannonserbara": "avannonserbar",
    "avannonserbarare": "avannonserbar",
    "avannonserbarares": "avannonserbar",
    "avannonserbaras": "avannonserbar",
    "avannonserbarast": "avannonserbar",
    "avannonserbaraste": "avannonserbar",
    "avannonserbarastes": "avannonserbar",
    "avannonserbarasts": "avannonserbar",
    "avannonserbare": "avannonserbar",
    "avannonserbares": "avannonserbar",
    "avannonserbarheten": "avannonserbarhet",
    "avannonserbarhetens": "avannonserbarhet",
    "avannonserbarhets": "avannonserbarhet",
    "avannonserbars": "avannonserbar",
    "avannonserbart": "avannonserbar",
    "avannonserbarts": "avannonserbar",
    "avannonseringar": "avannonsering",
    "avannonseringarna": "avannonsering",
    "avannonseringarnas": "avannonsering",
    "avannonseringars": "avannonsering",
    "avannonseringen": "avannonsering",
    "avannonseringens": "avannonsering",
    "avannonserings": "avannonsering",
    "avannonserna": "avannons",
    "avannonsernas": "avannons",
    "avannonsers": "avannons",
    "avans": "ava",
    "avansen": "avans",
    "avansens": "avans",
    "avanser": "avans",
    "avanserna": "avans",
    "avansernas": "avans",
    "avansers": "avans",
    "avantgardes": "avantgarde",
    "avantgardet": "avantgarde",
    "avantgardets": "avantgarde",
    "avantgardismen": "avantgardism",
    "avantgardismens": "avantgardism",
    "avantgardismer": "avantgardism",
    "avantgardismerna": "avantgardism",
    "avantgardismernas": "avantgardism",
    "avantgardismers": "avantgardism",
    "avantgardisms": "avantgardism",
    "avantgardisten": "avantgardist",
    "avantgardistens": "avantgardist",
    "avantgardister": "avantgardist",
    "avantgardisterna": "avantgardist",
    "avantgardisternas": "avantgardist",
    "avantgardisters": "avantgardist",
    "avantgardistiska": "avantgardistisk",
    "avantgardistiskare": "avantgardistisk",
    "avantgardistiskares": "avantgardistisk",
    "avantgardistiskas": "avantgardistisk",
    "avantgardistiskast": "avantgardistisk",
    "avantgardistiskaste": "avantgardistisk",
    "avantgardistiskastes": "avantgardistisk",
    "avantgardistiskasts": "avantgardistisk",
    "avantgardistiske": "avantgardistisk",
    "avantgardistiskes": "avantgardistisk",
    "avantgardistisks": "avantgardistisk",
    "avantgardistiskt": "avantgardistisk",
    "avantgardistiskts": "avantgardistisk",
    "avantgardists": "avantgardist",
    "avantlogen": "avantloge",
    "avantlogens": "avantloge",
    "avantloger": "avantloge",
    "avantlogerna": "avantloge",
    "avantlogernas": "avantloge",
    "avantlogers": "avantloge",
    "avantloges": "avantloge",
    "avantscenen": "avantscen",
    "avantscenens": "avantscen",
    "avantscener": "avantscen",
    "avantscenerna": "avantscen",
    "avantscenernas": "avantscen",
    "avantsceners": "avantscen",
    "avantscens": "avantscen",
    "avar": "ava",
    "avarten": "avart",
    "avartens": "avart",
    "avarter": "avart",
    "avarterna": "avart",
    "avarternas": "avart",
    "avarters": "avart",
    "avarts": "avart",
    "avas": "ava",
    "avat": "ava",
    "avataren": "avatar",
    "avatarens": "avatar",
    "avatarer": "avatar",
    "avatarerna": "avatar",
    "avatarernas": "avatar",
    "avatarers": "avatar",
    "avatars": "avatar",
    "avats": "ava",
    "avbalk": "avbalka",
    "avbalkad": "avbalka",
    "avbalkade": "avbalka",
    "avbalkades": "avbalka",
    "avbalkads": "avbalka",
    "avbalkande": "avbalka",
    "avbalkanden": "avbalkande",
    "avbalkandena": "avbalkande",
    "avbalkandenas": "avbalkande",
    "avbalkandens": "avbalkande",
    "avbalkandes": "avbalkande",
    "avbalkandet": "avbalkande",
    "avbalkandets": "avbalkande",
    "avbalkar": "avbalka",
    "avbalkas": "avbalka",
    "avbalkat": "avbalka",
    "avbalkats": "avbalka",
    "avbalkningar": "avbalkning",
    "avbalkningarna": "avbalkning",
    "avbalkningarnas": "avbalkning",
    "avbalkningars": "avbalkning",
    "avbalkningen": "avbalkning",
    "avbalkningens": "avbalkning",
    "avbalknings": "avbalkning",
    "avbasningar": "avbasning",
    "avbasningarna": "avbasning",
    "avbasningarnas": "avbasning",
    "avbasningars": "avbasning",
    "avbasningen": "avbasning",
    "avbasningens": "avbasning",
    "avbasnings": "avbasning",
    "avbeställ": "avbeställa",
    "avbeställande": "avbeställa",
    "avbeställanden": "avbeställande",
    "avbeställandena": "avbeställande",
    "avbeställandenas": "avbeställande",
    "avbeställandens": "avbeställande",
    "avbeställandes": "avbeställande",
    "avbeställandet": "avbeställande",
    "avbeställandets": "avbeställande",
    "avbeställas": "avbeställa",
    "avbeställd": "avbeställa",
    "avbeställda": "avbeställa",
    "avbeställdas": "avbeställa",
    "avbeställde": "avbeställa",
    "avbeställdes": "avbeställa",
    "avbeställds": "avbeställa",
    "avbeställer": "avbeställa",
    "avbeställes": "avbeställa",
    "avbeställs": "avbeställa",
    "avbeställt": "avbeställa",
    "avbeställts": "avbeställa",
    "avbet": "avbeta",
    "avbetad": "avbeta",
    "avbetade": "avbeta",
    "avbetades": "avbeta",
    "avbetads": "avbeta",
    "avbetalad": "avbetala",
    "avbetalade": "avbetala",
    "avbetalades": "avbetala",
    "avbetalads": "avbetala",
    "avbetalande": "avbetala",
    "avbetalanden": "avbetalande",
    "avbetalandena": "avbetalande",
    "avbetalandenas": "avbetalande",
    "avbetalandens": "avbetalande",
    "avbetalandes": "avbetalande",
    "avbetalandet": "avbetalande",
    "avbetalandets": "avbetalande",
    "avbetalar": "avbetala",
    "avbetalas": "avbetala",
    "avbetalat": "avbetala",
    "avbetalats": "avbetala",
    "avbetalningar": "avbetalning",
    "avbetalningarna": "avbetalning",
    "avbetalningarnas": "avbetalning",
    "avbetalningars": "avbetalning",
    "avbetalningen": "avbetalning",
    "avbetalningens": "avbetalning",
    "avbetalnings": "avbetalning",
    "avbetande": "avbeta",
    "avbetanden": "avbetande",
    "avbetandena": "avbetande",
    "avbetandenas": "avbetande",
    "avbetandens": "avbetande",
    "avbetandes": "avbetande",
    "avbetandet": "avbetande",
    "avbetandets": "avbetande",
    "avbetar": "avbeta",
    "avbetas": "avbeta",
    "avbetat": "avbeta",
    "avbetats": "avbeta",
    "avbetingningar": "avbetingning",
    "avbetingningarna": "avbetingning",
    "avbetingningarnas": "avbetingning",
    "avbetingningars": "avbetingning",
    "avbetingningen": "avbetingning",
    "avbetingningens": "avbetingning",
    "avbetingnings": "avbetingning",
    "avbildad": "avbilda",
    "avbildade": "avbilda",
    "avbildades": "avbilda",
    "avbildads": "avbilda",
    "avbildande": "avbilda",
    "avbildanden": "avbildande",
    "avbildandena": "avbildande",
    "avbildandenas": "avbildande",
    "avbildandens": "avbildande",
    "avbildandes": "avbildande",
    "avbildandet": "avbildande",
    "avbildandets": "avbildande",
    "avbildar": "avbilda",
    "avbildas": "avbilda",
    "avbildat": "avbilda",
    "avbildats": "avbilda",
    "avbilden": "avbild",
    "avbildens": "avbild",
    "avbilder": "avbild",
    "avbilderna": "avbild",
    "avbildernas": "avbild",
    "avbilders": "avbild",
    "avbildningar": "avbildning",
    "avbildningarna": "avbildning",
    "avbildningarnas": "avbildning",
    "avbildningars": "avbildning",
    "avbildningen": "avbildning",
    "avbildningens": "avbildning",
    "avbildnings": "avbildning",
    "avbildningsfelen": "avbildningsfel",
    "avbildningsfelens": "avbildningsfel",
    "avbildningsfelet": "avbildningsfel",
    "avbildningsfelets": "avbildningsfel",
    "avbildningsfels": "avbildningsfel",
    "avbilds": "avbild",
    "avbitar": "avbitare",
    "avbitaren": "avbitare",
    "avbitarens": "avbitare",
    "avbitares": "avbitare",
    "avbitarna": "avbitare",
    "avbitarnas": "avbitare",
    "avbitartänger": "avbitartång",
    "avbitartängerna": "avbitartång",
    "avbitartängernas": "avbitartång",
    "avbitartängers": "avbitartång",
    "avbitartången": "avbitartång",
    "avbitartångens": "avbitartång",
    "avbitartångs": "avbitartång",
    "avblås": "avblåsa",
    "avblåsande": "avblåsa",
    "avblåsanden": "avblåsande",
    "avblåsandena": "avblåsande",
    "avblåsandenas": "avblåsande",
    "avblåsandens": "avblåsande",
    "avblåsandes": "avblåsande",
    "avblåsandet": "avblåsande",
    "avblåsandets": "avblåsande",
    "avblåsas": "avblåsa",
    "avblåser": "avblåsa",
    "avblåses": "avblåsa",
    "avblåsningar": "avblåsning",
    "avblåsningarna": "avblåsning",
    "avblåsningarnas": "avblåsning",
    "avblåsningars": "avblåsning",
    "avblåsningen": "avblåsning",
    "avblåsningens": "avblåsning",
    "avblåsnings": "avblåsning",
    "avblåst": "avblåsa",
    "avblåsta": "avblåsa",
    "avblåstas": "avblåsa",
    "avblåste": "avblåsa",
    "avblåstes": "avblåsa",
    "avblåsts": "avblåsa",
    "avbrotten": "avbrott",
    "avbrottens": "avbrott",
    "avbrottet": "avbrott",
    "avbrottets": "avbrott",
    "avbrotts": "avbrott",
    "avbruten": "avbryta",
    "avbrutens": "avbryta",
    "avbrutet": "avbryta",
    "avbrutets": "avbryta",
    "avbrutit": "avbryta",
    "avbrutits": "avbryta",
    "avbrutna": "avbryta",
    "avbrutnas": "avbryta",
    "avbrutne": "avbryta",
    "avbrutnes": "avbryta",
    "avbryt": "avbryta",
    "avbrytande": "avbryta",
    "avbrytanden": "avbrytande",
    "avbrytandena": "avbrytande",
    "avbrytandenas": "avbrytande",
    "avbrytandens": "avbrytande",
    "avbrytandes": "avbrytande",
    "avbrytandet": "avbrytande",
    "avbrytandets": "avbrytande",
    "avbrytar": "avbrytare",
    "avbrytaren": "avbrytare",
    "avbrytarens": "avbrytare",
    "avbrytares": "avbrytare",
    "avbrytarna": "avbrytare",
    "avbrytarnas": "avbrytare",
    "avbrytas": "avbryta",
    "avbryte": "avbryta",
    "avbryter": "avbryta",
    "avbrytes": "avbryta",
    "avbryts": "avbryta",
    "avbräcken": "avbräck",
    "avbräckens": "avbräck",
    "avbräcket": "avbräck",
    "avbräckets": "avbräck",
    "avbräcks": "avbräck",
    "avbränningar": "avbränning",
    "avbränningarna": "avbränning",
    "avbränningarnas": "avbränning",
    "avbränningars": "avbränning",
    "avbränningen": "avbränning",
    "avbränningens": "avbränning",
    "avbrännings": "avbränning",
    "avbröstningar": "avbröstning",
    "avbröstningarna": "avbröstning",
    "avbröstningarnas": "avbröstning",
    "avbröstningars": "avbröstning",
    "avbröstningen": "avbröstning",
    "avbröstningens": "avbröstning",
    "avbröstnings": "avbröstning",
    "avbröt": "avbryta",
    "avbröte": "avbryta",
    "avbrötes": "avbryta",
    "avbröts": "avbryta",
    "avbytar": "avbytare",
    "avbytaren": "avbytare",
    "avbytarens": "avbytare",
    "avbytares": "avbytare",
    "avbytarna": "avbytare",
    "avbytarnas": "avbytare",
    "avbäringar": "avbäring",
    "avbäringarna": "avbäring",
    "avbäringarnas": "avbäring",
    "avbäringars": "avbäring",
    "avbäringen": "avbäring",
    "avbäringens": "avbäring",
    "avbärings": "avbäring",
    "avbärningar": "avbärning",
    "avbärningarna": "avbärning",
    "avbärningarnas": "avbärning",
    "avbärningars": "avbärning",
    "avbärningen": "avbärning",
    "avbärningens": "avbärning",
    "avbärnings": "avbärning",
    "avböj": "avböja",
    "avböjande": "avböja",
    "avböjanden": "avböjande",
    "avböjandena": "avböjande",
    "avböjandenas": "avböjande",
    "avböjandens": "avböjande",
    "avböjandes": "avböjande",
    "avböjandet": "avböjande",
    "avböjandets": "avböjande",
    "avböjas": "avböja",
    "avböjd": "avböja",
    "avböjda": "avböja",
    "avböjdas": "avböja",
    "avböjde": "avböja",
    "avböjdes": "avböja",
    "avböjds": "avböja",
    "avböjer": "avböja",
    "avböjes": "avböja",
    "avböjningar": "avböjning",
    "avböjningarna": "avböjning",
    "avböjningarnas": "avböjning",
    "avböjningars": "avböjning",
    "avböjningen": "avböjning",
    "avböjningens": "avböjning",
    "avböjnings": "avböjning",
    "avböjs": "avböja",
    "avböjt": "avböja",
    "avböjts": "avböja",
    "avbönen": "avbön",
    "avbönens": "avbön",
    "avböner": "avbön",
    "avbönerna": "avbön",
    "avbönernas": "avbön",
    "avböners": "avbön",
    "avböns": "avbön",
    "avbörd": "avbörda",
    "avbördad": "avbörda",
    "avbördade": "avbörda",
    "avbördades": "avbörda",
    "avbördads": "avbörda",
    "avbördande": "avbörda",
    "avbördanden": "avbördande",
    "avbördandena": "avbördande",
    "avbördandenas": "avbördande",
    "avbördandens": "avbördande",
    "avbördandes": "avbördande",
    "avbördandet": "avbördande",
    "avbördandets": "avbördande",
    "avbördar": "avbörda",
    "avbördas": "avbörda",
    "avbördat": "avbörda",
    "avbördats": "avbörda",
    "avd-s": "avd",
    "avd.-s": "avd.",
    "avd.:s": "avd.",
    "avd.s": "avd.",
    "avd:s": "avd",
    "avdagatag": "avdagata",
    "avdagataga": "avdagata",
    "avdagatagande": "avdagata",
    "avdagataganden": "avdagatagande",
    "avdagatagandena": "avdagatagande",
    "avdagatagandenas": "avdagatagande",
    "avdagatagandens": "avdagatagande",
    "avdagatagandes": "avdagatagande",
    "avdagatagandet": "avdagatagande",
    "avdagatagandets": "avdagatagande",
    "avdagatagas": "avdagata",
    "avdagatage": "avdagata",
    "avdagatagen": "avdagata",
    "avdagatagens": "avdagata",
    "avdagatager": "avdagata",
    "avdagatages": "avdagata",
    "avdagataget": "avdagata",
    "avdagatagets": "avdagata",
    "avdagatagit": "avdagata",
    "avdagatagits": "avdagata",
    "avdagatagna": "avdagata",
    "avdagatagnas": "avdagata",
    "avdagatagne": "avdagata",
    "avdagatagnes": "avdagata",
    "avdagatags": "avdagata",
    "avdagatar": "avdagata",
    "avdagatas": "avdagata",
    "avdagatog": "avdagata",
    "avdagatoge": "avdagata",
    "avdagatoges": "avdagata",
    "avdagatogs": "avdagata",
    "avdankade": "avdankad",
    "avdankades": "avdankad",
    "avdankads": "avdankad",
    "avdankat": "avdankad",
    "avdankats": "avdankad",
    "avdelad": "avdela",
    "avdelade": "avdela",
    "avdelades": "avdela",
    "avdelads": "avdela",
    "avdelande": "avdela",
    "avdelanden": "avdelande",
    "avdelandena": "avdelande",
    "avdelandenas": "avdelande",
    "avdelandens": "avdelande",
    "avdelandes": "avdelande",
    "avdelandet": "avdelande",
    "avdelandets": "avdelande",
    "avdelar": "avdela",
    "avdelas": "avdela",
    "avdelat": "avdela",
    "avdelats": "avdela",
    "avdelningar": "avdelning",
    "avdelningarna": "avdelning",
    "avdelningarnas": "avdelning",
    "avdelningars": "avdelning",
    "avdelningen": "avdelning",
    "avdelningens": "avdelning",
    "avdelnings": "avdelning",
    "avdelningschefen": "avdelningschef",
    "avdelningschefens": "avdelningschef",
    "avdelningschefer": "avdelningschef",
    "avdelningscheferna": "avdelningschef",
    "avdelningschefernas": "avdelningschef",
    "avdelningschefers": "avdelningschef",
    "avdelningschefs": "avdelningschef",
    "avdelningsdirektören": "avdelningsdirektör",
    "avdelningsdirektörens": "avdelningsdirektör",
    "avdelningsdirektörer": "avdelningsdirektör",
    "avdelningsdirektörerna": "avdelningsdirektör",
    "avdelningsdirektörernas": "avdelningsdirektör",
    "avdelningsdirektörers": "avdelningsdirektör",
    "avdelningsdirektörn": "avdelningsdirektör",
    "avdelningsdirektörns": "avdelningsdirektör",
    "avdelningsdirektörs": "avdelningsdirektör",
    "avdelningssköterskan": "avdelningssköterska",
    "avdelningssköterskans": "avdelningssköterska",
    "avdelningssköterskas": "avdelningssköterska",
    "avdelningssköterske": "avdelningssköterska",
    "avdelningssköterskor": "avdelningssköterska",
    "avdelningssköterskorna": "avdelningssköterska",
    "avdelningssköterskornas": "avdelningssköterska",
    "avdelningssköterskors": "avdelningssköterska",
    "avdragen": "avdrag",
    "avdragens": "avdrag",
    "avdraget": "avdrag",
    "avdragets": "avdrag",
    "avdrags": "avdrag",
    "avdragsgilla": "avdragsgill",
    "avdragsgillare": "avdragsgill",
    "avdragsgillares": "avdragsgill",
    "avdragsgillas": "avdragsgill",
    "avdragsgillast": "avdragsgill",
    "avdragsgillaste": "avdragsgill",
    "avdragsgillastes": "avdragsgill",
    "avdragsgillasts": "avdragsgill",
    "avdragsgille": "avdragsgill",
    "avdragsgilles": "avdragsgill",
    "avdragsgills": "avdragsgill",
    "avdragsgillt": "avdragsgill",
    "avdragsgillts": "avdragsgill",
    "avdragsmöjligheten": "avdragsmöjlighet",
    "avdragsmöjlighetens": "avdragsmöjlighet",
    "avdragsmöjligheter": "avdragsmöjlighet",
    "avdragsmöjligheterna": "avdragsmöjlighet",
    "avdragsmöjligheternas": "avdragsmöjlighet",
    "avdragsmöjligheters": "avdragsmöjlighet",
    "avdragsmöjlighets": "avdragsmöjlighet",
    "avdramatiserad": "avdramatisera",
    "avdramatiserade": "avdramatisera",
    "avdramatiserades": "avdramatisera",
    "avdramatiserads": "avdramatisera",
    "avdramatiserande": "avdramatisera",
    "avdramatiseranden": "avdramatiserande",
    "avdramatiserandena": "avdramatiserande",
    "avdramatiserandenas": "avdramatiserande",
    "avdramatiserandens": "avdramatiserande",
    "avdramatiserandes": "avdramatiserande",
    "avdramatiserandet": "avdramatiserande",
    "avdramatiserandets": "avdramatiserande",
    "avdramatiserar": "avdramatisera",
    "avdramatiseras": "avdramatisera",
    "avdramatiserat": "avdramatisera",
    "avdramatiserats": "avdramatisera",
    "avdramatiserbara": "avdramatiserbar",
    "avdramatiserbarare": "avdramatiserbar",
    "avdramatiserbarares": "avdramatiserbar",
    "avdramatiserbaras": "avdramatiserbar",
    "avdramatiserbarast": "avdramatiserbar",
    "avdramatiserbaraste": "avdramatiserbar",
    "avdramatiserbarastes": "avdramatiserbar",
    "avdramatiserbarasts": "avdramatiserbar",
    "avdramatiserbare": "avdramatiserbar",
    "avdramatiserbares": "avdramatiserbar",
    "avdramatiserbarheten": "avdramatiserbarhet",
    "avdramatiserbarhetens": "avdramatiserbarhet",
    "avdramatiserbarhets": "avdramatiserbarhet",
    "avdramatiserbars": "avdramatiserbar",
    "avdramatiserbart": "avdramatiserbar",
    "avdramatiserbarts": "avdramatiserbar",
    "avdramatiseringar": "avdramatisering",
    "avdramatiseringarna": "avdramatisering",
    "avdramatiseringarnas": "avdramatisering",
    "avdramatiseringars": "avdramatisering",
    "avdramatiseringen": "avdramatisering",
    "avdramatiseringens": "avdramatisering",
    "avdramatiserings": "avdramatisering",
    "avdrev": "avdriva",
    "avdrevs": "avdriva",
    "avdriften": "avdrift",
    "avdriftens": "avdrift",
    "avdrifts": "avdrift",
    "avdriv": "avdriva",
    "avdrivande": "avdriva",
    "avdrivanden": "avdrivande",
    "avdrivandena": "avdrivande",
    "avdrivandenas": "avdrivande",
    "avdrivandens": "avdrivande",
    "avdrivandes": "avdrivande",
    "avdrivandet": "avdrivande",
    "avdrivandets": "avdrivande",
    "avdrivas": "avdriva",
    "avdrive": "avdriva",
    "avdriven": "avdriva",
    "avdrivens": "avdriva",
    "avdriver": "avdriva",
    "avdrives": "avdriva",
    "avdrivet": "avdriva",
    "avdrivets": "avdriva",
    "avdrivit": "avdriva",
    "avdrivits": "avdriva",
    "avdrivna": "avdriva",
    "avdrivnas": "avdriva",
    "avdrivne": "avdriva",
    "avdrivnes": "avdriva",
    "avdrivs": "avdriva",
    "avds": "avd",
    "avdunst": "avdunsta",
    "avdunstad": "avdunsta",
    "avdunstade": "avdunsta",
    "avdunstades": "avdunsta",
    "avdunstads": "avdunsta",
    "avdunstande": "avdunsta",
    "avdunstanden": "avdunstande",
    "avdunstandena": "avdunstande",
    "avdunstandenas": "avdunstande",
    "avdunstandens": "avdunstande",
    "avdunstandes": "avdunstande",
    "avdunstandet": "avdunstande",
    "avdunstandets": "avdunstande",
    "avdunstar": "avdunsta",
    "avdunstas": "avdunsta",
    "avdunstat": "avdunsta",
    "avdunstats": "avdunsta",
    "avdunstningar": "avdunstning",
    "avdunstningarna": "avdunstning",
    "avdunstningarnas": "avdunstning",
    "avdunstningars": "avdunstning",
    "avdunstningen": "avdunstning",
    "avdunstningens": "avdunstning",
    "avdunstnings": "avdunstning",
    "avdäm": "avdämma",
    "avdämd": "avdämma",
    "avdämda": "avdämma",
    "avdämdas": "avdämma",
    "avdämde": "avdämma",
    "avdämdes": "avdämma",
    "avdämds": "avdämma",
    "avdämmande": "avdämma",
    "avdämmanden": "avdämmande",
    "avdämmandena": "avdämmande",
    "avdämmandenas": "avdämmande",
    "avdämmandens": "avdämmande",
    "avdämmandes": "avdämmande",
    "avdämmandet": "avdämmande",
    "avdämmandets": "avdämmande",
    "avdämmas": "avdämma",
    "avdämmer": "avdämma",
    "avdäms": "avdämma",
    "avdämt": "avdämma",
    "avdämts": "avdämma",
    "avdöda": "avdöd",
    "avdödare": "avdöd",
    "avdödares": "avdöd",
    "avdödas": "avdöd",
    "avdödast": "avdöd",
    "avdödaste": "avdöd",
    "avdödastes": "avdöd",
    "avdödasts": "avdöd",
    "avdöde": "avdöd",
    "avdödes": "avdöd",
    "avdöds": "avdöd",
    "avdöm": "avdöma",
    "avdömande": "avdöma",
    "avdömanden": "avdömande",
    "avdömandena": "avdömande",
    "avdömandenas": "avdömande",
    "avdömandens": "avdömande",
    "avdömandes": "avdömande",
    "avdömandet": "avdömande",
    "avdömandets": "avdömande",
    "avdömas": "avdöma",
    "avdömd": "avdöma",
    "avdömda": "avdöma",
    "avdömdas": "avdöma",
    "avdömde": "avdöma",
    "avdömdes": "avdöma",
    "avdömds": "avdöma",
    "avdömer": "avdöma",
    "avdöms": "avdöma",
    "avdömt": "avdöma",
    "avdömts": "avdöma",
    "avdött": "avdöd",
    "avdötts": "avdöd",
    "avecen": "avec",
    "avecens": "avec",
    "avecer": "avec",
    "avecerna": "avec",
    "avecernas": "avec",
    "avecers": "avec",
    "avecs": "avec",
    "aveln": "avel",
    "avelns": "avel",
    "avels": "avel",
    "avelsdjuren": "avelsdjur",
    "avelsdjurens": "avelsdjur",
    "avelsdjuret": "avelsdjur",
    "avelsdjurets": "avelsdjur",
    "avelsdjurs": "avelsdjur",
    "avelshingstar": "avelshingst",
    "avelshingstarna": "avelshingst",
    "avelshingstarnas": "avelshingst",
    "avelshingstars": "avelshingst",
    "avelshingsten": "avelshingst",
    "avelshingstens": "avelshingst",
    "avelshingsts": "avelshingst",
    "aven": "ave",
    "avena": "ave",
    "avenas": "ave",
    "avenbokar": "avenbok",
    "avenbokarna": "avenbok",
    "avenbokarnas": "avenbok",
    "avenbokars": "avenbok",
    "avenboken": "avenbok",
    "avenbokens": "avenbok",
    "avenboks": "avenbok",
    "avens": "ave",
    "avenyer": "aveny",
    "avenyerna": "aveny",
    "avenyernas": "aveny",
    "avenyers": "aveny",
    "avenyn": "aveny",
    "avenyns": "aveny",
    "avenys": "aveny",
    "aversen": "avers",
    "aversens": "avers",
    "averser": "avers",
    "averserna": "avers",
    "aversernas": "avers",
    "aversers": "avers",
    "aversionen": "aversion",
    "aversionens": "aversion",
    "aversioner": "aversion",
    "aversionerna": "aversion",
    "aversionernas": "aversion",
    "aversioners": "aversion",
    "aversions": "aversion",
    "aversionsterapien": "aversionsterapi",
    "aversionsterapiens": "aversionsterapi",
    "aversionsterapin": "aversionsterapi",
    "aversionsterapins": "aversionsterapi",
    "aversionsterapis": "aversionsterapi",
    "aves": "ave",
    "avet": "ave",
    "avets": "ave",
    "avfall": "avfalla",
    "avfallande": "avfalla",
    "avfallanden": "avfallande",
    "avfallandena": "avfallande",
    "avfallandenas": "avfallande",
    "avfallandens": "avfallande",
    "avfallandes": "avfallande",
    "avfallandet": "avfallande",
    "avfallandets": "avfallande",
    "avfallas": "avfalla",
    "avfalle": "avfalla",
    "avfallen": "avfalla",
    "avfallens": "avfallen",
    "avfaller": "avfalla",
    "avfalles": "avfalla",
    "avfallet": "avfallen",
    "avfallets": "avfallen",
    "avfallit": "avfalla",
    "avfallits": "avfalla",
    "avfallna": "avfallen",
    "avfallnare": "avfallen",
    "avfallnares": "avfallen",
    "avfallnas": "avfallen",
    "avfallnast": "avfallen",
    "avfallnaste": "avfallen",
    "avfallnastes": "avfallen",
    "avfallnasts": "avfallen",
    "avfallne": "avfallen",
    "avfallnes": "avfallen",
    "avfalls": "avfalla",
    "avfallsfoders": "avfallsfoder",
    "avfallsfodret": "avfallsfoder",
    "avfallsfodrets": "avfallsfoder",
    "avfallskvarnar": "avfallskvarn",
    "avfallskvarnarna": "avfallskvarn",
    "avfallskvarnarnas": "avfallskvarn",
    "avfallskvarnars": "avfallskvarn",
    "avfallskvarnen": "avfallskvarn",
    "avfallskvarnens": "avfallskvarn",
    "avfallskvarns": "avfallskvarn",
    "avfallsråvar": "avfallsråvara",
    "avfallsråvaran": "avfallsråvara",
    "avfallsråvarans": "avfallsråvara",
    "avfallsråvaras": "avfallsråvara",
    "avfallsråvare": "avfallsråvara",
    "avfallsråvaror": "avfallsråvara",
    "avfallsråvarorna": "avfallsråvara",
    "avfallsråvarornas": "avfallsråvara",
    "avfallsråvarors": "avfallsråvara",
    "avfallsråvars": "avfallsråvara",
    "avfallsupplagen": "avfallsupplag",
    "avfallsupplagens": "avfallsupplag",
    "avfallsupplaget": "avfallsupplag",
    "avfallsupplagets": "avfallsupplag",
    "avfallsupplags": "avfallsupplag",
    "avfallsvirkes": "avfallsvirke",
    "avfallsvirket": "avfallsvirke",
    "avfallsvirkets": "avfallsvirke",
    "avfarten": "avfart",
    "avfartens": "avfart",
    "avfarter": "avfart",
    "avfarterna": "avfart",
    "avfarternas": "avfart",
    "avfarters": "avfart",
    "avfarts": "avfart",
    "avfatt": "avfatta",
    "avfattad": "avfatta",
    "avfattade": "avfatta",
    "avfattades": "avfatta",
    "avfattads": "avfatta",
    "avfattande": "avfatta",
    "avfattanden": "avfattande",
    "avfattandena": "avfattande",
    "avfattandenas": "avfattande",
    "avfattandens": "avfattande",
    "avfattandes": "avfattande",
    "avfattandet": "avfattande",
    "avfattandets": "avfattande",
    "avfattar": "avfatta",
    "avfattas": "avfatta",
    "avfattat": "avfatta",
    "avfattats": "avfatta",
    "avfattningar": "avfattning",
    "avfattningarna": "avfattning",
    "avfattningarnas": "avfattning",
    "avfattningars": "avfattning",
    "avfattningen": "avfattning",
    "avfattningens": "avfattning",
    "avfattnings": "avfattning",
    "avfettad": "avfetta",
    "avfettade": "avfetta",
    "avfettades": "avfetta",
    "avfettads": "avfetta",
    "avfettande": "avfetta",
    "avfettanden": "avfettande",
    "avfettandena": "avfettande",
    "avfettandenas": "avfettande",
    "avfettandens": "avfettande",
    "avfettandes": "avfettande",
    "avfettandet": "avfettande",
    "avfettandets": "avfettande",
    "avfettar": "avfetta",
    "avfettas": "avfetta",
    "avfettat": "avfetta",
    "avfettats": "avfetta",
    "avfettningar": "avfettning",
    "avfettningarna": "avfettning",
    "avfettningarnas": "avfettning",
    "avfettningars": "avfettning",
    "avfettningen": "avfettning",
    "avfettningens": "avfettning",
    "avfettnings": "avfettning",
    "avfettningsmedels": "avfettningsmedel",
    "avfettningsmedlen": "avfettningsmedel",
    "avfettningsmedlens": "avfettningsmedel",
    "avfettningsmedlet": "avfettningsmedel",
    "avfettningsmedlets": "avfettningsmedel",
    "avflagnade": "avflagnad",
    "avflagnades": "avflagnad",
    "avflagnads": "avflagnad",
    "avflagnat": "avflagnad",
    "avflagnats": "avflagnad",
    "avflytt": "avflytta",
    "avflyttad": "avflytta",
    "avflyttade": "avflytta",
    "avflyttades": "avflytta",
    "avflyttads": "avflytta",
    "avflyttande": "avflytta",
    "avflyttanden": "avflyttande",
    "avflyttandena": "avflyttande",
    "avflyttandenas": "avflyttande",
    "avflyttandens": "avflyttande",
    "avflyttandes": "avflyttande",
    "avflyttandet": "avflyttande",
    "avflyttandets": "avflyttande",
    "avflyttar": "avflytta",
    "avflyttas": "avflytta",
    "avflyttat": "avflytta",
    "avflyttats": "avflytta",
    "avflyttningsförbuden": "avflyttningsförbud",
    "avflyttningsförbudens": "avflyttningsförbud",
    "avflyttningsförbudet": "avflyttningsförbud",
    "avflyttningsförbudets": "avflyttningsförbud",
    "avflyttningsförbuds": "avflyttningsförbud",
    "avflöden": "avflöde",
    "avflödena": "avflöde",
    "avflödenas": "avflöde",
    "avflödens": "avflöde",
    "avflödes": "avflöde",
    "avflödet": "avflöde",
    "avflödets": "avflöde",
    "avfolk": "avfolka",
    "avfolkad": "avfolka",
    "avfolkade": "avfolka",
    "avfolkades": "avfolka",
    "avfolkads": "avfolka",
    "avfolkande": "avfolka",
    "avfolkanden": "avfolkande",
    "avfolkandena": "avfolkande",
    "avfolkandenas": "avfolkande",
    "avfolkandens": "avfolkande",
    "avfolkandes": "avfolkande",
    "avfolkandet": "avfolkande",
    "avfolkandets": "avfolkande",
    "avfolkar": "avfolka",
    "avfolkas": "avfolka",
    "avfolkat": "avfolka",
    "avfolkats": "avfolka",
    "avfolkningar": "avfolkning",
    "avfolkningarna": "avfolkning",
    "avfolkningarnas": "avfolkning",
    "avfolkningars": "avfolkning",
    "avfolkningen": "avfolkning",
    "avfolkningens": "avfolkning",
    "avfolknings": "avfolkning",
    "avfordrad": "avfordra",
    "avfordrade": "avfordra",
    "avfordrades": "avfordra",
    "avfordrads": "avfordra",
    "avfordrande": "avfordra",
    "avfordranden": "avfordrande",
    "avfordrandena": "avfordrande",
    "avfordrandenas": "avfordrande",
    "avfordrandens": "avfordrande",
    "avfordrandes": "avfordrande",
    "avfordrandet": "avfordrande",
    "avfordrandets": "avfordrande",
    "avfordrans": "avfordran",
    "avfordrar": "avfordra",
    "avfordras": "avfordra",
    "avfordrat": "avfordra",
    "avfordrats": "avfordra",
    "avfrost": "avfrosta",
    "avfrostad": "avfrosta",
    "avfrostade": "avfrosta",
    "avfrostades": "avfrosta",
    "avfrostads": "avfrosta",
    "avfrostande": "avfrosta",
    "avfrostanden": "avfrostande",
    "avfrostandena": "avfrostande",
    "avfrostandenas": "avfrostande",
    "avfrostandens": "avfrostande",
    "avfrostandes": "avfrostande",
    "avfrostandet": "avfrostande",
    "avfrostandets": "avfrostande",
    "avfrostar": "avfrosta",
    "avfrostas": "avfrosta",
    "avfrostat": "avfrosta",
    "avfrostats": "avfrosta",
    "avfrostningar": "avfrostning",
    "avfrostningarna": "avfrostning",
    "avfrostningarnas": "avfrostning",
    "avfrostningars": "avfrostning",
    "avfrostningen": "avfrostning",
    "avfrostningens": "avfrostning",
    "avfrostnings": "avfrostning",
    "avfuktad": "avfukta",
    "avfuktade": "avfukta",
    "avfuktades": "avfukta",
    "avfuktads": "avfukta",
    "avfuktande": "avfukta",
    "avfuktanden": "avfuktande",
    "avfuktandena": "avfuktande",
    "avfuktandenas": "avfuktande",
    "avfuktandens": "avfuktande",
    "avfuktandes": "avfuktande",
    "avfuktandet": "avfuktande",
    "avfuktandets": "avfuktande",
    "avfuktar": "avfuktare",
    "avfuktaren": "avfuktare",
    "avfuktarens": "avfuktare",
    "avfuktares": "avfuktare",
    "avfuktarna": "avfuktare",
    "avfuktarnas": "avfuktare",
    "avfuktas": "avfukta",
    "avfuktat": "avfukta",
    "avfuktats": "avfukta",
    "avfyr": "avfyra",
    "avfyrad": "avfyra",
    "avfyrade": "avfyra",
    "avfyrades": "avfyra",
    "avfyrads": "avfyra",
    "avfyrande": "avfyra",
    "avfyranden": "avfyrande",
    "avfyrandena": "avfyrande",
    "avfyrandenas": "avfyrande",
    "avfyrandens": "avfyrande",
    "avfyrandes": "avfyrande",
    "avfyrandet": "avfyrande",
    "avfyrandets": "avfyrande",
    "avfyrar": "avfyra",
    "avfyras": "avfyra",
    "avfyrat": "avfyra",
    "avfyrats": "avfyra",
    "avfyrningar": "avfyrning",
    "avfyrningarna": "avfyrning",
    "avfyrningarnas": "avfyrning",
    "avfyrningars": "avfyrning",
    "avfyrningen": "avfyrning",
    "avfyrningens": "avfyrning",
    "avfyrnings": "avfyrning",
    "avfyrningskoden": "avfyrningskod",
    "avfyrningskodens": "avfyrningskod",
    "avfyrningskoder": "avfyrningskod",
    "avfyrningskoderna": "avfyrningskod",
    "avfyrningskodernas": "avfyrningskod",
    "avfyrningskoders": "avfyrningskod",
    "avfyrningskods": "avfyrningskod",
    "avfälliga": "avfällig",
    "avfälligare": "avfällig",
    "avfälligares": "avfällig",
    "avfälligas": "avfällig",
    "avfälligast": "avfällig",
    "avfälligaste": "avfällig",
    "avfälligastes": "avfällig",
    "avfälligasts": "avfällig",
    "avfällige": "avfällig",
    "avfälliges": "avfällig",
    "avfälligheten": "avfällighet",
    "avfällighetens": "avfällighet",
    "avfällighets": "avfällighet",
    "avfälligs": "avfällig",
    "avfälligt": "avfällig",
    "avfälligts": "avfällig",
    "avfällingar": "avfälling",
    "avfällingarna": "avfälling",
    "avfällingarnas": "avfälling",
    "avfällingars": "avfälling",
    "avfällingen": "avfälling",
    "avfällingens": "avfälling",
    "avfällings": "avfälling",
    "avfärdad": "avfärda",
    "avfärdade": "avfärda",
    "avfärdades": "avfärda",
    "avfärdads": "avfärda",
    "avfärdande": "avfärda",
    "avfärdanden": "avfärdande",
    "avfärdandena": "avfärdande",
    "avfärdandenas": "avfärdande",
    "avfärdandens": "avfärdande",
    "avfärdandes": "avfärdande",
    "avfärdandet": "avfärdande",
    "avfärdandets": "avfärdande",
    "avfärdar": "avfärda",
    "avfärdas": "avfärda",
    "avfärdat": "avfärda",
    "avfärdats": "avfärda",
    "avfärden": "avfärd",
    "avfärdens": "avfärd",
    "avfärder": "avfärd",
    "avfärderna": "avfärd",
    "avfärdernas": "avfärd",
    "avfärders": "avfärd",
    "avfärds": "avfärd",
    "avfödan": "avföda",
    "avfödans": "avföda",
    "avfödas": "avföda",
    "avföll": "avfalla",
    "avfölle": "avfalla",
    "avfölles": "avfalla",
    "avfölls": "avfalla",
    "avför": "avföra",
    "avförande": "avföra",
    "avföranden": "avförande",
    "avförandena": "avförande",
    "avförandenas": "avförande",
    "avförandens": "avförande",
    "avförandes": "avförande",
    "avförandet": "avförande",
    "avförandets": "avförande",
    "avföras": "avföra",
    "avförd": "avföra",
    "avförda": "avföra",
    "avfördas": "avföra",
    "avförde": "avföra",
    "avfördes": "avföra",
    "avförds": "avföra",
    "avföres": "avföra",
    "avföringar": "avföring",
    "avföringarna": "avföring",
    "avföringarnas": "avföring",
    "avföringars": "avföring",
    "avföringen": "avföring",
    "avföringens": "avföring",
    "avförings": "avföring",
    "avföringsmedels": "avföringsmedel",
    "avföringsmedlen": "avföringsmedel",
    "avföringsmedlens": "avföringsmedel",
    "avföringsmedlet": "avföringsmedel",
    "avföringsmedlets": "avföringsmedel",
    "avförs": "avföra",
    "avfört": "avföra",
    "avförts": "avföra",
    "avgas": "avgaser",
    "avgaserna": "avgaser",
    "avgasernas": "avgaser",
    "avgasers": "avgaser",
    "avgasförgiftningar": "avgasförgiftning",
    "avgasförgiftningarna": "avgasförgiftning",
    "avgasförgiftningarnas": "avgasförgiftning",
    "avgasförgiftningars": "avgasförgiftning",
    "avgasförgiftningen": "avgasförgiftning",
    "avgasförgiftningens": "avgasförgiftning",
    "avgasförgiftnings": "avgasförgiftning",
    "avgasrören": "avgasrör",
    "avgasrörens": "avgasrör",
    "avgasröret": "avgasrör",
    "avgasrörets": "avgasrör",
    "avgasrörs": "avgasrör",
    "avgav": "avge",
    "avgavs": "avge",
    "avgeende": "avge",
    "avgeendes": "avge",
    "avger": "avge",
    "avges": "avge",
    "avgett": "avge",
    "avgetts": "avge",
    "avgick": "avgå",
    "avgicks": "avgå",
    "avgift": "avgifta",
    "avgiftad": "avgifta",
    "avgiftade": "avgifta",
    "avgiftades": "avgifta",
    "avgiftads": "avgifta",
    "avgiftande": "avgifta",
    "avgiftanden": "avgiftande",
    "avgiftandena": "avgiftande",
    "avgiftandenas": "avgiftande",
    "avgiftandens": "avgiftande",
    "avgiftandes": "avgiftande",
    "avgiftandet": "avgiftande",
    "avgiftandets": "avgiftande",
    "avgiftar": "avgifta",
    "avgiftas": "avgifta",
    "avgiftat": "avgifta",
    "avgiftats": "avgifta",
    "avgiften": "avgift",
    "avgiftens": "avgift",
    "avgifter": "avgift",
    "avgifterna": "avgift",
    "avgifternas": "avgift",
    "avgifters": "avgift",
    "avgiftningar": "avgiftning",
    "avgiftningarna": "avgiftning",
    "avgiftningarnas": "avgiftning",
    "avgiftningars": "avgiftning",
    "avgiftningen": "avgiftning",
    "avgiftningens": "avgiftning",
    "avgiftnings": "avgiftning",
    "avgiftningskliniken": "avgiftningsklinik",
    "avgiftningsklinikens": "avgiftningsklinik",
    "avgiftningskliniker": "avgiftningsklinik",
    "avgiftningsklinikerna": "avgiftningsklinik",
    "avgiftningsklinikernas": "avgiftningsklinik",
    "avgiftningsklinikers": "avgiftningsklinik",
    "avgiftningskliniks": "avgiftningsklinik",
    "avgifts": "avgift",
    "avgiftsbela": "avgiftsbelägga",
    "avgiftsbelade": "avgiftsbelägga",
    "avgiftsbelades": "avgiftsbelägga",
    "avgiftsbelagd": "avgiftsbelägga",
    "avgiftsbelagda": "avgiftsbelägga",
    "avgiftsbelagdas": "avgiftsbelägga",
    "avgiftsbelagde": "avgiftsbelägga",
    "avgiftsbelagdes": "avgiftsbelägga",
    "avgiftsbelagds": "avgiftsbelägga",
    "avgiftsbelagt": "avgiftsbelägga",
    "avgiftsbelagts": "avgiftsbelägga",
    "avgiftsbelas": "avgiftsbelägga",
    "avgiftsbelägg": "avgiftsbelägga",
    "avgiftsbeläggande": "avgiftsbelägga",
    "avgiftsbelägganden": "avgiftsbeläggande",
    "avgiftsbeläggandena": "avgiftsbeläggande",
    "avgiftsbeläggandenas": "avgiftsbeläggande",
    "avgiftsbeläggandens": "avgiftsbeläggande",
    "avgiftsbeläggandes": "avgiftsbeläggande",
    "avgiftsbeläggandet": "avgiftsbeläggande",
    "avgiftsbeläggandets": "avgiftsbeläggande",
    "avgiftsbeläggas": "avgiftsbelägga",
    "avgiftsbelägger": "avgiftsbelägga",
    "avgiftsbelägges": "avgiftsbelägga",
    "avgiftsbeläggs": "avgiftsbelägga",
    "avginge": "avgå",
    "avginges": "avgå",
    "avgiv": "avge",
    "avgiva": "avge",
    "avgivande": "avge",
    "avgivanden": "avgivande",
    "avgivandena": "avgivande",
    "avgivandenas": "avgivande",
    "avgivandens": "avgivande",
    "avgivandes": "avgivande",
    "avgivandet": "avgivande",
    "avgivandets": "avgivande",
    "avgivas": "avge",
    "avgive": "avge",
    "avgiven": "avge",
    "avgivens": "avge",
    "avgiver": "avge",
    "avgives": "avge",
    "avgivet": "avge",
    "avgivets": "avge",
    "avgivit": "avge",
    "avgivits": "avge",
    "avgivna": "avge",
    "avgivnas": "avge",
    "avgivne": "avge",
    "avgivnes": "avge",
    "avgivs": "avge",
    "avgjord": "avgöra",
    "avgjorda": "avgöra",
    "avgjordare": "avgjord",
    "avgjordares": "avgjord",
    "avgjordas": "avgöra",
    "avgjordast": "avgjord",
    "avgjordaste": "avgjord",
    "avgjordastes": "avgjord",
    "avgjordasts": "avgjord",
    "avgjorde": "avgöra",
    "avgjordes": "avgöra",
    "avgjords": "avgöra",
    "avgjort": "avgöra",
    "avgjorts": "avgöra",
    "avgjutningar": "avgjutning",
    "avgjutningarna": "avgjutning",
    "avgjutningarnas": "avgjutning",
    "avgjutningars": "avgjutning",
    "avgjutningen": "avgjutning",
    "avgjutningens": "avgjutning",
    "avgjutnings": "avgjutning",
    "avglansen": "avglans",
    "avglansens": "avglans",
    "avgrunden": "avgrund",
    "avgrundens": "avgrund",
    "avgrunder": "avgrund",
    "avgrunderna": "avgrund",
    "avgrundernas": "avgrund",
    "avgrunders": "avgrund",
    "avgrunds": "avgrund",
    "avgrundsandar": "avgrundsande",
    "avgrundsandarna": "avgrundsande",
    "avgrundsandarnas": "avgrundsande",
    "avgrundsandars": "avgrundsande",
    "avgrundsanden": "avgrundsande",
    "avgrundsandens": "avgrundsande",
    "avgrundsandes": "avgrundsande",
    "avgrundsdjupa": "avgrundsdjup",
    "avgrundsdjupare": "avgrundsdjup",
    "avgrundsdjupares": "avgrundsdjup",
    "avgrundsdjupas": "avgrundsdjup",
    "avgrundsdjupast": "avgrundsdjup",
    "avgrundsdjupaste": "avgrundsdjup",
    "avgrundsdjupastes": "avgrundsdjup",
    "avgrundsdjupasts": "avgrundsdjup",
    "avgrundsdjupe": "avgrundsdjup",
    "avgrundsdjupes": "avgrundsdjup",
    "avgrundsdjups": "avgrundsdjup",
    "avgrundsdjupt": "avgrundsdjup",
    "avgrundsdjupts": "avgrundsdjup",
    "avgränsad": "avgränsa",
    "avgränsade": "avgränsa",
    "avgränsades": "avgränsa",
    "avgränsads": "avgränsa",
    "avgränsande": "avgränsa",
    "avgränsanden": "avgränsande",
    "avgränsandena": "avgränsande",
    "avgränsandenas": "avgränsande",
    "avgränsandens": "avgränsande",
    "avgränsandes": "avgränsande",
    "avgränsandet": "avgränsande",
    "avgränsandets": "avgränsande",
    "avgränsar": "avgränsa",
    "avgränsas": "avgränsa",
    "avgränsat": "avgränsa",
    "avgränsats": "avgränsa",
    "avgudabilden": "avgudabild",
    "avgudabildens": "avgudabild",
    "avgudabilder": "avgudabild",
    "avgudabilderna": "avgudabild",
    "avgudabildernas": "avgudabild",
    "avgudabilders": "avgudabild",
    "avgudabilds": "avgudabild",
    "avgudad": "avguda",
    "avgudade": "avguda",
    "avgudades": "avguda",
    "avgudads": "avguda",
    "avgudande": "avguda",
    "avgudanden": "avgudande",
    "avgudandena": "avgudande",
    "avgudandenas": "avgudande",
    "avgudandens": "avgudande",
    "avgudandes": "avgudande",
    "avgudandet": "avgudande",
    "avgudandets": "avgudande",
    "avgudar": "avguda",
    "avgudarna": "avgud",
    "avgudarnas": "avgud",
    "avgudars": "avgud",
    "avgudas": "avguda",
    "avgudat": "avguda",
    "avgudats": "avguda",
    "avguden": "avgud",
    "avgudens": "avgud",
    "avguds": "avgud",
    "avgälden": "avgäld",
    "avgäldens": "avgäld",
    "avgälder": "avgäld",
    "avgälderna": "avgäld",
    "avgäldernas": "avgäld",
    "avgälders": "avgäld",
    "avgälds": "avgäld",
    "avgärd": "avgärda",
    "avgärdad": "avgärda",
    "avgärdade": "avgärda",
    "avgärdades": "avgärda",
    "avgärdads": "avgärda",
    "avgärdande": "avgärda",
    "avgärdanden": "avgärdande",
    "avgärdandena": "avgärdande",
    "avgärdandenas": "avgärdande",
    "avgärdandens": "avgärdande",
    "avgärdandes": "avgärdande",
    "avgärdandet": "avgärdande",
    "avgärdandets": "avgärdande",
    "avgärdar": "avgärda",
    "avgärdas": "avgärda",
    "avgärdat": "avgärda",
    "avgärdats": "avgärda",
    "avgående": "avgå",
    "avgåenden": "avgående",
    "avgåendena": "avgående",
    "avgåendenas": "avgående",
    "avgåendens": "avgående",
    "avgåendes": "avgående",
    "avgåendet": "avgående",
    "avgåendets": "avgående",
    "avgångar": "avgång",
    "avgångarna": "avgång",
    "avgångarnas": "avgång",
    "avgångars": "avgång",
    "avgånge": "avgå",
    "avgången": "avgång",
    "avgångens": "avgång",
    "avgånges": "avgå",
    "avgånget": "avgå",
    "avgångets": "avgå",
    "avgångna": "avgå",
    "avgångnas": "avgå",
    "avgångne": "avgå",
    "avgångnes": "avgå",
    "avgångs": "avgång",
    "avgångsbetygen": "avgångsbetyg",
    "avgångsbetygens": "avgångsbetyg",
    "avgångsbetyget": "avgångsbetyg",
    "avgångsbetygets": "avgångsbetyg",
    "avgångsbetygs": "avgångsbetyg",
    "avgångsbidragen": "avgångsbidrag",
    "avgångsbidragens": "avgångsbidrag",
    "avgångsbidraget": "avgångsbidrag",
    "avgångsbidragets": "avgångsbidrag",
    "avgångsbidrags": "avgångsbidrag",
    "avgångshallar": "avgångshall",
    "avgångshallarna": "avgångshall",
    "avgångshallarnas": "avgångshall",
    "avgångshallars": "avgångshall",
    "avgångshallen": "avgångshall",
    "avgångshallens": "avgångshall",
    "avgångshalls": "avgångshall",
    "avgångsklassen": "avgångsklass",
    "avgångsklassens": "avgångsklass",
    "avgångsklasser": "avgångsklass",
    "avgångsklasserna": "avgångsklass",
    "avgångsklassernas": "avgångsklass",
    "avgångsklassers": "avgångsklass",
    "avgångskraven": "avgångskrav",
    "avgångskravens": "avgångskrav",
    "avgångskravet": "avgångskrav",
    "avgångskravets": "avgångskrav",
    "avgångskravs": "avgångskrav",
    "avgångsvederlagen": "avgångsvederlag",
    "avgångsvederlagens": "avgångsvederlag",
    "avgångsvederlaget": "avgångsvederlag",
    "avgångsvederlagets": "avgångsvederlag",
    "avgångsvederlags": "avgångsvederlag",
    "avgår": "avgå",
    "avgås": "avgå",
    "avgått": "avgå",
    "avgåtts": "avgå",
    "avgåve": "avge",
    "avgåves": "avge",
    "avgör": "avgöra",
    "avgörande": "avgöra",
    "avgöranden": "avgörande",
    "avgörandena": "avgörande",
    "avgörandenas": "avgörande",
    "avgörandens": "avgörande",
    "avgörandes": "avgörande",
    "avgörandet": "avgörande",
    "avgörandets": "avgörande",
    "avgöras": "avgöra",
    "avgöres": "avgöra",
    "avgörs": "avgöra",
    "avhandlad": "avhandla",
    "avhandlade": "avhandla",
    "avhandlades": "avhandla",
    "avhandlads": "avhandla",
    "avhandlande": "avhandla",
    "avhandlanden": "avhandlande",
    "avhandlandena": "avhandlande",
    "avhandlandenas": "avhandlande",
    "avhandlandens": "avhandlande",
    "avhandlandes": "avhandlande",
    "avhandlandet": "avhandlande",
    "avhandlandets": "avhandlande",
    "avhandlar": "avhandla",
    "avhandlas": "avhandla",
    "avhandlat": "avhandla",
    "avhandlats": "avhandla",
    "avhandlingar": "avhandling",
    "avhandlingarna": "avhandling",
    "avhandlingarnas": "avhandling",
    "avhandlingars": "avhandling",
    "avhandlingen": "avhandling",
    "avhandlingens": "avhandling",
    "avhandlings": "avhandling",
    "avhjälp": "avhjälpa",
    "avhjälpande": "avhjälpa",
    "avhjälpanden": "avhjälpande",
    "avhjälpandena": "avhjälpande",
    "avhjälpandenas": "avhjälpande",
    "avhjälpandens": "avhjälpande",
    "avhjälpandes": "avhjälpande",
    "avhjälpandet": "avhjälpande",
    "avhjälpandets": "avhjälpande",
    "avhjälpas": "avhjälpa",
    "avhjälper": "avhjälpa",
    "avhjälpes": "avhjälpa",
    "avhjälps": "avhjälpa",
    "avhjälpt": "avhjälpa",
    "avhjälpta": "avhjälpa",
    "avhjälptas": "avhjälpa",
    "avhjälpte": "avhjälpa",
    "avhjälptes": "avhjälpa",
    "avhjälpts": "avhjälpa",
    "avhoppade": "avhoppad",
    "avhoppades": "avhoppad",
    "avhoppads": "avhoppad",
    "avhoppar": "avhoppare",
    "avhopparen": "avhoppare",
    "avhopparens": "avhoppare",
    "avhoppares": "avhoppare",
    "avhopparna": "avhoppare",
    "avhopparnas": "avhoppare",
    "avhoppat": "avhoppad",
    "avhoppats": "avhoppad",
    "avhoppen": "avhopp",
    "avhoppens": "avhopp",
    "avhoppet": "avhopp",
    "avhoppets": "avhopp",
    "avhopps": "avhopp",
    "avhys": "avhysa",
    "avhysande": "avhysa",
    "avhysanden": "avhysande",
    "avhysandena": "avhysande",
    "avhysandenas": "avhysande",
    "avhysandens": "avhysande",
    "avhysandes": "avhysande",
    "avhysandet": "avhysande",
    "avhysandets": "avhysande",
    "avhysas": "avhysa",
    "avhyser": "avhysa",
    "avhyses": "avhysa",
    "avhyst": "avhysa",
    "avhysta": "avhysa",
    "avhystas": "avhysa",
    "avhyste": "avhysa",
    "avhystes": "avhysa",
    "avhysts": "avhysa",
    "avhyvlingar": "avhyvling",
    "avhyvlingarna": "avhyvling",
    "avhyvlingarnas": "avhyvling",
    "avhyvlingars": "avhyvling",
    "avhyvlingen": "avhyvling",
    "avhyvlingens": "avhyvling",
    "avhyvlings": "avhyvling",
    "avhällningar": "avhällning",
    "avhällningarna": "avhällning",
    "avhällningarnas": "avhällning",
    "avhällningars": "avhällning",
    "avhällningen": "avhällning",
    "avhällningens": "avhällning",
    "avhällnings": "avhällning",
    "avhällningsöppningar": "avhällningsöppning",
    "avhällningsöppningarna": "avhällningsöppning",
    "avhällningsöppningarnas": "avhällningsöppning",
    "avhällningsöppningars": "avhällningsöppning",
    "avhällningsöppningen": "avhällningsöppning",
    "avhällningsöppningens": "avhällningsöppning",
    "avhällningsöppnings": "avhällningsöppning",
    "avhämt": "avhämta",
    "avhämtad": "avhämta",
    "avhämtade": "avhämta",
    "avhämtades": "avhämta",
    "avhämtads": "avhämta",
    "avhämtande": "avhämta",
    "avhämtanden": "avhämtande",
    "avhämtandena": "avhämtande",
    "avhämtandenas": "avhämtande",
    "avhämtandens": "avhämtande",
    "avhämtandes": "avhämtande",
    "avhämtandet": "avhämtande",
    "avhämtandets": "avhämtande",
    "avhämtar": "avhämta",
    "avhämtas": "avhämta",
    "avhämtat": "avhämta",
    "avhämtats": "avhämta",
    "avhämtningar": "avhämtning",
    "avhämtningarna": "avhämtning",
    "avhämtningarnas": "avhämtning",
    "avhämtningars": "avhämtning",
    "avhämtningen": "avhämtning",
    "avhämtningens": "avhämtning",
    "avhämtnings": "avhämtning",
    "avhänd": "avhända",
    "avhändande": "avhända",
    "avhändanden": "avhändande",
    "avhändandena": "avhändande",
    "avhändandenas": "avhändande",
    "avhändandens": "avhändande",
    "avhändandes": "avhändande",
    "avhändandet": "avhändande",
    "avhändandets": "avhändande",
    "avhändas": "avhända",
    "avhände": "avhända",
    "avhänder": "avhända",
    "avhändes": "avhända",
    "avhänds": "avhända",
    "avhäng": "avhänga",
    "avhängande": "avhänga",
    "avhänganden": "avhängande",
    "avhängandena": "avhängande",
    "avhängandenas": "avhängande",
    "avhängandens": "avhängande",
    "avhängandes": "avhängande",
    "avhängandet": "avhängande",
    "avhängandets": "avhängande",
    "avhängas": "avhänga",
    "avhängd": "avhänga",
    "avhängda": "avhängd",
    "avhängdare": "avhängd",
    "avhängdares": "avhängd",
    "avhängdas": "avhängd",
    "avhängdast": "avhängd",
    "avhängdaste": "avhängd",
    "avhängdastes": "avhängd",
    "avhängdasts": "avhängd",
    "avhängde": "avhängd",
    "avhängdes": "avhängd",
    "avhängds": "avhängd",
    "avhänger": "avhänga",
    "avhänges": "avhänga",
    "avhängiga": "avhängig",
    "avhängigare": "avhängig",
    "avhängigares": "avhängig",
    "avhängigas": "avhängig",
    "avhängigast": "avhängig",
    "avhängigaste": "avhängig",
    "avhängigastes": "avhängig",
    "avhängigasts": "avhängig",
    "avhängige": "avhängig",
    "avhängiges": "avhängig",
    "avhängigheten": "avhängighet",
    "avhängighetens": "avhängighet",
    "avhängighets": "avhängighet",
    "avhängigs": "avhängig",
    "avhängigt": "avhängig",
    "avhängigts": "avhängig",
    "avhängs": "avhänga",
    "avhängt": "avhängd",
    "avhängts": "avhängd",
    "avhänt": "avhända",
    "avhänts": "avhända",
    "avhärd": "avhärda",
    "avhärdad": "avhärda",
    "avhärdade": "avhärda",
    "avhärdades": "avhärda",
    "avhärdads": "avhärda",
    "avhärdande": "avhärda",
    "avhärdanden": "avhärdande",
    "avhärdandena": "avhärdande",
    "avhärdandenas": "avhärdande",
    "avhärdandens": "avhärdande",
    "avhärdandes": "avhärdande",
    "avhärdandet": "avhärdande",
    "avhärdandets": "avhärdande",
    "avhärdar": "avhärda",
    "avhärdas": "avhärda",
    "avhärdat": "avhärda",
    "avhärdats": "avhärda",
    "avhästningar": "avhästning",
    "avhästningarna": "avhästning",
    "avhästningarnas": "avhästning",
    "avhästningars": "avhästning",
    "avhästningen": "avhästning",
    "avhästningens": "avhästning",
    "avhästnings": "avhästning",
    "avhåll": "avhålla",
    "avhållande": "avhålla",
    "avhållanden": "avhållande",
    "avhållandena": "avhållande",
    "avhållandenas": "avhållande",
    "avhållandens": "avhållande",
    "avhållandes": "avhållande",
    "avhållandet": "avhållande",
    "avhållandets": "avhållande",
    "avhållas": "avhålla",
    "avhålle": "avhålla",
    "avhållen": "avhålla",
    "avhållens": "avhållen",
    "avhåller": "avhålla",
    "avhålles": "avhålla",
    "avhållet": "avhållen",
    "avhållets": "avhållen",
    "avhållit": "avhålla",
    "avhållits": "avhålla",
    "avhållna": "avhållen",
    "avhållnare": "avhållen",
    "avhållnares": "avhållen",
    "avhållnas": "avhållen",
    "avhållnast": "avhållen",
    "avhållnaste": "avhållen",
    "avhållnastes": "avhållen",
    "avhållnasts": "avhållen",
    "avhållne": "avhållen",
    "avhållnes": "avhållen",
    "avhålls": "avhålla",
    "avhållsamheten": "avhållsamhet",
    "avhållsamhetens": "avhållsamhet",
    "avhållsamhets": "avhållsamhet",
    "avhållsamma": "avhållsam",
    "avhållsammare": "avhållsam",
    "avhållsammares": "avhållsam",
    "avhållsammas": "avhållsam",
    "avhållsammast": "avhållsam",
    "avhållsammaste": "avhållsam",
    "avhållsammastes": "avhållsam",
    "avhållsammasts": "avhållsam",
    "avhållsamme": "avhållsam",
    "avhållsammes": "avhållsam",
    "avhållsams": "avhållsam",
    "avhållsamt": "avhållsam",
    "avhållsamts": "avhållsam",
    "avhöll": "avhålla",
    "avhölle": "avhålla",
    "avhölles": "avhålla",
    "avhölls": "avhålla",
    "avhör": "avhöra",
    "avhörande": "avhöra",
    "avhöranden": "avhörande",
    "avhörandena": "avhörande",
    "avhörandenas": "avhörande",
    "avhörandens": "avhörande",
    "avhörandes": "avhörande",
    "avhörandet": "avhörande",
    "avhörandets": "avhörande",
    "avhöras": "avhöra",
    "avhörd": "avhöra",
    "avhörda": "avhöra",
    "avhördas": "avhöra",
    "avhörde": "avhöra",
    "avhördes": "avhöra",
    "avhörds": "avhöra",
    "avhöres": "avhöra",
    "avhörs": "avhöra",
    "avhört": "avhöra",
    "avhörts": "avhöra",
    "avhöst": "avhösta",
    "avhöstad": "avhösta",
    "avhöstade": "avhösta",
    "avhöstades": "avhösta",
    "avhöstads": "avhösta",
    "avhöstande": "avhösta",
    "avhöstanden": "avhöstande",
    "avhöstandena": "avhöstande",
    "avhöstandenas": "avhöstande",
    "avhöstandens": "avhöstande",
    "avhöstandes": "avhöstande",
    "avhöstandet": "avhöstande",
    "avhöstandets": "avhöstande",
    "avhöstar": "avhösta",
    "avhöstas": "avhösta",
    "avhöstat": "avhösta",
    "avhöstats": "avhösta",
    "aviarie": "aviarium",
    "aviarier": "aviarium",
    "aviarierna": "aviarium",
    "aviariernas": "aviarium",
    "aviariers": "aviarium",
    "aviariet": "aviarium",
    "aviariets": "aviarium",
    "aviariums": "aviarium",
    "aviatiken": "aviatik",
    "aviatikens": "aviatik",
    "aviatiks": "aviatik",
    "aviatiska": "aviatisk",
    "aviatiskare": "aviatisk",
    "aviatiskares": "aviatisk",
    "aviatiskas": "aviatisk",
    "aviatiskast": "aviatisk",
    "aviatiskaste": "aviatisk",
    "aviatiskastes": "aviatisk",
    "aviatiskasts": "aviatisk",
    "aviatiske": "aviatisk",
    "aviatiskes": "aviatisk",
    "aviatisks": "aviatisk",
    "aviatiskt": "aviatisk",
    "aviatiskts": "aviatisk",
    "aviatören": "aviatör",
    "aviatörens": "aviatör",
    "aviatörer": "aviatör",
    "aviatörerna": "aviatör",
    "aviatörernas": "aviatör",
    "aviatörers": "aviatör",
    "aviatörs": "aviatör",
    "avien": "avi",
    "aviens": "avi",
    "avier": "avi",
    "avierna": "avi",
    "aviernas": "avi",
    "aviers": "avi",
    "avig": "aviga",
    "aviga": "avig",
    "avigan": "aviga",
    "avigans": "aviga",
    "avigare": "avig",
    "avigares": "avig",
    "avigas": "aviga",
    "avigast": "avig",
    "avigaste": "avig",
    "avigastes": "avig",
    "avigasts": "avig",
    "avige": "aviga",
    "aviges": "avig",
    "avigor": "aviga",
    "avigorna": "aviga",
    "avigornas": "aviga",
    "avigors": "aviga",
    "avigs": "aviga",
    "avigsidan": "avigsida",
    "avigsidans": "avigsida",
    "avigsidas": "avigsida",
    "avigside": "avigsida",
    "avigsides": "avigsida",
    "avigsidor": "avigsida",
    "avigsidorna": "avigsida",
    "avigsidornas": "avigsida",
    "avigsidors": "avigsida",
    "avigt": "avig",
    "avigts": "avig",
    "avin": "avi",
    "avins": "avi",
    "avis": "avisa",
    "avisad": "avisa",
    "avisade": "avisa",
    "avisades": "avisa",
    "avisads": "avisa",
    "avisan": "avisa",
    "avisande": "avisa",
    "avisanden": "avisande",
    "avisandena": "avisande",
    "avisandenas": "avisande",
    "avisandens": "avisande",
    "avisandes": "avisande",
    "avisandet": "avisande",
    "avisandets": "avisande",
    "avisans": "avisa",
    "avisar": "avisa",
    "avisas": "avisa",
    "avisat": "avisa",
    "avisats": "avisa",
    "avise": "avisa",
    "avisen": "avis",
    "avisens": "avis",
    "aviser": "avis",
    "aviserad": "avisera",
    "aviserade": "avisera",
    "aviserades": "avisera",
    "aviserads": "avisera",
    "aviserande": "avisera",
    "aviseranden": "aviserande",
    "aviserandena": "aviserande",
    "aviserandenas": "aviserande",
    "aviserandens": "aviserande",
    "aviserandes": "aviserande",
    "aviserandet": "aviserande",
    "aviserandets": "aviserande",
    "aviserar": "avisera",
    "aviseras": "avisera",
    "aviserat": "avisera",
    "aviserats": "avisera",
    "aviserbara": "aviserbar",
    "aviserbarare": "aviserbar",
    "aviserbarares": "aviserbar",
    "aviserbaras": "aviserbar",
    "aviserbarast": "aviserbar",
    "aviserbaraste": "aviserbar",
    "aviserbarastes": "aviserbar",
    "aviserbarasts": "aviserbar",
    "aviserbare": "aviserbar",
    "aviserbares": "aviserbar",
    "aviserbarheten": "aviserbarhet",
    "aviserbarhetens": "aviserbarhet",
    "aviserbarhets": "aviserbarhet",
    "aviserbars": "aviserbar",
    "aviserbart": "aviserbar",
    "aviserbarts": "aviserbar",
    "aviseringar": "avisering",
    "aviseringarna": "avisering",
    "aviseringarnas": "avisering",
    "aviseringars": "avisering",
    "aviseringen": "avisering",
    "aviseringens": "avisering",
    "aviserings": "avisering",
    "aviseringsperioden": "aviseringsperiod",
    "aviseringsperiodens": "aviseringsperiod",
    "aviseringsperioder": "aviseringsperiod",
    "aviseringsperioderna": "aviseringsperiod",
    "aviseringsperiodernas": "aviseringsperiod",
    "aviseringsperioders": "aviseringsperiod",
    "aviseringsperiods": "aviseringsperiod",
    "aviserna": "avis",
    "avisernas": "avis",
    "avisers": "avis",
    "avisningen": "avisning",
    "avisningens": "avisning",
    "avisnings": "avisning",
    "avisningsanläggningar": "avisningsanläggning",
    "avisningsanläggningarna": "avisningsanläggning",
    "avisningsanläggningarnas": "avisningsanläggning",
    "avisningsanläggningars": "avisningsanläggning",
    "avisningsanläggningen": "avisningsanläggning",
    "avisningsanläggningens": "avisningsanläggning",
    "avisningsanläggnings": "avisningsanläggning",
    "avisofartygen": "avisofartyg",
    "avisofartygens": "avisofartyg",
    "avisofartyget": "avisofartyg",
    "avisofartygets": "avisofartyg",
    "avisofartygs": "avisofartyg",
    "avisor": "avisa",
    "avisorna": "avisa",
    "avisornas": "avisa",
    "avisors": "avisa",
    "avitaminosen": "avitaminos",
    "avitaminosens": "avitaminos",
    "avitaminoser": "avitaminos",
    "avitaminoserna": "avitaminos",
    "avitaminosernas": "avitaminos",
    "avitaminosers": "avitaminos",
    "avjagad": "avjaga",
    "avjagade": "avjaga",
    "avjagades": "avjaga",
    "avjagads": "avjaga",
    "avjagande": "avjaga",
    "avjaganden": "avjagande",
    "avjagandena": "avjagande",
    "avjagandenas": "avjagande",
    "avjagandens": "avjagande",
    "avjagandes": "avjagande",
    "avjagandet": "avjagande",
    "avjagandets": "avjagande",
    "avjagar": "avjaga",
    "avjagas": "avjaga",
    "avjagat": "avjaga",
    "avjagats": "avjaga",
    "avjämnad": "avjämna",
    "avjämnade": "avjämna",
    "avjämnades": "avjämna",
    "avjämnads": "avjämna",
    "avjämnande": "avjämna",
    "avjämnanden": "avjämnande",
    "avjämnandena": "avjämnande",
    "avjämnandenas": "avjämnande",
    "avjämnandens": "avjämnande",
    "avjämnandes": "avjämnande",
    "avjämnandet": "avjämnande",
    "avjämnandets": "avjämnande",
    "avjämnar": "avjämna",
    "avjämnas": "avjämna",
    "avjämnat": "avjämna",
    "avjämnats": "avjämna",
    "avkalkad": "avkalka",
    "avkalkade": "avkalka",
    "avkalkades": "avkalka",
    "avkalkads": "avkalka",
    "avkalkande": "avkalka",
    "avkalkanden": "avkalkande",
    "avkalkandena": "avkalkande",
    "avkalkandenas": "avkalkande",
    "avkalkandens": "avkalkande",
    "avkalkandes": "avkalkande",
    "avkalkandet": "avkalkande",
    "avkalkandets": "avkalkande",
    "avkalkar": "avkalka",
    "avkalkas": "avkalka",
    "avkalkat": "avkalka",
    "avkalkats": "avkalka",
    "avkastade": "avkasta",
    "avkastades": "avkasta",
    "avkastande": "avkasta",
    "avkastanden": "avkastande",
    "avkastandena": "avkastande",
    "avkastandenas": "avkastande",
    "avkastandens": "avkastande",
    "avkastandes": "avkastande",
    "avkastandet": "avkastande",
    "avkastandets": "avkastande",
    "avkastar": "avkasta",
    "avkastas": "avkasta",
    "avkastat": "avkasta",
    "avkastats": "avkasta",
    "avkastningar": "avkastning",
    "avkastningarna": "avkastning",
    "avkastningarnas": "avkastning",
    "avkastningars": "avkastning",
    "avkastningen": "avkastning",
    "avkastningens": "avkastning",
    "avkastnings": "avkastning",
    "avklappningar": "avklappning",
    "avklappningarna": "avklappning",
    "avklappningarnas": "avklappning",
    "avklappningars": "avklappning",
    "avklappningen": "avklappning",
    "avklappningens": "avklappning",
    "avklappnings": "avklappning",
    "avklar": "avklara",
    "avklarad": "avklara",
    "avklarade": "avklara",
    "avklarades": "avklara",
    "avklarads": "avklara",
    "avklarande": "avklara",
    "avklaranden": "avklarande",
    "avklarandena": "avklarande",
    "avklarandenas": "avklarande",
    "avklarandens": "avklarande",
    "avklarandes": "avklarande",
    "avklarandet": "avklarande",
    "avklarandets": "avklarande",
    "avklarar": "avklara",
    "avklaras": "avklara",
    "avklarat": "avklara",
    "avklarats": "avklara",
    "avklingad": "avklinga",
    "avklingade": "avklinga",
    "avklingades": "avklinga",
    "avklingads": "avklinga",
    "avklingande": "avklinga",
    "avklinganden": "avklingande",
    "avklingandena": "avklingande",
    "avklingandenas": "avklingande",
    "avklingandens": "avklingande",
    "avklingandes": "avklingande",
    "avklingandet": "avklingande",
    "avklingandets": "avklingande",
    "avklingar": "avklinga",
    "avklingas": "avklinga",
    "avklingat": "avklinga",
    "avklingats": "avklinga",
    "avkläd": "avklä",
    "avkläda": "avklä",
    "avklädande": "avklä",
    "avklädanden": "avklädande",
    "avklädandena": "avklädande",
    "avklädandenas": "avklädande",
    "avklädandens": "avklädande",
    "avklädandes": "avklädande",
    "avklädandet": "avklädande",
    "avklädandets": "avklädande",
    "avklädas": "avklä",
    "avklädd": "avklä",
    "avklädda": "avklä",
    "avkläddas": "avklä",
    "avklädde": "avklä",
    "avkläddes": "avklä",
    "avklädds": "avklä",
    "avkläder": "avklä",
    "avklädningar": "avklädning",
    "avklädningarna": "avklädning",
    "avklädningarnas": "avklädning",
    "avklädningars": "avklädning",
    "avklädningen": "avklädning",
    "avklädningens": "avklädning",
    "avklädnings": "avklädning",
    "avkläds": "avklä",
    "avkläende": "avklä",
    "avkläendes": "avklä",
    "avklär": "avklä",
    "avkläs": "avklä",
    "avklätt": "avklä",
    "avklätts": "avklä",
    "avknoppad": "avknoppa",
    "avknoppade": "avknoppa",
    "avknoppades": "avknoppa",
    "avknoppads": "avknoppa",
    "avknoppande": "avknoppa",
    "avknoppanden": "avknoppande",
    "avknoppandena": "avknoppande",
    "avknoppandenas": "avknoppande",
    "avknoppandens": "avknoppande",
    "avknoppandes": "avknoppande",
    "avknoppandet": "avknoppande",
    "avknoppandets": "avknoppande",
    "avknoppar": "avknoppa",
    "avknoppas": "avknoppa",
    "avknoppat": "avknoppa",
    "avknoppats": "avknoppa",
    "avknoppningar": "avknoppning",
    "avknoppningarna": "avknoppning",
    "avknoppningarnas": "avknoppning",
    "avknoppningars": "avknoppning",
    "avknoppningen": "avknoppning",
    "avknoppningens": "avknoppning",
    "avknoppnings": "avknoppning",
    "avknoppningsföretagen": "avknoppningsföretag",
    "avknoppningsföretagens": "avknoppningsföretag",
    "avknoppningsföretaget": "avknoppningsföretag",
    "avknoppningsföretagets": "avknoppningsföretag",
    "avknoppningsföretags": "avknoppningsföretag",
    "avkodad": "avkoda",
    "avkodade": "avkoda",
    "avkodades": "avkoda",
    "avkodads": "avkoda",
    "avkodande": "avkoda",
    "avkodandes": "avkoda",
    "avkodar": "avkoda",
    "avkodas": "avkoda",
    "avkodat": "avkoda",
    "avkodats": "avkoda",
    "avkoken": "avkok",
    "avkokens": "avkok",
    "avkoket": "avkok",
    "avkokets": "avkok",
    "avkoks": "avkok",
    "avkoloniserad": "avkolonisera",
    "avkoloniserade": "avkolonisera",
    "avkoloniserades": "avkolonisera",
    "avkoloniserads": "avkolonisera",
    "avkoloniserande": "avkolonisera",
    "avkoloniseranden": "avkoloniserande",
    "avkoloniserandena": "avkoloniserande",
    "avkoloniserandenas": "avkoloniserande",
    "avkoloniserandens": "avkoloniserande",
    "avkoloniserandes": "avkoloniserande",
    "avkoloniserandet": "avkoloniserande",
    "avkoloniserandets": "avkoloniserande",
    "avkoloniserar": "avkolonisera",
    "avkoloniseras": "avkolonisera",
    "avkoloniserat": "avkolonisera",
    "avkoloniserats": "avkolonisera",
    "avkoloniserbara": "avkoloniserbar",
    "avkoloniserbarare": "avkoloniserbar",
    "avkoloniserbarares": "avkoloniserbar",
    "avkoloniserbaras": "avkoloniserbar",
    "avkoloniserbarast": "avkoloniserbar",
    "avkoloniserbaraste": "avkoloniserbar",
    "avkoloniserbarastes": "avkoloniserbar",
    "avkoloniserbarasts": "avkoloniserbar",
    "avkoloniserbare": "avkoloniserbar",
    "avkoloniserbares": "avkoloniserbar",
    "avkoloniserbarheten": "avkoloniserbarhet",
    "avkoloniserbarhetens": "avkoloniserbarhet",
    "avkoloniserbarhets": "avkoloniserbarhet",
    "avkoloniserbars": "avkoloniserbar",
    "avkoloniserbart": "avkoloniserbar",
    "avkoloniserbarts": "avkoloniserbar",
    "avkoloniseringar": "avkolonisering",
    "avkoloniseringarna": "avkolonisering",
    "avkoloniseringarnas": "avkolonisering",
    "avkoloniseringars": "avkolonisering",
    "avkoloniseringen": "avkolonisering",
    "avkoloniseringens": "avkolonisering",
    "avkoloniserings": "avkolonisering",
    "avkom": "avkomma",
    "avkomlingar": "avkomling",
    "avkomlingarna": "avkomling",
    "avkomlingarnas": "avkomling",
    "avkomlingars": "avkomling",
    "avkomlingen": "avkomling",
    "avkomlingens": "avkomling",
    "avkomlings": "avkomling",
    "avkomman": "avkomma",
    "avkommans": "avkomma",
    "avkommas": "avkomma",
    "avkomme": "avkomma",
    "avkommor": "avkomma",
    "avkommorna": "avkomma",
    "avkommornas": "avkomma",
    "avkommors": "avkomma",
    "avkoms": "avkomma",
    "avkomsten": "avkomst",
    "avkomstens": "avkomst",
    "avkomsträtten": "avkomsträtt",
    "avkomsträttens": "avkomsträtt",
    "avkomsträtts": "avkomsträtt",
    "avkomsts": "avkomst",
    "avkopplad": "avkoppla",
    "avkopplade": "avkoppla",
    "avkopplades": "avkoppla",
    "avkopplads": "avkoppla",
    "avkopplande": "avkoppla",
    "avkopplanden": "avkopplande",
    "avkopplandena": "avkopplande",
    "avkopplandenas": "avkopplande",
    "avkopplandens": "avkopplande",
    "avkopplandes": "avkopplande",
    "avkopplandet": "avkopplande",
    "avkopplandets": "avkopplande",
    "avkopplar": "avkoppla",
    "avkopplas": "avkoppla",
    "avkopplat": "avkoppla",
    "avkopplats": "avkoppla",
    "avkopplingar": "avkoppling",
    "avkopplingarna": "avkoppling",
    "avkopplingarnas": "avkoppling",
    "avkopplingars": "avkoppling",
    "avkopplingen": "avkoppling",
    "avkopplingens": "avkoppling",
    "avkopplings": "avkoppling",
    "avkort": "avkorta",
    "avkortad": "avkorta",
    "avkortade": "avkorta",
    "avkortades": "avkorta",
    "avkortads": "avkorta",
    "avkortande": "avkorta",
    "avkortanden": "avkortande",
    "avkortandena": "avkortande",
    "avkortandenas": "avkortande",
    "avkortandens": "avkortande",
    "avkortandes": "avkortande",
    "avkortandet": "avkortande",
    "avkortandets": "avkortande",
    "avkortar": "avkorta",
    "avkortas": "avkorta",
    "avkortat": "avkorta",
    "avkortats": "avkorta",
    "avkortningar": "avkortning",
    "avkortningarna": "avkortning",
    "avkortningarnas": "avkortning",
    "avkortningars": "avkortning",
    "avkortningen": "avkortning",
    "avkortningens": "avkortning",
    "avkortnings": "avkortning",
    "avkriminaliserad": "avkriminalisera",
    "avkriminaliserade": "avkriminalisera",
    "avkriminaliserades": "avkriminalisera",
    "avkriminaliserads": "avkriminalisera",
    "avkriminaliserande": "avkriminalisera",
    "avkriminaliseranden": "avkriminaliserande",
    "avkriminaliserandena": "avkriminaliserande",
    "avkriminaliserandenas": "avkriminaliserande",
    "avkriminaliserandens": "avkriminaliserande",
    "avkriminaliserandes": "avkriminaliserande",
    "avkriminaliserandet": "avkriminaliserande",
    "avkriminaliserandets": "avkriminaliserande",
    "avkriminaliserar": "avkriminalisera",
    "avkriminaliseras": "avkriminalisera",
    "avkriminaliserat": "avkriminalisera",
    "avkriminaliserats": "avkriminalisera",
    "avkriminaliserbara": "avkriminaliserbar",
    "avkriminaliserbarare": "avkriminaliserbar",
    "avkriminaliserbarares": "avkriminaliserbar",
    "avkriminaliserbaras": "avkriminaliserbar",
    "avkriminaliserbarast": "avkriminaliserbar",
    "avkriminaliserbaraste": "avkriminaliserbar",
    "avkriminaliserbarastes": "avkriminaliserbar",
    "avkriminaliserbarasts": "avkriminaliserbar",
    "avkriminaliserbare": "avkriminaliserbar",
    "avkriminaliserbares": "avkriminaliserbar",
    "avkriminaliserbarheten": "avkriminaliserbarhet",
    "avkriminaliserbarhetens": "avkriminaliserbarhet",
    "avkriminaliserbarhets": "avkriminaliserbarhet",
    "avkriminaliserbars": "avkriminaliserbar",
    "avkriminaliserbart": "avkriminaliserbar",
    "avkriminaliserbarts": "avkriminaliserbar",
    "avkriminaliseringar": "avkriminalisering",
    "avkriminaliseringarna": "avkriminalisering",
    "avkriminaliseringarnas": "avkriminalisering",
    "avkriminaliseringars": "avkriminalisering",
    "avkriminaliseringen": "avkriminalisering",
    "avkriminaliseringens": "avkriminalisering",
    "avkriminaliserings": "avkriminalisering",
    "avkristnad": "avkristna",
    "avkristnade": "avkristna",
    "avkristnades": "avkristna",
    "avkristnads": "avkristna",
    "avkristnande": "avkristna",
    "avkristnanden": "avkristnande",
    "avkristnandena": "avkristnande",
    "avkristnandenas": "avkristnande",
    "avkristnandens": "avkristnande",
    "avkristnandes": "avkristnande",
    "avkristnandet": "avkristnande",
    "avkristnandets": "avkristnande",
    "avkristnar": "avkristna",
    "avkristnas": "avkristna",
    "avkristnat": "avkristna",
    "avkristnats": "avkristna",
    "avkrokar": "avkrok",
    "avkrokarna": "avkrok",
    "avkrokarnas": "avkrok",
    "avkrokars": "avkrok",
    "avkroken": "avkrok",
    "avkrokens": "avkrok",
    "avkroks": "avkrok",
    "avkräv": "avkräva",
    "avkrävande": "avkräva",
    "avkrävanden": "avkrävande",
    "avkrävandena": "avkrävande",
    "avkrävandenas": "avkrävande",
    "avkrävandens": "avkrävande",
    "avkrävandes": "avkrävande",
    "avkrävandet": "avkrävande",
    "avkrävandets": "avkrävande",
    "avkrävas": "avkräva",
    "avkrävd": "avkräva",
    "avkrävda": "avkräva",
    "avkrävdas": "avkräva",
    "avkrävde": "avkräva",
    "avkrävdes": "avkräva",
    "avkrävds": "avkräva",
    "avkräver": "avkräva",
    "avkräves": "avkräva",
    "avkrävs": "avkräva",
    "avkrävt": "avkräva",
    "avkrävts": "avkräva",
    "avkunnad": "avkunna",
    "avkunnade": "avkunna",
    "avkunnades": "avkunna",
    "avkunnads": "avkunna",
    "avkunnande": "avkunna",
    "avkunnanden": "avkunnande",
    "avkunnandena": "avkunnande",
    "avkunnandenas": "avkunnande",
    "avkunnandens": "avkunnande",
    "avkunnandes": "avkunnande",
    "avkunnandet": "avkunnande",
    "avkunnandets": "avkunnande",
    "avkunnar": "avkunna",
    "avkunnas": "avkunna",
    "avkunnat": "avkunna",
    "avkunnats": "avkunna",
    "avkyl": "avkyla",
    "avkylande": "avkyla",
    "avkylandes": "avkyla",
    "avkylde": "avkyla",
    "avkyler": "avkyla",
    "avkylningar": "avkylning",
    "avkylningarna": "avkylning",
    "avkylningarnas": "avkylning",
    "avkylningars": "avkylning",
    "avkylningen": "avkylning",
    "avkylningens": "avkylning",
    "avkylnings": "avkylning",
    "avkylt": "avkyla",
    "avkänd": "avkänna",
    "avkända": "avkänna",
    "avkändas": "avkänna",
    "avkände": "avkänna",
    "avkändes": "avkänna",
    "avkänds": "avkänna",
    "avkänn": "avkänna",
    "avkännande": "avkänna",
    "avkännandes": "avkänna",
    "avkännar": "avkännare",
    "avkännaren": "avkännare",
    "avkännarens": "avkännare",
    "avkännares": "avkännare",
    "avkännarna": "avkännare",
    "avkännarnas": "avkännare",
    "avkännas": "avkänna",
    "avkänner": "avkänna",
    "avkännes": "avkänna",
    "avkänns": "avkänna",
    "avkänt": "avkänna",
    "avkänts": "avkänna",
    "avkön": "avköna",
    "avkönad": "avköna",
    "avkönade": "avköna",
    "avkönades": "avköna",
    "avkönads": "avköna",
    "avkönande": "avköna",
    "avkönanden": "avkönande",
    "avkönandena": "avkönande",
    "avkönandenas": "avkönande",
    "avkönandens": "avkönande",
    "avkönandes": "avkönande",
    "avkönandet": "avkönande",
    "avkönandets": "avkönande",
    "avkönar": "avköna",
    "avkönas": "avköna",
    "avkönat": "avköna",
    "avkönats": "avköna",
    "avkörningsrampen": "avkörningsramp",
    "avkörningsrampens": "avkörningsramp",
    "avkörningsramper": "avkörningsramp",
    "avkörningsramperna": "avkörningsramp",
    "avkörningsrampernas": "avkörningsramp",
    "avkörningsrampers": "avkörningsramp",
    "avkörningsramps": "avkörningsramp",
    "avla": "avlägga",
    "avlad": "avla",
    "avlade": "avlägga",
    "avlades": "avlägga",
    "avlads": "avla",
    "avlagd": "avlägga",
    "avlagda": "avlägga",
    "avlagdare": "avlagd",
    "avlagdares": "avlagd",
    "avlagdas": "avlägga",
    "avlagdast": "avlagd",
    "avlagdaste": "avlagd",
    "avlagdastes": "avlagd",
    "avlagdasts": "avlagd",
    "avlagde": "avlägga",
    "avlagdes": "avlägga",
    "avlagds": "avlägga",
    "avlagrad": "avlagra",
    "avlagrade": "avlagra",
    "avlagrades": "avlagra",
    "avlagrads": "avlagra",
    "avlagrande": "avlagra",
    "avlagranden": "avlagrande",
    "avlagrandena": "avlagrande",
    "avlagrandenas": "avlagrande",
    "avlagrandens": "avlagrande",
    "avlagrandes": "avlagrande",
    "avlagrandet": "avlagrande",
    "avlagrandets": "avlagrande",
    "avlagrar": "avlagra",
    "avlagras": "avlagra",
    "avlagrat": "avlagra",
    "avlagrats": "avlagra",
    "avlagringar": "avlagring",
    "avlagringarna": "avlagring",
    "avlagringarnas": "avlagring",
    "avlagringars": "avlagring",
    "avlagringen": "avlagring",
    "avlagringens": "avlagring",
    "avlagrings": "avlagring",
    "avlagt": "avlägga",
    "avlagts": "avlägga",
    "avlande": "avla",
    "avlanden": "avlande",
    "avlandena": "avlande",
    "avlandenas": "avlande",
    "avlandens": "avlande",
    "avlandes": "avlande",
    "avlandet": "avlande",
    "avlandets": "avlande",
    "avlar": "avla",
    "avlas": "avlägga",
    "avlast": "avlasta",
    "avlastad": "avlasta",
    "avlastade": "avlasta",
    "avlastades": "avlasta",
    "avlastads": "avlasta",
    "avlastande": "avlasta",
    "avlastanden": "avlastande",
    "avlastandena": "avlastande",
    "avlastandenas": "avlastande",
    "avlastandens": "avlastande",
    "avlastandes": "avlastande",
    "avlastandet": "avlastande",
    "avlastandets": "avlastande",
    "avlastar": "avlastare",
    "avlastaren": "avlastare",
    "avlastarens": "avlastare",
    "avlastares": "avlastare",
    "avlastarna": "avlastare",
    "avlastarnas": "avlastare",
    "avlastas": "avlasta",
    "avlastat": "avlasta",
    "avlastats": "avlasta",
    "avlastningar": "avlastning",
    "avlastningarna": "avlastning",
    "avlastningarnas": "avlastning",
    "avlastningars": "avlastning",
    "avlastningen": "avlastning",
    "avlastningens": "avlastning",
    "avlastnings": "avlastning",
    "avlastningsplatsen": "avlastningsplats",
    "avlastningsplatsens": "avlastningsplats",
    "avlastningsplatser": "avlastningsplats",
    "avlastningsplatserna": "avlastningsplats",
    "avlastningsplatsernas": "avlastningsplats",
    "avlastningsplatsers": "avlastningsplats",
    "avlat": "avla",
    "avlaten": "avlat",
    "avlatens": "avlat",
    "avlats": "avlat",
    "avlatsbreven": "avlatsbrev",
    "avlatsbrevens": "avlatsbrev",
    "avlatsbrevet": "avlatsbrev",
    "avlatsbrevets": "avlatsbrev",
    "avlatsbrevs": "avlatsbrev",
    "avled": "avlida",
    "avledande": "avleda",
    "avledanden": "avledande",
    "avledandena": "avledande",
    "avledandenas": "avledande",
    "avledandens": "avledande",
    "avledandes": "avledande",
    "avledandet": "avledande",
    "avledandets": "avledande",
    "avledas": "avleda",
    "avledd": "avleda",
    "avledda": "avleda",
    "avleddas": "avleda",
    "avledde": "avleda",
    "avleddes": "avleda",
    "avledds": "avleda",
    "avleder": "avleda",
    "avledes": "avleda",
    "avledningar": "avledning",
    "avledningarna": "avledning",
    "avledningarnas": "avledning",
    "avledningars": "avledning",
    "avledningen": "avledning",
    "avledningens": "avledning",
    "avlednings": "avledning",
    "avledningsändelsen": "avledningsändelse",
    "avledningsändelsens": "avledningsändelse",
    "avledningsändelser": "avledningsändelse",
    "avledningsändelserna": "avledningsändelse",
    "avledningsändelsernas": "avledningsändelse",
    "avledningsändelsers": "avledningsändelse",
    "avledningsändelses": "avledningsändelse",
    "avleds": "avlida",
    "avlelsen": "avlelse",
    "avlelsens": "avlelse",
    "avlelses": "avlelse",
    "avlett": "avleda",
    "avletts": "avleda",
    "avlid": "avlida",
    "avlidande": "avlida",
    "avlidanden": "avlidande",
    "avlidandena": "avlidande",
    "avlidandenas": "avlidande",
    "avlidandens": "avlidande",
    "avlidandes": "avlidande",
    "avlidandet": "avlidande",
    "avlidandets": "avlidande",
    "avlidas": "avlida",
    "avlide": "avlida",
    "avliden": "avlida",
    "avlidens": "avlida",
    "avlider": "avlida",
    "avlides": "avlida",
    "avlidet": "avlida",
    "avlidets": "avlida",
    "avlidit": "avlida",
    "avlidits": "avlida",
    "avlidna": "avlida",
    "avlidnas": "avlida",
    "avlidne": "avlida",
    "avlidnes": "avlida",
    "avlids": "avlida",
    "avlingen": "avlinge",
    "avlingena": "avlinge",
    "avlingenas": "avlinge",
    "avlingens": "avlinge",
    "avlinges": "avlinge",
    "avlinget": "avlinge",
    "avlingets": "avlinge",
    "avliv": "avliva",
    "avlivad": "avliva",
    "avlivade": "avliva",
    "avlivades": "avliva",
    "avlivads": "avliva",
    "avlivande": "avliva",
    "avlivanden": "avlivande",
    "avlivandena": "avlivande",
    "avlivandenas": "avlivande",
    "avlivandens": "avlivande",
    "avlivandes": "avlivande",
    "avlivandet": "avlivande",
    "avlivandets": "avlivande",
    "avlivar": "avliva",
    "avlivas": "avliva",
    "avlivat": "avliva",
    "avlivats": "avliva",
    "avljuden": "avljud",
    "avljudens": "avljud",
    "avljudet": "avljud",
    "avljudets": "avljud",
    "avljuds": "avljud",
    "avlock": "avlocka",
    "avlockad": "avlocka",
    "avlockade": "avlocka",
    "avlockades": "avlocka",
    "avlockads": "avlocka",
    "avlockande": "avlocka",
    "avlockanden": "avlockande",
    "avlockandena": "avlockande",
    "avlockandenas": "avlockande",
    "avlockandens": "avlockande",
    "avlockandes": "avlockande",
    "avlockandet": "avlockande",
    "avlockandets": "avlockande",
    "avlockar": "avlocka",
    "avlockas": "avlocka",
    "avlockat": "avlocka",
    "avlockats": "avlocka",
    "avloppen": "avlopp",
    "avloppens": "avlopp",
    "avloppet": "avlopp",
    "avloppets": "avlopp",
    "avlopps": "avlopp",
    "avloppsdiken": "avloppsdike",
    "avloppsdikena": "avloppsdike",
    "avloppsdikenas": "avloppsdike",
    "avloppsdikens": "avloppsdike",
    "avloppsdikes": "avloppsdike",
    "avloppsdiket": "avloppsdike",
    "avloppsdikets": "avloppsdike",
    "avloppsledningar": "avloppsledning",
    "avloppsledningarna": "avloppsledning",
    "avloppsledningarnas": "avloppsledning",
    "avloppsledningars": "avloppsledning",
    "avloppsledningen": "avloppsledning",
    "avloppsledningens": "avloppsledning",
    "avloppslednings": "avloppsledning",
    "avloppsrensar": "avloppsrensare",
    "avloppsrensaren": "avloppsrensare",
    "avloppsrensarens": "avloppsrensare",
    "avloppsrensares": "avloppsrensare",
    "avloppsrensarna": "avloppsrensare",
    "avloppsrensarnas": "avloppsrensare",
    "avloppsrensningar": "avloppsrensning",
    "avloppsrensningarna": "avloppsrensning",
    "avloppsrensningarnas": "avloppsrensning",
    "avloppsrensningars": "avloppsrensning",
    "avloppsrensningen": "avloppsrensning",
    "avloppsrensningens": "avloppsrensning",
    "avloppsrensnings": "avloppsrensning",
    "avloppsrensningsslangar": "avloppsrensningsslang",
    "avloppsrensningsslangarna": "avloppsrensningsslang",
    "avloppsrensningsslangarnas": "avloppsrensningsslang",
    "avloppsrensningsslangars": "avloppsrensningsslang",
    "avloppsrensningsslangen": "avloppsrensningsslang",
    "avloppsrensningsslangens": "avloppsrensningsslang",
    "avloppsrensningsslangs": "avloppsrensningsslang",
    "avloppsslammet": "avloppsslam",
    "avloppsslammets": "avloppsslam",
    "avloppsslams": "avloppsslam",
    "avloppsvattens": "avloppsvatten",
    "avloppsvattnen": "avloppsvatten",
    "avloppsvattnens": "avloppsvatten",
    "avloppsvattnet": "avloppsvatten",
    "avloppsvattnets": "avloppsvatten",
    "avloss": "avlossa",
    "avlossad": "avlossa",
    "avlossade": "avlossa",
    "avlossades": "avlossa",
    "avlossads": "avlossa",
    "avlossande": "avlossa",
    "avlossanden": "avlossande",
    "avlossandena": "avlossande",
    "avlossandenas": "avlossande",
    "avlossandens": "avlossande",
    "avlossandes": "avlossande",
    "avlossandet": "avlossande",
    "avlossandets": "avlossande",
    "avlossar": "avlossa",
    "avlossas": "avlossa",
    "avlossat": "avlossa",
    "avlossats": "avlossa",
    "avlus": "avlusa",
    "avlusad": "avlusa",
    "avlusade": "avlusa",
    "avlusades": "avlusa",
    "avlusads": "avlusa",
    "avlusande": "avlusa",
    "avlusanden": "avlusande",
    "avlusandena": "avlusande",
    "avlusandenas": "avlusande",
    "avlusandens": "avlusande",
    "avlusandes": "avlusande",
    "avlusandet": "avlusande",
    "avlusandets": "avlusande",
    "avlusar": "avlusa",
    "avlusas": "avlusa",
    "avlusat": "avlusa",
    "avlusats": "avlusa",
    "avlusningar": "avlusning",
    "avlusningarna": "avlusning",
    "avlusningarnas": "avlusning",
    "avlusningars": "avlusning",
    "avlusningen": "avlusning",
    "avlusningens": "avlusning",
    "avlusnings": "avlusning",
    "avlusningsmedels": "avlusningsmedel",
    "avlusningsmedlen": "avlusningsmedel",
    "avlusningsmedlens": "avlusningsmedel",
    "avlusningsmedlet": "avlusningsmedel",
    "avlusningsmedlets": "avlusningsmedel",
    "avlut": "avluta",
    "avlutad": "avluta",
    "avlutade": "avluta",
    "avlutades": "avluta",
    "avlutads": "avluta",
    "avlutande": "avluta",
    "avlutanden": "avlutande",
    "avlutandena": "avlutande",
    "avlutandenas": "avlutande",
    "avlutandens": "avlutande",
    "avlutandes": "avlutande",
    "avlutandet": "avlutande",
    "avlutandets": "avlutande",
    "avlutar": "avluta",
    "avlutas": "avluta",
    "avlutat": "avluta",
    "avlutats": "avluta",
    "avlys": "avlysa",
    "avlysande": "avlysa",
    "avlysanden": "avlysande",
    "avlysandena": "avlysande",
    "avlysandenas": "avlysande",
    "avlysandens": "avlysande",
    "avlysandes": "avlysande",
    "avlysandet": "avlysande",
    "avlysandets": "avlysande",
    "avlysas": "avlysa",
    "avlyser": "avlysa",
    "avlyses": "avlysa",
    "avlyssnad": "avlyssna",
    "avlyssnade": "avlyssna",
    "avlyssnades": "avlyssna",
    "avlyssnads": "avlyssna",
    "avlyssnande": "avlyssna",
    "avlyssnanden": "avlyssnande",
    "avlyssnandena": "avlyssnande",
    "avlyssnandenas": "avlyssnande",
    "avlyssnandens": "avlyssnande",
    "avlyssnandes": "avlyssnande",
    "avlyssnandet": "avlyssnande",
    "avlyssnandets": "avlyssnande",
    "avlyssnar": "avlyssna",
    "avlyssnas": "avlyssna",
    "avlyssnat": "avlyssna",
    "avlyssnats": "avlyssna",
    "avlyssningar": "avlyssning",
    "avlyssningarna": "avlyssning",
    "avlyssningarnas": "avlyssning",
    "avlyssningars": "avlyssning",
    "avlyssningen": "avlyssning",
    "avlyssningens": "avlyssning",
    "avlyssnings": "avlyssning",
    "avlyssningsapparaturen": "avlyssningsapparatur",
    "avlyssningsapparaturens": "avlyssningsapparatur",
    "avlyssningsapparaturer": "avlyssningsapparatur",
    "avlyssningsapparaturerna": "avlyssningsapparatur",
    "avlyssningsapparaturernas": "avlyssningsapparatur",
    "avlyssningsapparaturers": "avlyssningsapparatur",
    "avlyssningsapparaturs": "avlyssningsapparatur",
    "avlyst": "avlysa",
    "avlysta": "avlysa",
    "avlystas": "avlysa",
    "avlyste": "avlysa",
    "avlystes": "avlysa",
    "avlysts": "avlysa",
    "avlägg": "avlägga",
    "avläggande": "avlägga",
    "avlägganden": "avläggande",
    "avläggandena": "avläggande",
    "avläggandenas": "avläggande",
    "avläggandens": "avläggande",
    "avläggandes": "avläggande",
    "avläggandet": "avläggande",
    "avläggandets": "avläggande",
    "avläggar": "avläggare",
    "avläggaren": "avläggare",
    "avläggarens": "avläggare",
    "avläggares": "avläggare",
    "avläggarna": "avläggare",
    "avläggarnas": "avläggare",
    "avläggas": "avlägga",
    "avlägger": "avlägga",
    "avlägges": "avlägga",
    "avläggningar": "avläggning",
    "avläggningarna": "avläggning",
    "avläggningarnas": "avläggning",
    "avläggningars": "avläggning",
    "avläggningen": "avläggning",
    "avläggningens": "avläggning",
    "avläggnings": "avläggning",
    "avläggs": "avlägga",
    "avlägsenheten": "avlägsenhet",
    "avlägsenhetens": "avlägsenhet",
    "avlägsenhets": "avlägsenhet",
    "avlägsens": "avlägsen",
    "avlägset": "avlägsen",
    "avlägsets": "avlägsen",
    "avlägsna": "avlägsen",
    "avlägsnad": "avlägsna",
    "avlägsnade": "avlägsna",
    "avlägsnades": "avlägsna",
    "avlägsnads": "avlägsna",
    "avlägsnande": "avlägsna",
    "avlägsnanden": "avlägsnande",
    "avlägsnandena": "avlägsnande",
    "avlägsnandenas": "avlägsnande",
    "avlägsnandens": "avlägsnande",
    "avlägsnandes": "avlägsnande",
    "avlägsnandet": "avlägsnande",
    "avlägsnandets": "avlägsnande",
    "avlägsnar": "avlägsna",
    "avlägsnare": "avlägsen",
    "avlägsnares": "avlägsen",
    "avlägsnas": "avlägsna",
    "avlägsnast": "avlägsen",
    "avlägsnaste": "avlägsen",
    "avlägsnastes": "avlägsen",
    "avlägsnasts": "avlägsen",
    "avlägsnat": "avlägsna",
    "avlägsnats": "avlägsna",
    "avlägsne": "avlägsen",
    "avlägsnes": "avlägsen",
    "avlämnad": "avlämna",
    "avlämnade": "avlämna",
    "avlämnades": "avlämna",
    "avlämnads": "avlämna",
    "avlämnande": "avlämna",
    "avlämnanden": "avlämnande",
    "avlämnandena": "avlämnande",
    "avlämnandenas": "avlämnande",
    "avlämnandens": "avlämnande",
    "avlämnandes": "avlämnande",
    "avlämnandet": "avlämnande",
    "avlämnandets": "avlämnande",
    "avlämnar": "avlämna",
    "avlämnas": "avlämna",
    "avlämnat": "avlämna",
    "avlämnats": "avlämna",
    "avlämningar": "avlämning",
    "avlämningarna": "avlämning",
    "avlämningarnas": "avlämning",
    "avlämningars": "avlämning",
    "avlämningen": "avlämning",
    "avlämningens": "avlämning",
    "avlämnings": "avlämning",
    "avlänkad": "avlänka",
    "avlänkade": "avlänka",
    "avlänkades": "avlänka",
    "avlänkads": "avlänka",
    "avlänkande": "avlänka",
    "avlänkanden": "avlänkande",
    "avlänkandena": "avlänkande",
    "avlänkandenas": "avlänkande",
    "avlänkandens": "avlänkande",
    "avlänkandes": "avlänkande",
    "avlänkandet": "avlänkande",
    "avlänkandets": "avlänkande",
    "avlänkar": "avlänka",
    "avlänkas": "avlänka",
    "avlänkat": "avlänka",
    "avlänkats": "avlänka",
    "avläs": "avläsa",
    "avläsande": "avläsa",
    "avläsanden": "avläsande",
    "avläsandena": "avläsande",
    "avläsandenas": "avläsande",
    "avläsandens": "avläsande",
    "avläsandes": "avläsande",
    "avläsandet": "avläsande",
    "avläsandets": "avläsande",
    "avläsar": "avläsare",
    "avläsaren": "avläsare",
    "avläsarens": "avläsare",
    "avläsares": "avläsare",
    "avläsarna": "avläsare",
    "avläsarnas": "avläsare",
    "avläsas": "avläsa",
    "avläsbara": "avläsbar",
    "avläsbarare": "avläsbar",
    "avläsbarares": "avläsbar",
    "avläsbaras": "avläsbar",
    "avläsbarast": "avläsbar",
    "avläsbaraste": "avläsbar",
    "avläsbarastes": "avläsbar",
    "avläsbarasts": "avläsbar",
    "avläsbare": "avläsbar",
    "avläsbares": "avläsbar",
    "avläsbarheten": "avläsbarhet",
    "avläsbarhetens": "avläsbarhet",
    "avläsbarhets": "avläsbarhet",
    "avläsbars": "avläsbar",
    "avläsbart": "avläsbar",
    "avläsbarts": "avläsbar",
    "avläser": "avläsa",
    "avläses": "avläsa",
    "avläsningar": "avläsning",
    "avläsningarna": "avläsning",
    "avläsningarnas": "avläsning",
    "avläsningars": "avläsning",
    "avläsningen": "avläsning",
    "avläsningens": "avläsning",
    "avläsnings": "avläsning",
    "avläst": "avläsa",
    "avlästa": "avläsa",
    "avlästas": "avläsa",
    "avläste": "avläsa",
    "avlästes": "avläsa",
    "avlästs": "avläsa",
    "avlät": "avlåta",
    "avläts": "avlåta",
    "avlånga": "avlång",
    "avlångare": "avlång",
    "avlångares": "avlång",
    "avlångas": "avlång",
    "avlångast": "avlång",
    "avlångaste": "avlång",
    "avlångastes": "avlång",
    "avlångasts": "avlång",
    "avlånge": "avlång",
    "avlånges": "avlång",
    "avlångheten": "avlånghet",
    "avlånghetens": "avlånghet",
    "avlånghets": "avlånghet",
    "avlångs": "avlång",
    "avlångt": "avlång",
    "avlångts": "avlång",
    "avlåt": "avlåta",
    "avlåtande": "avlåta",
    "avlåtanden": "avlåtande",
    "avlåtandena": "avlåtande",
    "avlåtandenas": "avlåtande",
    "avlåtandens": "avlåtande",
    "avlåtandes": "avlåtande",
    "avlåtandet": "avlåtande",
    "avlåtandets": "avlåtande",
    "avlåtas": "avlåta",
    "avlåte": "avlåta",
    "avlåten": "avlåta",
    "avlåtens": "avlåta",
    "avlåter": "avlåta",
    "avlåtes": "avlåta",
    "avlåtet": "avlåta",
    "avlåtets": "avlåta",
    "avlåtit": "avlåta",
    "avlåtits": "avlåta",
    "avlåtna": "avlåta",
    "avlåtnas": "avlåta",
    "avlåtne": "avlåta",
    "avlåtnes": "avlåta",
    "avlåts": "avlåta",
    "avlönad": "avlöna",
    "avlönade": "avlöna",
    "avlönades": "avlöna",
    "avlönads": "avlöna",
    "avlönande": "avlöna",
    "avlönanden": "avlönande",
    "avlönandena": "avlönande",
    "avlönandenas": "avlönande",
    "avlönandens": "avlönande",
    "avlönandes": "avlönande",
    "avlönandet": "avlönande",
    "avlönandets": "avlönande",
    "avlönar": "avlöna",
    "avlönas": "avlöna",
    "avlönat": "avlöna",
    "avlönats": "avlöna",
    "avlöningar": "avlöning",
    "avlöningarna": "avlöning",
    "avlöningarnas": "avlöning",
    "avlöningars": "avlöning",
    "avlöningen": "avlöning",
    "avlöningens": "avlöning",
    "avlönings": "avlöning",
    "avlöp": "avlöpa",
    "avlöpande": "avlöpa",
    "avlöpanden": "avlöpande",
    "avlöpandena": "avlöpande",
    "avlöpandenas": "avlöpande",
    "avlöpandens": "avlöpande",
    "avlöpandes": "avlöpande",
    "avlöpandet": "avlöpande",
    "avlöpandets": "avlöpande",
    "avlöpas": "avlöpa",
    "avlöper": "avlöpa",
    "avlöpes": "avlöpa",
    "avlöpningar": "avlöpning",
    "avlöpningarna": "avlöpning",
    "avlöpningarnas": "avlöpning",
    "avlöpningars": "avlöpning",
    "avlöpningen": "avlöpning",
    "avlöpningens": "avlöpning",
    "avlöpnings": "avlöpning",
    "avlöps": "avlöpa",
    "avlöpt": "avlöpa",
    "avlöpta": "avlöpa",
    "avlöptas": "avlöpa",
    "avlöpte": "avlöpa",
    "avlöptes": "avlöpa",
    "avlöpts": "avlöpa",
    "avlös": "avlösa",
    "avlösande": "avlösa",
    "avlösanden": "avlösande",
    "avlösandena": "avlösande",
    "avlösandenas": "avlösande",
    "avlösandens": "avlösande",
    "avlösandes": "avlösande",
    "avlösandet": "avlösande",
    "avlösandets": "avlösande",
    "avlösas": "avlösa",
    "avlöser": "avlösa",
    "avlöses": "avlösa",
    "avlösningar": "avlösning",
    "avlösningarna": "avlösning",
    "avlösningarnas": "avlösning",
    "avlösningars": "avlösning",
    "avlösningen": "avlösning",
    "avlösningens": "avlösning",
    "avlösnings": "avlösning",
    "avlöst": "avlösa",
    "avlösta": "avlösa",
    "avlöstas": "avlösa",
    "avlöste": "avlösa",
    "avlöstes": "avlösa",
    "avlösts": "avlösa",
    "avlöv": "avlöva",
    "avlövad": "avlöva",
    "avlövade": "avlöva",
    "avlövades": "avlöva",
    "avlövads": "avlöva",
    "avlövande": "avlöva",
    "avlövanden": "avlövande",
    "avlövandena": "avlövande",
    "avlövandenas": "avlövande",
    "avlövandens": "avlövande",
    "avlövandes": "avlövande",
    "avlövandet": "avlövande",
    "avlövandets": "avlövande",
    "avlövar": "avlöva",
    "avlövas": "avlöva",
    "avlövat": "avlöva",
    "avlövats": "avlöva",
    "avmagnetiserad": "avmagnetisera",
    "avmagnetiserade": "avmagnetisera",
    "avmagnetiserades": "avmagnetisera",
    "avmagnetiserads": "avmagnetisera",
    "avmagnetiserande": "avmagnetisera",
    "avmagnetiseranden": "avmagnetiserande",
    "avmagnetiserandena": "avmagnetiserande",
    "avmagnetiserandenas": "avmagnetiserande",
    "avmagnetiserandens": "avmagnetiserande",
    "avmagnetiserandes": "avmagnetiserande",
    "avmagnetiserandet": "avmagnetiserande",
    "avmagnetiserandets": "avmagnetiserande",
    "avmagnetiserar": "avmagnetisera",
    "avmagnetiseras": "avmagnetisera",
    "avmagnetiserat": "avmagnetisera",
    "avmagnetiserats": "avmagnetisera",
    "avmagnetiserbara": "avmagnetiserbar",
    "avmagnetiserbarare": "avmagnetiserbar",
    "avmagnetiserbarares": "avmagnetiserbar",
    "avmagnetiserbaras": "avmagnetiserbar",
    "avmagnetiserbarast": "avmagnetiserbar",
    "avmagnetiserbaraste": "avmagnetiserbar",
    "avmagnetiserbarastes": "avmagnetiserbar",
    "avmagnetiserbarasts": "avmagnetiserbar",
    "avmagnetiserbare": "avmagnetiserbar",
    "avmagnetiserbares": "avmagnetiserbar",
    "avmagnetiserbarheten": "avmagnetiserbarhet",
    "avmagnetiserbarhetens": "avmagnetiserbarhet",
    "avmagnetiserbarhets": "avmagnetiserbarhet",
    "avmagnetiserbars": "avmagnetiserbar",
    "avmagnetiserbart": "avmagnetiserbar",
    "avmagnetiserbarts": "avmagnetiserbar",
    "avmagnetiseringar": "avmagnetisering",
    "avmagnetiseringarna": "avmagnetisering",
    "avmagnetiseringarnas": "avmagnetisering",
    "avmagnetiseringars": "avmagnetisering",
    "avmagnetiseringen": "avmagnetisering",
    "avmagnetiseringens": "avmagnetisering",
    "avmagnetiserings": "avmagnetisering",
    "avmagnetiseringsprocessen": "avmagnetiseringsprocess",
    "avmagnetiseringsprocessens": "avmagnetiseringsprocess",
    "avmagnetiseringsprocesser": "avmagnetiseringsprocess",
    "avmagnetiseringsprocesserna": "avmagnetiseringsprocess",
    "avmagnetiseringsprocessernas": "avmagnetiseringsprocess",
    "avmagnetiseringsprocessers": "avmagnetiseringsprocess",
    "avmagrade": "avmagrad",
    "avmagrades": "avmagrad",
    "avmagrads": "avmagrad",
    "avmagrat": "avmagrad",
    "avmagrats": "avmagrad",
    "avmagringar": "avmagring",
    "avmagringarna": "avmagring",
    "avmagringarnas": "avmagring",
    "avmagringars": "avmagring",
    "avmagringen": "avmagring",
    "avmagringens": "avmagring",
    "avmagrings": "avmagring",
    "avmarschen": "avmarsch",
    "avmarschens": "avmarsch",
    "avmarscher": "avmarsch",
    "avmarscherna": "avmarsch",
    "avmarschernas": "avmarsch",
    "avmarschers": "avmarsch",
    "avmarschs": "avmarsch",
    "avmask": "avmaska",
    "avmaskad": "avmaska",
    "avmaskade": "avmaska",
    "avmaskades": "avmaska",
    "avmaskads": "avmaska",
    "avmaskande": "avmaska",
    "avmaskanden": "avmaskande",
    "avmaskandena": "avmaskande",
    "avmaskandenas": "avmaskande",
    "avmaskandens": "avmaskande",
    "avmaskandes": "avmaskande",
    "avmaskandet": "avmaskande",
    "avmaskandets": "avmaskande",
    "avmaskar": "avmaska",
    "avmaskas": "avmaska",
    "avmaskat": "avmaska",
    "avmaskats": "avmaska",
    "avmaskningar": "avmaskning",
    "avmaskningarna": "avmaskning",
    "avmaskningarnas": "avmaskning",
    "avmaskningars": "avmaskning",
    "avmaskningen": "avmaskning",
    "avmaskningens": "avmaskning",
    "avmasknings": "avmaskning",
    "avmaskningskuren": "avmaskningskur",
    "avmaskningskurens": "avmaskningskur",
    "avmaskningskurer": "avmaskningskur",
    "avmaskningskurerna": "avmaskningskur",
    "avmaskningskurernas": "avmaskningskur",
    "avmaskningskurers": "avmaskningskur",
    "avmaskningskurs": "avmaskningskur",
    "avmast": "avmasta",
    "avmastad": "avmasta",
    "avmastade": "avmasta",
    "avmastades": "avmasta",
    "avmastads": "avmasta",
    "avmastande": "avmasta",
    "avmastanden": "avmastande",
    "avmastandena": "avmastande",
    "avmastandenas": "avmastande",
    "avmastandens": "avmastande",
    "avmastandes": "avmastande",
    "avmastandet": "avmastande",
    "avmastandets": "avmastande",
    "avmastar": "avmasta",
    "avmastas": "avmasta",
    "avmastat": "avmasta",
    "avmastats": "avmasta",
    "avmatt": "avmatta",
    "avmattad": "avmatta",
    "avmattade": "avmatta",
    "avmattades": "avmattas",
    "avmattads": "avmatta",
    "avmattande": "avmatta",
    "avmattanden": "avmattande",
    "avmattandena": "avmattande",
    "avmattandenas": "avmattande",
    "avmattandens": "avmattande",
    "avmattandes": "avmattande",
    "avmattandet": "avmattande",
    "avmattandets": "avmattande",
    "avmattar": "avmatta",
    "avmattas": "avmatta",
    "avmattat": "avmatta",
    "avmattats": "avmattas",
    "avmattningar": "avmattning",
    "avmattningarna": "avmattning",
    "avmattningarnas": "avmattning",
    "avmattningars": "avmattning",
    "avmattningen": "avmattning",
    "avmattningens": "avmattning",
    "avmattnings": "avmattning",
    "avmät": "avmäta",
    "avmätande": "avmäta",
    "avmätanden": "avmätande",
    "avmätandena": "avmätande",
    "avmätandenas": "avmätande",
    "avmätandens": "avmätande",
    "avmätandes": "avmätande",
    "avmätandet": "avmätande",
    "avmätandets": "avmätande",
    "avmätas": "avmäta",
    "avmäter": "avmäta",
    "avmätes": "avmäta",
    "avmätningar": "avmätning",
    "avmätningarna": "avmätning",
    "avmätningarnas": "avmätning",
    "avmätningars": "avmätning",
    "avmätningen": "avmätning",
    "avmätningens": "avmätning",
    "avmätnings": "avmätning",
    "avmäts": "avmäta",
    "avmätt": "avmäta",
    "avmätta": "avmätt",
    "avmättare": "avmätt",
    "avmättares": "avmätt",
    "avmättas": "avmätt",
    "avmättast": "avmätt",
    "avmättaste": "avmätt",
    "avmättastes": "avmätt",
    "avmättasts": "avmätt",
    "avmätte": "avmätt",
    "avmättes": "avmätt",
    "avmättheten": "avmätthet",
    "avmätthetens": "avmätthet",
    "avmätthets": "avmätthet",
    "avmätts": "avmätt",
    "avnavlad": "avnavla",
    "avnavlade": "avnavla",
    "avnavlades": "avnavla",
    "avnavlads": "avnavla",
    "avnavlande": "avnavla",
    "avnavlanden": "avnavlande",
    "avnavlandena": "avnavlande",
    "avnavlandenas": "avnavlande",
    "avnavlandens": "avnavlande",
    "avnavlandes": "avnavlande",
    "avnavlandet": "avnavlande",
    "avnavlandets": "avnavlande",
    "avnavlar": "avnavla",
    "avnavlas": "avnavla",
    "avnavlat": "avnavla",
    "avnavlats": "avnavla",
    "avnazifierad": "avnazifiera",
    "avnazifierade": "avnazifiera",
    "avnazifierades": "avnazifiera",
    "avnazifierads": "avnazifiera",
    "avnazifierande": "avnazifiera",
    "avnazifieranden": "avnazifierande",
    "avnazifierandena": "avnazifierande",
    "avnazifierandenas": "avnazifierande",
    "avnazifierandens": "avnazifierande",
    "avnazifierandes": "avnazifierande",
    "avnazifierandet": "avnazifierande",
    "avnazifierandets": "avnazifierande",
    "avnazifierar": "avnazifiera",
    "avnazifieras": "avnazifiera",
    "avnazifierat": "avnazifiera",
    "avnazifierats": "avnazifiera",
    "avnazifierbara": "avnazifierbar",
    "avnazifierbarare": "avnazifierbar",
    "avnazifierbarares": "avnazifierbar",
    "avnazifierbaras": "avnazifierbar",
    "avnazifierbarast": "avnazifierbar",
    "avnazifierbaraste": "avnazifierbar",
    "avnazifierbarastes": "avnazifierbar",
    "avnazifierbarasts": "avnazifierbar",
    "avnazifierbare": "avnazifierbar",
    "avnazifierbares": "avnazifierbar",
    "avnazifierbarheten": "avnazifierbarhet",
    "avnazifierbarhetens": "avnazifierbarhet",
    "avnazifierbarhets": "avnazifierbarhet",
    "avnazifierbars": "avnazifierbar",
    "avnazifierbart": "avnazifierbar",
    "avnazifierbarts": "avnazifierbar",
    "avnazifieringar": "avnazifiering",
    "avnazifieringarna": "avnazifiering",
    "avnazifieringarnas": "avnazifiering",
    "avnazifieringars": "avnazifiering",
    "avnazifieringen": "avnazifiering",
    "avnazifieringens": "avnazifiering",
    "avnazifierings": "avnazifiering",
    "avnjut": "avnjuta",
    "avnjutande": "avnjuta",
    "avnjutanden": "avnjutande",
    "avnjutandena": "avnjutande",
    "avnjutandenas": "avnjutande",
    "avnjutandens": "avnjutande",
    "avnjutandes": "avnjutande",
    "avnjutandet": "avnjutande",
    "avnjutandets": "avnjutande",
    "avnjutas": "avnjuta",
    "avnjute": "avnjuta",
    "avnjuten": "avnjuta",
    "avnjutens": "avnjuta",
    "avnjuter": "avnjuta",
    "avnjutes": "avnjuta",
    "avnjutet": "avnjuta",
    "avnjutets": "avnjuta",
    "avnjutit": "avnjuta",
    "avnjutits": "avnjuta",
    "avnjutna": "avnjuta",
    "avnjutnas": "avnjuta",
    "avnjutne": "avnjuta",
    "avnjutnes": "avnjuta",
    "avnjuts": "avnjuta",
    "avnjöt": "avnjuta",
    "avnjöte": "avnjuta",
    "avnjötes": "avnjuta",
    "avnjöts": "avnjuta",
    "avnämar": "avnämare",
    "avnämaren": "avnämare",
    "avnämarens": "avnämare",
    "avnämares": "avnämare",
    "avnämarna": "avnämare",
    "avnämarnas": "avnämare",
    "avocadon": "avocado",
    "avocadons": "avocado",
    "avocador": "avocado",
    "avocadorna": "avocado",
    "avocadornas": "avocado",
    "avocadors": "avocado",
    "avocados": "avocado",
    "avoga": "avog",
    "avogare": "avog",
    "avogares": "avog",
    "avogas": "avog",
    "avogast": "avog",
    "avogaste": "avog",
    "avogastes": "avog",
    "avogasts": "avog",
    "avoge": "avog",
    "avoges": "avog",
    "avogs": "avog",
    "avogt": "avog",
    "avogts": "avog",
    "avokadon": "avokado",
    "avokadons": "avokado",
    "avokador": "avokado",
    "avokadorna": "avokado",
    "avokadornas": "avokado",
    "avokadors": "avokado",
    "avokados": "avokado",
    "avor": "ava",
    "avorna": "ava",
    "avornas": "ava",
    "avors": "ava",
    "avpassad": "avpassa",
    "avpassade": "avpassa",
    "avpassades": "avpassa",
    "avpassads": "avpassa",
    "avpassande": "avpassa",
    "avpassanden": "avpassande",
    "avpassandena": "avpassande",
    "avpassandenas": "avpassande",
    "avpassandens": "avpassande",
    "avpassandes": "avpassande",
    "avpassandet": "avpassande",
    "avpassandets": "avpassande",
    "avpassar": "avpassa",
    "avpassas": "avpassa",
    "avpassat": "avpassa",
    "avpassats": "avpassa",
    "avpatrullerad": "avpatrullera",
    "avpatrullerade": "avpatrullera",
    "avpatrullerades": "avpatrullera",
    "avpatrullerads": "avpatrullera",
    "avpatrullerande": "avpatrullera",
    "avpatrulleranden": "avpatrullerande",
    "avpatrullerandena": "avpatrullerande",
    "avpatrullerandenas": "avpatrullerande",
    "avpatrullerandens": "avpatrullerande",
    "avpatrullerandes": "avpatrullerande",
    "avpatrullerandet": "avpatrullerande",
    "avpatrullerandets": "avpatrullerande",
    "avpatrullerar": "avpatrullera",
    "avpatrulleras": "avpatrullera",
    "avpatrullerat": "avpatrullera",
    "avpatrullerats": "avpatrullera",
    "avpatrullerbara": "avpatrullerbar",
    "avpatrullerbarare": "avpatrullerbar",
    "avpatrullerbarares": "avpatrullerbar",
    "avpatrullerbaras": "avpatrullerbar",
    "avpatrullerbarast": "avpatrullerbar",
    "avpatrullerbaraste": "avpatrullerbar",
    "avpatrullerbarastes": "avpatrullerbar",
    "avpatrullerbarasts": "avpatrullerbar",
    "avpatrullerbare": "avpatrullerbar",
    "avpatrullerbares": "avpatrullerbar",
    "avpatrullerbarheten": "avpatrullerbarhet",
    "avpatrullerbarhetens": "avpatrullerbarhet",
    "avpatrullerbarhets": "avpatrullerbarhet",
    "avpatrullerbars": "avpatrullerbar",
    "avpatrullerbart": "avpatrullerbar",
    "avpatrullerbarts": "avpatrullerbar",
    "avpatrulleringar": "avpatrullering",
    "avpatrulleringarna": "avpatrullering",
    "avpatrulleringarnas": "avpatrullering",
    "avpatrulleringars": "avpatrullering",
    "avpatrulleringen": "avpatrullering",
    "avpatrulleringens": "avpatrullering",
    "avpatrullerings": "avpatrullering",
    "avplanad": "avplana",
    "avplanade": "avplana",
    "avplanades": "avplana",
    "avplanads": "avplana",
    "avplanande": "avplana",
    "avplananden": "avplanande",
    "avplanandena": "avplanande",
    "avplanandenas": "avplanande",
    "avplanandens": "avplanande",
    "avplanandes": "avplanande",
    "avplanandet": "avplanande",
    "avplanandets": "avplanande",
    "avplanar": "avplana",
    "avplanas": "avplana",
    "avplanat": "avplana",
    "avplanats": "avplana",
    "avpolitiserad": "avpolitisera",
    "avpolitiserade": "avpolitisera",
    "avpolitiserades": "avpolitisera",
    "avpolitiserads": "avpolitisera",
    "avpolitiserande": "avpolitisera",
    "avpolitiseranden": "avpolitiserande",
    "avpolitiserandena": "avpolitiserande",
    "avpolitiserandenas": "avpolitiserande",
    "avpolitiserandens": "avpolitiserande",
    "avpolitiserandes": "avpolitiserande",
    "avpolitiserandet": "avpolitiserande",
    "avpolitiserandets": "avpolitiserande",
    "avpolitiserar": "avpolitisera",
    "avpolitiseras": "avpolitisera",
    "avpolitiserat": "avpolitisera",
    "avpolitiserats": "avpolitisera",
    "avpolitiserbara": "avpolitiserbar",
    "avpolitiserbarare": "avpolitiserbar",
    "avpolitiserbarares": "avpolitiserbar",
    "avpolitiserbaras": "avpolitiserbar",
    "avpolitiserbarast": "avpolitiserbar",
    "avpolitiserbaraste": "avpolitiserbar",
    "avpolitiserbarastes": "avpolitiserbar",
    "avpolitiserbarasts": "avpolitiserbar",
    "avpolitiserbare": "avpolitiserbar",
    "avpolitiserbares": "avpolitiserbar",
    "avpolitiserbarheten": "avpolitiserbarhet",
    "avpolitiserbarhetens": "avpolitiserbarhet",
    "avpolitiserbarhets": "avpolitiserbarhet",
    "avpolitiserbars": "avpolitiserbar",
    "avpolitiserbart": "avpolitiserbar",
    "avpolitiserbarts": "avpolitiserbar",
    "avpolitiseringar": "avpolitisering",
    "avpolitiseringarna": "avpolitisering",
    "avpolitiseringarnas": "avpolitisering",
    "avpolitiseringars": "avpolitisering",
    "avpolitiseringen": "avpolitisering",
    "avpolitiseringens": "avpolitisering",
    "avpolitiserings": "avpolitisering",
    "avpolletterad": "avpollettera",
    "avpolletterade": "avpollettera",
    "avpolletterades": "avpollettera",
    "avpolletterads": "avpollettera",
    "avpolletterande": "avpollettera",
    "avpolletteranden": "avpolletterande",
    "avpolletterandena": "avpolletterande",
    "avpolletterandenas": "avpolletterande",
    "avpolletterandens": "avpolletterande",
    "avpolletterandes": "avpolletterande",
    "avpolletterandet": "avpolletterande",
    "avpolletterandets": "avpolletterande",
    "avpolletterar": "avpollettera",
    "avpolletteras": "avpollettera",
    "avpolletterat": "avpollettera",
    "avpolletterats": "avpollettera",
    "avpolletterbara": "avpolletterbar",
    "avpolletterbarare": "avpolletterbar",
    "avpolletterbarares": "avpolletterbar",
    "avpolletterbaras": "avpolletterbar",
    "avpolletterbarast": "avpolletterbar",
    "avpolletterbaraste": "avpolletterbar",
    "avpolletterbarastes": "avpolletterbar",
    "avpolletterbarasts": "avpolletterbar",
    "avpolletterbare": "avpolletterbar",
    "avpolletterbares": "avpolletterbar",
    "avpolletterbarheten": "avpolletterbarhet",
    "avpolletterbarhetens": "avpolletterbarhet",
    "avpolletterbarhets": "avpolletterbarhet",
    "avpolletterbars": "avpolletterbar",
    "avpolletterbart": "avpolletterbar",
    "avpolletterbarts": "avpolletterbar",
    "avpolletteringar": "avpollettering",
    "avpolletteringarna": "avpollettering",
    "avpolletteringarnas": "avpollettering",
    "avpolletteringars": "avpollettering",
    "avpolletteringen": "avpollettering",
    "avpolletteringens": "avpollettering",
    "avpolletterings": "avpollettering",
    "avporträtterad": "avporträttera",
    "avporträtterade": "avporträttera",
    "avporträtterades": "avporträttera",
    "avporträtterads": "avporträttera",
    "avporträtterande": "avporträttera",
    "avporträtteranden": "avporträtterande",
    "avporträtterandena": "avporträtterande",
    "avporträtterandenas": "avporträtterande",
    "avporträtterandens": "avporträtterande",
    "avporträtterandes": "avporträtterande",
    "avporträtterandet": "avporträtterande",
    "avporträtterandets": "avporträtterande",
    "avporträtterar": "avporträttera",
    "avporträtteras": "avporträttera",
    "avporträtterat": "avporträttera",
    "avporträtterats": "avporträttera",
    "avporträtterbara": "avporträtterbar",
    "avporträtterbarare": "avporträtterbar",
    "avporträtterbarares": "avporträtterbar",
    "avporträtterbaras": "avporträtterbar",
    "avporträtterbarast": "avporträtterbar",
    "avporträtterbaraste": "avporträtterbar",
    "avporträtterbarastes": "avporträtterbar",
    "avporträtterbarasts": "avporträtterbar",
    "avporträtterbare": "avporträtterbar",
    "avporträtterbares": "avporträtterbar",
    "avporträtterbarheten": "avporträtterbarhet",
    "avporträtterbarhetens": "avporträtterbarhet",
    "avporträtterbarhets": "avporträtterbarhet",
    "avporträtterbars": "avporträtterbar",
    "avporträtterbart": "avporträtterbar",
    "avporträtterbarts": "avporträtterbar",
    "avporträtteringar": "avporträttering",
    "avporträtteringarna": "avporträttering",
    "avporträtteringarnas": "avporträttering",
    "avporträtteringars": "avporträttering",
    "avporträtteringen": "avporträttering",
    "avporträtteringens": "avporträttering",
    "avporträtterings": "avporträttering",
    "avpress": "avpressa",
    "avpressad": "avpressa",
    "avpressade": "avpressa",
    "avpressades": "avpressa",
    "avpressads": "avpressa",
    "avpressande": "avpressa",
    "avpressanden": "avpressande",
    "avpressandena": "avpressande",
    "avpressandenas": "avpressande",
    "avpressandens": "avpressande",
    "avpressandes": "avpressande",
    "avpressandet": "avpressande",
    "avpressandets": "avpressande",
    "avpressar": "avpressa",
    "avpressas": "avpressa",
    "avpressat": "avpressa",
    "avpressats": "avpressa",
    "avraden": "avrad",
    "avradens": "avrad",
    "avrads": "avrad",
    "avrakade": "avrakad",
    "avrakades": "avrakad",
    "avrakads": "avrakad",
    "avrakat": "avrakad",
    "avrakats": "avrakad",
    "avrann": "avrinna",
    "avranns": "avrinna",
    "avreagerad": "avreagera",
    "avreagerade": "avreagera",
    "avreagerades": "avreagera",
    "avreagerads": "avreagera",
    "avreagerande": "avreagera",
    "avreageranden": "avreagerande",
    "avreagerandena": "avreagerande",
    "avreagerandenas": "avreagerande",
    "avreagerandens": "avreagerande",
    "avreagerandes": "avreagerande",
    "avreagerandet": "avreagerande",
    "avreagerandets": "avreagerande",
    "avreagerar": "avreagera",
    "avreageras": "avreagera",
    "avreagerat": "avreagera",
    "avreagerats": "avreagera",
    "avreagerbara": "avreagerbar",
    "avreagerbarare": "avreagerbar",
    "avreagerbarares": "avreagerbar",
    "avreagerbaras": "avreagerbar",
    "avreagerbarast": "avreagerbar",
    "avreagerbaraste": "avreagerbar",
    "avreagerbarastes": "avreagerbar",
    "avreagerbarasts": "avreagerbar",
    "avreagerbare": "avreagerbar",
    "avreagerbares": "avreagerbar",
    "avreagerbarheten": "avreagerbarhet",
    "avreagerbarhetens": "avreagerbarhet",
    "avreagerbarhets": "avreagerbarhet",
    "avreagerbars": "avreagerbar",
    "avreagerbart": "avreagerbar",
    "avreagerbarts": "avreagerbar",
    "avreageringar": "avreagering",
    "avreageringarna": "avreagering",
    "avreageringarnas": "avreagering",
    "avreageringars": "avreagering",
    "avreageringen": "avreagering",
    "avreageringens": "avreagering",
    "avreagerings": "avreagering",
    "avred": "avreda",
    "avredande": "avreda",
    "avredanden": "avredande",
    "avredandena": "avredande",
    "avredandenas": "avredande",
    "avredandens": "avredande",
    "avredandes": "avredande",
    "avredandet": "avredande",
    "avredandets": "avredande",
    "avredas": "avreda",
    "avredd": "avreda",
    "avredda": "avreda",
    "avreddas": "avreda",
    "avredde": "avreda",
    "avreddes": "avreda",
    "avredds": "avreda",
    "avreder": "avreda",
    "avredes": "avreda",
    "avredningar": "avredning",
    "avredningarna": "avredning",
    "avredningarnas": "avredning",
    "avredningars": "avredning",
    "avredningen": "avredning",
    "avredningens": "avredning",
    "avrednings": "avredning",
    "avreds": "avreda",
    "avregistrerad": "avregistrera",
    "avregistrerade": "avregistrera",
    "avregistrerades": "avregistrera",
    "avregistrerads": "avregistrera",
    "avregistrerande": "avregistrera",
    "avregistreranden": "avregistrerande",
    "avregistrerandena": "avregistrerande",
    "avregistrerandenas": "avregistrerande",
    "avregistrerandens": "avregistrerande",
    "avregistrerandes": "avregistrerande",
    "avregistrerandet": "avregistrerande",
    "avregistrerandets": "avregistrerande",
    "avregistrerar": "avregistrera",
    "avregistreras": "avregistrera",
    "avregistrerat": "avregistrera",
    "avregistrerats": "avregistrera",
    "avregistrerbara": "avregistrerbar",
    "avregistrerbarare": "avregistrerbar",
    "avregistrerbarares": "avregistrerbar",
    "avregistrerbaras": "avregistrerbar",
    "avregistrerbarast": "avregistrerbar",
    "avregistrerbaraste": "avregistrerbar",
    "avregistrerbarastes": "avregistrerbar",
    "avregistrerbarasts": "avregistrerbar",
    "avregistrerbare": "avregistrerbar",
    "avregistrerbares": "avregistrerbar",
    "avregistrerbarheten": "avregistrerbarhet",
    "avregistrerbarhetens": "avregistrerbarhet",
    "avregistrerbarhets": "avregistrerbarhet",
    "avregistrerbars": "avregistrerbar",
    "avregistrerbart": "avregistrerbar",
    "avregistrerbarts": "avregistrerbar",
    "avregistreringar": "avregistrering",
    "avregistreringarna": "avregistrering",
    "avregistreringarnas": "avregistrering",
    "avregistreringars": "avregistrering",
    "avregistreringen": "avregistrering",
    "avregistreringens": "avregistrering",
    "avregistrerings": "avregistrering",
    "avreglerad": "avreglera",
    "avreglerade": "avreglera",
    "avreglerades": "avreglera",
    "avreglerads": "avreglera",
    "avreglerande": "avreglera",
    "avregleranden": "avreglerande",
    "avreglerandena": "avreglerande",
    "avreglerandenas": "avreglerande",
    "avreglerandens": "avreglerande",
    "avreglerandes": "avreglerande",
    "avreglerandet": "avreglerande",
    "avreglerandets": "avreglerande",
    "avreglerar": "avreglera",
    "avregleras": "avreglera",
    "avreglerat": "avreglera",
    "avreglerats": "avreglera",
    "avreglerbara": "avreglerbar",
    "avreglerbarare": "avreglerbar",
    "avreglerbarares": "avreglerbar",
    "avreglerbaras": "avreglerbar",
    "avreglerbarast": "avreglerbar",
    "avreglerbaraste": "avreglerbar",
    "avreglerbarastes": "avreglerbar",
    "avreglerbarasts": "avreglerbar",
    "avreglerbare": "avreglerbar",
    "avreglerbares": "avreglerbar",
    "avreglerbarheten": "avreglerbarhet",
    "avreglerbarhetens": "avreglerbarhet",
    "avreglerbarhets": "avreglerbarhet",
    "avreglerbars": "avreglerbar",
    "avreglerbart": "avreglerbar",
    "avreglerbarts": "avreglerbar",
    "avregleringar": "avreglering",
    "avregleringarna": "avreglering",
    "avregleringarnas": "avreglering",
    "avregleringars": "avreglering",
    "avregleringen": "avreglering",
    "avregleringens": "avreglering",
    "avreglerings": "avreglering",
    "avrenset": "avrens",
    "avrensets": "avrens",
    "avres": "avresa",
    "avresan": "avresa",
    "avresande": "avresa",
    "avresanden": "avresande",
    "avresandena": "avresande",
    "avresandenas": "avresande",
    "avresandens": "avresande",
    "avresandes": "avresande",
    "avresandet": "avresande",
    "avresandets": "avresande",
    "avresans": "avresa",
    "avresas": "avresa",
    "avrese": "avresa",
    "avreser": "avresa",
    "avreses": "avresa",
    "avresor": "avresa",
    "avresorna": "avresa",
    "avresornas": "avresa",
    "avresors": "avresa",
    "avrest": "avresa",
    "avresta": "avresa",
    "avrestas": "avresa",
    "avreste": "avresa",
    "avrestes": "avresa",
    "avrests": "avresa",
    "avrett": "avreda",
    "avretts": "avreda",
    "avringningar": "avringning",
    "avringningarna": "avringning",
    "avringningarnas": "avringning",
    "avringningars": "avringning",
    "avringningen": "avringning",
    "avringningens": "avringning",
    "avringnings": "avringning",
    "avrinn": "avrinna",
    "avrinnande": "avrinna",
    "avrinnanden": "avrinnande",
    "avrinnandena": "avrinnande",
    "avrinnandenas": "avrinnande",
    "avrinnandens": "avrinnande",
    "avrinnandes": "avrinnande",
    "avrinnandet": "avrinnande",
    "avrinnandets": "avrinnande",
    "avrinnas": "avrinna",
    "avrinne": "avrinna",
    "avrinner": "avrinna",
    "avrinnes": "avrinna",
    "avrinningar": "avrinning",
    "avrinningarna": "avrinning",
    "avrinningarnas": "avrinning",
    "avrinningars": "avrinning",
    "avrinningen": "avrinning",
    "avrinningens": "avrinning",
    "avrinnings": "avrinning",
    "avrinns": "avrinna",
    "avrivningar": "avrivning",
    "avrivningarna": "avrivning",
    "avrivningarnas": "avrivning",
    "avrivningars": "avrivning",
    "avrivningen": "avrivning",
    "avrivningens": "avrivning",
    "avrivnings": "avrivning",
    "avromantiserad": "avromantisera",
    "avromantiserade": "avromantisera",
    "avromantiserades": "avromantisera",
    "avromantiserads": "avromantisera",
    "avromantiserande": "avromantisera",
    "avromantiseranden": "avromantiserande",
    "avromantiserandena": "avromantiserande",
    "avromantiserandenas": "avromantiserande",
    "avromantiserandens": "avromantiserande",
    "avromantiserandes": "avromantiserande",
    "avromantiserandet": "avromantiserande",
    "avromantiserandets": "avromantiserande",
    "avromantiserar": "avromantisera",
    "avromantiseras": "avromantisera",
    "avromantiserat": "avromantisera",
    "avromantiserats": "avromantisera",
    "avromantiserbara": "avromantiserbar",
    "avromantiserbarare": "avromantiserbar",
    "avromantiserbarares": "avromantiserbar",
    "avromantiserbaras": "avromantiserbar",
    "avromantiserbarast": "avromantiserbar",
    "avromantiserbaraste": "avromantiserbar",
    "avromantiserbarastes": "avromantiserbar",
    "avromantiserbarasts": "avromantiserbar",
    "avromantiserbare": "avromantiserbar",
    "avromantiserbares": "avromantiserbar",
    "avromantiserbarheten": "avromantiserbarhet",
    "avromantiserbarhetens": "avromantiserbarhet",
    "avromantiserbarhets": "avromantiserbarhet",
    "avromantiserbars": "avromantiserbar",
    "avromantiserbart": "avromantiserbar",
    "avromantiserbarts": "avromantiserbar",
    "avromantiseringar": "avromantisering",
    "avromantiseringarna": "avromantisering",
    "avromantiseringarnas": "avromantisering",
    "avromantiseringars": "avromantisering",
    "avromantiseringen": "avromantisering",
    "avromantiseringens": "avromantisering",
    "avromantiserings": "avromantisering",
    "avropen": "avrop",
    "avropens": "avrop",
    "avropet": "avrop",
    "avropets": "avrop",
    "avrops": "avrop",
    "avrundad": "avrunda",
    "avrundade": "avrunda",
    "avrundades": "avrunda",
    "avrundads": "avrunda",
    "avrundande": "avrunda",
    "avrundanden": "avrundande",
    "avrundandena": "avrundande",
    "avrundandenas": "avrundande",
    "avrundandens": "avrundande",
    "avrundandes": "avrundande",
    "avrundandet": "avrundande",
    "avrundandets": "avrundande",
    "avrundar": "avrunda",
    "avrundas": "avrunda",
    "avrundat": "avrunda",
    "avrundats": "avrunda",
    "avrunna": "avrinna",
    "avrunnas": "avrinna",
    "avrunne": "avrinna",
    "avrunnen": "avrinna",
    "avrunnens": "avrinna",
    "avrunnes": "avrinna",
    "avrunnet": "avrinna",
    "avrunnets": "avrinna",
    "avrunnit": "avrinna",
    "avrunnits": "avrinna",
    "avrustad": "avrusta",
    "avrustade": "avrusta",
    "avrustades": "avrusta",
    "avrustads": "avrusta",
    "avrustande": "avrusta",
    "avrustanden": "avrustande",
    "avrustandena": "avrustande",
    "avrustandenas": "avrustande",
    "avrustandens": "avrustande",
    "avrustandes": "avrustande",
    "avrustandet": "avrustande",
    "avrustandets": "avrustande",
    "avrustar": "avrusta",
    "avrustas": "avrusta",
    "avrustat": "avrusta",
    "avrustats": "avrusta",
    "avräknad": "avräkna",
    "avräknade": "avräkna",
    "avräknades": "avräkna",
    "avräknads": "avräkna",
    "avräknande": "avräkna",
    "avräknanden": "avräknande",
    "avräknandena": "avräknande",
    "avräknandenas": "avräknande",
    "avräknandens": "avräknande",
    "avräknandes": "avräknande",
    "avräknandet": "avräknande",
    "avräknandets": "avräknande",
    "avräknar": "avräkna",
    "avräknas": "avräkna",
    "avräknat": "avräkna",
    "avräknats": "avräkna",
    "avräkningar": "avräkning",
    "avräkningarna": "avräkning",
    "avräkningarnas": "avräkning",
    "avräkningars": "avräkning",
    "avräkningen": "avräkning",
    "avräkningens": "avräkning",
    "avräknings": "avräkning",
    "avräkningsnot": "avräkningsnota",
    "avräkningsnotan": "avräkningsnota",
    "avräkningsnotans": "avräkningsnota",
    "avräkningsnotas": "avräkningsnota",
    "avräkningsnote": "avräkningsnota",
    "avräkningsnotor": "avräkningsnota",
    "avräkningsnotorna": "avräkningsnota",
    "avräkningsnotornas": "avräkningsnota",
    "avräkningsnotors": "avräkningsnota",
    "avräkningsnots": "avräkningsnota",
    "avrättad": "avrätta",
    "avrättade": "avrätta",
    "avrättades": "avrätta",
    "avrättads": "avrätta",
    "avrättande": "avrätta",
    "avrättanden": "avrättande",
    "avrättandena": "avrättande",
    "avrättandenas": "avrättande",
    "avrättandens": "avrättande",
    "avrättandes": "avrättande",
    "avrättandet": "avrättande",
    "avrättandets": "avrättande",
    "avrättar": "avrätta",
    "avrättas": "avrätta",
    "avrättat": "avrätta",
    "avrättats": "avrätta",
    "avrättningar": "avrättning",
    "avrättningarna": "avrättning",
    "avrättningarnas": "avrättning",
    "avrättningars": "avrättning",
    "avrättningen": "avrättning",
    "avrättningens": "avrättning",
    "avrättnings": "avrättning",
    "avrättningsplatsen": "avrättningsplats",
    "avrättningsplatsens": "avrättningsplats",
    "avrättningsplatser": "avrättningsplats",
    "avrättningsplatserna": "avrättningsplats",
    "avrättningsplatsernas": "avrättningsplats",
    "avrättningsplatsers": "avrättningsplats",
    "avråd": "avråda",
    "avrådande": "avråda",
    "avrådanden": "avrådande",
    "avrådandena": "avrådande",
    "avrådandenas": "avrådande",
    "avrådandens": "avrådande",
    "avrådandes": "avrådande",
    "avrådandet": "avrådande",
    "avrådandets": "avrådande",
    "avrådans": "avrådan",
    "avrådas": "avråda",
    "avrådd": "avråda",
    "avrådda": "avråda",
    "avråddas": "avråda",
    "avrådde": "avråda",
    "avråddes": "avråda",
    "avrådds": "avråda",
    "avråder": "avråda",
    "avrådes": "avråda",
    "avråds": "avråda",
    "avrått": "avråda",
    "avråtts": "avråda",
    "avsa": "avsäga",
    "avsade": "avsäga",
    "avsades": "avsäga",
    "avsagd": "avsäga",
    "avsagda": "avsäga",
    "avsagdas": "avsäga",
    "avsagde": "avsäga",
    "avsagdes": "avsäga",
    "avsagds": "avsäga",
    "avsagt": "avsäga",
    "avsagts": "avsäga",
    "avsaknaden": "avsaknad",
    "avsaknadens": "avsaknad",
    "avsaknader": "avsaknad",
    "avsaknaderna": "avsaknad",
    "avsaknadernas": "avsaknad",
    "avsaknaders": "avsaknad",
    "avsaknads": "avsaknad",
    "avsaltad": "avsalta",
    "avsaltade": "avsalta",
    "avsaltades": "avsalta",
    "avsaltads": "avsalta",
    "avsaltande": "avsalta",
    "avsaltanden": "avsaltande",
    "avsaltandena": "avsaltande",
    "avsaltandenas": "avsaltande",
    "avsaltandens": "avsaltande",
    "avsaltandes": "avsaltande",
    "avsaltandet": "avsaltande",
    "avsaltandets": "avsaltande",
    "avsaltar": "avsalta",
    "avsaltas": "avsalta",
    "avsaltat": "avsalta",
    "avsaltats": "avsalta",
    "avsalus": "avsalu",
    "avsas": "avsäga",
    "avsatsen": "avsats",
    "avsatsens": "avsats",
    "avsatser": "avsats",
    "avsatserna": "avsats",
    "avsatsernas": "avsats",
    "avsatsers": "avsats",
    "avsatt": "avsätta",
    "avsatta": "avsätta",
    "avsattas": "avsätta",
    "avsatte": "avsätta",
    "avsattes": "avsätta",
    "avsatts": "avsätta",
    "avsedd": "avse",
    "avsedda": "avse",
    "avseddas": "avse",
    "avsedde": "avse",
    "avseddes": "avse",
    "avsedds": "avse",
    "avseende": "avse",
    "avseenden": "avseende",
    "avseendena": "avseende",
    "avseendenas": "avseende",
    "avseendens": "avseende",
    "avseendes": "avseende",
    "avseendet": "avseende",
    "avseendets": "avseende",
    "avseglad": "avsegla",
    "avseglade": "avsegla",
    "avseglades": "avsegla",
    "avseglads": "avsegla",
    "avseglande": "avsegla",
    "avseglanden": "avseglande",
    "avseglandena": "avseglande",
    "avseglandenas": "avseglande",
    "avseglandens": "avseglande",
    "avseglandes": "avseglande",
    "avseglandet": "avseglande",
    "avseglandets": "avseglande",
    "avseglar": "avsegla",
    "avseglas": "avsegla",
    "avseglat": "avsegla",
    "avseglats": "avsegla",
    "avseglingar": "avsegling",
    "avseglingarna": "avsegling",
    "avseglingarnas": "avsegling",
    "avseglingars": "avsegling",
    "avseglingen": "avsegling",
    "avseglingens": "avsegling",
    "avseglings": "avsegling",
    "avser": "avse",
    "avses": "avse",
    "avsett": "avse",
    "avsetts": "avse",
    "avsevärda": "avsevärd",
    "avsevärdare": "avsevärd",
    "avsevärdares": "avsevärd",
    "avsevärdas": "avsevärd",
    "avsevärdast": "avsevärd",
    "avsevärdaste": "avsevärd",
    "avsevärdastes": "avsevärd",
    "avsevärdasts": "avsevärd",
    "avsevärde": "avsevärd",
    "avsevärdes": "avsevärd",
    "avsevärds": "avsevärd",
    "avsevärt": "avsevärd",
    "avsevärts": "avsevärd",
    "avsigkommenheten": "avsigkommenhet",
    "avsigkommenhetens": "avsigkommenhet",
    "avsigkommenhets": "avsigkommenhet",
    "avsigkommens": "avsigkommen",
    "avsigkommet": "avsigkommen",
    "avsigkommets": "avsigkommen",
    "avsigkomna": "avsigkommen",
    "avsigkomnare": "avsigkommen",
    "avsigkomnares": "avsigkommen",
    "avsigkomnas": "avsigkommen",
    "avsigkomnast": "avsigkommen",
    "avsigkomnaste": "avsigkommen",
    "avsigkomnastes": "avsigkommen",
    "avsigkomnasts": "avsigkommen",
    "avsigkomne": "avsigkommen",
    "avsigkomnes": "avsigkommen",
    "avsikten": "avsikt",
    "avsiktens": "avsikt",
    "avsikter": "avsikt",
    "avsikterna": "avsikt",
    "avsikternas": "avsikt",
    "avsikters": "avsikt",
    "avsiktliga": "avsiktlig",
    "avsiktligare": "avsiktlig",
    "avsiktligares": "avsiktlig",
    "avsiktligas": "avsiktlig",
    "avsiktligast": "avsiktlig",
    "avsiktligaste": "avsiktlig",
    "avsiktligastes": "avsiktlig",
    "avsiktligasts": "avsiktlig",
    "avsiktlige": "avsiktlig",
    "avsiktliges": "avsiktlig",
    "avsiktligheten": "avsiktlighet",
    "avsiktlighetens": "avsiktlighet",
    "avsiktlighets": "avsiktlighet",
    "avsiktligs": "avsiktlig",
    "avsiktligt": "avsiktlig",
    "avsiktligts": "avsiktlig",
    "avsikts": "avsikt",
    "avsiktsförklaringar": "avsiktsförklaring",
    "avsiktsförklaringarna": "avsiktsförklaring",
    "avsiktsförklaringarnas": "avsiktsförklaring",
    "avsiktsförklaringars": "avsiktsförklaring",
    "avsiktsförklaringen": "avsiktsförklaring",
    "avsiktsförklaringens": "avsiktsförklaring",
    "avsiktsförklarings": "avsiktsförklaring",
    "avsittningar": "avsittning",
    "avsittningarna": "avsittning",
    "avsittningarnas": "avsittning",
    "avsittningars": "avsittning",
    "avsittningen": "avsittning",
    "avsittningens": "avsittning",
    "avsittnings": "avsittning",
    "avsjung": "avsjunga",
    "avsjungande": "avsjunga",
    "avsjunganden": "avsjungande",
    "avsjungandena": "avsjungande",
    "avsjungandenas": "avsjungande",
    "avsjungandens": "avsjungande",
    "avsjungandes": "avsjungande",
    "avsjungandet": "avsjungande",
    "avsjungandets": "avsjungande",
    "avsjungas": "avsjunga",
    "avsjunge": "avsjunga",
    "avsjungen": "avsjunga",
    "avsjungens": "avsjunga",
    "avsjunger": "avsjunga",
    "avsjunges": "avsjunga",
    "avsjunget": "avsjunga",
    "avsjungets": "avsjunga",
    "avsjungit": "avsjunga",
    "avsjungits": "avsjunga",
    "avsjungna": "avsjunga",
    "avsjungnas": "avsjunga",
    "avsjungne": "avsjunga",
    "avsjungnes": "avsjunga",
    "avsjungs": "avsjunga",
    "avsjöng": "avsjunga",
    "avsjönge": "avsjunga",
    "avsjönges": "avsjunga",
    "avsjöngs": "avsjunga",
    "avskaffad": "avskaffa",
    "avskaffade": "avskaffa",
    "avskaffades": "avskaffa",
    "avskaffads": "avskaffa",
    "avskaffande": "avskaffa",
    "avskaffanden": "avskaffande",
    "avskaffandena": "avskaffande",
    "avskaffandenas": "avskaffande",
    "avskaffandens": "avskaffande",
    "avskaffandes": "avskaffande",
    "avskaffandet": "avskaffande",
    "avskaffandets": "avskaffande",
    "avskaffar": "avskaffa",
    "avskaffas": "avskaffa",
    "avskaffat": "avskaffa",
    "avskaffats": "avskaffa",
    "avskar": "avskära",
    "avskars": "avskära",
    "avskav": "avskava",
    "avskavande": "avskava",
    "avskavanden": "avskavande",
    "avskavandena": "avskavande",
    "avskavandenas": "avskavande",
    "avskavandens": "avskavande",
    "avskavandes": "avskavande",
    "avskavandet": "avskavande",
    "avskavandets": "avskavande",
    "avskavas": "avskava",
    "avskavd": "avskava",
    "avskavda": "avskava",
    "avskavdas": "avskava",
    "avskavde": "avskava",
    "avskavdes": "avskava",
    "avskavds": "avskava",
    "avskaver": "avskava",
    "avskaves": "avskava",
    "avskavs": "avskava",
    "avskavt": "avskava",
    "avskavts": "avskava",
    "avskedad": "avskeda",
    "avskedade": "avskeda",
    "avskedades": "avskeda",
    "avskedads": "avskeda",
    "avskedande": "avskeda",
    "avskedanden": "avskedande",
    "avskedandena": "avskedande",
    "avskedandenas": "avskedande",
    "avskedandens": "avskedande",
    "avskedandes": "avskedande",
    "avskedandet": "avskedande",
    "avskedandets": "avskedande",
    "avskedar": "avskeda",
    "avskedas": "avskeda",
    "avskedat": "avskeda",
    "avskedats": "avskeda",
    "avskeden": "avsked",
    "avskedens": "avsked",
    "avskedet": "avsked",
    "avskedets": "avsked",
    "avskeds": "avsked",
    "avskedsansökans": "avskedsansökan",
    "avskedsbreven": "avskedsbrev",
    "avskedsbrevens": "avskedsbrev",
    "avskedsbrevet": "avskedsbrev",
    "avskedsbrevets": "avskedsbrev",
    "avskedsbrevs": "avskedsbrev",
    "avskedsdikten": "avskedsdikt",
    "avskedsdiktens": "avskedsdikt",
    "avskedsdikter": "avskedsdikt",
    "avskedsdikterna": "avskedsdikt",
    "avskedsdikternas": "avskedsdikt",
    "avskedsdikters": "avskedsdikt",
    "avskedsdikts": "avskedsdikt",
    "avskedshälsningar": "avskedshälsning",
    "avskedshälsningarna": "avskedshälsning",
    "avskedshälsningarnas": "avskedshälsning",
    "avskedshälsningars": "avskedshälsning",
    "avskedshälsningen": "avskedshälsning",
    "avskedshälsningens": "avskedshälsning",
    "avskedshälsnings": "avskedshälsning",
    "avskedsknullen": "avskedsknull",
    "avskedsknullens": "avskedsknull",
    "avskedsknullet": "avskedsknull",
    "avskedsknullets": "avskedsknull",
    "avskedsknulls": "avskedsknull",
    "avskedsturnéer": "avskedsturné",
    "avskedsturnéerna": "avskedsturné",
    "avskedsturnéernas": "avskedsturné",
    "avskedsturnéers": "avskedsturné",
    "avskedsturnén": "avskedsturné",
    "avskedsturnéns": "avskedsturné",
    "avskedsturnés": "avskedsturné",
    "avskild": "avskilja",
    "avskilda": "avskilja",
    "avskildare": "avskild",
    "avskildares": "avskild",
    "avskildas": "avskilja",
    "avskildast": "avskild",
    "avskildaste": "avskild",
    "avskildastes": "avskild",
    "avskildasts": "avskild",
    "avskilde": "avskilja",
    "avskildes": "avskilja",
    "avskildheten": "avskildhet",
    "avskildhetens": "avskildhet",
    "avskildheter": "avskildhet",
    "avskildheterna": "avskildhet",
    "avskildheternas": "avskildhet",
    "avskildheters": "avskildhet",
    "avskildhets": "avskildhet",
    "avskilds": "avskilja",
    "avskilj": "avskilja",
    "avskiljande": "avskilja",
    "avskiljanden": "avskiljande",
    "avskiljandena": "avskiljande",
    "avskiljandenas": "avskiljande",
    "avskiljandens": "avskiljande",
    "avskiljandes": "avskiljande",
    "avskiljandet": "avskiljande",
    "avskiljandets": "avskiljande",
    "avskiljas": "avskilja",
    "avskiljer": "avskilja",
    "avskiljes": "avskilja",
    "avskiljs": "avskilja",
    "avskilt": "avskilja",
    "avskilts": "avskilja",
    "avskjut": "avskjuta",
    "avskjutande": "avskjuta",
    "avskjutanden": "avskjutande",
    "avskjutandena": "avskjutande",
    "avskjutandenas": "avskjutande",
    "avskjutandens": "avskjutande",
    "avskjutandes": "avskjutande",
    "avskjutandet": "avskjutande",
    "avskjutandets": "avskjutande",
    "avskjutas": "avskjuta",
    "avskjute": "avskjuta",
    "avskjuten": "avskjuta",
    "avskjutens": "avskjuta",
    "avskjuter": "avskjuta",
    "avskjutes": "avskjuta",
    "avskjutet": "avskjuta",
    "avskjutets": "avskjuta",
    "avskjutit": "avskjuta",
    "avskjutits": "avskjuta",
    "avskjutna": "avskjuta",
    "avskjutnas": "avskjuta",
    "avskjutne": "avskjuta",
    "avskjutnes": "avskjuta",
    "avskjutningar": "avskjutning",
    "avskjutningarna": "avskjutning",
    "avskjutningarnas": "avskjutning",
    "avskjutningars": "avskjutning",
    "avskjutningen": "avskjutning",
    "avskjutningens": "avskjutning",
    "avskjutnings": "avskjutning",
    "avskjuts": "avskjuta",
    "avskogningen": "avskogning",
    "avskogningens": "avskogning",
    "avskognings": "avskogning",
    "avskrapet": "avskrap",
    "avskrapets": "avskrap",
    "avskraps": "avskrap",
    "avskrev": "avskriva",
    "avskrevs": "avskriva",
    "avskriften": "avskrift",
    "avskriftens": "avskrift",
    "avskrifter": "avskrift",
    "avskrifterna": "avskrift",
    "avskrifternas": "avskrift",
    "avskrifters": "avskrift",
    "avskrifts": "avskrift",
    "avskriv": "avskriva",
    "avskrivande": "avskriva",
    "avskrivanden": "avskrivande",
    "avskrivandena": "avskrivande",
    "avskrivandenas": "avskrivande",
    "avskrivandens": "avskrivande",
    "avskrivandes": "avskrivande",
    "avskrivandet": "avskrivande",
    "avskrivandets": "avskrivande",
    "avskrivas": "avskriva",
    "avskrive": "avskriva",
    "avskriven": "avskriva",
    "avskrivens": "avskriva",
    "avskriver": "avskriva",
    "avskrives": "avskriva",
    "avskrivet": "avskriva",
    "avskrivets": "avskriva",
    "avskrivit": "avskriva",
    "avskrivits": "avskriva",
    "avskrivna": "avskriva",
    "avskrivnas": "avskriva",
    "avskrivne": "avskriva",
    "avskrivnes": "avskriva",
    "avskrivningar": "avskrivning",
    "avskrivningarna": "avskrivning",
    "avskrivningarnas": "avskrivning",
    "avskrivningars": "avskrivning",
    "avskrivningen": "avskrivning",
    "avskrivningens": "avskrivning",
    "avskrivnings": "avskrivning",
    "avskrivningsobjekten": "avskrivningsobjekt",
    "avskrivningsobjektens": "avskrivningsobjekt",
    "avskrivningsobjektet": "avskrivningsobjekt",
    "avskrivningsobjektets": "avskrivningsobjekt",
    "avskrivningsobjekts": "avskrivningsobjekt",
    "avskrivs": "avskriva",
    "avskrotar": "avskrot",
    "avskrotarna": "avskrot",
    "avskrotarnas": "avskrot",
    "avskrotars": "avskrot",
    "avskroten": "avskrot",
    "avskrotens": "avskrot",
    "avskrotet": "avskrot",
    "avskrotets": "avskrot",
    "avskrots": "avskrot",
    "avskräck": "avskräcka",
    "avskräckande": "avskräcka",
    "avskräckanden": "avskräckande",
    "avskräckandena": "avskräckande",
    "avskräckandenas": "avskräckande",
    "avskräckandens": "avskräckande",
    "avskräckandes": "avskräckande",
    "avskräckandet": "avskräckande",
    "avskräckandets": "avskräckande",
    "avskräckas": "avskräcka",
    "avskräcker": "avskräcka",
    "avskräckes": "avskräcka",
    "avskräckningar": "avskräckning",
    "avskräckningarna": "avskräckning",
    "avskräckningarnas": "avskräckning",
    "avskräckningars": "avskräckning",
    "avskräckningen": "avskräckning",
    "avskräckningens": "avskräckning",
    "avskräcknings": "avskräckning",
    "avskräckningspolitiken": "avskräckningspolitik",
    "avskräckningspolitikens": "avskräckningspolitik",
    "avskräckningspolitiks": "avskräckningspolitik",
    "avskräcks": "avskräcka",
    "avskräckt": "avskräcka",
    "avskräckta": "avskräcka",
    "avskräcktas": "avskräcka",
    "avskräckte": "avskräcka",
    "avskräcktes": "avskräcka",
    "avskräckts": "avskräcka",
    "avskräd": "avskräda",
    "avskrädande": "avskräda",
    "avskrädanden": "avskrädande",
    "avskrädandena": "avskrädande",
    "avskrädandenas": "avskrädande",
    "avskrädandens": "avskrädande",
    "avskrädandes": "avskrädande",
    "avskrädandet": "avskrädande",
    "avskrädandets": "avskrädande",
    "avskrädas": "avskräda",
    "avskrädd": "avskräda",
    "avskrädda": "avskräda",
    "avskräddas": "avskräda",
    "avskrädde": "avskräda",
    "avskräddes": "avskräda",
    "avskrädds": "avskräda",
    "avskräden": "avskräde",
    "avskrädena": "avskräde",
    "avskrädenas": "avskräde",
    "avskrädens": "avskräde",
    "avskräder": "avskräda",
    "avskrädes": "avskräde",
    "avskrädeshögar": "avskrädeshög",
    "avskrädeshögarna": "avskrädeshög",
    "avskrädeshögarnas": "avskrädeshög",
    "avskrädeshögars": "avskrädeshög",
    "avskrädeshögen": "avskrädeshög",
    "avskrädeshögens": "avskrädeshög",
    "avskrädeshögs": "avskrädeshög",
    "avskrädet": "avskräde",
    "avskrädets": "avskräde",
    "avskräds": "avskräda",
    "avskrätt": "avskräda",
    "avskrätts": "avskräda",
    "avskummet": "avskum",
    "avskummets": "avskum",
    "avskums": "avskum",
    "avskure": "avskära",
    "avskuren": "avskära",
    "avskurens": "avskära",
    "avskures": "avskära",
    "avskuret": "avskära",
    "avskurets": "avskära",
    "avskurit": "avskära",
    "avskurits": "avskära",
    "avskurna": "avskära",
    "avskurnas": "avskära",
    "avskurne": "avskära",
    "avskurnes": "avskära",
    "avskydd": "avsky",
    "avskydda": "avsky",
    "avskyddas": "avsky",
    "avskydde": "avsky",
    "avskyddes": "avsky",
    "avskydds": "avsky",
    "avskyende": "avsky",
    "avskyenden": "avskyende",
    "avskyendena": "avskyende",
    "avskyendenas": "avskyende",
    "avskyendens": "avskyende",
    "avskyendes": "avskyende",
    "avskyendet": "avskyende",
    "avskyendets": "avskyende",
    "avskyn": "avsky",
    "avskyns": "avsky",
    "avskyr": "avsky",
    "avskys": "avsky",
    "avskytt": "avsky",
    "avskytts": "avsky",
    "avskyvärda": "avskyvärd",
    "avskyvärdare": "avskyvärd",
    "avskyvärdares": "avskyvärd",
    "avskyvärdas": "avskyvärd",
    "avskyvärdast": "avskyvärd",
    "avskyvärdaste": "avskyvärd",
    "avskyvärdastes": "avskyvärd",
    "avskyvärdasts": "avskyvärd",
    "avskyvärde": "avskyvärd",
    "avskyvärdes": "avskyvärd",
    "avskyvärdheten": "avskyvärdhet",
    "avskyvärdhetens": "avskyvärdhet",
    "avskyvärdhets": "avskyvärdhet",
    "avskyvärds": "avskyvärd",
    "avskyvärt": "avskyvärd",
    "avskyvärts": "avskyvärd",
    "avskär": "avskära",
    "avskärande": "avskära",
    "avskäranden": "avskärande",
    "avskärandena": "avskärande",
    "avskärandenas": "avskärande",
    "avskärandens": "avskärande",
    "avskärandes": "avskärande",
    "avskärandet": "avskärande",
    "avskärandets": "avskärande",
    "avskäras": "avskära",
    "avskäre": "avskära",
    "avskäres": "avskära",
    "avskärm": "avskärma",
    "avskärmad": "avskärma",
    "avskärmade": "avskärma",
    "avskärmades": "avskärma",
    "avskärmads": "avskärma",
    "avskärmande": "avskärma",
    "avskärmanden": "avskärmande",
    "avskärmandena": "avskärmande",
    "avskärmandenas": "avskärmande",
    "avskärmandens": "avskärmande",
    "avskärmandes": "avskärmande",
    "avskärmandet": "avskärmande",
    "avskärmandets": "avskärmande",
    "avskärmar": "avskärma",
    "avskärmas": "avskärma",
    "avskärmat": "avskärma",
    "avskärmats": "avskärma",
    "avskärningar": "avskärning",
    "avskärningarna": "avskärning",
    "avskärningarnas": "avskärning",
    "avskärningars": "avskärning",
    "avskärningen": "avskärning",
    "avskärningens": "avskärning",
    "avskärnings": "avskärning",
    "avskärs": "avskära",
    "avsköt": "avskjuta",
    "avsköte": "avskjuta",
    "avskötes": "avskjuta",
    "avsköts": "avskjuta",
    "avslagen": "avslag",
    "avslagenheten": "avslagenhet",
    "avslagenhetens": "avslagenhet",
    "avslagenhets": "avslagenhet",
    "avslagens": "avslagen",
    "avslaget": "avslagen",
    "avslagets": "avslagen",
    "avslagit": "avslå",
    "avslagits": "avslå",
    "avslagna": "avslagen",
    "avslagnare": "avslagen",
    "avslagnares": "avslagen",
    "avslagnas": "avslagen",
    "avslagnast": "avslagen",
    "avslagnaste": "avslagen",
    "avslagnastes": "avslagen",
    "avslagnasts": "avslagen",
    "avslagne": "avslagen",
    "avslagnes": "avslagen",
    "avslags": "avslag",
    "avslappnade": "avslappnad",
    "avslappnades": "avslappnad",
    "avslappnads": "avslappnad",
    "avslappnat": "avslappnad",
    "avslappnats": "avslappnad",
    "avslappningar": "avslappning",
    "avslappningarna": "avslappning",
    "avslappningarnas": "avslappning",
    "avslappningars": "avslappning",
    "avslappningen": "avslappning",
    "avslappningens": "avslappning",
    "avslappnings": "avslappning",
    "avslappningsskivan": "avslappningsskiva",
    "avslappningsskivans": "avslappningsskiva",
    "avslappningsskivas": "avslappningsskiva",
    "avslappningsskive": "avslappningsskiva",
    "avslappningsskivor": "avslappningsskiva",
    "avslappningsskivorna": "avslappningsskiva",
    "avslappningsskivornas": "avslappningsskiva",
    "avslappningsskivors": "avslappningsskiva",
    "avslappningsövningar": "avslappningsövning",
    "avslappningsövningarna": "avslappningsövning",
    "avslappningsövningarnas": "avslappningsövning",
    "avslappningsövningars": "avslappningsövning",
    "avslappningsövningen": "avslappningsövning",
    "avslappningsövningens": "avslappningsövning",
    "avslappningsövnings": "avslappningsövning",
    "avslet": "avslita",
    "avslets": "avslita",
    "avslip": "avslipa",
    "avslipad": "avslipa",
    "avslipade": "avslipa",
    "avslipades": "avslipa",
    "avslipads": "avslipa",
    "avslipande": "avslipa",
    "avslipanden": "avslipande",
    "avslipandena": "avslipande",
    "avslipandenas": "avslipande",
    "avslipandens": "avslipande",
    "avslipandes": "avslipande",
    "avslipandet": "avslipande",
    "avslipandets": "avslipande",
    "avslipar": "avslipa",
    "avslipas": "avslipa",
    "avslipat": "avslipa",
    "avslipats": "avslipa",
    "avslit": "avslita",
    "avslitande": "avslita",
    "avslitanden": "avslitande",
    "avslitandena": "avslitande",
    "avslitandenas": "avslitande",
    "avslitandens": "avslitande",
    "avslitandes": "avslitande",
    "avslitandet": "avslitande",
    "avslitandets": "avslitande",
    "avslitas": "avslita",
    "avslite": "avslita",
    "avsliten": "avslita",
    "avslitens": "avslita",
    "avsliter": "avslita",
    "avslites": "avslita",
    "avslitet": "avslita",
    "avslitets": "avslita",
    "avslitit": "avslita",
    "avslitits": "avslita",
    "avslitna": "avslita",
    "avslitnas": "avslita",
    "avslitne": "avslita",
    "avslitnes": "avslita",
    "avslits": "avslita",
    "avslog": "avslå",
    "avsloge": "avslå",
    "avsloges": "avslå",
    "avslogs": "avslå",
    "avslut": "avsluta",
    "avslutad": "avsluta",
    "avslutade": "avsluta",
    "avslutades": "avsluta",
    "avslutads": "avsluta",
    "avslutande": "avsluta",
    "avslutanden": "avslutande",
    "avslutandena": "avslutande",
    "avslutandenas": "avslutande",
    "avslutandens": "avslutande",
    "avslutandes": "avslutande",
    "avslutandet": "avslutande",
    "avslutandets": "avslutande",
    "avslutar": "avsluta",
    "avslutas": "avsluta",
    "avslutat": "avsluta",
    "avslutats": "avsluta",
    "avsluten": "avslut",
    "avslutens": "avslut",
    "avslutet": "avslut",
    "avslutets": "avslut",
    "avslutningar": "avslutning",
    "avslutningarna": "avslutning",
    "avslutningarnas": "avslutning",
    "avslutningars": "avslutning",
    "avslutningen": "avslutning",
    "avslutningens": "avslutning",
    "avslutnings": "avslutning",
    "avslutningsfesten": "avslutningsfest",
    "avslutningsfestens": "avslutningsfest",
    "avslutningsfester": "avslutningsfest",
    "avslutningsfesterna": "avslutningsfest",
    "avslutningsfesternas": "avslutningsfest",
    "avslutningsfesters": "avslutningsfest",
    "avslutningsfests": "avslutningsfest",
    "avsluts": "avslut",
    "avslående": "avslå",
    "avslåenden": "avslående",
    "avslåendena": "avslående",
    "avslåendenas": "avslående",
    "avslåendens": "avslående",
    "avslåendes": "avslående",
    "avslåendet": "avslående",
    "avslåendets": "avslående",
    "avslår": "avslå",
    "avslås": "avslå",
    "avslöjad": "avslöja",
    "avslöjade": "avslöja",
    "avslöjades": "avslöja",
    "avslöjads": "avslöja",
    "avslöjande": "avslöja",
    "avslöjanden": "avslöjande",
    "avslöjandena": "avslöjande",
    "avslöjandenas": "avslöjande",
    "avslöjandens": "avslöjande",
    "avslöjandes": "avslöjande",
    "avslöjandet": "avslöjande",
    "avslöjandets": "avslöjande",
    "avslöjar": "avslöja",
    "avslöjas": "avslöja",
    "avslöjat": "avslöja",
    "avslöjats": "avslöja",
    "avsmak": "avsmaka",
    "avsmakad": "avsmaka",
    "avsmakade": "avsmaka",
    "avsmakades": "avsmaka",
    "avsmakads": "avsmaka",
    "avsmakande": "avsmaka",
    "avsmakanden": "avsmakande",
    "avsmakandena": "avsmakande",
    "avsmakandenas": "avsmakande",
    "avsmakandens": "avsmakande",
    "avsmakandes": "avsmakande",
    "avsmakandet": "avsmakande",
    "avsmakandets": "avsmakande",
    "avsmakar": "avsmaka",
    "avsmakas": "avsmaka",
    "avsmakat": "avsmaka",
    "avsmakats": "avsmaka",
    "avsmaken": "avsmak",
    "avsmakens": "avsmak",
    "avsmaks": "avsmak",
    "avsmaln": "avsmalna",
    "avsmalnad": "avsmalna",
    "avsmalnade": "avsmalna",
    "avsmalnades": "avsmalna",
    "avsmalnads": "avsmalna",
    "avsmalnande": "avsmalna",
    "avsmalnanden": "avsmalnande",
    "avsmalnandena": "avsmalnande",
    "avsmalnandenas": "avsmalnande",
    "avsmalnandens": "avsmalnande",
    "avsmalnandes": "avsmalnande",
    "avsmalnandet": "avsmalnande",
    "avsmalnandets": "avsmalnande",
    "avsmalnar": "avsmalna",
    "avsmalnas": "avsmalna",
    "avsmalnat": "avsmalna",
    "avsmalnats": "avsmalna",
    "avsmältningar": "avsmältning",
    "avsmältningarna": "avsmältning",
    "avsmältningarnas": "avsmältning",
    "avsmältningars": "avsmältning",
    "avsmältningen": "avsmältning",
    "avsmältningens": "avsmältning",
    "avsmältnings": "avsmältning",
    "avsnitten": "avsnitt",
    "avsnittens": "avsnitt",
    "avsnittet": "avsnitt",
    "avsnittets": "avsnitt",
    "avsnitts": "avsnitt",
    "avsnopp": "avsnoppa",
    "avsnoppad": "avsnoppa",
    "avsnoppade": "avsnoppad",
    "avsnoppades": "avsnoppad",
    "avsnoppads": "avsnoppad",
    "avsnoppande": "avsnoppa",
    "avsnoppanden": "avsnoppande",
    "avsnoppandena": "avsnoppande",
    "avsnoppandenas": "avsnoppande",
    "avsnoppandens": "avsnoppande",
    "avsnoppandes": "avsnoppande",
    "avsnoppandet": "avsnoppande",
    "avsnoppandets": "avsnoppande",
    "avsnoppar": "avsnoppa",
    "avsnoppas": "avsnoppa",
    "avsnoppat": "avsnoppad",
    "avsnoppats": "avsnoppad",
    "avsnör": "avsnöra",
    "avsnörande": "avsnöra",
    "avsnöranden": "avsnörande",
    "avsnörandena": "avsnörande",
    "avsnörandenas": "avsnörande",
    "avsnörandens": "avsnörande",
    "avsnörandes": "avsnörande",
    "avsnörandet": "avsnörande",
    "avsnörandets": "avsnörande",
    "avsnöras": "avsnöra",
    "avsnörd": "avsnöra",
    "avsnörda": "avsnöra",
    "avsnördas": "avsnöra",
    "avsnörde": "avsnöra",
    "avsnördes": "avsnöra",
    "avsnörds": "avsnöra",
    "avsnöres": "avsnöra",
    "avsnörningar": "avsnörning",
    "avsnörningarna": "avsnörning",
    "avsnörningarnas": "avsnörning",
    "avsnörningars": "avsnörning",
    "avsnörningen": "avsnörning",
    "avsnörningens": "avsnörning",
    "avsnörnings": "avsnörning",
    "avsnörningsteorien": "avsnörningsteori",
    "avsnörningsteoriens": "avsnörningsteori",
    "avsnörningsteorier": "avsnörningsteori",
    "avsnörningsteorierna": "avsnörningsteori",
    "avsnörningsteoriernas": "avsnörningsteori",
    "avsnörningsteoriers": "avsnörningsteori",
    "avsnörningsteorin": "avsnörningsteori",
    "avsnörningsteorins": "avsnörningsteori",
    "avsnörningsteoris": "avsnörningsteori",
    "avsnörs": "avsnöra",
    "avsnört": "avsnöra",
    "avsnörts": "avsnöra",
    "avsocialiserad": "avsocialisera",
    "avsocialiserade": "avsocialisera",
    "avsocialiserades": "avsocialisera",
    "avsocialiserads": "avsocialisera",
    "avsocialiserande": "avsocialisera",
    "avsocialiseranden": "avsocialiserande",
    "avsocialiserandena": "avsocialiserande",
    "avsocialiserandenas": "avsocialiserande",
    "avsocialiserandens": "avsocialiserande",
    "avsocialiserandes": "avsocialiserande",
    "avsocialiserandet": "avsocialiserande",
    "avsocialiserandets": "avsocialiserande",
    "avsocialiserar": "avsocialisera",
    "avsocialiseras": "avsocialisera",
    "avsocialiserat": "avsocialisera",
    "avsocialiserats": "avsocialisera",
    "avsocialiserbara": "avsocialiserbar",
    "avsocialiserbarare": "avsocialiserbar",
    "avsocialiserbarares": "avsocialiserbar",
    "avsocialiserbaras": "avsocialiserbar",
    "avsocialiserbarast": "avsocialiserbar",
    "avsocialiserbaraste": "avsocialiserbar",
    "avsocialiserbarastes": "avsocialiserbar",
    "avsocialiserbarasts": "avsocialiserbar",
    "avsocialiserbare": "avsocialiserbar",
    "avsocialiserbares": "avsocialiserbar",
    "avsocialiserbarheten": "avsocialiserbarhet",
    "avsocialiserbarhetens": "avsocialiserbarhet",
    "avsocialiserbarhets": "avsocialiserbarhet",
    "avsocialiserbars": "avsocialiserbar",
    "avsocialiserbart": "avsocialiserbar",
    "avsocialiserbarts": "avsocialiserbar",
    "avsocialiseringar": "avsocialisering",
    "avsocialiseringarna": "avsocialisering",
    "avsocialiseringarnas": "avsocialisering",
    "avsocialiseringars": "avsocialisering",
    "avsocialiseringen": "avsocialisering",
    "avsocialiseringens": "avsocialisering",
    "avsocialiserings": "avsocialisering",
    "avsomn": "avsomna",
    "avsomnad": "avsomna",
    "avsomnade": "avsomna",
    "avsomnades": "avsomna",
    "avsomnads": "avsomna",
    "avsomnande": "avsomna",
    "avsomnanden": "avsomnande",
    "avsomnandena": "avsomnande",
    "avsomnandenas": "avsomnande",
    "avsomnandens": "avsomnande",
    "avsomnandes": "avsomnande",
    "avsomnandet": "avsomnande",
    "avsomnandets": "avsomnande",
    "avsomnar": "avsomna",
    "avsomnas": "avsomna",
    "avsomnat": "avsomna",
    "avsomnats": "avsomna",
    "avsparkar": "avspark",
    "avsparkarna": "avspark",
    "avsparkarnas": "avspark",
    "avsparkars": "avspark",
    "avsparken": "avspark",
    "avsparkens": "avspark",
    "avsparks": "avspark",
    "avspeglad": "avspegla",
    "avspeglade": "avspegla",
    "avspeglades": "avspegla",
    "avspeglads": "avspegla",
    "avspeglande": "avspegla",
    "avspeglanden": "avspeglande",
    "avspeglandena": "avspeglande",
    "avspeglandenas": "avspeglande",
    "avspeglandens": "avspeglande",
    "avspeglandes": "avspeglande",
    "avspeglandet": "avspeglande",
    "avspeglandets": "avspeglande",
    "avspeglar": "avspegla",
    "avspeglas": "avspegla",
    "avspeglat": "avspegla",
    "avspeglats": "avspegla",
    "avspeglingar": "avspegling",
    "avspeglingarna": "avspegling",
    "avspeglingarnas": "avspegling",
    "avspeglingars": "avspegling",
    "avspeglingen": "avspegling",
    "avspeglingens": "avspegling",
    "avspeglings": "avspegling",
    "avspelad": "avspela",
    "avspelade": "avspela",
    "avspelades": "avspela",
    "avspelads": "avspela",
    "avspelande": "avspela",
    "avspelanden": "avspelande",
    "avspelandena": "avspelande",
    "avspelandenas": "avspelande",
    "avspelandens": "avspelande",
    "avspelandes": "avspelande",
    "avspelandet": "avspelande",
    "avspelandets": "avspelande",
    "avspelar": "avspela",
    "avspelas": "avspela",
    "avspelat": "avspela",
    "avspelats": "avspela",
    "avspelningar": "avspelning",
    "avspelningarna": "avspelning",
    "avspelningarnas": "avspelning",
    "avspelningars": "avspelning",
    "avspelningen": "avspelning",
    "avspelningens": "avspelning",
    "avspelnings": "avspelning",
    "avspis": "avspisa",
    "avspisad": "avspisa",
    "avspisade": "avspisa",
    "avspisades": "avspisa",
    "avspisads": "avspisa",
    "avspisande": "avspisa",
    "avspisanden": "avspisande",
    "avspisandena": "avspisande",
    "avspisandenas": "avspisande",
    "avspisandens": "avspisande",
    "avspisandes": "avspisande",
    "avspisandet": "avspisande",
    "avspisandets": "avspisande",
    "avspisar": "avspisa",
    "avspisas": "avspisa",
    "avspisat": "avspisa",
    "avspisats": "avspisa",
    "avsprången": "avsprång",
    "avsprångens": "avsprång",
    "avsprånget": "avsprång",
    "avsprångets": "avsprång",
    "avsprångs": "avsprång",
    "avspända": "avspänd",
    "avspändare": "avspänd",
    "avspändares": "avspänd",
    "avspändas": "avspänd",
    "avspändast": "avspänd",
    "avspändaste": "avspänd",
    "avspändastes": "avspänd",
    "avspändasts": "avspänd",
    "avspände": "avspänd",
    "avspändes": "avspänd",
    "avspändheten": "avspändhet",
    "avspändhetens": "avspändhet",
    "avspändhets": "avspändhet",
    "avspänds": "avspänd",
    "avspänningar": "avspänning",
    "avspänningarna": "avspänning",
    "avspänningarnas": "avspänning",
    "avspänningars": "avspänning",
    "avspänningen": "avspänning",
    "avspänningens": "avspänning",
    "avspännings": "avspänning",
    "avspänningspedagogen": "avspänningspedagog",
    "avspänningspedagogens": "avspänningspedagog",
    "avspänningspedagoger": "avspänningspedagog",
    "avspänningspedagogerna": "avspänningspedagog",
    "avspänningspedagogernas": "avspänningspedagog",
    "avspänningspedagogers": "avspänningspedagog",
    "avspänningspedagogs": "avspänningspedagog",
    "avspänt": "avspänd",
    "avspänts": "avspänd",
    "avspärr": "avspärra",
    "avspärrad": "avspärra",
    "avspärrade": "avspärra",
    "avspärrades": "avspärra",
    "avspärrads": "avspärra",
    "avspärrande": "avspärra",
    "avspärranden": "avspärrande",
    "avspärrandena": "avspärrande",
    "avspärrandenas": "avspärrande",
    "avspärrandens": "avspärrande",
    "avspärrandes": "avspärrande",
    "avspärrandet": "avspärrande",
    "avspärrandets": "avspärrande",
    "avspärrar": "avspärra",
    "avspärras": "avspärra",
    "avspärrat": "avspärra",
    "avspärrats": "avspärra",
    "avspärrningar": "avspärrning",
    "avspärrningarna": "avspärrning",
    "avspärrningarnas": "avspärrning",
    "avspärrningars": "avspärrning",
    "avspärrningen": "avspärrning",
    "avspärrningens": "avspärrning",
    "avspärrnings": "avspärrning",
    "avstaliniserad": "avstalinisera",
    "avstaliniserade": "avstalinisera",
    "avstaliniserades": "avstalinisera",
    "avstaliniserads": "avstalinisera",
    "avstaliniserande": "avstalinisera",
    "avstaliniseranden": "avstaliniserande",
    "avstaliniserandena": "avstaliniserande",
    "avstaliniserandenas": "avstaliniserande",
    "avstaliniserandens": "avstaliniserande",
    "avstaliniserandes": "avstaliniserande",
    "avstaliniserandet": "avstaliniserande",
    "avstaliniserandets": "avstaliniserande",
    "avstaliniserar": "avstalinisera",
    "avstaliniseras": "avstalinisera",
    "avstaliniserat": "avstalinisera",
    "avstaliniserats": "avstalinisera",
    "avstaliniserbara": "avstaliniserbar",
    "avstaliniserbarare": "avstaliniserbar",
    "avstaliniserbarares": "avstaliniserbar",
    "avstaliniserbaras": "avstaliniserbar",
    "avstaliniserbarast": "avstaliniserbar",
    "avstaliniserbaraste": "avstaliniserbar",
    "avstaliniserbarastes": "avstaliniserbar",
    "avstaliniserbarasts": "avstaliniserbar",
    "avstaliniserbare": "avstaliniserbar",
    "avstaliniserbares": "avstaliniserbar",
    "avstaliniserbarheten": "avstaliniserbarhet",
    "avstaliniserbarhetens": "avstaliniserbarhet",
    "avstaliniserbarhets": "avstaliniserbarhet",
    "avstaliniserbars": "avstaliniserbar",
    "avstaliniserbart": "avstaliniserbar",
    "avstaliniserbarts": "avstaliniserbar",
    "avstaliniseringar": "avstalinisering",
    "avstaliniseringarna": "avstalinisering",
    "avstaliniseringarnas": "avstalinisering",
    "avstaliniseringars": "avstalinisering",
    "avstaliniseringen": "avstalinisering",
    "avstaliniseringens": "avstalinisering",
    "avstaliniserings": "avstalinisering",
    "avstampen": "avstamp",
    "avstampens": "avstamp",
    "avstampet": "avstamp",
    "avstampets": "avstamp",
    "avstamps": "avstamp",
    "avstann": "avstanna",
    "avstannad": "avstanna",
    "avstannade": "avstanna",
    "avstannades": "avstanna",
    "avstannads": "avstanna",
    "avstannande": "avstanna",
    "avstannanden": "avstannande",
    "avstannandena": "avstannande",
    "avstannandenas": "avstannande",
    "avstannandens": "avstannande",
    "avstannandes": "avstannande",
    "avstannandet": "avstannande",
    "avstannandets": "avstannande",
    "avstannar": "avstanna",
    "avstannas": "avstanna",
    "avstannat": "avstanna",
    "avstannats": "avstanna",
    "avstav": "avstava",
    "avstavad": "avstava",
    "avstavade": "avstava",
    "avstavades": "avstava",
    "avstavads": "avstava",
    "avstavande": "avstava",
    "avstavanden": "avstavande",
    "avstavandena": "avstavande",
    "avstavandenas": "avstavande",
    "avstavandens": "avstavande",
    "avstavandes": "avstavande",
    "avstavandet": "avstavande",
    "avstavandets": "avstavande",
    "avstavar": "avstava",
    "avstavas": "avstava",
    "avstavat": "avstava",
    "avstavats": "avstava",
    "avstavningar": "avstavning",
    "avstavningarna": "avstavning",
    "avstavningarnas": "avstavning",
    "avstavningars": "avstavning",
    "avstavningen": "avstavning",
    "avstavningens": "avstavning",
    "avstavnings": "avstavning",
    "avstegen": "avsteg",
    "avstegens": "avsteg",
    "avsteget": "avsteg",
    "avstegets": "avsteg",
    "avstegs": "avsteg",
    "avstickar": "avstickare",
    "avstickaren": "avstickare",
    "avstickarens": "avstickare",
    "avstickares": "avstickare",
    "avstickarna": "avstickare",
    "avstickarnas": "avstickare",
    "avstickningar": "avstickning",
    "avstickningarna": "avstickning",
    "avstickningarnas": "avstickning",
    "avstickningars": "avstickning",
    "avstickningen": "avstickning",
    "avstickningens": "avstickning",
    "avsticknings": "avstickning",
    "avstigningar": "avstigning",
    "avstigningarna": "avstigning",
    "avstigningarnas": "avstigning",
    "avstigningars": "avstigning",
    "avstigningen": "avstigning",
    "avstigningens": "avstigning",
    "avstignings": "avstigning",
    "avstjälpningar": "avstjälpning",
    "avstjälpningarna": "avstjälpning",
    "avstjälpningarnas": "avstjälpning",
    "avstjälpningars": "avstjälpning",
    "avstjälpningen": "avstjälpning",
    "avstjälpningens": "avstjälpning",
    "avstjälpnings": "avstjälpning",
    "avstjälpningscentralen": "avstjälpningscentral",
    "avstjälpningscentralens": "avstjälpningscentral",
    "avstjälpningscentraler": "avstjälpningscentral",
    "avstjälpningscentralerna": "avstjälpningscentral",
    "avstjälpningscentralernas": "avstjälpningscentral",
    "avstjälpningscentralers": "avstjälpningscentral",
    "avstjälpningscentrals": "avstjälpningscentral",
    "avstjälpningsplatsen": "avstjälpningsplats",
    "avstjälpningsplatsens": "avstjälpningsplats",
    "avstjälpningsplatser": "avstjälpningsplats",
    "avstjälpningsplatserna": "avstjälpningsplats",
    "avstjälpningsplatsernas": "avstjälpningsplats",
    "avstjälpningsplatsers": "avstjälpningsplats",
    "avstod": "avstå",
    "avstode": "avstå",
    "avstodes": "avstå",
    "avstods": "avstå",
    "avstress": "avstressa",
    "avstressad": "avstressa",
    "avstressade": "avstressad",
    "avstressades": "avstressad",
    "avstressads": "avstressad",
    "avstressande": "avstressa",
    "avstressanden": "avstressande",
    "avstressandena": "avstressande",
    "avstressandenas": "avstressande",
    "avstressandens": "avstressande",
    "avstressandes": "avstressande",
    "avstressandet": "avstressande",
    "avstressandets": "avstressande",
    "avstressar": "avstressa",
    "avstressas": "avstressa",
    "avstressat": "avstressad",
    "avstressats": "avstressad",
    "avstyck": "avstycka",
    "avstyckad": "avstycka",
    "avstyckade": "avstycka",
    "avstyckades": "avstycka",
    "avstyckads": "avstycka",
    "avstyckande": "avstycka",
    "avstyckanden": "avstyckande",
    "avstyckandena": "avstyckande",
    "avstyckandenas": "avstyckande",
    "avstyckandens": "avstyckande",
    "avstyckandes": "avstyckande",
    "avstyckandet": "avstyckande",
    "avstyckandets": "avstyckande",
    "avstyckar": "avstycka",
    "avstyckas": "avstycka",
    "avstyckat": "avstycka",
    "avstyckats": "avstycka",
    "avstyr": "avstyra",
    "avstyrande": "avstyra",
    "avstyranden": "avstyrande",
    "avstyrandena": "avstyrande",
    "avstyrandenas": "avstyrande",
    "avstyrandens": "avstyrande",
    "avstyrandes": "avstyrande",
    "avstyrandet": "avstyrande",
    "avstyrandets": "avstyrande",
    "avstyras": "avstyra",
    "avstyrd": "avstyra",
    "avstyrda": "avstyra",
    "avstyrdas": "avstyra",
    "avstyrde": "avstyra",
    "avstyrdes": "avstyra",
    "avstyrds": "avstyra",
    "avstyres": "avstyra",
    "avstyrk": "avstyrka",
    "avstyrkande": "avstyrka",
    "avstyrkanden": "avstyrkande",
    "avstyrkandena": "avstyrkande",
    "avstyrkandenas": "avstyrkande",
    "avstyrkandens": "avstyrkande",
    "avstyrkandes": "avstyrkande",
    "avstyrkandet": "avstyrkande",
    "avstyrkandets": "avstyrkande",
    "avstyrkas": "avstyrka",
    "avstyrker": "avstyrka",
    "avstyrkes": "avstyrka",
    "avstyrks": "avstyrka",
    "avstyrkt": "avstyrka",
    "avstyrkta": "avstyrka",
    "avstyrktas": "avstyrka",
    "avstyrkte": "avstyrka",
    "avstyrktes": "avstyrka",
    "avstyrkts": "avstyrka",
    "avstyrs": "avstyra",
    "avstyrt": "avstyra",
    "avstyrts": "avstyra",
    "avställ": "avställa",
    "avställande": "avställa",
    "avställanden": "avställande",
    "avställandena": "avställande",
    "avställandenas": "avställande",
    "avställandens": "avställande",
    "avställandes": "avställande",
    "avställandet": "avställande",
    "avställandets": "avställande",
    "avställas": "avställa",
    "avställd": "avställa",
    "avställda": "avställa",
    "avställdas": "avställa",
    "avställde": "avställa",
    "avställdes": "avställa",
    "avställds": "avställa",
    "avställer": "avställa",
    "avställes": "avställa",
    "avställningar": "avställning",
    "avställningarna": "avställning",
    "avställningarnas": "avställning",
    "avställningars": "avställning",
    "avställningen": "avställning",
    "avställningens": "avställning",
    "avställnings": "avställning",
    "avställningsytan": "avställningsyta",
    "avställningsytans": "avställningsyta",
    "avställningsytas": "avställningsyta",
    "avställningsyte": "avställningsyta",
    "avställningsytor": "avställningsyta",
    "avställningsytorna": "avställningsyta",
    "avställningsytornas": "avställningsyta",
    "avställningsytors": "avställningsyta",
    "avställs": "avställa",
    "avställt": "avställa",
    "avställts": "avställa",
    "avstäm": "avstämma",
    "avstämd": "avstämma",
    "avstämda": "avstämma",
    "avstämdas": "avstämma",
    "avstämde": "avstämma",
    "avstämdes": "avstämma",
    "avstämds": "avstämma",
    "avstämmande": "avstämma",
    "avstämmanden": "avstämmande",
    "avstämmandena": "avstämmande",
    "avstämmandenas": "avstämmande",
    "avstämmandens": "avstämmande",
    "avstämmandes": "avstämmande",
    "avstämmandet": "avstämmande",
    "avstämmandets": "avstämmande",
    "avstämmas": "avstämma",
    "avstämmer": "avstämma",
    "avstämplingar": "avstämpling",
    "avstämplingarna": "avstämpling",
    "avstämplingarnas": "avstämpling",
    "avstämplingars": "avstämpling",
    "avstämplingen": "avstämpling",
    "avstämplingens": "avstämpling",
    "avstämplings": "avstämpling",
    "avstäms": "avstämma",
    "avstämt": "avstämma",
    "avstämts": "avstämma",
    "avstäng": "avstänga",
    "avstängande": "avstänga",
    "avstänganden": "avstängande",
    "avstängandena": "avstängande",
    "avstängandenas": "avstängande",
    "avstängandens": "avstängande",
    "avstängandes": "avstängande",
    "avstängandet": "avstängande",
    "avstängandets": "avstängande",
    "avstängas": "avstänga",
    "avstängd": "avstänga",
    "avstängda": "avstänga",
    "avstängdas": "avstänga",
    "avstängde": "avstänga",
    "avstängdes": "avstänga",
    "avstängds": "avstänga",
    "avstänger": "avstänga",
    "avstänges": "avstänga",
    "avstängningar": "avstängning",
    "avstängningarna": "avstängning",
    "avstängningarnas": "avstängning",
    "avstängningars": "avstängning",
    "avstängningen": "avstängning",
    "avstängningens": "avstängning",
    "avstängnings": "avstängning",
    "avstängs": "avstänga",
    "avstängt": "avstänga",
    "avstängts": "avstänga",
    "avstående": "avstå",
    "avståenden": "avstående",
    "avståendena": "avstående",
    "avståendenas": "avstående",
    "avståendens": "avstående",
    "avståendes": "avstående",
    "avståendet": "avstående",
    "avståendets": "avstående",
    "avstånden": "avstånd",
    "avståndens": "avstånd",
    "avståndet": "avstånd",
    "avståndets": "avstånd",
    "avstånds": "avstånd",
    "avståndsinformationen": "avståndsinformation",
    "avståndsinformationens": "avståndsinformation",
    "avståndsinformationer": "avståndsinformation",
    "avståndsinformationerna": "avståndsinformation",
    "avståndsinformationernas": "avståndsinformation",
    "avståndsinformationers": "avståndsinformation",
    "avståndsinformations": "avståndsinformation",
    "avståndskraften": "avståndskraft",
    "avståndskraftens": "avståndskraft",
    "avståndskrafter": "avståndskraft",
    "avståndskrafterna": "avståndskraft",
    "avståndskrafternas": "avståndskraft",
    "avståndskrafters": "avståndskraft",
    "avståndskrafts": "avståndskraft",
    "avståndsmätar": "avståndsmätare",
    "avståndsmätaren": "avståndsmätare",
    "avståndsmätarens": "avståndsmätare",
    "avståndsmätares": "avståndsmätare",
    "avståndsmätarna": "avståndsmätare",
    "avståndsmätarnas": "avståndsmätare",
    "avståndsmätningar": "avståndsmätning",
    "avståndsmätningarna": "avståndsmätning",
    "avståndsmätningarnas": "avståndsmätning",
    "avståndsmätningars": "avståndsmätning",
    "avståndsmätningen": "avståndsmätning",
    "avståndsmätningens": "avståndsmätning",
    "avståndsmätnings": "avståndsmätning",
    "avståndstaganden": "avståndstagande",
    "avståndstagandena": "avståndstagande",
    "avståndstagandenas": "avståndstagande",
    "avståndstagandens": "avståndstagande",
    "avståndstagandes": "avståndstagande",
    "avståndstagandet": "avståndstagande",
    "avståndstagandets": "avståndstagande",
    "avståndsverkans": "avståndsverkan",
    "avstår": "avstå",
    "avstås": "avstå",
    "avstått": "avstå",
    "avståtts": "avstå",
    "avstör": "avstöra",
    "avstörande": "avstöra",
    "avstöranden": "avstörande",
    "avstörandena": "avstörande",
    "avstörandenas": "avstörande",
    "avstörandens": "avstörande",
    "avstörandes": "avstörande",
    "avstörandet": "avstörande",
    "avstörandets": "avstörande",
    "avstöras": "avstöra",
    "avstörd": "avstöra",
    "avstörda": "avstöra",
    "avstördas": "avstöra",
    "avstörde": "avstöra",
    "avstördes": "avstöra",
    "avstörds": "avstöra",
    "avstöres": "avstöra",
    "avstörs": "avstöra",
    "avstört": "avstöra",
    "avstörts": "avstöra",
    "avstöt": "avstöta",
    "avstötande": "avstöta",
    "avstötanden": "avstötande",
    "avstötandena": "avstötande",
    "avstötandenas": "avstötande",
    "avstötandens": "avstötande",
    "avstötandes": "avstötande",
    "avstötandet": "avstötande",
    "avstötandets": "avstötande",
    "avstötas": "avstöta",
    "avstöter": "avstöta",
    "avstötes": "avstöta",
    "avstöts": "avstöta",
    "avstött": "avstöta",
    "avstötta": "avstöta",
    "avstöttas": "avstöta",
    "avstötte": "avstöta",
    "avstöttes": "avstöta",
    "avstötts": "avstöta",
    "avsugningar": "avsugning",
    "avsugningarna": "avsugning",
    "avsugningarnas": "avsugning",
    "avsugningars": "avsugning",
    "avsugningen": "avsugning",
    "avsugningens": "avsugning",
    "avsugnings": "avsugning",
    "avsvalkningar": "avsvalkning",
    "avsvalkningarna": "avsvalkning",
    "avsvalkningarnas": "avsvalkning",
    "avsvalkningars": "avsvalkning",
    "avsvalkningen": "avsvalkning",
    "avsvalkningens": "avsvalkning",
    "avsvalknings": "avsvalkning",
    "avsvaln": "avsvalna",
    "avsvalnad": "avsvalna",
    "avsvalnade": "avsvalna",
    "avsvalnades": "avsvalna",
    "avsvalnads": "avsvalna",
    "avsvalnande": "avsvalna",
    "avsvalnanden": "avsvalnande",
    "avsvalnandena": "avsvalnande",
    "avsvalnandenas": "avsvalnande",
    "avsvalnandens": "avsvalnande",
    "avsvalnandes": "avsvalnande",
    "avsvalnandet": "avsvalnande",
    "avsvalnandets": "avsvalnande",
    "avsvalnar": "avsvalna",
    "avsvalnas": "avsvalna",
    "avsvalnat": "avsvalna",
    "avsvalnats": "avsvalna",
    "avsvavlad": "avsvavla",
    "avsvavlade": "avsvavla",
    "avsvavlades": "avsvavla",
    "avsvavlads": "avsvavla",
    "avsvavlande": "avsvavla",
    "avsvavlanden": "avsvavlande",
    "avsvavlandena": "avsvavlande",
    "avsvavlandenas": "avsvavlande",
    "avsvavlandens": "avsvavlande",
    "avsvavlandes": "avsvavlande",
    "avsvavlandet": "avsvavlande",
    "avsvavlandets": "avsvavlande",
    "avsvavlar": "avsvavla",
    "avsvavlas": "avsvavla",
    "avsvavlat": "avsvavla",
    "avsvavlats": "avsvavla",
    "avsvim": "avsvimma",
    "avsvimmade": "avsvimma",
    "avsvimmades": "avsvimma",
    "avsvimmande": "avsvimma",
    "avsvimmanden": "avsvimmande",
    "avsvimmandena": "avsvimmande",
    "avsvimmandenas": "avsvimmande",
    "avsvimmandens": "avsvimmande",
    "avsvimmandes": "avsvimmande",
    "avsvimmandet": "avsvimmande",
    "avsvimmandets": "avsvimmande",
    "avsvimmar": "avsvimma",
    "avsvimmas": "avsvimma",
    "avsvimmat": "avsvimma",
    "avsvimmats": "avsvimma",
    "avsvor": "avsvärja",
    "avsvors": "avsvärja",
    "avsvure": "avsvärja",
    "avsvuren": "avsvärja",
    "avsvurens": "avsvärja",
    "avsvures": "avsvärja",
    "avsvuret": "avsvärja",
    "avsvurets": "avsvärja",
    "avsvurit": "avsvärja",
    "avsvurits": "avsvärja",
    "avsvurna": "avsvärja",
    "avsvurnas": "avsvärja",
    "avsvurne": "avsvärja",
    "avsvurnes": "avsvärja",
    "avsvär": "avsvärja",
    "avsvära": "avsvärja",
    "avsvärande": "avsvärja",
    "avsvärandes": "avsvärja",
    "avsväras": "avsvärja",
    "avsvärj": "avsvärja",
    "avsvärjande": "avsvärja",
    "avsvärjanden": "avsvärjande",
    "avsvärjandena": "avsvärjande",
    "avsvärjandenas": "avsvärjande",
    "avsvärjandens": "avsvärjande",
    "avsvärjandes": "avsvärjande",
    "avsvärjandet": "avsvärjande",
    "avsvärjandets": "avsvärjande",
    "avsvärjas": "avsvärja",
    "avsvärjd": "avsvärja",
    "avsvärjda": "avsvärja",
    "avsvärjdas": "avsvärja",
    "avsvärjde": "avsvärja",
    "avsvärjdes": "avsvärja",
    "avsvärjds": "avsvärja",
    "avsvärje": "avsvärja",
    "avsvärjer": "avsvärja",
    "avsvärjes": "avsvärja",
    "avsvärjs": "avsvärja",
    "avsvärjt": "avsvärja",
    "avsvärjts": "avsvärja",
    "avsyn": "avsyna",
    "avsynad": "avsyna",
    "avsynade": "avsyna",
    "avsynades": "avsyna",
    "avsynads": "avsyna",
    "avsynande": "avsyna",
    "avsynanden": "avsynande",
    "avsynandena": "avsynande",
    "avsynandenas": "avsynande",
    "avsynandens": "avsynande",
    "avsynandes": "avsynande",
    "avsynandet": "avsynande",
    "avsynandets": "avsynande",
    "avsynar": "avsynare",
    "avsynaren": "avsynare",
    "avsynarens": "avsynare",
    "avsynares": "avsynare",
    "avsynarna": "avsynare",
    "avsynarnas": "avsynare",
    "avsynas": "avsyna",
    "avsynat": "avsyna",
    "avsynats": "avsyna",
    "avsäg": "avsäga",
    "avsägande": "avsäga",
    "avsäganden": "avsägande",
    "avsägandena": "avsägande",
    "avsägandenas": "avsägande",
    "avsägandens": "avsägande",
    "avsägandes": "avsägande",
    "avsägandet": "avsägande",
    "avsägandets": "avsägande",
    "avsägas": "avsäga",
    "avsägelsen": "avsägelse",
    "avsägelsens": "avsägelse",
    "avsägelser": "avsägelse",
    "avsägelserna": "avsägelse",
    "avsägelsernas": "avsägelse",
    "avsägelsers": "avsägelse",
    "avsägelses": "avsägelse",
    "avsäger": "avsäga",
    "avsäges": "avsäga",
    "avsägs": "avsäga",
    "avsäj": "avsäga",
    "avsäja": "avsäga",
    "avsäjande": "avsäga",
    "avsäjandes": "avsäga",
    "avsäjas": "avsäga",
    "avsäjer": "avsäga",
    "avsäjes": "avsäga",
    "avsäjs": "avsäga",
    "avsänd": "avsända",
    "avsändande": "avsända",
    "avsändanden": "avsändande",
    "avsändandena": "avsändande",
    "avsändandenas": "avsändande",
    "avsändandens": "avsändande",
    "avsändandes": "avsändande",
    "avsändandet": "avsändande",
    "avsändandets": "avsändande",
    "avsändar": "avsändare",
    "avsändaren": "avsändare",
    "avsändarens": "avsändare",
    "avsändares": "avsändare",
    "avsändarna": "avsändare",
    "avsändarnas": "avsändare",
    "avsändas": "avsända",
    "avsände": "avsända",
    "avsänder": "avsända",
    "avsändes": "avsända",
    "avsänds": "avsända",
    "avsänt": "avsända",
    "avsänts": "avsända",
    "avsätt": "avsätta",
    "avsättande": "avsätta",
    "avsättanden": "avsättande",
    "avsättandena": "avsättande",
    "avsättandenas": "avsättande",
    "avsättandens": "avsättande",
    "avsättandes": "avsättande",
    "avsättandet": "avsättande",
    "avsättandets": "avsättande",
    "avsättas": "avsätta",
    "avsätter": "avsätta",
    "avsättes": "avsätta",
    "avsättliga": "avsättlig",
    "avsättligare": "avsättlig",
    "avsättligares": "avsättlig",
    "avsättligas": "avsättlig",
    "avsättligast": "avsättlig",
    "avsättligaste": "avsättlig",
    "avsättligastes": "avsättlig",
    "avsättligasts": "avsättlig",
    "avsättlige": "avsättlig",
    "avsättliges": "avsättlig",
    "avsättligheten": "avsättlighet",
    "avsättlighetens": "avsättlighet",
    "avsättlighets": "avsättlighet",
    "avsättligs": "avsättlig",
    "avsättligt": "avsättlig",
    "avsättligts": "avsättlig",
    "avsättningar": "avsättning",
    "avsättningarna": "avsättning",
    "avsättningarnas": "avsättning",
    "avsättningars": "avsättning",
    "avsättningen": "avsättning",
    "avsättningens": "avsättning",
    "avsättnings": "avsättning",
    "avsättningsbassängen": "avsättningsbassäng",
    "avsättningsbassängens": "avsättningsbassäng",
    "avsättningsbassänger": "avsättningsbassäng",
    "avsättningsbassängerna": "avsättningsbassäng",
    "avsättningsbassängernas": "avsättningsbassäng",
    "avsättningsbassängers": "avsättningsbassäng",
    "avsättningsbassängs": "avsättningsbassäng",
    "avsätts": "avsätta",
    "avsåg": "avse",
    "avsågad": "avsåga",
    "avsågade": "avsåga",
    "avsågades": "avsåga",
    "avsågads": "avsåga",
    "avsågande": "avsåga",
    "avsåganden": "avsågande",
    "avsågandena": "avsågande",
    "avsågandenas": "avsågande",
    "avsågandens": "avsågande",
    "avsågandes": "avsågande",
    "avsågandet": "avsågande",
    "avsågandets": "avsågande",
    "avsågar": "avsåga",
    "avsågas": "avsåga",
    "avsågat": "avsåga",
    "avsågats": "avsåga",
    "avsåge": "avse",
    "avsåges": "avse",
    "avsågs": "avse",
    "avsök": "avsöka",
    "avsökande": "avsöka",
    "avsökanden": "avsökande",
    "avsökandena": "avsökande",
    "avsökandenas": "avsökande",
    "avsökandens": "avsökande",
    "avsökandes": "avsökande",
    "avsökandet": "avsökande",
    "avsökandets": "avsökande",
    "avsökar": "avsökare",
    "avsökaren": "avsökare",
    "avsökarens": "avsökare",
    "avsökares": "avsökare",
    "avsökarna": "avsökare",
    "avsökarnas": "avsökare",
    "avsökas": "avsöka",
    "avsöker": "avsöka",
    "avsökes": "avsöka",
    "avsöks": "avsöka",
    "avsökt": "avsöka",
    "avsökta": "avsöka",
    "avsöktas": "avsöka",
    "avsökte": "avsöka",
    "avsöktes": "avsöka",
    "avsökts": "avsöka",
    "avsöndrad": "avsöndra",
    "avsöndrade": "avsöndra",
    "avsöndrades": "avsöndra",
    "avsöndrads": "avsöndra",
    "avsöndrande": "avsöndra",
    "avsöndranden": "avsöndrande",
    "avsöndrandena": "avsöndrande",
    "avsöndrandenas": "avsöndrande",
    "avsöndrandens": "avsöndrande",
    "avsöndrandes": "avsöndrande",
    "avsöndrandet": "avsöndrande",
    "avsöndrandets": "avsöndrande",
    "avsöndrar": "avsöndra",
    "avsöndras": "avsöndra",
    "avsöndrat": "avsöndra",
    "avsöndrats": "avsöndra",
    "avsöndringar": "avsöndring",
    "avsöndringarna": "avsöndring",
    "avsöndringarnas": "avsöndring",
    "avsöndringars": "avsöndring",
    "avsöndringen": "avsöndring",
    "avsöndringens": "avsöndring",
    "avsöndrings": "avsöndring",
    "avtack": "avtacka",
    "avtackad": "avtacka",
    "avtackade": "avtacka",
    "avtackades": "avtacka",
    "avtackads": "avtacka",
    "avtackande": "avtacka",
    "avtackanden": "avtackande",
    "avtackandena": "avtackande",
    "avtackandenas": "avtackande",
    "avtackandens": "avtackande",
    "avtackandes": "avtackande",
    "avtackandet": "avtackande",
    "avtackandets": "avtackande",
    "avtackar": "avtacka",
    "avtackas": "avtacka",
    "avtackat": "avtacka",
    "avtackats": "avtacka",
    "avtacklade": "avtacklad",
    "avtacklades": "avtacklad",
    "avtacklads": "avtacklad",
    "avtacklat": "avtacklad",
    "avtacklats": "avtacklad",
    "avtag": "avta",
    "avtaga": "avta",
    "avtagande": "avta",
    "avtagandes": "avtagande",
    "avtagandet": "avtagande",
    "avtagandets": "avtagande",
    "avtagas": "avta",
    "avtagbara": "avtagbar",
    "avtagbarare": "avtagbar",
    "avtagbarares": "avtagbar",
    "avtagbaras": "avtagbar",
    "avtagbarast": "avtagbar",
    "avtagbaraste": "avtagbar",
    "avtagbarastes": "avtagbar",
    "avtagbarasts": "avtagbar",
    "avtagbare": "avtagbar",
    "avtagbares": "avtagbar",
    "avtagbarheten": "avtagbarhet",
    "avtagbarhetens": "avtagbarhet",
    "avtagbarhets": "avtagbarhet",
    "avtagbars": "avtagbar",
    "avtagbart": "avtagbar",
    "avtagbarts": "avtagbar",
    "avtage": "avta",
    "avtagen": "avta",
    "avtagens": "avta",
    "avtager": "avta",
    "avtages": "avta",
    "avtaget": "avta",
    "avtagets": "avta",
    "avtagit": "avta",
    "avtagits": "avta",
    "avtagna": "avta",
    "avtagnas": "avta",
    "avtagne": "avta",
    "avtagnes": "avta",
    "avtagningar": "avtagning",
    "avtagningarna": "avtagning",
    "avtagningarnas": "avtagning",
    "avtagningars": "avtagning",
    "avtagningen": "avtagning",
    "avtagningens": "avtagning",
    "avtagnings": "avtagning",
    "avtags": "avta",
    "avtagsvägar": "avtagsväg",
    "avtagsvägarna": "avtagsväg",
    "avtagsvägarnas": "avtagsväg",
    "avtagsvägars": "avtagsväg",
    "avtagsvägen": "avtagsväg",
    "avtagsvägens": "avtagsväg",
    "avtagsvägs": "avtagsväg",
    "avtalad": "avtala",
    "avtalade": "avtala",
    "avtalades": "avtala",
    "avtalads": "avtala",
    "avtalande": "avtala",
    "avtalanden": "avtalande",
    "avtalandena": "avtalande",
    "avtalandenas": "avtalande",
    "avtalandens": "avtalande",
    "avtalandes": "avtalande",
    "avtalandet": "avtalande",
    "avtalandets": "avtalande",
    "avtalar": "avtala",
    "avtalas": "avtala",
    "avtalat": "avtala",
    "avtalats": "avtala",
    "avtalen": "avtal",
    "avtalens": "avtal",
    "avtalet": "avtal",
    "avtalets": "avtal",
    "avtals": "avtal",
    "avtalsenliga": "avtalsenlig",
    "avtalsenligare": "avtalsenlig",
    "avtalsenligares": "avtalsenlig",
    "avtalsenligas": "avtalsenlig",
    "avtalsenligast": "avtalsenlig",
    "avtalsenligaste": "avtalsenlig",
    "avtalsenligastes": "avtalsenlig",
    "avtalsenligasts": "avtalsenlig",
    "avtalsenlige": "avtalsenlig",
    "avtalsenliges": "avtalsenlig",
    "avtalsenligheten": "avtalsenlighet",
    "avtalsenlighetens": "avtalsenlighet",
    "avtalsenlighets": "avtalsenlighet",
    "avtalsenligs": "avtalsenlig",
    "avtalsenligt": "avtalsenlig",
    "avtalsenligts": "avtalsenlig",
    "avtalsfriheten": "avtalsfrihet",
    "avtalsfrihetens": "avtalsfrihet",
    "avtalsfriheter": "avtalsfrihet",
    "avtalsfriheterna": "avtalsfrihet",
    "avtalsfriheternas": "avtalsfrihet",
    "avtalsfriheters": "avtalsfrihet",
    "avtalsfrihets": "avtalsfrihet",
    "avtalsförhandlingar": "avtalsförhandling",
    "avtalsförhandlingarna": "avtalsförhandling",
    "avtalsförhandlingarnas": "avtalsförhandling",
    "avtalsförhandlingars": "avtalsförhandling",
    "avtalsförhandlingen": "avtalsförhandling",
    "avtalsförhandlingens": "avtalsförhandling",
    "avtalsförhandlings": "avtalsförhandling",
    "avtalsmässiga": "avtalsmässig",
    "avtalsmässigare": "avtalsmässig",
    "avtalsmässigares": "avtalsmässig",
    "avtalsmässigas": "avtalsmässig",
    "avtalsmässigast": "avtalsmässig",
    "avtalsmässigaste": "avtalsmässig",
    "avtalsmässigastes": "avtalsmässig",
    "avtalsmässigasts": "avtalsmässig",
    "avtalsmässige": "avtalsmässig",
    "avtalsmässiges": "avtalsmässig",
    "avtalsmässigs": "avtalsmässig",
    "avtalsmässigt": "avtalsmässig",
    "avtalsmässigts": "avtalsmässig",
    "avtalsperioden": "avtalsperiod",
    "avtalsperiodens": "avtalsperiod",
    "avtalsperioder": "avtalsperiod",
    "avtalsperioderna": "avtalsperiod",
    "avtalsperiodernas": "avtalsperiod",
    "avtalsperioders": "avtalsperiod",
    "avtalsperiods": "avtalsperiod",
    "avtalsrätten": "avtalsrätt",
    "avtalsrättens": "avtalsrätt",
    "avtalsrätts": "avtalsrätt",
    "avtalsrörelsen": "avtalsrörelse",
    "avtalsrörelsens": "avtalsrörelse",
    "avtalsrörelser": "avtalsrörelse",
    "avtalsrörelserna": "avtalsrörelse",
    "avtalsrörelsernas": "avtalsrörelse",
    "avtalsrörelsers": "avtalsrörelse",
    "avtalsrörelses": "avtalsrörelse",
    "avtalssekreterar": "avtalssekreterare",
    "avtalssekreteraren": "avtalssekreterare",
    "avtalssekreterarens": "avtalssekreterare",
    "avtalssekreterares": "avtalssekreterare",
    "avtalssekreterarna": "avtalssekreterare",
    "avtalssekreterarnas": "avtalssekreterare",
    "avtalsstridiga": "avtalsstridig",
    "avtalsstridigare": "avtalsstridig",
    "avtalsstridigares": "avtalsstridig",
    "avtalsstridigas": "avtalsstridig",
    "avtalsstridigast": "avtalsstridig",
    "avtalsstridigaste": "avtalsstridig",
    "avtalsstridigastes": "avtalsstridig",
    "avtalsstridigasts": "avtalsstridig",
    "avtalsstridige": "avtalsstridig",
    "avtalsstridiges": "avtalsstridig",
    "avtalsstridigs": "avtalsstridig",
    "avtalsstridigt": "avtalsstridig",
    "avtalsstridigts": "avtalsstridig",
    "avtapp": "avtappa",
    "avtappad": "avtappa",
    "avtappade": "avtappa",
    "avtappades": "avtappa",
    "avtappads": "avtappa",
    "avtappande": "avtappa",
    "avtappanden": "avtappande",
    "avtappandena": "avtappande",
    "avtappandenas": "avtappande",
    "avtappandens": "avtappande",
    "avtappandes": "avtappande",
    "avtappandet": "avtappande",
    "avtappandets": "avtappande",
    "avtappar": "avtappa",
    "avtappas": "avtappa",
    "avtappat": "avtappa",
    "avtappats": "avtappa",
    "avtappningar": "avtappning",
    "avtappningarna": "avtappning",
    "avtappningarnas": "avtappning",
    "avtappningars": "avtappning",
    "avtappningen": "avtappning",
    "avtappningens": "avtappning",
    "avtappnings": "avtappning",
    "avtar": "avta",
    "avtas": "avta",
    "avtecknad": "avteckna",
    "avtecknade": "avteckna",
    "avtecknades": "avteckna",
    "avtecknads": "avteckna",
    "avtecknande": "avteckna",
    "avtecknanden": "avtecknande",
    "avtecknandena": "avtecknande",
    "avtecknandenas": "avtecknande",
    "avtecknandens": "avtecknande",
    "avtecknandes": "avtecknande",
    "avtecknandet": "avtecknande",
    "avtecknandets": "avtecknande",
    "avtecknar": "avteckna",
    "avtecknas": "avteckna",
    "avtecknat": "avteckna",
    "avtecknats": "avteckna",
    "avtjänad": "avtjäna",
    "avtjänade": "avtjäna",
    "avtjänades": "avtjäna",
    "avtjänads": "avtjäna",
    "avtjänande": "avtjäna",
    "avtjänanden": "avtjänande",
    "avtjänandena": "avtjänande",
    "avtjänandenas": "avtjänande",
    "avtjänandens": "avtjänande",
    "avtjänandes": "avtjänande",
    "avtjänandet": "avtjänande",
    "avtjänandets": "avtjänande",
    "avtjänar": "avtjäna",
    "avtjänas": "avtjäna",
    "avtjänat": "avtjäna",
    "avtjänats": "avtjäna",
    "avtog": "avta",
    "avtoge": "avta",
    "avtoges": "avta",
    "avtogs": "avta",
    "avtonad": "avtona",
    "avtonade": "avtona",
    "avtonades": "avtona",
    "avtonads": "avtona",
    "avtonande": "avtona",
    "avtonanden": "avtonande",
    "avtonandena": "avtonande",
    "avtonandenas": "avtonande",
    "avtonandens": "avtonande",
    "avtonandes": "avtonande",
    "avtonandet": "avtonande",
    "avtonandets": "avtonande",
    "avtonar": "avtona",
    "avtonas": "avtona",
    "avtonat": "avtona",
    "avtonats": "avtona",
    "avtoningar": "avtoning",
    "avtoningarna": "avtoning",
    "avtoningarnas": "avtoning",
    "avtoningars": "avtoning",
    "avtoningen": "avtoning",
    "avtoningens": "avtoning",
    "avtonings": "avtoning",
    "avtrapp": "avtrappa",
    "avtrappad": "avtrappa",
    "avtrappade": "avtrappa",
    "avtrappades": "avtrappa",
    "avtrappads": "avtrappa",
    "avtrappande": "avtrappa",
    "avtrappanden": "avtrappande",
    "avtrappandena": "avtrappande",
    "avtrappandenas": "avtrappande",
    "avtrappandens": "avtrappande",
    "avtrappandes": "avtrappande",
    "avtrappandet": "avtrappande",
    "avtrappandets": "avtrappande",
    "avtrappar": "avtrappa",
    "avtrappas": "avtrappa",
    "avtrappat": "avtrappa",
    "avtrappats": "avtrappa",
    "avtrubb": "avtrubba",
    "avtrubbad": "avtrubba",
    "avtrubbade": "avtrubba",
    "avtrubbades": "avtrubba",
    "avtrubbads": "avtrubba",
    "avtrubbande": "avtrubba",
    "avtrubbanden": "avtrubbande",
    "avtrubbandena": "avtrubbande",
    "avtrubbandenas": "avtrubbande",
    "avtrubbandens": "avtrubbande",
    "avtrubbandes": "avtrubbande",
    "avtrubbandet": "avtrubbande",
    "avtrubbandets": "avtrubbande",
    "avtrubbar": "avtrubba",
    "avtrubbas": "avtrubba",
    "avtrubbat": "avtrubba",
    "avtrubbats": "avtrubba",
    "avtryckar": "avtryckare",
    "avtryckaren": "avtryckare",
    "avtryckarens": "avtryckare",
    "avtryckares": "avtryckare",
    "avtryckarna": "avtryckare",
    "avtryckarnas": "avtryckare",
    "avtrycken": "avtryck",
    "avtryckens": "avtryck",
    "avtrycket": "avtryck",
    "avtryckets": "avtryck",
    "avtrycks": "avtryck",
    "avträd": "avträda",
    "avträdande": "avträda",
    "avträdanden": "avträdande",
    "avträdandena": "avträdande",
    "avträdandenas": "avträdande",
    "avträdandens": "avträdande",
    "avträdandes": "avträdande",
    "avträdandet": "avträdande",
    "avträdandets": "avträdande",
    "avträdas": "avträda",
    "avträdd": "avträda",
    "avträdda": "avträda",
    "avträddas": "avträda",
    "avträdde": "avträda",
    "avträddes": "avträda",
    "avträdds": "avträda",
    "avträdelsen": "avträdelse",
    "avträdelsens": "avträdelse",
    "avträdelser": "avträdelse",
    "avträdelserna": "avträdelse",
    "avträdelsernas": "avträdelse",
    "avträdelsers": "avträdelse",
    "avträdelses": "avträdelse",
    "avträden": "avträde",
    "avträdena": "avträde",
    "avträdenas": "avträde",
    "avträdens": "avträde",
    "avträder": "avträda",
    "avträdes": "avträde",
    "avträdet": "avträde",
    "avträdets": "avträde",
    "avträds": "avträda",
    "avträtt": "avträda",
    "avträtts": "avträda",
    "avtunn": "avtunna",
    "avtunnad": "avtunna",
    "avtunnade": "avtunna",
    "avtunnades": "avtunna",
    "avtunnads": "avtunna",
    "avtunnande": "avtunna",
    "avtunnanden": "avtunnande",
    "avtunnandena": "avtunnande",
    "avtunnandenas": "avtunnande",
    "avtunnandens": "avtunnande",
    "avtunnandes": "avtunnande",
    "avtunnandet": "avtunnande",
    "avtunnandets": "avtunnande",
    "avtunnar": "avtunna",
    "avtunnas": "avtunna",
    "avtunnat": "avtunna",
    "avtunnats": "avtunna",
    "avtvagit": "avtvå",
    "avtvagits": "avtvå",
    "avtvagningar": "avtvagning",
    "avtvagningarna": "avtvagning",
    "avtvagningarnas": "avtvagning",
    "avtvagningars": "avtvagning",
    "avtvagningen": "avtvagning",
    "avtvagningens": "avtvagning",
    "avtvagnings": "avtvagning",
    "avtvang": "avtvinga",
    "avtvangs": "avtvinga",
    "avtving": "avtvinga",
    "avtvingad": "avtvinga",
    "avtvingade": "avtvinga",
    "avtvingades": "avtvinga",
    "avtvingads": "avtvinga",
    "avtvingande": "avtvinga",
    "avtvinganden": "avtvingande",
    "avtvingandena": "avtvingande",
    "avtvingandenas": "avtvingande",
    "avtvingandens": "avtvingande",
    "avtvingandes": "avtvingande",
    "avtvingandet": "avtvingande",
    "avtvingandets": "avtvingande",
    "avtvingar": "avtvinga",
    "avtvingas": "avtvinga",
    "avtvingat": "avtvinga",
    "avtvingats": "avtvinga",
    "avtvinge": "avtvinga",
    "avtvinges": "avtvinga",
    "avtvunge": "avtvinga",
    "avtvungen": "avtvinga",
    "avtvungens": "avtvinga",
    "avtvunges": "avtvinga",
    "avtvunget": "avtvinga",
    "avtvungets": "avtvinga",
    "avtvungit": "avtvinga",
    "avtvungits": "avtvinga",
    "avtvungna": "avtvinga",
    "avtvungnas": "avtvinga",
    "avtvungne": "avtvinga",
    "avtvungnes": "avtvinga",
    "avtvådd": "avtvå",
    "avtvådda": "avtvå",
    "avtvåddas": "avtvå",
    "avtvådde": "avtvå",
    "avtvåddes": "avtvå",
    "avtvådds": "avtvå",
    "avtvående": "avtvå",
    "avtvåenden": "avtvående",
    "avtvåendena": "avtvående",
    "avtvåendenas": "avtvående",
    "avtvåendens": "avtvående",
    "avtvåendes": "avtvående",
    "avtvåendet": "avtvående",
    "avtvåendets": "avtvående",
    "avtvår": "avtvå",
    "avtvås": "avtvå",
    "avtvått": "avtvå",
    "avtvåtts": "avtvå",
    "avtäck": "avtäcka",
    "avtäckande": "avtäcka",
    "avtäckanden": "avtäckande",
    "avtäckandena": "avtäckande",
    "avtäckandenas": "avtäckande",
    "avtäckandens": "avtäckande",
    "avtäckandes": "avtäckande",
    "avtäckandet": "avtäckande",
    "avtäckandets": "avtäckande",
    "avtäckas": "avtäcka",
    "avtäcker": "avtäcka",
    "avtäckes": "avtäcka",
    "avtäcks": "avtäcka",
    "avtäckt": "avtäcka",
    "avtäckta": "avtäcka",
    "avtäcktas": "avtäcka",
    "avtäckte": "avtäcka",
    "avtäcktes": "avtäcka",
    "avtäckts": "avtäcka",
    "avtärda": "avtärd",
    "avtärdare": "avtärd",
    "avtärdares": "avtärd",
    "avtärdas": "avtärd",
    "avtärdast": "avtärd",
    "avtärdaste": "avtärd",
    "avtärdastes": "avtärd",
    "avtärdasts": "avtärd",
    "avtärde": "avtärd",
    "avtärdes": "avtärd",
    "avtärdheten": "avtärdhet",
    "avtärdhetens": "avtärdhet",
    "avtärdhets": "avtärdhet",
    "avtärds": "avtärd",
    "avtärt": "avtärd",
    "avtärts": "avtärd",
    "avtåg": "avtåga",
    "avtågad": "avtåga",
    "avtågade": "avtåga",
    "avtågades": "avtåga",
    "avtågads": "avtåga",
    "avtågande": "avtåga",
    "avtåganden": "avtågande",
    "avtågandena": "avtågande",
    "avtågandenas": "avtågande",
    "avtågandens": "avtågande",
    "avtågandes": "avtågande",
    "avtågandet": "avtågande",
    "avtågandets": "avtågande",
    "avtågar": "avtåga",
    "avtågas": "avtåga",
    "avtågat": "avtåga",
    "avtågats": "avtåga",
    "avtågen": "avtåg",
    "avtågens": "avtåg",
    "avtåget": "avtåg",
    "avtågets": "avtåg",
    "avtågs": "avtåg",
    "avundades": "avundas",
    "avundats": "avundas",
    "avunden": "avund",
    "avundens": "avund",
    "avunds": "avund",
    "avundsamma": "avundsam",
    "avundsammare": "avundsam",
    "avundsammares": "avundsam",
    "avundsammas": "avundsam",
    "avundsammast": "avundsam",
    "avundsammaste": "avundsam",
    "avundsammastes": "avundsam",
    "avundsammasts": "avundsam",
    "avundsamme": "avundsam",
    "avundsammes": "avundsam",
    "avundsams": "avundsam",
    "avundsamt": "avundsam",
    "avundsamts": "avundsam",
    "avundsjuka": "avundsjuk",
    "avundsjukan": "avundsjuka",
    "avundsjukans": "avundsjuka",
    "avundsjukare": "avundsjuk",
    "avundsjukares": "avundsjuk",
    "avundsjukas": "avundsjuka",
    "avundsjukast": "avundsjuk",
    "avundsjukaste": "avundsjuk",
    "avundsjukastes": "avundsjuk",
    "avundsjukasts": "avundsjuk",
    "avundsjuke": "avundsjuka",
    "avundsjukes": "avundsjuk",
    "avundsjukheten": "avundsjukhet",
    "avundsjukhetens": "avundsjukhet",
    "avundsjukhets": "avundsjukhet",
    "avundsjuks": "avundsjuka",
    "avundsjukt": "avundsjuk",
    "avundsjukts": "avundsjuk",
    "avundsmannen": "avundsman",
    "avundsmannens": "avundsman",
    "avundsmans": "avundsman",
    "avundsmän": "avundsman",
    "avundsmännen": "avundsman",
    "avundsmännens": "avundsman",
    "avundsmäns": "avundsman",
    "avundsvärda": "avundsvärd",
    "avundsvärdare": "avundsvärd",
    "avundsvärdares": "avundsvärd",
    "avundsvärdas": "avundsvärd",
    "avundsvärdast": "avundsvärd",
    "avundsvärdaste": "avundsvärd",
    "avundsvärdastes": "avundsvärd",
    "avundsvärdasts": "avundsvärd",
    "avundsvärde": "avundsvärd",
    "avundsvärdes": "avundsvärd",
    "avundsvärdheten": "avundsvärdhet",
    "avundsvärdhetens": "avundsvärdhet",
    "avundsvärdhets": "avundsvärdhet",
    "avundsvärds": "avundsvärd",
    "avundsvärt": "avundsvärd",
    "avundsvärts": "avundsvärd",
    "avvaktad": "avvakta",
    "avvaktade": "avvakta",
    "avvaktades": "avvakta",
    "avvaktads": "avvakta",
    "avvaktande": "avvakta",
    "avvaktanden": "avvaktande",
    "avvaktandena": "avvaktande",
    "avvaktandenas": "avvaktande",
    "avvaktandens": "avvaktande",
    "avvaktandes": "avvaktande",
    "avvaktandet": "avvaktande",
    "avvaktandets": "avvaktande",
    "avvaktar": "avvakta",
    "avvaktas": "avvakta",
    "avvaktat": "avvakta",
    "avvaktats": "avvakta",
    "avvand": "avvänja",
    "avvanda": "avvänja",
    "avvandas": "avvänja",
    "avvande": "avvänja",
    "avvandes": "avvänja",
    "avvands": "avvänja",
    "avvann": "avvinna",
    "avvanns": "avvinna",
    "avvant": "avvänja",
    "avvants": "avvänja",
    "avvar": "avvara",
    "avvarade": "avvara",
    "avvarades": "avvara",
    "avvarande": "avvara",
    "avvaranden": "avvarande",
    "avvarandena": "avvarande",
    "avvarandenas": "avvarande",
    "avvarandens": "avvarande",
    "avvarandes": "avvarande",
    "avvarandet": "avvarande",
    "avvarandets": "avvarande",
    "avvarar": "avvara",
    "avvaras": "avvara",
    "avvarat": "avvara",
    "avvarats": "avvara",
    "avvarit": "avvara",
    "avvarits": "avvara",
    "avvattnad": "avvattna",
    "avvattnade": "avvattna",
    "avvattnades": "avvattna",
    "avvattnads": "avvattna",
    "avvattnande": "avvattna",
    "avvattnanden": "avvattnande",
    "avvattnandena": "avvattnande",
    "avvattnandenas": "avvattnande",
    "avvattnandens": "avvattnande",
    "avvattnandes": "avvattnande",
    "avvattnandet": "avvattnande",
    "avvattnandets": "avvattnande",
    "avvattnar": "avvattna",
    "avvattnas": "avvattna",
    "avvattnat": "avvattna",
    "avvattnats": "avvattna",
    "avvecklad": "avveckla",
    "avvecklade": "avveckla",
    "avvecklades": "avveckla",
    "avvecklads": "avveckla",
    "avvecklande": "avveckla",
    "avvecklanden": "avvecklande",
    "avvecklandena": "avvecklande",
    "avvecklandenas": "avvecklande",
    "avvecklandens": "avvecklande",
    "avvecklandes": "avvecklande",
    "avvecklandet": "avvecklande",
    "avvecklandets": "avvecklande",
    "avvecklar": "avveckla",
    "avvecklas": "avveckla",
    "avvecklat": "avveckla",
    "avvecklats": "avveckla",
    "avvecklingar": "avveckling",
    "avvecklingarna": "avveckling",
    "avvecklingarnas": "avveckling",
    "avvecklingars": "avveckling",
    "avvecklingen": "avveckling",
    "avvecklingens": "avveckling",
    "avvecklings": "avveckling",
    "avvek": "avvika",
    "avveke": "avvika",
    "avvekes": "avvika",
    "avveks": "avvika",
    "avverkad": "avverka",
    "avverkade": "avverka",
    "avverkades": "avverka",
    "avverkads": "avverka",
    "avverkande": "avverka",
    "avverkanden": "avverkande",
    "avverkandena": "avverkande",
    "avverkandenas": "avverkande",
    "avverkandens": "avverkande",
    "avverkandes": "avverkande",
    "avverkandet": "avverkande",
    "avverkandets": "avverkande",
    "avverkar": "avverka",
    "avverkas": "avverka",
    "avverkat": "avverka",
    "avverkats": "avverka",
    "avverkningar": "avverkning",
    "avverkningarna": "avverkning",
    "avverkningarnas": "avverkning",
    "avverkningars": "avverkning",
    "avverkningen": "avverkning",
    "avverkningens": "avverkning",
    "avverknings": "avverkning",
    "avverkningsarbeten": "avverkningsarbete",
    "avverkningsarbetena": "avverkningsarbete",
    "avverkningsarbetenas": "avverkningsarbete",
    "avverkningsarbetens": "avverkningsarbete",
    "avverkningsarbetes": "avverkningsarbete",
    "avverkningsarbetet": "avverkningsarbete",
    "avverkningsarbetets": "avverkningsarbete",
    "avverkningsarbets": "avverkningsarbete",
    "avvik": "avvika",
    "avvikande": "avvika",
    "avvikanden": "avvikande",
    "avvikandena": "avvikande",
    "avvikandenas": "avvikande",
    "avvikandens": "avvikande",
    "avvikandes": "avvikande",
    "avvikandet": "avvikande",
    "avvikandets": "avvikande",
    "avvikar": "avvikare",
    "avvikaren": "avvikare",
    "avvikarens": "avvikare",
    "avvikares": "avvikare",
    "avvikarna": "avvikare",
    "avvikarnas": "avvikare",
    "avvikas": "avvika",
    "avvike": "avvika",
    "avvikelsen": "avvikelse",
    "avvikelsens": "avvikelse",
    "avvikelseprocenten": "avvikelseprocent",
    "avvikelseprocentens": "avvikelseprocent",
    "avvikelseprocents": "avvikelseprocent",
    "avvikelser": "avvikelse",
    "avvikelserna": "avvikelse",
    "avvikelsernas": "avvikelse",
    "avvikelsers": "avvikelse",
    "avvikelses": "avvikelse",
    "avviken": "avvika",
    "avvikens": "avvika",
    "avviker": "avvika",
    "avvikes": "avvika",
    "avviket": "avvika",
    "avvikets": "avvika",
    "avvikit": "avvika",
    "avvikits": "avvika",
    "avvikna": "avvika",
    "avviknas": "avvika",
    "avvikne": "avvika",
    "avviknes": "avvika",
    "avviks": "avvika",
    "avvikt": "avvika",
    "avvikts": "avvika",
    "avvinn": "avvinna",
    "avvinnande": "avvinna",
    "avvinnanden": "avvinnande",
    "avvinnandena": "avvinnande",
    "avvinnandenas": "avvinnande",
    "avvinnandens": "avvinnande",
    "avvinnandes": "avvinnande",
    "avvinnandet": "avvinnande",
    "avvinnandets": "avvinnande",
    "avvinnas": "avvinna",
    "avvinne": "avvinna",
    "avvinner": "avvinna",
    "avvinnes": "avvinna",
    "avvinns": "avvinna",
    "avvisad": "avvisa",
    "avvisade": "avvisa",
    "avvisades": "avvisa",
    "avvisads": "avvisa",
    "avvisande": "avvisa",
    "avvisanden": "avvisande",
    "avvisandena": "avvisande",
    "avvisandenas": "avvisande",
    "avvisandens": "avvisande",
    "avvisandes": "avvisande",
    "avvisandet": "avvisande",
    "avvisandets": "avvisande",
    "avvisar": "avvisare",
    "avvisaren": "avvisare",
    "avvisarens": "avvisare",
    "avvisares": "avvisare",
    "avvisarna": "avvisare",
    "avvisarnas": "avvisare",
    "avvisas": "avvisa",
    "avvisat": "avvisa",
    "avvisats": "avvisa",
    "avvisningar": "avvisning",
    "avvisningarna": "avvisning",
    "avvisningarnas": "avvisning",
    "avvisningars": "avvisning",
    "avvisningen": "avvisning",
    "avvisningens": "avvisning",
    "avvisnings": "avvisning",
    "avvisningsbesluten": "avvisningsbeslut",
    "avvisningsbeslutens": "avvisningsbeslut",
    "avvisningsbeslutet": "avvisningsbeslut",
    "avvisningsbeslutets": "avvisningsbeslut",
    "avvisningsbesluts": "avvisningsbeslut",
    "avvit": "avvita",
    "avvitad": "avvita",
    "avvitade": "avvita",
    "avvitades": "avvita",
    "avvitads": "avvita",
    "avvitande": "avvita",
    "avvitanden": "avvitande",
    "avvitandena": "avvitande",
    "avvitandenas": "avvitande",
    "avvitandens": "avvitande",
    "avvitandes": "avvitande",
    "avvitandet": "avvitande",
    "avvitandets": "avvitande",
    "avvitar": "avvita",
    "avvitas": "avvita",
    "avvitat": "avvita",
    "avvitats": "avvita",
    "avvittrad": "avvittra",
    "avvittrade": "avvittra",
    "avvittrades": "avvittra",
    "avvittrads": "avvittra",
    "avvittrande": "avvittra",
    "avvittranden": "avvittrande",
    "avvittrandena": "avvittrande",
    "avvittrandenas": "avvittrande",
    "avvittrandens": "avvittrande",
    "avvittrandes": "avvittrande",
    "avvittrandet": "avvittrande",
    "avvittrandets": "avvittrande",
    "avvittrar": "avvittra",
    "avvittras": "avvittra",
    "avvittrat": "avvittra",
    "avvittrats": "avvittra",
    "avvunna": "avvinna",
    "avvunnas": "avvinna",
    "avvunne": "avvinna",
    "avvunnen": "avvinna",
    "avvunnens": "avvinna",
    "avvunnes": "avvinna",
    "avvunnet": "avvinna",
    "avvunnets": "avvinna",
    "avvunnit": "avvinna",
    "avvunnits": "avvinna",
    "avväg": "avväga",
    "avvägande": "avväga",
    "avväganden": "avvägande",
    "avvägandena": "avvägande",
    "avvägandenas": "avvägande",
    "avvägandens": "avvägande",
    "avvägandes": "avvägande",
    "avvägandet": "avvägande",
    "avvägandets": "avvägande",
    "avvägar": "avväg",
    "avvägarna": "avväg",
    "avvägarnas": "avväg",
    "avvägars": "avväg",
    "avvägas": "avväga",
    "avvägd": "avväga",
    "avvägda": "avväga",
    "avvägdas": "avväga",
    "avvägde": "avväga",
    "avvägdes": "avväga",
    "avvägds": "avväga",
    "avvägen": "avväg",
    "avvägens": "avväg",
    "avväger": "avväga",
    "avväges": "avväga",
    "avvägningar": "avvägning",
    "avvägningarna": "avvägning",
    "avvägningarnas": "avvägning",
    "avvägningars": "avvägning",
    "avvägningen": "avvägning",
    "avvägningens": "avvägning",
    "avvägnings": "avvägning",
    "avvägningsinstrumenten": "avvägningsinstrument",
    "avvägningsinstrumentens": "avvägningsinstrument",
    "avvägningsinstrumentet": "avvägningsinstrument",
    "avvägningsinstrumentets": "avvägningsinstrument",
    "avvägningsinstruments": "avvägningsinstrument",
    "avvägs": "avväga",
    "avvägt": "avväga",
    "avvägts": "avväga",
    "avvänd": "avvända",
    "avvändande": "avvända",
    "avvändanden": "avvändande",
    "avvändandena": "avvändande",
    "avvändandenas": "avvändande",
    "avvändandens": "avvändande",
    "avvändandes": "avvändande",
    "avvändandet": "avvändande",
    "avvändandets": "avvändande",
    "avvändas": "avvända",
    "avvände": "avvända",
    "avvänder": "avvända",
    "avvändes": "avvända",
    "avvänds": "avvända",
    "avvänj": "avvänja",
    "avvänjande": "avvänja",
    "avvänjanden": "avvänjande",
    "avvänjandena": "avvänjande",
    "avvänjandenas": "avvänjande",
    "avvänjandens": "avvänjande",
    "avvänjandes": "avvänjande",
    "avvänjandet": "avvänjande",
    "avvänjandets": "avvänjande",
    "avvänjas": "avvänja",
    "avvänjer": "avvänja",
    "avvänjes": "avvänja",
    "avvänjningar": "avvänjning",
    "avvänjningarna": "avvänjning",
    "avvänjningarnas": "avvänjning",
    "avvänjningars": "avvänjning",
    "avvänjningen": "avvänjning",
    "avvänjningens": "avvänjning",
    "avvänjnings": "avvänjning",
    "avvänjningstiden": "avvänjningstid",
    "avvänjningstidens": "avvänjningstid",
    "avvänjningstider": "avvänjningstid",
    "avvänjningstiderna": "avvänjningstid",
    "avvänjningstidernas": "avvänjningstid",
    "avvänjningstiders": "avvänjningstid",
    "avvänjningstids": "avvänjningstid",
    "avvänjs": "avvänja",
    "avvänt": "avvända",
    "avvänts": "avvända",
    "avväpn": "avväpna",
    "avväpnad": "avväpna",
    "avväpnade": "avväpna",
    "avväpnades": "avväpna",
    "avväpnads": "avväpna",
    "avväpnande": "avväpna",
    "avväpnanden": "avväpnande",
    "avväpnandena": "avväpnande",
    "avväpnandenas": "avväpnande",
    "avväpnandens": "avväpnande",
    "avväpnandes": "avväpnande",
    "avväpnandet": "avväpnande",
    "avväpnandets": "avväpnande",
    "avväpnar": "avväpna",
    "avväpnas": "avväpna",
    "avväpnat": "avväpna",
    "avväpnats": "avväpna",
    "avvärj": "avvärja",
    "avvärjande": "avvärja",
    "avvärjanden": "avvärjande",
    "avvärjandena": "avvärjande",
    "avvärjandenas": "avvärjande",
    "avvärjandens": "avvärjande",
    "avvärjandes": "avvärjande",
    "avvärjandet": "avvärjande",
    "avvärjandets": "avvärjande",
    "avvärjas": "avvärja",
    "avvärjd": "avvärja",
    "avvärjda": "avvärja",
    "avvärjdas": "avvärja",
    "avvärjde": "avvärja",
    "avvärjdes": "avvärja",
    "avvärjds": "avvärja",
    "avvärjer": "avvärja",
    "avvärjes": "avvärja",
    "avvärjs": "avvärja",
    "avvärjt": "avvärja",
    "avvärjts": "avvärja",
    "avytterliga": "avytterlig",
    "avytterligare": "avytterlig",
    "avytterligares": "avytterlig",
    "avytterligas": "avytterlig",
    "avytterligast": "avytterlig",
    "avytterligaste": "avytterlig",
    "avytterligastes": "avytterlig",
    "avytterligasts": "avytterlig",
    "avytterlige": "avytterlig",
    "avytterliges": "avytterlig",
    "avytterligheten": "avytterlighet",
    "avytterlighetens": "avytterlighet",
    "avytterlighets": "avytterlighet",
    "avytterligs": "avytterlig",
    "avytterligt": "avytterlig",
    "avytterligts": "avytterlig",
    "avyttrad": "avyttra",
    "avyttrade": "avyttra",
    "avyttrades": "avyttra",
    "avyttrads": "avyttra",
    "avyttrande": "avyttra",
    "avyttranden": "avyttrande",
    "avyttrandena": "avyttrande",
    "avyttrandenas": "avyttrande",
    "avyttrandens": "avyttrande",
    "avyttrandes": "avyttrande",
    "avyttrandet": "avyttrande",
    "avyttrandets": "avyttrande",
    "avyttrar": "avyttra",
    "avyttras": "avyttra",
    "avyttrat": "avyttra",
    "avyttrats": "avyttra",
    "avät": "aväta",
    "avätande": "aväta",
    "avätanden": "avätande",
    "avätandena": "avätande",
    "avätandenas": "avätande",
    "avätandens": "avätande",
    "avätandes": "avätande",
    "avätandet": "avätande",
    "avätandets": "avätande",
    "avätas": "aväta",
    "aväte": "aväta",
    "aväten": "aväta",
    "avätens": "aväta",
    "aväter": "aväta",
    "avätes": "aväta",
    "avätet": "aväta",
    "avätets": "aväta",
    "avätit": "aväta",
    "avätits": "aväta",
    "avätna": "aväta",
    "avätnas": "aväta",
    "avätne": "aväta",
    "avätnes": "aväta",
    "aväts": "aväta",
    "avåkningar": "avåkning",
    "avåkningarna": "avåkning",
    "avåkningarnas": "avåkning",
    "avåkningars": "avåkning",
    "avåkningen": "avåkning",
    "avåkningens": "avåkning",
    "avåknings": "avåkning",
    "avåt": "aväta",
    "avåte": "aväta",
    "avåtes": "aväta",
    "avåts": "aväta",
    "axad": "axa",
    "axade": "axa",
    "axades": "axa",
    "axads": "axa",
    "axande": "axa",
    "axandes": "axande",
    "axandet": "axande",
    "axandets": "axande",
    "axar": "axa",
    "axas": "axa",
    "axat": "axa",
    "axats": "axa",
    "axblommiga": "axblommig",
    "axblommigare": "axblommig",
    "axblommigares": "axblommig",
    "axblommigas": "axblommig",
    "axblommigast": "axblommig",
    "axblommigaste": "axblommig",
    "axblommigastes": "axblommig",
    "axblommigasts": "axblommig",
    "axblommige": "axblommig",
    "axblommiges": "axblommig",
    "axblommigs": "axblommig",
    "axblommigt": "axblommig",
    "axblommigts": "axblommig",
    "axelbanden": "axelband",
    "axelbandens": "axelband",
    "axelbandet": "axelband",
    "axelbandets": "axelband",
    "axelbands": "axelband",
    "axelbreda": "axelbred",
    "axelbredare": "axelbred",
    "axelbredares": "axelbred",
    "axelbredas": "axelbred",
    "axelbredast": "axelbred",
    "axelbredaste": "axelbred",
    "axelbredastes": "axelbred",
    "axelbredasts": "axelbred",
    "axelbrede": "axelbred",
    "axelbredes": "axelbred",
    "axelbreds": "axelbred",
    "axelbrett": "axelbred",
    "axelbretts": "axelbred",
    "axelböss": "axelbössa",
    "axelbössan": "axelbössa",
    "axelbössans": "axelbössa",
    "axelbössas": "axelbössa",
    "axelbösse": "axelbössa",
    "axelbössor": "axelbössa",
    "axelbössorna": "axelbössa",
    "axelbössornas": "axelbössa",
    "axelbössors": "axelbössa",
    "axeldiametern": "axeldiameter",
    "axeldiameterns": "axeldiameter",
    "axeldiameters": "axeldiameter",
    "axeldiametrar": "axeldiameter",
    "axeldiametrarna": "axeldiameter",
    "axeldiametrarnas": "axeldiameter",
    "axeldiametrars": "axeldiameter",
    "axelgehängen": "axelgehäng",
    "axelgehängens": "axelgehäng",
    "axelgehänget": "axelgehäng",
    "axelgehängets": "axelgehäng",
    "axelgehängs": "axelgehäng",
    "axelhålen": "axelhål",
    "axelhålens": "axelhål",
    "axelhålet": "axelhål",
    "axelhålets": "axelhål",
    "axelhåls": "axelhål",
    "axelhölsterna": "axelhölster",
    "axelhölsternas": "axelhölster",
    "axelhölsters": "axelhölster",
    "axelhölstren": "axelhölster",
    "axelhölstrens": "axelhölster",
    "axelhölstret": "axelhölster",
    "axelhölstrets": "axelhölster",
    "axelinflammationen": "axelinflammation",
    "axelinflammationens": "axelinflammation",
    "axelinflammationer": "axelinflammation",
    "axelinflammationerna": "axelinflammation",
    "axelinflammationernas": "axelinflammation",
    "axelinflammationers": "axelinflammation",
    "axelinflammations": "axelinflammation",
    "axelklaffar": "axelklaff",
    "axelklaffarna": "axelklaff",
    "axelklaffarnas": "axelklaff",
    "axelklaffars": "axelklaff",
    "axelklaffen": "axelklaff",
    "axelklaffens": "axelklaff",
    "axelklaffs": "axelklaff",
    "axelkopplingar": "axelkoppling",
    "axelkopplingarna": "axelkoppling",
    "axelkopplingarnas": "axelkoppling",
    "axelkopplingars": "axelkoppling",
    "axelkopplingen": "axelkoppling",
    "axelkopplingens": "axelkoppling",
    "axelkopplings": "axelkoppling",
    "axellagerna": "axellager",
    "axellagernas": "axellager",
    "axellagers": "axellager",
    "axellagren": "axellager",
    "axellagrens": "axellager",
    "axellagret": "axellager",
    "axellagrets": "axellager",
    "axelmuffar": "axelmuff",
    "axelmuffarna": "axelmuff",
    "axelmuffarnas": "axelmuff",
    "axelmuffars": "axelmuff",
    "axelmuffen": "axelmuff",
    "axelmuffens": "axelmuff",
    "axelmuffs": "axelmuff",
    "axeln": "axel",
    "axelns": "axel",
    "axelremmar": "axelrem",
    "axelremmarna": "axelrem",
    "axelremmarnas": "axelrem",
    "axelremmars": "axelrem",
    "axelremmen": "axelrem",
    "axelremmens": "axelrem",
    "axelrems": "axelrem",
    "axelremsväsk": "axelremsväska",
    "axelremsväskan": "axelremsväska",
    "axelremsväskans": "axelremsväska",
    "axelremsväskas": "axelremsväska",
    "axelremsväske": "axelremsväska",
    "axelremsväskor": "axelremsväska",
    "axelremsväskorna": "axelremsväska",
    "axelremsväskornas": "axelremsväska",
    "axelremsväskors": "axelremsväska",
    "axelriktningar": "axelriktning",
    "axelriktningarna": "axelriktning",
    "axelriktningarnas": "axelriktning",
    "axelriktningars": "axelriktning",
    "axelriktningen": "axelriktning",
    "axelriktningens": "axelriktning",
    "axelriktnings": "axelriktning",
    "axelryckningar": "axelryckning",
    "axelryckningarna": "axelryckning",
    "axelryckningarnas": "axelryckning",
    "axelryckningars": "axelryckning",
    "axelryckningen": "axelryckning",
    "axelryckningens": "axelryckning",
    "axelrycknings": "axelryckning",
    "axels": "axel",
    "axelseten": "axelset",
    "axelsetens": "axelset",
    "axelsetet": "axelset",
    "axelsetets": "axelset",
    "axelsets": "axelset",
    "axen": "ax",
    "axens": "ax",
    "axet": "ax",
    "axets": "ax",
    "axiala": "axial",
    "axialare": "axial",
    "axialares": "axial",
    "axialas": "axial",
    "axialast": "axial",
    "axialaste": "axial",
    "axialastes": "axial",
    "axialasts": "axial",
    "axiale": "axial",
    "axiales": "axial",
    "axials": "axial",
    "axialt": "axial",
    "axialts": "axial",
    "axiomatiserad": "axiomatisera",
    "axiomatiserade": "axiomatisera",
    "axiomatiserades": "axiomatisera",
    "axiomatiserads": "axiomatisera",
    "axiomatiserande": "axiomatisera",
    "axiomatiseranden": "axiomatiserande",
    "axiomatiserandena": "axiomatiserande",
    "axiomatiserandenas": "axiomatiserande",
    "axiomatiserandens": "axiomatiserande",
    "axiomatiserandes": "axiomatiserande",
    "axiomatiserandet": "axiomatiserande",
    "axiomatiserandets": "axiomatiserande",
    "axiomatiserar": "axiomatisera",
    "axiomatiseras": "axiomatisera",
    "axiomatiserat": "axiomatisera",
    "axiomatiserats": "axiomatisera",
    "axiomatiserbara": "axiomatiserbar",
    "axiomatiserbarare": "axiomatiserbar",
    "axiomatiserbarares": "axiomatiserbar",
    "axiomatiserbaras": "axiomatiserbar",
    "axiomatiserbarast": "axiomatiserbar",
    "axiomatiserbaraste": "axiomatiserbar",
    "axiomatiserbarastes": "axiomatiserbar",
    "axiomatiserbarasts": "axiomatiserbar",
    "axiomatiserbare": "axiomatiserbar",
    "axiomatiserbares": "axiomatiserbar",
    "axiomatiserbarheten": "axiomatiserbarhet",
    "axiomatiserbarhetens": "axiomatiserbarhet",
    "axiomatiserbarhets": "axiomatiserbarhet",
    "axiomatiserbars": "axiomatiserbar",
    "axiomatiserbart": "axiomatiserbar",
    "axiomatiserbarts": "axiomatiserbar",
    "axiomatiseringar": "axiomatisering",
    "axiomatiseringarna": "axiomatisering",
    "axiomatiseringarnas": "axiomatisering",
    "axiomatiseringars": "axiomatisering",
    "axiomatiseringen": "axiomatisering",
    "axiomatiseringens": "axiomatisering",
    "axiomatiserings": "axiomatisering",
    "axiomatiska": "axiomatisk",
    "axiomatiskare": "axiomatisk",
    "axiomatiskares": "axiomatisk",
    "axiomatiskas": "axiomatisk",
    "axiomatiskast": "axiomatisk",
    "axiomatiskaste": "axiomatisk",
    "axiomatiskastes": "axiomatisk",
    "axiomatiskasts": "axiomatisk",
    "axiomatiske": "axiomatisk",
    "axiomatiskes": "axiomatisk",
    "axiomatisks": "axiomatisk",
    "axiomatiskt": "axiomatisk",
    "axiomatiskts": "axiomatisk",
    "axiomen": "axiom",
    "axiomens": "axiom",
    "axiomet": "axiom",
    "axiomets": "axiom",
    "axioms": "axiom",
    "axionen": "axion",
    "axionens": "axion",
    "axioner": "axion",
    "axionerna": "axion",
    "axionernas": "axion",
    "axioners": "axion",
    "axionförtätningar": "axionförtätning",
    "axionförtätningarna": "axionförtätning",
    "axionförtätningarnas": "axionförtätning",
    "axionförtätningars": "axionförtätning",
    "axionförtätningen": "axionförtätning",
    "axionförtätningens": "axionförtätning",
    "axionförtätnings": "axionförtätning",
    "axions": "axion",
    "axlad": "axla",
    "axlade": "axla",
    "axlades": "axla",
    "axlads": "axla",
    "axlande": "axla",
    "axlanden": "axlande",
    "axlandena": "axlande",
    "axlandenas": "axlande",
    "axlandens": "axlande",
    "axlandes": "axlande",
    "axlandet": "axlande",
    "axlandets": "axlande",
    "axlar": "axla",
    "axlarna": "axel",
    "axlarnas": "axel",
    "axlars": "axel",
    "axlas": "axla",
    "axlat": "axla",
    "axlats": "axla",
    "axplocken": "axplock",
    "axplockens": "axplock",
    "axplocket": "axplock",
    "axplockets": "axplock",
    "axplocks": "axplock",
    "axsvingeln": "axsvingel",
    "axsvingelns": "axsvingel",
    "axsvingels": "axsvingel",
    "ayahuascan": "ayahuasca",
    "ayahuascans": "ayahuasca",
    "ayahuascas": "ayahuasca",
    "ayatollahs": "ayatollah",
    "ayatollan": "ayatolla",
    "ayatollans": "ayatolla",
    "ayatollas": "ayatolla",
    "ayatollor": "ayatolla",
    "ayatollorna": "ayatolla",
    "ayatollornas": "ayatolla",
    "ayatollors": "ayatolla",
    "ayrshireboskapen": "ayrshireboskap",
    "ayrshireboskapens": "ayrshireboskap",
    "ayrshireboskaps": "ayrshireboskap",
    "azale": "azalea",
    "azalean": "azalea",
    "azaleans": "azalea",
    "azaleas": "azalea",
    "azalee": "azalea",
    "azaleor": "azalea",
    "azaleorna": "azalea",
    "azaleornas": "azalea",
    "azaleors": "azalea",
    "azales": "azalea",
    "azerbajdzjanen": "azerbajdzjan",
    "azerbajdzjanens": "azerbajdzjan",
    "azerbajdzjaner": "azerbajdzjan",
    "azerbajdzjanerna": "azerbajdzjan",
    "azerbajdzjanernas": "azerbajdzjan",
    "azerbajdzjaners": "azerbajdzjan",
    "azerbajdzjans": "azerbajdzjan",
    "azerbajdzjansk": "azerbajdzjanska",
    "azerbajdzjanska": "azerbajdzjansk",
    "azerbajdzjanskan": "azerbajdzjanska",
    "azerbajdzjanskans": "azerbajdzjanska",
    "azerbajdzjanskare": "azerbajdzjansk",
    "azerbajdzjanskares": "azerbajdzjansk",
    "azerbajdzjanskas": "azerbajdzjanska",
    "azerbajdzjanskast": "azerbajdzjansk",
    "azerbajdzjanskaste": "azerbajdzjansk",
    "azerbajdzjanskastes": "azerbajdzjansk",
    "azerbajdzjanskasts": "azerbajdzjansk",
    "azerbajdzjanske": "azerbajdzjanska",
    "azerbajdzjanskes": "azerbajdzjansk",
    "azerbajdzjanskor": "azerbajdzjanska",
    "azerbajdzjanskorna": "azerbajdzjanska",
    "azerbajdzjanskornas": "azerbajdzjanska",
    "azerbajdzjanskors": "azerbajdzjanska",
    "azerbajdzjansks": "azerbajdzjansk",
    "azerbajdzjanskt": "azerbajdzjansk",
    "azerbajdzjanskts": "azerbajdzjansk",
    "azimuten": "azimut",
    "azimutens": "azimut",
    "azimuts": "azimut",
    "azteken": "aztek",
    "aztekens": "aztek",
    "azteker": "aztek",
    "aztekerna": "aztek",
    "aztekernas": "aztek",
    "aztekers": "aztek",
    "aztekiska": "aztekisk",
    "aztekiskare": "aztekisk",
    "aztekiskares": "aztekisk",
    "aztekiskas": "aztekisk",
    "aztekiskast": "aztekisk",
    "aztekiskaste": "aztekisk",
    "aztekiskastes": "aztekisk",
    "aztekiskasts": "aztekisk",
    "aztekiske": "aztekisk",
    "aztekiskes": "aztekisk",
    "aztekisks": "aztekisk",
    "aztekiskt": "aztekisk",
    "aztekiskts": "aztekisk",
    "azteks": "aztek",
    "azurblåa": "azurblå",
    "azurblåare": "azurblå",
    "azurblåares": "azurblå",
    "azurblåas": "azurblå",
    "azurblåast": "azurblå",
    "azurblåaste": "azurblå",
    "azurblåastes": "azurblå",
    "azurblåasts": "azurblå",
    "azurblåe": "azurblå",
    "azurblåes": "azurblå",
    "azurblås": "azurblå",
    "azurblått": "azurblå",
    "azurblåtts": "azurblå",
    "azuren": "azur",
    "azurens": "azur",
    "azurn": "azur",
    "azurns": "azur",
    "azurs": "azur",
    "b-et": "b",
    "b-ets": "b",
    "b-n": "b",
    "b-na": "b",
    "b-nas": "b",
    "b-ns": "b",
    "b-t": "b",
    "b-ts": "b",
    "b:et": "b",
    "b:ets": "b",
    "b:n": "b",
    "b:na": "b",
    "b:nas": "b",
    "b:ns": "b",
    "b:s": "b",
    "b:t": "b",
    "b:ts": "b",
    "babbel": "babbla",
    "babbels": "babbel",
    "babblade": "babbla",
    "babblades": "babbla",
    "babblande": "babbla",
    "babblanden": "babblande",
    "babblandena": "babblande",
    "babblandenas": "babblande",
    "babblandens": "babblande",
    "babblandes": "babblande",
    "babblandet": "babblande",
    "babblandets": "babblande",
    "babblar": "babbla",
    "babblas": "babbla",
    "babblat": "babbla",
    "babblats": "babbla",
    "babblet": "babbel",
    "babblets": "babbel",
    "babianen": "babian",
    "babianens": "babian",
    "babianer": "babian",
    "babianerna": "babian",
    "babianernas": "babian",
    "babianers": "babian",
    "babians": "babian",
    "babies": "baby",
    "babiesarna": "baby",
    "babiesarnas": "baby",
    "babords": "babord",
    "babordsvakten": "babordsvakt",
    "babordsvaktens": "babordsvakt",
    "babordsvakter": "babordsvakt",
    "babordsvakterna": "babordsvakt",
    "babordsvakternas": "babordsvakt",
    "babordsvakters": "babordsvakt",
    "babordsvakts": "babordsvakt",
    "babordsår": "babordsåra",
    "babordsåran": "babordsåra",
    "babordsårans": "babordsåra",
    "babordsåras": "babordsåra",
    "babordsåre": "babordsåra",
    "babordsåror": "babordsåra",
    "babordsårorna": "babordsåra",
    "babordsårornas": "babordsåra",
    "babordsårors": "babordsåra",
    "babordsårs": "babordsåra",
    "babusjk": "babusjka",
    "babusjkan": "babusjka",
    "babusjkans": "babusjka",
    "babusjkas": "babusjka",
    "babusjke": "babusjka",
    "babusjkor": "babusjka",
    "babusjkorna": "babusjka",
    "babusjkornas": "babusjka",
    "babusjkors": "babusjka",
    "babusjks": "babusjka",
    "babyar": "baby",
    "babyarna": "baby",
    "babyarnas": "baby",
    "babyars": "baby",
    "babybyx": "babybyxa",
    "babybyxan": "babybyxa",
    "babybyxans": "babybyxa",
    "babybyxas": "babybyxa",
    "babybyxe": "babybyxa",
    "babybyxor": "babybyxa",
    "babybyxorna": "babybyxa",
    "babybyxornas": "babybyxa",
    "babybyxors": "babybyxa",
    "babydräkten": "babydräkt",
    "babydräktens": "babydräkt",
    "babydräkter": "babydräkt",
    "babydräkterna": "babydräkt",
    "babydräkternas": "babydräkt",
    "babydräkters": "babydräkt",
    "babydräkts": "babydräkt",
    "babyer": "baby",
    "babyerna": "baby",
    "babyernas": "baby",
    "babyers": "baby",
    "babyloniern": "babylonier",
    "babylonierna": "babylonier",
    "babyloniernas": "babylonier",
    "babylonierns": "babylonier",
    "babyloniers": "babylonier",
    "babyloniska": "babylonisk",
    "babyloniskare": "babylonisk",
    "babyloniskares": "babylonisk",
    "babyloniskas": "babylonisk",
    "babyloniskast": "babylonisk",
    "babyloniskaste": "babylonisk",
    "babyloniskastes": "babylonisk",
    "babyloniskasts": "babylonisk",
    "babyloniske": "babylonisk",
    "babyloniskes": "babylonisk",
    "babylonisks": "babylonisk",
    "babyloniskt": "babylonisk",
    "babyloniskts": "babylonisk",
    "babyn": "baby",
    "babyns": "baby",
    "babys": "baby",
    "babysimmet": "babysim",
    "babysimmets": "babysim",
    "babysims": "babysim",
    "babysittern": "babysitter",
    "babysitterna": "babysitter",
    "babysitternas": "babysitter",
    "babysitterns": "babysitter",
    "babysitters": "babysitter",
    "babysittersarna": "babysitter",
    "babysittersarnas": "babysitter",
    "babysittrar": "babysitter",
    "babysittrarna": "babysitter",
    "babysittrarnas": "babysitter",
    "babysittrars": "babysitter",
    "baccaraten": "baccarat",
    "baccaratens": "baccarat",
    "baccarats": "baccarat",
    "bacillbärar": "bacillbärare",
    "bacillbäraren": "bacillbärare",
    "bacillbärarens": "bacillbärare",
    "bacillbärares": "bacillbärare",
    "bacillbärarna": "bacillbärare",
    "bacillbärarnas": "bacillbärare",
    "bacillen": "bacill",
    "bacillens": "bacill",
    "baciller": "bacill",
    "bacillerna": "bacill",
    "bacillernas": "bacill",
    "bacillers": "bacill",
    "bacills": "bacill",
    "bacillskräcken": "bacillskräck",
    "bacillskräckens": "bacillskräck",
    "bacillskräcks": "bacillskräck",
    "back": "backe",
    "backad": "backa",
    "backade": "backa",
    "backades": "backa",
    "backads": "backa",
    "backan": "backa",
    "backanalen": "backanal",
    "backanalens": "backanal",
    "backanaler": "backanal",
    "backanalerna": "backanal",
    "backanalernas": "backanal",
    "backanalers": "backanal",
    "backanals": "backanal",
    "backande": "backa",
    "backanden": "backande",
    "backandena": "backande",
    "backandenas": "backande",
    "backandens": "backande",
    "backandes": "backande",
    "backandet": "backande",
    "backandets": "backande",
    "backanisen": "backanis",
    "backanisens": "backanis",
    "backans": "backa",
    "backanten": "backant",
    "backantens": "backant",
    "backanter": "backant",
    "backanterna": "backant",
    "backanternas": "backant",
    "backanters": "backant",
    "backants": "backant",
    "backar": "backe",
    "backarna": "backe",
    "backarnas": "backe",
    "backars": "backe",
    "backas": "backa",
    "backat": "backa",
    "backats": "backa",
    "backe": "backa",
    "backen": "backe",
    "backens": "backe",
    "backes": "backe",
    "backfischar": "backfisch",
    "backfischarna": "backfisch",
    "backfischarnas": "backfisch",
    "backfischars": "backfisch",
    "backfischen": "backfisch",
    "backfischens": "backfisch",
    "backfischs": "backfisch",
    "backgammonen": "backgammon",
    "backgammonens": "backgammon",
    "backgammonet": "backgammon",
    "backgammonets": "backgammon",
    "backgammons": "backgammon",
    "backhammern": "backhammer",
    "backhammerns": "backhammer",
    "backhammers": "backhammer",
    "backhamrar": "backhammer",
    "backhamrarna": "backhammer",
    "backhamrarnas": "backhammer",
    "backhamrars": "backhammer",
    "backhanden": "backhand",
    "backhandens": "backhand",
    "backhands": "backhand",
    "backhoppar": "backhoppare",
    "backhopparen": "backhoppare",
    "backhopparens": "backhoppare",
    "backhoppares": "backhoppare",
    "backhopparna": "backhoppare",
    "backhopparnas": "backhoppare",
    "backhoppningar": "backhoppning",
    "backhoppningarna": "backhoppning",
    "backhoppningarnas": "backhoppning",
    "backhoppningars": "backhoppning",
    "backhoppningen": "backhoppning",
    "backhoppningens": "backhoppning",
    "backhoppnings": "backhoppning",
    "backiga": "backig",
    "backigare": "backig",
    "backigares": "backig",
    "backigas": "backig",
    "backigast": "backig",
    "backigaste": "backig",
    "backigastes": "backig",
    "backigasts": "backig",
    "backige": "backig",
    "backiges": "backig",
    "backigs": "backig",
    "backigt": "backig",
    "backigts": "backig",
    "backkrönen": "backkrön",
    "backkrönens": "backkrön",
    "backkrönet": "backkrön",
    "backkrönets": "backkrön",
    "backkröns": "backkrön",
    "backlandskapen": "backlandskap",
    "backlandskapens": "backlandskap",
    "backlandskapet": "backlandskap",
    "backlandskapets": "backlandskap",
    "backlandskaps": "backlandskap",
    "backor": "backa",
    "backorna": "backa",
    "backornas": "backa",
    "backors": "backa",
    "backpackern": "backpacker",
    "backpackerns": "backpacker",
    "backpackers": "backpacker",
    "backpackersarna": "backpacker",
    "backpackersarnas": "backpacker",
    "backpackersen": "backpacker",
    "backpackersens": "backpacker",
    "backpackingen": "backpacking",
    "backpackingens": "backpacking",
    "backpackings": "backpacking",
    "backs": "backe",
    "backsipp": "backsippa",
    "backsippan": "backsippa",
    "backsippans": "backsippa",
    "backsippas": "backsippa",
    "backsippe": "backsippa",
    "backsippor": "backsippa",
    "backsipporna": "backsippa",
    "backsippornas": "backsippa",
    "backsippors": "backsippa",
    "backsipps": "backsippa",
    "backslagen": "backslag",
    "backslagens": "backslag",
    "backslaget": "backslag",
    "backslagets": "backslag",
    "backslags": "backslag",
    "backspegeln": "backspegel",
    "backspegelns": "backspegel",
    "backspegels": "backspegel",
    "backspeglar": "backspegel",
    "backspeglarna": "backspegel",
    "backspeglarnas": "backspegel",
    "backspeglars": "backspegel",
    "backstagen": "backstag",
    "backstagens": "backstag",
    "backstaget": "backstag",
    "backstagets": "backstag",
    "backstags": "backstag",
    "backströmmar": "backström",
    "backströmmarna": "backström",
    "backströmmarnas": "backström",
    "backströmmars": "backström",
    "backströmmen": "backström",
    "backströmmens": "backström",
    "backströms": "backström",
    "backstugan": "backstuga",
    "backstugans": "backstuga",
    "backstugas": "backstuga",
    "backstuge": "backstuga",
    "backstugor": "backstuga",
    "backstugorna": "backstuga",
    "backstugornas": "backstuga",
    "backstugors": "backstuga",
    "backstugu": "backstuga",
    "backstugusittar": "backstugusittare",
    "backstugusittaren": "backstugusittare",
    "backstugusittarens": "backstugusittare",
    "backstugusittares": "backstugusittare",
    "backstugusittarna": "backstugusittare",
    "backstugusittarnas": "backstugusittare",
    "backsval": "backsvala",
    "backsvalan": "backsvala",
    "backsvalans": "backsvala",
    "backsvalas": "backsvala",
    "backsvale": "backsvala",
    "backsvalor": "backsvala",
    "backsvalorna": "backsvala",
    "backsvalornas": "backsvala",
    "backsvalors": "backsvala",
    "backsvals": "backsvala",
    "backsöt": "backsöta",
    "backsötan": "backsöta",
    "backsötans": "backsöta",
    "backsötas": "backsöta",
    "backsöte": "backsöta",
    "backsötor": "backsöta",
    "backsötorna": "backsöta",
    "backsötornas": "backsöta",
    "backsötors": "backsöta",
    "backsöts": "backsöta",
    "backtimjanen": "backtimjan",
    "backtimjanens": "backtimjan",
    "backtimjans": "backtimjan",
    "backup": "backupa",
    "backupad": "backupa",
    "backupade": "backupa",
    "backupades": "backupa",
    "backupads": "backupa",
    "backupande": "backupa",
    "backupanden": "backupande",
    "backupandena": "backupande",
    "backupandenas": "backupande",
    "backupandens": "backupande",
    "backupandes": "backupande",
    "backupandet": "backupande",
    "backupandets": "backupande",
    "backupar": "backupa",
    "backupas": "backupa",
    "backupat": "backupa",
    "backupats": "backupa",
    "backupen": "backup",
    "backupens": "backup",
    "backuper": "backup",
    "backuperna": "backup",
    "backupernas": "backup",
    "backupers": "backup",
    "backupp": "backuppa",
    "backuppad": "backuppa",
    "backuppade": "backuppa",
    "backuppades": "backuppa",
    "backuppads": "backuppa",
    "backuppande": "backuppa",
    "backuppanden": "backuppande",
    "backuppandena": "backuppande",
    "backuppandenas": "backuppande",
    "backuppandens": "backuppande",
    "backuppandes": "backuppande",
    "backuppandet": "backuppande",
    "backuppandets": "backuppande",
    "backuppar": "backuppa",
    "backuppas": "backuppa",
    "backuppat": "backuppa",
    "backuppats": "backuppa",
    "backuppen": "backupp",
    "backuppens": "backupp",
    "backupper": "backupp",
    "backupperna": "backupp",
    "backuppernas": "backupp",
    "backuppers": "backupp",
    "backupps": "backupp",
    "backups": "backup",
    "backvialen": "backvial",
    "backvialens": "backvial",
    "backvialer": "backvial",
    "backvialerna": "backvial",
    "backvialernas": "backvial",
    "backvialers": "backvial",
    "backvials": "backvial",
    "backväxeln": "backväxel",
    "backväxelns": "backväxel",
    "backväxels": "backväxel",
    "backväxlar": "backväxel",
    "backväxlarna": "backväxel",
    "backväxlarnas": "backväxel",
    "backväxlars": "backväxel",
    "baconen": "bacon",
    "baconens": "bacon",
    "baconet": "bacon",
    "baconets": "bacon",
    "bacons": "bacon",
    "bad": "be",
    "badad": "bada",
    "badade": "bada",
    "badades": "bada",
    "badads": "bada",
    "badande": "bada",
    "badanden": "badande",
    "badandena": "badande",
    "badandenas": "badande",
    "badandens": "badande",
    "badandes": "badande",
    "badandet": "badande",
    "badandets": "badande",
    "badanläggningar": "badanläggning",
    "badanläggningarna": "badanläggning",
    "badanläggningarnas": "badanläggning",
    "badanläggningars": "badanläggning",
    "badanläggningen": "badanläggning",
    "badanläggningens": "badanläggning",
    "badanläggnings": "badanläggning",
    "badar": "badare",
    "badaren": "badare",
    "badarens": "badare",
    "badares": "badare",
    "badarna": "badare",
    "badarnas": "badare",
    "badas": "bada",
    "badat": "bada",
    "badats": "bada",
    "badbassängen": "badbassäng",
    "badbassängens": "badbassäng",
    "badbassänger": "badbassäng",
    "badbassängerna": "badbassäng",
    "badbassängernas": "badbassäng",
    "badbassängers": "badbassäng",
    "badbassängs": "badbassäng",
    "badborst": "badborste",
    "badborstar": "badborste",
    "badborstarna": "badborste",
    "badborstarnas": "badborste",
    "badborstars": "badborste",
    "badborsten": "badborste",
    "badborstens": "badborste",
    "badborstes": "badborste",
    "badbyx": "badbyxa",
    "badbyxan": "badbyxa",
    "badbyxans": "badbyxa",
    "badbyxas": "badbyxa",
    "badbyxe": "badbyxa",
    "badbyxor": "badbyxa",
    "badbyxorna": "badbyxa",
    "badbyxornas": "badbyxa",
    "badbyxors": "badbyxa",
    "badd": "badda",
    "baddad": "badda",
    "baddade": "badda",
    "baddades": "badda",
    "baddads": "badda",
    "baddande": "badda",
    "baddanden": "baddande",
    "baddandena": "baddande",
    "baddandenas": "baddande",
    "baddandens": "baddande",
    "baddandes": "baddande",
    "baddandet": "baddande",
    "baddandets": "baddande",
    "baddar": "baddare",
    "baddaren": "baddare",
    "baddarens": "baddare",
    "baddares": "baddare",
    "baddarna": "baddare",
    "baddarnas": "baddare",
    "baddas": "badda",
    "baddat": "badda",
    "baddats": "badda",
    "baddjäveln": "baddjävel",
    "baddjävelns": "baddjävel",
    "baddjävels": "baddjävel",
    "baddjävlar": "baddjävel",
    "baddjävlarna": "baddjävel",
    "baddjävlarnas": "baddjävel",
    "baddjävlars": "baddjävel",
    "baddräkten": "baddräkt",
    "baddräktens": "baddräkt",
    "baddräkter": "baddräkt",
    "baddräkterna": "baddräkt",
    "baddräkternas": "baddräkt",
    "baddräkters": "baddräkt",
    "baddräkts": "baddräkt",
    "bade": "be",
    "baden": "bad",
    "badens": "bad",
    "badensar": "badensare",
    "badensaren": "badensare",
    "badensarens": "badensare",
    "badensares": "badensare",
    "badensarna": "badensare",
    "badensarnas": "badensare",
    "badensiska": "badensisk",
    "badensiskare": "badensisk",
    "badensiskares": "badensisk",
    "badensiskas": "badensisk",
    "badensiskast": "badensisk",
    "badensiskaste": "badensisk",
    "badensiskastes": "badensisk",
    "badensiskasts": "badensisk",
    "badensiske": "badensisk",
    "badensiskes": "badensisk",
    "badensisks": "badensisk",
    "badensiskt": "badensisk",
    "badensiskts": "badensisk",
    "bades": "be",
    "badet": "bad",
    "badets": "bad",
    "badflick": "badflicka",
    "badflickan": "badflicka",
    "badflickans": "badflicka",
    "badflickas": "badflicka",
    "badflicke": "badflicka",
    "badflickor": "badflicka",
    "badflickorna": "badflicka",
    "badflickornas": "badflicka",
    "badflickors": "badflicka",
    "badflicks": "badflicka",
    "badgästen": "badgäst",
    "badgästens": "badgäst",
    "badgäster": "badgäst",
    "badgästerna": "badgäst",
    "badgästernas": "badgäst",
    "badgästers": "badgäst",
    "badgästs": "badgäst",
    "badhanddukar": "badhandduk",
    "badhanddukarna": "badhandduk",
    "badhanddukarnas": "badhandduk",
    "badhanddukars": "badhandduk",
    "badhandduken": "badhandduk",
    "badhanddukens": "badhandduk",
    "badhandduks": "badhandduk",
    "badhusen": "badhus",
    "badhusens": "badhus",
    "badhuset": "badhus",
    "badhusets": "badhus",
    "badhytten": "badhytt",
    "badhyttens": "badhytt",
    "badhytter": "badhytt",
    "badhytterna": "badhytt",
    "badhytternas": "badhytt",
    "badhytters": "badhytt",
    "badhytts": "badhytt",
    "badkapp": "badkappa",
    "badkappan": "badkappa",
    "badkappans": "badkappa",
    "badkappas": "badkappa",
    "badkappe": "badkappa",
    "badkappor": "badkappa",
    "badkapporna": "badkappa",
    "badkappornas": "badkappa",
    "badkappors": "badkappa",
    "badkapps": "badkappa",
    "badkaren": "badkar",
    "badkarens": "badkar",
    "badkaret": "badkar",
    "badkarets": "badkar",
    "badkars": "badkar",
    "badkarseffekten": "badkarseffekt",
    "badkarseffektens": "badkarseffekt",
    "badkarseffekter": "badkarseffekt",
    "badkarseffekterna": "badkarseffekt",
    "badkarseffekternas": "badkarseffekt",
    "badkarseffekters": "badkarseffekt",
    "badkarseffekts": "badkarseffekt",
    "badkarskanten": "badkarskant",
    "badkarskantens": "badkarskant",
    "badkarskanter": "badkarskant",
    "badkarskanterna": "badkarskant",
    "badkarskanternas": "badkarskant",
    "badkarskanters": "badkarskant",
    "badkarskants": "badkarskant",
    "badklipp": "badklippa",
    "badklippan": "badklippa",
    "badklippans": "badklippa",
    "badklippas": "badklippa",
    "badklippe": "badklippa",
    "badklippor": "badklippa",
    "badklipporna": "badklippa",
    "badklippornas": "badklippa",
    "badklippors": "badklippa",
    "badklipps": "badklippa",
    "badlakanen": "badlakan",
    "badlakanens": "badlakan",
    "badlakanet": "badlakan",
    "badlakanets": "badlakan",
    "badlakans": "badlakan",
    "badmintonbollar": "badmintonboll",
    "badmintonbollarna": "badmintonboll",
    "badmintonbollarnas": "badmintonboll",
    "badmintonbollars": "badmintonboll",
    "badmintonbollen": "badmintonboll",
    "badmintonbollens": "badmintonboll",
    "badmintonbolls": "badmintonboll",
    "badmintonen": "badminton",
    "badmintonens": "badminton",
    "badmintonet": "badminton",
    "badmintonets": "badminton",
    "badmintonrackar": "badmintonrack",
    "badmintonrackarna": "badmintonrack",
    "badmintonrackarnas": "badmintonrack",
    "badmintonrackars": "badmintonrack",
    "badmintonracken": "badmintonrack",
    "badmintonrackens": "badmintonrack",
    "badmintonracket": "badmintonrack",
    "badmintonracketar": "badmintonracket",
    "badmintonracketarna": "badmintonracket",
    "badmintonracketarnas": "badmintonracket",
    "badmintonracketars": "badmintonracket",
    "badmintonracketen": "badmintonracket",
    "badmintonracketens": "badmintonracket",
    "badmintonrackets": "badmintonracket",
    "badmintonracks": "badmintonrack",
    "badmintons": "badminton",
    "badmöss": "badmössa",
    "badmössan": "badmössa",
    "badmössans": "badmössa",
    "badmössas": "badmössa",
    "badmösse": "badmössa",
    "badmössor": "badmössa",
    "badmössorna": "badmössa",
    "badmössornas": "badmössa",
    "badmössors": "badmössa",
    "badorten": "badort",
    "badortens": "badort",
    "badorter": "badort",
    "badorterna": "badort",
    "badorternas": "badort",
    "badorters": "badort",
    "badorts": "badort",
    "badrummen": "badrum",
    "badrummens": "badrum",
    "badrummet": "badrum",
    "badrummets": "badrum",
    "badrums": "badrum",
    "badrumsdörrar": "badrumsdörr",
    "badrumsdörrarna": "badrumsdörr",
    "badrumsdörrarnas": "badrumsdörr",
    "badrumsdörrars": "badrumsdörr",
    "badrumsdörren": "badrumsdörr",
    "badrumsdörrens": "badrumsdörr",
    "badrumsdörrs": "badrumsdörr",
    "badrumsfläktar": "badrumsfläkt",
    "badrumsfläktarna": "badrumsfläkt",
    "badrumsfläktarnas": "badrumsfläkt",
    "badrumsfläktars": "badrumsfläkt",
    "badrumsfläkten": "badrumsfläkt",
    "badrumsfläktens": "badrumsfläkt",
    "badrumsfläkts": "badrumsfläkt",
    "badrumsfärgen": "badrumsfärg",
    "badrumsfärgens": "badrumsfärg",
    "badrumsfärger": "badrumsfärg",
    "badrumsfärgerna": "badrumsfärg",
    "badrumsfärgernas": "badrumsfärg",
    "badrumsfärgers": "badrumsfärg",
    "badrumsfärgs": "badrumsfärg",
    "badrumsgolven": "badrumsgolv",
    "badrumsgolvens": "badrumsgolv",
    "badrumsgolvet": "badrumsgolv",
    "badrumsgolvets": "badrumsgolv",
    "badrumsgolvs": "badrumsgolv",
    "badrumsmöbeln": "badrumsmöbel",
    "badrumsmöbelns": "badrumsmöbel",
    "badrumsmöbels": "badrumsmöbel",
    "badrumsmöbler": "badrumsmöbel",
    "badrumsmöblerna": "badrumsmöbel",
    "badrumsmöblernas": "badrumsmöbel",
    "badrumsmöblers": "badrumsmöbel",
    "badrumsskåpen": "badrumsskåp",
    "badrumsskåpens": "badrumsskåp",
    "badrumsskåpet": "badrumsskåp",
    "badrumsskåpets": "badrumsskåp",
    "badrumsskåps": "badrumsskåp",
    "badrumsspegeln": "badrumsspegel",
    "badrumsspegelns": "badrumsspegel",
    "badrumsspegels": "badrumsspegel",
    "badrumsspeglar": "badrumsspegel",
    "badrumsspeglarna": "badrumsspegel",
    "badrumsspeglarnas": "badrumsspegel",
    "badrumsspeglars": "badrumsspegel",
    "bads": "be",
    "badsalter": "badsalt",
    "badsalterna": "badsalt",
    "badsalternas": "badsalt",
    "badsalters": "badsalt",
    "badsaltet": "badsalt",
    "badsaltets": "badsalt",
    "badsalts": "badsalt",
    "badskon": "badsko",
    "badskons": "badsko",
    "badskor": "badsko",
    "badskorna": "badsko",
    "badskornas": "badsko",
    "badskors": "badsko",
    "badskos": "badsko",
    "badstranden": "badstrand",
    "badstrandens": "badstrand",
    "badstrands": "badstrand",
    "badstränder": "badstrand",
    "badstränderna": "badstrand",
    "badsträndernas": "badstrand",
    "badstränders": "badstrand",
    "badställen": "badställe",
    "badställena": "badställe",
    "badställenas": "badställe",
    "badställens": "badställe",
    "badställes": "badställe",
    "badstället": "badställe",
    "badställets": "badställe",
    "badtoffeln": "badtoffel",
    "badtoffelns": "badtoffel",
    "badtoffels": "badtoffel",
    "badtoffla": "badtoffel",
    "badtofflan": "badtoffel",
    "badtofflans": "badtoffel",
    "badtofflas": "badtoffel",
    "badtoffle": "badtoffel",
    "badtofflor": "badtoffel",
    "badtofflorna": "badtoffel",
    "badtofflornas": "badtoffel",
    "badtofflors": "badtoffel",
    "badturisten": "badturist",
    "badturistens": "badturist",
    "badturister": "badturist",
    "badturisterna": "badturist",
    "badturisternas": "badturist",
    "badturisters": "badturist",
    "badturists": "badturist",
    "badvakten": "badvakt",
    "badvaktens": "badvakt",
    "badvakter": "badvakt",
    "badvakterna": "badvakt",
    "badvakternas": "badvakt",
    "badvakters": "badvakt",
    "badvakts": "badvakt",
    "badvattens": "badvatten",
    "badvattnen": "badvatten",
    "badvattnens": "badvatten",
    "badvattnet": "badvatten",
    "badvattnets": "badvatten",
    "bag-in-boxar": "bag-in-box",
    "bag-in-boxarna": "bag-in-box",
    "bag-in-boxarnas": "bag-in-box",
    "bag-in-boxars": "bag-in-box",
    "bag-in-boxen": "bag-in-box",
    "bag-in-boxens": "bag-in-box",
    "bagageinlämningar": "bagageinlämning",
    "bagageinlämningarna": "bagageinlämning",
    "bagageinlämningarnas": "bagageinlämning",
    "bagageinlämningars": "bagageinlämning",
    "bagageinlämningen": "bagageinlämning",
    "bagageinlämningens": "bagageinlämning",
    "bagageinlämnings": "bagageinlämning",
    "bagagekärr": "bagagekärra",
    "bagagekärran": "bagagekärra",
    "bagagekärrans": "bagagekärra",
    "bagagekärras": "bagagekärra",
    "bagagekärre": "bagagekärra",
    "bagagekärror": "bagagekärra",
    "bagagekärrorna": "bagagekärra",
    "bagagekärrornas": "bagagekärra",
    "bagagekärrors": "bagagekärra",
    "bagagekärrs": "bagagekärra",
    "bagageluck": "bagagelucka",
    "bagageluckan": "bagagelucka",
    "bagageluckans": "bagagelucka",
    "bagageluckas": "bagagelucka",
    "bagagelucke": "bagagelucka",
    "bagageluckor": "bagagelucka",
    "bagageluckorna": "bagagelucka",
    "bagageluckornas": "bagagelucka",
    "bagageluckors": "bagagelucka",
    "bagagelucks": "bagagelucka",
    "bagagen": "bagage",
    "bagagens": "bagage",
    "bagages": "bagage",
    "bagagestroppar": "bagagestropp",
    "bagagestropparna": "bagagestropp",
    "bagagestropparnas": "bagagestropp",
    "bagagestroppars": "bagagestropp",
    "bagagestroppen": "bagagestropp",
    "bagagestroppens": "bagagestropp",
    "bagagestropps": "bagagestropp",
    "bagaget": "bagage",
    "bagagets": "bagage",
    "bagageutrymmen": "bagageutrymme",
    "bagageutrymmena": "bagageutrymme",
    "bagageutrymmenas": "bagageutrymme",
    "bagageutrymmens": "bagageutrymme",
    "bagageutrymmes": "bagageutrymme",
    "bagageutrymmet": "bagageutrymme",
    "bagageutrymmets": "bagageutrymme",
    "bagar": "bagare",
    "bagarbodar": "bagarbod",
    "bagarbodarna": "bagarbod",
    "bagarbodarnas": "bagarbod",
    "bagarbodars": "bagarbod",
    "bagarboden": "bagarbod",
    "bagarbodens": "bagarbod",
    "bagarbods": "bagarbod",
    "bagaren": "bagare",
    "bagarens": "bagare",
    "bagares": "bagare",
    "bagarmöss": "bagarmössa",
    "bagarmössan": "bagarmössa",
    "bagarmössans": "bagarmössa",
    "bagarmössas": "bagarmössa",
    "bagarmösse": "bagarmössa",
    "bagarmössor": "bagarmössa",
    "bagarmössorna": "bagarmössa",
    "bagarmössornas": "bagarmössa",
    "bagarmössors": "bagarmössa",
    "bagarna": "bagare",
    "bagarnas": "bagare",
    "bagars": "bag",
    "bagatellartade": "bagatellartad",
    "bagatellartades": "bagatellartad",
    "bagatellartads": "bagatellartad",
    "bagatellartat": "bagatellartad",
    "bagatellartats": "bagatellartad",
    "bagatellen": "bagatell",
    "bagatellens": "bagatell",
    "bagateller": "bagatell",
    "bagatellerna": "bagatell",
    "bagatellernas": "bagatell",
    "bagatellers": "bagatell",
    "bagatelliserad": "bagatellisera",
    "bagatelliserade": "bagatellisera",
    "bagatelliserades": "bagatellisera",
    "bagatelliserads": "bagatellisera",
    "bagatelliserande": "bagatellisera",
    "bagatelliseranden": "bagatelliserande",
    "bagatelliserandena": "bagatelliserande",
    "bagatelliserandenas": "bagatelliserande",
    "bagatelliserandens": "bagatelliserande",
    "bagatelliserandes": "bagatelliserande",
    "bagatelliserandet": "bagatelliserande",
    "bagatelliserandets": "bagatelliserande",
    "bagatelliserar": "bagatellisera",
    "bagatelliseras": "bagatellisera",
    "bagatelliserat": "bagatellisera",
    "bagatelliserats": "bagatellisera",
    "bagatelliserbara": "bagatelliserbar",
    "bagatelliserbarare": "bagatelliserbar",
    "bagatelliserbarares": "bagatelliserbar",
    "bagatelliserbaras": "bagatelliserbar",
    "bagatelliserbarast": "bagatelliserbar",
    "bagatelliserbaraste": "bagatelliserbar",
    "bagatelliserbarastes": "bagatelliserbar",
    "bagatelliserbarasts": "bagatelliserbar",
    "bagatelliserbare": "bagatelliserbar",
    "bagatelliserbares": "bagatelliserbar",
    "bagatelliserbarheten": "bagatelliserbarhet",
    "bagatelliserbarhetens": "bagatelliserbarhet",
    "bagatelliserbarhets": "bagatelliserbarhet",
    "bagatelliserbars": "bagatelliserbar",
    "bagatelliserbart": "bagatelliserbar",
    "bagatelliserbarts": "bagatelliserbar",
    "bagatelliseringar": "bagatellisering",
    "bagatelliseringarna": "bagatellisering",
    "bagatelliseringarnas": "bagatellisering",
    "bagatelliseringars": "bagatellisering",
    "bagatelliseringen": "bagatellisering",
    "bagatelliseringens": "bagatellisering",
    "bagatelliserings": "bagatellisering",
    "bagatellmålen": "bagatellmål",
    "bagatellmålens": "bagatellmål",
    "bagatellmålet": "bagatellmål",
    "bagatellmålets": "bagatellmål",
    "bagatellmåls": "bagatellmål",
    "bagatells": "bagatell",
    "bageln": "bagel",
    "bagelns": "bagel",
    "bagels": "bagel",
    "bagelsarna": "bagel",
    "bagelsarnas": "bagel",
    "bagelsen": "bagel",
    "bagelsens": "bagel",
    "bagen": "bag",
    "bagens": "bag",
    "bagerier": "bageri",
    "bagerierna": "bageri",
    "bageriernas": "bageri",
    "bageriers": "bageri",
    "bageriet": "bageri",
    "bageriets": "bageri",
    "bagerimargariner": "bagerimargarin",
    "bagerimargarinerna": "bagerimargarin",
    "bagerimargarinernas": "bagerimargarin",
    "bagerimargariners": "bagerimargarin",
    "bagerimargarinet": "bagerimargarin",
    "bagerimargarinets": "bagerimargarin",
    "bagerimargarins": "bagerimargarin",
    "bageris": "bageri",
    "bagerit": "bageri",
    "bagerits": "bageri",
    "bagg": "bagge",
    "baggar": "bagge",
    "baggarna": "bagge",
    "baggarnas": "bagge",
    "baggars": "bagge",
    "baggbölad": "baggböla",
    "baggbölade": "baggböla",
    "baggbölades": "baggböla",
    "baggbölads": "baggböla",
    "baggbölande": "baggböla",
    "baggbölanden": "baggbölande",
    "baggbölandena": "baggbölande",
    "baggbölandenas": "baggbölande",
    "baggbölandens": "baggbölande",
    "baggbölandes": "baggbölande",
    "baggbölandet": "baggbölande",
    "baggbölandets": "baggbölande",
    "baggbölar": "baggböla",
    "baggbölas": "baggböla",
    "baggbölat": "baggböla",
    "baggbölats": "baggböla",
    "baggböleriet": "baggböleri",
    "baggböleriets": "baggböleri",
    "baggböleris": "baggböleri",
    "baggbölerit": "baggböleri",
    "baggbölerits": "baggböleri",
    "baggen": "bagge",
    "baggens": "bagge",
    "bagges": "bagge",
    "baggs": "bagge",
    "bagisar": "bagis",
    "bagisarna": "bagis",
    "bagisarnas": "bagis",
    "bagisars": "bagis",
    "bagisen": "bagis",
    "bagisens": "bagis",
    "bags": "bag",
    "baguetten": "baguette",
    "baguettens": "baguette",
    "baguetter": "baguette",
    "baguetterna": "baguette",
    "baguetternas": "baguette",
    "baguetters": "baguette",
    "baguettes": "baguette",
    "bahamanen": "bahaman",
    "bahamanens": "bahaman",
    "bahamaner": "bahaman",
    "bahamanerna": "bahaman",
    "bahamanernas": "bahaman",
    "bahamaners": "bahaman",
    "bahamans": "bahaman",
    "bahamanska": "bahamansk",
    "bahamanskan": "bahamanska",
    "bahamanskans": "bahamanska",
    "bahamanskare": "bahamansk",
    "bahamanskares": "bahamansk",
    "bahamanskas": "bahamanska",
    "bahamanskast": "bahamansk",
    "bahamanskaste": "bahamansk",
    "bahamanskastes": "bahamansk",
    "bahamanskasts": "bahamansk",
    "bahamanske": "bahamanska",
    "bahamanskes": "bahamansk",
    "bahamanskor": "bahamanska",
    "bahamanskorna": "bahamanska",
    "bahamanskornas": "bahamanska",
    "bahamanskors": "bahamanska",
    "bahamansks": "bahamansk",
    "bahamanskt": "bahamansk",
    "bahamanskts": "bahamansk",
    "bahrainar": "bahrainare",
    "bahrainaren": "bahrainare",
    "bahrainarens": "bahrainare",
    "bahrainares": "bahrainare",
    "bahrainarna": "bahrainare",
    "bahrainarnas": "bahrainare",
    "bahrainska": "bahrainsk",
    "bahrainskan": "bahrainska",
    "bahrainskans": "bahrainska",
    "bahrainskare": "bahrainsk",
    "bahrainskares": "bahrainsk",
    "bahrainskas": "bahrainska",
    "bahrainskast": "bahrainsk",
    "bahrainskaste": "bahrainsk",
    "bahrainskastes": "bahrainsk",
    "bahrainskasts": "bahrainsk",
    "bahrainske": "bahrainska",
    "bahrainskes": "bahrainsk",
    "bahrainskor": "bahrainska",
    "bahrainskorna": "bahrainska",
    "bahrainskornas": "bahrainska",
    "bahrainskors": "bahrainska",
    "bahrainsks": "bahrainsk",
    "bahrainskt": "bahrainsk",
    "bahrainskts": "bahrainsk",
    "bahytten": "bahytt",
    "bahyttens": "bahytt",
    "bahytter": "bahytt",
    "bahytterna": "bahytt",
    "bahytternas": "bahytt",
    "bahytters": "bahytt",
    "bahytts": "bahytt",
    "baiss": "baissa",
    "baissad": "baissa",
    "baissade": "baissa",
    "baissades": "baissa",
    "baissads": "baissa",
    "baissande": "baissa",
    "baissanden": "baissande",
    "baissandena": "baissande",
    "baissandenas": "baissande",
    "baissandens": "baissande",
    "baissandes": "baissande",
    "baissandet": "baissande",
    "baissandets": "baissande",
    "baissar": "baissa",
    "baissas": "baissa",
    "baissat": "baissa",
    "baissats": "baissa",
    "baissen": "baisse",
    "baissens": "baisse",
    "baisser": "baisse",
    "baisserna": "baisse",
    "baissernas": "baisse",
    "baissers": "baisse",
    "baisses": "baisse",
    "bajadären": "bajadär",
    "bajadärens": "bajadär",
    "bajadärer": "bajadär",
    "bajadärerna": "bajadär",
    "bajadärernas": "bajadär",
    "bajadärers": "bajadär",
    "bajadärs": "bajadär",
    "bajerska": "bajersk",
    "bajerskare": "bajersk",
    "bajerskares": "bajersk",
    "bajerskas": "bajersk",
    "bajerskast": "bajersk",
    "bajerskaste": "bajersk",
    "bajerskastes": "bajersk",
    "bajerskasts": "bajersk",
    "bajerske": "bajersk",
    "bajerskes": "bajersk",
    "bajersks": "bajersk",
    "bajerskt": "bajersk",
    "bajerskts": "bajersk",
    "bajonettbaljan": "bajonettbalja",
    "bajonettbaljans": "bajonettbalja",
    "bajonettbaljas": "bajonettbalja",
    "bajonettbalje": "bajonettbalja",
    "bajonettbaljor": "bajonettbalja",
    "bajonettbaljorna": "bajonettbalja",
    "bajonettbaljornas": "bajonettbalja",
    "bajonettbaljors": "bajonettbalja",
    "bajonetten": "bajonett",
    "bajonettens": "bajonett",
    "bajonetter": "bajonett",
    "bajonetterna": "bajonett",
    "bajonetternas": "bajonett",
    "bajonetters": "bajonett",
    "bajonettfattningar": "bajonettfattning",
    "bajonettfattningarna": "bajonettfattning",
    "bajonettfattningarnas": "bajonettfattning",
    "bajonettfattningars": "bajonettfattning",
    "bajonettfattningen": "bajonettfattning",
    "bajonettfattningens": "bajonettfattning",
    "bajonettfattnings": "bajonettfattning",
    "bajonetts": "bajonett",
    "bajonettspetsar": "bajonettspets",
    "bajonettspetsarna": "bajonettspets",
    "bajonettspetsarnas": "bajonettspets",
    "bajonettspetsars": "bajonettspets",
    "bajonettspetsen": "bajonettspets",
    "bajonettspetsens": "bajonettspets",
    "bajrar": "bajrare",
    "bajraren": "bajrare",
    "bajrarens": "bajrare",
    "bajrares": "bajrare",
    "bajrarna": "bajrare",
    "bajrarnas": "bajrare",
    "bajs": "bajsa",
    "bajsad": "bajsa",
    "bajsade": "bajsa",
    "bajsades": "bajsa",
    "bajsads": "bajsa",
    "bajsande": "bajsa",
    "bajsanden": "bajsande",
    "bajsandena": "bajsande",
    "bajsandenas": "bajsande",
    "bajsandens": "bajsande",
    "bajsandes": "bajsande",
    "bajsandet": "bajsande",
    "bajsandets": "bajsande",
    "bajsar": "bajsa",
    "bajsas": "bajsa",
    "bajsat": "bajsa",
    "bajsats": "bajsa",
    "bajsbruna": "bajsbrun",
    "bajsbrunare": "bajsbrun",
    "bajsbrunares": "bajsbrun",
    "bajsbrunas": "bajsbrun",
    "bajsbrunast": "bajsbrun",
    "bajsbrunaste": "bajsbrun",
    "bajsbrunastes": "bajsbrun",
    "bajsbrunasts": "bajsbrun",
    "bajsbrune": "bajsbrun",
    "bajsbrunes": "bajsbrun",
    "bajsbruns": "bajsbrun",
    "bajsbrunt": "bajsbrun",
    "bajsbrunts": "bajsbrun",
    "bajset": "bajs",
    "bajsets": "bajs",
    "bajshögar": "bajshög",
    "bajshögarna": "bajshög",
    "bajshögarnas": "bajshög",
    "bajshögars": "bajshög",
    "bajshögen": "bajshög",
    "bajshögens": "bajshög",
    "bajshögs": "bajshög",
    "bajsiga": "bajsig",
    "bajsigare": "bajsig",
    "bajsigares": "bajsig",
    "bajsigas": "bajsig",
    "bajsigast": "bajsig",
    "bajsigaste": "bajsig",
    "bajsigastes": "bajsig",
    "bajsigasts": "bajsig",
    "bajsige": "bajsig",
    "bajsiges": "bajsig",
    "bajsigs": "bajsig",
    "bajsigt": "bajsig",
    "bajsigts": "bajsig",
    "bajsnödiga": "bajsnödig",
    "bajsnödigare": "bajsnödig",
    "bajsnödigares": "bajsnödig",
    "bajsnödigas": "bajsnödig",
    "bajsnödigast": "bajsnödig",
    "bajsnödigaste": "bajsnödig",
    "bajsnödigastes": "bajsnödig",
    "bajsnödigasts": "bajsnödig",
    "bajsnödige": "bajsnödig",
    "bajsnödiges": "bajsnödig",
    "bajsnödigs": "bajsnödig",
    "bajsnödigt": "bajsnödig",
    "bajsnödigts": "bajsnödig",
    "bak": "baka",
    "bakad": "baka",
    "bakade": "baka",
    "bakades": "baka",
    "bakads": "baka",
    "bakande": "baka",
    "bakanden": "bakande",
    "bakandena": "bakande",
    "bakandenas": "bakande",
    "bakandens": "bakande",
    "bakandes": "bakande",
    "bakandet": "bakande",
    "bakandets": "bakande",
    "bakar": "baka",
    "bakarna": "bak",
    "bakarnas": "bak",
    "bakars": "bak",
    "bakarven": "bakarv",
    "bakarvens": "bakarv",
    "bakarvet": "bakarv",
    "bakarvets": "bakarv",
    "bakarvingar": "bakarvinge",
    "bakarvingarna": "bakarvinge",
    "bakarvingarnas": "bakarvinge",
    "bakarvingars": "bakarvinge",
    "bakarvingen": "bakarvinge",
    "bakarvingens": "bakarvinge",
    "bakarvinges": "bakarvinge",
    "bakarvs": "bakarv",
    "bakas": "baka",
    "bakat": "baka",
    "bakats": "baka",
    "bakaxeln": "bakaxel",
    "bakaxelns": "bakaxel",
    "bakaxels": "bakaxel",
    "bakaxelväxeln": "bakaxelväxel",
    "bakaxelväxelns": "bakaxelväxel",
    "bakaxelväxels": "bakaxelväxel",
    "bakaxelväxlar": "bakaxelväxel",
    "bakaxelväxlarna": "bakaxelväxel",
    "bakaxelväxlarnas": "bakaxelväxel",
    "bakaxelväxlars": "bakaxelväxel",
    "bakaxlar": "bakaxel",
    "bakaxlarna": "bakaxel",
    "bakaxlarnas": "bakaxel",
    "bakaxlars": "bakaxel",
    "bakband": "bakbinda",
    "bakbands": "bakbinda",
    "bakbenen": "bakben",
    "bakbenens": "bakben",
    "bakbenet": "bakben",
    "bakbenets": "bakben",
    "bakbens": "bakben",
    "bakbind": "bakbinda",
    "bakbindande": "bakbinda",
    "bakbindanden": "bakbindande",
    "bakbindandena": "bakbindande",
    "bakbindandenas": "bakbindande",
    "bakbindandens": "bakbindande",
    "bakbindandes": "bakbindande",
    "bakbindandet": "bakbindande",
    "bakbindandets": "bakbindande",
    "bakbindas": "bakbinda",
    "bakbinde": "bakbinda",
    "bakbinder": "bakbinda",
    "bakbindes": "bakbinda",
    "bakbinds": "bakbinda",
    "bakblåsar": "bakblåsare",
    "bakblåsaren": "bakblåsare",
    "bakblåsarens": "bakblåsare",
    "bakblåsares": "bakblåsare",
    "bakblåsarna": "bakblåsare",
    "bakblåsarnas": "bakblåsare",
    "bakbunde": "bakbinda",
    "bakbunden": "bakbinda",
    "bakbundens": "bakbinda",
    "bakbundes": "bakbinda",
    "bakbundet": "bakbinda",
    "bakbundets": "bakbinda",
    "bakbundit": "bakbinda",
    "bakbundits": "bakbinda",
    "bakbundna": "bakbinda",
    "bakbundnas": "bakbinda",
    "bakbundne": "bakbinda",
    "bakbundnes": "bakbinda",
    "bakdant": "bakdanta",
    "bakdantad": "bakdanta",
    "bakdantade": "bakdanta",
    "bakdantades": "bakdanta",
    "bakdantads": "bakdanta",
    "bakdantande": "bakdanta",
    "bakdantanden": "bakdantande",
    "bakdantandena": "bakdantande",
    "bakdantandenas": "bakdantande",
    "bakdantandens": "bakdantande",
    "bakdantandes": "bakdantande",
    "bakdantandet": "bakdantande",
    "bakdantandets": "bakdantande",
    "bakdantar": "bakdanta",
    "bakdantas": "bakdanta",
    "bakdantat": "bakdanta",
    "bakdantats": "bakdanta",
    "bakdelar": "bakdel",
    "bakdelarna": "bakdel",
    "bakdelarnas": "bakdel",
    "bakdelars": "bakdel",
    "bakdelen": "bakdel",
    "bakdelens": "bakdel",
    "bakdels": "bakdel",
    "bakdäcken": "bakdäck",
    "bakdäckens": "bakdäck",
    "bakdäcket": "bakdäck",
    "bakdäckets": "bakdäck",
    "bakdäcks": "bakdäck",
    "bakdörrar": "bakdörr",
    "bakdörrarna": "bakdörr",
    "bakdörrarnas": "bakdörr",
    "bakdörrars": "bakdörr",
    "bakdörren": "bakdörr",
    "bakdörrens": "bakdörr",
    "bakdörrs": "bakdörr",
    "bakeliten": "bakelit",
    "bakelitens": "bakelit",
    "bakelits": "bakelit",
    "bakelsen": "bakelse",
    "bakelsens": "bakelse",
    "bakelser": "bakelse",
    "bakelserna": "bakelse",
    "bakelsernas": "bakelse",
    "bakelsers": "bakelse",
    "bakelses": "bakelse",
    "baken": "bak",
    "bakens": "bak",
    "bakersta": "bakre",
    "bakerstas": "bakre",
    "bakerste": "bakre",
    "bakerstes": "bakre",
    "baket": "bak",
    "bakets": "bak",
    "bakfick": "bakficka",
    "bakfickan": "bakficka",
    "bakfickans": "bakficka",
    "bakfickas": "bakficka",
    "bakficke": "bakficka",
    "bakfickor": "bakficka",
    "bakfickorna": "bakficka",
    "bakfickornas": "bakficka",
    "bakfickors": "bakficka",
    "bakficks": "bakficka",
    "bakfoten": "bakfot",
    "bakfotens": "bakfot",
    "bakfots": "bakfot",
    "bakfulla": "bakfull",
    "bakfullare": "bakfull",
    "bakfullares": "bakfull",
    "bakfullas": "bakfull",
    "bakfullast": "bakfull",
    "bakfullaste": "bakfull",
    "bakfullastes": "bakfull",
    "bakfullasts": "bakfull",
    "bakfulle": "bakfull",
    "bakfulles": "bakfull",
    "bakfullheten": "bakfullhet",
    "bakfullhetens": "bakfullhet",
    "bakfullhets": "bakfullhet",
    "bakfulls": "bakfull",
    "bakfullt": "bakfull",
    "bakfullts": "bakfull",
    "bakfyll": "bakfylla",
    "bakfyllan": "bakfylla",
    "bakfyllans": "bakfylla",
    "bakfyllas": "bakfylla",
    "bakfylle": "bakfylla",
    "bakfyllor": "bakfylla",
    "bakfyllorna": "bakfylla",
    "bakfyllornas": "bakfylla",
    "bakfyllors": "bakfylla",
    "bakfylls": "bakfylla",
    "bakfötter": "bakfot",
    "bakfötterna": "bakfot",
    "bakfötternas": "bakfot",
    "bakfötters": "bakfot",
    "bakgat": "bakgata",
    "bakgatan": "bakgata",
    "bakgatans": "bakgata",
    "bakgatas": "bakgata",
    "bakgate": "bakgata",
    "bakgator": "bakgata",
    "bakgatorna": "bakgata",
    "bakgatornas": "bakgata",
    "bakgators": "bakgata",
    "bakgats": "bakgata",
    "bakgrunden": "bakgrund",
    "bakgrundens": "bakgrund",
    "bakgrunder": "bakgrund",
    "bakgrunderna": "bakgrund",
    "bakgrundernas": "bakgrund",
    "bakgrunders": "bakgrund",
    "bakgrunds": "bakgrund",
    "bakgrundsfiguren": "bakgrundsfigur",
    "bakgrundsfigurens": "bakgrundsfigur",
    "bakgrundsfigurer": "bakgrundsfigur",
    "bakgrundsfigurerna": "bakgrundsfigur",
    "bakgrundsfigurernas": "bakgrundsfigur",
    "bakgrundsfigurers": "bakgrundsfigur",
    "bakgrundsfigurs": "bakgrundsfigur",
    "bakgrundsmusiken": "bakgrundsmusik",
    "bakgrundsmusikens": "bakgrundsmusik",
    "bakgrundsmusiks": "bakgrundsmusik",
    "bakgrundsreportagen": "bakgrundsreportage",
    "bakgrundsreportagens": "bakgrundsreportage",
    "bakgrundsreportages": "bakgrundsreportage",
    "bakgrundsreportaget": "bakgrundsreportage",
    "bakgrundsreportagets": "bakgrundsreportage",
    "bakgrundsstrålningar": "bakgrundsstrålning",
    "bakgrundsstrålningarna": "bakgrundsstrålning",
    "bakgrundsstrålningarnas": "bakgrundsstrålning",
    "bakgrundsstrålningars": "bakgrundsstrålning",
    "bakgrundsstrålningen": "bakgrundsstrålning",
    "bakgrundsstrålningens": "bakgrundsstrålning",
    "bakgrundsstrålnings": "bakgrundsstrålning",
    "bakgrundstalen": "bakgrundstal",
    "bakgrundstalens": "bakgrundstal",
    "bakgrundstalet": "bakgrundstal",
    "bakgrundstalets": "bakgrundstal",
    "bakgrundstals": "bakgrundstal",
    "bakgrundstonen": "bakgrundston",
    "bakgrundstonens": "bakgrundston",
    "bakgrundstoner": "bakgrundston",
    "bakgrundstonerna": "bakgrundston",
    "bakgrundstonernas": "bakgrundston",
    "bakgrundstoners": "bakgrundston",
    "bakgrundstons": "bakgrundston",
    "bakgrundsvariabeln": "bakgrundsvariabel",
    "bakgrundsvariabelns": "bakgrundsvariabel",
    "bakgrundsvariabels": "bakgrundsvariabel",
    "bakgrundsvariabler": "bakgrundsvariabel",
    "bakgrundsvariablerna": "bakgrundsvariabel",
    "bakgrundsvariablernas": "bakgrundsvariabel",
    "bakgrundsvariablers": "bakgrundsvariabel",
    "bakgårdar": "bakgård",
    "bakgårdarna": "bakgård",
    "bakgårdarnas": "bakgård",
    "bakgårdars": "bakgård",
    "bakgården": "bakgård",
    "bakgårdens": "bakgård",
    "bakgårds": "bakgård",
    "bakhala": "bakhal",
    "bakhalare": "bakhal",
    "bakhalares": "bakhal",
    "bakhalas": "bakhal",
    "bakhalast": "bakhal",
    "bakhalaste": "bakhal",
    "bakhalastes": "bakhal",
    "bakhalasts": "bakhal",
    "bakhale": "bakhal",
    "bakhales": "bakhal",
    "bakhals": "bakhal",
    "bakhalt": "bakhal",
    "bakhalts": "bakhal",
    "bakhasar": "bakhas",
    "bakhasarna": "bakhas",
    "bakhasarnas": "bakhas",
    "bakhasars": "bakhas",
    "bakhasen": "bakhas",
    "bakhasens": "bakhas",
    "bakhasor": "bakhas",
    "bakhasorna": "bakhas",
    "bakhasornas": "bakhas",
    "bakhasors": "bakhas",
    "bakhjulen": "bakhjul",
    "bakhjulens": "bakhjul",
    "bakhjulet": "bakhjul",
    "bakhjulets": "bakhjul",
    "bakhjuls": "bakhjul",
    "bakhuvuden": "bakhuvud",
    "bakhuvudena": "bakhuvud",
    "bakhuvudenas": "bakhuvud",
    "bakhuvudens": "bakhuvud",
    "bakhuvudet": "bakhuvud",
    "bakhuvudets": "bakhuvud",
    "bakhuvuds": "bakhuvud",
    "bakhållen": "bakhåll",
    "bakhållens": "bakhåll",
    "bakhållet": "bakhåll",
    "bakhållets": "bakhåll",
    "bakhålls": "bakhåll",
    "bakjouren": "bakjour",
    "bakjourens": "bakjour",
    "bakjourer": "bakjour",
    "bakjourerna": "bakjour",
    "bakjourernas": "bakjour",
    "bakjourers": "bakjour",
    "bakjours": "bakjour",
    "bakkanten": "bakkant",
    "bakkantens": "bakkant",
    "bakkanter": "bakkant",
    "bakkanterna": "bakkant",
    "bakkanternas": "bakkant",
    "bakkanters": "bakkant",
    "bakkants": "bakkant",
    "bakkapp": "bakkappa",
    "bakkappan": "bakkappa",
    "bakkappans": "bakkappa",
    "bakkappas": "bakkappa",
    "bakkappe": "bakkappa",
    "bakkappor": "bakkappa",
    "bakkapporna": "bakkappa",
    "bakkappornas": "bakkappa",
    "bakkappors": "bakkappa",
    "bakkapps": "bakkappa",
    "bakkroppar": "bakkropp",
    "bakkropparna": "bakkropp",
    "bakkropparnas": "bakkropp",
    "bakkroppars": "bakkropp",
    "bakkroppen": "bakkropp",
    "bakkroppens": "bakkropp",
    "bakkropps": "bakkropp",
    "bakladdar": "bakladdare",
    "bakladdaren": "bakladdare",
    "bakladdarens": "bakladdare",
    "bakladdares": "bakladdare",
    "bakladdarna": "bakladdare",
    "bakladdarnas": "bakladdare",
    "bakladdningar": "bakladdning",
    "bakladdningarna": "bakladdning",
    "bakladdningarnas": "bakladdning",
    "bakladdningars": "bakladdning",
    "bakladdningen": "bakladdning",
    "bakladdningens": "bakladdning",
    "bakladdnings": "bakladdning",
    "baklamp": "baklampa",
    "baklampan": "baklampa",
    "baklampans": "baklampa",
    "baklampas": "baklampa",
    "baklampe": "baklampa",
    "baklampor": "baklampa",
    "baklamporna": "baklampa",
    "baklampornas": "baklampa",
    "baklampors": "baklampa",
    "baklamps": "baklampa",
    "baklandet": "bakland",
    "baklandets": "bakland",
    "baklands": "bakland",
    "bakljusen": "bakljus",
    "bakljusens": "bakljus",
    "bakljuset": "bakljus",
    "bakljusets": "bakljus",
    "bakljusrampen": "bakljusramp",
    "bakljusrampens": "bakljusramp",
    "bakljusramper": "bakljusramp",
    "bakljusramperna": "bakljusramp",
    "bakljusrampernas": "bakljusramp",
    "bakljusrampers": "bakljusramp",
    "bakljusramps": "bakljusramp",
    "bakluck": "baklucka",
    "bakluckan": "baklucka",
    "bakluckans": "baklucka",
    "bakluckas": "baklucka",
    "baklucke": "baklucka",
    "bakluckor": "baklucka",
    "bakluckorna": "baklucka",
    "bakluckornas": "baklucka",
    "bakluckors": "baklucka",
    "baklucks": "baklucka",
    "baklängesordboken": "baklängesordbok",
    "baklängesordbokens": "baklängesordbok",
    "baklängesordboks": "baklängesordbok",
    "baklängesordböcker": "baklängesordbok",
    "baklängesordböckerna": "baklängesordbok",
    "baklängesordböckernas": "baklängesordbok",
    "baklängesordböckers": "baklängesordbok",
    "baklängesvandringar": "baklängesvandring",
    "baklängesvandringarna": "baklängesvandring",
    "baklängesvandringarnas": "baklängesvandring",
    "baklängesvandringars": "baklängesvandring",
    "baklängesvandringen": "baklängesvandring",
    "baklängesvandringens": "baklängesvandring",
    "baklängesvandrings": "baklängesvandring",
    "bakläx": "bakläxa",
    "bakläxan": "bakläxa",
    "bakläxans": "bakläxa",
    "bakläxas": "bakläxa",
    "bakläxe": "bakläxa",
    "bakläxor": "bakläxa",
    "bakläxorna": "bakläxa",
    "bakläxornas": "bakläxa",
    "bakläxors": "bakläxa",
    "bakningar": "bakning",
    "bakningarna": "bakning",
    "bakningarnas": "bakning",
    "bakningars": "bakning",
    "bakningen": "bakning",
    "bakningens": "bakning",
    "baknings": "bakning",
    "bakplåtar": "bakplåt",
    "bakplåtarna": "bakplåt",
    "bakplåtarnas": "bakplåt",
    "bakplåtars": "bakplåt",
    "bakplåten": "bakplåt",
    "bakplåtens": "bakplåt",
    "bakplåts": "bakplåt",
    "bakplåtspapperen": "bakplåtspapper",
    "bakplåtspapperens": "bakplåtspapper",
    "bakplåtspapperet": "bakplåtspapper",
    "bakplåtspapperets": "bakplåtspapper",
    "bakplåtspapperna": "bakplåtspapper",
    "bakplåtspappernas": "bakplåtspapper",
    "bakplåtspappers": "bakplåtspapper",
    "bakplåtspappren": "bakplåtspapper",
    "bakplåtspapprens": "bakplåtspapper",
    "bakplåtspappret": "bakplåtspapper",
    "bakplåtspapprets": "bakplåtspapper",
    "bakprojektionen": "bakprojektion",
    "bakprojektionens": "bakprojektion",
    "bakprojektioner": "bakprojektion",
    "bakprojektionerna": "bakprojektion",
    "bakprojektionernas": "bakprojektion",
    "bakprojektioners": "bakprojektion",
    "bakprojektions": "bakprojektion",
    "bakpulverna": "bakpulver",
    "bakpulvernas": "bakpulver",
    "bakpulvers": "bakpulver",
    "bakpulvren": "bakpulver",
    "bakpulvrens": "bakpulver",
    "bakpulvret": "bakpulver",
    "bakpulvrets": "bakpulver",
    "bakres": "bakre",
    "bakrusen": "bakrus",
    "bakrusens": "bakrus",
    "bakruset": "bakrus",
    "bakrusets": "bakrus",
    "bakrutan": "bakruta",
    "bakrutans": "bakruta",
    "bakrutas": "bakruta",
    "bakrute": "bakruta",
    "bakrutor": "bakruta",
    "bakrutorna": "bakruta",
    "bakrutornas": "bakruta",
    "bakrutors": "bakruta",
    "baks": "bak",
    "baksidan": "baksida",
    "baksidans": "baksida",
    "baksidas": "baksida",
    "bakside": "baksida",
    "baksides": "baksida",
    "baksidesreklamen": "baksidesreklam",
    "baksidesreklamens": "baksidesreklam",
    "baksidesreklams": "baksidesreklam",
    "baksidestexten": "baksidestext",
    "baksidestextens": "baksidestext",
    "baksidestexter": "baksidestext",
    "baksidestexterna": "baksidestext",
    "baksidestexternas": "baksidestext",
    "baksidestexters": "baksidestext",
    "baksidestexts": "baksidestext",
    "baksidor": "baksida",
    "baksidorna": "baksida",
    "baksidornas": "baksida",
    "baksidors": "baksida",
    "bakslagen": "bakslag",
    "bakslagens": "bakslag",
    "bakslaget": "bakslag",
    "bakslagets": "bakslag",
    "bakslags": "bakslag",
    "bakslagsventilen": "bakslagsventil",
    "bakslagsventilens": "bakslagsventil",
    "bakslagsventiler": "bakslagsventil",
    "bakslagsventilerna": "bakslagsventil",
    "bakslagsventilernas": "bakslagsventil",
    "bakslagsventilers": "bakslagsventil",
    "bakslagsventils": "bakslagsventil",
    "baksluga": "bakslug",
    "bakslugare": "bakslug",
    "bakslugares": "bakslug",
    "bakslugas": "bakslug",
    "bakslugast": "bakslug",
    "bakslugaste": "bakslug",
    "bakslugastes": "bakslug",
    "bakslugasts": "bakslug",
    "baksluge": "bakslug",
    "baksluges": "bakslug",
    "bakslugheten": "bakslughet",
    "bakslughetens": "bakslughet",
    "bakslughets": "bakslughet",
    "bakslugs": "bakslug",
    "bakslugt": "bakslug",
    "bakslugts": "bakslug",
    "baksmäll": "baksmälla",
    "baksmällan": "baksmälla",
    "baksmällans": "baksmälla",
    "baksmällas": "baksmälla",
    "baksmälle": "baksmälla",
    "baksmällor": "baksmälla",
    "baksmällorna": "baksmälla",
    "baksmällornas": "baksmälla",
    "baksmällors": "baksmälla",
    "baksmälls": "baksmälla",
    "bakspåren": "bakspår",
    "bakspårens": "bakspår",
    "bakspåret": "bakspår",
    "bakspårets": "bakspår",
    "bakspårs": "bakspår",
    "baksträvar": "baksträvare",
    "baksträvaren": "baksträvare",
    "baksträvarens": "baksträvare",
    "baksträvares": "baksträvare",
    "baksträvarna": "baksträvare",
    "baksträvarnas": "baksträvare",
    "bakströmmar": "bakström",
    "bakströmmarna": "bakström",
    "bakströmmarnas": "bakström",
    "bakströmmars": "bakström",
    "bakströmmen": "bakström",
    "bakströmmens": "bakström",
    "bakströms": "bakström",
    "bakstycken": "bakstycke",
    "bakstyckena": "bakstycke",
    "bakstyckenas": "bakstycke",
    "bakstyckens": "bakstycke",
    "bakstyckes": "bakstycke",
    "bakstycket": "bakstycke",
    "bakstyckets": "bakstycke",
    "bakstycks": "bakstycke",
    "baksäten": "baksäte",
    "baksätena": "baksäte",
    "baksätenas": "baksäte",
    "baksätens": "baksäte",
    "baksätes": "baksäte",
    "baksätet": "baksäte",
    "baksätets": "baksäte",
    "baktalad": "baktala",
    "baktalade": "baktala",
    "baktalades": "baktala",
    "baktalads": "baktala",
    "baktalande": "baktala",
    "baktalanden": "baktalande",
    "baktalandena": "baktalande",
    "baktalandenas": "baktalande",
    "baktalandens": "baktalande",
    "baktalandes": "baktalande",
    "baktalandet": "baktalande",
    "baktalandets": "baktalande",
    "baktalar": "baktala",
    "baktalas": "baktala",
    "baktalat": "baktala",
    "baktalats": "baktala",
    "baktalet": "baktal",
    "baktalets": "baktal",
    "baktals": "baktal",
    "baktank": "baktanke",
    "baktankar": "baktanke",
    "baktankarna": "baktanke",
    "baktankarnas": "baktanke",
    "baktankars": "baktanke",
    "baktanken": "baktanke",
    "baktankens": "baktanke",
    "baktankes": "baktanke",
    "baktanks": "baktanke",
    "baktassar": "baktass",
    "baktassarna": "baktass",
    "baktassarnas": "baktass",
    "baktassars": "baktass",
    "baktassen": "baktass",
    "baktassens": "baktass",
    "baktericida": "baktericid",
    "baktericidare": "baktericid",
    "baktericidares": "baktericid",
    "baktericidas": "baktericid",
    "baktericidast": "baktericid",
    "baktericidaste": "baktericid",
    "baktericidastes": "baktericid",
    "baktericidasts": "baktericid",
    "baktericide": "baktericid",
    "baktericiden": "baktericid",
    "baktericidens": "baktericid",
    "baktericider": "baktericid",
    "baktericiderna": "baktericid",
    "baktericidernas": "baktericid",
    "baktericiders": "baktericid",
    "baktericides": "baktericid",
    "baktericids": "baktericid",
    "bakteriearten": "bakterieart",
    "bakterieartens": "bakterieart",
    "bakteriearter": "bakterieart",
    "bakteriearterna": "bakterieart",
    "bakteriearternas": "bakterieart",
    "bakteriearters": "bakterieart",
    "bakteriearts": "bakterieart",
    "bakteriehärdar": "bakteriehärd",
    "bakteriehärdarna": "bakteriehärd",
    "bakteriehärdarnas": "bakteriehärd",
    "bakteriehärdars": "bakteriehärd",
    "bakteriehärden": "bakteriehärd",
    "bakteriehärdens": "bakteriehärd",
    "bakteriehärds": "bakteriehärd",
    "bakterieinfektionen": "bakterieinfektion",
    "bakterieinfektionens": "bakterieinfektion",
    "bakterieinfektioner": "bakterieinfektion",
    "bakterieinfektionerna": "bakterieinfektion",
    "bakterieinfektionernas": "bakterieinfektion",
    "bakterieinfektioners": "bakterieinfektion",
    "bakterieinfektions": "bakterieinfektion",
    "bakteriekulturen": "bakteriekultur",
    "bakteriekulturens": "bakteriekultur",
    "bakteriekulturer": "bakteriekultur",
    "bakteriekulturerna": "bakteriekultur",
    "bakteriekulturernas": "bakteriekultur",
    "bakteriekulturers": "bakteriekultur",
    "bakteriekulturs": "bakteriekultur",
    "bakterien": "bakterie",
    "bakteriens": "bakterie",
    "bakterier": "bakterie",
    "bakterierna": "bakterie",
    "bakteriernas": "bakterie",
    "bakteriers": "bakterie",
    "bakteries": "bakterie",
    "bakteriesmittade": "bakteriesmittad",
    "bakteriesmittades": "bakteriesmittad",
    "bakteriesmittads": "bakteriesmittad",
    "bakteriesmittat": "bakteriesmittad",
    "bakteriesmittats": "bakteriesmittad",
    "bakteriofagen": "bakteriofag",
    "bakteriofagens": "bakteriofag",
    "bakteriofager": "bakteriofag",
    "bakteriofagerna": "bakteriofag",
    "bakteriofagernas": "bakteriofag",
    "bakteriofagers": "bakteriofag",
    "bakteriofags": "bakteriofag",
    "bakteriologen": "bakteriolog",
    "bakteriologens": "bakteriolog",
    "bakteriologer": "bakteriolog",
    "bakteriologerna": "bakteriolog",
    "bakteriologernas": "bakteriolog",
    "bakteriologers": "bakteriolog",
    "bakteriologien": "bakteriologi",
    "bakteriologiens": "bakteriologi",
    "bakteriologin": "bakteriologi",
    "bakteriologins": "bakteriologi",
    "bakteriologis": "bakteriologi",
    "bakteriologiska": "bakteriologisk",
    "bakteriologiskare": "bakteriologisk",
    "bakteriologiskares": "bakteriologisk",
    "bakteriologiskas": "bakteriologisk",
    "bakteriologiskast": "bakteriologisk",
    "bakteriologiskaste": "bakteriologisk",
    "bakteriologiskastes": "bakteriologisk",
    "bakteriologiskasts": "bakteriologisk",
    "bakteriologiske": "bakteriologisk",
    "bakteriologiskes": "bakteriologisk",
    "bakteriologisks": "bakteriologisk",
    "bakteriologiskt": "bakteriologisk",
    "bakteriologiskts": "bakteriologisk",
    "bakteriologs": "bakteriolog",
    "baktunga": "baktung",
    "baktungare": "baktung",
    "baktungares": "baktung",
    "baktungas": "baktung",
    "baktungast": "baktung",
    "baktungaste": "baktung",
    "baktungastes": "baktung",
    "baktungasts": "baktung",
    "baktunge": "baktung",
    "baktunges": "baktung",
    "baktungheten": "baktunghet",
    "baktunghetens": "baktunghet",
    "baktunghets": "baktunghet",
    "baktungs": "baktung",
    "baktungt": "baktung",
    "baktungts": "baktung",
    "bakugnar": "bakugn",
    "bakugnarna": "bakugn",
    "bakugnarnas": "bakugn",
    "bakugnars": "bakugn",
    "bakugnen": "bakugn",
    "bakugnens": "bakugn",
    "bakugns": "bakugn",
    "bakvattens": "bakvatten",
    "bakvattnen": "bakvatten",
    "bakvattnens": "bakvatten",
    "bakvattnet": "bakvatten",
    "bakvattnets": "bakvatten",
    "bakverken": "bakverk",
    "bakverkens": "bakverk",
    "bakverket": "bakverk",
    "bakverkets": "bakverk",
    "bakverks": "bakverk",
    "bakvikten": "bakvikt",
    "bakviktens": "bakvikt",
    "bakvikter": "bakvikt",
    "bakvikterna": "bakvikt",
    "bakvikternas": "bakvikt",
    "bakvikters": "bakvikt",
    "bakvikts": "bakvikt",
    "bakvägar": "bakväg",
    "bakvägarna": "bakväg",
    "bakvägarnas": "bakväg",
    "bakvägars": "bakväg",
    "bakvägen": "bakväg",
    "bakvägens": "bakväg",
    "bakvägs": "bakväg",
    "bakvända": "bakvänd",
    "bakvändare": "bakvänd",
    "bakvändares": "bakvänd",
    "bakvändas": "bakvänd",
    "bakvändast": "bakvänd",
    "bakvändaste": "bakvänd",
    "bakvändastes": "bakvänd",
    "bakvändasts": "bakvänd",
    "bakvände": "bakvänd",
    "bakvändes": "bakvänd",
    "bakvändheten": "bakvändhet",
    "bakvändhetens": "bakvändhet",
    "bakvändhets": "bakvändhet",
    "bakvänds": "bakvänd",
    "bakvänt": "bakvänd",
    "bakvänts": "bakvänd",
    "bakänd": "bakända",
    "bakändan": "bakända",
    "bakändans": "bakända",
    "bakändar": "bakände",
    "bakändarna": "bakände",
    "bakändarnas": "bakände",
    "bakändars": "bakände",
    "bakändas": "bakända",
    "bakände": "bakända",
    "bakänden": "bakände",
    "bakändens": "bakände",
    "bakändes": "bakände",
    "bakändor": "bakända",
    "bakändorna": "bakända",
    "bakändornas": "bakända",
    "bakändors": "bakända",
    "bakänds": "bakända",
    "bakåtkammade": "bakåtkammad",
    "bakåtkammades": "bakåtkammad",
    "bakåtkammads": "bakåtkammad",
    "bakåtkammat": "bakåtkammad",
    "bakåtkammats": "bakåtkammad",
    "bakåtlutade": "bakåtlutad",
    "bakåtlutades": "bakåtlutad",
    "bakåtlutads": "bakåtlutad",
    "bakåtlutat": "bakåtlutad",
    "bakåtlutats": "bakåtlutad",
    "bakåtriktade": "bakåtriktad",
    "bakåtriktades": "bakåtriktad",
    "bakåtriktads": "bakåtriktad",
    "bakåtriktat": "bakåtriktad",
    "bakåtriktats": "bakåtriktad",
    "bakåtsträvar": "bakåtsträvare",
    "bakåtsträvaren": "bakåtsträvare",
    "bakåtsträvarens": "bakåtsträvare",
    "bakåtsträvares": "bakåtsträvare",
    "bakåtsträvarna": "bakåtsträvare",
    "bakåtsträvarnas": "bakåtsträvare",
    "bal": "bale",
    "balad": "bala",
    "balade": "bala",
    "balades": "bala",
    "balads": "bala",
    "balalajk": "balalajka",
    "balalajkan": "balalajka",
    "balalajkans": "balalajka",
    "balalajkas": "balalajka",
    "balalajke": "balalajka",
    "balalajkor": "balalajka",
    "balalajkorna": "balalajka",
    "balalajkornas": "balalajka",
    "balalajkors": "balalajka",
    "balalajks": "balalajka",
    "balande": "bala",
    "balanden": "balande",
    "balandena": "balande",
    "balandenas": "balande",
    "balandens": "balande",
    "balandes": "balande",
    "balandet": "balande",
    "balandets": "balande",
    "balansakten": "balansakt",
    "balansaktens": "balansakt",
    "balansakter": "balansakt",
    "balansakterna": "balansakt",
    "balansakternas": "balansakt",
    "balansakters": "balansakt",
    "balansakts": "balansakt",
    "balansen": "balans",
    "balansens": "balans",
    "balanser": "balans",
    "balanserad": "balansera",
    "balanserade": "balanserad",
    "balanserades": "balanserad",
    "balanserads": "balanserad",
    "balanserande": "balansera",
    "balanseranden": "balanserande",
    "balanserandena": "balanserande",
    "balanserandenas": "balanserande",
    "balanserandens": "balanserande",
    "balanserandes": "balanserande",
    "balanserandet": "balanserande",
    "balanserandets": "balanserande",
    "balanserar": "balansera",
    "balanseras": "balansera",
    "balanserat": "balanserad",
    "balanserats": "balanserad",
    "balanserbara": "balanserbar",
    "balanserbarare": "balanserbar",
    "balanserbarares": "balanserbar",
    "balanserbaras": "balanserbar",
    "balanserbarast": "balanserbar",
    "balanserbaraste": "balanserbar",
    "balanserbarastes": "balanserbar",
    "balanserbarasts": "balanserbar",
    "balanserbare": "balanserbar",
    "balanserbares": "balanserbar",
    "balanserbarheten": "balanserbarhet",
    "balanserbarhetens": "balanserbarhet",
    "balanserbarhets": "balanserbarhet",
    "balanserbars": "balanserbar",
    "balanserbart": "balanserbar",
    "balanserbarts": "balanserbar",
    "balanseringar": "balansering",
    "balanseringarna": "balansering",
    "balanseringarnas": "balansering",
    "balanseringars": "balansering",
    "balanseringen": "balansering",
    "balanseringens": "balansering",
    "balanserings": "balansering",
    "balanserna": "balans",
    "balansernas": "balans",
    "balansers": "balans",
    "balanserstänger": "balanserstång",
    "balanserstängerna": "balanserstång",
    "balanserstängernas": "balanserstång",
    "balanserstängers": "balanserstång",
    "balanserstången": "balanserstång",
    "balanserstångens": "balanserstång",
    "balanserstångs": "balanserstång",
    "balansgången": "balansgång",
    "balansgångens": "balansgång",
    "balansgångs": "balansgång",
    "balanshjulen": "balanshjul",
    "balanshjulens": "balanshjul",
    "balanshjulet": "balanshjul",
    "balanshjulets": "balanshjul",
    "balanshjuls": "balanshjul",
    "balanskonstnären": "balanskonstnär",
    "balanskonstnärens": "balanskonstnär",
    "balanskonstnärer": "balanskonstnär",
    "balanskonstnärerna": "balanskonstnär",
    "balanskonstnärernas": "balanskonstnär",
    "balanskonstnärers": "balanskonstnär",
    "balanskonstnärs": "balanskonstnär",
    "balanskonton": "balanskonto",
    "balanskontona": "balanskonto",
    "balanskontonas": "balanskonto",
    "balanskontons": "balanskonto",
    "balanskontos": "balanskonto",
    "balanskontot": "balanskonto",
    "balanskontots": "balanskonto",
    "balansnummerna": "balansnummer",
    "balansnummernas": "balansnummer",
    "balansnummers": "balansnummer",
    "balansnumren": "balansnummer",
    "balansnumrens": "balansnummer",
    "balansnumret": "balansnummer",
    "balansnumrets": "balansnummer",
    "balansorganen": "balansorgan",
    "balansorganens": "balansorgan",
    "balansorganet": "balansorgan",
    "balansorganets": "balansorgan",
    "balansorgans": "balansorgan",
    "balansplogar": "balansplog",
    "balansplogarna": "balansplog",
    "balansplogarnas": "balansplog",
    "balansplogars": "balansplog",
    "balansplogen": "balansplog",
    "balansplogens": "balansplog",
    "balansplogs": "balansplog",
    "balansroderna": "balansroder",
    "balansrodernas": "balansroder",
    "balansroders": "balansroder",
    "balansrodren": "balansroder",
    "balansrodrens": "balansroder",
    "balansrodret": "balansroder",
    "balansrodrets": "balansroder",
    "balansrubbningar": "balansrubbning",
    "balansrubbningarna": "balansrubbning",
    "balansrubbningarnas": "balansrubbning",
    "balansrubbningars": "balansrubbning",
    "balansrubbningen": "balansrubbning",
    "balansrubbningens": "balansrubbning",
    "balansrubbnings": "balansrubbning",
    "balansräkningar": "balansräkning",
    "balansräkningarna": "balansräkning",
    "balansräkningarnas": "balansräkning",
    "balansräkningars": "balansräkning",
    "balansräkningen": "balansräkning",
    "balansräkningens": "balansräkning",
    "balansräknings": "balansräkning",
    "balanssinnes": "balanssinne",
    "balanssinnet": "balanssinne",
    "balanssinnets": "balanssinne",
    "balansvågar": "balansvåg",
    "balansvågarna": "balansvåg",
    "balansvågarnas": "balansvåg",
    "balansvågars": "balansvåg",
    "balansvågen": "balansvåg",
    "balansvågens": "balansvåg",
    "balansvågs": "balansvåg",
    "balar": "bale",
    "balarna": "bale",
    "balarnas": "bale",
    "balars": "bale",
    "balas": "bala",
    "balat": "bala",
    "balatan": "balata",
    "balatans": "balata",
    "balatas": "balata",
    "balats": "bala",
    "baldakinen": "baldakin",
    "baldakinens": "baldakin",
    "baldakiner": "baldakin",
    "baldakinerna": "baldakin",
    "baldakinernas": "baldakin",
    "baldakiners": "baldakin",
    "baldakins": "baldakin",
    "baldersbrån": "baldersbrå",
    "baldersbråna": "baldersbrå",
    "baldersbrånas": "baldersbrå",
    "baldersbråns": "baldersbrå",
    "baldersbrår": "baldersbrå",
    "baldersbrårna": "baldersbrå",
    "baldersbrårnas": "baldersbrå",
    "baldersbrårs": "baldersbrå",
    "baldersbrås": "baldersbrå",
    "baldersbråt": "baldersbrå",
    "baldersbråts": "baldersbrå",
    "balen": "bale",
    "balens": "bale",
    "baler": "bal",
    "balerna": "bal",
    "balernas": "bal",
    "balers": "bal",
    "bales": "bale",
    "balettdansen": "balettdans",
    "balettdansens": "balettdans",
    "balettdanser": "balettdans",
    "balettdanserna": "balettdans",
    "balettdansernas": "balettdans",
    "balettdansers": "balettdans",
    "balettdansösen": "balettdansös",
    "balettdansösens": "balettdansös",
    "balettdansöser": "balettdansös",
    "balettdansöserna": "balettdansös",
    "balettdansösernas": "balettdansös",
    "balettdansösers": "balettdansös",
    "baletten": "balett",
    "balettens": "balett",
    "baletter": "balett",
    "baletterna": "balett",
    "baletternas": "balett",
    "baletters": "balett",
    "balettmästar": "balettmästare",
    "balettmästaren": "balettmästare",
    "balettmästarens": "balettmästare",
    "balettmästares": "balettmästare",
    "balettmästarna": "balettmästare",
    "balettmästarnas": "balettmästare",
    "baletts": "balett",
    "balj": "balja",
    "baljan": "balja",
    "baljans": "balja",
    "baljas": "balja",
    "balje": "balja",
    "baljor": "balja",
    "baljorna": "balja",
    "baljornas": "balja",
    "baljors": "balja",
    "baljs": "balja",
    "baljväxten": "baljväxt",
    "baljväxtens": "baljväxt",
    "baljväxter": "baljväxt",
    "baljväxterna": "baljväxt",
    "baljväxternas": "baljväxt",
    "baljväxters": "baljväxt",
    "baljväxts": "baljväxt",
    "balkanfolken": "balkanfolk",
    "balkanfolkens": "balkanfolk",
    "balkanfolket": "balkanfolk",
    "balkanfolkets": "balkanfolk",
    "balkanfolks": "balkanfolk",
    "balkaniserade": "balkaniserad",
    "balkaniserades": "balkaniserad",
    "balkaniserads": "balkaniserad",
    "balkaniserat": "balkaniserad",
    "balkaniserats": "balkaniserad",
    "balkaniseringar": "balkanisering",
    "balkaniseringarna": "balkanisering",
    "balkaniseringarnas": "balkanisering",
    "balkaniseringars": "balkanisering",
    "balkaniseringen": "balkanisering",
    "balkaniseringens": "balkanisering",
    "balkaniserings": "balkanisering",
    "balkanländernas": "balkanländerna",
    "balkar": "balk",
    "balkarna": "balk",
    "balkarnas": "balk",
    "balkars": "balk",
    "balken": "balk",
    "balkens": "balk",
    "balkknäet": "balkknä",
    "balkknäets": "balkknä",
    "balkknän": "balkknä",
    "balkknäna": "balkknä",
    "balkknänas": "balkknä",
    "balkknäns": "balkknä",
    "balkknäs": "balkknä",
    "balkknät": "balkknä",
    "balkknäts": "balkknä",
    "balkmåtten": "balkmått",
    "balkmåttens": "balkmått",
    "balkmåttet": "balkmått",
    "balkmåttets": "balkmått",
    "balkmåtts": "balkmått",
    "balkongen": "balkong",
    "balkongens": "balkong",
    "balkonger": "balkong",
    "balkongerna": "balkong",
    "balkongernas": "balkong",
    "balkongers": "balkong",
    "balkongs": "balkong",
    "balks": "balk",
    "balkskon": "balksko",
    "balkskons": "balksko",
    "balkskor": "balksko",
    "balkskorna": "balksko",
    "balkskornas": "balksko",
    "balkskors": "balksko",
    "balkskos": "balksko",
    "balkverken": "balkverk",
    "balkverkens": "balkverk",
    "balkverket": "balkverk",
    "balkverkets": "balkverk",
    "balkverks": "balkverk",
    "balkvägar": "balkvägare",
    "balkvägaren": "balkvägare",
    "balkvägarens": "balkvägare",
    "balkvägares": "balkvägare",
    "balkvägarna": "balkvägare",
    "balkvägarnas": "balkvägare",
    "ball": "balle",
    "balla": "ball",
    "balladen": "ballad",
    "balladens": "ballad",
    "ballader": "ballad",
    "balladerna": "ballad",
    "balladernas": "ballad",
    "balladers": "ballad",
    "ballads": "ballad",
    "ballar": "balle",
    "ballare": "ball",
    "ballares": "ball",
    "ballarna": "balle",
    "ballarnas": "balle",
    "ballars": "balle",
    "ballas": "ball",
    "ballast": "ball",
    "ballaste": "ball",
    "ballasten": "ballast",
    "ballastens": "ballast",
    "ballaster": "ballast",
    "ballasterna": "ballast",
    "ballasternas": "ballast",
    "ballasters": "ballast",
    "ballastes": "ball",
    "ballasts": "ballast",
    "balle": "ball",
    "ballen": "balle",
    "ballens": "balle",
    "ballerin": "ballerina",
    "ballerinan": "ballerina",
    "ballerinans": "ballerina",
    "ballerinas": "ballerina",
    "ballerine": "ballerina",
    "ballerinor": "ballerina",
    "ballerinorna": "ballerina",
    "ballerinornas": "ballerina",
    "ballerinors": "ballerina",
    "ballerins": "ballerina",
    "balles": "balle",
    "ballheten": "ballhet",
    "ballhetens": "ballhet",
    "ballhets": "ballhet",
    "ballistiken": "ballistik",
    "ballistikens": "ballistik",
    "ballistiks": "ballistik",
    "ballongbluffar": "ballongbluff",
    "ballongbluffarna": "ballongbluff",
    "ballongbluffarnas": "ballongbluff",
    "ballongbluffars": "ballongbluff",
    "ballongbluffen": "ballongbluff",
    "ballongbluffens": "ballongbluff",
    "ballongbluffs": "ballongbluff",
    "ballongbollar": "ballongboll",
    "ballongbollarna": "ballongboll",
    "ballongbollarnas": "ballongboll",
    "ballongbollars": "ballongboll",
    "ballongbollen": "ballongboll",
    "ballongbollens": "ballongboll",
    "ballongbolls": "ballongboll",
    "ballongburens": "ballongburen",
    "ballongburet": "ballongburen",
    "ballongburets": "ballongburen",
    "ballongburna": "ballongburen",
    "ballongburnas": "ballongburen",
    "ballongburne": "ballongburen",
    "ballongburnes": "ballongburen",
    "ballongdäcken": "ballongdäck",
    "ballongdäckens": "ballongdäck",
    "ballongdäcket": "ballongdäck",
    "ballongdäckets": "ballongdäck",
    "ballongdäcks": "ballongdäck",
    "ballongen": "ballong",
    "ballongens": "ballong",
    "ballonger": "ballong",
    "ballongerna": "ballong",
    "ballongernas": "ballong",
    "ballongers": "ballong",
    "ballongfamiljen": "ballongfamilj",
    "ballongfamiljens": "ballongfamilj",
    "ballongfamiljer": "ballongfamilj",
    "ballongfamiljerna": "ballongfamilj",
    "ballongfamiljernas": "ballongfamilj",
    "ballongfamiljers": "ballongfamilj",
    "ballongfamiljs": "ballongfamilj",
    "ballonggasen": "ballonggas",
    "ballonggasens": "ballonggas",
    "ballonggaser": "ballonggas",
    "ballonggaserna": "ballonggas",
    "ballonggasernas": "ballonggas",
    "ballonggasers": "ballonggas",
    "ballongmagar": "ballongmage",
    "ballongmagarna": "ballongmage",
    "ballongmagarnas": "ballongmage",
    "ballongmagars": "ballongmage",
    "ballongmagen": "ballongmage",
    "ballongmagens": "ballongmage",
    "ballongmages": "ballongmage",
    "ballongpojk": "ballongpojke",
    "ballongpojkar": "ballongpojke",
    "ballongpojkarna": "ballongpojke",
    "ballongpojkarnas": "ballongpojke",
    "ballongpojkars": "ballongpojke",
    "ballongpojken": "ballongpojke",
    "ballongpojkens": "ballongpojke",
    "ballongpojkes": "ballongpojke",
    "ballongpojks": "ballongpojke",
    "ballongprickar": "ballongprick",
    "ballongprickarna": "ballongprick",
    "ballongprickarnas": "ballongprick",
    "ballongprickars": "ballongprick",
    "ballongpricken": "ballongprick",
    "ballongprickens": "ballongprick",
    "ballongpricks": "ballongprick",
    "ballongs": "ballong",
    "ballongsegels": "ballongsegel",
    "ballongseglen": "ballongsegel",
    "ballongseglens": "ballongsegel",
    "ballongseglet": "ballongsegel",
    "ballongseglets": "ballongsegel",
    "balloptikonen": "balloptikon",
    "balloptikonens": "balloptikon",
    "balloptikonet": "balloptikon",
    "balloptikonets": "balloptikon",
    "balloptikons": "balloptikon",
    "balloterad": "ballotera",
    "balloterade": "ballotera",
    "balloterades": "ballotera",
    "balloterads": "ballotera",
    "balloterande": "ballotera",
    "balloteranden": "balloterande",
    "balloterandena": "balloterande",
    "balloterandenas": "balloterande",
    "balloterandens": "balloterande",
    "balloterandes": "balloterande",
    "balloterandet": "balloterande",
    "balloterandets": "balloterande",
    "balloterar": "ballotera",
    "balloteras": "ballotera",
    "balloterat": "ballotera",
    "balloterats": "ballotera",
    "balloterbara": "balloterbar",
    "balloterbarare": "balloterbar",
    "balloterbarares": "balloterbar",
    "balloterbaras": "balloterbar",
    "balloterbarast": "balloterbar",
    "balloterbaraste": "balloterbar",
    "balloterbarastes": "balloterbar",
    "balloterbarasts": "balloterbar",
    "balloterbare": "balloterbar",
    "balloterbares": "balloterbar",
    "balloterbarheten": "balloterbarhet",
    "balloterbarhetens": "balloterbarhet",
    "balloterbarhets": "balloterbarhet",
    "balloterbars": "balloterbar",
    "balloterbart": "balloterbar",
    "balloterbarts": "balloterbar",
    "balloteringar": "ballotering",
    "balloteringarna": "ballotering",
    "balloteringarnas": "ballotering",
    "balloteringars": "ballotering",
    "balloteringen": "ballotering",
    "balloteringens": "ballotering",
    "balloterings": "ballotering",
    "balls": "balle",
    "ballt": "ball",
    "ballts": "ball",
    "balneologen": "balneolog",
    "balneologens": "balneolog",
    "balneologer": "balneolog",
    "balneologerna": "balneolog",
    "balneologernas": "balneolog",
    "balneologers": "balneolog",
    "balneologien": "balneologi",
    "balneologiens": "balneologi",
    "balneologin": "balneologi",
    "balneologins": "balneologi",
    "balneologis": "balneologi",
    "balneologs": "balneolog",
    "bals": "balsa",
    "balsalar": "balsal",
    "balsalarna": "balsal",
    "balsalarnas": "balsal",
    "balsalars": "balsal",
    "balsalen": "balsal",
    "balsalens": "balsal",
    "balsals": "balsal",
    "balsamen": "balsam",
    "balsamens": "balsam",
    "balsamer": "balsam",
    "balsamerad": "balsamera",
    "balsamerade": "balsamera",
    "balsamerades": "balsamera",
    "balsamerads": "balsamera",
    "balsamerande": "balsamera",
    "balsameranden": "balsamerande",
    "balsamerandena": "balsamerande",
    "balsamerandenas": "balsamerande",
    "balsamerandens": "balsamerande",
    "balsamerandes": "balsamerande",
    "balsamerandet": "balsamerande",
    "balsamerandets": "balsamerande",
    "balsamerar": "balsamera",
    "balsameras": "balsamera",
    "balsamerat": "balsamera",
    "balsamerats": "balsamera",
    "balsamerbara": "balsamerbar",
    "balsamerbarare": "balsamerbar",
    "balsamerbarares": "balsamerbar",
    "balsamerbaras": "balsamerbar",
    "balsamerbarast": "balsamerbar",
    "balsamerbaraste": "balsamerbar",
    "balsamerbarastes": "balsamerbar",
    "balsamerbarasts": "balsamerbar",
    "balsamerbare": "balsamerbar",
    "balsamerbares": "balsamerbar",
    "balsamerbarheten": "balsamerbarhet",
    "balsamerbarhetens": "balsamerbarhet",
    "balsamerbarhets": "balsamerbarhet",
    "balsamerbars": "balsamerbar",
    "balsamerbart": "balsamerbar",
    "balsamerbarts": "balsamerbar",
    "balsameringar": "balsamering",
    "balsameringarna": "balsamering",
    "balsameringarnas": "balsamering",
    "balsameringars": "balsamering",
    "balsameringen": "balsamering",
    "balsameringens": "balsamering",
    "balsamerings": "balsamering",
    "balsamerna": "balsam",
    "balsamernas": "balsam",
    "balsamers": "balsam",
    "balsaminen": "balsamin",
    "balsaminens": "balsamin",
    "balsaminer": "balsamin",
    "balsaminerna": "balsamin",
    "balsaminernas": "balsamin",
    "balsaminers": "balsamin",
    "balsamins": "balsamin",
    "balsamiska": "balsamisk",
    "balsamiskare": "balsamisk",
    "balsamiskares": "balsamisk",
    "balsamiskas": "balsamisk",
    "balsamiskast": "balsamisk",
    "balsamiskaste": "balsamisk",
    "balsamiskastes": "balsamisk",
    "balsamiskasts": "balsamisk",
    "balsamiske": "balsamisk",
    "balsamiskes": "balsamisk",
    "balsamisks": "balsamisk",
    "balsamiskt": "balsamisk",
    "balsamiskts": "balsamisk",
    "balsams": "balsam",
    "balsamterpentinen": "balsamterpentin",
    "balsamterpentinens": "balsamterpentin",
    "balsamterpentiner": "balsamterpentin",
    "balsamterpentinerna": "balsamterpentin",
    "balsamterpentinernas": "balsamterpentin",
    "balsamterpentiners": "balsamterpentin",
    "balsamterpentins": "balsamterpentin",
    "balsan": "balsa",
    "balsans": "balsa",
    "balsas": "balsa",
    "balsaträet": "balsaträ",
    "balsaträets": "balsaträ",
    "balsaträs": "balsaträ",
    "balsaträt": "balsaträ",
    "balsaträts": "balsaträ",
    "balse": "balsa",
    "balsor": "balsa",
    "balsorna": "balsa",
    "balsornas": "balsa",
    "balsors": "balsa",
    "balten": "balt",
    "baltens": "balt",
    "balter": "balt",
    "balterna": "balt",
    "balternas": "balt",
    "balters": "balt",
    "baltiska": "baltisk",
    "baltiskan": "baltiska",
    "baltiskans": "baltiska",
    "baltiskare": "baltisk",
    "baltiskares": "baltisk",
    "baltiskas": "baltiska",
    "baltiskast": "baltisk",
    "baltiskaste": "baltisk",
    "baltiskastes": "baltisk",
    "baltiskasts": "baltisk",
    "baltiske": "baltiska",
    "baltiskes": "baltisk",
    "baltiskor": "baltiska",
    "baltiskorna": "baltiska",
    "baltiskornas": "baltiska",
    "baltiskors": "baltiska",
    "baltisks": "baltisk",
    "baltiskt": "baltisk",
    "baltiskts": "baltisk",
    "balts": "balt",
    "baltutlämningar": "baltutlämning",
    "baltutlämningarna": "baltutlämning",
    "baltutlämningarnas": "baltutlämning",
    "baltutlämningars": "baltutlämning",
    "baltutlämningen": "baltutlämning",
    "baltutlämningens": "baltutlämning",
    "baltutlämnings": "baltutlämning",
    "balunsen": "baluns",
    "balunsens": "baluns",
    "balunser": "baluns",
    "balunserna": "baluns",
    "balunsernas": "baluns",
    "balunsers": "baluns",
    "balustern": "baluster",
    "balusterns": "baluster",
    "balusters": "baluster",
    "balustraden": "balustrad",
    "balustradens": "balustrad",
    "balustrader": "balustrad",
    "balustraderna": "balustrad",
    "balustradernas": "balustrad",
    "balustraders": "balustrad",
    "balustrads": "balustrad",
    "balustrar": "baluster",
    "balustrarna": "baluster",
    "balustrarnas": "baluster",
    "balustrars": "baluster",
    "balustrer": "baluster",
    "balustrerna": "baluster",
    "balustrernas": "baluster",
    "balustrers": "baluster",
    "bamban": "bamba",
    "bambans": "bamba",
    "bambas": "bamba",
    "bambor": "bamba",
    "bamborna": "bamba",
    "bambornas": "bamba",
    "bambors": "bamba",
    "bambun": "bambu",
    "bambuns": "bambu",
    "bamburören": "bamburör",
    "bamburörens": "bamburör",
    "bamburöret": "bamburör",
    "bamburörets": "bamburör",
    "bamburörs": "bamburör",
    "bambus": "bambu",
    "bambusoff": "bambusoffa",
    "bambusoffan": "bambusoffa",
    "bambusoffans": "bambusoffa",
    "bambusoffas": "bambusoffa",
    "bambusoffe": "bambusoffa",
    "bambusoffor": "bambusoffa",
    "bambusofforna": "bambusoffa",
    "bambusoffornas": "bambusoffa",
    "bambusoffors": "bambusoffa",
    "bambusoffs": "bambusoffa",
    "ban": "bana",
    "banala": "banal",
    "banalare": "banal",
    "banalares": "banal",
    "banalas": "banal",
    "banalast": "banal",
    "banalaste": "banal",
    "banalastes": "banal",
    "banalasts": "banal",
    "banale": "banal",
    "banales": "banal",
    "banaliserad": "banalisera",
    "banaliserade": "banalisera",
    "banaliserades": "banalisera",
    "banaliserads": "banalisera",
    "banaliserande": "banalisera",
    "banaliseranden": "banaliserande",
    "banaliserandena": "banaliserande",
    "banaliserandenas": "banaliserande",
    "banaliserandens": "banaliserande",
    "banaliserandes": "banaliserande",
    "banaliserandet": "banaliserande",
    "banaliserandets": "banaliserande",
    "banaliserar": "banalisera",
    "banaliseras": "banalisera",
    "banaliserat": "banalisera",
    "banaliserats": "banalisera",
    "banaliserbara": "banaliserbar",
    "banaliserbarare": "banaliserbar",
    "banaliserbarares": "banaliserbar",
    "banaliserbaras": "banaliserbar",
    "banaliserbarast": "banaliserbar",
    "banaliserbaraste": "banaliserbar",
    "banaliserbarastes": "banaliserbar",
    "banaliserbarasts": "banaliserbar",
    "banaliserbare": "banaliserbar",
    "banaliserbares": "banaliserbar",
    "banaliserbarheten": "banaliserbarhet",
    "banaliserbarhetens": "banaliserbarhet",
    "banaliserbarhets": "banaliserbarhet",
    "banaliserbars": "banaliserbar",
    "banaliserbart": "banaliserbar",
    "banaliserbarts": "banaliserbar",
    "banaliseringar": "banalisering",
    "banaliseringarna": "banalisering",
    "banaliseringarnas": "banalisering",
    "banaliseringars": "banalisering",
    "banaliseringen": "banalisering",
    "banaliseringens": "banalisering",
    "banaliserings": "banalisering",
    "banaliteten": "banalitet",
    "banalitetens": "banalitet",
    "banaliteter": "banalitet",
    "banaliteterna": "banalitet",
    "banaliteternas": "banalitet",
    "banaliteters": "banalitet",
    "banalitets": "banalitet",
    "banals": "banal",
    "banalt": "banal",
    "banalts": "banal",
    "banan": "bana",
    "bananen": "banan",
    "bananens": "banan",
    "bananer": "banan",
    "bananerna": "banan",
    "bananernas": "banan",
    "bananers": "banan",
    "bananflug": "bananfluga",
    "bananflugan": "bananfluga",
    "bananflugans": "bananfluga",
    "bananflugas": "bananfluga",
    "bananfluge": "bananfluga",
    "bananflugor": "bananfluga",
    "bananflugorna": "bananfluga",
    "bananflugornas": "bananfluga",
    "bananflugors": "bananfluga",
    "bananflugs": "bananfluga",
    "banankontakten": "banankontakt",
    "banankontaktens": "banankontakt",
    "banankontakter": "banankontakt",
    "banankontakterna": "banankontakt",
    "banankontakternas": "banankontakt",
    "banankontakters": "banankontakt",
    "banankontakts": "banankontakt",
    "bananrepubliken": "bananrepublik",
    "bananrepublikens": "bananrepublik",
    "bananrepubliker": "bananrepublik",
    "bananrepublikerna": "bananrepublik",
    "bananrepublikernas": "bananrepublik",
    "bananrepublikers": "bananrepublik",
    "bananrepubliks": "bananrepublik",
    "banans": "banan",
    "bananstockar": "bananstock",
    "bananstockarna": "bananstock",
    "bananstockarnas": "bananstock",
    "bananstockars": "bananstock",
    "bananstocken": "bananstock",
    "bananstockens": "bananstock",
    "bananstocks": "bananstock",
    "banar": "ban",
    "banarna": "ban",
    "banarnas": "ban",
    "banars": "ban",
    "banas": "bana",
    "banbrytar": "banbrytare",
    "banbrytaren": "banbrytare",
    "banbrytarens": "banbrytare",
    "banbrytares": "banbrytare",
    "banbrytarna": "banbrytare",
    "banbrytarnas": "banbrytare",
    "bancos": "banco",
    "band": "binda",
    "bandad": "banda",
    "bandade": "banda",
    "bandades": "banda",
    "bandads": "banda",
    "bandagen": "bandage",
    "bandagens": "bandage",
    "bandages": "bandage",
    "bandaget": "bandage",
    "bandagets": "bandage",
    "bandande": "banda",
    "bandanden": "bandande",
    "bandandena": "bandande",
    "bandandenas": "bandande",
    "bandandens": "bandande",
    "bandandes": "bandande",
    "bandandet": "bandande",
    "bandandets": "bandande",
    "bandar": "banda",
    "bandas": "banda",
    "bandat": "banda",
    "bandats": "banda",
    "banden": "band",
    "bandens": "band",
    "banderolen": "banderol",
    "banderolens": "banderol",
    "banderoler": "banderol",
    "banderolerna": "banderol",
    "banderolernas": "banderol",
    "banderolers": "banderol",
    "banderollen": "banderoll",
    "banderollens": "banderoll",
    "banderoller": "banderoll",
    "banderollerna": "banderoll",
    "banderollernas": "banderoll",
    "banderollers": "banderoll",
    "banderolls": "banderoll",
    "banderols": "banderol",
    "bandet": "band",
    "bandets": "band",
    "bandfordonen": "bandfordon",
    "bandfordonens": "bandfordon",
    "bandfordonet": "bandfordon",
    "bandfordonets": "bandfordon",
    "bandfordons": "bandfordon",
    "bandgeneratorer": "bandgenerator",
    "bandgeneratorerna": "bandgenerator",
    "bandgeneratorernas": "bandgenerator",
    "bandgeneratorers": "bandgenerator",
    "bandgeneratorn": "bandgenerator",
    "bandgeneratorns": "bandgenerator",
    "bandgenerators": "bandgenerator",
    "bandhundar": "bandhund",
    "bandhundarna": "bandhund",
    "bandhundarnas": "bandhund",
    "bandhundars": "bandhund",
    "bandhunden": "bandhund",
    "bandhundens": "bandhund",
    "bandhunds": "bandhund",
    "banditen": "bandit",
    "banditens": "bandit",
    "banditer": "bandit",
    "banditerna": "bandit",
    "banditernas": "bandit",
    "banditers": "bandit",
    "banditgängen": "banditgäng",
    "banditgängens": "banditgäng",
    "banditgänget": "banditgäng",
    "banditgängets": "banditgäng",
    "banditgängs": "banditgäng",
    "bandits": "bandit",
    "bandmedlemmar": "bandmedlem",
    "bandmedlemmarna": "bandmedlem",
    "bandmedlemmarnas": "bandmedlem",
    "bandmedlemmars": "bandmedlem",
    "bandmedlemmen": "bandmedlem",
    "bandmedlemmens": "bandmedlem",
    "bandmedlems": "bandmedlem",
    "bandolären": "bandolär",
    "bandolärens": "bandolär",
    "bandoläret": "bandolär",
    "bandolärets": "bandolär",
    "bandolärs": "bandolär",
    "bandoteken": "bandotek",
    "bandotekens": "bandotek",
    "bandoteket": "bandotek",
    "bandotekets": "bandotek",
    "bandoteks": "bandotek",
    "bands": "binda",
    "bandspektra": "bandspektrum",
    "bandspektrana": "bandspektrum",
    "bandspektranas": "bandspektrum",
    "bandspektras": "bandspektrum",
    "bandspektrena": "bandspektrum",
    "bandspektrenas": "bandspektrum",
    "bandspektrer": "bandspektrum",
    "bandspektrers": "bandspektrum",
    "bandspektret": "bandspektrum",
    "bandspektrets": "bandspektrum",
    "bandspektrumen": "bandspektrum",
    "bandspektrumens": "bandspektrum",
    "bandspektrumet": "bandspektrum",
    "bandspektrumets": "bandspektrum",
    "bandspektrums": "bandspektrum",
    "bandspelar": "bandspelare",
    "bandspelaren": "bandspelare",
    "bandspelarens": "bandspelare",
    "bandspelares": "bandspelare",
    "bandspelarna": "bandspelare",
    "bandspelarnas": "bandspelare",
    "bandstationen": "bandstation",
    "bandstationens": "bandstation",
    "bandstationer": "bandstation",
    "bandstationerna": "bandstation",
    "bandstationernas": "bandstation",
    "bandstationers": "bandstation",
    "bandstations": "bandstation",
    "bandsågar": "bandsåg",
    "bandsågarna": "bandsåg",
    "bandsågarnas": "bandsåg",
    "bandsågars": "bandsåg",
    "bandsågen": "bandsåg",
    "bandsågens": "bandsåg",
    "bandsågs": "bandsåg",
    "bandtraktorer": "bandtraktor",
    "bandtraktorerna": "bandtraktor",
    "bandtraktorernas": "bandtraktor",
    "bandtraktorers": "bandtraktor",
    "bandtraktorn": "bandtraktor",
    "bandtraktorns": "bandtraktor",
    "bandtraktors": "bandtraktor",
    "bandupptagningar": "bandupptagning",
    "bandupptagningarna": "bandupptagning",
    "bandupptagningarnas": "bandupptagning",
    "bandupptagningars": "bandupptagning",
    "bandupptagningen": "bandupptagning",
    "bandupptagningens": "bandupptagning",
    "bandupptagnings": "bandupptagning",
    "bandybollar": "bandyboll",
    "bandybollarna": "bandyboll",
    "bandybollarnas": "bandyboll",
    "bandybollars": "bandyboll",
    "bandybollen": "bandyboll",
    "bandybollens": "bandyboll",
    "bandybolls": "bandyboll",
    "bandyklubb": "bandyklubba",
    "bandyklubban": "bandyklubba",
    "bandyklubbans": "bandyklubba",
    "bandyklubbas": "bandyklubba",
    "bandyklubbe": "bandyklubba",
    "bandyklubbor": "bandyklubba",
    "bandyklubborna": "bandyklubba",
    "bandyklubbornas": "bandyklubba",
    "bandyklubbors": "bandyklubba",
    "bandyklubbs": "bandyklubba",
    "bandyn": "bandy",
    "bandyns": "bandy",
    "bandyrören": "bandyrör",
    "bandyrörens": "bandyrör",
    "bandyröret": "bandyrör",
    "bandyrörets": "bandyrör",
    "bandyrörs": "bandyrör",
    "bandys": "bandy",
    "bandyslagen": "bandyslag",
    "bandyslagens": "bandyslag",
    "bandyslaget": "bandyslag",
    "bandyslagets": "bandyslag",
    "bandyslags": "bandyslag",
    "bane": "bana",
    "banemannen": "baneman",
    "banemannens": "baneman",
    "banemans": "baneman",
    "banemän": "baneman",
    "banemännen": "baneman",
    "banemännens": "baneman",
    "banemäns": "baneman",
    "banen": "ban",
    "banens": "ban",
    "baneren": "baner",
    "banerens": "baner",
    "baneret": "baner",
    "banerets": "baner",
    "banerförar": "banerförare",
    "banerföraren": "banerförare",
    "banerförarens": "banerförare",
    "banerförares": "banerförare",
    "banerförarna": "banerförare",
    "banerförarnas": "banerförare",
    "baners": "baner",
    "banes": "bane",
    "banesåren": "banesår",
    "banesårens": "banesår",
    "banesåret": "banesår",
    "banesårets": "banesår",
    "banesårs": "banesår",
    "banga": "bang",
    "bangar": "bang",
    "bangare": "bang",
    "bangares": "bang",
    "bangarna": "bang",
    "bangarnas": "bang",
    "bangars": "bang",
    "bangas": "bang",
    "bangast": "bang",
    "bangaste": "bang",
    "bangastes": "bang",
    "bangasts": "bang",
    "bange": "bang",
    "bangen": "bang",
    "bangens": "bang",
    "banges": "bang",
    "bangheten": "banghet",
    "banghetens": "banghet",
    "banghets": "banghet",
    "bangladeshar": "bangladeshare",
    "bangladesharen": "bangladeshare",
    "bangladesharens": "bangladeshare",
    "bangladeshares": "bangladeshare",
    "bangladesharna": "bangladeshare",
    "bangladesharnas": "bangladeshare",
    "bangladeshiern": "bangladeshier",
    "bangladeshierna": "bangladeshier",
    "bangladeshiernas": "bangladeshier",
    "bangladeshierns": "bangladeshier",
    "bangladeshiers": "bangladeshier",
    "bangladeshiska": "bangladeshisk",
    "bangladeshiskan": "bangladeshiska",
    "bangladeshiskans": "bangladeshiska",
    "bangladeshiskare": "bangladeshisk",
    "bangladeshiskares": "bangladeshisk",
    "bangladeshiskas": "bangladeshiska",
    "bangladeshiskast": "bangladeshisk",
    "bangladeshiskaste": "bangladeshisk",
    "bangladeshiskastes": "bangladeshisk",
    "bangladeshiskasts": "bangladeshisk",
    "bangladeshiske": "bangladeshiska",
    "bangladeshiskes": "bangladeshisk",
    "bangladeshiskor": "bangladeshiska",
    "bangladeshiskorna": "bangladeshiska",
    "bangladeshiskornas": "bangladeshiska",
    "bangladeshiskors": "bangladeshiska",
    "bangladeshisks": "bangladeshisk",
    "bangladeshiskt": "bangladeshisk",
    "bangladeshiskts": "bangladeshisk",
    "bangolfen": "bangolf",
    "bangolfens": "bangolf",
    "bangolfs": "bangolf",
    "bangs": "bang",
    "bangt": "bang",
    "bangts": "bang",
    "bangårdar": "bangård",
    "bangårdarna": "bangård",
    "bangårdarnas": "bangård",
    "bangårdars": "bangård",
    "bangården": "bangård",
    "bangårdens": "bangård",
    "bangårds": "bangård",
    "banhallar": "banhall",
    "banhallarna": "banhall",
    "banhallarnas": "banhall",
    "banhallars": "banhall",
    "banhallen": "banhall",
    "banhallens": "banhall",
    "banhalls": "banhall",
    "baningar": "baning",
    "baningarna": "baning",
    "baningarnas": "baning",
    "baningars": "baning",
    "baningen": "baning",
    "baningens": "baning",
    "banings": "baning",
    "banjon": "banjo",
    "banjons": "banjo",
    "banjor": "banjo",
    "banjorna": "banjo",
    "banjornas": "banjo",
    "banjors": "banjo",
    "banjos": "banjo",
    "bank": "banka",
    "bankad": "banka",
    "bankade": "banka",
    "bankades": "banka",
    "bankads": "banka",
    "bankande": "banka",
    "bankanden": "bankande",
    "bankandena": "bankande",
    "bankandenas": "bankande",
    "bankandens": "bankande",
    "bankandes": "bankande",
    "bankandet": "bankande",
    "bankandets": "bankande",
    "bankar": "banka",
    "bankarna": "bank",
    "bankarnas": "bank",
    "bankars": "bank",
    "bankas": "banka",
    "bankat": "banka",
    "bankats": "banka",
    "bankboken": "bankbok",
    "bankbokens": "bankbok",
    "bankboks": "bankbok",
    "bankböcker": "bankbok",
    "bankböckerna": "bankbok",
    "bankböckernas": "bankbok",
    "bankböckers": "bankbok",
    "bankdirektören": "bankdirektör",
    "bankdirektörens": "bankdirektör",
    "bankdirektörer": "bankdirektör",
    "bankdirektörerna": "bankdirektör",
    "bankdirektörernas": "bankdirektör",
    "bankdirektörers": "bankdirektör",
    "bankdirektörn": "bankdirektör",
    "bankdirektörns": "bankdirektör",
    "bankdirektörs": "bankdirektör",
    "banken": "bank",
    "bankens": "bank",
    "banker": "bank",
    "bankerna": "bank",
    "bankernas": "bank",
    "bankers": "bank",
    "banketten": "bankett",
    "bankettens": "bankett",
    "banketter": "bankett",
    "banketterna": "bankett",
    "banketternas": "bankett",
    "banketters": "bankett",
    "banketts": "bankett",
    "bankfacken": "bankfack",
    "bankfackens": "bankfack",
    "bankfacket": "bankfack",
    "bankfackets": "bankfack",
    "bankfacks": "bankfack",
    "bankgiron": "bankgiro",
    "bankgirona": "bankgiro",
    "bankgironas": "bankgiro",
    "bankgirons": "bankgiro",
    "bankgiros": "bankgiro",
    "bankgirot": "bankgiro",
    "bankgirots": "bankgiro",
    "bankinspektionen": "bankinspektion",
    "bankinspektionens": "bankinspektion",
    "bankinspektioner": "bankinspektion",
    "bankinspektionerna": "bankinspektion",
    "bankinspektionernas": "bankinspektion",
    "bankinspektioners": "bankinspektion",
    "bankinspektions": "bankinspektion",
    "bankiren": "bankir",
    "bankirens": "bankir",
    "bankirer": "bankir",
    "bankirerna": "bankir",
    "bankirernas": "bankir",
    "bankirers": "bankir",
    "bankirhustrun": "bankirhustru",
    "bankirhustruns": "bankirhustru",
    "bankirhustrur": "bankirhustru",
    "bankirhustrurna": "bankirhustru",
    "bankirhustrurnas": "bankirhustru",
    "bankirhustrurs": "bankirhustru",
    "bankirhustrus": "bankirhustru",
    "bankirs": "bankir",
    "bankkamreren": "bankkamrer",
    "bankkamrerens": "bankkamrer",
    "bankkamrerer": "bankkamrer",
    "bankkamrererna": "bankkamrer",
    "bankkamrerernas": "bankkamrer",
    "bankkamrerers": "bankkamrer",
    "bankkamrern": "bankkamrer",
    "bankkamrerns": "bankkamrer",
    "bankkamrers": "bankkamrer",
    "bankkapitalen": "bankkapital",
    "bankkapitalens": "bankkapital",
    "bankkapitalet": "bankkapital",
    "bankkapitalets": "bankkapital",
    "bankkapitals": "bankkapital",
    "bankkollapsen": "bankkollaps",
    "bankkollapsens": "bankkollaps",
    "bankkollapser": "bankkollaps",
    "bankkollapserna": "bankkollaps",
    "bankkollapsernas": "bankkollaps",
    "bankkollapsers": "bankkollaps",
    "bankkonton": "bankkonto",
    "bankkontona": "bankkonto",
    "bankkontonas": "bankkonto",
    "bankkontons": "bankkonto",
    "bankkontos": "bankkonto",
    "bankkontot": "bankkonto",
    "bankkontots": "bankkonto",
    "bankkorten": "bankkort",
    "bankkortens": "bankkort",
    "bankkortet": "bankkort",
    "bankkortets": "bankkort",
    "bankkorts": "bankkort",
    "bankkunden": "bankkund",
    "bankkundens": "bankkund",
    "bankkunder": "bankkund",
    "bankkunderna": "bankkund",
    "bankkundernas": "bankkund",
    "bankkunders": "bankkund",
    "bankkunds": "bankkund",
    "banklånen": "banklån",
    "banklånens": "banklån",
    "banklånet": "banklån",
    "banklånets": "banklån",
    "banklåns": "banklån",
    "bankmannen": "bankman",
    "bankmannens": "bankman",
    "bankmans": "bankman",
    "bankmän": "bankman",
    "bankmännen": "bankman",
    "bankmännens": "bankman",
    "bankmäns": "bankman",
    "bankmässiga": "bankmässig",
    "bankmässigare": "bankmässig",
    "bankmässigares": "bankmässig",
    "bankmässigas": "bankmässig",
    "bankmässigast": "bankmässig",
    "bankmässigaste": "bankmässig",
    "bankmässigastes": "bankmässig",
    "bankmässigasts": "bankmässig",
    "bankmässige": "bankmässig",
    "bankmässiges": "bankmässig",
    "bankmässigs": "bankmässig",
    "bankmässigt": "bankmässig",
    "bankmässigts": "bankmässig",
    "bankniss": "banknisse",
    "banknissar": "banknisse",
    "banknissarna": "banknisse",
    "banknissarnas": "banknisse",
    "banknissars": "banknisse",
    "banknissen": "banknisse",
    "banknissens": "banknisse",
    "banknisses": "banknisse",
    "bankofullmäktige": "bankofullmäktig",
    "bankofullmäktigen": "bankofullmäktig",
    "bankofullmäktigena": "bankofullmäktig",
    "bankofullmäktigenas": "bankofullmäktig",
    "bankofullmäktigens": "bankofullmäktig",
    "bankofullmäktiges": "bankofullmäktig",
    "bankofullmäktigs": "bankofullmäktig",
    "bankomaten": "bankomat",
    "bankomatens": "bankomat",
    "bankomater": "bankomat",
    "bankomaterna": "bankomat",
    "bankomaternas": "bankomat",
    "bankomaters": "bankomat",
    "bankomatrånar": "bankomatrånare",
    "bankomatrånaren": "bankomatrånare",
    "bankomatrånarens": "bankomatrånare",
    "bankomatrånares": "bankomatrånare",
    "bankomatrånarna": "bankomatrånare",
    "bankomatrånarnas": "bankomatrånare",
    "bankomats": "bankomat",
    "bankos": "banko",
    "bankrutta": "bankrutt",
    "bankruttare": "bankrutt",
    "bankruttares": "bankrutt",
    "bankruttas": "bankrutt",
    "bankruttast": "bankrutt",
    "bankruttaste": "bankrutt",
    "bankruttastes": "bankrutt",
    "bankruttasts": "bankrutt",
    "bankrutte": "bankrutt",
    "bankrutten": "bankrutt",
    "bankruttens": "bankrutt",
    "bankrutter": "bankrutt",
    "bankrutterad": "bankruttera",
    "bankrutterade": "bankruttera",
    "bankrutterades": "bankruttera",
    "bankrutterads": "bankruttera",
    "bankrutterande": "bankruttera",
    "bankrutteranden": "bankrutterande",
    "bankrutterandena": "bankrutterande",
    "bankrutterandenas": "bankrutterande",
    "bankrutterandens": "bankrutterande",
    "bankrutterandes": "bankrutterande",
    "bankrutterandet": "bankrutterande",
    "bankrutterandets": "bankrutterande",
    "bankrutterar": "bankruttera",
    "bankrutteras": "bankruttera",
    "bankrutterat": "bankruttera",
    "bankrutterats": "bankruttera",
    "bankrutterbara": "bankrutterbar",
    "bankrutterbarare": "bankrutterbar",
    "bankrutterbarares": "bankrutterbar",
    "bankrutterbaras": "bankrutterbar",
    "bankrutterbarast": "bankrutterbar",
    "bankrutterbaraste": "bankrutterbar",
    "bankrutterbarastes": "bankrutterbar",
    "bankrutterbarasts": "bankrutterbar",
    "bankrutterbare": "bankrutterbar",
    "bankrutterbares": "bankrutterbar",
    "bankrutterbarheten": "bankrutterbarhet",
    "bankrutterbarhetens": "bankrutterbarhet",
    "bankrutterbarhets": "bankrutterbarhet",
    "bankrutterbars": "bankrutterbar",
    "bankrutterbart": "bankrutterbar",
    "bankrutterbarts": "bankrutterbar",
    "bankrutteringar": "bankruttering",
    "bankrutteringarna": "bankruttering",
    "bankrutteringarnas": "bankruttering",
    "bankrutteringars": "bankruttering",
    "bankrutteringen": "bankruttering",
    "bankrutteringens": "bankruttering",
    "bankrutterings": "bankruttering",
    "bankrutterna": "bankrutt",
    "bankrutternas": "bankrutt",
    "bankrutters": "bankrutt",
    "bankruttes": "bankrutt",
    "bankruttmässiga": "bankruttmässig",
    "bankruttmässigare": "bankruttmässig",
    "bankruttmässigares": "bankruttmässig",
    "bankruttmässigas": "bankruttmässig",
    "bankruttmässigast": "bankruttmässig",
    "bankruttmässigaste": "bankruttmässig",
    "bankruttmässigastes": "bankruttmässig",
    "bankruttmässigasts": "bankruttmässig",
    "bankruttmässige": "bankruttmässig",
    "bankruttmässiges": "bankruttmässig",
    "bankruttmässigs": "bankruttmässig",
    "bankruttmässigt": "bankruttmässig",
    "bankruttmässigts": "bankruttmässig",
    "bankrutts": "bankrutt",
    "bankruttören": "bankruttör",
    "bankruttörens": "bankruttör",
    "bankruttörer": "bankruttör",
    "bankruttörerna": "bankruttör",
    "bankruttörernas": "bankruttör",
    "bankruttörers": "bankruttör",
    "bankruttörs": "bankruttör",
    "bankrånar": "bankrånare",
    "bankrånaren": "bankrånare",
    "bankrånarens": "bankrånare",
    "bankrånares": "bankrånare",
    "bankrånarna": "bankrånare",
    "bankrånarnas": "bankrånare",
    "bankrånen": "bankrån",
    "bankrånens": "bankrån",
    "bankrånet": "bankrån",
    "bankrånets": "bankrån",
    "bankråns": "bankrån",
    "bankrörelsen": "bankrörelse",
    "bankrörelsens": "bankrörelse",
    "bankrörelser": "bankrörelse",
    "bankrörelserna": "bankrörelse",
    "bankrörelsernas": "bankrörelse",
    "bankrörelsers": "bankrörelse",
    "bankrörelses": "bankrörelse",
    "banks": "bank",
    "banksparanden": "banksparande",
    "banksparandena": "banksparande",
    "banksparandenas": "banksparande",
    "banksparandens": "banksparande",
    "banksparandes": "banksparande",
    "banksparandet": "banksparande",
    "banksparandets": "banksparande",
    "bankväxeln": "bankväxel",
    "bankväxelns": "bankväxel",
    "bankväxels": "bankväxel",
    "bankväxlar": "bankväxel",
    "bankväxlarna": "bankväxel",
    "bankväxlarnas": "bankväxel",
    "bankväxlars": "bankväxel",
    "banlöpningar": "banlöpning",
    "banlöpningarna": "banlöpning",
    "banlöpningarnas": "banlöpning",
    "banlöpningars": "banlöpning",
    "banlöpningen": "banlöpning",
    "banlöpningens": "banlöpning",
    "banlöpnings": "banlöpning",
    "bann": "bannor",
    "bannad": "banna",
    "bannade": "banna",
    "bannades": "banna",
    "bannads": "banna",
    "bannande": "banna",
    "bannanden": "bannande",
    "bannandena": "bannande",
    "bannandenas": "bannande",
    "bannandens": "bannande",
    "bannandes": "bannande",
    "bannandet": "bannande",
    "bannandets": "bannande",
    "bannar": "banna",
    "bannas": "banna",
    "bannat": "banna",
    "bannats": "banna",
    "bannbull": "bannbulla",
    "bannbullan": "bannbulla",
    "bannbullans": "bannbulla",
    "bannbullas": "bannbulla",
    "bannbulle": "bannbulla",
    "bannbullor": "bannbulla",
    "bannbullorna": "bannbulla",
    "bannbullornas": "bannbulla",
    "bannbullors": "bannbulla",
    "bannbulls": "bannbulla",
    "bannen": "bann",
    "bannens": "bann",
    "bannet": "bann",
    "bannets": "bann",
    "bannlys": "bannlysa",
    "bannlysande": "bannlysa",
    "bannlysanden": "bannlysande",
    "bannlysandena": "bannlysande",
    "bannlysandenas": "bannlysande",
    "bannlysandens": "bannlysande",
    "bannlysandes": "bannlysande",
    "bannlysandet": "bannlysande",
    "bannlysandets": "bannlysande",
    "bannlysas": "bannlysa",
    "bannlyser": "bannlysa",
    "bannlyses": "bannlysa",
    "bannlyst": "bannlysa",
    "bannlysta": "bannlysa",
    "bannlystas": "bannlysa",
    "bannlyste": "bannlysa",
    "bannlystes": "bannlysa",
    "bannlysts": "bannlysa",
    "bannorna": "bannor",
    "bannornas": "bannor",
    "bannors": "bannor",
    "banns": "bannor",
    "bannstrål": "bannstråle",
    "bannstrålar": "bannstråle",
    "bannstrålarna": "bannstråle",
    "bannstrålarnas": "bannstråle",
    "bannstrålars": "bannstråle",
    "bannstrålen": "bannstråle",
    "bannstrålens": "bannstråle",
    "bannstråles": "bannstråle",
    "bannstråls": "bannstråle",
    "banor": "bana",
    "banorna": "bana",
    "banornas": "bana",
    "banors": "bana",
    "banrekorden": "banrekord",
    "banrekordens": "banrekord",
    "banrekordet": "banrekord",
    "banrekordets": "banrekord",
    "banrekords": "banrekord",
    "banrörelsen": "banrörelse",
    "banrörelsens": "banrörelse",
    "banrörelser": "banrörelse",
    "banrörelserna": "banrörelse",
    "banrörelsernas": "banrörelse",
    "banrörelsers": "banrörelse",
    "banrörelses": "banrörelse",
    "bans": "bana",
    "banskjutningar": "banskjutning",
    "banskjutningarna": "banskjutning",
    "banskjutningarnas": "banskjutning",
    "banskjutningars": "banskjutning",
    "banskjutningen": "banskjutning",
    "banskjutningens": "banskjutning",
    "banskjutnings": "banskjutning",
    "banskyttes": "banskytte",
    "banskyttet": "banskytte",
    "banskyttets": "banskytte",
    "bant": "banta",
    "bantad": "banta",
    "bantade": "banta",
    "bantades": "banta",
    "bantads": "banta",
    "bantamvikten": "bantamvikt",
    "bantamviktens": "bantamvikt",
    "bantamvikts": "bantamvikt",
    "bantande": "banta",
    "bantanden": "bantande",
    "bantandena": "bantande",
    "bantandenas": "bantande",
    "bantandens": "bantande",
    "bantandes": "bantande",
    "bantandet": "bantande",
    "bantandets": "bantande",
    "bantar": "banta",
    "bantas": "banta",
    "bantat": "banta",
    "bantats": "banta",
    "bantlären": "bantlär",
    "bantlärens": "bantlär",
    "bantläret": "bantlär",
    "bantlärets": "bantlär",
    "bantlärs": "bantlär",
    "bantningar": "bantning",
    "bantningarna": "bantning",
    "bantningarnas": "bantning",
    "bantningars": "bantning",
    "bantningen": "bantning",
    "bantningens": "bantning",
    "bantnings": "bantning",
    "bantningsmedels": "bantningsmedel",
    "bantningsmedlen": "bantningsmedel",
    "bantningsmedlens": "bantningsmedel",
    "bantningsmedlet": "bantningsmedel",
    "bantningsmedlets": "bantningsmedel",
    "bantufolken": "bantufolk",
    "bantufolkens": "bantufolk",
    "bantufolket": "bantufolk",
    "bantufolkets": "bantufolk",
    "bantufolks": "bantufolk",
    "bantuspråken": "bantuspråk",
    "bantuspråkens": "bantuspråk",
    "bantuspråket": "bantuspråk",
    "bantuspråkets": "bantuspråk",
    "bantuspråks": "bantuspråk",
    "banvagnar": "banvagn",
    "banvagnarna": "banvagn",
    "banvagnarnas": "banvagn",
    "banvagnars": "banvagn",
    "banvagnen": "banvagn",
    "banvagnens": "banvagn",
    "banvagns": "banvagn",
    "banvallar": "banvall",
    "banvallarna": "banvall",
    "banvallarnas": "banvall",
    "banvallars": "banvall",
    "banvallen": "banvall",
    "banvallens": "banvall",
    "banvalls": "banvall",
    "baptismen": "baptism",
    "baptismens": "baptism",
    "baptismer": "baptism",
    "baptismerna": "baptism",
    "baptismernas": "baptism",
    "baptismers": "baptism",
    "baptisms": "baptism",
    "baptisten": "baptist",
    "baptistens": "baptist",
    "baptister": "baptist",
    "baptisterie": "baptisterium",
    "baptisterier": "baptisterium",
    "baptisterierna": "baptisterium",
    "baptisteriernas": "baptisterium",
    "baptisteriers": "baptisterium",
    "baptisteriet": "baptisterium",
    "baptisteriets": "baptisterium",
    "baptisteriums": "baptisterium",
    "baptisterna": "baptist",
    "baptisternas": "baptist",
    "baptisters": "baptist",
    "baptistiska": "baptistisk",
    "baptistiskas": "baptistisk",
    "baptistiske": "baptistisk",
    "baptistiskes": "baptistisk",
    "baptistisks": "baptistisk",
    "baptistiskt": "baptistisk",
    "baptistiskts": "baptistisk",
    "baptists": "baptist",
    "bar": "bära",
    "bara": "bar",
    "baracken": "barack",
    "barackens": "barack",
    "baracker": "barack",
    "barackerna": "barack",
    "barackernas": "barack",
    "barackers": "barack",
    "baracks": "barack",
    "barare": "bar",
    "barares": "bar",
    "bararmade": "bararmad",
    "bararmades": "bararmad",
    "bararmads": "bararmad",
    "bararmat": "bararmad",
    "bararmats": "bararmad",
    "baras": "bar",
    "barast": "bar",
    "baraste": "bar",
    "barastes": "bar",
    "barasts": "bar",
    "barbadiern": "barbadier",
    "barbadierna": "barbadier",
    "barbadiernas": "barbadier",
    "barbadierns": "barbadier",
    "barbadiers": "barbadier",
    "barbadiska": "barbadisk",
    "barbadiskan": "barbadiska",
    "barbadiskans": "barbadiska",
    "barbadiskare": "barbadisk",
    "barbadiskares": "barbadisk",
    "barbadiskas": "barbadiska",
    "barbadiskast": "barbadisk",
    "barbadiskaste": "barbadisk",
    "barbadiskastes": "barbadisk",
    "barbadiskasts": "barbadisk",
    "barbadiske": "barbadiska",
    "barbadiskes": "barbadisk",
    "barbadiskor": "barbadiska",
    "barbadiskorna": "barbadiska",
    "barbadiskornas": "barbadiska",
    "barbadiskors": "barbadiska",
    "barbadisks": "barbadisk",
    "barbadiskt": "barbadisk",
    "barbadiskts": "barbadisk",
    "barbaren": "barbar",
    "barbarens": "barbar",
    "barbarer": "barbar",
    "barbarerna": "barbar",
    "barbarernas": "barbar",
    "barbarers": "barbar",
    "barbariet": "barbari",
    "barbariets": "barbari",
    "barbaris": "barbari",
    "barbariska": "barbarisk",
    "barbariskare": "barbarisk",
    "barbariskares": "barbarisk",
    "barbariskas": "barbarisk",
    "barbariskast": "barbarisk",
    "barbariskaste": "barbarisk",
    "barbariskastes": "barbarisk",
    "barbariskasts": "barbarisk",
    "barbariske": "barbarisk",
    "barbariskes": "barbarisk",
    "barbarisks": "barbarisk",
    "barbariskt": "barbarisk",
    "barbariskts": "barbarisk",
    "barbarismen": "barbarism",
    "barbarismens": "barbarism",
    "barbarismer": "barbarism",
    "barbarismerna": "barbarism",
    "barbarismernas": "barbarism",
    "barbarismers": "barbarism",
    "barbarisms": "barbarism",
    "barbarit": "barbari",
    "barbarits": "barbari",
    "barbars": "barbar",
    "barbenta": "barbent",
    "barbentare": "barbent",
    "barbentares": "barbent",
    "barbentas": "barbent",
    "barbentast": "barbent",
    "barbentaste": "barbent",
    "barbentastes": "barbent",
    "barbentasts": "barbent",
    "barbente": "barbent",
    "barbentes": "barbent",
    "barbents": "barbent",
    "barberar": "barberare",
    "barberaren": "barberare",
    "barberarens": "barberare",
    "barberares": "barberare",
    "barberarna": "barberare",
    "barberarnas": "barberare",
    "barbituraten": "barbiturat",
    "barbituratens": "barbiturat",
    "barbiturater": "barbiturat",
    "barbituraterna": "barbiturat",
    "barbituraternas": "barbiturat",
    "barbituraters": "barbiturat",
    "barbituratet": "barbiturat",
    "barbituratets": "barbiturat",
    "barbiturats": "barbiturat",
    "barbröstade": "barbröstad",
    "barbröstades": "barbröstad",
    "barbröstads": "barbröstad",
    "barbröstat": "barbröstad",
    "barbröstats": "barbröstad",
    "barden": "bard",
    "bardens": "bard",
    "barder": "bard",
    "barderna": "bard",
    "bardernas": "bard",
    "barders": "bard",
    "bardisanen": "bardisan",
    "bardisanens": "bardisan",
    "bardisaner": "bardisan",
    "bardisanerna": "bardisan",
    "bardisanernas": "bardisan",
    "bardisaners": "bardisan",
    "bardisans": "bardisan",
    "bardiskar": "bardisk",
    "bardiskarna": "bardisk",
    "bardiskarnas": "bardisk",
    "bardiskars": "bardisk",
    "bardisken": "bardisk",
    "bardiskens": "bardisk",
    "bardisks": "bardisk",
    "bards": "bard",
    "bardunen": "bardun",
    "bardunens": "bardun",
    "barduner": "bardun",
    "bardunerna": "bardun",
    "bardunernas": "bardun",
    "barduners": "bardun",
    "barduns": "bardun",
    "bardvalar": "bardval",
    "bardvalarna": "bardval",
    "bardvalarnas": "bardval",
    "bardvalars": "bardval",
    "bardvalen": "bardval",
    "bardvalens": "bardval",
    "bardvals": "bardval",
    "bare": "bar",
    "baren": "bar",
    "barens": "bar",
    "barer": "bar",
    "barerna": "bar",
    "barernas": "bar",
    "barers": "bar",
    "bares": "bar",
    "baretten": "barett",
    "barettens": "barett",
    "baretter": "barett",
    "baretterna": "barett",
    "baretternas": "barett",
    "baretters": "barett",
    "baretts": "barett",
    "barfotade": "barfotad",
    "barfotades": "barfotad",
    "barfotads": "barfotad",
    "barfotalassar": "barfotalasse",
    "barfotalassarna": "barfotalasse",
    "barfotalassarnas": "barfotalasse",
    "barfotalassars": "barfotalasse",
    "barfotalassen": "barfotalasse",
    "barfotalassens": "barfotalasse",
    "barfotalasses": "barfotalasse",
    "barfotaläkar": "barfotaläkare",
    "barfotaläkaren": "barfotaläkare",
    "barfotaläkarens": "barfotaläkare",
    "barfotaläkares": "barfotaläkare",
    "barfotaläkarna": "barfotaläkare",
    "barfotaläkarnas": "barfotaläkare",
    "barfotalöpningar": "barfotalöpning",
    "barfotalöpningarna": "barfotalöpning",
    "barfotalöpningarnas": "barfotalöpning",
    "barfotalöpningars": "barfotalöpning",
    "barfotalöpningen": "barfotalöpning",
    "barfotalöpningens": "barfotalöpning",
    "barfotalöpnings": "barfotalöpning",
    "barfotamunkar": "barfotamunk",
    "barfotamunkarna": "barfotamunk",
    "barfotamunkarnas": "barfotamunk",
    "barfotamunkars": "barfotamunk",
    "barfotamunken": "barfotamunk",
    "barfotamunkens": "barfotamunk",
    "barfotamunks": "barfotamunk",
    "barfotat": "barfotad",
    "barfotats": "barfotad",
    "barfrosten": "barfrost",
    "barfrostens": "barfrost",
    "barfrosts": "barfrost",
    "barheten": "barhet",
    "barhetens": "barhet",
    "barhets": "barhet",
    "barhuvade": "barhuvad",
    "barhuvades": "barhuvad",
    "barhuvads": "barhuvad",
    "barhuvat": "barhuvad",
    "barhuvats": "barhuvad",
    "bariet": "barium",
    "bariets": "barium",
    "baritonen": "bariton",
    "baritonens": "bariton",
    "baritoner": "bariton",
    "baritonerna": "bariton",
    "baritonernas": "bariton",
    "baritoners": "bariton",
    "baritons": "bariton",
    "bariumet": "barium",
    "bariumets": "barium",
    "bariumföreningar": "bariumförening",
    "bariumföreningarna": "bariumförening",
    "bariumföreningarnas": "bariumförening",
    "bariumföreningars": "bariumförening",
    "bariumföreningen": "bariumförening",
    "bariumföreningens": "bariumförening",
    "bariumförenings": "bariumförening",
    "bariums": "barium",
    "bariumsalter": "bariumsalt",
    "bariumsalterna": "bariumsalt",
    "bariumsalternas": "bariumsalt",
    "bariumsalters": "bariumsalt",
    "bariumsaltet": "bariumsalt",
    "bariumsaltets": "bariumsalt",
    "bariumsalts": "bariumsalt",
    "bariumsulfaten": "bariumsulfat",
    "bariumsulfatens": "bariumsulfat",
    "bariumsulfater": "bariumsulfat",
    "bariumsulfaterna": "bariumsulfat",
    "bariumsulfaternas": "bariumsulfat",
    "bariumsulfaters": "bariumsulfat",
    "bariumsulfatet": "bariumsulfat",
    "bariumsulfatets": "bariumsulfat",
    "bariumsulfats": "bariumsulfat",
    "bark": "barka",
    "barkad": "barka",
    "barkade": "barka",
    "barkades": "barka",
    "barkads": "barka",
    "barkande": "barka",
    "barkanden": "barkande",
    "barkandena": "barkande",
    "barkandenas": "barkande",
    "barkandens": "barkande",
    "barkandes": "barkande",
    "barkandet": "barkande",
    "barkandets": "barkande",
    "barkar": "barka",
    "barkarna": "bark",
    "barkarnas": "bark",
    "barkarollen": "barkaroll",
    "barkarollens": "barkaroll",
    "barkaroller": "barkaroll",
    "barkarollerna": "barkaroll",
    "barkarollernas": "barkaroll",
    "barkarollers": "barkaroll",
    "barkarolls": "barkaroll",
    "barkars": "bark",
    "barkassen": "barkass",
    "barkassens": "barkass",
    "barkasser": "barkass",
    "barkasserna": "barkass",
    "barkassernas": "barkass",
    "barkassers": "barkass",
    "barkat": "barka",
    "barkats": "barka",
    "barkborr": "barkborre",
    "barkborrar": "barkborre",
    "barkborrarna": "barkborre",
    "barkborrarnas": "barkborre",
    "barkborrars": "barkborre",
    "barkborren": "barkborre",
    "barkborrens": "barkborre",
    "barkborres": "barkborre",
    "barkborrs": "barkborre",
    "barkbröden": "barkbröd",
    "barkbrödens": "barkbröd",
    "barkbrödet": "barkbröd",
    "barkbrödets": "barkbröd",
    "barkbröds": "barkbröd",
    "barkbåtar": "barkbåt",
    "barkbåtarna": "barkbåt",
    "barkbåtarnas": "barkbåt",
    "barkbåtars": "barkbåt",
    "barkbåten": "barkbåt",
    "barkbåtens": "barkbåt",
    "barkbåts": "barkbåt",
    "barken": "bark",
    "barkens": "bark",
    "barker": "bark",
    "barkerna": "bark",
    "barkernas": "bark",
    "barkers": "bark",
    "barkisar": "barkis",
    "barkisarna": "barkis",
    "barkisarnas": "barkis",
    "barkisars": "barkis",
    "barkisen": "barkis",
    "barkisens": "barkis",
    "barklagen": "barklag",
    "barklagens": "barklag",
    "barklags": "barklag",
    "barks": "bark",
    "barkspad": "barkspade",
    "barkspadar": "barkspade",
    "barkspadarna": "barkspade",
    "barkspadarnas": "barkspade",
    "barkspadars": "barkspade",
    "barkspaden": "barkspade",
    "barkspadens": "barkspade",
    "barkspades": "barkspade",
    "barkspads": "barkspade",
    "barktäkten": "barktäkt",
    "barktäktens": "barktäkt",
    "barktäkter": "barktäkt",
    "barktäkterna": "barktäkt",
    "barktäkternas": "barktäkt",
    "barktäkters": "barktäkt",
    "barktäkts": "barktäkt",
    "barkympad": "barkympa",
    "barkympade": "barkympa",
    "barkympades": "barkympa",
    "barkympads": "barkympa",
    "barkympande": "barkympa",
    "barkympanden": "barkympande",
    "barkympandena": "barkympande",
    "barkympandenas": "barkympande",
    "barkympandens": "barkympande",
    "barkympandes": "barkympande",
    "barkympandet": "barkympande",
    "barkympandets": "barkympande",
    "barkympar": "barkympa",
    "barkympas": "barkympa",
    "barkympat": "barkympa",
    "barkympats": "barkympa",
    "barlastad": "barlasta",
    "barlastade": "barlasta",
    "barlastades": "barlasta",
    "barlastads": "barlasta",
    "barlastande": "barlasta",
    "barlastanden": "barlastande",
    "barlastandena": "barlastande",
    "barlastandenas": "barlastande",
    "barlastandens": "barlastande",
    "barlastandes": "barlastande",
    "barlastandet": "barlastande",
    "barlastandets": "barlastande",
    "barlastar": "barlasta",
    "barlastas": "barlasta",
    "barlastat": "barlasta",
    "barlastats": "barlasta",
    "barlasten": "barlast",
    "barlastens": "barlast",
    "barlaster": "barlast",
    "barlasterna": "barlast",
    "barlasternas": "barlast",
    "barlasters": "barlast",
    "barlastkölar": "barlastköl",
    "barlastkölarna": "barlastköl",
    "barlastkölarnas": "barlastköl",
    "barlastkölars": "barlastköl",
    "barlastkölen": "barlastköl",
    "barlastkölens": "barlastköl",
    "barlastköls": "barlastköl",
    "barlasts": "barlast",
    "barmar": "barm",
    "barmarken": "barmark",
    "barmarkens": "barmark",
    "barmarker": "barmark",
    "barmarkerna": "barmark",
    "barmarkernas": "barmark",
    "barmarkers": "barmark",
    "barmarks": "barmark",
    "barmarna": "barm",
    "barmarnas": "barm",
    "barmars": "barm",
    "barmen": "barm",
    "barmens": "barm",
    "barmhärtiga": "barmhärtig",
    "barmhärtigare": "barmhärtig",
    "barmhärtigares": "barmhärtig",
    "barmhärtigas": "barmhärtig",
    "barmhärtigast": "barmhärtig",
    "barmhärtigaste": "barmhärtig",
    "barmhärtigastes": "barmhärtig",
    "barmhärtigasts": "barmhärtig",
    "barmhärtige": "barmhärtig",
    "barmhärtiges": "barmhärtig",
    "barmhärtigheten": "barmhärtighet",
    "barmhärtighetens": "barmhärtighet",
    "barmhärtigheter": "barmhärtighet",
    "barmhärtigheterna": "barmhärtighet",
    "barmhärtigheternas": "barmhärtighet",
    "barmhärtigheters": "barmhärtighet",
    "barmhärtighets": "barmhärtighet",
    "barmhärtighetsgärningar": "barmhärtighetsgärning",
    "barmhärtighetsgärningarna": "barmhärtighetsgärning",
    "barmhärtighetsgärningarnas": "barmhärtighetsgärning",
    "barmhärtighetsgärningars": "barmhärtighetsgärning",
    "barmhärtighetsgärningen": "barmhärtighetsgärning",
    "barmhärtighetsgärningens": "barmhärtighetsgärning",
    "barmhärtighetsgärnings": "barmhärtighetsgärning",
    "barmhärtighetsmorden": "barmhärtighetsmord",
    "barmhärtighetsmordens": "barmhärtighetsmord",
    "barmhärtighetsmordet": "barmhärtighetsmord",
    "barmhärtighetsmordets": "barmhärtighetsmord",
    "barmhärtighetsmords": "barmhärtighetsmord",
    "barmhärtigs": "barmhärtig",
    "barmhärtigt": "barmhärtig",
    "barmhärtigts": "barmhärtig",
    "barms": "barm",
    "barnadödligheten": "barnadödlighet",
    "barnadödlighetens": "barnadödlighet",
    "barnadödligheter": "barnadödlighet",
    "barnadödligheterna": "barnadödlighet",
    "barnadödligheternas": "barnadödlighet",
    "barnadödligheters": "barnadödlighet",
    "barnadödlighets": "barnadödlighet",
    "barnafader": "barnafar",
    "barnafadern": "barnafar",
    "barnafaderns": "barnafar",
    "barnafaders": "barnafar",
    "barnafars": "barnafar",
    "barnafasder": "barnafar",
    "barnafäder": "barnafar",
    "barnafäderna": "barnafar",
    "barnafädernas": "barnafar",
    "barnafäders": "barnafar",
    "barnaföderskan": "barnaföderska",
    "barnaföderskans": "barnaföderska",
    "barnaföderskas": "barnaföderska",
    "barnaföderske": "barnaföderska",
    "barnaföderskor": "barnaföderska",
    "barnaföderskorna": "barnaföderska",
    "barnaföderskornas": "barnaföderska",
    "barnaföderskors": "barnaföderska",
    "barnamorden": "barnamord",
    "barnamordens": "barnamord",
    "barnamordet": "barnamord",
    "barnamordets": "barnamord",
    "barnamords": "barnamord",
    "barnansikten": "barnansikte",
    "barnansiktena": "barnansikte",
    "barnansiktenas": "barnansikte",
    "barnansiktens": "barnansikte",
    "barnansiktes": "barnansikte",
    "barnansiktet": "barnansikte",
    "barnansiktets": "barnansikte",
    "barnansikts": "barnansikte",
    "barnaroven": "barnarov",
    "barnarovens": "barnarov",
    "barnarovet": "barnarov",
    "barnarovets": "barnarov",
    "barnarovs": "barnarov",
    "barnasinnen": "barnasinne",
    "barnasinnena": "barnasinne",
    "barnasinnenas": "barnasinne",
    "barnasinnens": "barnasinne",
    "barnasinnes": "barnasinne",
    "barnasinnet": "barnasinne",
    "barnasinnets": "barnasinne",
    "barnaskar": "barnaskara",
    "barnaskaran": "barnaskara",
    "barnaskarans": "barnaskara",
    "barnaskaras": "barnaskara",
    "barnaskare": "barnaskara",
    "barnaskaror": "barnaskara",
    "barnaskarorna": "barnaskara",
    "barnaskarornas": "barnaskara",
    "barnaskarors": "barnaskara",
    "barnaskars": "barnaskara",
    "barnatron": "barnatro",
    "barnatrons": "barnatro",
    "barnatros": "barnatro",
    "barnavårdar": "barnavård",
    "barnavårdarna": "barnavård",
    "barnavårdarnas": "barnavård",
    "barnavårdars": "barnavård",
    "barnavården": "barnavård",
    "barnavårdens": "barnavård",
    "barnavårds": "barnavård",
    "barnavårdscentralen": "barnavårdscentral",
    "barnavårdscentralens": "barnavårdscentral",
    "barnavårdscentraler": "barnavårdscentral",
    "barnavårdscentralerna": "barnavårdscentral",
    "barnavårdscentralernas": "barnavårdscentral",
    "barnavårdscentralers": "barnavårdscentral",
    "barnavårdscentrals": "barnavårdscentral",
    "barnavårdsmannen": "barnavårdsman",
    "barnavårdsmannens": "barnavårdsman",
    "barnavårdsmans": "barnavårdsman",
    "barnavårdsmän": "barnavårdsman",
    "barnavårdsmännen": "barnavårdsman",
    "barnavårdsmännens": "barnavårdsman",
    "barnavårdsmäns": "barnavårdsman",
    "barnavårdsnämnden": "barnavårdsnämnd",
    "barnavårdsnämndens": "barnavårdsnämnd",
    "barnavårdsnämnder": "barnavårdsnämnd",
    "barnavårdsnämnderna": "barnavårdsnämnd",
    "barnavårdsnämndernas": "barnavårdsnämnd",
    "barnavårdsnämnders": "barnavårdsnämnd",
    "barnavårdsnämnds": "barnavårdsnämnd",
    "barnbarnen": "barnbarn",
    "barnbarnens": "barnbarn",
    "barnbarnet": "barnbarn",
    "barnbarnets": "barnbarn",
    "barnbarns": "barnbarn",
    "barnbarnsbarnen": "barnbarnsbarn",
    "barnbarnsbarnens": "barnbarnsbarn",
    "barnbarnsbarnet": "barnbarnsbarn",
    "barnbarnsbarnets": "barnbarnsbarn",
    "barnbarnsbarns": "barnbarnsbarn",
    "barnbecket": "barnbeck",
    "barnbeckets": "barnbeck",
    "barnbecks": "barnbeck",
    "barnbegränsningar": "barnbegränsning",
    "barnbegränsningarna": "barnbegränsning",
    "barnbegränsningarnas": "barnbegränsning",
    "barnbegränsningars": "barnbegränsning",
    "barnbegränsningen": "barnbegränsning",
    "barnbegränsningens": "barnbegränsning",
    "barnbegränsnings": "barnbegränsning",
    "barnbespisningar": "barnbespisning",
    "barnbespisningarna": "barnbespisning",
    "barnbespisningarnas": "barnbespisning",
    "barnbespisningars": "barnbespisning",
    "barnbespisningen": "barnbespisning",
    "barnbespisningens": "barnbespisning",
    "barnbespisnings": "barnbespisning",
    "barnbidragen": "barnbidrag",
    "barnbidragens": "barnbidrag",
    "barnbidraget": "barnbidrag",
    "barnbidragets": "barnbidrag",
    "barnbidrags": "barnbidrag",
    "barnboken": "barnbok",
    "barnbokens": "barnbok",
    "barnboks": "barnbok",
    "barnbyar": "barnby",
    "barnbyarna": "barnby",
    "barnbyarnas": "barnby",
    "barnbyars": "barnby",
    "barnbyn": "barnby",
    "barnbyns": "barnby",
    "barnbys": "barnby",
    "barnböcker": "barnbok",
    "barnböckerna": "barnbok",
    "barnböckernas": "barnbok",
    "barnböckers": "barnbok",
    "barnbördshusen": "barnbördshus",
    "barnbördshusens": "barnbördshus",
    "barnbördshuset": "barnbördshus",
    "barnbördshusets": "barnbördshus",
    "barncrosshjälmar": "barncrosshjälm",
    "barncrosshjälmarna": "barncrosshjälm",
    "barncrosshjälmarnas": "barncrosshjälm",
    "barncrosshjälmars": "barncrosshjälm",
    "barncrosshjälmen": "barncrosshjälm",
    "barncrosshjälmens": "barncrosshjälm",
    "barncrosshjälms": "barncrosshjälm",
    "barncykeln": "barncykel",
    "barncykelns": "barncykel",
    "barncykels": "barncykel",
    "barncyklar": "barncykel",
    "barncyklarna": "barncykel",
    "barncyklarnas": "barncykel",
    "barncyklars": "barncykel",
    "barndaghemmen": "barndaghem",
    "barndaghemmens": "barndaghem",
    "barndaghemmet": "barndaghem",
    "barndaghemmets": "barndaghem",
    "barndaghems": "barndaghem",
    "barndomar": "barndom",
    "barndomarna": "barndom",
    "barndomarnas": "barndom",
    "barndomars": "barndom",
    "barndomen": "barndom",
    "barndomens": "barndom",
    "barndoms": "barndom",
    "barndomsparadisen": "barndomsparadis",
    "barndomsparadisens": "barndomsparadis",
    "barndomsparadiset": "barndomsparadis",
    "barndomsparadisets": "barndomsparadis",
    "barndomsupplevelsen": "barndomsupplevelse",
    "barndomsupplevelsens": "barndomsupplevelse",
    "barndomsupplevelser": "barndomsupplevelse",
    "barndomsupplevelserna": "barndomsupplevelse",
    "barndomsupplevelsernas": "barndomsupplevelse",
    "barndomsupplevelsers": "barndomsupplevelse",
    "barndomsupplevelses": "barndomsupplevelse",
    "barndomsvännen": "barndomsvän",
    "barndomsvännens": "barndomsvän",
    "barndomsvänner": "barndomsvän",
    "barndomsvännerna": "barndomsvän",
    "barndomsvännernas": "barndomsvän",
    "barndomsvänners": "barndomsvän",
    "barndomsväns": "barndomsvän",
    "barndopen": "barndop",
    "barndopens": "barndop",
    "barndopet": "barndop",
    "barndopets": "barndop",
    "barndops": "barndop",
    "barndosen": "barndos",
    "barndosens": "barndos",
    "barndoser": "barndos",
    "barndoserna": "barndos",
    "barndosernas": "barndos",
    "barndosers": "barndos",
    "barnen": "barn",
    "barnens": "barn",
    "barnet": "barn",
    "barnets": "barn",
    "barnfamiljen": "barnfamilj",
    "barnfamiljens": "barnfamilj",
    "barnfamiljer": "barnfamilj",
    "barnfamiljerna": "barnfamilj",
    "barnfamiljernas": "barnfamilj",
    "barnfamiljers": "barnfamilj",
    "barnfamiljs": "barnfamilj",
    "barnflick": "barnflicka",
    "barnflickan": "barnflicka",
    "barnflickans": "barnflicka",
    "barnflickas": "barnflicka",
    "barnflicke": "barnflicka",
    "barnflickor": "barnflicka",
    "barnflickorna": "barnflicka",
    "barnflickornas": "barnflicka",
    "barnflickors": "barnflicka",
    "barnflicks": "barnflicka",
    "barnfotomodellen": "barnfotomodell",
    "barnfotomodellens": "barnfotomodell",
    "barnfotomodeller": "barnfotomodell",
    "barnfotomodellerna": "barnfotomodell",
    "barnfotomodellernas": "barnfotomodell",
    "barnfotomodellers": "barnfotomodell",
    "barnfotomodells": "barnfotomodell",
    "barnfödda": "barnfödd",
    "barnföddare": "barnfödd",
    "barnföddares": "barnfödd",
    "barnföddas": "barnfödd",
    "barnföddast": "barnfödd",
    "barnföddaste": "barnfödd",
    "barnföddastes": "barnfödd",
    "barnföddasts": "barnfödd",
    "barnfödde": "barnfödd",
    "barnföddes": "barnfödd",
    "barnfödds": "barnfödd",
    "barnförbjudenheten": "barnförbjudenhet",
    "barnförbjudenhetens": "barnförbjudenhet",
    "barnförbjudenhets": "barnförbjudenhet",
    "barnförbjudens": "barnförbjuden",
    "barnförbjudet": "barnförbjuden",
    "barnförbjudets": "barnförbjuden",
    "barnförbjudna": "barnförbjuden",
    "barnförbjudnare": "barnförbjuden",
    "barnförbjudnares": "barnförbjuden",
    "barnförbjudnas": "barnförbjuden",
    "barnförbjudnast": "barnförbjuden",
    "barnförbjudnaste": "barnförbjuden",
    "barnförbjudnastes": "barnförbjuden",
    "barnförbjudnasts": "barnförbjuden",
    "barnförbjudne": "barnförbjuden",
    "barnförbjudnes": "barnförbjuden",
    "barnförlamningar": "barnförlamning",
    "barnförlamningarna": "barnförlamning",
    "barnförlamningarnas": "barnförlamning",
    "barnförlamningars": "barnförlamning",
    "barnförlamningen": "barnförlamning",
    "barnförlamningens": "barnförlamning",
    "barnförlamnings": "barnförlamning",
    "barnfött": "barnfödd",
    "barnfötts": "barnfödd",
    "barngruppen": "barngrupp",
    "barngruppens": "barngrupp",
    "barngrupper": "barngrupp",
    "barngrupperna": "barngrupp",
    "barngruppernas": "barngrupp",
    "barngruppers": "barngrupp",
    "barngrupps": "barngrupp",
    "barnhemmen": "barnhem",
    "barnhemmens": "barnhem",
    "barnhemmet": "barnhem",
    "barnhemmets": "barnhem",
    "barnhems": "barnhem",
    "barnhemsbarnen": "barnhemsbarn",
    "barnhemsbarnens": "barnhemsbarn",
    "barnhemsbarnet": "barnhemsbarn",
    "barnhemsbarnets": "barnhemsbarn",
    "barnhemsbarns": "barnhemsbarn",
    "barnhemsplaceringar": "barnhemsplacering",
    "barnhemsplaceringarna": "barnhemsplacering",
    "barnhemsplaceringarnas": "barnhemsplacering",
    "barnhemsplaceringars": "barnhemsplacering",
    "barnhemsplaceringen": "barnhemsplacering",
    "barnhemsplaceringens": "barnhemsplacering",
    "barnhemsplacerings": "barnhemsplacering",
    "barnhuvuden": "barnhuvud",
    "barnhuvudena": "barnhuvud",
    "barnhuvudenas": "barnhuvud",
    "barnhuvudens": "barnhuvud",
    "barnhuvudet": "barnhuvud",
    "barnhuvudets": "barnhuvud",
    "barnhuvuds": "barnhuvud",
    "barnkalasen": "barnkalas",
    "barnkalasens": "barnkalas",
    "barnkalaset": "barnkalas",
    "barnkalasets": "barnkalas",
    "barnkammar": "barnkammare",
    "barnkammaren": "barnkammare",
    "barnkammarens": "barnkammare",
    "barnkammares": "barnkammare",
    "barnkammarfönsterna": "barnkammarfönster",
    "barnkammarfönsternas": "barnkammarfönster",
    "barnkammarfönsters": "barnkammarfönster",
    "barnkammarfönstren": "barnkammarfönster",
    "barnkammarfönstrens": "barnkammarfönster",
    "barnkammarfönstret": "barnkammarfönster",
    "barnkammarfönstrets": "barnkammarfönster",
    "barnkammarsagan": "barnkammarsaga",
    "barnkammarsagans": "barnkammarsaga",
    "barnkammarsagas": "barnkammarsaga",
    "barnkammarsage": "barnkammarsaga",
    "barnkammarsago": "barnkammarsaga",
    "barnkammarsagor": "barnkammarsaga",
    "barnkammarsagorna": "barnkammarsaga",
    "barnkammarsagornas": "barnkammarsaga",
    "barnkammarsagors": "barnkammarsaga",
    "barnkamrar": "barnkammare",
    "barnkamrarna": "barnkammare",
    "barnkamrarnas": "barnkammare",
    "barnkamrars": "barnkammare",
    "barnkliniken": "barnklinik",
    "barnklinikens": "barnklinik",
    "barnkliniker": "barnklinik",
    "barnklinikerna": "barnklinik",
    "barnklinikernas": "barnklinik",
    "barnklinikers": "barnklinik",
    "barnkliniks": "barnklinik",
    "barnkläderna": "barnkläder",
    "barnklädernas": "barnkläder",
    "barnkläders": "barnkläder",
    "barnklädes": "barnkläder",
    "barnkläds": "barnkläder",
    "barnkolonien": "barnkoloni",
    "barnkoloniens": "barnkoloni",
    "barnkolonier": "barnkoloni",
    "barnkolonierna": "barnkoloni",
    "barnkoloniernas": "barnkoloni",
    "barnkoloniers": "barnkoloni",
    "barnkolonin": "barnkoloni",
    "barnkolonins": "barnkoloni",
    "barnkolonis": "barnkoloni",
    "barnkroppar": "barnkropp",
    "barnkropparna": "barnkropp",
    "barnkropparnas": "barnkropp",
    "barnkroppars": "barnkropp",
    "barnkroppen": "barnkropp",
    "barnkroppens": "barnkropp",
    "barnkropps": "barnkropp",
    "barnkära": "barnkär",
    "barnkärare": "barnkär",
    "barnkärares": "barnkär",
    "barnkäras": "barnkär",
    "barnkärast": "barnkär",
    "barnkäraste": "barnkär",
    "barnkärastes": "barnkär",
    "barnkärasts": "barnkär",
    "barnkäre": "barnkär",
    "barnkäres": "barnkär",
    "barnkärs": "barnkär",
    "barnkärt": "barnkär",
    "barnkärts": "barnkär",
    "barnkören": "barnkör",
    "barnkörens": "barnkör",
    "barnkörer": "barnkör",
    "barnkörerna": "barnkör",
    "barnkörernas": "barnkör",
    "barnkörers": "barnkör",
    "barnkörs": "barnkör",
    "barnlediga": "barnledig",
    "barnledigare": "barnledig",
    "barnledigares": "barnledig",
    "barnledigas": "barnledig",
    "barnledigast": "barnledig",
    "barnledigaste": "barnledig",
    "barnledigastes": "barnledig",
    "barnledigasts": "barnledig",
    "barnledige": "barnledig",
    "barnlediges": "barnledig",
    "barnledigheten": "barnledighet",
    "barnledighetens": "barnledighet",
    "barnledighets": "barnledighet",
    "barnledigs": "barnledig",
    "barnledigt": "barnledig",
    "barnledigts": "barnledig",
    "barnlekar": "barnlek",
    "barnlekarna": "barnlek",
    "barnlekarnas": "barnlek",
    "barnlekars": "barnlek",
    "barnleken": "barnlek",
    "barnlekens": "barnlek",
    "barnleks": "barnlek",
    "barnläkar": "barnläkare",
    "barnläkaren": "barnläkare",
    "barnläkarens": "barnläkare",
    "barnläkares": "barnläkare",
    "barnläkarna": "barnläkare",
    "barnläkarnas": "barnläkare",
    "barnlösa": "barnlös",
    "barnlösare": "barnlös",
    "barnlösares": "barnlös",
    "barnlösas": "barnlös",
    "barnlösast": "barnlös",
    "barnlösaste": "barnlös",
    "barnlösastes": "barnlös",
    "barnlösasts": "barnlös",
    "barnlöse": "barnlös",
    "barnlöses": "barnlös",
    "barnlösheten": "barnlöshet",
    "barnlöshetens": "barnlöshet",
    "barnlöshets": "barnlöshet",
    "barnlöst": "barnlös",
    "barnlösts": "barnlös",
    "barnmorskan": "barnmorska",
    "barnmorskans": "barnmorska",
    "barnmorskas": "barnmorska",
    "barnmorske": "barnmorska",
    "barnmorskor": "barnmorska",
    "barnmorskorna": "barnmorska",
    "barnmorskornas": "barnmorska",
    "barnmorskors": "barnmorska",
    "barnneurologen": "barnneurolog",
    "barnneurologens": "barnneurolog",
    "barnneurologer": "barnneurolog",
    "barnneurologerna": "barnneurolog",
    "barnneurologernas": "barnneurolog",
    "barnneurologers": "barnneurolog",
    "barnneurologs": "barnneurolog",
    "barnomsorgen": "barnomsorg",
    "barnomsorgens": "barnomsorg",
    "barnomsorgs": "barnomsorg",
    "barnomsorgsavgiften": "barnomsorgsavgift",
    "barnomsorgsavgiftens": "barnomsorgsavgift",
    "barnomsorgsavgifter": "barnomsorgsavgift",
    "barnomsorgsavgifterna": "barnomsorgsavgift",
    "barnomsorgsavgifternas": "barnomsorgsavgift",
    "barnomsorgsavgifters": "barnomsorgsavgift",
    "barnomsorgsavgifts": "barnomsorgsavgift",
    "barnomsorgskostnaden": "barnomsorgskostnad",
    "barnomsorgskostnadens": "barnomsorgskostnad",
    "barnomsorgskostnader": "barnomsorgskostnad",
    "barnomsorgskostnaderna": "barnomsorgskostnad",
    "barnomsorgskostnadernas": "barnomsorgskostnad",
    "barnomsorgskostnaders": "barnomsorgskostnad",
    "barnomsorgskostnads": "barnomsorgskostnad",
    "barnparkeringar": "barnparkering",
    "barnparkeringarna": "barnparkering",
    "barnparkeringarnas": "barnparkering",
    "barnparkeringars": "barnparkering",
    "barnparkeringen": "barnparkering",
    "barnparkeringens": "barnparkering",
    "barnparkerings": "barnparkering",
    "barnpassningar": "barnpassning",
    "barnpassningarna": "barnpassning",
    "barnpassningarnas": "barnpassning",
    "barnpassningars": "barnpassning",
    "barnpassningen": "barnpassning",
    "barnpassningens": "barnpassning",
    "barnpassnings": "barnpassning",
    "barnpornografien": "barnpornografi",
    "barnpornografiens": "barnpornografi",
    "barnpornografin": "barnpornografi",
    "barnpornografins": "barnpornografi",
    "barnpornografis": "barnpornografi",
    "barnporranklagade": "barnporranklagad",
    "barnporranklagades": "barnporranklagad",
    "barnporranklagads": "barnporranklagad",
    "barnporranklagat": "barnporranklagad",
    "barnporranklagats": "barnporranklagad",
    "barnporren": "barnporr",
    "barnporrens": "barnporr",
    "barnporrhärvan": "barnporrhärva",
    "barnporrhärvans": "barnporrhärva",
    "barnporrhärvas": "barnporrhärva",
    "barnporrhärve": "barnporrhärva",
    "barnporrhärvor": "barnporrhärva",
    "barnporrhärvorna": "barnporrhärva",
    "barnporrhärvornas": "barnporrhärva",
    "barnporrhärvors": "barnporrhärva",
    "barnporrs": "barnporr",
    "barnroven": "barnrov",
    "barnrovens": "barnrov",
    "barnrovet": "barnrov",
    "barnrovets": "barnrov",
    "barnrovs": "barnrov",
    "barnrättskämpar": "barnrättskämpe",
    "barnrättskämparna": "barnrättskämpe",
    "barnrättskämparnas": "barnrättskämpe",
    "barnrättskämpars": "barnrättskämpe",
    "barnrättskämpen": "barnrättskämpe",
    "barnrättskämpens": "barnrättskämpe",
    "barnrättskämpes": "barnrättskämpe",
    "barns": "barn",
    "barnsaken": "barnsak",
    "barnsakens": "barnsak",
    "barnsaker": "barnsak",
    "barnsakerna": "barnsak",
    "barnsakernas": "barnsak",
    "barnsakers": "barnsak",
    "barnsaks": "barnsak",
    "barnsbörden": "barnsbörd",
    "barnsbördens": "barnsbörd",
    "barnsbörder": "barnsbörd",
    "barnsbörderna": "barnsbörd",
    "barnsbördernas": "barnsbörd",
    "barnsbörders": "barnsbörd",
    "barnsbörds": "barnsbörd",
    "barnsjukdomar": "barnsjukdom",
    "barnsjukdomarna": "barnsjukdom",
    "barnsjukdomarnas": "barnsjukdom",
    "barnsjukdomars": "barnsjukdom",
    "barnsjukdomen": "barnsjukdom",
    "barnsjukdomens": "barnsjukdom",
    "barnsjukdoms": "barnsjukdom",
    "barnsjukhusen": "barnsjukhus",
    "barnsjukhusens": "barnsjukhus",
    "barnsjukhuset": "barnsjukhus",
    "barnsjukhusets": "barnsjukhus",
    "barnskon": "barnsko",
    "barnskons": "barnsko",
    "barnskor": "barnsko",
    "barnskorna": "barnsko",
    "barnskornas": "barnsko",
    "barnskors": "barnsko",
    "barnskos": "barnsko",
    "barnskottkärr": "barnskottkärra",
    "barnskottkärran": "barnskottkärra",
    "barnskottkärrans": "barnskottkärra",
    "barnskottkärras": "barnskottkärra",
    "barnskottkärre": "barnskottkärra",
    "barnskottkärror": "barnskottkärra",
    "barnskottkärrorna": "barnskottkärra",
    "barnskottkärrornas": "barnskottkärra",
    "barnskottkärrors": "barnskottkärra",
    "barnskottkärrs": "barnskottkärra",
    "barnsköterskan": "barnsköterska",
    "barnsköterskans": "barnsköterska",
    "barnsköterskas": "barnsköterska",
    "barnsköterske": "barnsköterska",
    "barnsköterskor": "barnsköterska",
    "barnsköterskorna": "barnsköterska",
    "barnsköterskornas": "barnsköterska",
    "barnsköterskors": "barnsköterska",
    "barnsliga": "barnslig",
    "barnsligare": "barnslig",
    "barnsligares": "barnslig",
    "barnsligas": "barnslig",
    "barnsligast": "barnslig",
    "barnsligaste": "barnslig",
    "barnsligastes": "barnslig",
    "barnsligasts": "barnslig",
    "barnslige": "barnslig",
    "barnsliges": "barnslig",
    "barnsligheten": "barnslighet",
    "barnslighetens": "barnslighet",
    "barnsligheter": "barnslighet",
    "barnsligheterna": "barnslighet",
    "barnsligheternas": "barnslighet",
    "barnsligheters": "barnslighet",
    "barnslighets": "barnslighet",
    "barnsligs": "barnslig",
    "barnsligt": "barnslig",
    "barnsligts": "barnslig",
    "barnsoldaten": "barnsoldat",
    "barnsoldatens": "barnsoldat",
    "barnsoldater": "barnsoldat",
    "barnsoldaterna": "barnsoldat",
    "barnsoldaternas": "barnsoldat",
    "barnsoldaters": "barnsoldat",
    "barnsoldats": "barnsoldat",
    "barnstugan": "barnstuga",
    "barnstugans": "barnstuga",
    "barnstugas": "barnstuga",
    "barnstuge": "barnstuga",
    "barnstugor": "barnstuga",
    "barnstugorna": "barnstuga",
    "barnstugornas": "barnstuga",
    "barnstugors": "barnstuga",
    "barnstugu": "barnstuga",
    "barnsäkerheten": "barnsäkerhet",
    "barnsäkerhetens": "barnsäkerhet",
    "barnsäkerhets": "barnsäkerhet",
    "barnsäkers": "barnsäker",
    "barnsäkert": "barnsäker",
    "barnsäkerts": "barnsäker",
    "barnsäkra": "barnsäker",
    "barnsäkrare": "barnsäker",
    "barnsäkrares": "barnsäker",
    "barnsäkras": "barnsäker",
    "barnsäkrast": "barnsäker",
    "barnsäkraste": "barnsäker",
    "barnsäkrastes": "barnsäker",
    "barnsäkrasts": "barnsäker",
    "barnsäkre": "barnsäker",
    "barnsäkres": "barnsäker",
    "barnsängar": "barnsäng",
    "barnsängarna": "barnsäng",
    "barnsängarnas": "barnsäng",
    "barnsängars": "barnsäng",
    "barnsängen": "barnsäng",
    "barnsängens": "barnsäng",
    "barnsängs": "barnsäng",
    "barnteckningar": "barnteckning",
    "barnteckningarna": "barnteckning",
    "barnteckningarnas": "barnteckning",
    "barnteckningars": "barnteckning",
    "barnteckningen": "barnteckning",
    "barnteckningens": "barnteckning",
    "barntecknings": "barnteckning",
    "barntillsynen": "barntillsyn",
    "barntillsynens": "barntillsyn",
    "barntillsyns": "barntillsyn",
    "barntillåtenheten": "barntillåtenhet",
    "barntillåtenhetens": "barntillåtenhet",
    "barntillåtenhets": "barntillåtenhet",
    "barntillåtens": "barntillåten",
    "barntillåtet": "barntillåten",
    "barntillåtets": "barntillåten",
    "barntillåtna": "barntillåten",
    "barntillåtnare": "barntillåten",
    "barntillåtnares": "barntillåten",
    "barntillåtnas": "barntillåten",
    "barntillåtnast": "barntillåten",
    "barntillåtnaste": "barntillåten",
    "barntillåtnastes": "barntillåten",
    "barntillåtnasts": "barntillåten",
    "barntillåtne": "barntillåten",
    "barntillåtnes": "barntillåten",
    "barntoaletten": "barntoalett",
    "barntoalettens": "barntoalett",
    "barntoaletter": "barntoalett",
    "barntoaletterna": "barntoalett",
    "barntoaletternas": "barntoalett",
    "barntoaletters": "barntoalett",
    "barntoaletts": "barntoalett",
    "barnungar": "barnunge",
    "barnungarna": "barnunge",
    "barnungarnas": "barnunge",
    "barnungars": "barnunge",
    "barnungen": "barnunge",
    "barnungens": "barnunge",
    "barnunges": "barnunge",
    "barnvagnar": "barnvagn",
    "barnvagnarna": "barnvagn",
    "barnvagnarnas": "barnvagn",
    "barnvagnars": "barnvagn",
    "barnvagnen": "barnvagn",
    "barnvagnens": "barnvagn",
    "barnvagns": "barnvagn",
    "barnvakten": "barnvakt",
    "barnvaktens": "barnvakt",
    "barnvakter": "barnvakt",
    "barnvakterna": "barnvakt",
    "barnvakternas": "barnvakt",
    "barnvakters": "barnvakt",
    "barnvakts": "barnvakt",
    "barnvattenkannan": "barnvattenkanna",
    "barnvattenkannans": "barnvattenkanna",
    "barnvattenkannas": "barnvattenkanna",
    "barnvattenkanne": "barnvattenkanna",
    "barnvattenkannor": "barnvattenkanna",
    "barnvattenkannorna": "barnvattenkanna",
    "barnvattenkannornas": "barnvattenkanna",
    "barnvattenkannors": "barnvattenkanna",
    "barnvis": "barnvisa",
    "barnvisan": "barnvisa",
    "barnvisans": "barnvisa",
    "barnvisas": "barnvisa",
    "barnvise": "barnvisa",
    "barnvisor": "barnvisa",
    "barnvisorna": "barnvisa",
    "barnvisornas": "barnvisa",
    "barnvisors": "barnvisa",
    "barnvälgörenhetsorganisationen": "barnvälgörenhetsorganisation",
    "barnvälgörenhetsorganisationens": "barnvälgörenhetsorganisation",
    "barnvälgörenhetsorganisationer": "barnvälgörenhetsorganisation",
    "barnvälgörenhetsorganisationerna": "barnvälgörenhetsorganisation",
    "barnvälgörenhetsorganisationernas": "barnvälgörenhetsorganisation",
    "barnvälgörenhetsorganisationers": "barnvälgörenhetsorganisation",
    "barnvälgörenhetsorganisations": "barnvälgörenhetsorganisation",
    "barocka": "barock",
    "barockare": "barock",
    "barockares": "barock",
    "barockas": "barock",
    "barockast": "barock",
    "barockaste": "barock",
    "barockastes": "barock",
    "barockasts": "barock",
    "barocke": "barock",
    "barocken": "barock",
    "barockens": "barock",
    "barockes": "barock",
    "barockkonsten": "barockkonst",
    "barockkonstens": "barockkonst",
    "barockkonster": "barockkonst",
    "barockkonsterna": "barockkonst",
    "barockkonsternas": "barockkonst",
    "barockkonsters": "barockkonst",
    "barockkonsts": "barockkonst",
    "barocklyriken": "barocklyrik",
    "barocklyrikens": "barocklyrik",
    "barocklyriks": "barocklyrik",
    "barockmusiken": "barockmusik",
    "barockmusikens": "barockmusik",
    "barockmusiks": "barockmusik",
    "barockmässiga": "barockmässig",
    "barockmässigare": "barockmässig",
    "barockmässigares": "barockmässig",
    "barockmässigas": "barockmässig",
    "barockmässigast": "barockmässig",
    "barockmässigaste": "barockmässig",
    "barockmässigastes": "barockmässig",
    "barockmässigasts": "barockmässig",
    "barockmässige": "barockmässig",
    "barockmässiges": "barockmässig",
    "barockmässigs": "barockmässig",
    "barockmässigt": "barockmässig",
    "barockmässigts": "barockmässig",
    "barockpärl": "barockpärla",
    "barockpärlan": "barockpärla",
    "barockpärlans": "barockpärla",
    "barockpärlas": "barockpärla",
    "barockpärle": "barockpärla",
    "barockpärlor": "barockpärla",
    "barockpärlorna": "barockpärla",
    "barockpärlornas": "barockpärla",
    "barockpärlors": "barockpärla",
    "barockpärls": "barockpärla",
    "barocks": "barock",
    "barockstilar": "barockstil",
    "barockstilarna": "barockstil",
    "barockstilarnas": "barockstil",
    "barockstilars": "barockstil",
    "barockstilen": "barockstil",
    "barockstilens": "barockstil",
    "barockstils": "barockstil",
    "barockt": "barock",
    "barockts": "barock",
    "barografen": "barograf",
    "barografens": "barograf",
    "barografer": "barograf",
    "barograferna": "barograf",
    "barografernas": "barograf",
    "barografers": "barograf",
    "barografs": "barograf",
    "barogrammen": "barogram",
    "barogrammens": "barogram",
    "barogrammet": "barogram",
    "barogrammets": "barogram",
    "barograms": "barogram",
    "barometerfallen": "barometerfall",
    "barometerfallens": "barometerfall",
    "barometerfallet": "barometerfall",
    "barometerfallets": "barometerfall",
    "barometerfalls": "barometerfall",
    "barometern": "barometer",
    "barometerns": "barometer",
    "barometers": "barometer",
    "barometerstånden": "barometerstånd",
    "barometerståndens": "barometerstånd",
    "barometerståndet": "barometerstånd",
    "barometerståndets": "barometerstånd",
    "barometerstånds": "barometerstånd",
    "barometrar": "barometer",
    "barometrarna": "barometer",
    "barometrarnas": "barometer",
    "barometrars": "barometer",
    "barometriska": "barometrisk",
    "barometriskare": "barometrisk",
    "barometriskares": "barometrisk",
    "barometriskas": "barometrisk",
    "barometriskast": "barometrisk",
    "barometriskaste": "barometrisk",
    "barometriskastes": "barometrisk",
    "barometriskasts": "barometrisk",
    "barometriske": "barometrisk",
    "barometriskes": "barometrisk",
    "barometrisks": "barometrisk",
    "barometriskt": "barometrisk",
    "barometriskts": "barometrisk",
    "baronen": "baron",
    "baronens": "baron",
    "baroner": "baron",
    "baronerna": "baron",
    "baronernas": "baron",
    "baroners": "baron",
    "baroness": "baronessa",
    "baronessan": "baronessa",
    "baronessans": "baronessa",
    "baronessas": "baronessa",
    "baronesse": "baronessa",
    "baronessor": "baronessa",
    "baronessorna": "baronessa",
    "baronessornas": "baronessa",
    "baronessors": "baronessa",
    "barons": "baron",
    "barospiratorer": "barospirator",
    "barospiratorerna": "barospirator",
    "barospiratorernas": "barospirator",
    "barospiratorers": "barospirator",
    "barospiratorn": "barospirator",
    "barospiratorns": "barospirator",
    "barospirators": "barospirator",
    "barr": "barra",
    "barrad": "barra",
    "barrade": "barra",
    "barrades": "barra",
    "barrads": "barra",
    "barrande": "barra",
    "barranden": "barrande",
    "barrandena": "barrande",
    "barrandenas": "barrande",
    "barrandens": "barrande",
    "barrandes": "barrande",
    "barrandet": "barrande",
    "barrandets": "barrande",
    "barrar": "barra",
    "barras": "barra",
    "barrat": "barra",
    "barrats": "barra",
    "barrdoften": "barrdoft",
    "barrdoftens": "barrdoft",
    "barrdofter": "barrdoft",
    "barrdofterna": "barrdoft",
    "barrdofternas": "barrdoft",
    "barrdofters": "barrdoft",
    "barrdofts": "barrdoft",
    "barren": "barr",
    "barrens": "barr",
    "barrer": "barr",
    "barrerna": "barr",
    "barrernas": "barr",
    "barrers": "barr",
    "barret": "barr",
    "barrets": "barr",
    "barrikaden": "barrikad",
    "barrikadens": "barrikad",
    "barrikader": "barrikad",
    "barrikaderad": "barrikadera",
    "barrikaderade": "barrikadera",
    "barrikaderades": "barrikadera",
    "barrikaderads": "barrikadera",
    "barrikaderande": "barrikadera",
    "barrikaderanden": "barrikaderande",
    "barrikaderandena": "barrikaderande",
    "barrikaderandenas": "barrikaderande",
    "barrikaderandens": "barrikaderande",
    "barrikaderandes": "barrikaderande",
    "barrikaderandet": "barrikaderande",
    "barrikaderandets": "barrikaderande",
    "barrikaderar": "barrikadera",
    "barrikaderas": "barrikadera",
    "barrikaderat": "barrikadera",
    "barrikaderats": "barrikadera",
    "barrikaderbara": "barrikaderbar",
    "barrikaderbarare": "barrikaderbar",
    "barrikaderbarares": "barrikaderbar",
    "barrikaderbaras": "barrikaderbar",
    "barrikaderbarast": "barrikaderbar",
    "barrikaderbaraste": "barrikaderbar",
    "barrikaderbarastes": "barrikaderbar",
    "barrikaderbarasts": "barrikaderbar",
    "barrikaderbare": "barrikaderbar",
    "barrikaderbares": "barrikaderbar",
    "barrikaderbarheten": "barrikaderbarhet",
    "barrikaderbarhetens": "barrikaderbarhet",
    "barrikaderbarhets": "barrikaderbarhet",
    "barrikaderbars": "barrikaderbar",
    "barrikaderbart": "barrikaderbar",
    "barrikaderbarts": "barrikaderbar",
    "barrikaderingar": "barrikadering",
    "barrikaderingarna": "barrikadering",
    "barrikaderingarnas": "barrikadering",
    "barrikaderingars": "barrikadering",
    "barrikaderingen": "barrikadering",
    "barrikaderingens": "barrikadering",
    "barrikaderings": "barrikadering",
    "barrikaderna": "barrikad",
    "barrikadernas": "barrikad",
    "barrikaders": "barrikad",
    "barrikadkämpar": "barrikadkämpe",
    "barrikadkämparna": "barrikadkämpe",
    "barrikadkämparnas": "barrikadkämpe",
    "barrikadkämpars": "barrikadkämpe",
    "barrikadkämpen": "barrikadkämpe",
    "barrikadkämpens": "barrikadkämpe",
    "barrikadkämpes": "barrikadkämpe",
    "barrikads": "barrikad",
    "barrikadstriden": "barrikadstrid",
    "barrikadstridens": "barrikadstrid",
    "barrikadstrider": "barrikadstrid",
    "barrikadstriderna": "barrikadstrid",
    "barrikadstridernas": "barrikadstrid",
    "barrikadstriders": "barrikadstrid",
    "barrikadstrids": "barrikadstrid",
    "barriären": "barriär",
    "barriärens": "barriär",
    "barriärer": "barriär",
    "barriärerna": "barriär",
    "barriärernas": "barriär",
    "barriärers": "barriär",
    "barriärs": "barriär",
    "barrs": "barr",
    "barrskogar": "barrskog",
    "barrskogarna": "barrskog",
    "barrskogarnas": "barrskog",
    "barrskogars": "barrskog",
    "barrskogen": "barrskog",
    "barrskogens": "barrskog",
    "barrskogs": "barrskog",
    "barrskogsgränsen": "barrskogsgräns",
    "barrskogsgränsens": "barrskogsgräns",
    "barrskogsgränser": "barrskogsgräns",
    "barrskogsgränserna": "barrskogsgräns",
    "barrskogsgränsernas": "barrskogsgräns",
    "barrskogsgränsers": "barrskogsgräns",
    "barrskogsnunnan": "barrskogsnunna",
    "barrskogsnunnans": "barrskogsnunna",
    "barrskogsnunnas": "barrskogsnunna",
    "barrskogsnunne": "barrskogsnunna",
    "barrskogsnunnor": "barrskogsnunna",
    "barrskogsnunnorna": "barrskogsnunna",
    "barrskogsnunnornas": "barrskogsnunna",
    "barrskogsnunnors": "barrskogsnunna",
    "barrskogsregionen": "barrskogsregion",
    "barrskogsregionens": "barrskogsregion",
    "barrskogsregioner": "barrskogsregion",
    "barrskogsregionerna": "barrskogsregion",
    "barrskogsregionernas": "barrskogsregion",
    "barrskogsregioners": "barrskogsregion",
    "barrskogsregions": "barrskogsregion",
    "barrträden": "barrträd",
    "barrträdens": "barrträd",
    "barrträdet": "barrträd",
    "barrträdets": "barrträd",
    "barrträds": "barrträd",
    "barrträdskott": "barrträdskotte",
    "barrträdskottar": "barrträdskotte",
    "barrträdskottarna": "barrträdskotte",
    "barrträdskottarnas": "barrträdskotte",
    "barrträdskottars": "barrträdskotte",
    "barrträdskotten": "barrträdskotte",
    "barrträdskottens": "barrträdskotte",
    "barrträdskottes": "barrträdskotte",
    "barrträdskotts": "barrträdskotte",
    "barrträdsplant": "barrträdsplanta",
    "barrträdsplantan": "barrträdsplanta",
    "barrträdsplantans": "barrträdsplanta",
    "barrträdsplantas": "barrträdsplanta",
    "barrträdsplante": "barrträdsplanta",
    "barrträdsplantor": "barrträdsplanta",
    "barrträdsplantorna": "barrträdsplanta",
    "barrträdsplantornas": "barrträdsplanta",
    "barrträdsplantors": "barrträdsplanta",
    "barrträdsplants": "barrträdsplanta",
    "barrträdssorten": "barrträdssort",
    "barrträdssortens": "barrträdssort",
    "barrträdssorter": "barrträdssort",
    "barrträdssorterna": "barrträdssort",
    "barrträdssorternas": "barrträdssort",
    "barrträdssorters": "barrträdssort",
    "barrträdssorts": "barrträdssort",
    "bars": "bära",
    "barserveringar": "barservering",
    "barserveringarna": "barservering",
    "barserveringarnas": "barservering",
    "barserveringars": "barservering",
    "barserveringen": "barservering",
    "barserveringens": "barservering",
    "barserverings": "barservering",
    "barska": "barsk",
    "barskare": "barsk",
    "barskares": "barsk",
    "barskas": "barsk",
    "barskast": "barsk",
    "barskaste": "barsk",
    "barskastes": "barsk",
    "barskasts": "barsk",
    "barske": "barsk",
    "barskes": "barsk",
    "barskheten": "barskhet",
    "barskhetens": "barskhet",
    "barskhets": "barskhet",
    "barskrapade": "barskrapad",
    "barskrapades": "barskrapad",
    "barskrapads": "barskrapad",
    "barskrapat": "barskrapad",
    "barskrapats": "barskrapad",
    "barsks": "barsk",
    "barskt": "barsk",
    "barskts": "barsk",
    "barskåpen": "barskåp",
    "barskåpens": "barskåp",
    "barskåpet": "barskåp",
    "barskåpets": "barskåp",
    "barskåps": "barskåp",
    "barstolar": "barstol",
    "barstolarna": "barstol",
    "barstolarnas": "barstol",
    "barstolars": "barstol",
    "barstolen": "barstol",
    "barstolens": "barstol",
    "barstols": "barstol",
    "bart": "bar",
    "bartendern": "bartender",
    "bartenderns": "bartender",
    "bartenders": "bartender",
    "bartendrar": "bartender",
    "bartendrarna": "bartender",
    "bartendrarnas": "bartender",
    "bartendrars": "bartender",
    "barts": "bar",
    "barvintern": "barvinter",
    "barvinterns": "barvinter",
    "barvinters": "barvinter",
    "barvintrar": "barvinter",
    "barvintrarna": "barvinter",
    "barvintrarnas": "barvinter",
    "barvintrars": "barvinter",
    "barysfären": "barysfär",
    "barysfärens": "barysfär",
    "barysfärer": "barysfär",
    "barysfärerna": "barysfär",
    "barysfärernas": "barysfär",
    "barysfärers": "barysfär",
    "barysfärs": "barysfär",
    "baryten": "baryt",
    "barytens": "baryt",
    "barytonen": "baryton",
    "barytonens": "baryton",
    "barytoner": "baryton",
    "barytonerna": "baryton",
    "barytonernas": "baryton",
    "barytoners": "baryton",
    "barytons": "baryton",
    "baryts": "baryt",
    "bas": "basa",
    "basade": "basa",
    "basades": "basa",
    "basala": "basal",
    "basalare": "basal",
    "basalares": "basal",
    "basalas": "basal",
    "basalast": "basal",
    "basalaste": "basal",
    "basalastes": "basal",
    "basalasts": "basal",
    "basale": "basal",
    "basales": "basal",
    "basals": "basal",
    "basalt": "basal",
    "basalten": "basalt",
    "basaltens": "basalt",
    "basalts": "basalt",
    "basande": "basa",
    "basanden": "basande",
    "basandena": "basande",
    "basandenas": "basande",
    "basandens": "basande",
    "basandes": "basande",
    "basandet": "basande",
    "basandets": "basande",
    "basar": "basa",
    "basaren": "basar",
    "basarens": "basar",
    "basarer": "basar",
    "basarerna": "basar",
    "basarernas": "basar",
    "basarers": "basar",
    "basarna": "bas",
    "basarnas": "bas",
    "basars": "basar",
    "basas": "basa",
    "basat": "basa",
    "basats": "basa",
    "basbeloppen": "basbelopp",
    "basbeloppens": "basbelopp",
    "basbeloppet": "basbelopp",
    "basbeloppets": "basbelopp",
    "basbelopps": "basbelopp",
    "baseballen": "baseball",
    "baseballens": "baseball",
    "baseballs": "baseball",
    "baseballsträet": "baseballsträ",
    "baseballsträets": "baseballsträ",
    "baseballsträn": "baseballsträ",
    "baseballsträna": "baseballsträ",
    "baseballstränas": "baseballsträ",
    "baseballsträns": "baseballsträ",
    "baseballsträs": "baseballsträ",
    "baseballsträt": "baseballsträ",
    "baseballsträts": "baseballsträ",
    "baseballträet": "baseballträ",
    "baseballträets": "baseballträ",
    "baseballträn": "baseballträ",
    "baseballträna": "baseballträ",
    "baseballtränas": "baseballträ",
    "baseballträns": "baseballträ",
    "baseballträs": "baseballträ",
    "baseballträt": "baseballträ",
    "baseballträts": "baseballträ",
    "basebollar": "baseboll",
    "basebollarna": "baseboll",
    "basebollarnas": "baseboll",
    "basebollars": "baseboll",
    "basebollen": "baseboll",
    "basebollens": "baseboll",
    "basebolls": "baseboll",
    "basebollsträet": "basebollsträ",
    "basebollsträets": "basebollsträ",
    "basebollsträn": "basebollsträ",
    "basebollsträna": "basebollsträ",
    "basebollstränas": "basebollsträ",
    "basebollsträns": "basebollsträ",
    "basebollsträs": "basebollsträ",
    "basebollsträt": "basebollsträ",
    "basebollsträts": "basebollsträ",
    "basebollträet": "basebollträ",
    "basebollträets": "basebollträ",
    "basebollträn": "basebollträ",
    "basebollträna": "basebollträ",
    "basebolltränas": "basebollträ",
    "basebollträns": "basebollträ",
    "basebollträs": "basebollträ",
    "basebollträt": "basebollträ",
    "basebollträts": "basebollträ",
    "basedowen": "basedow",
    "basedowens": "basedow",
    "basedows": "basedow",
    "basen": "bas",
    "basenheten": "basenhet",
    "basenhetens": "basenhet",
    "basenheter": "basenhet",
    "basenheterna": "basenhet",
    "basenheternas": "basenhet",
    "basenheters": "basenhet",
    "basenhets": "basenhet",
    "basens": "bas",
    "baser": "bas",
    "baserad": "basera",
    "baserade": "basera",
    "baserades": "basera",
    "baserads": "basera",
    "baserande": "basera",
    "baseranden": "baserande",
    "baserandena": "baserande",
    "baserandenas": "baserande",
    "baserandens": "baserande",
    "baserandes": "baserande",
    "baserandet": "baserande",
    "baserandets": "baserande",
    "baserar": "basera",
    "baseras": "basera",
    "baserat": "basera",
    "baserats": "basera",
    "baserbara": "baserbar",
    "baserbarare": "baserbar",
    "baserbarares": "baserbar",
    "baserbaras": "baserbar",
    "baserbarast": "baserbar",
    "baserbaraste": "baserbar",
    "baserbarastes": "baserbar",
    "baserbarasts": "baserbar",
    "baserbare": "baserbar",
    "baserbares": "baserbar",
    "baserbarheten": "baserbarhet",
    "baserbarhetens": "baserbarhet",
    "baserbarhets": "baserbarhet",
    "baserbars": "baserbar",
    "baserbart": "baserbar",
    "baserbarts": "baserbar",
    "baseringar": "basering",
    "baseringarna": "basering",
    "baseringarnas": "basering",
    "baseringars": "basering",
    "baseringen": "basering",
    "baseringens": "basering",
    "baserings": "basering",
    "baserna": "bas",
    "basernas": "bas",
    "basers": "bas",
    "basfiolen": "basfiol",
    "basfiolens": "basfiol",
    "basfioler": "basfiol",
    "basfiolerna": "basfiol",
    "basfiolernas": "basfiol",
    "basfiolers": "basfiol",
    "basfiols": "basfiol",
    "basfiolsfodralen": "basfiolsfodral",
    "basfiolsfodralens": "basfiolsfodral",
    "basfiolsfodralet": "basfiolsfodral",
    "basfiolsfodralets": "basfiolsfodral",
    "basfiolsfodrals": "basfiolsfodral",
    "basfiolsfodralsmakar": "basfiolsfodralsmakare",
    "basfiolsfodralsmakaregesällen": "basfiolsfodralsmakaregesäll",
    "basfiolsfodralsmakaregesällens": "basfiolsfodralsmakaregesäll",
    "basfiolsfodralsmakaregesäller": "basfiolsfodralsmakaregesäll",
    "basfiolsfodralsmakaregesällerna": "basfiolsfodralsmakaregesäll",
    "basfiolsfodralsmakaregesällernas": "basfiolsfodralsmakaregesäll",
    "basfiolsfodralsmakaregesällers": "basfiolsfodralsmakaregesäll",
    "basfiolsfodralsmakaregesälls": "basfiolsfodralsmakaregesäll",
    "basfiolsfodralsmakaren": "basfiolsfodralsmakare",
    "basfiolsfodralsmakarens": "basfiolsfodralsmakare",
    "basfiolsfodralsmakares": "basfiolsfodralsmakare",
    "basfiolsfodralsmakarna": "basfiolsfodralsmakare",
    "basfiolsfodralsmakarnas": "basfiolsfodralsmakare",
    "basfärdigheten": "basfärdighet",
    "basfärdighetens": "basfärdighet",
    "basfärdigheter": "basfärdighet",
    "basfärdigheterna": "basfärdighet",
    "basfärdigheternas": "basfärdighet",
    "basfärdigheters": "basfärdighet",
    "basfärdighets": "basfärdighet",
    "basfödan": "basföda",
    "basfödans": "basföda",
    "basfödas": "basföda",
    "basgitarren": "basgitarr",
    "basgitarrens": "basgitarr",
    "basgitarrer": "basgitarr",
    "basgitarrerna": "basgitarr",
    "basgitarrernas": "basgitarr",
    "basgitarrers": "basgitarr",
    "basgitarrs": "basgitarr",
    "basilik": "basilika",
    "basilikan": "basilika",
    "basilikans": "basilika",
    "basilikas": "basilika",
    "basilike": "basilika",
    "basilikor": "basilika",
    "basilikorna": "basilika",
    "basilikornas": "basilika",
    "basilikors": "basilika",
    "basiliks": "basilika",
    "basilisken": "basilisk",
    "basiliskens": "basilisk",
    "basilisker": "basilisk",
    "basiliskerna": "basilisk",
    "basiliskernas": "basilisk",
    "basiliskers": "basilisk",
    "basilisks": "basilisk",
    "basisen": "basis",
    "basisens": "basis",
    "basiska": "basisk",
    "basiskare": "basisk",
    "basiskares": "basisk",
    "basiskas": "basisk",
    "basiskast": "basisk",
    "basiskaste": "basisk",
    "basiskastes": "basisk",
    "basiskasts": "basisk",
    "basiske": "basisk",
    "basiskes": "basisk",
    "basisks": "basisk",
    "basiskt": "basisk",
    "basiskts": "basisk",
    "basisten": "basist",
    "basistens": "basist",
    "basister": "basist",
    "basisterna": "basist",
    "basisternas": "basist",
    "basisters": "basist",
    "basists": "basist",
    "basken": "bask",
    "baskens": "bask",
    "basker": "bask",
    "baskern": "basker",
    "baskerna": "bask",
    "baskernas": "bask",
    "baskerns": "basker",
    "baskers": "basker",
    "basketbollar": "basketboll",
    "basketbollarna": "basketboll",
    "basketbollarnas": "basketboll",
    "basketbollars": "basketboll",
    "basketbollen": "basketboll",
    "basketbollens": "basketboll",
    "basketbolls": "basketboll",
    "basketen": "basket",
    "basketens": "basket",
    "basketproffsen": "basketproffs",
    "basketproffsens": "basketproffs",
    "basketproffset": "basketproffs",
    "basketproffsets": "basketproffs",
    "baskets": "basket",
    "baskisk": "baskiska",
    "baskiska": "baskisk",
    "baskiskan": "baskiska",
    "baskiskans": "baskiska",
    "baskiskare": "baskisk",
    "baskiskares": "baskisk",
    "baskiskas": "baskiska",
    "baskiskast": "baskisk",
    "baskiskaste": "baskisk",
    "baskiskastes": "baskisk",
    "baskiskasts": "baskisk",
    "baskiske": "baskiska",
    "baskiskes": "baskisk",
    "baskiskor": "baskiska",
    "baskiskorna": "baskiska",
    "baskiskornas": "baskiska",
    "baskiskors": "baskiska",
    "baskisks": "baskisk",
    "baskiskt": "baskisk",
    "baskiskts": "baskisk",
    "baskrar": "basker",
    "baskrarna": "basker",
    "baskrarnas": "basker",
    "baskrars": "basker",
    "basks": "bask",
    "baslinjen": "baslinje",
    "baslinjens": "baslinje",
    "baslinjer": "baslinje",
    "baslinjerna": "baslinje",
    "baslinjernas": "baslinje",
    "baslinjers": "baslinje",
    "baslinjes": "baslinje",
    "baslägerna": "basläger",
    "baslägernas": "basläger",
    "baslägers": "basläger",
    "baslägren": "basläger",
    "baslägrens": "basläger",
    "baslägret": "basläger",
    "baslägrets": "basläger",
    "basningar": "basning",
    "basningarna": "basning",
    "basningarnas": "basning",
    "basningars": "basning",
    "basningen": "basning",
    "basningens": "basning",
    "basnings": "basning",
    "basorganisationen": "basorganisation",
    "basorganisationens": "basorganisation",
    "basorganisationer": "basorganisation",
    "basorganisationerna": "basorganisation",
    "basorganisationernas": "basorganisation",
    "basorganisationers": "basorganisation",
    "basorganisations": "basorganisation",
    "basplatt": "basplatta",
    "basplattan": "basplatta",
    "basplattans": "basplatta",
    "basplattas": "basplatta",
    "basplatte": "basplatta",
    "basplattor": "basplatta",
    "basplattorna": "basplatta",
    "basplattornas": "basplatta",
    "basplattors": "basplatta",
    "basplatts": "basplatta",
    "basreliefen": "basrelief",
    "basreliefens": "basrelief",
    "basreliefer": "basrelief",
    "basrelieferna": "basrelief",
    "basreliefernas": "basrelief",
    "basreliefers": "basrelief",
    "basreliefs": "basrelief",
    "bass": "basse",
    "bassar": "basse",
    "bassarna": "basse",
    "bassarnas": "basse",
    "bassars": "basse",
    "bassen": "basse",
    "bassens": "basse",
    "basses": "basse",
    "bassetar": "basset",
    "bassetarna": "basset",
    "bassetarnas": "basset",
    "bassetars": "basset",
    "basseten": "basset",
    "bassetens": "basset",
    "bassets": "basset",
    "bassetsarna": "basset",
    "bassetsarnas": "basset",
    "bassetsen": "basset",
    "bassetsens": "basset",
    "bassningar": "bassning",
    "bassningarna": "bassning",
    "bassningarnas": "bassning",
    "bassningars": "bassning",
    "bassningen": "bassning",
    "bassningens": "bassning",
    "bassnings": "bassning",
    "basstationen": "basstation",
    "basstationens": "basstation",
    "basstationer": "basstation",
    "basstationerna": "basstation",
    "basstationernas": "basstation",
    "basstationers": "basstation",
    "basstations": "basstation",
    "bassträck": "bassträcka",
    "bassträckan": "bassträcka",
    "bassträckans": "bassträcka",
    "bassträckas": "bassträcka",
    "bassträcke": "bassträcka",
    "bassträckor": "bassträcka",
    "bassträckorna": "bassträcka",
    "bassträckornas": "bassträcka",
    "bassträckors": "bassträcka",
    "bassträcks": "bassträcka",
    "bassängen": "bassäng",
    "bassängens": "bassäng",
    "bassänger": "bassäng",
    "bassängerna": "bassäng",
    "bassängernas": "bassäng",
    "bassängers": "bassäng",
    "bassängs": "bassäng",
    "bast": "basta",
    "bastad": "basta",
    "bastade": "basta",
    "bastades": "basta",
    "bastads": "basta",
    "bastande": "basta",
    "bastanden": "bastande",
    "bastandena": "bastande",
    "bastandenas": "bastande",
    "bastandens": "bastande",
    "bastandes": "bastande",
    "bastandet": "bastande",
    "bastandets": "bastande",
    "bastanta": "bastant",
    "bastantare": "bastant",
    "bastantares": "bastant",
    "bastantas": "bastant",
    "bastantast": "bastant",
    "bastantaste": "bastant",
    "bastantastes": "bastant",
    "bastantasts": "bastant",
    "bastante": "bastant",
    "bastantes": "bastant",
    "bastants": "bastant",
    "bastar": "basta",
    "bastarden": "bastard",
    "bastardens": "bastard",
    "bastarder": "bastard",
    "bastarderna": "bastard",
    "bastardernas": "bastard",
    "bastarders": "bastard",
    "bastardformen": "bastardform",
    "bastardformens": "bastardform",
    "bastardformer": "bastardform",
    "bastardformerna": "bastardform",
    "bastardformernas": "bastardform",
    "bastardformers": "bastardform",
    "bastardforms": "bastardform",
    "bastardnäktergalar": "bastardnäktergal",
    "bastardnäktergalarna": "bastardnäktergal",
    "bastardnäktergalarnas": "bastardnäktergal",
    "bastardnäktergalars": "bastardnäktergal",
    "bastardnäktergalen": "bastardnäktergal",
    "bastardnäktergalens": "bastardnäktergal",
    "bastardnäktergals": "bastardnäktergal",
    "bastards": "bastard",
    "bastas": "basta",
    "bastat": "basta",
    "bastats": "basta",
    "bastcellen": "bastcell",
    "bastcellens": "bastcell",
    "bastceller": "bastcell",
    "bastcellerna": "bastcell",
    "bastcellernas": "bastcell",
    "bastcellers": "bastcell",
    "bastcells": "bastcell",
    "basten": "bast",
    "bastens": "bast",
    "bastet": "bast",
    "bastets": "bast",
    "bastfibern": "bastfiber",
    "bastfiberns": "bastfiber",
    "bastfibers": "bastfiber",
    "bastfibrer": "bastfiber",
    "bastfibrerna": "bastfiber",
    "bastfibrernas": "bastfiber",
    "bastfibrers": "bastfiber",
    "bastingeringar": "bastingering",
    "bastingeringarna": "bastingering",
    "bastingeringarnas": "bastingering",
    "bastingeringars": "bastingering",
    "bastingeringen": "bastingering",
    "bastingeringens": "bastingering",
    "bastingerings": "bastingering",
    "bastionen": "bastion",
    "bastionens": "bastion",
    "bastioner": "bastion",
    "bastionerna": "bastion",
    "bastionernas": "bastion",
    "bastioners": "bastion",
    "bastions": "bastion",
    "bastkjolar": "bastkjol",
    "bastkjolarna": "bastkjol",
    "bastkjolarnas": "bastkjol",
    "bastkjolars": "bastkjol",
    "bastkjolen": "bastkjol",
    "bastkjolens": "bastkjol",
    "bastkjols": "bastkjol",
    "bastmatt": "bastmatta",
    "bastmattan": "bastmatta",
    "bastmattans": "bastmatta",
    "bastmattas": "bastmatta",
    "bastmatte": "bastmatta",
    "bastmattor": "bastmatta",
    "bastmattorna": "bastmatta",
    "bastmattornas": "bastmatta",
    "bastmattors": "bastmatta",
    "bastmatts": "bastmatta",
    "bastonaden": "bastonad",
    "bastonadens": "bastonad",
    "bastonader": "bastonad",
    "bastonaderna": "bastonad",
    "bastonadernas": "bastonad",
    "bastonaders": "bastonad",
    "bastonads": "bastonad",
    "basts": "bast",
    "bastub": "bastuba",
    "bastubaden": "bastubad",
    "bastubadens": "bastubad",
    "bastubadet": "bastubad",
    "bastubadets": "bastubad",
    "bastubads": "bastubad",
    "bastuban": "bastuba",
    "bastubans": "bastuba",
    "bastubas": "bastuba",
    "bastube": "bastuba",
    "bastubor": "bastuba",
    "bastuborna": "bastuba",
    "bastubornas": "bastuba",
    "bastubors": "bastuba",
    "bastubs": "bastuba",
    "bastuföreningar": "bastuförening",
    "bastuföreningarna": "bastuförening",
    "bastuföreningarnas": "bastuförening",
    "bastuföreningars": "bastuförening",
    "bastuföreningen": "bastuförening",
    "bastuföreningens": "bastuförening",
    "bastuförenings": "bastuförening",
    "bastuklubbar": "bastuklubb",
    "bastuklubbarna": "bastuklubb",
    "bastuklubbarnas": "bastuklubb",
    "bastuklubbars": "bastuklubb",
    "bastuklubben": "bastuklubb",
    "bastuklubbens": "bastuklubb",
    "bastuklubbs": "bastuklubb",
    "bastun": "bastu",
    "bastuns": "bastu",
    "bastur": "bastu",
    "basturna": "bastu",
    "basturnas": "bastu",
    "basturs": "bastu",
    "bastus": "bastu",
    "basunen": "basun",
    "basunens": "basun",
    "basuner": "basun",
    "basunerna": "basun",
    "basunernas": "basun",
    "basuners": "basun",
    "basuns": "basun",
    "basunstötar": "basunstöt",
    "basunstötarna": "basunstöt",
    "basunstötarnas": "basunstöt",
    "basunstötars": "basunstöt",
    "basunstöten": "basunstöt",
    "basunstötens": "basunstöt",
    "basunstöts": "basunstöt",
    "basvar": "basvara",
    "basvaran": "basvara",
    "basvarans": "basvara",
    "basvaras": "basvara",
    "basvare": "basvara",
    "basvaror": "basvara",
    "basvarorna": "basvara",
    "basvarornas": "basvara",
    "basvarors": "basvara",
    "basvars": "basvara",
    "basvinkeln": "basvinkel",
    "basvinkelns": "basvinkel",
    "basvinkels": "basvinkel",
    "basvinklar": "basvinkel",
    "basvinklarna": "basvinkel",
    "basvinklarnas": "basvinkel",
    "basvinklars": "basvinkel",
    "basvägar": "basväg",
    "basvägarna": "basväg",
    "basvägarnas": "basväg",
    "basvägars": "basväg",
    "basvägen": "basväg",
    "basvägens": "basväg",
    "basvägs": "basväg",
    "basytan": "basyta",
    "basytans": "basyta",
    "basytas": "basyta",
    "basyte": "basyta",
    "basytor": "basyta",
    "basytorna": "basyta",
    "basytornas": "basyta",
    "basytors": "basyta",
    "basåren": "basår",
    "basårens": "basår",
    "basåret": "basår",
    "basårets": "basår",
    "basårs": "basår",
    "bataljen": "batalj",
    "bataljens": "batalj",
    "bataljer": "batalj",
    "bataljerna": "batalj",
    "bataljernas": "batalj",
    "bataljers": "batalj",
    "bataljmålar": "bataljmålare",
    "bataljmålaren": "bataljmålare",
    "bataljmålarens": "bataljmålare",
    "bataljmålares": "bataljmålare",
    "bataljmålarna": "bataljmålare",
    "bataljmålarnas": "bataljmålare",
    "bataljmålningar": "bataljmålning",
    "bataljmålningarna": "bataljmålning",
    "bataljmålningarnas": "bataljmålning",
    "bataljmålningars": "bataljmålning",
    "bataljmålningen": "bataljmålning",
    "bataljmålningens": "bataljmålning",
    "bataljmålnings": "bataljmålning",
    "bataljonen": "bataljon",
    "bataljonens": "bataljon",
    "bataljoner": "bataljon",
    "bataljonerna": "bataljon",
    "bataljonernas": "bataljon",
    "bataljoners": "bataljon",
    "bataljons": "bataljon",
    "bataljonschefen": "bataljonschef",
    "bataljonschefens": "bataljonschef",
    "bataljonschefer": "bataljonschef",
    "bataljonscheferna": "bataljonschef",
    "bataljonschefernas": "bataljonschef",
    "bataljonschefers": "bataljonschef",
    "bataljonschefs": "bataljonschef",
    "bataljs": "batalj",
    "bataten": "batat",
    "batatens": "batat",
    "batater": "batat",
    "bataterna": "batat",
    "bataternas": "batat",
    "bataters": "batat",
    "batats": "batat",
    "batiken": "batik",
    "batikens": "batik",
    "batiks": "batik",
    "batisten": "batist",
    "batistens": "batist",
    "batister": "batist",
    "batisterna": "batist",
    "batisternas": "batist",
    "batisters": "batist",
    "batists": "batist",
    "batongen": "batong",
    "batongens": "batong",
    "batonger": "batong",
    "batongerna": "batong",
    "batongernas": "batong",
    "batongers": "batong",
    "batongs": "batong",
    "batongslagen": "batongslag",
    "batongslagens": "batongslag",
    "batongslaget": "batongslag",
    "batongslagets": "batongslag",
    "batongslags": "batongslag",
    "battensen": "battens",
    "battensens": "battens",
    "batteridriften": "batteridrift",
    "batteridriftens": "batteridrift",
    "batteridrifts": "batteridrift",
    "batteridrivens": "batteridriven",
    "batteridrivet": "batteridriven",
    "batteridrivets": "batteridriven",
    "batteridrivna": "batteridriven",
    "batteridrivnare": "batteridriven",
    "batteridrivnares": "batteridriven",
    "batteridrivnas": "batteridriven",
    "batteridrivnast": "batteridriven",
    "batteridrivnaste": "batteridriven",
    "batteridrivnastes": "batteridriven",
    "batteridrivnasts": "batteridriven",
    "batteridrivne": "batteridriven",
    "batteridrivnes": "batteridriven",
    "batterielden": "batterield",
    "batterieldens": "batterield",
    "batterields": "batterield",
    "batterier": "batteri",
    "batterierna": "batteri",
    "batteriernas": "batteri",
    "batteriers": "batteri",
    "batteriet": "batteri",
    "batteriets": "batteri",
    "batteriklämman": "batteriklämma",
    "batteriklämmans": "batteriklämma",
    "batteriklämmas": "batteriklämma",
    "batteriklämme": "batteriklämma",
    "batteriklämmor": "batteriklämma",
    "batteriklämmorna": "batteriklämma",
    "batteriklämmornas": "batteriklämma",
    "batteriklämmors": "batteriklämma",
    "batteriladdar": "batteriladdare",
    "batteriladdaren": "batteriladdare",
    "batteriladdarens": "batteriladdare",
    "batteriladdares": "batteriladdare",
    "batteriladdarna": "batteriladdare",
    "batteriladdarnas": "batteriladdare",
    "batteriladdningar": "batteriladdning",
    "batteriladdningarna": "batteriladdning",
    "batteriladdningarnas": "batteriladdning",
    "batteriladdningars": "batteriladdning",
    "batteriladdningen": "batteriladdning",
    "batteriladdningens": "batteriladdning",
    "batteriladdnings": "batteriladdning",
    "batteriprovar": "batteriprovare",
    "batteriprovaren": "batteriprovare",
    "batteriprovarens": "batteriprovare",
    "batteriprovares": "batteriprovare",
    "batteriprovarna": "batteriprovare",
    "batteriprovarnas": "batteriprovare",
    "batteriradion": "batteriradio",
    "batteriradions": "batteriradio",
    "batteriradios": "batteriradio",
    "batteris": "batteri",
    "batterisekatören": "batterisekatör",
    "batterisekatörens": "batterisekatör",
    "batterisekatörer": "batterisekatör",
    "batterisekatörerna": "batterisekatör",
    "batterisekatörernas": "batterisekatör",
    "batterisekatörers": "batterisekatör",
    "batterisekatörs": "batterisekatör",
    "batteristen": "batterist",
    "batteristens": "batterist",
    "batterister": "batterist",
    "batteristerna": "batterist",
    "batteristernas": "batterist",
    "batteristers": "batterist",
    "batterists": "batterist",
    "batterit": "batteri",
    "batterits": "batteri",
    "batteritändningar": "batteritändning",
    "batteritändningarna": "batteritändning",
    "batteritändningarnas": "batteritändning",
    "batteritändningars": "batteritändning",
    "batteritändningen": "batteritändning",
    "batteritändningens": "batteritändning",
    "batteritändnings": "batteritändning",
    "batterivattens": "batterivatten",
    "batterivattnet": "batterivatten",
    "batterivattnets": "batterivatten",
    "battingar": "batting",
    "battingarna": "batting",
    "battingarnas": "batting",
    "battingars": "batting",
    "battingen": "batting",
    "battingens": "batting",
    "battings": "batting",
    "batysfären": "batysfär",
    "batysfärens": "batysfär",
    "batysfärer": "batysfär",
    "batysfärerna": "batysfär",
    "batysfärernas": "batysfär",
    "batysfärers": "batysfär",
    "batysfärs": "batysfär",
    "bauden": "baud",
    "baudens": "baud",
    "bauds": "baud",
    "bautastenar": "bautasten",
    "bautastenarna": "bautasten",
    "bautastenarnas": "bautasten",
    "bautastenars": "bautasten",
    "bautastenen": "bautasten",
    "bautastenens": "bautasten",
    "bautastens": "bautasten",
    "bauxiten": "bauxit",
    "bauxitens": "bauxit",
    "bauxits": "bauxit",
    "bax": "baxa",
    "baxad": "baxa",
    "baxade": "baxa",
    "baxades": "baxa",
    "baxads": "baxa",
    "baxande": "baxa",
    "baxanden": "baxande",
    "baxandena": "baxande",
    "baxandenas": "baxande",
    "baxandens": "baxande",
    "baxandes": "baxande",
    "baxandet": "baxande",
    "baxandets": "baxande",
    "baxar": "baxa",
    "baxas": "baxa",
    "baxat": "baxa",
    "baxats": "baxa",
    "baxnade": "baxna",
    "baxnades": "baxna",
    "baxnande": "baxna",
    "baxnanden": "baxnande",
    "baxnandena": "baxnande",
    "baxnandenas": "baxnande",
    "baxnandens": "baxnande",
    "baxnandes": "baxnande",
    "baxnandet": "baxnande",
    "baxnandets": "baxnande",
    "baxnar": "baxna",
    "baxnas": "baxna",
    "baxnat": "baxna",
    "baxnats": "baxna",
    "bazook": "bazooka",
    "bazookan": "bazooka",
    "bazookans": "bazooka",
    "bazookas": "bazooka",
    "bazooke": "bazooka",
    "bazookor": "bazooka",
    "bazookorna": "bazooka",
    "bazookornas": "bazooka",
    "bazookors": "bazooka",
    "bazooks": "bazooka",
    "beaglar": "beagle",
    "beaglarna": "beagle",
    "beaglarnas": "beagle",
    "beaglars": "beagle",
    "beaglen": "beagle",
    "beaglens": "beagle",
    "beagles": "beagle",
    "beakt": "beakta",
    "beaktad": "beakta",
    "beaktade": "beakta",
    "beaktades": "beakta",
    "beaktads": "beakta",
    "beaktande": "beakta",
    "beaktandes": "beaktande",
    "beaktandet": "beaktande",
    "beaktandets": "beaktande",
    "beaktansvärda": "beaktansvärd",
    "beaktansvärdare": "beaktansvärd",
    "beaktansvärdares": "beaktansvärd",
    "beaktansvärdas": "beaktansvärd",
    "beaktansvärdast": "beaktansvärd",
    "beaktansvärdaste": "beaktansvärd",
    "beaktansvärdastes": "beaktansvärd",
    "beaktansvärdasts": "beaktansvärd",
    "beaktansvärde": "beaktansvärd",
    "beaktansvärdes": "beaktansvärd",
    "beaktansvärds": "beaktansvärd",
    "beaktansvärt": "beaktansvärd",
    "beaktansvärts": "beaktansvärd",
    "beaktar": "beakta",
    "beaktas": "beakta",
    "beaktat": "beakta",
    "beaktats": "beakta",
    "bean": "bea",
    "beans": "bea",
    "bearbet": "bearbeta",
    "bearbetad": "bearbeta",
    "bearbetade": "bearbeta",
    "bearbetades": "bearbeta",
    "bearbetads": "bearbeta",
    "bearbetande": "bearbeta",
    "bearbetanden": "bearbetande",
    "bearbetandena": "bearbetande",
    "bearbetandenas": "bearbetande",
    "bearbetandens": "bearbetande",
    "bearbetandes": "bearbetande",
    "bearbetandet": "bearbetande",
    "bearbetandets": "bearbetande",
    "bearbetar": "bearbeta",
    "bearbetas": "bearbeta",
    "bearbetat": "bearbeta",
    "bearbetats": "bearbeta",
    "bearbetningar": "bearbetning",
    "bearbetningarna": "bearbetning",
    "bearbetningarnas": "bearbetning",
    "bearbetningars": "bearbetning",
    "bearbetningen": "bearbetning",
    "bearbetningens": "bearbetning",
    "bearbetnings": "bearbetning",
    "bearnaisen": "bearnaise",
    "bearnaisens": "bearnaise",
    "bearnaiser": "bearnaise",
    "bearnaiserna": "bearnaise",
    "bearnaisernas": "bearnaise",
    "bearnaisers": "bearnaise",
    "bearnaises": "bearnaise",
    "bearnaisesåsen": "bearnaisesås",
    "bearnaisesåsens": "bearnaisesås",
    "bearnaisesåser": "bearnaisesås",
    "bearnaisesåserna": "bearnaisesås",
    "bearnaisesåsernas": "bearnaisesås",
    "bearnaisesåsers": "bearnaisesås",
    "bearnäsen": "bearnäs",
    "bearnäsens": "bearnäs",
    "bearnäser": "bearnäs",
    "bearnäserna": "bearnäs",
    "bearnäsernas": "bearnäs",
    "bearnäsers": "bearnäs",
    "bearnässåsen": "bearnässås",
    "bearnässåsens": "bearnässås",
    "bearnässåser": "bearnässås",
    "bearnässåserna": "bearnässås",
    "bearnässåsernas": "bearnässås",
    "bearnässåsers": "bearnässås",
    "beas": "bea",
    "beatnikar": "beatnik",
    "beatnikarna": "beatnik",
    "beatnikarnas": "beatnik",
    "beatnikars": "beatnik",
    "beatniken": "beatnik",
    "beatnikens": "beatnik",
    "beatniks": "beatnik",
    "bebisar": "bebis",
    "bebisarna": "bebis",
    "bebisarnas": "bebis",
    "bebisars": "bebis",
    "bebisen": "bebis",
    "bebisens": "bebis",
    "bebodd": "bebo",
    "bebodda": "bebodd",
    "beboddare": "bebodd",
    "beboddares": "bebodd",
    "beboddas": "bebodd",
    "beboddast": "bebodd",
    "beboddaste": "bebodd",
    "beboddastes": "bebodd",
    "beboddasts": "bebodd",
    "bebodde": "bebodd",
    "beboddes": "bebodd",
    "bebodds": "bebodd",
    "beboeliga": "beboelig",
    "beboeligare": "beboelig",
    "beboeligares": "beboelig",
    "beboeligas": "beboelig",
    "beboeligast": "beboelig",
    "beboeligaste": "beboelig",
    "beboeligastes": "beboelig",
    "beboeligasts": "beboelig",
    "beboelige": "beboelig",
    "beboeliges": "beboelig",
    "beboeligheten": "beboelighet",
    "beboelighetens": "beboelighet",
    "beboelighets": "beboelighet",
    "beboeligs": "beboelig",
    "beboeligt": "beboelig",
    "beboeligts": "beboelig",
    "beboende": "bebo",
    "beboenden": "beboende",
    "beboendena": "beboende",
    "beboendenas": "beboende",
    "beboendens": "beboende",
    "beboendes": "beboende",
    "beboendet": "beboende",
    "beboendets": "beboende",
    "bebopen": "bebop",
    "bebopens": "bebop",
    "bebops": "bebop",
    "bebor": "bebo",
    "bebos": "bebo",
    "bebott": "bebodd",
    "bebotts": "bebodd",
    "bebygg": "bebygga",
    "bebyggande": "bebygga",
    "bebygganden": "bebyggande",
    "bebyggandena": "bebyggande",
    "bebyggandenas": "bebyggande",
    "bebyggandens": "bebyggande",
    "bebyggandes": "bebyggande",
    "bebyggandet": "bebyggande",
    "bebyggandets": "bebyggande",
    "bebyggas": "bebygga",
    "bebyggd": "bebygga",
    "bebyggda": "bebygga",
    "bebyggdas": "bebygga",
    "bebyggde": "bebygga",
    "bebyggdes": "bebygga",
    "bebyggds": "bebygga",
    "bebyggelsen": "bebyggelse",
    "bebyggelsenamnen": "bebyggelsenamn",
    "bebyggelsenamnens": "bebyggelsenamn",
    "bebyggelsenamnet": "bebyggelsenamn",
    "bebyggelsenamnets": "bebyggelsenamn",
    "bebyggelsenamns": "bebyggelsenamn",
    "bebyggelsens": "bebyggelse",
    "bebyggelser": "bebyggelse",
    "bebyggelserna": "bebyggelse",
    "bebyggelsernas": "bebyggelse",
    "bebyggelsers": "bebyggelse",
    "bebyggelses": "bebyggelse",
    "bebygger": "bebygga",
    "bebygges": "bebygga",
    "bebyggs": "bebygga",
    "bebyggt": "bebygga",
    "bebyggts": "bebygga",
    "bebåd": "bebåda",
    "bebådad": "bebåda",
    "bebådade": "bebåda",
    "bebådades": "bebåda",
    "bebådads": "bebåda",
    "bebådande": "bebåda",
    "bebådanden": "bebådande",
    "bebådandena": "bebådande",
    "bebådandenas": "bebådande",
    "bebådandens": "bebådande",
    "bebådandes": "bebådande",
    "bebådandet": "bebådande",
    "bebådandets": "bebådande",
    "bebådar": "bebåda",
    "bebådas": "bebåda",
    "bebådat": "bebåda",
    "bebådats": "bebåda",
    "bebådelsen": "bebådelse",
    "bebådelsens": "bebådelse",
    "bebådelser": "bebådelse",
    "bebådelserna": "bebådelse",
    "bebådelsernas": "bebådelse",
    "bebådelsers": "bebådelse",
    "bebådelses": "bebådelse",
    "becherovkan": "becherovka",
    "becherovkans": "becherovka",
    "becherovkas": "becherovka",
    "beck": "becka",
    "beckad": "becka",
    "beckade": "becka",
    "beckades": "becka",
    "beckads": "becka",
    "beckande": "becka",
    "beckanden": "beckande",
    "beckandena": "beckande",
    "beckandenas": "beckande",
    "beckandens": "beckande",
    "beckandes": "beckande",
    "beckandet": "beckande",
    "beckandets": "beckande",
    "beckar": "becka",
    "beckas": "becka",
    "beckasinen": "beckasin",
    "beckasinens": "beckasin",
    "beckasiner": "beckasin",
    "beckasinerna": "beckasin",
    "beckasinernas": "beckasin",
    "beckasiners": "beckasin",
    "beckasins": "beckasin",
    "beckat": "becka",
    "beckats": "becka",
    "becket": "beck",
    "beckets": "beck",
    "beckiga": "beckig",
    "beckigare": "beckig",
    "beckigares": "beckig",
    "beckigas": "beckig",
    "beckigast": "beckig",
    "beckigaste": "beckig",
    "beckigastes": "beckig",
    "beckigasts": "beckig",
    "beckige": "beckig",
    "beckiges": "beckig",
    "beckigheten": "beckighet",
    "beckighetens": "beckighet",
    "beckighets": "beckighet",
    "beckigs": "beckig",
    "beckigt": "beckig",
    "beckigts": "beckig",
    "beckmörka": "beckmörk",
    "beckmörkare": "beckmörk",
    "beckmörkares": "beckmörk",
    "beckmörkas": "beckmörk",
    "beckmörkast": "beckmörk",
    "beckmörkaste": "beckmörk",
    "beckmörkastes": "beckmörk",
    "beckmörkasts": "beckmörk",
    "beckmörke": "beckmörk",
    "beckmörkes": "beckmörk",
    "beckmörks": "beckmörk",
    "beckmörkt": "beckmörk",
    "beckmörkts": "beckmörk",
    "beckpärl": "beckpärla",
    "beckpärlan": "beckpärla",
    "beckpärlans": "beckpärla",
    "beckpärlas": "beckpärla",
    "beckpärle": "beckpärla",
    "beckpärlor": "beckpärla",
    "beckpärlorna": "beckpärla",
    "beckpärlornas": "beckpärla",
    "beckpärlors": "beckpärla",
    "beckpärls": "beckpärla",
    "becks": "beck",
    "becquerelen": "becquerel",
    "becquerelens": "becquerel",
    "becquerels": "becquerel",
    "bed": "be",
    "beda": "be",
    "bedagade": "bedagad",
    "bedagades": "bedagad",
    "bedagads": "bedagad",
    "bedagat": "bedagad",
    "bedagats": "bedagad",
    "bedande": "be",
    "bedandes": "be",
    "bedarr": "bedarra",
    "bedarrad": "bedarra",
    "bedarrade": "bedarra",
    "bedarrades": "bedarra",
    "bedarrads": "bedarra",
    "bedarrande": "bedarra",
    "bedarranden": "bedarrande",
    "bedarrandena": "bedarrande",
    "bedarrandenas": "bedarrande",
    "bedarrandens": "bedarrande",
    "bedarrandes": "bedarrande",
    "bedarrandet": "bedarrande",
    "bedarrandets": "bedarrande",
    "bedarrar": "bedarra",
    "bedarras": "bedarra",
    "bedarrat": "bedarra",
    "bedarrats": "bedarra",
    "bedas": "be",
    "bedd": "be",
    "bedda": "be",
    "beddas": "be",
    "bedde": "be",
    "beddes": "be",
    "bedds": "be",
    "bede": "be",
    "beder": "be",
    "bedes": "be",
    "bedj": "be",
    "bedja": "be",
    "bedjande": "be",
    "bedjandes": "bedjande",
    "bedjandet": "bedjande",
    "bedjandets": "bedjande",
    "bedjas": "be",
    "bedje": "be",
    "bedjer": "be",
    "bedjes": "be",
    "bedrag": "bedra",
    "bedraga": "bedra",
    "bedragande": "bedra",
    "bedraganden": "bedragande",
    "bedragandena": "bedragande",
    "bedragandenas": "bedragande",
    "bedragandens": "bedragande",
    "bedragandes": "bedragande",
    "bedragandet": "bedragande",
    "bedragandets": "bedragande",
    "bedragar": "bedragare",
    "bedragaren": "bedragare",
    "bedragarens": "bedragare",
    "bedragares": "bedragare",
    "bedragarna": "bedragare",
    "bedragarnas": "bedragare",
    "bedragas": "bedra",
    "bedrage": "bedra",
    "bedragen": "bedra",
    "bedragens": "bedra",
    "bedrager": "bedra",
    "bedrages": "bedra",
    "bedraget": "bedra",
    "bedragets": "bedra",
    "bedragit": "bedra",
    "bedragits": "bedra",
    "bedragna": "bedra",
    "bedragnas": "bedra",
    "bedragne": "bedra",
    "bedragnes": "bedra",
    "bedrags": "bedra",
    "bedrar": "bedra",
    "bedras": "bedra",
    "bedrev": "bedriva",
    "bedrevs": "bedriva",
    "bedriften": "bedrift",
    "bedriftens": "bedrift",
    "bedrifter": "bedrift",
    "bedrifterna": "bedrift",
    "bedrifternas": "bedrift",
    "bedrifters": "bedrift",
    "bedrifts": "bedrift",
    "bedriv": "bedriva",
    "bedrivande": "bedriva",
    "bedrivanden": "bedrivande",
    "bedrivandena": "bedrivande",
    "bedrivandenas": "bedrivande",
    "bedrivandens": "bedrivande",
    "bedrivandes": "bedrivande",
    "bedrivandet": "bedrivande",
    "bedrivandets": "bedrivande",
    "bedrivas": "bedriva",
    "bedrive": "bedriva",
    "bedriven": "bedriva",
    "bedrivens": "bedriva",
    "bedriver": "bedriva",
    "bedrives": "bedriva",
    "bedrivet": "bedriva",
    "bedrivets": "bedriva",
    "bedrivit": "bedriva",
    "bedrivits": "bedriva",
    "bedrivna": "bedriva",
    "bedrivnas": "bedriva",
    "bedrivne": "bedriva",
    "bedrivnes": "bedriva",
    "bedrivs": "bedriva",
    "bedrog": "bedra",
    "bedroge": "bedra",
    "bedroges": "bedra",
    "bedrogs": "bedra",
    "bedrägerier": "bedrägeri",
    "bedrägerierna": "bedrägeri",
    "bedrägeriernas": "bedrägeri",
    "bedrägeriers": "bedrägeri",
    "bedrägeriet": "bedrägeri",
    "bedrägeriets": "bedrägeri",
    "bedrägeris": "bedrägeri",
    "bedrägerit": "bedrägeri",
    "bedrägerits": "bedrägeri",
    "bedrägliga": "bedräglig",
    "bedrägligare": "bedräglig",
    "bedrägligares": "bedräglig",
    "bedrägligas": "bedräglig",
    "bedrägligast": "bedräglig",
    "bedrägligaste": "bedräglig",
    "bedrägligastes": "bedräglig",
    "bedrägligasts": "bedräglig",
    "bedräglige": "bedräglig",
    "bedrägliges": "bedräglig",
    "bedrägligheten": "bedräglighet",
    "bedräglighetens": "bedräglighet",
    "bedrägligheter": "bedräglighet",
    "bedrägligheterna": "bedräglighet",
    "bedrägligheternas": "bedräglighet",
    "bedrägligheters": "bedräglighet",
    "bedräglighets": "bedräglighet",
    "bedrägligs": "bedräglig",
    "bedrägligt": "bedräglig",
    "bedrägligts": "bedräglig",
    "bedröv": "bedröva",
    "bedrövad": "bedröva",
    "bedrövade": "bedrövad",
    "bedrövades": "bedrövad",
    "bedrövads": "bedrövad",
    "bedrövande": "bedröva",
    "bedrövanden": "bedrövande",
    "bedrövandena": "bedrövande",
    "bedrövandenas": "bedrövande",
    "bedrövandens": "bedrövande",
    "bedrövandes": "bedrövande",
    "bedrövandet": "bedrövande",
    "bedrövandets": "bedrövande",
    "bedrövar": "bedröva",
    "bedrövas": "bedröva",
    "bedrövat": "bedrövad",
    "bedrövats": "bedrövad",
    "bedrövelsen": "bedrövelse",
    "bedrövelsens": "bedrövelse",
    "bedrövelser": "bedrövelse",
    "bedrövelserna": "bedrövelse",
    "bedrövelsernas": "bedrövelse",
    "bedrövelsers": "bedrövelse",
    "bedrövelses": "bedrövelse",
    "bedrövliga": "bedrövlig",
    "bedrövligare": "bedrövlig",
    "bedrövligares": "bedrövlig",
    "bedrövligas": "bedrövlig",
    "bedrövligast": "bedrövlig",
    "bedrövligaste": "bedrövlig",
    "bedrövligastes": "bedrövlig",
    "bedrövligasts": "bedrövlig",
    "bedrövlige": "bedrövlig",
    "bedrövliges": "bedrövlig",
    "bedrövligheten": "bedrövlighet",
    "bedrövlighetens": "bedrövlighet",
    "bedrövligheter": "bedrövlighet",
    "bedrövligheterna": "bedrövlighet",
    "bedrövligheternas": "bedrövlighet",
    "bedrövligheters": "bedrövlighet",
    "bedrövlighets": "bedrövlighet",
    "bedrövligs": "bedrövlig",
    "bedrövligt": "bedrövlig",
    "bedrövligts": "bedrövlig",
    "beds": "be",
    "beduinen": "beduin",
    "beduinens": "beduin",
    "beduiner": "beduin",
    "beduinerna": "beduin",
    "beduinernas": "beduin",
    "beduiners": "beduin",
    "beduins": "beduin",
    "bedyr": "bedyra",
    "bedyrad": "bedyra",
    "bedyrade": "bedyra",
    "bedyrades": "bedyra",
    "bedyrads": "bedyra",
    "bedyrande": "bedyra",
    "bedyranden": "bedyrande",
    "bedyrandena": "bedyrande",
    "bedyrandenas": "bedyrande",
    "bedyrandens": "bedyrande",
    "bedyrandes": "bedyrande",
    "bedyrandet": "bedyrande",
    "bedyrandets": "bedyrande",
    "bedyrar": "bedyra",
    "bedyras": "bedyra",
    "bedyrat": "bedyra",
    "bedyrats": "bedyra",
    "bedår": "bedåra",
    "bedårad": "bedåra",
    "bedårade": "bedåra",
    "bedårades": "bedåra",
    "bedårads": "bedåra",
    "bedårande": "bedåra",
    "bedåranden": "bedårande",
    "bedårandena": "bedårande",
    "bedårandenas": "bedårande",
    "bedårandens": "bedårande",
    "bedårandes": "bedårande",
    "bedårandet": "bedårande",
    "bedårandets": "bedårande",
    "bedårar": "bedåra",
    "bedåras": "bedåra",
    "bedårat": "bedåra",
    "bedårats": "bedåra",
    "bedöm": "bedöma",
    "bedömande": "bedöma",
    "bedömanden": "bedömande",
    "bedömandena": "bedömande",
    "bedömandenas": "bedömande",
    "bedömandens": "bedömande",
    "bedömandes": "bedömande",
    "bedömandet": "bedömande",
    "bedömandets": "bedömande",
    "bedömar": "bedömare",
    "bedömaren": "bedömare",
    "bedömarens": "bedömare",
    "bedömares": "bedömare",
    "bedömarna": "bedömare",
    "bedömarnas": "bedömare",
    "bedömas": "bedöma",
    "bedömd": "bedöma",
    "bedömda": "bedöma",
    "bedömdas": "bedöma",
    "bedömde": "bedöma",
    "bedömdes": "bedöma",
    "bedömds": "bedöma",
    "bedömer": "bedöma",
    "bedömningar": "bedömning",
    "bedömningarna": "bedömning",
    "bedömningarnas": "bedömning",
    "bedömningars": "bedömning",
    "bedömningen": "bedömning",
    "bedömningens": "bedömning",
    "bedömnings": "bedömning",
    "bedöms": "bedöma",
    "bedömt": "bedöma",
    "bedömts": "bedöma",
    "bedöv": "bedöva",
    "bedövad": "bedöva",
    "bedövade": "bedöva",
    "bedövades": "bedöva",
    "bedövads": "bedöva",
    "bedövande": "bedöva",
    "bedövanden": "bedövande",
    "bedövandena": "bedövande",
    "bedövandenas": "bedövande",
    "bedövandens": "bedövande",
    "bedövandes": "bedövande",
    "bedövandet": "bedövande",
    "bedövandets": "bedövande",
    "bedövar": "bedöva",
    "bedövas": "bedöva",
    "bedövat": "bedöva",
    "bedövats": "bedöva",
    "bedövningar": "bedövning",
    "bedövningarna": "bedövning",
    "bedövningarnas": "bedövning",
    "bedövningars": "bedövning",
    "bedövningen": "bedövning",
    "bedövningens": "bedövning",
    "bedövnings": "bedövning",
    "bedövningsmedels": "bedövningsmedel",
    "bedövningsmedlen": "bedövningsmedel",
    "bedövningsmedlens": "bedövningsmedel",
    "bedövningsmedlet": "bedövningsmedel",
    "bedövningsmedlets": "bedövningsmedel",
    "beedig": "beediga",
    "beedigad": "beediga",
    "beedigade": "beediga",
    "beedigades": "beediga",
    "beedigads": "beediga",
    "beedigande": "beediga",
    "beediganden": "beedigande",
    "beedigandena": "beedigande",
    "beedigandenas": "beedigande",
    "beedigandens": "beedigande",
    "beedigandes": "beedigande",
    "beedigandet": "beedigande",
    "beedigandets": "beedigande",
    "beedigar": "beediga",
    "beedigas": "beediga",
    "beedigat": "beediga",
    "beedigats": "beediga",
    "beende": "be",
    "beendes": "beende",
    "beendet": "beende",
    "beendets": "beende",
    "befall": "befalla",
    "befallande": "befalla",
    "befallanden": "befallande",
    "befallandena": "befallande",
    "befallandenas": "befallande",
    "befallandens": "befallande",
    "befallandes": "befallande",
    "befallandet": "befallande",
    "befallandets": "befallande",
    "befallas": "befalla",
    "befalld": "befalla",
    "befallda": "befalla",
    "befalldas": "befalla",
    "befallde": "befalla",
    "befalldes": "befalla",
    "befallds": "befalla",
    "befaller": "befalla",
    "befalles": "befalla",
    "befallningar": "befallning",
    "befallningarna": "befallning",
    "befallningarnas": "befallning",
    "befallningars": "befallning",
    "befallningen": "befallning",
    "befallningens": "befallning",
    "befallnings": "befallning",
    "befallningshavanden": "befallningshavande",
    "befallningshavandena": "befallningshavande",
    "befallningshavandenas": "befallningshavande",
    "befallningshavandens": "befallningshavande",
    "befallningshavandes": "befallningshavande",
    "befallningsmannen": "befallningsman",
    "befallningsmannens": "befallningsman",
    "befallningsmans": "befallningsman",
    "befallningsmän": "befallningsman",
    "befallningsmännen": "befallningsman",
    "befallningsmännens": "befallningsman",
    "befallningsmäns": "befallningsman",
    "befalls": "befalla",
    "befallt": "befalla",
    "befallts": "befalla",
    "befanns": "befinnas",
    "befar": "befara",
    "befarad": "befara",
    "befarade": "befara",
    "befarades": "befara",
    "befarads": "befara",
    "befarande": "befara",
    "befaranden": "befarande",
    "befarandena": "befarande",
    "befarandenas": "befarande",
    "befarandens": "befarande",
    "befarandes": "befarande",
    "befarandet": "befarande",
    "befarandets": "befarande",
    "befarar": "befara",
    "befaras": "befara",
    "befarat": "befara",
    "befarats": "befara",
    "befare": "befara",
    "befaren": "befara",
    "befarens": "befaren",
    "befares": "befara",
    "befaret": "befaren",
    "befarets": "befaren",
    "befarit": "befara",
    "befarits": "befara",
    "befarna": "befaren",
    "befarnare": "befaren",
    "befarnares": "befaren",
    "befarnas": "befaren",
    "befarnast": "befaren",
    "befarnaste": "befaren",
    "befarnastes": "befaren",
    "befarnasts": "befaren",
    "befarne": "befaren",
    "befarnes": "befaren",
    "befars": "befara",
    "befattningar": "befattning",
    "befattningarna": "befattning",
    "befattningarnas": "befattning",
    "befattningars": "befattning",
    "befattningen": "befattning",
    "befattningens": "befattning",
    "befattnings": "befattning",
    "befattningshavar": "befattningshavare",
    "befattningshavaren": "befattningshavare",
    "befattningshavarens": "befattningshavare",
    "befattningshavares": "befattningshavare",
    "befattningshavarna": "befattningshavare",
    "befattningshavarnas": "befattningshavare",
    "befattningsmässiga": "befattningsmässig",
    "befattningsmässigare": "befattningsmässig",
    "befattningsmässigares": "befattningsmässig",
    "befattningsmässigas": "befattningsmässig",
    "befattningsmässigast": "befattningsmässig",
    "befattningsmässigaste": "befattningsmässig",
    "befattningsmässigastes": "befattningsmässig",
    "befattningsmässigasts": "befattningsmässig",
    "befattningsmässige": "befattningsmässig",
    "befattningsmässiges": "befattningsmässig",
    "befattningsmässigs": "befattningsmässig",
    "befattningsmässigt": "befattningsmässig",
    "befattningsmässigts": "befattningsmässig",
    "befinnandes": "befinnande",
    "befinnandet": "befinnande",
    "befinnandets": "befinnande",
    "befinnes": "befinnas",
    "befinns": "befinnas",
    "befintliga": "befintlig",
    "befintligare": "befintlig",
    "befintligares": "befintlig",
    "befintligas": "befintlig",
    "befintligast": "befintlig",
    "befintligaste": "befintlig",
    "befintligastes": "befintlig",
    "befintligasts": "befintlig",
    "befintlige": "befintlig",
    "befintliges": "befintlig",
    "befintligheten": "befintlighet",
    "befintlighetens": "befintlighet",
    "befintligheter": "befintlighet",
    "befintligheterna": "befintlighet",
    "befintligheternas": "befintlighet",
    "befintligheters": "befintlighet",
    "befintlighets": "befintlighet",
    "befintligs": "befintlig",
    "befintligt": "befintlig",
    "befintligts": "befintlig",
    "befjädrade": "befjädrad",
    "befjädrades": "befjädrad",
    "befjädrads": "befjädrad",
    "befjädrat": "befjädrad",
    "befjädrats": "befjädrad",
    "befjädringar": "befjädring",
    "befjädringarna": "befjädring",
    "befjädringarnas": "befjädring",
    "befjädringars": "befjädring",
    "befjädringen": "befjädring",
    "befjädringens": "befjädring",
    "befjädrings": "befjädring",
    "befläck": "befläcka",
    "befläckad": "befläcka",
    "befläckade": "befläcka",
    "befläckades": "befläcka",
    "befläckads": "befläcka",
    "befläckande": "befläcka",
    "befläckanden": "befläckande",
    "befläckandena": "befläckande",
    "befläckandenas": "befläckande",
    "befläckandens": "befläckande",
    "befläckandes": "befläckande",
    "befläckandet": "befläckande",
    "befläckandets": "befläckande",
    "befläckar": "befläcka",
    "befläckas": "befläcka",
    "befläckat": "befläcka",
    "befläckats": "befläcka",
    "befogade": "befogad",
    "befogades": "befogad",
    "befogads": "befogad",
    "befogat": "befogad",
    "befogats": "befogad",
    "befogenheten": "befogenhet",
    "befogenhetens": "befogenhet",
    "befogenheter": "befogenhet",
    "befogenheterna": "befogenhet",
    "befogenheternas": "befogenhet",
    "befogenheters": "befogenhet",
    "befogenhets": "befogenhet",
    "befolk": "befolka",
    "befolkad": "befolka",
    "befolkade": "befolka",
    "befolkades": "befolka",
    "befolkads": "befolka",
    "befolkande": "befolka",
    "befolkanden": "befolkande",
    "befolkandena": "befolkande",
    "befolkandenas": "befolkande",
    "befolkandens": "befolkande",
    "befolkandes": "befolkande",
    "befolkandet": "befolkande",
    "befolkandets": "befolkande",
    "befolkar": "befolka",
    "befolkas": "befolka",
    "befolkat": "befolka",
    "befolkats": "befolka",
    "befolkningar": "befolkning",
    "befolkningarna": "befolkning",
    "befolkningarnas": "befolkning",
    "befolkningars": "befolkning",
    "befolkningen": "befolkning",
    "befolkningens": "befolkning",
    "befolknings": "befolkning",
    "befolkningsexplosionen": "befolkningsexplosion",
    "befolkningsexplosionens": "befolkningsexplosion",
    "befolkningsexplosioner": "befolkningsexplosion",
    "befolkningsexplosionerna": "befolkningsexplosion",
    "befolkningsexplosionernas": "befolkningsexplosion",
    "befolkningsexplosioners": "befolkningsexplosion",
    "befolkningsexplosions": "befolkningsexplosion",
    "befolkningsgruppen": "befolkningsgrupp",
    "befolkningsgruppens": "befolkningsgrupp",
    "befolkningsgrupper": "befolkningsgrupp",
    "befolkningsgrupperna": "befolkningsgrupp",
    "befolkningsgruppernas": "befolkningsgrupp",
    "befolkningsgruppers": "befolkningsgrupp",
    "befolkningsgrupps": "befolkningsgrupp",
    "befolkningsmässiga": "befolkningsmässig",
    "befolkningsmässigare": "befolkningsmässig",
    "befolkningsmässigares": "befolkningsmässig",
    "befolkningsmässigas": "befolkningsmässig",
    "befolkningsmässigast": "befolkningsmässig",
    "befolkningsmässigaste": "befolkningsmässig",
    "befolkningsmässigastes": "befolkningsmässig",
    "befolkningsmässigasts": "befolkningsmässig",
    "befolkningsmässige": "befolkningsmässig",
    "befolkningsmässiges": "befolkningsmässig",
    "befolkningsmässigs": "befolkningsmässig",
    "befolkningsmässigt": "befolkningsmässig",
    "befolkningsmässigts": "befolkningsmässig",
    "befolkningspolitiken": "befolkningspolitik",
    "befolkningspolitikens": "befolkningspolitik",
    "befolkningspolitiks": "befolkningspolitik",
    "befolkningspolitiska": "befolkningspolitisk",
    "befolkningspolitiskas": "befolkningspolitisk",
    "befolkningspolitiske": "befolkningspolitisk",
    "befolkningspolitiskes": "befolkningspolitisk",
    "befolkningspolitisks": "befolkningspolitisk",
    "befolkningspolitiskt": "befolkningspolitisk",
    "befolkningspolitiskts": "befolkningspolitisk",
    "befolkningspyramiden": "befolkningspyramid",
    "befolkningspyramidens": "befolkningspyramid",
    "befolkningspyramider": "befolkningspyramid",
    "befolkningspyramiderna": "befolkningspyramid",
    "befolkningspyramidernas": "befolkningspyramid",
    "befolkningspyramiders": "befolkningspyramid",
    "befolkningspyramids": "befolkningspyramid",
    "befolkningsstatistiken": "befolkningsstatistik",
    "befolkningsstatistikens": "befolkningsstatistik",
    "befolkningsstatistiker": "befolkningsstatistik",
    "befolkningsstatistikerna": "befolkningsstatistik",
    "befolkningsstatistikernas": "befolkningsstatistik",
    "befolkningsstatistikers": "befolkningsstatistik",
    "befolkningsstatistiks": "befolkningsstatistik",
    "befolkningstillväxten": "befolkningstillväxt",
    "befolkningstillväxtens": "befolkningstillväxt",
    "befolkningstillväxts": "befolkningstillväxt",
    "befolkningsundersökningar": "befolkningsundersökning",
    "befolkningsundersökningarna": "befolkningsundersökning",
    "befolkningsundersökningarnas": "befolkningsundersökning",
    "befolkningsundersökningars": "befolkningsundersökning",
    "befolkningsundersökningen": "befolkningsundersökning",
    "befolkningsundersökningens": "befolkningsundersökning",
    "befolkningsundersöknings": "befolkningsundersökning",
    "befolkningsökningar": "befolkningsökning",
    "befolkningsökningarna": "befolkningsökning",
    "befolkningsökningarnas": "befolkningsökning",
    "befolkningsökningars": "befolkningsökning",
    "befolkningsökningen": "befolkningsökning",
    "befolkningsökningens": "befolkningsökning",
    "befolkningsöknings": "befolkningsökning",
    "befor": "befara",
    "befordrad": "befordra",
    "befordrade": "befordra",
    "befordrades": "befordra",
    "befordrads": "befordra",
    "befordrande": "befordra",
    "befordranden": "befordrande",
    "befordrandena": "befordrande",
    "befordrandenas": "befordrande",
    "befordrandens": "befordrande",
    "befordrandes": "befordrande",
    "befordrandet": "befordrande",
    "befordrandets": "befordrande",
    "befordrans": "befordran",
    "befordrar": "befordra",
    "befordras": "befordra",
    "befordrat": "befordra",
    "befordrats": "befordra",
    "befordringar": "befordring",
    "befordringarna": "befordring",
    "befordringarnas": "befordring",
    "befordringars": "befordring",
    "befordringen": "befordring",
    "befordringens": "befordring",
    "befordrings": "befordring",
    "befordringsgrunden": "befordringsgrund",
    "befordringsgrundens": "befordringsgrund",
    "befordringsgrunder": "befordringsgrund",
    "befordringsgrunderna": "befordringsgrund",
    "befordringsgrundernas": "befordringsgrund",
    "befordringsgrunders": "befordringsgrund",
    "befordringsgrunds": "befordringsgrund",
    "befordringsgångar": "befordringsgång",
    "befordringsgångarna": "befordringsgång",
    "befordringsgångarnas": "befordringsgång",
    "befordringsgångars": "befordringsgång",
    "befordringsgången": "befordringsgång",
    "befordringsgångens": "befordringsgång",
    "befordringsgångs": "befordringsgång",
    "before": "befara",
    "befores": "befara",
    "befors": "befara",
    "befrakt": "befrakta",
    "befraktad": "befrakta",
    "befraktade": "befrakta",
    "befraktades": "befrakta",
    "befraktads": "befrakta",
    "befraktande": "befrakta",
    "befraktanden": "befraktande",
    "befraktandena": "befraktande",
    "befraktandenas": "befraktande",
    "befraktandens": "befraktande",
    "befraktandes": "befraktande",
    "befraktandet": "befraktande",
    "befraktandets": "befraktande",
    "befraktar": "befraktare",
    "befraktaren": "befraktare",
    "befraktarens": "befraktare",
    "befraktares": "befraktare",
    "befraktarna": "befraktare",
    "befraktarnas": "befraktare",
    "befraktas": "befrakta",
    "befraktat": "befrakta",
    "befraktats": "befrakta",
    "befraktningar": "befraktning",
    "befraktningarna": "befraktning",
    "befraktningarnas": "befraktning",
    "befraktningars": "befraktning",
    "befraktningen": "befraktning",
    "befraktningens": "befraktning",
    "befraktnings": "befraktning",
    "befri": "befria",
    "befriad": "befria",
    "befriade": "befria",
    "befriades": "befria",
    "befriads": "befria",
    "befriande": "befria",
    "befrianden": "befriande",
    "befriandena": "befriande",
    "befriandenas": "befriande",
    "befriandens": "befriande",
    "befriandes": "befriande",
    "befriandet": "befriande",
    "befriandets": "befriande",
    "befriar": "befria",
    "befrias": "befria",
    "befriat": "befria",
    "befriats": "befria",
    "befrielseakten": "befrielseakt",
    "befrielseaktens": "befrielseakt",
    "befrielseakter": "befrielseakt",
    "befrielseakterna": "befrielseakt",
    "befrielseakternas": "befrielseakt",
    "befrielseakters": "befrielseakt",
    "befrielseakts": "befrielseakt",
    "befrielsearméer": "befrielsearmé",
    "befrielsearméerna": "befrielsearmé",
    "befrielsearméernas": "befrielsearmé",
    "befrielsearméers": "befrielsearmé",
    "befrielsearmén": "befrielsearmé",
    "befrielsearméns": "befrielsearmé",
    "befrielsearmés": "befrielsearmé",
    "befrielsefronten": "befrielsefront",
    "befrielsefrontens": "befrielsefront",
    "befrielsefronter": "befrielsefront",
    "befrielsefronterna": "befrielsefront",
    "befrielsefronternas": "befrielsefront",
    "befrielsefronters": "befrielsefront",
    "befrielsefronts": "befrielsefront",
    "befrielsekampen": "befrielsekamp",
    "befrielsekampens": "befrielsekamp",
    "befrielsekamper": "befrielsekamp",
    "befrielsekamperna": "befrielsekamp",
    "befrielsekampernas": "befrielsekamp",
    "befrielsekampers": "befrielsekamp",
    "befrielsekamps": "befrielsekamp",
    "befrielsekrigen": "befrielsekrig",
    "befrielsekrigens": "befrielsekrig",
    "befrielsekriget": "befrielsekrig",
    "befrielsekrigets": "befrielsekrig",
    "befrielsekrigs": "befrielsekrig",
    "befrielsen": "befrielse",
    "befrielsens": "befrielse",
    "befrielser": "befrielse",
    "befrielserna": "befrielse",
    "befrielsernas": "befrielse",
    "befrielsers": "befrielse",
    "befrielserörelsen": "befrielserörelse",
    "befrielserörelsens": "befrielserörelse",
    "befrielserörelser": "befrielserörelse",
    "befrielserörelserna": "befrielserörelse",
    "befrielserörelsernas": "befrielserörelse",
    "befrielserörelsers": "befrielserörelse",
    "befrielserörelses": "befrielserörelse",
    "befrielses": "befrielse",
    "befrukt": "befrukta",
    "befruktad": "befrukta",
    "befruktade": "befrukta",
    "befruktades": "befrukta",
    "befruktads": "befrukta",
    "befruktande": "befrukta",
    "befruktanden": "befruktande",
    "befruktandena": "befruktande",
    "befruktandenas": "befruktande",
    "befruktandens": "befruktande",
    "befruktandes": "befruktande",
    "befruktandet": "befruktande",
    "befruktandets": "befruktande",
    "befruktar": "befrukta",
    "befruktas": "befrukta",
    "befruktat": "befrukta",
    "befruktats": "befrukta",
    "befruktningar": "befruktning",
    "befruktningarna": "befruktning",
    "befruktningarnas": "befruktning",
    "befruktningars": "befruktning",
    "befruktningen": "befruktning",
    "befruktningens": "befruktning",
    "befruktnings": "befruktning",
    "befruktningsögonblicken": "befruktningsögonblick",
    "befruktningsögonblickens": "befruktningsögonblick",
    "befruktningsögonblicket": "befruktningsögonblick",
    "befruktningsögonblickets": "befruktningsögonblick",
    "befruktningsögonblicks": "befruktningsögonblick",
    "befrynd": "befrynda",
    "befryndad": "befrynda",
    "befryndade": "befryndad",
    "befryndades": "befryndad",
    "befryndads": "befryndad",
    "befryndande": "befrynda",
    "befryndanden": "befryndande",
    "befryndandena": "befryndande",
    "befryndandenas": "befryndande",
    "befryndandens": "befryndande",
    "befryndandes": "befryndande",
    "befryndandet": "befryndande",
    "befryndandets": "befryndande",
    "befryndar": "befrynda",
    "befryndas": "befrynda",
    "befryndat": "befryndad",
    "befryndats": "befryndad",
    "befrämj": "befrämja",
    "befrämjad": "befrämja",
    "befrämjade": "befrämja",
    "befrämjades": "befrämja",
    "befrämjads": "befrämja",
    "befrämjande": "befrämja",
    "befrämjanden": "befrämjande",
    "befrämjandena": "befrämjande",
    "befrämjandenas": "befrämjande",
    "befrämjandens": "befrämjande",
    "befrämjandes": "befrämjande",
    "befrämjandet": "befrämjande",
    "befrämjandets": "befrämjande",
    "befrämjar": "befrämjare",
    "befrämjaren": "befrämjare",
    "befrämjarens": "befrämjare",
    "befrämjares": "befrämjare",
    "befrämjarna": "befrämjare",
    "befrämjarnas": "befrämjare",
    "befrämjas": "befrämja",
    "befrämjat": "befrämja",
    "befrämjats": "befrämja",
    "befullmäktig": "befullmäktiga",
    "befullmäktigad": "befullmäktiga",
    "befullmäktigade": "befullmäktiga",
    "befullmäktigades": "befullmäktiga",
    "befullmäktigads": "befullmäktiga",
    "befullmäktigande": "befullmäktiga",
    "befullmäktiganden": "befullmäktigande",
    "befullmäktigandena": "befullmäktigande",
    "befullmäktigandenas": "befullmäktigande",
    "befullmäktigandens": "befullmäktigande",
    "befullmäktigandes": "befullmäktigande",
    "befullmäktigandet": "befullmäktigande",
    "befullmäktigandets": "befullmäktigande",
    "befullmäktigar": "befullmäktiga",
    "befullmäktigas": "befullmäktiga",
    "befullmäktigat": "befullmäktiga",
    "befullmäktigats": "befullmäktiga",
    "befunnits": "befinnas",
    "befälen": "befäl",
    "befälens": "befäl",
    "befälet": "befäl",
    "befälets": "befäl",
    "befälhavar": "befälhavare",
    "befälhavaren": "befälhavare",
    "befälhavarens": "befälhavare",
    "befälhavares": "befälhavare",
    "befälhavarna": "befälhavare",
    "befälhavarnas": "befälhavare",
    "befäls": "befäl",
    "befälseleven": "befälselev",
    "befälselevens": "befälselev",
    "befälselever": "befälselev",
    "befälseleverna": "befälselev",
    "befälselevernas": "befälselev",
    "befälselevers": "befälselev",
    "befälselevs": "befälselev",
    "befälsföringar": "befälsföring",
    "befälsföringarna": "befälsföring",
    "befälsföringarnas": "befälsföring",
    "befälsföringars": "befälsföring",
    "befälsföringen": "befälsföring",
    "befälsföringens": "befälsföring",
    "befälsförings": "befälsföring",
    "befälsgraden": "befälsgrad",
    "befälsgradens": "befälsgrad",
    "befälsgrader": "befälsgrad",
    "befälsgraderna": "befälsgrad",
    "befälsgradernas": "befälsgrad",
    "befälsgraders": "befälsgrad",
    "befälsgrads": "befälsgrad",
    "befälsställningar": "befälsställning",
    "befälsställningarna": "befälsställning",
    "befälsställningarnas": "befälsställning",
    "befälsställningars": "befälsställning",
    "befälsställningen": "befälsställning",
    "befälsställningens": "befälsställning",
    "befälsställnings": "befälsställning",
    "befälstalangen": "befälstalang",
    "befälstalangens": "befälstalang",
    "befälstalanger": "befälstalang",
    "befälstalangerna": "befälstalang",
    "befälstalangernas": "befälstalang",
    "befälstalangers": "befälstalang",
    "befälstalangs": "befälstalang",
    "befälsteckens": "befälstecken",
    "befälstecknen": "befälstecken",
    "befälstecknens": "befälstecken",
    "befälstecknet": "befälstecken",
    "befälstecknets": "befälstecken",
    "befälsuppdragen": "befälsuppdrag",
    "befälsuppdragens": "befälsuppdrag",
    "befälsuppdraget": "befälsuppdrag",
    "befälsuppdragets": "befälsuppdrag",
    "befälsuppdrags": "befälsuppdrag",
    "befängda": "befängd",
    "befängdare": "befängd",
    "befängdares": "befängd",
    "befängdas": "befängd",
    "befängdast": "befängd",
    "befängdaste": "befängd",
    "befängdastes": "befängd",
    "befängdasts": "befängd",
    "befängde": "befängd",
    "befängdes": "befängd",
    "befängdheten": "befängdhet",
    "befängdhetens": "befängdhet",
    "befängdheter": "befängdhet",
    "befängdheterna": "befängdhet",
    "befängdheternas": "befängdhet",
    "befängdheters": "befängdhet",
    "befängdhets": "befängdhet",
    "befängds": "befängd",
    "befängt": "befängd",
    "befängts": "befängd",
    "befäst": "befästa",
    "befästande": "befästa",
    "befästanden": "befästande",
    "befästandena": "befästande",
    "befästandenas": "befästande",
    "befästandens": "befästande",
    "befästandes": "befästande",
    "befästandet": "befästande",
    "befästandets": "befästande",
    "befästas": "befästa",
    "befäste": "befästa",
    "befäster": "befästa",
    "befästes": "befästa",
    "befästningar": "befästning",
    "befästningarna": "befästning",
    "befästningarnas": "befästning",
    "befästningars": "befästning",
    "befästningen": "befästning",
    "befästningens": "befästning",
    "befästnings": "befästning",
    "befästningsgravar": "befästningsgrav",
    "befästningsgravarna": "befästningsgrav",
    "befästningsgravarnas": "befästningsgrav",
    "befästningsgravars": "befästningsgrav",
    "befästningsgraven": "befästningsgrav",
    "befästningsgravens": "befästningsgrav",
    "befästningsgravs": "befästningsgrav",
    "befästningslinjen": "befästningslinje",
    "befästningslinjens": "befästningslinje",
    "befästningslinjer": "befästningslinje",
    "befästningslinjerna": "befästningslinje",
    "befästningslinjernas": "befästningslinje",
    "befästningslinjers": "befästningslinje",
    "befästningslinjes": "befästningslinje",
    "befästningsskydden": "befästningsskydd",
    "befästningsskyddens": "befästningsskydd",
    "befästningsskyddet": "befästningsskydd",
    "befästningsskyddets": "befästningsskydd",
    "befästningsskydds": "befästningsskydd",
    "befästningsverken": "befästningsverk",
    "befästningsverkens": "befästningsverk",
    "befästningsverket": "befästningsverk",
    "befästningsverkets": "befästningsverk",
    "befästningsverks": "befästningsverk",
    "befästs": "befästa",
    "begabb": "begabba",
    "begabbad": "begabba",
    "begabbade": "begabba",
    "begabbades": "begabba",
    "begabbads": "begabba",
    "begabbande": "begabba",
    "begabbanden": "begabbande",
    "begabbandena": "begabbande",
    "begabbandenas": "begabbande",
    "begabbandens": "begabbande",
    "begabbandes": "begabbande",
    "begabbandet": "begabbande",
    "begabbandets": "begabbande",
    "begabbar": "begabba",
    "begabbas": "begabba",
    "begabbat": "begabba",
    "begabbats": "begabba",
    "begagn": "begagna",
    "begagnad": "begagna",
    "begagnade": "begagnad",
    "begagnades": "begagnad",
    "begagnads": "begagnad",
    "begagnande": "begagna",
    "begagnanden": "begagnande",
    "begagnandena": "begagnande",
    "begagnandenas": "begagnande",
    "begagnandens": "begagnande",
    "begagnandes": "begagnande",
    "begagnandet": "begagnande",
    "begagnandets": "begagnande",
    "begagnar": "begagna",
    "begagnas": "begagna",
    "begagnat": "begagnad",
    "begagnatköpen": "begagnatköp",
    "begagnatköpens": "begagnatköp",
    "begagnatköpet": "begagnatköp",
    "begagnatköpets": "begagnatköp",
    "begagnatköps": "begagnatköp",
    "begagnats": "begagnad",
    "begap": "begapa",
    "begapad": "begapa",
    "begapade": "begapa",
    "begapades": "begapa",
    "begapads": "begapa",
    "begapande": "begapa",
    "begapanden": "begapande",
    "begapandena": "begapande",
    "begapandenas": "begapande",
    "begapandens": "begapande",
    "begapandes": "begapande",
    "begapandet": "begapande",
    "begapandets": "begapande",
    "begapar": "begapa",
    "begapas": "begapa",
    "begapat": "begapa",
    "begapats": "begapa",
    "begeistrade": "begeistrad",
    "begeistrades": "begeistrad",
    "begeistrads": "begeistrad",
    "begeistrat": "begeistrad",
    "begeistrats": "begeistrad",
    "begeistringar": "begeistring",
    "begeistringarna": "begeistring",
    "begeistringarnas": "begeistring",
    "begeistringars": "begeistring",
    "begeistringen": "begeistring",
    "begeistringens": "begeistring",
    "begeistrings": "begeistring",
    "begick": "begå",
    "begicks": "begå",
    "beginerån": "beginerå",
    "begineråns": "beginerå",
    "beginerår": "beginerå",
    "beginerårna": "beginerå",
    "beginerårnas": "beginerå",
    "beginerårs": "beginerå",
    "beginerås": "beginerå",
    "beginge": "begå",
    "beginges": "begå",
    "begivanden": "begivande",
    "begivandena": "begivande",
    "begivandenas": "begivande",
    "begivandens": "begivande",
    "begivandes": "begivande",
    "begivandet": "begivande",
    "begivandets": "begivande",
    "begivenheten": "begivenhet",
    "begivenhetens": "begivenhet",
    "begivenheter": "begivenhet",
    "begivenheterna": "begivenhet",
    "begivenheternas": "begivenhet",
    "begivenheters": "begivenhet",
    "begivenhets": "begivenhet",
    "begivens": "begiven",
    "begivet": "begiven",
    "begivets": "begiven",
    "begivna": "begiven",
    "begivnare": "begiven",
    "begivnares": "begiven",
    "begivnas": "begiven",
    "begivnast": "begiven",
    "begivnaste": "begiven",
    "begivnastes": "begiven",
    "begivnasts": "begiven",
    "begivne": "begiven",
    "begivnes": "begiven",
    "begjut": "begjuta",
    "begjutande": "begjuta",
    "begjutanden": "begjutande",
    "begjutandena": "begjutande",
    "begjutandenas": "begjutande",
    "begjutandens": "begjutande",
    "begjutandes": "begjutande",
    "begjutandet": "begjutande",
    "begjutandets": "begjutande",
    "begjutas": "begjuta",
    "begjute": "begjuta",
    "begjuten": "begjuta",
    "begjutens": "begjuta",
    "begjuter": "begjuta",
    "begjutes": "begjuta",
    "begjutet": "begjuta",
    "begjutets": "begjuta",
    "begjutit": "begjuta",
    "begjutits": "begjuta",
    "begjutna": "begjuta",
    "begjutnas": "begjuta",
    "begjutne": "begjuta",
    "begjutnes": "begjuta",
    "begjuts": "begjuta",
    "begläns": "beglänsa",
    "beglänsande": "beglänsa",
    "beglänsanden": "beglänsande",
    "beglänsandena": "beglänsande",
    "beglänsandenas": "beglänsande",
    "beglänsandens": "beglänsande",
    "beglänsandes": "beglänsande",
    "beglänsandet": "beglänsande",
    "beglänsandets": "beglänsande",
    "beglänsas": "beglänsa",
    "beglänser": "beglänsa",
    "beglänses": "beglänsa",
    "beglänst": "beglänsa",
    "beglänsta": "beglänsa",
    "beglänstas": "beglänsa",
    "beglänste": "beglänsa",
    "beglänstes": "beglänsa",
    "beglänsts": "beglänsa",
    "begoni": "begonia",
    "begonian": "begonia",
    "begonians": "begonia",
    "begonias": "begonia",
    "begonie": "begonia",
    "begonior": "begonia",
    "begoniorna": "begonia",
    "begoniornas": "begonia",
    "begoniors": "begonia",
    "begonis": "begonia",
    "begrav": "begrava",
    "begravande": "begrava",
    "begravanden": "begravande",
    "begravandena": "begravande",
    "begravandenas": "begravande",
    "begravandens": "begravande",
    "begravandes": "begravande",
    "begravandet": "begravande",
    "begravandets": "begravande",
    "begravas": "begrava",
    "begravd": "begrava",
    "begravda": "begrava",
    "begravdas": "begrava",
    "begravde": "begrava",
    "begravdes": "begrava",
    "begravds": "begrava",
    "begrave": "begrava",
    "begraven": "begrava",
    "begravens": "begrava",
    "begraver": "begrava",
    "begraves": "begrava",
    "begravet": "begrava",
    "begravets": "begrava",
    "begravit": "begrava",
    "begravits": "begrava",
    "begravna": "begrava",
    "begravnas": "begrava",
    "begravne": "begrava",
    "begravnes": "begrava",
    "begravningar": "begravning",
    "begravningarna": "begravning",
    "begravningarnas": "begravning",
    "begravningars": "begravning",
    "begravningen": "begravning",
    "begravningens": "begravning",
    "begravnings": "begravning",
    "begravningsakten": "begravningsakt",
    "begravningsaktens": "begravningsakt",
    "begravningsakter": "begravningsakt",
    "begravningsakterna": "begravningsakt",
    "begravningsakternas": "begravningsakt",
    "begravningsakters": "begravningsakt",
    "begravningsakts": "begravningsakt",
    "begravningsboken": "begravningsbok",
    "begravningsbokens": "begravningsbok",
    "begravningsboks": "begravningsbok",
    "begravningsbyråer": "begravningsbyrå",
    "begravningsbyråerna": "begravningsbyrå",
    "begravningsbyråernas": "begravningsbyrå",
    "begravningsbyråers": "begravningsbyrå",
    "begravningsbyrån": "begravningsbyrå",
    "begravningsbyråns": "begravningsbyrå",
    "begravningsbyrås": "begravningsbyrå",
    "begravningsböcker": "begravningsbok",
    "begravningsböckerna": "begravningsbok",
    "begravningsböckernas": "begravningsbok",
    "begravningsböckers": "begravningsbok",
    "begravningsdagar": "begravningsdag",
    "begravningsdagarna": "begravningsdag",
    "begravningsdagarnas": "begravningsdag",
    "begravningsdagars": "begravningsdag",
    "begravningsdagen": "begravningsdag",
    "begravningsdagens": "begravningsdag",
    "begravningsdags": "begravningsdag",
    "begravningsentreprenören": "begravningsentreprenör",
    "begravningsentreprenörens": "begravningsentreprenör",
    "begravningsentreprenörer": "begravningsentreprenör",
    "begravningsentreprenörerna": "begravningsentreprenör",
    "begravningsentreprenörernas": "begravningsentreprenör",
    "begravningsentreprenörers": "begravningsentreprenör",
    "begravningsentreprenörs": "begravningsentreprenör",
    "begravningsgästen": "begravningsgäst",
    "begravningsgästens": "begravningsgäst",
    "begravningsgäster": "begravningsgäst",
    "begravningsgästerna": "begravningsgäst",
    "begravningsgästernas": "begravningsgäst",
    "begravningsgästers": "begravningsgäst",
    "begravningsgästs": "begravningsgäst",
    "begravningshjälpen": "begravningshjälp",
    "begravningshjälpens": "begravningshjälp",
    "begravningshjälps": "begravningshjälp",
    "begravningskalasen": "begravningskalas",
    "begravningskalasens": "begravningskalas",
    "begravningskalaset": "begravningskalas",
    "begravningskalasets": "begravningskalas",
    "begravningskassan": "begravningskassa",
    "begravningskassans": "begravningskassa",
    "begravningskassas": "begravningskassa",
    "begravningskasse": "begravningskassa",
    "begravningskassor": "begravningskassa",
    "begravningskassorna": "begravningskassa",
    "begravningskassornas": "begravningskassa",
    "begravningskassors": "begravningskassa",
    "begravningskostnaderna": "begravningskostnader",
    "begravningskostnadernas": "begravningskostnader",
    "begravningskostnaders": "begravningskostnader",
    "begravningskostnads": "begravningskostnader",
    "begravningskransar": "begravningskrans",
    "begravningskransarna": "begravningskrans",
    "begravningskransarnas": "begravningskrans",
    "begravningskransars": "begravningskrans",
    "begravningskransen": "begravningskrans",
    "begravningskransens": "begravningskrans",
    "begravningsmarschen": "begravningsmarsch",
    "begravningsmarschens": "begravningsmarsch",
    "begravningsmarscher": "begravningsmarsch",
    "begravningsmarscherna": "begravningsmarsch",
    "begravningsmarschernas": "begravningsmarsch",
    "begravningsmarschers": "begravningsmarsch",
    "begravningsmarschs": "begravningsmarsch",
    "begravningsminen": "begravningsmin",
    "begravningsminens": "begravningsmin",
    "begravningsminer": "begravningsmin",
    "begravningsminerna": "begravningsmin",
    "begravningsminernas": "begravningsmin",
    "begravningsminers": "begravningsmin",
    "begravningsmins": "begravningsmin",
    "begravningsplatsen": "begravningsplats",
    "begravningsplatsens": "begravningsplats",
    "begravningsplatser": "begravningsplats",
    "begravningsplatserna": "begravningsplats",
    "begravningsplatsernas": "begravningsplats",
    "begravningsplatsers": "begravningsplats",
    "begravningsprocessionen": "begravningsprocession",
    "begravningsprocessionens": "begravningsprocession",
    "begravningsprocessioner": "begravningsprocession",
    "begravningsprocessionerna": "begravningsprocession",
    "begravningsprocessionernas": "begravningsprocession",
    "begravningsprocessioners": "begravningsprocession",
    "begravningsprocessions": "begravningsprocession",
    "begravningsspelen": "begravningsspel",
    "begravningsspelens": "begravningsspel",
    "begravningsspelet": "begravningsspel",
    "begravningsspelets": "begravningsspel",
    "begravningsspels": "begravningsspel",
    "begravningstågen": "begravningståg",
    "begravningstågens": "begravningståg",
    "begravningståget": "begravningståg",
    "begravningstågets": "begravningståg",
    "begravningstågs": "begravningståg",
    "begravs": "begrava",
    "begravt": "begrava",
    "begravts": "begrava",
    "begrep": "begripa",
    "begreppen": "begrepp",
    "begreppens": "begrepp",
    "begreppet": "begrepp",
    "begreppets": "begrepp",
    "begrepps": "begrepp",
    "begreppsanalysen": "begreppsanalys",
    "begreppsanalysens": "begreppsanalys",
    "begreppsanalyser": "begreppsanalys",
    "begreppsanalyserna": "begreppsanalys",
    "begreppsanalysernas": "begreppsanalys",
    "begreppsanalysers": "begreppsanalys",
    "begreppsanalytiska": "begreppsanalytisk",
    "begreppsanalytiskare": "begreppsanalytisk",
    "begreppsanalytiskares": "begreppsanalytisk",
    "begreppsanalytiskas": "begreppsanalytisk",
    "begreppsanalytiskast": "begreppsanalytisk",
    "begreppsanalytiskaste": "begreppsanalytisk",
    "begreppsanalytiskastes": "begreppsanalytisk",
    "begreppsanalytiskasts": "begreppsanalytisk",
    "begreppsanalytiske": "begreppsanalytisk",
    "begreppsanalytiskes": "begreppsanalytisk",
    "begreppsanalytisks": "begreppsanalytisk",
    "begreppsanalytiskt": "begreppsanalytisk",
    "begreppsanalytiskts": "begreppsanalytisk",
    "begreppsapparaten": "begreppsapparat",
    "begreppsapparatens": "begreppsapparat",
    "begreppsapparater": "begreppsapparat",
    "begreppsapparaterna": "begreppsapparat",
    "begreppsapparaternas": "begreppsapparat",
    "begreppsapparaters": "begreppsapparat",
    "begreppsapparats": "begreppsapparat",
    "begreppsbestämningar": "begreppsbestämning",
    "begreppsbestämningarna": "begreppsbestämning",
    "begreppsbestämningarnas": "begreppsbestämning",
    "begreppsbestämningars": "begreppsbestämning",
    "begreppsbestämningen": "begreppsbestämning",
    "begreppsbestämningens": "begreppsbestämning",
    "begreppsbestämnings": "begreppsbestämning",
    "begreppsbildningar": "begreppsbildning",
    "begreppsbildningarna": "begreppsbildning",
    "begreppsbildningarnas": "begreppsbildning",
    "begreppsbildningars": "begreppsbildning",
    "begreppsbildningen": "begreppsbildning",
    "begreppsbildningens": "begreppsbildning",
    "begreppsbildnings": "begreppsbildning",
    "begreppsförvirringar": "begreppsförvirring",
    "begreppsförvirringarna": "begreppsförvirring",
    "begreppsförvirringarnas": "begreppsförvirring",
    "begreppsförvirringars": "begreppsförvirring",
    "begreppsförvirringen": "begreppsförvirring",
    "begreppsförvirringens": "begreppsförvirring",
    "begreppsförvirrings": "begreppsförvirring",
    "begreppsliga": "begreppslig",
    "begreppsligare": "begreppslig",
    "begreppsligares": "begreppslig",
    "begreppsligas": "begreppslig",
    "begreppsligast": "begreppslig",
    "begreppsligaste": "begreppslig",
    "begreppsligastes": "begreppslig",
    "begreppsligasts": "begreppslig",
    "begreppslige": "begreppslig",
    "begreppsliges": "begreppslig",
    "begreppsligheten": "begreppslighet",
    "begreppslighetens": "begreppslighet",
    "begreppslighets": "begreppslighet",
    "begreppsligs": "begreppslig",
    "begreppsligt": "begreppslig",
    "begreppsligts": "begreppslig",
    "begreppsmässiga": "begreppsmässig",
    "begreppsmässigare": "begreppsmässig",
    "begreppsmässigares": "begreppsmässig",
    "begreppsmässigas": "begreppsmässig",
    "begreppsmässigast": "begreppsmässig",
    "begreppsmässigaste": "begreppsmässig",
    "begreppsmässigastes": "begreppsmässig",
    "begreppsmässigasts": "begreppsmässig",
    "begreppsmässige": "begreppsmässig",
    "begreppsmässiges": "begreppsmässig",
    "begreppsmässigs": "begreppsmässig",
    "begreppsmässigt": "begreppsmässig",
    "begreppsmässigts": "begreppsmässig",
    "begreppsnivåer": "begreppsnivå",
    "begreppsnivåerna": "begreppsnivå",
    "begreppsnivåernas": "begreppsnivå",
    "begreppsnivåers": "begreppsnivå",
    "begreppsnivån": "begreppsnivå",
    "begreppsnivåns": "begreppsnivå",
    "begreppsnivås": "begreppsnivå",
    "begreppssystemen": "begreppssystem",
    "begreppssystemens": "begreppssystem",
    "begreppssystemet": "begreppssystem",
    "begreppssystemets": "begreppssystem",
    "begreppssystems": "begreppssystem",
    "begreps": "begripa",
    "begrip": "begripa",
    "begripande": "begripa",
    "begripanden": "begripande",
    "begripandena": "begripande",
    "begripandenas": "begripande",
    "begripandens": "begripande",
    "begripandes": "begripande",
    "begripandet": "begripande",
    "begripandets": "begripande",
    "begripas": "begripa",
    "begripe": "begripa",
    "begripen": "begripa",
    "begripens": "begripa",
    "begriper": "begripa",
    "begripes": "begripa",
    "begripet": "begripa",
    "begripets": "begripa",
    "begripit": "begripa",
    "begripits": "begripa",
    "begripliga": "begriplig",
    "begripligare": "begriplig",
    "begripligares": "begriplig",
    "begripligas": "begriplig",
    "begripligast": "begriplig",
    "begripligaste": "begriplig",
    "begripligastes": "begriplig",
    "begripligasts": "begriplig",
    "begriplige": "begriplig",
    "begripliges": "begriplig",
    "begripligheten": "begriplighet",
    "begriplighetens": "begriplighet",
    "begripligheter": "begriplighet",
    "begripligheterna": "begriplighet",
    "begripligheternas": "begriplighet",
    "begripligheters": "begriplighet",
    "begriplighets": "begriplighet",
    "begripligs": "begriplig",
    "begripligt": "begriplig",
    "begripligts": "begriplig",
    "begripna": "begripa",
    "begripnas": "begripa",
    "begripne": "begripa",
    "begripnes": "begripa",
    "begrips": "begripa",
    "begrov": "begrava",
    "begrove": "begrava",
    "begroves": "begrava",
    "begrovs": "begrava",
    "begrund": "begrunda",
    "begrundad": "begrunda",
    "begrundade": "begrunda",
    "begrundades": "begrunda",
    "begrundads": "begrunda",
    "begrundande": "begrunda",
    "begrundanden": "begrundande",
    "begrundandena": "begrundande",
    "begrundandenas": "begrundande",
    "begrundandens": "begrundande",
    "begrundandes": "begrundande",
    "begrundandet": "begrundande",
    "begrundandets": "begrundande",
    "begrundans": "begrundan",
    "begrundar": "begrunda",
    "begrundas": "begrunda",
    "begrundat": "begrunda",
    "begrundats": "begrunda",
    "begräns": "begränsa",
    "begränsad": "begränsa",
    "begränsade": "begränsad",
    "begränsades": "begränsad",
    "begränsads": "begränsad",
    "begränsande": "begränsa",
    "begränsanden": "begränsande",
    "begränsandena": "begränsande",
    "begränsandenas": "begränsande",
    "begränsandens": "begränsande",
    "begränsandes": "begränsande",
    "begränsandet": "begränsande",
    "begränsandets": "begränsande",
    "begränsar": "begränsa",
    "begränsas": "begränsa",
    "begränsat": "begränsad",
    "begränsats": "begränsad",
    "begränsningar": "begränsning",
    "begränsningarna": "begränsning",
    "begränsningarnas": "begränsning",
    "begränsningars": "begränsning",
    "begränsningen": "begränsning",
    "begränsningens": "begränsning",
    "begränsnings": "begränsning",
    "begränsningslinjen": "begränsningslinje",
    "begränsningslinjens": "begränsningslinje",
    "begränsningslinjer": "begränsningslinje",
    "begränsningslinjerna": "begränsningslinje",
    "begränsningslinjernas": "begränsningslinje",
    "begränsningslinjers": "begränsningslinje",
    "begränsningslinjes": "begränsningslinje",
    "begränsningsytan": "begränsningsyta",
    "begränsningsytans": "begränsningsyta",
    "begränsningsytas": "begränsningsyta",
    "begränsningsyte": "begränsningsyta",
    "begränsningsytor": "begränsningsyta",
    "begränsningsytorna": "begränsningsyta",
    "begränsningsytornas": "begränsningsyta",
    "begränsningsytors": "begränsningsyta",
    "begrät": "begråta",
    "begräts": "begråta",
    "begråt": "begråta",
    "begråtande": "begråta",
    "begråtanden": "begråtande",
    "begråtandena": "begråtande",
    "begråtandenas": "begråtande",
    "begråtandens": "begråtande",
    "begråtandes": "begråtande",
    "begråtandet": "begråtande",
    "begråtandets": "begråtande",
    "begråtas": "begråta",
    "begråte": "begråta",
    "begråten": "begråta",
    "begråtens": "begråta",
    "begråter": "begråta",
    "begråtes": "begråta",
    "begråtet": "begråta",
    "begråtets": "begråta",
    "begråtit": "begråta",
    "begråtits": "begråta",
    "begråtna": "begråta",
    "begråtnas": "begråta",
    "begråtne": "begråta",
    "begråtnes": "begråta",
    "begråts": "begråta",
    "begynn": "begynna",
    "begynnande": "begynna",
    "begynnanden": "begynnande",
    "begynnandena": "begynnande",
    "begynnandenas": "begynnande",
    "begynnandens": "begynnande",
    "begynnandes": "begynnande",
    "begynnandet": "begynnande",
    "begynnandets": "begynnande",
    "begynnas": "begynna",
    "begynnelsebokstaven": "begynnelsebokstav",
    "begynnelsebokstavens": "begynnelsebokstav",
    "begynnelsebokstavs": "begynnelsebokstav",
    "begynnelsebokstäver": "begynnelsebokstav",
    "begynnelsebokstäverna": "begynnelsebokstav",
    "begynnelsebokstävernas": "begynnelsebokstav",
    "begynnelsebokstävers": "begynnelsebokstav",
    "begynnelsehastigheten": "begynnelsehastighet",
    "begynnelsehastighetens": "begynnelsehastighet",
    "begynnelsehastigheter": "begynnelsehastighet",
    "begynnelsehastigheterna": "begynnelsehastighet",
    "begynnelsehastigheternas": "begynnelsehastighet",
    "begynnelsehastigheters": "begynnelsehastighet",
    "begynnelsehastighets": "begynnelsehastighet",
    "begynnelselönen": "begynnelselön",
    "begynnelselönens": "begynnelselön",
    "begynnelselöner": "begynnelselön",
    "begynnelselönerna": "begynnelselön",
    "begynnelselönernas": "begynnelselön",
    "begynnelselöners": "begynnelselön",
    "begynnelselöns": "begynnelselön",
    "begynnelsen": "begynnelse",
    "begynnelsens": "begynnelse",
    "begynnelser": "begynnelse",
    "begynnelserimmen": "begynnelserim",
    "begynnelserimmens": "begynnelserim",
    "begynnelserimmet": "begynnelserim",
    "begynnelserimmets": "begynnelserim",
    "begynnelserims": "begynnelserim",
    "begynnelserna": "begynnelse",
    "begynnelsernas": "begynnelse",
    "begynnelsers": "begynnelse",
    "begynnelses": "begynnelse",
    "begynnelseskeden": "begynnelseskede",
    "begynnelseskedena": "begynnelseskede",
    "begynnelseskedenas": "begynnelseskede",
    "begynnelseskedens": "begynnelseskede",
    "begynnelseskedes": "begynnelseskede",
    "begynnelseskedet": "begynnelseskede",
    "begynnelseskedets": "begynnelseskede",
    "begynnelsespråken": "begynnelsespråk",
    "begynnelsespråkens": "begynnelsespråk",
    "begynnelsespråket": "begynnelsespråk",
    "begynnelsespråkets": "begynnelsespråk",
    "begynnelsespråks": "begynnelsespråk",
    "begynnelsestadie": "begynnelsestadium",
    "begynnelsestadier": "begynnelsestadium",
    "begynnelsestadierna": "begynnelsestadium",
    "begynnelsestadiernas": "begynnelsestadium",
    "begynnelsestadiers": "begynnelsestadium",
    "begynnelsestadiet": "begynnelsestadium",
    "begynnelsestadiets": "begynnelsestadium",
    "begynnelsestadiums": "begynnelsestadium",
    "begynnelsevärden": "begynnelsevärde",
    "begynnelsevärdena": "begynnelsevärde",
    "begynnelsevärdenas": "begynnelsevärde",
    "begynnelsevärdens": "begynnelsevärde",
    "begynnelsevärdes": "begynnelsevärde",
    "begynnelsevärdet": "begynnelsevärde",
    "begynnelsevärdets": "begynnelsevärde",
    "begynner": "begynna",
    "begynnes": "begynna",
    "begynns": "begynna",
    "begynt": "begynna",
    "begynte": "begynna",
    "begyntes": "begynna",
    "begynts": "begynna",
    "begär": "begära",
    "begärande": "begära",
    "begäranden": "begärande",
    "begärandena": "begärande",
    "begärandenas": "begärande",
    "begärandens": "begärande",
    "begärandes": "begärande",
    "begärandet": "begärande",
    "begärandets": "begärande",
    "begärans": "begäran",
    "begäras": "begära",
    "begärd": "begära",
    "begärda": "begära",
    "begärdas": "begära",
    "begärde": "begära",
    "begärdes": "begära",
    "begärds": "begära",
    "begärelsen": "begärelse",
    "begärelsens": "begärelse",
    "begärelser": "begärelse",
    "begärelserna": "begärelse",
    "begärelsernas": "begärelse",
    "begärelsers": "begärelse",
    "begärelses": "begärelse",
    "begären": "begär",
    "begärens": "begär",
    "begäres": "begära",
    "begäret": "begär",
    "begärets": "begär",
    "begärliga": "begärlig",
    "begärligare": "begärlig",
    "begärligares": "begärlig",
    "begärligas": "begärlig",
    "begärligast": "begärlig",
    "begärligaste": "begärlig",
    "begärligastes": "begärlig",
    "begärligasts": "begärlig",
    "begärlige": "begärlig",
    "begärliges": "begärlig",
    "begärligheten": "begärlighet",
    "begärlighetens": "begärlighet",
    "begärligheter": "begärlighet",
    "begärligheterna": "begärlighet",
    "begärligheternas": "begärlighet",
    "begärligheters": "begärlighet",
    "begärlighets": "begärlighet",
    "begärligs": "begärlig",
    "begärligt": "begärlig",
    "begärligts": "begärlig",
    "begärs": "begära",
    "begärt": "begära",
    "begärts": "begära",
    "begående": "begå",
    "begåenden": "begående",
    "begåendena": "begående",
    "begåendenas": "begående",
    "begåendens": "begående",
    "begåendes": "begående",
    "begåendet": "begående",
    "begåendets": "begående",
    "begånge": "begå",
    "begången": "begå",
    "begångens": "begå",
    "begånges": "begå",
    "begånget": "begå",
    "begångets": "begå",
    "begångna": "begå",
    "begångnas": "begå",
    "begångne": "begå",
    "begångnes": "begå",
    "begår": "begå",
    "begås": "begå",
    "begått": "begå",
    "begåtts": "begå",
    "begåv": "begåva",
    "begåvad": "begåva",
    "begåvade": "begåvad",
    "begåvades": "begåvad",
    "begåvads": "begåvad",
    "begåvande": "begåva",
    "begåvanden": "begåvande",
    "begåvandena": "begåvande",
    "begåvandenas": "begåvande",
    "begåvandens": "begåvande",
    "begåvandes": "begåvande",
    "begåvandet": "begåvande",
    "begåvandets": "begåvande",
    "begåvar": "begåva",
    "begåvas": "begåva",
    "begåvat": "begåvad",
    "begåvats": "begåvad",
    "begåvningar": "begåvning",
    "begåvningarna": "begåvning",
    "begåvningarnas": "begåvning",
    "begåvningars": "begåvning",
    "begåvningen": "begåvning",
    "begåvningens": "begåvning",
    "begåvnings": "begåvning",
    "begåvningsmässiga": "begåvningsmässig",
    "begåvningsmässigare": "begåvningsmässig",
    "begåvningsmässigares": "begåvningsmässig",
    "begåvningsmässigas": "begåvningsmässig",
    "begåvningsmässigast": "begåvningsmässig",
    "begåvningsmässigaste": "begåvningsmässig",
    "begåvningsmässigastes": "begåvningsmässig",
    "begåvningsmässigasts": "begåvningsmässig",
    "begåvningsmässige": "begåvningsmässig",
    "begåvningsmässiges": "begåvningsmässig",
    "begåvningsmässigs": "begåvningsmässig",
    "begåvningsmässigt": "begåvningsmässig",
    "begåvningsmässigts": "begåvningsmässig",
    "begåvningsreserven": "begåvningsreserv",
    "begåvningsreservens": "begåvningsreserv",
    "begåvningsreserver": "begåvningsreserv",
    "begåvningsreserverna": "begåvningsreserv",
    "begåvningsreservernas": "begåvningsreserv",
    "begåvningsreservers": "begåvningsreserv",
    "begåvningsreservs": "begåvningsreserv",
    "begöt": "begjuta",
    "begöte": "begjuta",
    "begötes": "begjuta",
    "begöts": "begjuta",
    "behag": "behaga",
    "behagade": "behaga",
    "behagades": "behaga",
    "behagande": "behaga",
    "behaganden": "behagande",
    "behagandena": "behagande",
    "behagandenas": "behagande",
    "behagandens": "behagande",
    "behagandes": "behagande",
    "behagandet": "behagande",
    "behagandets": "behagande",
    "behagar": "behaga",
    "behagas": "behaga",
    "behagat": "behaga",
    "behagats": "behaga",
    "behagen": "behag",
    "behagens": "behag",
    "behaget": "behag",
    "behagets": "behag",
    "behagfulla": "behagfull",
    "behagfullare": "behagfull",
    "behagfullares": "behagfull",
    "behagfullas": "behagfull",
    "behagfullast": "behagfull",
    "behagfullaste": "behagfull",
    "behagfullastes": "behagfull",
    "behagfullasts": "behagfull",
    "behagfulle": "behagfull",
    "behagfulles": "behagfull",
    "behagfullheten": "behagfullhet",
    "behagfullhetens": "behagfullhet",
    "behagfullheter": "behagfullhet",
    "behagfullheterna": "behagfullhet",
    "behagfullheternas": "behagfullhet",
    "behagfullheters": "behagfullhet",
    "behagfullhets": "behagfullhet",
    "behagfulls": "behagfull",
    "behagfullt": "behagfull",
    "behagfullts": "behagfull",
    "behagliga": "behaglig",
    "behagligare": "behaglig",
    "behagligares": "behaglig",
    "behagligas": "behaglig",
    "behagligast": "behaglig",
    "behagligaste": "behaglig",
    "behagligastes": "behaglig",
    "behagligasts": "behaglig",
    "behaglige": "behaglig",
    "behagliges": "behaglig",
    "behagligheten": "behaglighet",
    "behaglighetens": "behaglighet",
    "behagligheter": "behaglighet",
    "behagligheterna": "behaglighet",
    "behagligheternas": "behaglighet",
    "behagligheters": "behaglighet",
    "behaglighets": "behaglighet",
    "behagligs": "behaglig",
    "behagligt": "behaglig",
    "behagligts": "behaglig",
    "behags": "behag",
    "behagsjuka": "behagsjuk",
    "behagsjukan": "behagsjuka",
    "behagsjukans": "behagsjuka",
    "behagsjukare": "behagsjuk",
    "behagsjukares": "behagsjuk",
    "behagsjukas": "behagsjuka",
    "behagsjukast": "behagsjuk",
    "behagsjukaste": "behagsjuk",
    "behagsjukastes": "behagsjuk",
    "behagsjukasts": "behagsjuk",
    "behagsjuke": "behagsjuka",
    "behagsjukes": "behagsjuk",
    "behagsjukheten": "behagsjukhet",
    "behagsjukhetens": "behagsjukhet",
    "behagsjukhets": "behagsjukhet",
    "behagsjuks": "behagsjuka",
    "behagsjukt": "behagsjuk",
    "behagsjukts": "behagsjuk",
    "behandlad": "behandla",
    "behandlade": "behandla",
    "behandlades": "behandla",
    "behandlads": "behandla",
    "behandlande": "behandla",
    "behandlanden": "behandlande",
    "behandlandena": "behandlande",
    "behandlandenas": "behandlande",
    "behandlandens": "behandlande",
    "behandlandes": "behandlande",
    "behandlandet": "behandlande",
    "behandlandets": "behandlande",
    "behandlar": "behandla",
    "behandlas": "behandla",
    "behandlat": "behandla",
    "behandlats": "behandla",
    "behandlingar": "behandling",
    "behandlingarna": "behandling",
    "behandlingarnas": "behandling",
    "behandlingars": "behandling",
    "behandlingen": "behandling",
    "behandlingens": "behandling",
    "behandlings": "behandling",
    "behandlingsalternativen": "behandlingsalternativ",
    "behandlingsalternativens": "behandlingsalternativ",
    "behandlingsalternativet": "behandlingsalternativ",
    "behandlingsalternativets": "behandlingsalternativ",
    "behandlingsalternativs": "behandlingsalternativ",
    "behandlingsbara": "behandlingsbar",
    "behandlingsbarare": "behandlingsbar",
    "behandlingsbarares": "behandlingsbar",
    "behandlingsbaras": "behandlingsbar",
    "behandlingsbarast": "behandlingsbar",
    "behandlingsbaraste": "behandlingsbar",
    "behandlingsbarastes": "behandlingsbar",
    "behandlingsbarasts": "behandlingsbar",
    "behandlingsbare": "behandlingsbar",
    "behandlingsbares": "behandlingsbar",
    "behandlingsbarheten": "behandlingsbarhet",
    "behandlingsbarhetens": "behandlingsbarhet",
    "behandlingsbarhets": "behandlingsbarhet",
    "behandlingsbars": "behandlingsbar",
    "behandlingsbart": "behandlingsbar",
    "behandlingsbarts": "behandlingsbar",
    "behandlingsenheten": "behandlingsenhet",
    "behandlingsenhetens": "behandlingsenhet",
    "behandlingsenheter": "behandlingsenhet",
    "behandlingsenheterna": "behandlingsenhet",
    "behandlingsenheternas": "behandlingsenhet",
    "behandlingsenheters": "behandlingsenhet",
    "behandlingsenhets": "behandlingsenhet",
    "behandlingshemmen": "behandlingshem",
    "behandlingshemmens": "behandlingshem",
    "behandlingshemmet": "behandlingshem",
    "behandlingshemmets": "behandlingshem",
    "behandlingshems": "behandlingshem",
    "behandlingsmetoden": "behandlingsmetod",
    "behandlingsmetodens": "behandlingsmetod",
    "behandlingsmetoder": "behandlingsmetod",
    "behandlingsmetoderna": "behandlingsmetod",
    "behandlingsmetodernas": "behandlingsmetod",
    "behandlingsmetoders": "behandlingsmetod",
    "behandlingsmetods": "behandlingsmetod",
    "behandlingsmässiga": "behandlingsmässig",
    "behandlingsmässigare": "behandlingsmässig",
    "behandlingsmässigares": "behandlingsmässig",
    "behandlingsmässigas": "behandlingsmässig",
    "behandlingsmässigast": "behandlingsmässig",
    "behandlingsmässigaste": "behandlingsmässig",
    "behandlingsmässigastes": "behandlingsmässig",
    "behandlingsmässigasts": "behandlingsmässig",
    "behandlingsmässige": "behandlingsmässig",
    "behandlingsmässiges": "behandlingsmässig",
    "behandlingsmässigs": "behandlingsmässig",
    "behandlingsmässigt": "behandlingsmässig",
    "behandlingsmässigts": "behandlingsmässig",
    "behandlingsprogrammen": "behandlingsprogram",
    "behandlingsprogrammens": "behandlingsprogram",
    "behandlingsprogrammet": "behandlingsprogram",
    "behandlingsprogrammets": "behandlingsprogram",
    "behandlingsprograms": "behandlingsprogram",
    "behandlingsrummen": "behandlingsrum",
    "behandlingsrummens": "behandlingsrum",
    "behandlingsrummet": "behandlingsrum",
    "behandlingsrummets": "behandlingsrum",
    "behandlingsrums": "behandlingsrum",
    "behandskade": "behandskad",
    "behandskades": "behandskad",
    "behandskads": "behandskad",
    "behandskat": "behandskad",
    "behandskats": "behandskad",
    "behaviorismen": "behaviorism",
    "behaviorismens": "behaviorism",
    "behaviorismer": "behaviorism",
    "behaviorismerna": "behaviorism",
    "behaviorismernas": "behaviorism",
    "behaviorismers": "behaviorism",
    "behaviorisms": "behaviorism",
    "behavioristen": "behaviorist",
    "behavioristens": "behaviorist",
    "behaviorister": "behaviorist",
    "behavioristerna": "behaviorist",
    "behavioristernas": "behaviorist",
    "behavioristers": "behaviorist",
    "behavioristiska": "behavioristisk",
    "behavioristiskas": "behavioristisk",
    "behavioristiske": "behavioristisk",
    "behavioristiskes": "behavioristisk",
    "behavioristisks": "behavioristisk",
    "behavioristiskt": "behavioristisk",
    "behavioristiskts": "behavioristisk",
    "behaviorists": "behaviorist",
    "behjälpliga": "behjälplig",
    "behjälpligare": "behjälplig",
    "behjälpligares": "behjälplig",
    "behjälpligas": "behjälplig",
    "behjälpligast": "behjälplig",
    "behjälpligaste": "behjälplig",
    "behjälpligastes": "behjälplig",
    "behjälpligasts": "behjälplig",
    "behjälplige": "behjälplig",
    "behjälpliges": "behjälplig",
    "behjälpligheten": "behjälplighet",
    "behjälplighetens": "behjälplighet",
    "behjälplighets": "behjälplighet",
    "behjälpligs": "behjälplig",
    "behjälpligt": "behjälplig",
    "behjälpligts": "behjälplig",
    "behjärtade": "behjärtad",
    "behjärtades": "behjärtad",
    "behjärtads": "behjärtad",
    "behjärtansvärda": "behjärtansvärd",
    "behjärtansvärdare": "behjärtansvärd",
    "behjärtansvärdares": "behjärtansvärd",
    "behjärtansvärdas": "behjärtansvärd",
    "behjärtansvärdast": "behjärtansvärd",
    "behjärtansvärdaste": "behjärtansvärd",
    "behjärtansvärdastes": "behjärtansvärd",
    "behjärtansvärdasts": "behjärtansvärd",
    "behjärtansvärde": "behjärtansvärd",
    "behjärtansvärdes": "behjärtansvärd",
    "behjärtansvärds": "behjärtansvärd",
    "behjärtansvärt": "behjärtansvärd",
    "behjärtansvärts": "behjärtansvärd",
    "behjärtat": "behjärtad",
    "behjärtats": "behjärtad",
    "behjärtenheten": "behjärtenhet",
    "behjärtenhetens": "behjärtenhet",
    "behjärtenheter": "behjärtenhet",
    "behjärtenheterna": "behjärtenhet",
    "behjärtenheternas": "behjärtenhet",
    "behjärtenheters": "behjärtenhet",
    "behjärtenhets": "behjärtenhet",
    "behornade": "behornad",
    "behornades": "behornad",
    "behornads": "behornad",
    "behornat": "behornad",
    "behornats": "behornad",
    "behoven": "behov",
    "behovens": "behov",
    "behovet": "behov",
    "behovets": "behov",
    "behovlösa": "behovlös",
    "behovlösare": "behovlös",
    "behovlösares": "behovlös",
    "behovlösas": "behovlös",
    "behovlösast": "behovlös",
    "behovlösaste": "behovlös",
    "behovlösastes": "behovlös",
    "behovlösasts": "behovlös",
    "behovlöse": "behovlös",
    "behovlöses": "behovlös",
    "behovlösheten": "behovlöshet",
    "behovlöshetens": "behovlöshet",
    "behovlösheter": "behovlöshet",
    "behovlösheterna": "behovlöshet",
    "behovlösheternas": "behovlöshet",
    "behovlösheters": "behovlöshet",
    "behovlöshets": "behovlöshet",
    "behovlöst": "behovlös",
    "behovlösts": "behovlös",
    "behovs": "behov",
    "behovsprincipen": "behovsprincip",
    "behovsprincipens": "behovsprincip",
    "behovsprinciper": "behovsprincip",
    "behovsprinciperna": "behovsprincip",
    "behovsprincipernas": "behovsprincip",
    "behovsprincipers": "behovsprincip",
    "behovsprincips": "behovsprincip",
    "behovsprövade": "behovsprövad",
    "behovsprövades": "behovsprövad",
    "behovsprövads": "behovsprövad",
    "behovsprövat": "behovsprövad",
    "behovsprövats": "behovsprövad",
    "behovsprövningar": "behovsprövning",
    "behovsprövningarna": "behovsprövning",
    "behovsprövningarnas": "behovsprövning",
    "behovsprövningars": "behovsprövning",
    "behovsprövningen": "behovsprövning",
    "behovsprövningens": "behovsprövning",
    "behovsprövnings": "behovsprövning",
    "behovstillfredsställelsen": "behovstillfredsställelse",
    "behovstillfredsställelsens": "behovstillfredsställelse",
    "behovstillfredsställelser": "behovstillfredsställelse",
    "behovstillfredsställelserna": "behovstillfredsställelse",
    "behovstillfredsställelsernas": "behovstillfredsställelse",
    "behovstillfredsställelsers": "behovstillfredsställelse",
    "behovstillfredsställelses": "behovstillfredsställelse",
    "behovstrycken": "behovstryck",
    "behovstryckens": "behovstryck",
    "behovstrycket": "behovstryck",
    "behovstryckets": "behovstryck",
    "behovstrycks": "behovstryck",
    "behäftade": "behäftad",
    "behäftades": "behäftad",
    "behäftads": "behäftad",
    "behäftat": "behäftad",
    "behäftats": "behäftad",
    "behändiga": "behändig",
    "behändigare": "behändig",
    "behändigares": "behändig",
    "behändigas": "behändig",
    "behändigast": "behändig",
    "behändigaste": "behändig",
    "behändigastes": "behändig",
    "behändigasts": "behändig",
    "behändige": "behändig",
    "behändiges": "behändig",
    "behändigheten": "behändighet",
    "behändighetens": "behändighet",
    "behändighets": "behändighet",
    "behändigs": "behändig",
    "behändigt": "behändig",
    "behändigts": "behändig",
    "behäng": "behänga",
    "behängande": "behänga",
    "behänganden": "behängande",
    "behängandena": "behängande",
    "behängandenas": "behängande",
    "behängandens": "behängande",
    "behängandes": "behängande",
    "behängandet": "behängande",
    "behängandets": "behängande",
    "behängas": "behänga",
    "behängd": "behänga",
    "behängda": "behänga",
    "behängdas": "behänga",
    "behängde": "behänga",
    "behängdes": "behänga",
    "behängds": "behänga",
    "behänger": "behänga",
    "behänges": "behänga",
    "behängs": "behänga",
    "behängt": "behänga",
    "behängts": "behänga",
    "behärsk": "behärska",
    "behärskad": "behärska",
    "behärskade": "behärskad",
    "behärskades": "behärskad",
    "behärskads": "behärskad",
    "behärskande": "behärska",
    "behärskanden": "behärskande",
    "behärskandena": "behärskande",
    "behärskandenas": "behärskande",
    "behärskandens": "behärskande",
    "behärskandes": "behärskande",
    "behärskandet": "behärskande",
    "behärskandets": "behärskande",
    "behärskar": "behärska",
    "behärskas": "behärska",
    "behärskat": "behärskad",
    "behärskats": "behärskad",
    "behärskningar": "behärskning",
    "behärskningarna": "behärskning",
    "behärskningarnas": "behärskning",
    "behärskningars": "behärskning",
    "behärskningen": "behärskning",
    "behärskningens": "behärskning",
    "behärsknings": "behärskning",
    "behåar": "behå",
    "behåarna": "behå",
    "behåarnas": "behå",
    "behåars": "behå",
    "behåll": "behålla",
    "behållande": "behålla",
    "behållanden": "behållande",
    "behållandena": "behållande",
    "behållandenas": "behållande",
    "behållandens": "behållande",
    "behållandes": "behållande",
    "behållandet": "behållande",
    "behållandets": "behållande",
    "behållar": "behållare",
    "behållaren": "behållare",
    "behållarens": "behållare",
    "behållares": "behållare",
    "behållarna": "behållare",
    "behållarnas": "behållare",
    "behållas": "behålla",
    "behålle": "behålla",
    "behållen": "behålla",
    "behållens": "behålla",
    "behåller": "behålla",
    "behålles": "behålla",
    "behållet": "behålla",
    "behållets": "behålla",
    "behållit": "behålla",
    "behållits": "behålla",
    "behållna": "behålla",
    "behållnas": "behålla",
    "behållne": "behålla",
    "behållnes": "behålla",
    "behållningar": "behållning",
    "behållningarna": "behållning",
    "behållningarnas": "behållning",
    "behållningars": "behållning",
    "behållningen": "behållning",
    "behållningens": "behållning",
    "behållnings": "behållning",
    "behålls": "behålla",
    "behån": "behå",
    "behåns": "behå",
    "behårade": "behårad",
    "behårades": "behårad",
    "behårads": "behårad",
    "behårat": "behårad",
    "behårats": "behårad",
    "behåringar": "behåring",
    "behåringarna": "behåring",
    "behåringarnas": "behåring",
    "behåringars": "behåring",
    "behåringen": "behåring",
    "behåringens": "behåring",
    "behårings": "behåring",
    "behås": "behå",
    "behöll": "behålla",
    "behölle": "behålla",
    "behölles": "behålla",
    "behölls": "behålla",
    "behöriga": "behörig",
    "behörigare": "behörig",
    "behörigares": "behörig",
    "behörigas": "behörig",
    "behörigast": "behörig",
    "behörigaste": "behörig",
    "behörigastes": "behörig",
    "behörigasts": "behörig",
    "behörige": "behörig",
    "behöriges": "behörig",
    "behörigheten": "behörighet",
    "behörighetens": "behörighet",
    "behörigheter": "behörighet",
    "behörigheterna": "behörighet",
    "behörigheternas": "behörighet",
    "behörigheters": "behörighet",
    "behörighets": "behörighet",
    "behörighetsbevisen": "behörighetsbevis",
    "behörighetsbevisens": "behörighetsbevis",
    "behörighetsbeviset": "behörighetsbevis",
    "behörighetsbevisets": "behörighetsbevis",
    "behörigs": "behörig",
    "behörigt": "behörig",
    "behörigts": "behörig",
    "behöv": "behöva",
    "behövande": "behöva",
    "behövanden": "behövande",
    "behövandena": "behövande",
    "behövandenas": "behövande",
    "behövandens": "behövande",
    "behövandes": "behövande",
    "behövandet": "behövande",
    "behövandets": "behövande",
    "behövas": "behöva",
    "behövd": "behöva",
    "behövda": "behöva",
    "behövdas": "behöva",
    "behövde": "behöva",
    "behövdes": "behövas",
    "behövds": "behöva",
    "behöver": "behöva",
    "behöves": "behövas",
    "behövliga": "behövlig",
    "behövligare": "behövlig",
    "behövligares": "behövlig",
    "behövligas": "behövlig",
    "behövligast": "behövlig",
    "behövligaste": "behövlig",
    "behövligastes": "behövlig",
    "behövligasts": "behövlig",
    "behövlige": "behövlig",
    "behövliges": "behövlig",
    "behövligheten": "behövlighet",
    "behövlighetens": "behövlighet",
    "behövlighets": "behövlighet",
    "behövligs": "behövlig",
    "behövligt": "behövlig",
    "behövligts": "behövlig",
    "behövs": "behövas",
    "behövt": "behöva",
    "behövts": "behövas",
    "beigea": "beige",
    "beigeare": "beige",
    "beigeares": "beige",
    "beigeas": "beige",
    "beigeast": "beige",
    "beigeaste": "beige",
    "beigeastes": "beige",
    "beigeasts": "beige",
    "beiges": "beige",
    "beiget": "beige",
    "beigets": "beige",
    "beivrad": "beivra",
    "beivrade": "beivra",
    "beivrades": "beivra",
    "beivrads": "beivra",
    "beivrande": "beivra",
    "beivranden": "beivrande",
    "beivrandena": "beivrande",
    "beivrandenas": "beivrande",
    "beivrandens": "beivrande",
    "beivrandes": "beivrande",
    "beivrandet": "beivrande",
    "beivrandets": "beivrande",
    "beivrans": "beivran",
    "beivrar": "beivra",
    "beivras": "beivra",
    "beivrat": "beivra",
    "beivrats": "beivra",
    "bejak": "bejaka",
    "bejakad": "bejaka",
    "bejakade": "bejaka",
    "bejakades": "bejaka",
    "bejakads": "bejaka",
    "bejakande": "bejaka",
    "bejakanden": "bejakande",
    "bejakandena": "bejakande",
    "bejakandenas": "bejakande",
    "bejakandens": "bejakande",
    "bejakandes": "bejakande",
    "bejakandet": "bejakande",
    "bejakandets": "bejakande",
    "bejakar": "bejaka",
    "bejakas": "bejaka",
    "bejakat": "bejaka",
    "bejakats": "bejaka",
    "bejen": "bej",
    "bejens": "bej",
    "bejer": "bej",
    "bejerna": "bej",
    "bejernas": "bej",
    "bejers": "bej",
    "bejs": "bej",
    "bejublad": "bejubla",
    "bejublade": "bejubla",
    "bejublades": "bejubla",
    "bejublads": "bejubla",
    "bejublande": "bejubla",
    "bejublanden": "bejublande",
    "bejublandena": "bejublande",
    "bejublandenas": "bejublande",
    "bejublandens": "bejublande",
    "bejublandes": "bejublande",
    "bejublandet": "bejublande",
    "bejublandets": "bejublande",
    "bejublar": "bejubla",
    "bejublas": "bejubla",
    "bejublat": "bejubla",
    "bejublats": "bejubla",
    "bekaj": "bekaja",
    "bekajad": "bekaja",
    "bekajade": "bekaja",
    "bekajades": "bekaja",
    "bekajads": "bekaja",
    "bekajande": "bekaja",
    "bekajanden": "bekajande",
    "bekajandena": "bekajande",
    "bekajandenas": "bekajande",
    "bekajandens": "bekajande",
    "bekajandes": "bekajande",
    "bekajandet": "bekajande",
    "bekajandets": "bekajande",
    "bekajar": "bekaja",
    "bekajas": "bekaja",
    "bekajat": "bekaja",
    "bekajats": "bekaja",
    "bekanta": "bekant",
    "bekantare": "bekant",
    "bekantares": "bekant",
    "bekantas": "bekant",
    "bekantast": "bekant",
    "bekantaste": "bekant",
    "bekantastes": "bekant",
    "bekantasts": "bekant",
    "bekante": "bekant",
    "bekanten": "bekant",
    "bekantens": "bekant",
    "bekanter": "bekant",
    "bekanterna": "bekant",
    "bekanternas": "bekant",
    "bekanters": "bekant",
    "bekantes": "bekant",
    "bekantgjord": "bekantgöra",
    "bekantgjorda": "bekantgöra",
    "bekantgjordas": "bekantgöra",
    "bekantgjorde": "bekantgöra",
    "bekantgjordes": "bekantgöra",
    "bekantgjords": "bekantgöra",
    "bekantgjort": "bekantgöra",
    "bekantgjorts": "bekantgöra",
    "bekantgör": "bekantgöra",
    "bekantgörande": "bekantgöra",
    "bekantgöranden": "bekantgörande",
    "bekantgörandena": "bekantgörande",
    "bekantgörandenas": "bekantgörande",
    "bekantgörandens": "bekantgörande",
    "bekantgörandes": "bekantgörande",
    "bekantgörandet": "bekantgörande",
    "bekantgörandets": "bekantgörande",
    "bekantgöras": "bekantgöra",
    "bekantgöres": "bekantgöra",
    "bekantgörs": "bekantgöra",
    "bekantingar": "bekanting",
    "bekantingarna": "bekanting",
    "bekantingarnas": "bekanting",
    "bekantingars": "bekanting",
    "bekantingen": "bekanting",
    "bekantingens": "bekanting",
    "bekantings": "bekanting",
    "bekants": "bekant",
    "bekantskapen": "bekantskap",
    "bekantskapens": "bekantskap",
    "bekantskaper": "bekantskap",
    "bekantskaperna": "bekantskap",
    "bekantskapernas": "bekantskap",
    "bekantskapers": "bekantskap",
    "bekantskaps": "bekantskap",
    "bekantskapskretsar": "bekantskapskrets",
    "bekantskapskretsarna": "bekantskapskrets",
    "bekantskapskretsarnas": "bekantskapskrets",
    "bekantskapskretsars": "bekantskapskrets",
    "bekantskapskretsen": "bekantskapskrets",
    "bekantskapskretsens": "bekantskapskrets",
    "bekik": "bekika",
    "bekikad": "bekika",
    "bekikade": "bekika",
    "bekikades": "bekika",
    "bekikads": "bekika",
    "bekikande": "bekika",
    "bekikanden": "bekikande",
    "bekikandena": "bekikande",
    "bekikandenas": "bekikande",
    "bekikandens": "bekikande",
    "bekikandes": "bekikande",
    "bekikandet": "bekikande",
    "bekikandets": "bekikande",
    "bekikar": "bekika",
    "bekikas": "bekika",
    "bekikat": "bekika",
    "bekikats": "bekika",
    "beklag": "beklaga",
    "beklagad": "beklaga",
    "beklagade": "beklaga",
    "beklagades": "beklaga",
    "beklagads": "beklaga",
    "beklagande": "beklaga",
    "beklaganden": "beklagande",
    "beklagandena": "beklagande",
    "beklagandenas": "beklagande",
    "beklagandens": "beklagande",
    "beklagandes": "beklagande",
    "beklagandet": "beklagande",
    "beklagandets": "beklagande",
    "beklagansvärda": "beklagansvärd",
    "beklagansvärdare": "beklagansvärd",
    "beklagansvärdares": "beklagansvärd",
    "beklagansvärdas": "beklagansvärd",
    "beklagansvärdast": "beklagansvärd",
    "beklagansvärdaste": "beklagansvärd",
    "beklagansvärdastes": "beklagansvärd",
    "beklagansvärdasts": "beklagansvärd",
    "beklagansvärde": "beklagansvärd",
    "beklagansvärdes": "beklagansvärd",
    "beklagansvärds": "beklagansvärd",
    "beklagansvärt": "beklagansvärd",
    "beklagansvärts": "beklagansvärd",
    "beklagar": "beklaga",
    "beklagas": "beklaga",
    "beklagat": "beklaga",
    "beklagats": "beklaga",
    "beklagliga": "beklaglig",
    "beklagligare": "beklaglig",
    "beklagligares": "beklaglig",
    "beklagligas": "beklaglig",
    "beklagligast": "beklaglig",
    "beklagligaste": "beklaglig",
    "beklagligastes": "beklaglig",
    "beklagligasts": "beklaglig",
    "beklaglige": "beklaglig",
    "beklagliges": "beklaglig",
    "beklagligheten": "beklaglighet",
    "beklaglighetens": "beklaglighet",
    "beklaglighets": "beklaglighet",
    "beklagligs": "beklaglig",
    "beklagligt": "beklaglig",
    "beklagligts": "beklaglig",
    "bekläd": "beklä",
    "bekläda": "beklä",
    "beklädande": "beklä",
    "beklädanden": "beklädande",
    "beklädandena": "beklädande",
    "beklädandenas": "beklädande",
    "beklädandens": "beklädande",
    "beklädandes": "beklädande",
    "beklädandet": "beklädande",
    "beklädandets": "beklädande",
    "beklädas": "beklä",
    "beklädd": "beklä",
    "beklädda": "beklä",
    "bekläddas": "beklä",
    "beklädde": "beklä",
    "bekläddes": "beklä",
    "beklädds": "beklä",
    "bekläder": "beklä",
    "beklädnaden": "beklädnad",
    "beklädnadens": "beklädnad",
    "beklädnader": "beklädnad",
    "beklädnaderna": "beklädnad",
    "beklädnadernas": "beklädnad",
    "beklädnaders": "beklädnad",
    "beklädnads": "beklädnad",
    "bekläds": "beklä",
    "bekläende": "beklä",
    "bekläendes": "beklä",
    "beklämda": "beklämd",
    "beklämdare": "beklämd",
    "beklämdares": "beklämd",
    "beklämdas": "beklämd",
    "beklämdast": "beklämd",
    "beklämdaste": "beklämd",
    "beklämdastes": "beklämd",
    "beklämdasts": "beklämd",
    "beklämde": "beklämd",
    "beklämdes": "beklämd",
    "beklämdheten": "beklämdhet",
    "beklämdhetens": "beklämdhet",
    "beklämdhets": "beklämdhet",
    "beklämds": "beklämd",
    "beklämningar": "beklämning",
    "beklämningarna": "beklämning",
    "beklämningarnas": "beklämning",
    "beklämningars": "beklämning",
    "beklämningen": "beklämning",
    "beklämningens": "beklämning",
    "beklämnings": "beklämning",
    "beklämt": "beklämd",
    "beklämts": "beklämd",
    "beklär": "beklä",
    "bekläs": "beklä",
    "beklätt": "beklä",
    "beklätts": "beklä",
    "beknep": "beknipa",
    "bekneps": "beknipa",
    "beknip": "beknipa",
    "beknipande": "beknipa",
    "beknipanden": "beknipande",
    "beknipandena": "beknipande",
    "beknipandenas": "beknipande",
    "beknipandens": "beknipande",
    "beknipandes": "beknipande",
    "beknipandet": "beknipande",
    "beknipandets": "beknipande",
    "beknipas": "beknipa",
    "beknipe": "beknipa",
    "beknipen": "beknipa",
    "beknipens": "beknipa",
    "bekniper": "beknipa",
    "beknipes": "beknipa",
    "beknipet": "beknipa",
    "beknipets": "beknipa",
    "beknipit": "beknipa",
    "beknipits": "beknipa",
    "beknipna": "beknipa",
    "beknipnas": "beknipa",
    "beknipne": "beknipa",
    "beknipnes": "beknipa",
    "beknips": "beknipa",
    "bekom": "bekomma",
    "bekommande": "bekomma",
    "bekommanden": "bekommande",
    "bekommandena": "bekommande",
    "bekommandenas": "bekommande",
    "bekommandens": "bekommande",
    "bekommandes": "bekommande",
    "bekommandet": "bekommande",
    "bekommandets": "bekommande",
    "bekommas": "bekomma",
    "bekomme": "bekomma",
    "bekommer": "bekomma",
    "bekommes": "bekomma",
    "bekommit": "bekomma",
    "bekommits": "bekomma",
    "bekoms": "bekomma",
    "bekost": "bekosta",
    "bekostad": "bekosta",
    "bekostade": "bekosta",
    "bekostades": "bekosta",
    "bekostads": "bekosta",
    "bekostande": "bekosta",
    "bekostanden": "bekostande",
    "bekostandena": "bekostande",
    "bekostandenas": "bekostande",
    "bekostandens": "bekostande",
    "bekostandes": "bekostande",
    "bekostandet": "bekostande",
    "bekostandets": "bekostande",
    "bekostar": "bekosta",
    "bekostas": "bekosta",
    "bekostat": "bekosta",
    "bekostats": "bekosta",
    "bekostnaden": "bekostnad",
    "bekostnadens": "bekostnad",
    "bekostnader": "bekostnad",
    "bekostnaderna": "bekostnad",
    "bekostnadernas": "bekostnad",
    "bekostnaders": "bekostnad",
    "bekostnads": "bekostnad",
    "bekrans": "bekransa",
    "bekransad": "bekransa",
    "bekransade": "bekransa",
    "bekransades": "bekransa",
    "bekransads": "bekransa",
    "bekransande": "bekransa",
    "bekransanden": "bekransande",
    "bekransandena": "bekransande",
    "bekransandenas": "bekransande",
    "bekransandens": "bekransande",
    "bekransandes": "bekransande",
    "bekransandet": "bekransande",
    "bekransandets": "bekransande",
    "bekransar": "bekransa",
    "bekransas": "bekransa",
    "bekransat": "bekransa",
    "bekransats": "bekransa",
    "bekrig": "bekriga",
    "bekrigad": "bekriga",
    "bekrigade": "bekriga",
    "bekrigades": "bekriga",
    "bekrigads": "bekriga",
    "bekrigande": "bekriga",
    "bekriganden": "bekrigande",
    "bekrigandena": "bekrigande",
    "bekrigandenas": "bekrigande",
    "bekrigandens": "bekrigande",
    "bekrigandes": "bekrigande",
    "bekrigandet": "bekrigande",
    "bekrigandets": "bekrigande",
    "bekrigar": "bekriga",
    "bekrigas": "bekriga",
    "bekrigat": "bekriga",
    "bekrigats": "bekriga",
    "bekräft": "bekräfta",
    "bekräftad": "bekräfta",
    "bekräftade": "bekräfta",
    "bekräftades": "bekräfta",
    "bekräftads": "bekräfta",
    "bekräftande": "bekräfta",
    "bekräftanden": "bekräftande",
    "bekräftandena": "bekräftande",
    "bekräftandenas": "bekräftande",
    "bekräftandens": "bekräftande",
    "bekräftandes": "bekräftande",
    "bekräftandet": "bekräftande",
    "bekräftandets": "bekräftande",
    "bekräftar": "bekräfta",
    "bekräftas": "bekräfta",
    "bekräftat": "bekräfta",
    "bekräftats": "bekräfta",
    "bekräftelsen": "bekräftelse",
    "bekräftelsens": "bekräftelse",
    "bekräftelser": "bekräftelse",
    "bekräftelserna": "bekräftelse",
    "bekräftelsernas": "bekräftelse",
    "bekräftelsers": "bekräftelse",
    "bekräftelses": "bekräftelse",
    "bekrön": "bekröna",
    "bekrönande": "bekröna",
    "bekrönanden": "bekrönande",
    "bekrönandena": "bekrönande",
    "bekrönandenas": "bekrönande",
    "bekrönandens": "bekrönande",
    "bekrönandes": "bekrönande",
    "bekrönandet": "bekrönande",
    "bekrönandets": "bekrönande",
    "bekrönas": "bekröna",
    "bekröner": "bekröna",
    "bekrönes": "bekröna",
    "bekröningar": "bekröning",
    "bekröningarna": "bekröning",
    "bekröningarnas": "bekröning",
    "bekröningars": "bekröning",
    "bekröningen": "bekröning",
    "bekröningens": "bekröning",
    "bekrönings": "bekröning",
    "bekröns": "bekröna",
    "bekrönt": "bekröna",
    "bekrönta": "bekröna",
    "bekröntas": "bekröna",
    "bekrönte": "bekröna",
    "bekröntes": "bekröna",
    "bekrönts": "bekröna",
    "bekväma": "bekväm",
    "bekvämare": "bekväm",
    "bekvämares": "bekväm",
    "bekvämas": "bekväm",
    "bekvämast": "bekväm",
    "bekvämaste": "bekväm",
    "bekvämastes": "bekväm",
    "bekvämasts": "bekväm",
    "bekväme": "bekväm",
    "bekvämes": "bekväm",
    "bekvämheten": "bekvämhet",
    "bekvämhetens": "bekvämhet",
    "bekvämhets": "bekvämhet",
    "bekvämligheten": "bekvämlighet",
    "bekvämlighetens": "bekvämlighet",
    "bekvämligheter": "bekvämlighet",
    "bekvämligheterna": "bekvämlighet",
    "bekvämligheternas": "bekvämlighet",
    "bekvämligheters": "bekvämlighet",
    "bekvämlighets": "bekvämlighet",
    "bekvämlighetsflaggen": "bekvämlighetsflagg",
    "bekvämlighetsflaggens": "bekvämlighetsflagg",
    "bekvämlighetsflaggs": "bekvämlighetsflagg",
    "bekvämlighetsinrättningar": "bekvämlighetsinrättning",
    "bekvämlighetsinrättningarna": "bekvämlighetsinrättning",
    "bekvämlighetsinrättningarnas": "bekvämlighetsinrättning",
    "bekvämlighetsinrättningars": "bekvämlighetsinrättning",
    "bekvämlighetsinrättningen": "bekvämlighetsinrättning",
    "bekvämlighetsinrättningens": "bekvämlighetsinrättning",
    "bekvämlighetsinrättnings": "bekvämlighetsinrättning",
    "bekväms": "bekväm",
    "bekvämt": "bekväm",
    "bekvämts": "bekväm",
    "bekymmerfria": "bekymmerfri",
    "bekymmerfriare": "bekymmerfri",
    "bekymmerfriares": "bekymmerfri",
    "bekymmerfrias": "bekymmerfri",
    "bekymmerfriast": "bekymmerfri",
    "bekymmerfriaste": "bekymmerfri",
    "bekymmerfriastes": "bekymmerfri",
    "bekymmerfriasts": "bekymmerfri",
    "bekymmerfrie": "bekymmerfri",
    "bekymmerfries": "bekymmerfri",
    "bekymmerfris": "bekymmerfri",
    "bekymmerfritt": "bekymmerfri",
    "bekymmerfritts": "bekymmerfri",
    "bekymmerna": "bekymmer",
    "bekymmernas": "bekymmer",
    "bekymmers": "bekymmer",
    "bekymmersamheten": "bekymmersamhet",
    "bekymmersamhetens": "bekymmersamhet",
    "bekymmersamhets": "bekymmersamhet",
    "bekymmersamma": "bekymmersam",
    "bekymmersammare": "bekymmersam",
    "bekymmersammares": "bekymmersam",
    "bekymmersammas": "bekymmersam",
    "bekymmersammast": "bekymmersam",
    "bekymmersammaste": "bekymmersam",
    "bekymmersammastes": "bekymmersam",
    "bekymmersammasts": "bekymmersam",
    "bekymmersamme": "bekymmersam",
    "bekymmersammes": "bekymmersam",
    "bekymmersams": "bekymmersam",
    "bekymmersamt": "bekymmersam",
    "bekymmersamts": "bekymmersam",
    "bekymmersfria": "bekymmersfri",
    "bekymmersfriare": "bekymmersfri",
    "bekymmersfriares": "bekymmersfri",
    "bekymmersfrias": "bekymmersfri",
    "bekymmersfriast": "bekymmersfri",
    "bekymmersfriaste": "bekymmersfri",
    "bekymmersfriastes": "bekymmersfri",
    "bekymmersfriasts": "bekymmersfri",
    "bekymmersfrie": "bekymmersfri",
    "bekymmersfries": "bekymmersfri",
    "bekymmersfris": "bekymmersfri",
    "bekymmersfritt": "bekymmersfri",
    "bekymmersfritts": "bekymmersfri",
    "bekymmerslösa": "bekymmerslös",
    "bekymmerslösare": "bekymmerslös",
    "bekymmerslösares": "bekymmerslös",
    "bekymmerslösas": "bekymmerslös",
    "bekymmerslösast": "bekymmerslös",
    "bekymmerslösaste": "bekymmerslös",
    "bekymmerslösastes": "bekymmerslös",
    "bekymmerslösasts": "bekymmerslös",
    "bekymmerslöse": "bekymmerslös",
    "bekymmerslöses": "bekymmerslös",
    "bekymmerslösheten": "bekymmerslöshet",
    "bekymmerslöshetens": "bekymmerslöshet",
    "bekymmerslöshets": "bekymmerslöshet",
    "bekymmerslöst": "bekymmerslös",
    "bekymmerslösts": "bekymmerslös",
    "bekymmersrynk": "bekymmersrynka",
    "bekymmersrynkan": "bekymmersrynka",
    "bekymmersrynkans": "bekymmersrynka",
    "bekymmersrynkas": "bekymmersrynka",
    "bekymmersrynke": "bekymmersrynka",
    "bekymmersrynkor": "bekymmersrynka",
    "bekymmersrynkorna": "bekymmersrynka",
    "bekymmersrynkornas": "bekymmersrynka",
    "bekymmersrynkors": "bekymmersrynka",
    "bekymmersrynks": "bekymmersrynka",
    "bekymrad": "bekymra",
    "bekymrade": "bekymrad",
    "bekymrades": "bekymrad",
    "bekymrads": "bekymrad",
    "bekymrande": "bekymra",
    "bekymranden": "bekymrande",
    "bekymrandena": "bekymrande",
    "bekymrandenas": "bekymrande",
    "bekymrandens": "bekymrande",
    "bekymrandes": "bekymrande",
    "bekymrandet": "bekymrande",
    "bekymrandets": "bekymrande",
    "bekymrar": "bekymra",
    "bekymras": "bekymra",
    "bekymrat": "bekymrad",
    "bekymrats": "bekymrad",
    "bekymren": "bekymmer",
    "bekymrens": "bekymmer",
    "bekymret": "bekymmer",
    "bekymrets": "bekymmer",
    "bekyttade": "bekyttad",
    "bekyttades": "bekyttad",
    "bekyttads": "bekyttad",
    "bekyttat": "bekyttad",
    "bekyttats": "bekyttad",
    "bekämp": "bekämpa",
    "bekämpad": "bekämpa",
    "bekämpade": "bekämpa",
    "bekämpades": "bekämpa",
    "bekämpads": "bekämpa",
    "bekämpande": "bekämpa",
    "bekämpanden": "bekämpande",
    "bekämpandena": "bekämpande",
    "bekämpandenas": "bekämpande",
    "bekämpandens": "bekämpande",
    "bekämpandes": "bekämpande",
    "bekämpandet": "bekämpande",
    "bekämpandets": "bekämpande",
    "bekämpar": "bekämpa",
    "bekämpas": "bekämpa",
    "bekämpat": "bekämpa",
    "bekämpats": "bekämpa",
    "bekämpningar": "bekämpning",
    "bekämpningarna": "bekämpning",
    "bekämpningarnas": "bekämpning",
    "bekämpningars": "bekämpning",
    "bekämpningen": "bekämpning",
    "bekämpningens": "bekämpning",
    "bekämpnings": "bekämpning",
    "bekämpningsmedels": "bekämpningsmedel",
    "bekämpningsmedlen": "bekämpningsmedel",
    "bekämpningsmedlens": "bekämpningsmedel",
    "bekämpningsmedlet": "bekämpningsmedel",
    "bekämpningsmedlets": "bekämpningsmedel",
    "bekänd": "bekänna",
    "bekända": "bekänna",
    "bekändas": "bekänna",
    "bekände": "bekänna",
    "bekändes": "bekänna",
    "bekänds": "bekänna",
    "bekänn": "bekänna",
    "bekännande": "bekänna",
    "bekännanden": "bekännande",
    "bekännandena": "bekännande",
    "bekännandenas": "bekännande",
    "bekännandens": "bekännande",
    "bekännandes": "bekännande",
    "bekännandet": "bekännande",
    "bekännandets": "bekännande",
    "bekännar": "bekännare",
    "bekännaren": "bekännare",
    "bekännarens": "bekännare",
    "bekännares": "bekännare",
    "bekännarna": "bekännare",
    "bekännarnas": "bekännare",
    "bekännas": "bekänna",
    "bekännelsefriheten": "bekännelsefrihet",
    "bekännelsefrihetens": "bekännelsefrihet",
    "bekännelsefriheter": "bekännelsefrihet",
    "bekännelsefriheterna": "bekännelsefrihet",
    "bekännelsefriheternas": "bekännelsefrihet",
    "bekännelsefriheters": "bekännelsefrihet",
    "bekännelsefrihets": "bekännelsefrihet",
    "bekännelsen": "bekännelse",
    "bekännelsens": "bekännelse",
    "bekännelser": "bekännelse",
    "bekännelserna": "bekännelse",
    "bekännelsernas": "bekännelse",
    "bekännelseromanen": "bekännelseroman",
    "bekännelseromanens": "bekännelseroman",
    "bekännelseromaner": "bekännelseroman",
    "bekännelseromanerna": "bekännelseroman",
    "bekännelseromanernas": "bekännelseroman",
    "bekännelseromaners": "bekännelseroman",
    "bekännelseromans": "bekännelseroman",
    "bekännelsers": "bekännelse",
    "bekännelses": "bekännelse",
    "bekännelseskriften": "bekännelseskrift",
    "bekännelseskriftens": "bekännelseskrift",
    "bekännelseskrifter": "bekännelseskrift",
    "bekännelseskrifterna": "bekännelseskrift",
    "bekännelseskrifternas": "bekännelseskrift",
    "bekännelseskrifters": "bekännelseskrift",
    "bekännelseskrifts": "bekännelseskrift",
    "bekänner": "bekänna",
    "bekännes": "bekänna",
    "bekänns": "bekänna",
    "bekänt": "bekänna",
    "bekänts": "bekänna",
    "bela": "belägga",
    "belackar": "belackare",
    "belackaren": "belackare",
    "belackarens": "belackare",
    "belackares": "belackare",
    "belackarna": "belackare",
    "belackarnas": "belackare",
    "belade": "belägga",
    "belades": "belägga",
    "belagd": "belägga",
    "belagda": "belägga",
    "belagdas": "belägga",
    "belagde": "belägga",
    "belagdes": "belägga",
    "belagds": "belägga",
    "belagen": "belag",
    "belagens": "belag",
    "belaget": "belag",
    "belagets": "belag",
    "belags": "belag",
    "belagt": "belägga",
    "belagts": "belägga",
    "belamrad": "belamra",
    "belamrade": "belamra",
    "belamrades": "belamra",
    "belamrads": "belamra",
    "belamrande": "belamra",
    "belamranden": "belamrande",
    "belamrandena": "belamrande",
    "belamrandenas": "belamrande",
    "belamrandens": "belamrande",
    "belamrandes": "belamrande",
    "belamrandet": "belamrande",
    "belamrandets": "belamrande",
    "belamrar": "belamra",
    "belamras": "belamra",
    "belamrat": "belamra",
    "belamrats": "belamra",
    "belangade": "belanga",
    "belangades": "belanga",
    "belangande": "belanga",
    "belanganden": "belangande",
    "belangandena": "belangande",
    "belangandenas": "belangande",
    "belangandens": "belangande",
    "belangandes": "belangande",
    "belangandet": "belangande",
    "belangandets": "belangande",
    "belangar": "belanga",
    "belangas": "belanga",
    "belangat": "belanga",
    "belangats": "belanga",
    "belas": "belägga",
    "belast": "belasta",
    "belastad": "belasta",
    "belastade": "belasta",
    "belastades": "belasta",
    "belastads": "belasta",
    "belastande": "belasta",
    "belastanden": "belastande",
    "belastandena": "belastande",
    "belastandenas": "belastande",
    "belastandens": "belastande",
    "belastandes": "belastande",
    "belastandet": "belastande",
    "belastandets": "belastande",
    "belastar": "belasta",
    "belastas": "belasta",
    "belastat": "belasta",
    "belastats": "belasta",
    "belastningar": "belastning",
    "belastningarna": "belastning",
    "belastningarnas": "belastning",
    "belastningars": "belastning",
    "belastningen": "belastning",
    "belastningens": "belastning",
    "belastnings": "belastning",
    "belastningsskadan": "belastningsskada",
    "belastningsskadans": "belastningsskada",
    "belastningsskadas": "belastningsskada",
    "belastningsskade": "belastningsskada",
    "belastningsskador": "belastningsskada",
    "belastningsskadorna": "belastningsskada",
    "belastningsskadornas": "belastningsskada",
    "belastningsskadors": "belastningsskada",
    "belcantos": "belcanto",
    "beledsag": "beledsaga",
    "beledsagad": "beledsaga",
    "beledsagade": "beledsaga",
    "beledsagades": "beledsaga",
    "beledsagads": "beledsaga",
    "beledsagande": "beledsaga",
    "beledsaganden": "beledsagande",
    "beledsagandena": "beledsagande",
    "beledsagandenas": "beledsagande",
    "beledsagandens": "beledsagande",
    "beledsagandes": "beledsagande",
    "beledsagandet": "beledsagande",
    "beledsagandets": "beledsagande",
    "beledsagar": "beledsaga",
    "beledsagas": "beledsaga",
    "beledsagat": "beledsaga",
    "beledsagats": "beledsaga",
    "beleende": "bele",
    "beleenden": "beleende",
    "beleendena": "beleende",
    "beleendenas": "beleende",
    "beleendens": "beleende",
    "beleendes": "beleende",
    "beleendet": "beleende",
    "beleendets": "beleende",
    "belemniten": "belemnit",
    "belemnitens": "belemnit",
    "belemniter": "belemnit",
    "belemniterna": "belemnit",
    "belemniternas": "belemnit",
    "belemniters": "belemnit",
    "belemnits": "belemnit",
    "beler": "bele",
    "beles": "bele",
    "belett": "bele",
    "beletts": "bele",
    "belevade": "belevad",
    "belevades": "belevad",
    "belevads": "belevad",
    "belevat": "belevad",
    "belevats": "belevad",
    "belevenheten": "belevenhet",
    "belevenhetens": "belevenhet",
    "belevenheter": "belevenhet",
    "belevenheterna": "belevenhet",
    "belevenheternas": "belevenhet",
    "belevenheters": "belevenhet",
    "belevenhets": "belevenhet",
    "belgar": "belgare",
    "belgaren": "belgare",
    "belgarens": "belgare",
    "belgares": "belgare",
    "belgarna": "belgare",
    "belgarnas": "belgare",
    "belgiern": "belgier",
    "belgierna": "belgier",
    "belgiernas": "belgier",
    "belgierns": "belgier",
    "belgiers": "belgier",
    "belgiska": "belgisk",
    "belgiskan": "belgiska",
    "belgiskans": "belgiska",
    "belgiskare": "belgisk",
    "belgiskares": "belgisk",
    "belgiskas": "belgiska",
    "belgiskast": "belgisk",
    "belgiskaste": "belgisk",
    "belgiskastes": "belgisk",
    "belgiskasts": "belgisk",
    "belgiske": "belgiska",
    "belgiskes": "belgisk",
    "belgiskor": "belgiska",
    "belgiskorna": "belgiska",
    "belgiskornas": "belgiska",
    "belgiskors": "belgiska",
    "belgisks": "belgisk",
    "belgiskt": "belgisk",
    "belgiskts": "belgisk",
    "beliziern": "belizier",
    "belizierna": "belizier",
    "beliziernas": "belizier",
    "belizierns": "belizier",
    "beliziers": "belizier",
    "beliziska": "belizisk",
    "beliziskan": "beliziska",
    "beliziskans": "beliziska",
    "beliziskare": "belizisk",
    "beliziskares": "belizisk",
    "beliziskas": "beliziska",
    "beliziskast": "belizisk",
    "beliziskaste": "belizisk",
    "beliziskastes": "belizisk",
    "beliziskasts": "belizisk",
    "beliziske": "beliziska",
    "beliziskes": "belizisk",
    "beliziskor": "beliziska",
    "beliziskorna": "beliziska",
    "beliziskornas": "beliziska",
    "beliziskors": "beliziska",
    "belizisks": "belizisk",
    "beliziskt": "belizisk",
    "beliziskts": "belizisk",
    "beljug": "beljuga",
    "beljugande": "beljuga",
    "beljuganden": "beljugande",
    "beljugandena": "beljugande",
    "beljugandenas": "beljugande",
    "beljugandens": "beljugande",
    "beljugandes": "beljugande",
    "beljugandet": "beljugande",
    "beljugandets": "beljugande",
    "beljugas": "beljuga",
    "beljuge": "beljuga",
    "beljugen": "beljuga",
    "beljugens": "beljuga",
    "beljuger": "beljuga",
    "beljuges": "beljuga",
    "beljuget": "beljuga",
    "beljugets": "beljuga",
    "beljugit": "beljuga",
    "beljugits": "beljuga",
    "beljugna": "beljuga",
    "beljugnas": "beljuga",
    "beljugne": "beljuga",
    "beljugnes": "beljuga",
    "beljugs": "beljuga",
    "beljög": "beljuga",
    "beljöge": "beljuga",
    "beljöges": "beljuga",
    "beljögs": "beljuga",
    "belladonnan": "belladonna",
    "belladonnans": "belladonna",
    "belladonnas": "belladonna",
    "belletristen": "belletrist",
    "belletristens": "belletrist",
    "belletrister": "belletrist",
    "belletristerna": "belletrist",
    "belletristernas": "belletrist",
    "belletristers": "belletrist",
    "belletristiska": "belletristisk",
    "belletristiskare": "belletristisk",
    "belletristiskares": "belletristisk",
    "belletristiskas": "belletristisk",
    "belletristiskast": "belletristisk",
    "belletristiskaste": "belletristisk",
    "belletristiskastes": "belletristisk",
    "belletristiskasts": "belletristisk",
    "belletristiske": "belletristisk",
    "belletristiskes": "belletristisk",
    "belletristisks": "belletristisk",
    "belletristiskt": "belletristisk",
    "belletristiskts": "belletristisk",
    "belletrists": "belletrist",
    "bellisar": "bellis",
    "bellisarna": "bellis",
    "bellisarnas": "bellis",
    "bellisars": "bellis",
    "bellisen": "bellis",
    "bellisens": "bellis",
    "belliten": "bellit",
    "bellitens": "bellit",
    "bellits": "bellit",
    "belog": "bele",
    "beloge": "bele",
    "beloges": "bele",
    "belogs": "bele",
    "beloppen": "belopp",
    "beloppens": "belopp",
    "beloppet": "belopp",
    "beloppets": "belopp",
    "belopps": "belopp",
    "belys": "belysa",
    "belysande": "belysa",
    "belysanden": "belysande",
    "belysandena": "belysande",
    "belysandenas": "belysande",
    "belysandens": "belysande",
    "belysandes": "belysande",
    "belysandet": "belysande",
    "belysandets": "belysande",
    "belysas": "belysa",
    "belyser": "belysa",
    "belyses": "belysa",
    "belysningar": "belysning",
    "belysningarna": "belysning",
    "belysningarnas": "belysning",
    "belysningars": "belysning",
    "belysningen": "belysning",
    "belysningens": "belysning",
    "belysnings": "belysning",
    "belysningsarmaturen": "belysningsarmatur",
    "belysningsarmaturens": "belysningsarmatur",
    "belysningsarmaturer": "belysningsarmatur",
    "belysningsarmaturerna": "belysningsarmatur",
    "belysningsarmaturernas": "belysningsarmatur",
    "belysningsarmaturers": "belysningsarmatur",
    "belysningsarmaturs": "belysningsarmatur",
    "belysningsmäss": "belysningsmässa",
    "belysningsmässan": "belysningsmässa",
    "belysningsmässans": "belysningsmässa",
    "belysningsmässas": "belysningsmässa",
    "belysningsmässe": "belysningsmässa",
    "belysningsmässor": "belysningsmässa",
    "belysningsmässorna": "belysningsmässa",
    "belysningsmässornas": "belysningsmässa",
    "belysningsmässors": "belysningsmässa",
    "belysningsströmmar": "belysningsström",
    "belysningsströmmarna": "belysningsström",
    "belysningsströmmarnas": "belysningsström",
    "belysningsströmmars": "belysningsström",
    "belysningsströmmen": "belysningsström",
    "belysningsströmmens": "belysningsström",
    "belysningsströms": "belysningsström",
    "belysningsstyrkan": "belysningsstyrka",
    "belysningsstyrkans": "belysningsstyrka",
    "belysningsstyrkas": "belysningsstyrka",
    "belysningsstyrke": "belysningsstyrka",
    "belysningsstyrkor": "belysningsstyrka",
    "belysningsstyrkorna": "belysningsstyrka",
    "belysningsstyrkornas": "belysningsstyrka",
    "belysningsstyrkors": "belysningsstyrka",
    "belyst": "belysa",
    "belysta": "belysa",
    "belystas": "belysa",
    "belyste": "belysa",
    "belystes": "belysa",
    "belysts": "belysa",
    "belägenheten": "belägenhet",
    "belägenhetens": "belägenhet",
    "belägenheter": "belägenhet",
    "belägenheterna": "belägenhet",
    "belägenheternas": "belägenhet",
    "belägenheters": "belägenhet",
    "belägenhets": "belägenhet",
    "belägens": "belägen",
    "beläget": "belägen",
    "belägets": "belägen",
    "belägg": "belägga",
    "beläggande": "belägga",
    "belägganden": "beläggande",
    "beläggandena": "beläggande",
    "beläggandenas": "beläggande",
    "beläggandens": "beläggande",
    "beläggandes": "beläggande",
    "beläggandet": "beläggande",
    "beläggandets": "beläggande",
    "beläggas": "belägga",
    "beläggen": "belägg",
    "beläggens": "belägg",
    "belägger": "belägga",
    "belägges": "belägga",
    "belägget": "belägg",
    "beläggets": "belägg",
    "beläggningar": "beläggning",
    "beläggningarna": "beläggning",
    "beläggningarnas": "beläggning",
    "beläggningars": "beläggning",
    "beläggningen": "beläggning",
    "beläggningens": "beläggning",
    "beläggnings": "beläggning",
    "beläggningsringar": "beläggningsring",
    "beläggningsringarna": "beläggningsring",
    "beläggningsringarnas": "beläggningsring",
    "beläggningsringars": "beläggningsring",
    "beläggningsringen": "beläggningsring",
    "beläggningsringens": "beläggningsring",
    "beläggningsrings": "beläggningsring",
    "beläggningssnör": "beläggningssnöre",
    "beläggningssnören": "beläggningssnöre",
    "beläggningssnörena": "beläggningssnöre",
    "beläggningssnörenas": "beläggningssnöre",
    "beläggningssnörens": "beläggningssnöre",
    "beläggningssnöres": "beläggningssnöre",
    "beläggningssnöret": "beläggningssnöre",
    "beläggningssnörets": "beläggningssnöre",
    "beläggningssnörs": "beläggningssnöre",
    "beläggningsstämpeln": "beläggningsstämpel",
    "beläggningsstämpelns": "beläggningsstämpel",
    "beläggningsstämpels": "beläggningsstämpel",
    "beläggningsstämplar": "beläggningsstämpel",
    "beläggningsstämplarna": "beläggningsstämpel",
    "beläggningsstämplarnas": "beläggningsstämpel",
    "beläggningsstämplars": "beläggningsstämpel",
    "beläggs": "belägga",
    "belägna": "belägen",
    "belägnare": "belägen",
    "belägnares": "belägen",
    "belägnas": "belägen",
    "belägnast": "belägen",
    "belägnaste": "belägen",
    "belägnastes": "belägen",
    "belägnasts": "belägen",
    "belägne": "belägen",
    "belägnes": "belägen",
    "belägrad": "belägra",
    "belägrade": "belägra",
    "belägrades": "belägra",
    "belägrads": "belägra",
    "belägrande": "belägra",
    "belägranden": "belägrande",
    "belägrandena": "belägrande",
    "belägrandenas": "belägrande",
    "belägrandens": "belägrande",
    "belägrandes": "belägrande",
    "belägrandet": "belägrande",
    "belägrandets": "belägrande",
    "belägrar": "belägra",
    "belägras": "belägra",
    "belägrat": "belägra",
    "belägrats": "belägra",
    "belägringar": "belägring",
    "belägringarna": "belägring",
    "belägringarnas": "belägring",
    "belägringars": "belägring",
    "belägringen": "belägring",
    "belägringens": "belägring",
    "belägrings": "belägring",
    "belägringsartilleriet": "belägringsartilleri",
    "belägringsartilleriets": "belägringsartilleri",
    "belägringsartilleris": "belägringsartilleri",
    "belägringsartillerit": "belägringsartilleri",
    "belägringsartillerits": "belägringsartilleri",
    "belägringstillstånden": "belägringstillstånd",
    "belägringstillståndens": "belägringstillstånd",
    "belägringstillståndet": "belägringstillstånd",
    "belägringstillståndets": "belägringstillstånd",
    "belägringstillstånds": "belägringstillstånd",
    "belägringstornen": "belägringstorn",
    "belägringstornens": "belägringstorn",
    "belägringstornet": "belägringstorn",
    "belägringstornets": "belägringstorn",
    "belägringstorns": "belägringstorn",
    "beläsenheten": "beläsenhet",
    "beläsenhetens": "beläsenhet",
    "beläsenheter": "beläsenhet",
    "beläsenheterna": "beläsenhet",
    "beläsenheternas": "beläsenhet",
    "beläsenheters": "beläsenhet",
    "beläsenhets": "beläsenhet",
    "belästa": "beläst",
    "belästare": "beläst",
    "belästares": "beläst",
    "belästas": "beläst",
    "belästast": "beläst",
    "belästaste": "beläst",
    "belästastes": "beläst",
    "belästasts": "beläst",
    "beläste": "beläst",
    "belästes": "beläst",
    "belästheten": "belästhet",
    "belästhetens": "belästhet",
    "belästheter": "belästhet",
    "belästheterna": "belästhet",
    "belästheternas": "belästhet",
    "belästheters": "belästhet",
    "belästhets": "belästhet",
    "belästs": "beläst",
    "beläten": "beläte",
    "belätena": "beläte",
    "belätenas": "beläte",
    "belätens": "beläte",
    "belätes": "beläte",
    "belätet": "beläte",
    "belätets": "beläte",
    "beläts": "beläte",
    "belån": "belåna",
    "belånad": "belåna",
    "belånade": "belåna",
    "belånades": "belåna",
    "belånads": "belåna",
    "belånande": "belåna",
    "belånanden": "belånande",
    "belånandena": "belånande",
    "belånandenas": "belånande",
    "belånandens": "belånande",
    "belånandes": "belånande",
    "belånandet": "belånande",
    "belånandets": "belånande",
    "belånar": "belåna",
    "belånas": "belåna",
    "belånat": "belåna",
    "belånats": "belåna",
    "belåningar": "belåning",
    "belåningarna": "belåning",
    "belåningarnas": "belåning",
    "belåningars": "belåning",
    "belåningen": "belåning",
    "belåningens": "belåning",
    "belånings": "belåning",
    "belåningsgraden": "belåningsgrad",
    "belåningsgradens": "belåningsgrad",
    "belåningsgrader": "belåningsgrad",
    "belåningsgraderna": "belåningsgrad",
    "belåningsgradernas": "belåningsgrad",
    "belåningsgraders": "belåningsgrad",
    "belåningsgrads": "belåningsgrad",
    "belåtenheten": "belåtenhet",
    "belåtenhetens": "belåtenhet",
    "belåtenheter": "belåtenhet",
    "belåtenheterna": "belåtenhet",
    "belåtenheternas": "belåtenhet",
    "belåtenheters": "belåtenhet",
    "belåtenhets": "belåtenhet",
    "belåtens": "belåten",
    "belåtet": "belåten",
    "belåtets": "belåten",
    "belåtna": "belåten",
    "belåtnare": "belåten",
    "belåtnares": "belåten",
    "belåtnas": "belåten",
    "belåtnast": "belåten",
    "belåtnaste": "belåten",
    "belåtnastes": "belåten",
    "belåtnasts": "belåten",
    "belåtne": "belåten",
    "belåtnes": "belåten",
    "belön": "belöna",
    "belönad": "belöna",
    "belönade": "belöna",
    "belönades": "belöna",
    "belönads": "belöna",
    "belönande": "belöna",
    "belönanden": "belönande",
    "belönandena": "belönande",
    "belönandenas": "belönande",
    "belönandens": "belönande",
    "belönandes": "belönande",
    "belönandet": "belönande",
    "belönandets": "belönande",
    "belönar": "belöna",
    "belönas": "belöna",
    "belönat": "belöna",
    "belönats": "belöna",
    "belöningar": "belöning",
    "belöningarna": "belöning",
    "belöningarnas": "belöning",
    "belöningars": "belöning",
    "belöningen": "belöning",
    "belöningens": "belöning",
    "belönings": "belöning",
    "belöningssystemen": "belöningssystem",
    "belöningssystemens": "belöningssystem",
    "belöningssystemet": "belöningssystem",
    "belöningssystemets": "belöningssystem",
    "belöningssystems": "belöningssystem",
    "bemann": "bemanna",
    "bemannad": "bemanna",
    "bemannade": "bemannad",
    "bemannades": "bemannad",
    "bemannads": "bemannad",
    "bemannande": "bemanna",
    "bemannanden": "bemannande",
    "bemannandena": "bemannande",
    "bemannandenas": "bemannande",
    "bemannandens": "bemannande",
    "bemannandes": "bemannande",
    "bemannandet": "bemannande",
    "bemannandets": "bemannande",
    "bemannar": "bemanna",
    "bemannas": "bemanna",
    "bemannat": "bemannad",
    "bemannats": "bemannad",
    "bemanningar": "bemanning",
    "bemanningarna": "bemanning",
    "bemanningarnas": "bemanning",
    "bemanningars": "bemanning",
    "bemanningen": "bemanning",
    "bemanningens": "bemanning",
    "bemannings": "bemanning",
    "bemanningsföretagen": "bemanningsföretag",
    "bemanningsföretagens": "bemanningsföretag",
    "bemanningsföretaget": "bemanningsföretag",
    "bemanningsföretagets": "bemanningsföretag",
    "bemanningsföretags": "bemanningsföretag",
    "bemantlad": "bemantla",
    "bemantlade": "bemantla",
    "bemantlades": "bemantla",
    "bemantlads": "bemantla",
    "bemantlande": "bemantla",
    "bemantlanden": "bemantlande",
    "bemantlandena": "bemantlande",
    "bemantlandenas": "bemantlande",
    "bemantlandens": "bemantlande",
    "bemantlandes": "bemantlande",
    "bemantlandet": "bemantlande",
    "bemantlandets": "bemantlande",
    "bemantlar": "bemantla",
    "bemantlas": "bemantla",
    "bemantlat": "bemantla",
    "bemantlats": "bemantla",
    "bemedlad": "bemedla",
    "bemedlade": "bemedlad",
    "bemedlades": "bemedlad",
    "bemedlads": "bemedlad",
    "bemedlande": "bemedla",
    "bemedlanden": "bemedlande",
    "bemedlandena": "bemedlande",
    "bemedlandenas": "bemedlande",
    "bemedlandens": "bemedlande",
    "bemedlandes": "bemedlande",
    "bemedlandet": "bemedlande",
    "bemedlandets": "bemedlande",
    "bemedlar": "bemedla",
    "bemedlas": "bemedla",
    "bemedlat": "bemedlad",
    "bemedlats": "bemedlad",
    "bemyndig": "bemyndiga",
    "bemyndigad": "bemyndiga",
    "bemyndigade": "bemyndiga",
    "bemyndigades": "bemyndiga",
    "bemyndigads": "bemyndiga",
    "bemyndigande": "bemyndiga",
    "bemyndiganden": "bemyndigande",
    "bemyndigandena": "bemyndigande",
    "bemyndigandenas": "bemyndigande",
    "bemyndigandens": "bemyndigande",
    "bemyndigandes": "bemyndigande",
    "bemyndigandet": "bemyndigande",
    "bemyndigandets": "bemyndigande",
    "bemyndigar": "bemyndiga",
    "bemyndigas": "bemyndiga",
    "bemyndigat": "bemyndiga",
    "bemyndigats": "bemyndiga",
    "bemäng": "bemänga",
    "bemängande": "bemänga",
    "bemänganden": "bemängande",
    "bemängandena": "bemängande",
    "bemängandenas": "bemängande",
    "bemängandens": "bemängande",
    "bemängandes": "bemängande",
    "bemängandet": "bemängande",
    "bemängandets": "bemängande",
    "bemängas": "bemänga",
    "bemängd": "bemänga",
    "bemängda": "bemänga",
    "bemängdas": "bemänga",
    "bemängde": "bemänga",
    "bemängdes": "bemänga",
    "bemängds": "bemänga",
    "bemänger": "bemänga",
    "bemänges": "bemänga",
    "bemängs": "bemänga",
    "bemängt": "bemänga",
    "bemängts": "bemänga",
    "bemärk": "bemärka",
    "bemärkande": "bemärka",
    "bemärkanden": "bemärkande",
    "bemärkandena": "bemärkande",
    "bemärkandenas": "bemärkande",
    "bemärkandens": "bemärkande",
    "bemärkandes": "bemärkande",
    "bemärkandet": "bemärkande",
    "bemärkandets": "bemärkande",
    "bemärkas": "bemärka",
    "bemärkelsedagar": "bemärkelsedag",
    "bemärkelsedagarna": "bemärkelsedag",
    "bemärkelsedagarnas": "bemärkelsedag",
    "bemärkelsedagars": "bemärkelsedag",
    "bemärkelsedagen": "bemärkelsedag",
    "bemärkelsedagens": "bemärkelsedag",
    "bemärkelsedags": "bemärkelsedag",
    "bemärkelsedan": "bemärkelsedag",
    "bemärkelsedans": "bemärkelsedag",
    "bemärkelsedar": "bemärkelsedag",
    "bemärkelsedarna": "bemärkelsedag",
    "bemärkelsedarnas": "bemärkelsedag",
    "bemärkelsedars": "bemärkelsedag",
    "bemärkelsen": "bemärkelse",
    "bemärkelsens": "bemärkelse",
    "bemärkelser": "bemärkelse",
    "bemärkelserna": "bemärkelse",
    "bemärkelsernas": "bemärkelse",
    "bemärkelsers": "bemärkelse",
    "bemärkelses": "bemärkelse",
    "bemärker": "bemärka",
    "bemärkes": "bemärka",
    "bemärks": "bemärka",
    "bemärkt": "bemärka",
    "bemärkta": "bemärkt",
    "bemärktare": "bemärkt",
    "bemärktares": "bemärkt",
    "bemärktas": "bemärkt",
    "bemärktast": "bemärkt",
    "bemärktaste": "bemärkt",
    "bemärktastes": "bemärkt",
    "bemärktasts": "bemärkt",
    "bemärkte": "bemärkt",
    "bemärktes": "bemärkt",
    "bemärktheten": "bemärkthet",
    "bemärkthetens": "bemärkthet",
    "bemärkthets": "bemärkthet",
    "bemärkts": "bemärkt",
    "bemästrad": "bemästra",
    "bemästrade": "bemästra",
    "bemästrades": "bemästra",
    "bemästrads": "bemästra",
    "bemästrande": "bemästra",
    "bemästranden": "bemästrande",
    "bemästrandena": "bemästrande",
    "bemästrandenas": "bemästrande",
    "bemästrandens": "bemästrande",
    "bemästrandes": "bemästrande",
    "bemästrandet": "bemästrande",
    "bemästrandets": "bemästrande",
    "bemästrar": "bemästra",
    "bemästras": "bemästra",
    "bemästrat": "bemästra",
    "bemästrats": "bemästra",
    "bemödanden": "bemödande",
    "bemödandena": "bemödande",
    "bemödandenas": "bemödande",
    "bemödandens": "bemödande",
    "bemödandes": "bemödande",
    "bemödandet": "bemödande",
    "bemödandets": "bemödande",
    "bemöt": "bemöta",
    "bemötande": "bemöta",
    "bemötandes": "bemötande",
    "bemötandet": "bemötande",
    "bemötandets": "bemötande",
    "bemötas": "bemöta",
    "bemöter": "bemöta",
    "bemötes": "bemöta",
    "bemöts": "bemöta",
    "bemött": "bemöta",
    "bemötta": "bemöta",
    "bemöttas": "bemöta",
    "bemötte": "bemöta",
    "bemöttes": "bemöta",
    "bemötts": "bemöta",
    "ben": "bena",
    "benad": "bena",
    "benade": "bena",
    "benades": "bena",
    "benads": "bena",
    "benan": "bena",
    "benande": "bena",
    "benanden": "benande",
    "benandena": "benande",
    "benandenas": "benande",
    "benandens": "benande",
    "benandes": "benande",
    "benandet": "benande",
    "benandets": "benande",
    "benans": "bena",
    "benar": "bena",
    "benas": "bena",
    "benask": "benaska",
    "benaskan": "benaska",
    "benaskans": "benaska",
    "benaskas": "benaska",
    "benat": "bena",
    "benats": "bena",
    "benbildningar": "benbildning",
    "benbildningarna": "benbildning",
    "benbildningarnas": "benbildning",
    "benbildningars": "benbildning",
    "benbildningen": "benbildning",
    "benbildningens": "benbildning",
    "benbildnings": "benbildning",
    "benbrosken": "benbrosk",
    "benbroskens": "benbrosk",
    "benbrosket": "benbrosk",
    "benbroskets": "benbrosk",
    "benbrosks": "benbrosk",
    "benbrotten": "benbrott",
    "benbrottens": "benbrott",
    "benbrottet": "benbrott",
    "benbrottets": "benbrott",
    "benbrotts": "benbrott",
    "bene": "bena",
    "benediktinen": "benediktin",
    "benediktinens": "benediktin",
    "benediktiner": "benediktin",
    "benediktinerklosterna": "benediktinerkloster",
    "benediktinerklosternas": "benediktinerkloster",
    "benediktinerklosters": "benediktinerkloster",
    "benediktinerklostren": "benediktinerkloster",
    "benediktinerklostrens": "benediktinerkloster",
    "benediktinerklostret": "benediktinerkloster",
    "benediktinerklostrets": "benediktinerkloster",
    "benediktinermunkar": "benediktinermunk",
    "benediktinermunkarna": "benediktinermunk",
    "benediktinermunkarnas": "benediktinermunk",
    "benediktinermunkars": "benediktinermunk",
    "benediktinermunken": "benediktinermunk",
    "benediktinermunkens": "benediktinermunk",
    "benediktinermunks": "benediktinermunk",
    "benediktinerna": "benediktin",
    "benediktinernas": "benediktin",
    "benediktinerordens": "benediktinerorden",
    "benediktinerordnar": "benediktinerorden",
    "benediktinerordnarna": "benediktinerorden",
    "benediktinerordnarnas": "benediktinerorden",
    "benediktinerordnars": "benediktinerorden",
    "benediktinerordnen": "benediktinerorden",
    "benediktinerordnens": "benediktinerorden",
    "benediktiners": "benediktin",
    "benediktinklosterna": "benediktinkloster",
    "benediktinklosternas": "benediktinkloster",
    "benediktinklosters": "benediktinkloster",
    "benediktinklostren": "benediktinkloster",
    "benediktinklostrens": "benediktinkloster",
    "benediktinklostret": "benediktinkloster",
    "benediktinklostrets": "benediktinkloster",
    "benediktinordens": "benediktinorden",
    "benediktinordnar": "benediktinorden",
    "benediktinordnarna": "benediktinorden",
    "benediktinordnarnas": "benediktinorden",
    "benediktinordnars": "benediktinorden",
    "benediktinordnen": "benediktinorden",
    "benediktinordnens": "benediktinorden",
    "benediktins": "benediktin",
    "beneficie": "beneficium",
    "beneficier": "beneficium",
    "beneficierna": "beneficium",
    "beneficiernas": "beneficium",
    "beneficiers": "beneficium",
    "beneficiet": "beneficium",
    "beneficiets": "beneficium",
    "beneficiums": "beneficium",
    "benefika": "benefik",
    "benefikare": "benefik",
    "benefikares": "benefik",
    "benefikas": "benefik",
    "benefikast": "benefik",
    "benefikaste": "benefik",
    "benefikastes": "benefik",
    "benefikasts": "benefik",
    "benefike": "benefik",
    "benefikes": "benefik",
    "benefiks": "benefik",
    "benefikt": "benefik",
    "benefikts": "benefik",
    "benen": "ben",
    "benens": "ben",
    "benet": "ben",
    "benets": "ben",
    "benfiskar": "benfisk",
    "benfiskarna": "benfisk",
    "benfiskarnas": "benfisk",
    "benfiskars": "benfisk",
    "benfisken": "benfisk",
    "benfiskens": "benfisk",
    "benfisks": "benfisk",
    "benfragmenten": "benfragment",
    "benfragmentens": "benfragment",
    "benfragmentet": "benfragment",
    "benfragmentets": "benfragment",
    "benfragments": "benfragment",
    "benfria": "benfri",
    "benfriare": "benfri",
    "benfriares": "benfri",
    "benfrias": "benfri",
    "benfriast": "benfri",
    "benfriaste": "benfri",
    "benfriastes": "benfri",
    "benfriasts": "benfri",
    "benfrie": "benfri",
    "benfries": "benfri",
    "benfris": "benfri",
    "benfritt": "benfri",
    "benfritts": "benfri",
    "benfärgade": "benfärgad",
    "benfärgades": "benfärgad",
    "benfärgads": "benfärgad",
    "benfärgat": "benfärgad",
    "benfärgats": "benfärgad",
    "bengaliska": "bengalisk",
    "bengaliskare": "bengalisk",
    "bengaliskares": "bengalisk",
    "bengaliskas": "bengalisk",
    "bengaliskast": "bengalisk",
    "bengaliskaste": "bengalisk",
    "bengaliskastes": "bengalisk",
    "bengaliskasts": "bengalisk",
    "bengaliske": "bengalisk",
    "bengaliskes": "bengalisk",
    "bengalisks": "bengalisk",
    "bengaliskt": "bengalisk",
    "bengaliskts": "bengalisk",
    "bengeten": "benget",
    "bengetens": "benget",
    "bengets": "benget",
    "bengetter": "benget",
    "bengetterna": "benget",
    "bengetternas": "benget",
    "bengetters": "benget",
    "bengädd": "bengädda",
    "bengäddan": "bengädda",
    "bengäddans": "bengädda",
    "bengäddas": "bengädda",
    "bengädde": "bengädda",
    "bengäddor": "bengädda",
    "bengäddorna": "bengädda",
    "bengäddornas": "bengädda",
    "bengäddors": "bengädda",
    "bengädds": "bengädda",
    "benhinnan": "benhinna",
    "benhinnans": "benhinna",
    "benhinnas": "benhinna",
    "benhinne": "benhinna",
    "benhinneinflammationen": "benhinneinflammation",
    "benhinneinflammationens": "benhinneinflammation",
    "benhinneinflammationer": "benhinneinflammation",
    "benhinneinflammationerna": "benhinneinflammation",
    "benhinneinflammationernas": "benhinneinflammation",
    "benhinneinflammationers": "benhinneinflammation",
    "benhinneinflammations": "benhinneinflammation",
    "benhinnor": "benhinna",
    "benhinnorna": "benhinna",
    "benhinnornas": "benhinna",
    "benhinnors": "benhinna",
    "benhårda": "benhård",
    "benhårdare": "benhård",
    "benhårdares": "benhård",
    "benhårdas": "benhård",
    "benhårdast": "benhård",
    "benhårdaste": "benhård",
    "benhårdastes": "benhård",
    "benhårdasts": "benhård",
    "benhårde": "benhård",
    "benhårdes": "benhård",
    "benhårdheten": "benhårdhet",
    "benhårdhetens": "benhårdhet",
    "benhårdhets": "benhårdhet",
    "benhårds": "benhård",
    "benhårt": "benhård",
    "benhårts": "benhård",
    "beniga": "benig",
    "benigare": "benig",
    "benigares": "benig",
    "benigas": "benig",
    "benigast": "benig",
    "benigaste": "benig",
    "benigastes": "benig",
    "benigasts": "benig",
    "benige": "benig",
    "beniges": "benig",
    "benigna": "benign",
    "benignare": "benign",
    "benignares": "benign",
    "benignas": "benign",
    "benignast": "benign",
    "benignaste": "benign",
    "benignastes": "benign",
    "benignasts": "benign",
    "benigne": "benign",
    "benignes": "benign",
    "benigns": "benign",
    "benignt": "benign",
    "benignts": "benign",
    "benigs": "benig",
    "benigt": "benig",
    "benigts": "benig",
    "beniniern": "beninier",
    "beninierna": "beninier",
    "beniniernas": "beninier",
    "beninierns": "beninier",
    "beniniers": "beninier",
    "beninska": "beninsk",
    "beninskan": "beninska",
    "beninskans": "beninska",
    "beninskare": "beninsk",
    "beninskares": "beninsk",
    "beninskas": "beninska",
    "beninskast": "beninsk",
    "beninskaste": "beninsk",
    "beninskastes": "beninsk",
    "beninskasts": "beninsk",
    "beninske": "beninska",
    "beninskes": "beninsk",
    "beninskor": "beninska",
    "beninskorna": "beninska",
    "beninskornas": "beninska",
    "beninskors": "beninska",
    "beninsks": "beninsk",
    "beninskt": "beninsk",
    "beninskts": "beninsk",
    "benjamins": "benjamin",
    "benkläderna": "benkläder",
    "benklädernas": "benkläder",
    "benkläders": "benkläder",
    "benklädes": "benkläder",
    "benkläds": "benkläder",
    "benknot": "benknota",
    "benknotan": "benknota",
    "benknotans": "benknota",
    "benknotas": "benknota",
    "benknote": "benknota",
    "benknotor": "benknota",
    "benknotorna": "benknota",
    "benknotornas": "benknota",
    "benknotors": "benknota",
    "benknots": "benknota",
    "benlingar": "benling",
    "benlingarna": "benling",
    "benlingarnas": "benling",
    "benlingars": "benling",
    "benlingen": "benling",
    "benlingens": "benling",
    "benlings": "benling",
    "benmjölet": "benmjöl",
    "benmjölets": "benmjöl",
    "benmjöls": "benmjöl",
    "benmuskeln": "benmuskel",
    "benmuskelns": "benmuskel",
    "benmuskels": "benmuskel",
    "benmuskler": "benmuskel",
    "benmusklerna": "benmuskel",
    "benmusklernas": "benmuskel",
    "benmusklers": "benmuskel",
    "benmärgen": "benmärg",
    "benmärgens": "benmärg",
    "benmärgs": "benmärg",
    "benor": "bena",
    "benorna": "bena",
    "benornas": "bena",
    "benors": "bena",
    "benpip": "benpipa",
    "benpipan": "benpipa",
    "benpipans": "benpipa",
    "benpipas": "benpipa",
    "benpipe": "benpipa",
    "benpipor": "benpipa",
    "benpiporna": "benpipa",
    "benpipornas": "benpipa",
    "benpipors": "benpipa",
    "benpips": "benpipa",
    "benporsliner": "benporslin",
    "benporslinerna": "benporslin",
    "benporslinernas": "benporslin",
    "benporsliners": "benporslin",
    "benporslinet": "benporslin",
    "benporslinets": "benporslin",
    "benporslins": "benporslin",
    "benprotesen": "benprotes",
    "benprotesens": "benprotes",
    "benproteser": "benprotes",
    "benproteserna": "benprotes",
    "benprotesernas": "benprotes",
    "benprotesers": "benprotes",
    "benrangels": "benrangel",
    "benranglen": "benrangel",
    "benranglens": "benrangel",
    "benranglet": "benrangel",
    "benranglets": "benrangel",
    "benresten": "benrest",
    "benrestens": "benrest",
    "benrester": "benrest",
    "benresterna": "benrest",
    "benresternas": "benrest",
    "benresters": "benrest",
    "benrests": "benrest",
    "benrötan": "benröta",
    "benrötans": "benröta",
    "benrötas": "benröta",
    "benröte": "benröta",
    "bens": "bena",
    "bensenen": "bensen",
    "bensenens": "bensen",
    "bensenet": "bensen",
    "bensenets": "bensen",
    "bensens": "bensen",
    "bensinautomaten": "bensinautomat",
    "bensinautomatens": "bensinautomat",
    "bensinautomater": "bensinautomat",
    "bensinautomaterna": "bensinautomat",
    "bensinautomaternas": "bensinautomat",
    "bensinautomaters": "bensinautomat",
    "bensinautomats": "bensinautomat",
    "bensinbolagen": "bensinbolag",
    "bensinbolagens": "bensinbolag",
    "bensinbolaget": "bensinbolag",
    "bensinbolagets": "bensinbolag",
    "bensinbolags": "bensinbolag",
    "bensinbristen": "bensinbrist",
    "bensinbristens": "bensinbrist",
    "bensinbrists": "bensinbrist",
    "bensindrivens": "bensindriven",
    "bensindrivet": "bensindriven",
    "bensindrivets": "bensindriven",
    "bensindrivna": "bensindriven",
    "bensindrivnare": "bensindriven",
    "bensindrivnares": "bensindriven",
    "bensindrivnas": "bensindriven",
    "bensindrivnast": "bensindriven",
    "bensindrivnaste": "bensindriven",
    "bensindrivnastes": "bensindriven",
    "bensindrivnasts": "bensindriven",
    "bensindrivne": "bensindriven",
    "bensindrivnes": "bensindriven",
    "bensindunkar": "bensindunk",
    "bensindunkarna": "bensindunk",
    "bensindunkarnas": "bensindunk",
    "bensindunkars": "bensindunk",
    "bensindunken": "bensindunk",
    "bensindunkens": "bensindunk",
    "bensindunks": "bensindunk",
    "bensinen": "bensin",
    "bensinens": "bensin",
    "bensinförbrukningar": "bensinförbrukning",
    "bensinförbrukningarna": "bensinförbrukning",
    "bensinförbrukningarnas": "bensinförbrukning",
    "bensinförbrukningars": "bensinförbrukning",
    "bensinförbrukningen": "bensinförbrukning",
    "bensinförbrukningens": "bensinförbrukning",
    "bensinförbruknings": "bensinförbrukning",
    "bensinförsäljningen": "bensinförsäljning",
    "bensinförsäljningens": "bensinförsäljning",
    "bensinförsäljnings": "bensinförsäljning",
    "bensinmackar": "bensinmack",
    "bensinmackarna": "bensinmack",
    "bensinmackarnas": "bensinmack",
    "bensinmackars": "bensinmack",
    "bensinmacken": "bensinmack",
    "bensinmackens": "bensinmack",
    "bensinmacks": "bensinmack",
    "bensinmotorer": "bensinmotor",
    "bensinmotorerna": "bensinmotor",
    "bensinmotorernas": "bensinmotor",
    "bensinmotorers": "bensinmotor",
    "bensinmotorn": "bensinmotor",
    "bensinmotorns": "bensinmotor",
    "bensinmotors": "bensinmotor",
    "bensinprisen": "bensinpris",
    "bensinprisens": "bensinpris",
    "bensinpriser": "bensinpris",
    "bensinpriserna": "bensinpris",
    "bensinprisernas": "bensinpris",
    "bensinprisers": "bensinpris",
    "bensinpriset": "bensinpris",
    "bensinprisets": "bensinpris",
    "bensinpumpar": "bensinpump",
    "bensinpumparna": "bensinpump",
    "bensinpumparnas": "bensinpump",
    "bensinpumpars": "bensinpump",
    "bensinpumpen": "bensinpump",
    "bensinpumpens": "bensinpump",
    "bensinpumps": "bensinpump",
    "bensins": "bensin",
    "bensinskattehöjningar": "bensinskattehöjning",
    "bensinskattehöjningarna": "bensinskattehöjning",
    "bensinskattehöjningarnas": "bensinskattehöjning",
    "bensinskattehöjningars": "bensinskattehöjning",
    "bensinskattehöjningen": "bensinskattehöjning",
    "bensinskattehöjningens": "bensinskattehöjning",
    "bensinskattehöjnings": "bensinskattehöjning",
    "bensinskatten": "bensinskatt",
    "bensinskattens": "bensinskatt",
    "bensinskatter": "bensinskatt",
    "bensinskatterna": "bensinskatt",
    "bensinskatternas": "bensinskatt",
    "bensinskatters": "bensinskatt",
    "bensinskatts": "bensinskatt",
    "bensinsnåla": "bensinsnål",
    "bensinsnålare": "bensinsnål",
    "bensinsnålares": "bensinsnål",
    "bensinsnålas": "bensinsnål",
    "bensinsnålast": "bensinsnål",
    "bensinsnålaste": "bensinsnål",
    "bensinsnålastes": "bensinsnål",
    "bensinsnålasts": "bensinsnål",
    "bensinsnåle": "bensinsnål",
    "bensinsnåles": "bensinsnål",
    "bensinsnålheten": "bensinsnålhet",
    "bensinsnålhetens": "bensinsnålhet",
    "bensinsnålhets": "bensinsnålhet",
    "bensinsnåls": "bensinsnål",
    "bensinsnålt": "bensinsnål",
    "bensinsnålts": "bensinsnål",
    "bensinstationen": "bensinstation",
    "bensinstationens": "bensinstation",
    "bensinstationer": "bensinstation",
    "bensinstationerna": "bensinstation",
    "bensinstationernas": "bensinstation",
    "bensinstationers": "bensinstation",
    "bensinstations": "bensinstation",
    "bensinstoppen": "bensinstopp",
    "bensinstoppens": "bensinstopp",
    "bensinstoppet": "bensinstopp",
    "bensinstoppets": "bensinstopp",
    "bensinstopps": "bensinstopp",
    "bensintankar": "bensintank",
    "bensintankarna": "bensintank",
    "bensintankarnas": "bensintank",
    "bensintankars": "bensintank",
    "bensintanken": "bensintank",
    "bensintankens": "bensintank",
    "bensintanks": "bensintank",
    "bensintillsatsen": "bensintillsats",
    "bensintillsatsens": "bensintillsats",
    "bensintillsatser": "bensintillsats",
    "bensintillsatserna": "bensintillsats",
    "bensintillsatsernas": "bensintillsats",
    "bensintillsatsers": "bensintillsats",
    "benskadan": "benskada",
    "benskadans": "benskada",
    "benskadas": "benskada",
    "benskade": "benskada",
    "benskador": "benskada",
    "benskadorna": "benskada",
    "benskadornas": "benskada",
    "benskadors": "benskada",
    "bensken": "benskena",
    "benskenan": "benskena",
    "benskenans": "benskena",
    "benskenas": "benskena",
    "benskene": "benskena",
    "benskenor": "benskena",
    "benskenorna": "benskena",
    "benskenornas": "benskena",
    "benskenors": "benskena",
    "benskens": "benskena",
    "benskydden": "benskydd",
    "benskyddens": "benskydd",
    "benskyddet": "benskydd",
    "benskyddets": "benskydd",
    "benskydds": "benskydd",
    "bensköra": "benskör",
    "benskörare": "benskör",
    "benskörares": "benskör",
    "bensköras": "benskör",
    "benskörast": "benskör",
    "bensköraste": "benskör",
    "benskörastes": "benskör",
    "benskörasts": "benskör",
    "bensköre": "benskör",
    "bensköres": "benskör",
    "benskörheten": "benskörhet",
    "benskörhetens": "benskörhet",
    "benskörheter": "benskörhet",
    "benskörheterna": "benskörhet",
    "benskörheternas": "benskörhet",
    "benskörheters": "benskörhet",
    "benskörhets": "benskörhet",
    "benskörs": "benskör",
    "benskört": "benskör",
    "benskörts": "benskör",
    "bensoen": "bensoe",
    "bensoens": "bensoe",
    "bensoes": "bensoe",
    "bensoesyran": "bensoesyra",
    "bensoesyrans": "bensoesyra",
    "bensoesyras": "bensoesyra",
    "bensoesyre": "bensoesyra",
    "bensoesyror": "bensoesyra",
    "bensoesyrorna": "bensoesyra",
    "bensoesyrornas": "bensoesyra",
    "bensoesyrors": "bensoesyra",
    "bensolen": "bensol",
    "bensolens": "bensol",
    "bensols": "bensol",
    "benspetsar": "benspets",
    "benspetsarna": "benspets",
    "benspetsarnas": "benspets",
    "benspetsars": "benspets",
    "benspetsen": "benspets",
    "benspetsens": "benspets",
    "benstampar": "benstamp",
    "benstamparna": "benstamp",
    "benstamparnas": "benstamp",
    "benstampars": "benstamp",
    "benstampen": "benstamp",
    "benstampens": "benstamp",
    "benstamps": "benstamp",
    "benstom": "benstomme",
    "benstommar": "benstomme",
    "benstommarna": "benstomme",
    "benstommarnas": "benstomme",
    "benstommars": "benstomme",
    "benstommen": "benstomme",
    "benstommens": "benstomme",
    "benstommes": "benstomme",
    "benstoms": "benstomme",
    "benstrål": "benstråle",
    "benstrålar": "benstråle",
    "benstrålarna": "benstråle",
    "benstrålarnas": "benstråle",
    "benstrålars": "benstråle",
    "benstrålen": "benstråle",
    "benstrålens": "benstråle",
    "benstråles": "benstråle",
    "benstråls": "benstråle",
    "bensubstansen": "bensubstans",
    "bensubstansens": "bensubstans",
    "bensubstanser": "bensubstans",
    "bensubstanserna": "bensubstans",
    "bensubstansernas": "bensubstans",
    "bensubstansers": "bensubstans",
    "bensvulsten": "bensvulst",
    "bensvulstens": "bensvulst",
    "bensvulster": "bensvulst",
    "bensvulsterna": "bensvulst",
    "bensvulsternas": "bensvulst",
    "bensvulsters": "bensvulst",
    "bensvulsts": "bensvulst",
    "bensåren": "bensår",
    "bensårens": "bensår",
    "bensåret": "bensår",
    "bensårets": "bensår",
    "bensårs": "bensår",
    "benta": "bent",
    "bentare": "bent",
    "bentares": "bent",
    "bentas": "bent",
    "bentast": "bent",
    "bentaste": "bent",
    "bentastes": "bent",
    "bentasts": "bent",
    "bente": "bent",
    "bentes": "bent",
    "bentoniten": "bentonit",
    "bentonitens": "bentonit",
    "bentoniter": "bentonit",
    "bentoniterna": "bentonit",
    "bentoniternas": "bentonit",
    "bentoniters": "bentonit",
    "bentonits": "bentonit",
    "bentrakten": "bentrakt",
    "bentraktens": "bentrakt",
    "bentrakter": "bentrakt",
    "bentrakterna": "bentrakt",
    "bentrakternas": "bentrakt",
    "bentrakters": "bentrakt",
    "bentrakts": "bentrakt",
    "bentryn": "bentry",
    "bentryns": "bentry",
    "bentrys": "bentry",
    "bents": "bent",
    "bentuberkulosen": "bentuberkulos",
    "bentuberkulosens": "bentuberkulos",
    "bentylen": "bentyl",
    "bentylens": "bentyl",
    "bentyls": "bentyl",
    "benutskotten": "benutskott",
    "benutskottens": "benutskott",
    "benutskottet": "benutskott",
    "benutskottets": "benutskott",
    "benutskotts": "benutskott",
    "benveden": "benved",
    "benvedens": "benved",
    "benveds": "benved",
    "benvita": "benvit",
    "benvitare": "benvit",
    "benvitares": "benvit",
    "benvitas": "benvit",
    "benvitast": "benvit",
    "benvitaste": "benvit",
    "benvitastes": "benvit",
    "benvitasts": "benvit",
    "benvite": "benvit",
    "benvites": "benvit",
    "benvits": "benvit",
    "benvitt": "benvit",
    "benvitts": "benvit",
    "benvärmares": "benvärmare",
    "benvärmarna": "benvärmare",
    "benvärmarnas": "benvärmare",
    "benvävnaden": "benvävnad",
    "benvävnadens": "benvävnad",
    "benvävnader": "benvävnad",
    "benvävnaderna": "benvävnad",
    "benvävnadernas": "benvävnad",
    "benvävnaders": "benvävnad",
    "benvävnads": "benvävnad",
    "benägenheten": "benägenhet",
    "benägenhetens": "benägenhet",
    "benägenheter": "benägenhet",
    "benägenheterna": "benägenhet",
    "benägenheternas": "benägenhet",
    "benägenheters": "benägenhet",
    "benägenhets": "benägenhet",
    "benägens": "benägen",
    "benäget": "benägen",
    "benägets": "benägen",
    "benägna": "benägen",
    "benägnare": "benägen",
    "benägnares": "benägen",
    "benägnas": "benägen",
    "benägnast": "benägen",
    "benägnaste": "benägen",
    "benägnastes": "benägen",
    "benägnasts": "benägen",
    "benägne": "benägen",
    "benägnes": "benägen",
    "benämn": "benämna",
    "benämnande": "benämna",
    "benämnanden": "benämnande",
    "benämnandena": "benämnande",
    "benämnandenas": "benämnande",
    "benämnandens": "benämnande",
    "benämnandes": "benämnande",
    "benämnandet": "benämnande",
    "benämnandets": "benämnande",
    "benämnas": "benämna",
    "benämnd": "benämna",
    "benämnda": "benämna",
    "benämndas": "benämna",
    "benämnde": "benämna",
    "benämndes": "benämna",
    "benämnds": "benämna",
    "benämner": "benämna",
    "benämnes": "benämna",
    "benämningar": "benämning",
    "benämningarna": "benämning",
    "benämningarnas": "benämning",
    "benämningars": "benämning",
    "benämningen": "benämning",
    "benämningens": "benämning",
    "benämnings": "benämning",
    "benämns": "benämna",
    "benämnt": "benämna",
    "benämnts": "benämna",
    "benåd": "benåda",
    "benådad": "benåda",
    "benådade": "benåda",
    "benådades": "benåda",
    "benådads": "benåda",
    "benådande": "benåda",
    "benådanden": "benådande",
    "benådandena": "benådande",
    "benådandenas": "benådande",
    "benådandens": "benådande",
    "benådandes": "benådande",
    "benådandet": "benådande",
    "benådandets": "benådande",
    "benådar": "benåda",
    "benådas": "benåda",
    "benådat": "benåda",
    "benådats": "benåda",
    "benådningar": "benådning",
    "benådningarna": "benådning",
    "benådningarnas": "benådning",
    "benådningars": "benådning",
    "benådningen": "benådning",
    "benådningens": "benådning",
    "benådnings": "benådning",
    "beor": "bea",
    "beordrad": "beordra",
    "beordrade": "beordra",
    "beordrades": "beordra",
    "beordrads": "beordra",
    "beordrande": "beordra",
    "beordranden": "beordrande",
    "beordrandena": "beordrande",
    "beordrandenas": "beordrande",
    "beordrandens": "beordrande",
    "beordrandes": "beordrande",
    "beordrandet": "beordrande",
    "beordrandets": "beordrande",
    "beordrar": "beordra",
    "beordras": "beordra",
    "beordrat": "beordra",
    "beordrats": "beordra",
    "beorna": "bea",
    "beornas": "bea",
    "beors": "bea",
    "bepansrad": "bepansra",
    "bepansrade": "bepansra",
    "bepansrades": "bepansra",
    "bepansrads": "bepansra",
    "bepansrande": "bepansra",
    "bepansranden": "bepansrande",
    "bepansrandena": "bepansrande",
    "bepansrandenas": "bepansrande",
    "bepansrandens": "bepansrande",
    "bepansrandes": "bepansrande",
    "bepansrandet": "bepansrande",
    "bepansrandets": "bepansrande",
    "bepansrar": "bepansra",
    "bepansras": "bepansra",
    "bepansrat": "bepansra",
    "bepansrats": "bepansra",
    "bepansringar": "bepansring",
    "bepansringarna": "bepansring",
    "bepansringarnas": "bepansring",
    "bepansringars": "bepansring",
    "bepansringen": "bepansring",
    "bepansringens": "bepansring",
    "bepansrings": "bepansring",
    "bepris": "beprisa",
    "beprisad": "beprisa",
    "beprisade": "beprisa",
    "beprisades": "beprisa",
    "beprisads": "beprisa",
    "beprisande": "beprisa",
    "beprisanden": "beprisande",
    "beprisandena": "beprisande",
    "beprisandenas": "beprisande",
    "beprisandens": "beprisande",
    "beprisandes": "beprisande",
    "beprisandet": "beprisande",
    "beprisandets": "beprisande",
    "beprisar": "beprisa",
    "beprisas": "beprisa",
    "beprisat": "beprisa",
    "beprisats": "beprisa",
    "bepryd": "bepryda",
    "beprydande": "bepryda",
    "beprydanden": "beprydande",
    "beprydandena": "beprydande",
    "beprydandenas": "beprydande",
    "beprydandens": "beprydande",
    "beprydandes": "beprydande",
    "beprydandet": "beprydande",
    "beprydandets": "beprydande",
    "beprydas": "bepryda",
    "beprydd": "bepryda",
    "beprydda": "bepryda",
    "bepryddas": "bepryda",
    "beprydde": "bepryda",
    "bepryddes": "bepryda",
    "beprydds": "bepryda",
    "bepryder": "bepryda",
    "beprydes": "bepryda",
    "bepryds": "bepryda",
    "beprytt": "bepryda",
    "beprytts": "bepryda",
    "beprövade": "beprövad",
    "beprövades": "beprövad",
    "beprövads": "beprövad",
    "beprövat": "beprövad",
    "beprövats": "beprövad",
    "bepudrad": "bepudra",
    "bepudrade": "bepudra",
    "bepudrades": "bepudra",
    "bepudrads": "bepudra",
    "bepudrande": "bepudra",
    "bepudranden": "bepudrande",
    "bepudrandena": "bepudrande",
    "bepudrandenas": "bepudrande",
    "bepudrandens": "bepudrande",
    "bepudrandes": "bepudrande",
    "bepudrandet": "bepudrande",
    "bepudrandets": "bepudrande",
    "bepudrar": "bepudra",
    "bepudras": "bepudra",
    "bepudrat": "bepudra",
    "bepudrats": "bepudra",
    "ber": "be",
    "beramade": "beramad",
    "beramades": "beramad",
    "beramads": "beramad",
    "beramat": "beramad",
    "beramats": "beramad",
    "berberisen": "berberis",
    "berberisens": "berberis",
    "berbern": "berber",
    "berberna": "berber",
    "berbernas": "berber",
    "berberns": "berber",
    "berbers": "berber",
    "berceusen": "berceuse",
    "berceusens": "berceuse",
    "berceuser": "berceuse",
    "berceuserna": "berceuse",
    "berceusernas": "berceuse",
    "berceusers": "berceuse",
    "berceuses": "berceuse",
    "bered": "bereda",
    "beredande": "bereda",
    "beredanden": "beredande",
    "beredandena": "beredande",
    "beredandenas": "beredande",
    "beredandens": "beredande",
    "beredandes": "beredande",
    "beredandet": "beredande",
    "beredandets": "beredande",
    "beredar": "beredare",
    "beredaren": "beredare",
    "beredarens": "beredare",
    "beredares": "beredare",
    "beredarna": "beredare",
    "beredarnas": "beredare",
    "beredas": "bereda",
    "beredd": "bereda",
    "beredda": "beredd",
    "bereddare": "beredd",
    "bereddares": "beredd",
    "bereddas": "beredd",
    "bereddast": "beredd",
    "bereddaste": "beredd",
    "bereddastes": "beredd",
    "bereddasts": "beredd",
    "beredde": "beredd",
    "bereddes": "beredd",
    "beredds": "beredd",
    "beredelsen": "beredelse",
    "beredelsens": "beredelse",
    "beredelser": "beredelse",
    "beredelserna": "beredelse",
    "beredelsernas": "beredelse",
    "beredelsers": "beredelse",
    "beredelses": "beredelse",
    "bereder": "bereda",
    "beredes": "bereda",
    "beredningar": "beredning",
    "beredningarna": "beredning",
    "beredningarnas": "beredning",
    "beredningars": "beredning",
    "beredningen": "beredning",
    "beredningens": "beredning",
    "berednings": "beredning",
    "beredningsnämnden": "beredningsnämnd",
    "beredningsnämndens": "beredningsnämnd",
    "beredningsnämnder": "beredningsnämnd",
    "beredningsnämnderna": "beredningsnämnd",
    "beredningsnämndernas": "beredningsnämnd",
    "beredningsnämnders": "beredningsnämnd",
    "beredningsnämnds": "beredningsnämnd",
    "bereds": "bereda",
    "beredskapen": "beredskap",
    "beredskapens": "beredskap",
    "beredskaper": "beredskap",
    "beredskaperna": "beredskap",
    "beredskapernas": "beredskap",
    "beredskapers": "beredskap",
    "beredskaps": "beredskap",
    "beredskapsarbeten": "beredskapsarbete",
    "beredskapsarbetena": "beredskapsarbete",
    "beredskapsarbetenas": "beredskapsarbete",
    "beredskapsarbetens": "beredskapsarbete",
    "beredskapsarbetes": "beredskapsarbete",
    "beredskapsarbetet": "beredskapsarbete",
    "beredskapsarbetets": "beredskapsarbete",
    "beredskapsarbets": "beredskapsarbete",
    "beredskapslagerna": "beredskapslager",
    "beredskapslagernas": "beredskapslager",
    "beredskapslagers": "beredskapslager",
    "beredskapslagren": "beredskapslager",
    "beredskapslagrens": "beredskapslager",
    "beredskapslagret": "beredskapslager",
    "beredskapslagrets": "beredskapslager",
    "beredskapslagringar": "beredskapslagring",
    "beredskapslagringarna": "beredskapslagring",
    "beredskapslagringarnas": "beredskapslagring",
    "beredskapslagringars": "beredskapslagring",
    "beredskapslagringen": "beredskapslagring",
    "beredskapslagringens": "beredskapslagring",
    "beredskapslagrings": "beredskapslagring",
    "beredskapsmässiga": "beredskapsmässig",
    "beredskapsmässigare": "beredskapsmässig",
    "beredskapsmässigares": "beredskapsmässig",
    "beredskapsmässigas": "beredskapsmässig",
    "beredskapsmässigast": "beredskapsmässig",
    "beredskapsmässigaste": "beredskapsmässig",
    "beredskapsmässigastes": "beredskapsmässig",
    "beredskapsmässigasts": "beredskapsmässig",
    "beredskapsmässige": "beredskapsmässig",
    "beredskapsmässiges": "beredskapsmässig",
    "beredskapsmässigs": "beredskapsmässig",
    "beredskapsmässigt": "beredskapsmässig",
    "beredskapsmässigts": "beredskapsmässig",
    "beredskapsplanen": "beredskapsplan",
    "beredskapsplanens": "beredskapsplan",
    "beredskapsplanet": "beredskapsplan",
    "beredskapsplanets": "beredskapsplan",
    "beredskapsplans": "beredskapsplan",
    "beredskapsstaten": "beredskapsstat",
    "beredskapsstatens": "beredskapsstat",
    "beredskapsstater": "beredskapsstat",
    "beredskapsstaterna": "beredskapsstat",
    "beredskapsstaternas": "beredskapsstat",
    "beredskapsstaters": "beredskapsstat",
    "beredskapsstats": "beredskapsstat",
    "beredskapstjänsten": "beredskapstjänst",
    "beredskapstjänstens": "beredskapstjänst",
    "beredskapstjänster": "beredskapstjänst",
    "beredskapstjänsterna": "beredskapstjänst",
    "beredskapstjänsternas": "beredskapstjänst",
    "beredskapstjänsters": "beredskapstjänst",
    "beredskapstjänsts": "beredskapstjänst",
    "beredvilliga": "beredvillig",
    "beredvilligare": "beredvillig",
    "beredvilligares": "beredvillig",
    "beredvilligas": "beredvillig",
    "beredvilligast": "beredvillig",
    "beredvilligaste": "beredvillig",
    "beredvilligastes": "beredvillig",
    "beredvilligasts": "beredvillig",
    "beredvillige": "beredvillig",
    "beredvilliges": "beredvillig",
    "beredvilligheten": "beredvillighet",
    "beredvillighetens": "beredvillighet",
    "beredvilligheter": "beredvillighet",
    "beredvilligheterna": "beredvillighet",
    "beredvilligheternas": "beredvillighet",
    "beredvilligheters": "beredvillighet",
    "beredvillighets": "beredvillighet",
    "beredvilligs": "beredvillig",
    "beredvilligt": "beredvillig",
    "beredvilligts": "beredvillig",
    "beresta": "berest",
    "berestare": "berest",
    "berestares": "berest",
    "berestas": "berest",
    "berestast": "berest",
    "berestaste": "berest",
    "berestastes": "berest",
    "berestasts": "berest",
    "bereste": "berest",
    "berestes": "berest",
    "berestheten": "beresthet",
    "beresthetens": "beresthet",
    "beresthets": "beresthet",
    "berests": "berest",
    "berett": "beredd",
    "beretts": "beredd",
    "berg-och-dalbanan": "berg-och-dalbana",
    "berg-och-dalbanans": "berg-och-dalbana",
    "berg-och-dalbanas": "berg-och-dalbana",
    "berg-och-dalbane": "berg-och-dalbana",
    "berg-och-dalbanor": "berg-och-dalbana",
    "berg-och-dalbanorna": "berg-och-dalbana",
    "berg-och-dalbanornas": "berg-och-dalbana",
    "berg-och-dalbanors": "berg-och-dalbana",
    "bergakungar": "bergakung",
    "bergakungarna": "bergakung",
    "bergakungarnas": "bergakung",
    "bergakungars": "bergakung",
    "bergakungen": "bergakung",
    "bergakungens": "bergakung",
    "bergakungs": "bergakung",
    "bergamotten": "bergamott",
    "bergamottens": "bergamott",
    "bergamotter": "bergamott",
    "bergamotterna": "bergamott",
    "bergamotternas": "bergamott",
    "bergamotters": "bergamott",
    "bergamotts": "bergamott",
    "bergarten": "bergart",
    "bergartens": "bergart",
    "bergarter": "bergart",
    "bergarterna": "bergart",
    "bergarternas": "bergart",
    "bergarters": "bergart",
    "bergarts": "bergart",
    "bergartslagerna": "bergartslager",
    "bergartslagernas": "bergartslager",
    "bergartslagers": "bergartslager",
    "bergartslagren": "bergartslager",
    "bergartslagrens": "bergartslager",
    "bergartslagret": "bergartslager",
    "bergartslagrets": "bergartslager",
    "bergbanan": "bergbana",
    "bergbanans": "bergbana",
    "bergbanas": "bergbana",
    "bergbane": "bergbana",
    "bergbanor": "bergbana",
    "bergbanorna": "bergbana",
    "bergbanornas": "bergbana",
    "bergbanors": "bergbana",
    "bergbestigar": "bergbestigare",
    "bergbestigaren": "bergbestigare",
    "bergbestigarens": "bergbestigare",
    "bergbestigares": "bergbestigare",
    "bergbestigarna": "bergbestigare",
    "bergbestigarnas": "bergbestigare",
    "bergbestigningar": "bergbestigning",
    "bergbestigningarna": "bergbestigning",
    "bergbestigningarnas": "bergbestigning",
    "bergbestigningars": "bergbestigning",
    "bergbestigningen": "bergbestigning",
    "bergbestigningens": "bergbestigning",
    "bergbestignings": "bergbestigning",
    "bergborrar": "bergborr",
    "bergborrarna": "bergborr",
    "bergborrarnas": "bergborr",
    "bergborrars": "bergborr",
    "bergborren": "bergborr",
    "bergborrens": "bergborr",
    "bergborrningar": "bergborrning",
    "bergborrningarna": "bergborrning",
    "bergborrningarnas": "bergborrning",
    "bergborrningars": "bergborrning",
    "bergborrningen": "bergborrning",
    "bergborrningens": "bergborrning",
    "bergborrnings": "bergborrning",
    "bergborrs": "bergborr",
    "bergen": "berg",
    "bergens": "berg",
    "berget": "berg",
    "bergets": "berg",
    "bergfasta": "bergfast",
    "bergfastare": "bergfast",
    "bergfastares": "bergfast",
    "bergfastas": "bergfast",
    "bergfastast": "bergfast",
    "bergfastaste": "bergfast",
    "bergfastastes": "bergfast",
    "bergfastasts": "bergfast",
    "bergfaste": "bergfast",
    "bergfastes": "bergfast",
    "bergfasts": "bergfast",
    "bergfina": "bergfin",
    "bergfinare": "bergfin",
    "bergfinares": "bergfin",
    "bergfinas": "bergfin",
    "bergfinast": "bergfin",
    "bergfinaste": "bergfin",
    "bergfinastes": "bergfin",
    "bergfinasts": "bergfin",
    "bergfine": "bergfin",
    "bergfines": "bergfin",
    "bergfinkar": "bergfink",
    "bergfinkarna": "bergfink",
    "bergfinkarnas": "bergfink",
    "bergfinkars": "bergfink",
    "bergfinken": "bergfink",
    "bergfinkens": "bergfink",
    "bergfinks": "bergfink",
    "bergfins": "bergfin",
    "bergfint": "bergfin",
    "bergfints": "bergfin",
    "berggrunden": "berggrund",
    "berggrundens": "berggrund",
    "berggrunder": "berggrund",
    "berggrunderna": "berggrund",
    "berggrundernas": "berggrund",
    "berggrunders": "berggrund",
    "berggrunds": "berggrund",
    "berggylt": "berggylta",
    "berggyltan": "berggylta",
    "berggyltans": "berggylta",
    "berggyltas": "berggylta",
    "berggylte": "berggylta",
    "berggyltor": "berggylta",
    "berggyltorna": "berggylta",
    "berggyltornas": "berggylta",
    "berggyltors": "berggylta",
    "berggylts": "berggylta",
    "berghällar": "berghäll",
    "berghällarna": "berghäll",
    "berghällarnas": "berghäll",
    "berghällars": "berghäll",
    "berghällen": "berghäll",
    "berghällens": "berghäll",
    "berghälls": "berghäll",
    "bergiga": "bergig",
    "bergigare": "bergig",
    "bergigares": "bergig",
    "bergigas": "bergig",
    "bergigast": "bergig",
    "bergigaste": "bergig",
    "bergigastes": "bergig",
    "bergigasts": "bergig",
    "bergige": "bergig",
    "bergiges": "bergig",
    "bergigheten": "bergighet",
    "bergighetens": "bergighet",
    "bergighets": "bergighet",
    "bergigs": "bergig",
    "bergigt": "bergig",
    "bergigts": "bergig",
    "bergisar": "bergis",
    "bergisarna": "bergis",
    "bergisarnas": "bergis",
    "bergisars": "bergis",
    "bergisen": "bergis",
    "bergisens": "bergis",
    "bergkammar": "bergkam",
    "bergkammarna": "bergkam",
    "bergkammarnas": "bergkam",
    "bergkammars": "bergkam",
    "bergkammen": "bergkam",
    "bergkammens": "bergkam",
    "bergkams": "bergkam",
    "bergklackar": "bergklack",
    "bergklackarna": "bergklack",
    "bergklackarnas": "bergklack",
    "bergklackars": "bergklack",
    "bergklacken": "bergklack",
    "bergklackens": "bergklack",
    "bergklacks": "bergklack",
    "bergknall": "bergknalle",
    "bergknallar": "bergknalle",
    "bergknallarna": "bergknalle",
    "bergknallarnas": "bergknalle",
    "bergknallars": "bergknalle",
    "bergknallen": "bergknalle",
    "bergknallens": "bergknalle",
    "bergknalles": "bergknalle",
    "bergknalls": "bergknalle",
    "bergkristallen": "bergkristall",
    "bergkristallens": "bergkristall",
    "bergkristaller": "bergkristall",
    "bergkristallerna": "bergkristall",
    "bergkristallernas": "bergkristall",
    "bergkristallers": "bergkristall",
    "bergkristalls": "bergkristall",
    "bergkull": "bergkulle",
    "bergkullar": "bergkulle",
    "bergkullarna": "bergkulle",
    "bergkullarnas": "bergkulle",
    "bergkullars": "bergkulle",
    "bergkullen": "bergkulle",
    "bergkullens": "bergkulle",
    "bergkulles": "bergkulle",
    "bergkulls": "bergkulle",
    "berglandet": "bergland",
    "berglandets": "bergland",
    "berglands": "bergland",
    "bergnymfen": "bergnymf",
    "bergnymfens": "bergnymf",
    "bergnymfer": "bergnymf",
    "bergnymferna": "bergnymf",
    "bergnymfernas": "bergnymf",
    "bergnymfers": "bergnymf",
    "bergnymfs": "bergnymf",
    "bergoljan": "bergolja",
    "bergoljans": "bergolja",
    "bergoljas": "bergolja",
    "bergolje": "bergolja",
    "bergoljor": "bergolja",
    "bergoljorna": "bergolja",
    "bergoljornas": "bergolja",
    "bergoljors": "bergolja",
    "bergrummen": "bergrum",
    "bergrummens": "bergrum",
    "bergrummet": "bergrum",
    "bergrummets": "bergrum",
    "bergrums": "bergrum",
    "bergryggar": "bergrygg",
    "bergryggarna": "bergrygg",
    "bergryggarnas": "bergrygg",
    "bergryggars": "bergrygg",
    "bergryggen": "bergrygg",
    "bergryggens": "bergrygg",
    "bergryggs": "bergrygg",
    "bergsartilleriet": "bergsartilleri",
    "bergsartilleriets": "bergsartilleri",
    "bergsartilleris": "bergsartilleri",
    "bergsartillerit": "bergsartilleri",
    "bergsartillerits": "bergsartilleri",
    "bergsbestigar": "bergsbestigare",
    "bergsbestigaren": "bergsbestigare",
    "bergsbestigarens": "bergsbestigare",
    "bergsbestigares": "bergsbestigare",
    "bergsbestigarna": "bergsbestigare",
    "bergsbestigarnas": "bergsbestigare",
    "bergsbestigningar": "bergsbestigning",
    "bergsbestigningarna": "bergsbestigning",
    "bergsbestigningarnas": "bergsbestigning",
    "bergsbestigningars": "bergsbestigning",
    "bergsbestigningen": "bergsbestigning",
    "bergsbestigningens": "bergsbestigning",
    "bergsbestignings": "bergsbestigning",
    "bergsbestigningsexpeditionen": "bergsbestigningsexpedition",
    "bergsbestigningsexpeditionens": "bergsbestigningsexpedition",
    "bergsbestigningsexpeditioner": "bergsbestigningsexpedition",
    "bergsbestigningsexpeditionerna": "bergsbestigningsexpedition",
    "bergsbestigningsexpeditionernas": "bergsbestigningsexpedition",
    "bergsbestigningsexpeditioners": "bergsbestigningsexpedition",
    "bergsbestigningsexpeditions": "bergsbestigningsexpedition",
    "bergsbranten": "bergsbrant",
    "bergsbrantens": "bergsbrant",
    "bergsbranter": "bergsbrant",
    "bergsbranterna": "bergsbrant",
    "bergsbranternas": "bergsbrant",
    "bergsbranters": "bergsbrant",
    "bergsbrants": "bergsbrant",
    "bergsbruket": "bergsbruk",
    "bergsbrukets": "bergsbruk",
    "bergsbruks": "bergsbruk",
    "bergsformationen": "bergsformation",
    "bergsformationens": "bergsformation",
    "bergsformationer": "bergsformation",
    "bergsformationerna": "bergsformation",
    "bergsformationernas": "bergsformation",
    "bergsformationers": "bergsformation",
    "bergsformations": "bergsformation",
    "bergsgeten": "bergsget",
    "bergsgetens": "bergsget",
    "bergsgets": "bergsget",
    "bergsgetter": "bergsget",
    "bergsgetterna": "bergsget",
    "bergsgetternas": "bergsget",
    "bergsgetters": "bergsget",
    "bergsglaciären": "bergsglaciär",
    "bergsglaciärens": "bergsglaciär",
    "bergsglaciärer": "bergsglaciär",
    "bergsglaciärerna": "bergsglaciär",
    "bergsglaciärernas": "bergsglaciär",
    "bergsglaciärers": "bergsglaciär",
    "bergsglaciärs": "bergsglaciär",
    "bergsgorillan": "bergsgorilla",
    "bergsgorillans": "bergsgorilla",
    "bergsgorillas": "bergsgorilla",
    "bergsgorille": "bergsgorilla",
    "bergsgorillor": "bergsgorilla",
    "bergsgorillorna": "bergsgorilla",
    "bergsgorillornas": "bergsgorilla",
    "bergsgorillors": "bergsgorilla",
    "bergshanteringar": "bergshantering",
    "bergshanteringarna": "bergshantering",
    "bergshanteringarnas": "bergshantering",
    "bergshanteringars": "bergshantering",
    "bergshanteringen": "bergshantering",
    "bergshanteringens": "bergshantering",
    "bergshanterings": "bergshantering",
    "bergskedjan": "bergskedja",
    "bergskedjans": "bergskedja",
    "bergskedjas": "bergskedja",
    "bergskedje": "bergskedja",
    "bergskedjebildningar": "bergskedjebildning",
    "bergskedjebildningarna": "bergskedjebildning",
    "bergskedjebildningarnas": "bergskedjebildning",
    "bergskedjebildningars": "bergskedjebildning",
    "bergskedjebildningen": "bergskedjebildning",
    "bergskedjebildningens": "bergskedjebildning",
    "bergskedjebildnings": "bergskedjebildning",
    "bergskedjor": "bergskedja",
    "bergskedjorna": "bergskedja",
    "bergskedjornas": "bergskedja",
    "bergskedjors": "bergskedja",
    "bergsklimatet": "bergsklimat",
    "bergsklimatets": "bergsklimat",
    "bergsklimats": "bergsklimat",
    "bergsklyftan": "bergsklyfta",
    "bergsklyftans": "bergsklyfta",
    "bergsklyftas": "bergsklyfta",
    "bergsklyfte": "bergsklyfta",
    "bergsklyftor": "bergsklyfta",
    "bergsklyftorna": "bergsklyfta",
    "bergsklyftornas": "bergsklyfta",
    "bergsklyftors": "bergsklyfta",
    "bergsklättrar": "bergsklättrare",
    "bergsklättraren": "bergsklättrare",
    "bergsklättrarens": "bergsklättrare",
    "bergsklättrares": "bergsklättrare",
    "bergsklättrarna": "bergsklättrare",
    "bergsklättrarnas": "bergsklättrare",
    "bergsklättringar": "bergsklättring",
    "bergsklättringarna": "bergsklättring",
    "bergsklättringarnas": "bergsklättring",
    "bergsklättringars": "bergsklättring",
    "bergsklättringen": "bergsklättring",
    "bergsklättringens": "bergsklättring",
    "bergsklättrings": "bergsklättring",
    "bergskreden": "bergskred",
    "bergskredens": "bergskred",
    "bergskredet": "bergskred",
    "bergskredets": "bergskred",
    "bergskreds": "bergskred",
    "bergslagen": "bergslag",
    "bergslagens": "bergslag",
    "bergslager": "bergslag",
    "bergslagerna": "bergslager",
    "bergslagernas": "bergslager",
    "bergslagers": "bergslager",
    "bergslagren": "bergslager",
    "bergslagrens": "bergslager",
    "bergslagret": "bergslager",
    "bergslagrets": "bergslager",
    "bergslags": "bergslag",
    "bergslandskapen": "bergslandskap",
    "bergslandskapens": "bergslandskap",
    "bergslandskapet": "bergslandskap",
    "bergslandskapets": "bergslandskap",
    "bergslandskaps": "bergslandskap",
    "bergsmannen": "bergsman",
    "bergsmannens": "bergsman",
    "bergsmans": "bergsman",
    "bergsmassiven": "bergsmassiv",
    "bergsmassivens": "bergsmassiv",
    "bergsmassivet": "bergsmassiv",
    "bergsmassivets": "bergsmassiv",
    "bergsmassivs": "bergsmassiv",
    "bergsmän": "bergsman",
    "bergsmännen": "bergsman",
    "bergsmännens": "bergsman",
    "bergsmäns": "bergsman",
    "bergsområden": "bergsområde",
    "bergsområdena": "bergsområde",
    "bergsområdenas": "bergsområde",
    "bergsområdens": "bergsområde",
    "bergsområdes": "bergsområde",
    "bergsområdet": "bergsområde",
    "bergsområdets": "bergsområde",
    "bergsryggar": "bergsrygg",
    "bergsryggarna": "bergsrygg",
    "bergsryggarnas": "bergsrygg",
    "bergsryggars": "bergsrygg",
    "bergsryggen": "bergsrygg",
    "bergsryggens": "bergsrygg",
    "bergsryggs": "bergsrygg",
    "bergssidan": "bergssida",
    "bergssidans": "bergssida",
    "bergssidas": "bergssida",
    "bergsside": "bergssida",
    "bergssides": "bergssida",
    "bergssidor": "bergssida",
    "bergssidorna": "bergssida",
    "bergssidornas": "bergssida",
    "bergssidors": "bergssida",
    "bergsskolan": "bergsskola",
    "bergsskolans": "bergsskola",
    "bergsskolas": "bergsskola",
    "bergsskole": "bergsskola",
    "bergsskolor": "bergsskola",
    "bergsskolorna": "bergsskola",
    "bergsskolornas": "bergsskola",
    "bergsskolors": "bergsskola",
    "bergssluttningar": "bergssluttning",
    "bergssluttningarna": "bergssluttning",
    "bergssluttningarnas": "bergssluttning",
    "bergssluttningars": "bergssluttning",
    "bergssluttningen": "bergssluttning",
    "bergssluttningens": "bergssluttning",
    "bergssluttnings": "bergssluttning",
    "bergsstammar": "bergsstam",
    "bergsstammarna": "bergsstam",
    "bergsstammarnas": "bergsstam",
    "bergsstammars": "bergsstam",
    "bergsstammen": "bergsstam",
    "bergsstammens": "bergsstam",
    "bergsstams": "bergsstam",
    "bergstoppar": "bergstopp",
    "bergstopparna": "bergstopp",
    "bergstopparnas": "bergstopp",
    "bergstoppars": "bergstopp",
    "bergstoppen": "bergstopp",
    "bergstoppens": "bergstopp",
    "bergstopps": "bergstopp",
    "bergstrakten": "bergstrakt",
    "bergstraktens": "bergstrakt",
    "bergstrakter": "bergstrakt",
    "bergstrakterna": "bergstrakt",
    "bergstrakternas": "bergstrakt",
    "bergstrakters": "bergstrakt",
    "bergstrakts": "bergstrakt",
    "bergstupen": "bergstup",
    "bergstupens": "bergstup",
    "bergstupet": "bergstup",
    "bergstupets": "bergstup",
    "bergstups": "bergstup",
    "bergsyran": "bergsyra",
    "bergsyrans": "bergsyra",
    "bergsyras": "bergsyra",
    "bergsyre": "bergsyra",
    "bergsyror": "bergsyra",
    "bergsyrorna": "bergsyra",
    "bergsyrornas": "bergsyra",
    "bergsyrors": "bergsyra",
    "bergsäkerheten": "bergsäkerhet",
    "bergsäkerhetens": "bergsäkerhet",
    "bergsäkerhets": "bergsäkerhet",
    "bergsäkers": "bergsäker",
    "bergsäkert": "bergsäker",
    "bergsäkerts": "bergsäker",
    "bergsäkra": "bergsäker",
    "bergsäkrare": "bergsäker",
    "bergsäkrares": "bergsäker",
    "bergsäkras": "bergsäker",
    "bergsäkrast": "bergsäker",
    "bergsäkraste": "bergsäker",
    "bergsäkrastes": "bergsäker",
    "bergsäkrasts": "bergsäker",
    "bergsäkre": "bergsäker",
    "bergsäkres": "bergsäker",
    "bergtagens": "bergtagen",
    "bergtaget": "bergtagen",
    "bergtagets": "bergtagen",
    "bergtagna": "bergtagen",
    "bergtagnare": "bergtagen",
    "bergtagnares": "bergtagen",
    "bergtagnas": "bergtagen",
    "bergtagnast": "bergtagen",
    "bergtagnaste": "bergtagen",
    "bergtagnastes": "bergtagen",
    "bergtagnasts": "bergtagen",
    "bergtagne": "bergtagen",
    "bergtagnes": "bergtagen",
    "bergtallar": "bergtall",
    "bergtallarna": "bergtall",
    "bergtallarnas": "bergtall",
    "bergtallars": "bergtall",
    "bergtallen": "bergtall",
    "bergtallens": "bergtall",
    "bergtalls": "bergtall",
    "bergtoppar": "bergtopp",
    "bergtopparna": "bergtopp",
    "bergtopparnas": "bergtopp",
    "bergtoppars": "bergtopp",
    "bergtoppen": "bergtopp",
    "bergtoppens": "bergtopp",
    "bergtopps": "bergtopp",
    "bergtrollen": "bergtroll",
    "bergtrollens": "bergtroll",
    "bergtrollet": "bergtroll",
    "bergtrollets": "bergtroll",
    "bergtrolls": "bergtroll",
    "berguvar": "berguv",
    "berguvarna": "berguv",
    "berguvarnas": "berguv",
    "berguvars": "berguv",
    "berguven": "berguv",
    "berguvens": "berguv",
    "berguvs": "berguv",
    "bergvindar": "bergvind",
    "bergvindarna": "bergvind",
    "bergvindarnas": "bergvind",
    "bergvindars": "bergvind",
    "bergvinden": "bergvind",
    "bergvindens": "bergvind",
    "bergvinds": "bergvind",
    "bergväggar": "bergvägg",
    "bergväggarna": "bergvägg",
    "bergväggarnas": "bergvägg",
    "bergväggars": "bergvägg",
    "bergväggen": "bergvägg",
    "bergväggens": "bergvägg",
    "bergväggs": "bergvägg",
    "beriberin": "beriberi",
    "beriberins": "beriberi",
    "beriberis": "beriberi",
    "beridar": "beridare",
    "beridaren": "beridare",
    "beridarens": "beridare",
    "beridares": "beridare",
    "beridarna": "beridare",
    "beridarnas": "beridare",
    "beridens": "beriden",
    "beridet": "beriden",
    "beridets": "beriden",
    "beridna": "beriden",
    "beridnare": "beriden",
    "beridnares": "beriden",
    "beridnas": "beriden",
    "beridnast": "beriden",
    "beridnaste": "beriden",
    "beridnastes": "beriden",
    "beridnasts": "beriden",
    "beridne": "beriden",
    "beridnes": "beriden",
    "berik": "berika",
    "berikad": "berika",
    "berikade": "berika",
    "berikades": "berika",
    "berikads": "berika",
    "berikande": "berika",
    "berikanden": "berikande",
    "berikandena": "berikande",
    "berikandenas": "berikande",
    "berikandens": "berikande",
    "berikandes": "berikande",
    "berikandet": "berikande",
    "berikandets": "berikande",
    "berikar": "berika",
    "berikas": "berika",
    "berikat": "berika",
    "berikats": "berika",
    "beriktig": "beriktiga",
    "beriktigad": "beriktiga",
    "beriktigade": "beriktiga",
    "beriktigades": "beriktiga",
    "beriktigads": "beriktiga",
    "beriktigande": "beriktiga",
    "beriktiganden": "beriktigande",
    "beriktigandena": "beriktigande",
    "beriktigandenas": "beriktigande",
    "beriktigandens": "beriktigande",
    "beriktigandes": "beriktigande",
    "beriktigandet": "beriktigande",
    "beriktigandets": "beriktigande",
    "beriktigar": "beriktiga",
    "beriktigas": "beriktiga",
    "beriktigat": "beriktiga",
    "beriktigats": "beriktiga",
    "berkeliet": "berkelium",
    "berkeliets": "berkelium",
    "berkeliumet": "berkelium",
    "berkeliumets": "berkelium",
    "berkeliums": "berkelium",
    "berkisar": "berkis",
    "berkisarna": "berkis",
    "berkisarnas": "berkis",
    "berkisars": "berkis",
    "berkisen": "berkis",
    "berkisens": "berkis",
    "berlinerblåtts": "berlinerblått",
    "berlocken": "berlock",
    "berlockens": "berlock",
    "berlocker": "berlock",
    "berlockerna": "berlock",
    "berlockernas": "berlock",
    "berlockers": "berlock",
    "berlocks": "berlock",
    "bermudariggar": "bermudarigg",
    "bermudariggarna": "bermudarigg",
    "bermudariggarnas": "bermudarigg",
    "bermudariggars": "bermudarigg",
    "bermudariggen": "bermudarigg",
    "bermudariggens": "bermudarigg",
    "bermudariggs": "bermudarigg",
    "bermudashortsen": "bermudashorts",
    "bermudashortsens": "bermudashorts",
    "bernäsen": "bernäs",
    "bernäsens": "bernäs",
    "bernäser": "bernäs",
    "bernäserna": "bernäs",
    "bernäsernas": "bernäs",
    "bernäsers": "bernäs",
    "bernässåsen": "bernässås",
    "bernässåsens": "bernässås",
    "bernässåser": "bernässås",
    "bernässåserna": "bernässås",
    "bernässåsernas": "bernässås",
    "bernässåsers": "bernässås",
    "berodd": "bero",
    "berodda": "bero",
    "beroddas": "bero",
    "berodde": "bero",
    "beroddes": "bero",
    "berodds": "bero",
    "beroende": "bero",
    "beroenden": "beroende",
    "beroendena": "beroende",
    "beroendenas": "beroende",
    "beroendens": "beroende",
    "beroendeproblemen": "beroendeproblem",
    "beroendeproblemens": "beroendeproblem",
    "beroendeproblemet": "beroendeproblem",
    "beroendeproblemets": "beroendeproblem",
    "beroendeproblems": "beroendeproblem",
    "beroendes": "beroende",
    "beroendeställningar": "beroendeställning",
    "beroendeställningarna": "beroendeställning",
    "beroendeställningarnas": "beroendeställning",
    "beroendeställningars": "beroendeställning",
    "beroendeställningen": "beroendeställning",
    "beroendeställningens": "beroendeställning",
    "beroendeställnings": "beroendeställning",
    "beroendet": "beroende",
    "beroendets": "beroende",
    "beror": "bero",
    "beros": "bero",
    "berott": "bero",
    "berotts": "bero",
    "bersåer": "berså",
    "bersåerna": "berså",
    "bersåernas": "berså",
    "bersåers": "berså",
    "bersån": "berså",
    "bersåns": "berså",
    "bersås": "berså",
    "berteln": "bertel",
    "bertelns": "bertel",
    "bertels": "bertel",
    "bertlar": "bertel",
    "bertlarna": "bertel",
    "bertlarnas": "bertel",
    "bertlars": "bertel",
    "berusad": "berusa",
    "berusade": "berusad",
    "berusades": "berusad",
    "berusads": "berusad",
    "berusande": "berusa",
    "berusanden": "berusande",
    "berusandena": "berusande",
    "berusandenas": "berusande",
    "berusandens": "berusande",
    "berusandes": "berusande",
    "berusandet": "berusande",
    "berusandets": "berusande",
    "berusar": "berusa",
    "berusas": "berusa",
    "berusat": "berusad",
    "berusats": "berusad",
    "berusningar": "berusning",
    "berusningarna": "berusning",
    "berusningarnas": "berusning",
    "berusningars": "berusning",
    "berusningen": "berusning",
    "berusningens": "berusning",
    "berusnings": "berusning",
    "berusningsgraden": "berusningsgrad",
    "berusningsgradens": "berusningsgrad",
    "berusningsgrader": "berusningsgrad",
    "berusningsgraderna": "berusningsgrad",
    "berusningsgradernas": "berusningsgrad",
    "berusningsgraders": "berusningsgrad",
    "berusningsgrads": "berusningsgrad",
    "beryktade": "beryktad",
    "beryktades": "beryktad",
    "beryktads": "beryktad",
    "beryktat": "beryktad",
    "beryktats": "beryktad",
    "beryllen": "beryll",
    "beryllens": "beryll",
    "beryller": "beryll",
    "beryllerna": "beryll",
    "beryllernas": "beryll",
    "beryllers": "beryll",
    "beryllgröna": "beryllgrön",
    "beryllgrönare": "beryllgrön",
    "beryllgrönares": "beryllgrön",
    "beryllgrönas": "beryllgrön",
    "beryllgrönast": "beryllgrön",
    "beryllgrönaste": "beryllgrön",
    "beryllgrönastes": "beryllgrön",
    "beryllgrönasts": "beryllgrön",
    "beryllgröne": "beryllgrön",
    "beryllgrönes": "beryllgrön",
    "beryllgröns": "beryllgrön",
    "beryllgrönt": "beryllgrön",
    "beryllgrönts": "beryllgrön",
    "berylliet": "beryllium",
    "berylliets": "beryllium",
    "berylliumet": "beryllium",
    "berylliumets": "beryllium",
    "berylliums": "beryllium",
    "berylls": "beryll",
    "beräknad": "beräkna",
    "beräknade": "beräkna",
    "beräknades": "beräkna",
    "beräknads": "beräkna",
    "beräknande": "beräkna",
    "beräknanden": "beräknande",
    "beräknandena": "beräknande",
    "beräknandenas": "beräknande",
    "beräknandens": "beräknande",
    "beräknandes": "beräknande",
    "beräknandet": "beräknande",
    "beräknandets": "beräknande",
    "beräknar": "beräkna",
    "beräknas": "beräkna",
    "beräknat": "beräkna",
    "beräknats": "beräkna",
    "beräkneliga": "beräknelig",
    "beräkneligare": "beräknelig",
    "beräkneligares": "beräknelig",
    "beräkneligas": "beräknelig",
    "beräkneligast": "beräknelig",
    "beräkneligaste": "beräknelig",
    "beräkneligastes": "beräknelig",
    "beräkneligasts": "beräknelig",
    "beräknelige": "beräknelig",
    "beräkneliges": "beräknelig",
    "beräkneligheten": "beräknelighet",
    "beräknelighetens": "beräknelighet",
    "beräknelighets": "beräknelighet",
    "beräkneligs": "beräknelig",
    "beräkneligt": "beräknelig",
    "beräkneligts": "beräknelig",
    "beräkningar": "beräkning",
    "beräkningarna": "beräkning",
    "beräkningarnas": "beräkning",
    "beräkningars": "beräkning",
    "beräkningen": "beräkning",
    "beräkningens": "beräkning",
    "beräknings": "beräkning",
    "beräkningsgrunden": "beräkningsgrund",
    "beräkningsgrundens": "beräkningsgrund",
    "beräkningsgrunder": "beräkningsgrund",
    "beräkningsgrunderna": "beräkningsgrund",
    "beräkningsgrundernas": "beräkningsgrund",
    "beräkningsgrunders": "beräkningsgrund",
    "beräkningsgrunds": "beräkningsgrund",
    "beräkningsmetoden": "beräkningsmetod",
    "beräkningsmetodens": "beräkningsmetod",
    "beräkningsmetoder": "beräkningsmetod",
    "beräkningsmetoderna": "beräkningsmetod",
    "beräkningsmetodernas": "beräkningsmetod",
    "beräkningsmetoders": "beräkningsmetod",
    "beräkningsmetods": "beräkningsmetod",
    "beräkningsmässiga": "beräkningsmässig",
    "beräkningsmässigare": "beräkningsmässig",
    "beräkningsmässigares": "beräkningsmässig",
    "beräkningsmässigas": "beräkningsmässig",
    "beräkningsmässigast": "beräkningsmässig",
    "beräkningsmässigaste": "beräkningsmässig",
    "beräkningsmässigastes": "beräkningsmässig",
    "beräkningsmässigasts": "beräkningsmässig",
    "beräkningsmässige": "beräkningsmässig",
    "beräkningsmässiges": "beräkningsmässig",
    "beräkningsmässigs": "beräkningsmässig",
    "beräkningsmässigt": "beräkningsmässig",
    "beräkningsmässigts": "beräkningsmässig",
    "beräkningssätten": "beräkningssätt",
    "beräkningssättens": "beräkningssätt",
    "beräkningssättet": "beräkningssätt",
    "beräkningssättets": "beräkningssätt",
    "beräkningssätts": "beräkningssätt",
    "berätt": "berätta",
    "berättad": "berätta",
    "berättade": "berätta",
    "berättades": "berätta",
    "berättads": "berätta",
    "berättande": "berätta",
    "berättanden": "berättande",
    "berättandena": "berättande",
    "berättandenas": "berättande",
    "berättandens": "berättande",
    "berättandes": "berättande",
    "berättandet": "berättande",
    "berättandets": "berättande",
    "berättar": "berättare",
    "berättaren": "berättare",
    "berättarens": "berättare",
    "berättares": "berättare",
    "berättarglädjen": "berättarglädje",
    "berättarglädjens": "berättarglädje",
    "berättarglädjes": "berättarglädje",
    "berättarjagen": "berättarjag",
    "berättarjagens": "berättarjag",
    "berättarjaget": "berättarjag",
    "berättarjagets": "berättarjag",
    "berättarjags": "berättarjag",
    "berättarkonsten": "berättarkonst",
    "berättarkonstens": "berättarkonst",
    "berättarkonster": "berättarkonst",
    "berättarkonsterna": "berättarkonst",
    "berättarkonsternas": "berättarkonst",
    "berättarkonsters": "berättarkonst",
    "berättarkonsts": "berättarkonst",
    "berättarmässiga": "berättarmässig",
    "berättarmässigare": "berättarmässig",
    "berättarmässigares": "berättarmässig",
    "berättarmässigas": "berättarmässig",
    "berättarmässigast": "berättarmässig",
    "berättarmässigaste": "berättarmässig",
    "berättarmässigastes": "berättarmässig",
    "berättarmässigasts": "berättarmässig",
    "berättarmässige": "berättarmässig",
    "berättarmässiges": "berättarmässig",
    "berättarmässigs": "berättarmässig",
    "berättarmässigt": "berättarmässig",
    "berättarmässigts": "berättarmässig",
    "berättarna": "berättare",
    "berättarnas": "berättare",
    "berättarrösten": "berättarröst",
    "berättarröstens": "berättarröst",
    "berättarröster": "berättarröst",
    "berättarrösterna": "berättarröst",
    "berättarrösternas": "berättarröst",
    "berättarrösters": "berättarröst",
    "berättarrösts": "berättarröst",
    "berättartalangen": "berättartalang",
    "berättartalangens": "berättartalang",
    "berättartalanger": "berättartalang",
    "berättartalangerna": "berättartalang",
    "berättartalangernas": "berättartalang",
    "berättartalangers": "berättartalang",
    "berättartalangs": "berättartalang",
    "berättartekniken": "berättarteknik",
    "berättarteknikens": "berättarteknik",
    "berättartekniker": "berättarteknik",
    "berättarteknikerna": "berättarteknik",
    "berättarteknikernas": "berättarteknik",
    "berättarteknikers": "berättarteknik",
    "berättartekniks": "berättarteknik",
    "berättas": "berätta",
    "berättat": "berätta",
    "berättats": "berätta",
    "berättelsen": "berättelse",
    "berättelsens": "berättelse",
    "berättelser": "berättelse",
    "berättelserna": "berättelse",
    "berättelsernas": "berättelse",
    "berättelsers": "berättelse",
    "berättelses": "berättelse",
    "berättig": "berättiga",
    "berättigad": "berättiga",
    "berättigade": "berättigad",
    "berättigades": "berättigad",
    "berättigads": "berättigad",
    "berättigande": "berättiga",
    "berättigandes": "berättigande",
    "berättigandet": "berättigande",
    "berättigandets": "berättigande",
    "berättigar": "berättiga",
    "berättigas": "berättiga",
    "berättigat": "berättigad",
    "berättigats": "berättigad",
    "beröm": "berömma",
    "berömd": "berömma",
    "berömda": "berömma",
    "berömdare": "berömd",
    "berömdares": "berömd",
    "berömdas": "berömma",
    "berömdast": "berömd",
    "berömdaste": "berömd",
    "berömdastes": "berömd",
    "berömdasts": "berömd",
    "berömde": "berömma",
    "berömdes": "berömma",
    "berömdheten": "berömdhet",
    "berömdhetens": "berömdhet",
    "berömdheter": "berömdhet",
    "berömdheterna": "berömdhet",
    "berömdheternas": "berömdhet",
    "berömdheters": "berömdhet",
    "berömdhets": "berömdhet",
    "berömds": "berömma",
    "berömliga": "berömlig",
    "berömligare": "berömlig",
    "berömligares": "berömlig",
    "berömligas": "berömlig",
    "berömligast": "berömlig",
    "berömligaste": "berömlig",
    "berömligastes": "berömlig",
    "berömligasts": "berömlig",
    "berömlige": "berömlig",
    "berömliges": "berömlig",
    "berömligheten": "berömlighet",
    "berömlighetens": "berömlighet",
    "berömligheter": "berömlighet",
    "berömligheterna": "berömlighet",
    "berömligheternas": "berömlighet",
    "berömligheters": "berömlighet",
    "berömlighets": "berömlighet",
    "berömligs": "berömlig",
    "berömligt": "berömlig",
    "berömligts": "berömlig",
    "berömmande": "berömma",
    "berömmanden": "berömmande",
    "berömmandena": "berömmande",
    "berömmandenas": "berömmande",
    "berömmandens": "berömmande",
    "berömmandes": "berömmande",
    "berömmandet": "berömmande",
    "berömmandets": "berömmande",
    "berömmas": "berömma",
    "berömmelsen": "berömmelse",
    "berömmelsens": "berömmelse",
    "berömmelses": "berömmelse",
    "berömmer": "berömma",
    "berömmet": "beröm",
    "berömmets": "beröm",
    "beröms": "berömma",
    "berömt": "berömma",
    "berömts": "berömma",
    "berömvärda": "berömvärd",
    "berömvärdare": "berömvärd",
    "berömvärdares": "berömvärd",
    "berömvärdas": "berömvärd",
    "berömvärdast": "berömvärd",
    "berömvärdaste": "berömvärd",
    "berömvärdastes": "berömvärd",
    "berömvärdasts": "berömvärd",
    "berömvärde": "berömvärd",
    "berömvärdes": "berömvärd",
    "berömvärdheten": "berömvärdhet",
    "berömvärdhetens": "berömvärdhet",
    "berömvärdhets": "berömvärdhet",
    "berömvärds": "berömvärd",
    "berömvärt": "berömvärd",
    "berömvärts": "berömvärd",
    "berör": "beröra",
    "berörande": "beröra",
    "beröranden": "berörande",
    "berörandena": "berörande",
    "berörandenas": "berörande",
    "berörandens": "berörande",
    "berörandes": "berörande",
    "berörandet": "berörande",
    "berörandets": "berörande",
    "beröras": "beröra",
    "berörd": "beröra",
    "berörda": "berörd",
    "berördare": "berörd",
    "berördares": "berörd",
    "berördas": "berörd",
    "berördast": "berörd",
    "berördaste": "berörd",
    "berördastes": "berörd",
    "berördasts": "berörd",
    "berörde": "berörd",
    "berördes": "berörd",
    "berörds": "berörd",
    "beröres": "beröra",
    "beröringar": "beröring",
    "beröringarna": "beröring",
    "beröringarnas": "beröring",
    "beröringars": "beröring",
    "beröringen": "beröring",
    "beröringens": "beröring",
    "berörings": "beröring",
    "beröringsassociationen": "beröringsassociation",
    "beröringsassociationens": "beröringsassociation",
    "beröringsassociationer": "beröringsassociation",
    "beröringsassociationerna": "beröringsassociation",
    "beröringsassociationernas": "beröringsassociation",
    "beröringsassociationers": "beröringsassociation",
    "beröringsassociations": "beröringsassociation",
    "beröringselektriciteten": "beröringselektricitet",
    "beröringselektricitetens": "beröringselektricitet",
    "beröringselektriciteter": "beröringselektricitet",
    "beröringselektriciteterna": "beröringselektricitet",
    "beröringselektriciteternas": "beröringselektricitet",
    "beröringselektriciteters": "beröringselektricitet",
    "beröringselektricitets": "beröringselektricitet",
    "beröringsfria": "beröringsfri",
    "beröringsfriare": "beröringsfri",
    "beröringsfriares": "beröringsfri",
    "beröringsfrias": "beröringsfri",
    "beröringsfriast": "beröringsfri",
    "beröringsfriaste": "beröringsfri",
    "beröringsfriastes": "beröringsfri",
    "beröringsfriasts": "beröringsfri",
    "beröringsfrie": "beröringsfri",
    "beröringsfries": "beröringsfri",
    "beröringsfris": "beröringsfri",
    "beröringsfritt": "beröringsfri",
    "beröringsfritts": "beröringsfri",
    "beröringspunkten": "beröringspunkt",
    "beröringspunktens": "beröringspunkt",
    "beröringspunkter": "beröringspunkt",
    "beröringspunkterna": "beröringspunkt",
    "beröringspunkternas": "beröringspunkt",
    "beröringspunkters": "beröringspunkt",
    "beröringspunkts": "beröringspunkt",
    "beröringsskräcken": "beröringsskräck",
    "beröringsskräckens": "beröringsskräck",
    "beröringsskräcks": "beröringsskräck",
    "berörs": "beröra",
    "berört": "berörd",
    "berörts": "berörd",
    "beröv": "beröva",
    "berövad": "beröva",
    "berövade": "beröva",
    "berövades": "beröva",
    "berövads": "beröva",
    "berövande": "beröva",
    "berövanden": "berövande",
    "berövandena": "berövande",
    "berövandenas": "berövande",
    "berövandens": "berövande",
    "berövandes": "berövande",
    "berövandet": "berövande",
    "berövandets": "berövande",
    "berövar": "beröva",
    "berövas": "beröva",
    "berövat": "beröva",
    "berövats": "beröva",
    "besann": "besanna",
    "besannad": "besanna",
    "besannade": "besanna",
    "besannades": "besanna",
    "besannads": "besanna",
    "besannande": "besanna",
    "besannanden": "besannande",
    "besannandena": "besannande",
    "besannandenas": "besannande",
    "besannandens": "besannande",
    "besannandes": "besannande",
    "besannandet": "besannande",
    "besannandets": "besannande",
    "besannar": "besanna",
    "besannas": "besanna",
    "besannat": "besanna",
    "besannats": "besanna",
    "besatt": "besitta",
    "besatta": "besätta",
    "besattare": "besatt",
    "besattares": "besatt",
    "besattas": "besätta",
    "besattast": "besatt",
    "besattaste": "besatt",
    "besattastes": "besatt",
    "besattasts": "besatt",
    "besatte": "besätta",
    "besattes": "besätta",
    "besattheten": "besatthet",
    "besatthetens": "besatthet",
    "besattheter": "besatthet",
    "besattheterna": "besatthet",
    "besattheternas": "besatthet",
    "besattheters": "besatthet",
    "besatthets": "besatthet",
    "besatts": "besitta",
    "besedd": "bese",
    "besedda": "bese",
    "beseddas": "bese",
    "besedde": "bese",
    "beseddes": "bese",
    "besedds": "bese",
    "beseende": "bese",
    "beseendes": "beseende",
    "beseendet": "beseende",
    "beseendets": "beseende",
    "beseglad": "besegla",
    "beseglade": "besegla",
    "beseglades": "besegla",
    "beseglads": "besegla",
    "beseglande": "besegla",
    "beseglanden": "beseglande",
    "beseglandena": "beseglande",
    "beseglandenas": "beseglande",
    "beseglandens": "beseglande",
    "beseglandes": "beseglande",
    "beseglandet": "beseglande",
    "beseglandets": "beseglande",
    "beseglar": "besegla",
    "beseglas": "besegla",
    "beseglat": "besegla",
    "beseglats": "besegla",
    "besegrad": "besegra",
    "besegrade": "besegra",
    "besegrades": "besegra",
    "besegrads": "besegra",
    "besegrande": "besegra",
    "besegranden": "besegrande",
    "besegrandena": "besegrande",
    "besegrandenas": "besegrande",
    "besegrandens": "besegrande",
    "besegrandes": "besegrande",
    "besegrandet": "besegrande",
    "besegrandets": "besegrande",
    "besegrar": "besegrare",
    "besegraren": "besegrare",
    "besegrarens": "besegrare",
    "besegrares": "besegrare",
    "besegrarna": "besegrare",
    "besegrarnas": "besegrare",
    "besegras": "besegra",
    "besegrat": "besegra",
    "besegrats": "besegra",
    "beser": "bese",
    "beses": "bese",
    "besett": "bese",
    "besetts": "bese",
    "besicken": "besick",
    "besickens": "besick",
    "besicks": "besick",
    "besiffrade": "besiffrad",
    "besiffrades": "besiffrad",
    "besiffrads": "besiffrad",
    "besiffrat": "besiffrad",
    "besiffrats": "besiffrad",
    "besiffringar": "besiffring",
    "besiffringarna": "besiffring",
    "besiffringarnas": "besiffring",
    "besiffringars": "besiffring",
    "besiffringen": "besiffring",
    "besiffringens": "besiffring",
    "besiffrings": "besiffring",
    "besiktig": "besiktiga",
    "besiktigad": "besiktiga",
    "besiktigade": "besiktiga",
    "besiktigades": "besiktiga",
    "besiktigads": "besiktiga",
    "besiktigande": "besiktiga",
    "besiktiganden": "besiktigande",
    "besiktigandena": "besiktigande",
    "besiktigandenas": "besiktigande",
    "besiktigandens": "besiktigande",
    "besiktigandes": "besiktigande",
    "besiktigandet": "besiktigande",
    "besiktigandets": "besiktigande",
    "besiktigar": "besiktiga",
    "besiktigas": "besiktiga",
    "besiktigat": "besiktiga",
    "besiktigats": "besiktiga",
    "besiktningar": "besiktning",
    "besiktningarna": "besiktning",
    "besiktningarnas": "besiktning",
    "besiktningars": "besiktning",
    "besiktningen": "besiktning",
    "besiktningens": "besiktning",
    "besiktnings": "besiktning",
    "besiktningsinstrumenten": "besiktningsinstrument",
    "besiktningsinstrumentens": "besiktningsinstrument",
    "besiktningsinstrumentet": "besiktningsinstrument",
    "besiktningsinstrumentets": "besiktningsinstrument",
    "besiktningsinstruments": "besiktningsinstrument",
    "besiktningsmannen": "besiktningsman",
    "besiktningsmannens": "besiktningsman",
    "besiktningsmans": "besiktningsman",
    "besiktningsmän": "besiktningsman",
    "besiktningsmännen": "besiktningsman",
    "besiktningsmännens": "besiktningsman",
    "besiktningsmäns": "besiktningsman",
    "besiktningsprotokollen": "besiktningsprotokoll",
    "besiktningsprotokollens": "besiktningsprotokoll",
    "besiktningsprotokollet": "besiktningsprotokoll",
    "besiktningsprotokollets": "besiktningsprotokoll",
    "besiktningsprotokolls": "besiktningsprotokoll",
    "besinn": "besinna",
    "besinnad": "besinna",
    "besinnade": "besinnad",
    "besinnades": "besinnad",
    "besinnads": "besinnad",
    "besinnande": "besinna",
    "besinnanden": "besinnande",
    "besinnandena": "besinnande",
    "besinnandenas": "besinnande",
    "besinnandens": "besinnande",
    "besinnandes": "besinnande",
    "besinnandet": "besinnande",
    "besinnandets": "besinnande",
    "besinnar": "besinna",
    "besinnas": "besinna",
    "besinnat": "besinnad",
    "besinnats": "besinnad",
    "besinningar": "besinning",
    "besinningarna": "besinning",
    "besinningarnas": "besinning",
    "besinningars": "besinning",
    "besinningen": "besinning",
    "besinningens": "besinning",
    "besinnings": "besinning",
    "besinningsfulla": "besinningsfull",
    "besinningsfullare": "besinningsfull",
    "besinningsfullares": "besinningsfull",
    "besinningsfullas": "besinningsfull",
    "besinningsfullast": "besinningsfull",
    "besinningsfullaste": "besinningsfull",
    "besinningsfullastes": "besinningsfull",
    "besinningsfullasts": "besinningsfull",
    "besinningsfulle": "besinningsfull",
    "besinningsfulles": "besinningsfull",
    "besinningsfullheten": "besinningsfullhet",
    "besinningsfullhetens": "besinningsfullhet",
    "besinningsfullhets": "besinningsfullhet",
    "besinningsfulls": "besinningsfull",
    "besinningsfullt": "besinningsfull",
    "besinningsfullts": "besinningsfull",
    "besinningslösa": "besinningslös",
    "besinningslösare": "besinningslös",
    "besinningslösares": "besinningslös",
    "besinningslösas": "besinningslös",
    "besinningslösast": "besinningslös",
    "besinningslösaste": "besinningslös",
    "besinningslösastes": "besinningslös",
    "besinningslösasts": "besinningslös",
    "besinningslöse": "besinningslös",
    "besinningslöses": "besinningslös",
    "besinningslösheten": "besinningslöshet",
    "besinningslöshetens": "besinningslöshet",
    "besinningslösheter": "besinningslöshet",
    "besinningslösheterna": "besinningslöshet",
    "besinningslösheternas": "besinningslöshet",
    "besinningslösheters": "besinningslöshet",
    "besinningslöshets": "besinningslöshet",
    "besinningslöst": "besinningslös",
    "besinningslösts": "besinningslös",
    "besiquen": "besique",
    "besiquens": "besique",
    "besiques": "besique",
    "besitt": "besitta",
    "besittande": "besitta",
    "besittanden": "besittande",
    "besittandena": "besittande",
    "besittandenas": "besittande",
    "besittandens": "besittande",
    "besittandes": "besittande",
    "besittandet": "besittande",
    "besittandets": "besittande",
    "besittas": "besitta",
    "besitte": "besitta",
    "besitter": "besitta",
    "besittes": "besitta",
    "besittningar": "besittning",
    "besittningarna": "besittning",
    "besittningarnas": "besittning",
    "besittningars": "besittning",
    "besittningen": "besittning",
    "besittningens": "besittning",
    "besittnings": "besittning",
    "besittningshavar": "besittningshavare",
    "besittningshavaren": "besittningshavare",
    "besittningshavarens": "besittningshavare",
    "besittningshavares": "besittningshavare",
    "besittningshavarna": "besittningshavare",
    "besittningshavarnas": "besittningshavare",
    "besittningsrätten": "besittningsrätt",
    "besittningsrättens": "besittningsrätt",
    "besittningsrätter": "besittningsrätt",
    "besittningsrätterna": "besittningsrätt",
    "besittningsrätternas": "besittningsrätt",
    "besittningsrätters": "besittningsrätt",
    "besittningsrätts": "besittningsrätt",
    "besittningsskydden": "besittningsskydd",
    "besittningsskyddens": "besittningsskydd",
    "besittningsskyddet": "besittningsskydd",
    "besittningsskyddets": "besittningsskydd",
    "besittningsskydds": "besittningsskydd",
    "besitts": "besitta",
    "besjung": "besjunga",
    "besjungande": "besjunga",
    "besjunganden": "besjungande",
    "besjungandena": "besjungande",
    "besjungandenas": "besjungande",
    "besjungandens": "besjungande",
    "besjungandes": "besjungande",
    "besjungandet": "besjungande",
    "besjungandets": "besjungande",
    "besjungas": "besjunga",
    "besjunge": "besjunga",
    "besjungen": "besjunga",
    "besjungens": "besjunga",
    "besjunger": "besjunga",
    "besjunges": "besjunga",
    "besjunget": "besjunga",
    "besjungets": "besjunga",
    "besjungit": "besjunga",
    "besjungits": "besjunga",
    "besjungna": "besjunga",
    "besjungnas": "besjunga",
    "besjungne": "besjunga",
    "besjungnes": "besjunga",
    "besjungs": "besjunga",
    "besjälad": "besjäla",
    "besjälade": "besjäla",
    "besjälades": "besjäla",
    "besjälads": "besjäla",
    "besjälande": "besjäla",
    "besjälanden": "besjälande",
    "besjälandena": "besjälande",
    "besjälandenas": "besjälande",
    "besjälandens": "besjälande",
    "besjälandes": "besjälande",
    "besjälandet": "besjälande",
    "besjälandets": "besjälande",
    "besjälar": "besjäla",
    "besjälas": "besjäla",
    "besjälat": "besjäla",
    "besjälats": "besjäla",
    "besjöng": "besjunga",
    "besjönge": "besjunga",
    "besjönges": "besjunga",
    "besjöngs": "besjunga",
    "beska": "besk",
    "beskaffade": "beskaffad",
    "beskaffades": "beskaffad",
    "beskaffads": "beskaffad",
    "beskaffat": "beskaffad",
    "beskaffats": "beskaffad",
    "beskaffenheten": "beskaffenhet",
    "beskaffenhetens": "beskaffenhet",
    "beskaffenheter": "beskaffenhet",
    "beskaffenheterna": "beskaffenhet",
    "beskaffenheternas": "beskaffenhet",
    "beskaffenheters": "beskaffenhet",
    "beskaffenhets": "beskaffenhet",
    "beskan": "beska",
    "beskans": "beska",
    "beskar": "beskära",
    "beskare": "besk",
    "beskares": "besk",
    "beskarna": "besk",
    "beskarnas": "besk",
    "beskars": "beskära",
    "beskas": "beska",
    "beskast": "besk",
    "beskaste": "besk",
    "beskastes": "besk",
    "beskasts": "besk",
    "beskatt": "beskatta",
    "beskattad": "beskatta",
    "beskattade": "beskatta",
    "beskattades": "beskatta",
    "beskattads": "beskatta",
    "beskattande": "beskatta",
    "beskattanden": "beskattande",
    "beskattandena": "beskattande",
    "beskattandenas": "beskattande",
    "beskattandens": "beskattande",
    "beskattandes": "beskattande",
    "beskattandet": "beskattande",
    "beskattandets": "beskattande",
    "beskattar": "beskatta",
    "beskattas": "beskatta",
    "beskattat": "beskatta",
    "beskattats": "beskatta",
    "beskattningar": "beskattning",
    "beskattningarna": "beskattning",
    "beskattningarnas": "beskattning",
    "beskattningars": "beskattning",
    "beskattningen": "beskattning",
    "beskattningens": "beskattning",
    "beskattnings": "beskattning",
    "beskattningsbara": "beskattningsbar",
    "beskattningsbarare": "beskattningsbar",
    "beskattningsbarares": "beskattningsbar",
    "beskattningsbaras": "beskattningsbar",
    "beskattningsbarast": "beskattningsbar",
    "beskattningsbaraste": "beskattningsbar",
    "beskattningsbarastes": "beskattningsbar",
    "beskattningsbarasts": "beskattningsbar",
    "beskattningsbare": "beskattningsbar",
    "beskattningsbares": "beskattningsbar",
    "beskattningsbarheten": "beskattningsbarhet",
    "beskattningsbarhetens": "beskattningsbarhet",
    "beskattningsbarhets": "beskattningsbarhet",
    "beskattningsbars": "beskattningsbar",
    "beskattningsbart": "beskattningsbar",
    "beskattningsbarts": "beskattningsbar",
    "beskattningsgrunden": "beskattningsgrund",
    "beskattningsgrundens": "beskattningsgrund",
    "beskattningsgrunder": "beskattningsgrund",
    "beskattningsgrunderna": "beskattningsgrund",
    "beskattningsgrundernas": "beskattningsgrund",
    "beskattningsgrunders": "beskattningsgrund",
    "beskattningsgrunds": "beskattningsgrund",
    "beskattningsmakten": "beskattningsmakt",
    "beskattningsmaktens": "beskattningsmakt",
    "beskattningsmakts": "beskattningsmakt",
    "beskattningsnämnden": "beskattningsnämnd",
    "beskattningsnämndens": "beskattningsnämnd",
    "beskattningsnämnder": "beskattningsnämnd",
    "beskattningsnämnderna": "beskattningsnämnd",
    "beskattningsnämndernas": "beskattningsnämnd",
    "beskattningsnämnders": "beskattningsnämnd",
    "beskattningsnämnds": "beskattningsnämnd",
    "beskattningsprincipen": "beskattningsprincip",
    "beskattningsprincipens": "beskattningsprincip",
    "beskattningsprinciper": "beskattningsprincip",
    "beskattningsprinciperna": "beskattningsprincip",
    "beskattningsprincipernas": "beskattningsprincip",
    "beskattningsprincipers": "beskattningsprincip",
    "beskattningsprincips": "beskattningsprincip",
    "beskattningsrätten": "beskattningsrätt",
    "beskattningsrättens": "beskattningsrätt",
    "beskattningsrätts": "beskattningsrätt",
    "beskattningsåren": "beskattningsår",
    "beskattningsårens": "beskattningsår",
    "beskattningsåret": "beskattningsår",
    "beskattningsårets": "beskattningsår",
    "beskattningsårs": "beskattningsår",
    "beske": "besk",
    "beskeden": "besked",
    "beskedens": "besked",
    "beskedet": "besked",
    "beskedets": "besked",
    "beskedliga": "beskedlig",
    "beskedligare": "beskedlig",
    "beskedligares": "beskedlig",
    "beskedligas": "beskedlig",
    "beskedligast": "beskedlig",
    "beskedligaste": "beskedlig",
    "beskedligastes": "beskedlig",
    "beskedligasts": "beskedlig",
    "beskedlige": "beskedlig",
    "beskedliges": "beskedlig",
    "beskedligheten": "beskedlighet",
    "beskedlighetens": "beskedlighet",
    "beskedlighets": "beskedlighet",
    "beskedligs": "beskedlig",
    "beskedligt": "beskedlig",
    "beskedligts": "beskedlig",
    "beskeds": "besked",
    "besken": "besk",
    "beskens": "besk",
    "beskes": "besk",
    "beskheten": "beskhet",
    "beskhetens": "beskhet",
    "beskheter": "beskhet",
    "beskheterna": "beskhet",
    "beskheternas": "beskhet",
    "beskheters": "beskhet",
    "beskhets": "beskhet",
    "beskick": "beskicka",
    "beskickad": "beskicka",
    "beskickade": "beskicka",
    "beskickades": "beskicka",
    "beskickads": "beskicka",
    "beskickande": "beskicka",
    "beskickanden": "beskickande",
    "beskickandena": "beskickande",
    "beskickandenas": "beskickande",
    "beskickandens": "beskickande",
    "beskickandes": "beskickande",
    "beskickandet": "beskickande",
    "beskickandets": "beskickande",
    "beskickar": "beskicka",
    "beskickas": "beskicka",
    "beskickat": "beskicka",
    "beskickats": "beskicka",
    "beskickningar": "beskickning",
    "beskickningarna": "beskickning",
    "beskickningarnas": "beskickning",
    "beskickningars": "beskickning",
    "beskickningen": "beskickning",
    "beskickningens": "beskickning",
    "beskicknings": "beskickning",
    "beskickningschefen": "beskickningschef",
    "beskickningschefens": "beskickningschef",
    "beskickningschefer": "beskickningschef",
    "beskickningscheferna": "beskickningschef",
    "beskickningschefernas": "beskickningschef",
    "beskickningschefers": "beskickningschef",
    "beskickningschefs": "beskickningschef",
    "beskjut": "beskjuta",
    "beskjutande": "beskjuta",
    "beskjutanden": "beskjutande",
    "beskjutandena": "beskjutande",
    "beskjutandenas": "beskjutande",
    "beskjutandens": "beskjutande",
    "beskjutandes": "beskjutande",
    "beskjutandet": "beskjutande",
    "beskjutandets": "beskjutande",
    "beskjutas": "beskjuta",
    "beskjute": "beskjuta",
    "beskjuten": "beskjuta",
    "beskjutens": "beskjuta",
    "beskjuter": "beskjuta",
    "beskjutes": "beskjuta",
    "beskjutet": "beskjuta",
    "beskjutets": "beskjuta",
    "beskjutit": "beskjuta",
    "beskjutits": "beskjuta",
    "beskjutna": "beskjuta",
    "beskjutnas": "beskjuta",
    "beskjutne": "beskjuta",
    "beskjutnes": "beskjuta",
    "beskjutningar": "beskjutning",
    "beskjutningarna": "beskjutning",
    "beskjutningarnas": "beskjutning",
    "beskjutningars": "beskjutning",
    "beskjutningen": "beskjutning",
    "beskjutningens": "beskjutning",
    "beskjutnings": "beskjutning",
    "beskjuts": "beskjuta",
    "beskrev": "beskriva",
    "beskrevs": "beskriva",
    "beskriv": "beskriva",
    "beskrivande": "beskriva",
    "beskrivanden": "beskrivande",
    "beskrivandena": "beskrivande",
    "beskrivandenas": "beskrivande",
    "beskrivandens": "beskrivande",
    "beskrivandes": "beskrivande",
    "beskrivandet": "beskrivande",
    "beskrivandets": "beskrivande",
    "beskrivas": "beskriva",
    "beskrivbara": "beskrivbar",
    "beskrivbarare": "beskrivbar",
    "beskrivbarares": "beskrivbar",
    "beskrivbaras": "beskrivbar",
    "beskrivbarast": "beskrivbar",
    "beskrivbaraste": "beskrivbar",
    "beskrivbarastes": "beskrivbar",
    "beskrivbarasts": "beskrivbar",
    "beskrivbare": "beskrivbar",
    "beskrivbares": "beskrivbar",
    "beskrivbarheten": "beskrivbarhet",
    "beskrivbarhetens": "beskrivbarhet",
    "beskrivbarhets": "beskrivbarhet",
    "beskrivbars": "beskrivbar",
    "beskrivbart": "beskrivbar",
    "beskrivbarts": "beskrivbar",
    "beskrive": "beskriva",
    "beskriven": "beskriva",
    "beskrivens": "beskriva",
    "beskriver": "beskriva",
    "beskrives": "beskriva",
    "beskrivet": "beskriva",
    "beskrivets": "beskriva",
    "beskrivit": "beskriva",
    "beskrivits": "beskriva",
    "beskrivna": "beskriva",
    "beskrivnas": "beskriva",
    "beskrivne": "beskriva",
    "beskrivnes": "beskriva",
    "beskrivningar": "beskrivning",
    "beskrivningarna": "beskrivning",
    "beskrivningarnas": "beskrivning",
    "beskrivningars": "beskrivning",
    "beskrivningen": "beskrivning",
    "beskrivningens": "beskrivning",
    "beskrivnings": "beskrivning",
    "beskrivs": "beskriva",
    "besks": "besk",
    "besksöt": "besksöta",
    "besksötan": "besksöta",
    "besksötans": "besksöta",
    "besksötas": "besksöta",
    "besksöte": "besksöta",
    "besksötor": "besksöta",
    "besksötorna": "besksöta",
    "besksötornas": "besksöta",
    "besksötors": "besksöta",
    "besksöts": "besksöta",
    "beskt": "besk",
    "beskts": "besk",
    "beskugg": "beskugga",
    "beskuggad": "beskugga",
    "beskuggade": "beskugga",
    "beskuggades": "beskugga",
    "beskuggads": "beskugga",
    "beskuggande": "beskugga",
    "beskugganden": "beskuggande",
    "beskuggandena": "beskuggande",
    "beskuggandenas": "beskuggande",
    "beskuggandens": "beskuggande",
    "beskuggandes": "beskuggande",
    "beskuggandet": "beskuggande",
    "beskuggandets": "beskuggande",
    "beskuggar": "beskugga",
    "beskuggas": "beskugga",
    "beskuggat": "beskugga",
    "beskuggats": "beskugga",
    "beskure": "beskära",
    "beskuren": "beskära",
    "beskurens": "beskära",
    "beskures": "beskära",
    "beskuret": "beskära",
    "beskurets": "beskära",
    "beskurit": "beskära",
    "beskurits": "beskära",
    "beskurna": "beskära",
    "beskurnas": "beskära",
    "beskurne": "beskära",
    "beskurnes": "beskära",
    "beskydd": "beskydda",
    "beskyddad": "beskydda",
    "beskyddade": "beskydda",
    "beskyddades": "beskydda",
    "beskyddads": "beskydda",
    "beskyddande": "beskydda",
    "beskyddanden": "beskyddande",
    "beskyddandena": "beskyddande",
    "beskyddandenas": "beskyddande",
    "beskyddandens": "beskyddande",
    "beskyddandes": "beskyddande",
    "beskyddandet": "beskyddande",
    "beskyddandets": "beskyddande",
    "beskyddar": "beskyddare",
    "beskyddaren": "beskyddare",
    "beskyddarens": "beskyddare",
    "beskyddares": "beskyddare",
    "beskyddarna": "beskyddare",
    "beskyddarnas": "beskyddare",
    "beskyddas": "beskydda",
    "beskyddat": "beskydda",
    "beskyddats": "beskydda",
    "beskyddet": "beskydd",
    "beskyddets": "beskydd",
    "beskydds": "beskydd",
    "beskyll": "beskylla",
    "beskyllande": "beskylla",
    "beskyllanden": "beskyllande",
    "beskyllandena": "beskyllande",
    "beskyllandenas": "beskyllande",
    "beskyllandens": "beskyllande",
    "beskyllandes": "beskyllande",
    "beskyllandet": "beskyllande",
    "beskyllandets": "beskyllande",
    "beskyllas": "beskylla",
    "beskylld": "beskylla",
    "beskyllda": "beskylla",
    "beskylldas": "beskylla",
    "beskyllde": "beskylla",
    "beskylldes": "beskylla",
    "beskyllds": "beskylla",
    "beskyller": "beskylla",
    "beskylles": "beskylla",
    "beskyllningar": "beskyllning",
    "beskyllningarna": "beskyllning",
    "beskyllningarnas": "beskyllning",
    "beskyllningars": "beskyllning",
    "beskyllningen": "beskyllning",
    "beskyllningens": "beskyllning",
    "beskyllnings": "beskyllning",
    "beskylls": "beskylla",
    "beskyllt": "beskylla",
    "beskyllts": "beskylla",
    "beskäftiga": "beskäftig",
    "beskäftigare": "beskäftig",
    "beskäftigares": "beskäftig",
    "beskäftigas": "beskäftig",
    "beskäftigast": "beskäftig",
    "beskäftigaste": "beskäftig",
    "beskäftigastes": "beskäftig",
    "beskäftigasts": "beskäftig",
    "beskäftige": "beskäftig",
    "beskäftiges": "beskäftig",
    "beskäftigheten": "beskäftighet",
    "beskäftighetens": "beskäftighet",
    "beskäftigheter": "beskäftighet",
    "beskäftigheterna": "beskäftighet",
    "beskäftigheternas": "beskäftighet",
    "beskäftigheters": "beskäftighet",
    "beskäftighets": "beskäftighet",
    "beskäftigs": "beskäftig",
    "beskäftigt": "beskäftig",
    "beskäftigts": "beskäftig",
    "beskällar": "beskällare",
    "beskällaren": "beskällare",
    "beskällarens": "beskällare",
    "beskällares": "beskällare",
    "beskällaresjukan": "beskällaresjuka",
    "beskällaresjukans": "beskällaresjuka",
    "beskällaresjukas": "beskällaresjuka",
    "beskällaresjuke": "beskällaresjuka",
    "beskällaresjuks": "beskällaresjuka",
    "beskällarna": "beskällare",
    "beskällarnas": "beskällare",
    "beskällarsjukan": "beskällarsjuka",
    "beskällarsjukans": "beskällarsjuka",
    "beskällarsjukas": "beskällarsjuka",
    "beskällarsjuke": "beskällarsjuka",
    "beskällarsjuks": "beskällarsjuka",
    "beskänkta": "beskänkt",
    "beskänktare": "beskänkt",
    "beskänktares": "beskänkt",
    "beskänktas": "beskänkt",
    "beskänktast": "beskänkt",
    "beskänktaste": "beskänkt",
    "beskänktastes": "beskänkt",
    "beskänktasts": "beskänkt",
    "beskänkte": "beskänkt",
    "beskänktes": "beskänkt",
    "beskänkts": "beskänkt",
    "beskär": "beskära",
    "beskärande": "beskära",
    "beskäranden": "beskärande",
    "beskärandena": "beskärande",
    "beskärandenas": "beskärande",
    "beskärandens": "beskärande",
    "beskärandes": "beskärande",
    "beskärandet": "beskärande",
    "beskärandets": "beskärande",
    "beskäras": "beskära",
    "beskärd": "beskära",
    "beskärda": "beskärd",
    "beskärdare": "beskärd",
    "beskärdares": "beskärd",
    "beskärdas": "beskärd",
    "beskärdast": "beskärd",
    "beskärdaste": "beskärd",
    "beskärdastes": "beskärd",
    "beskärdasts": "beskärd",
    "beskärde": "beskärd",
    "beskärdes": "beskärd",
    "beskärds": "beskärd",
    "beskäre": "beskära",
    "beskäres": "beskära",
    "beskärm": "beskärma",
    "beskärmad": "beskärma",
    "beskärmade": "beskärma",
    "beskärmades": "beskärma",
    "beskärmads": "beskärma",
    "beskärmande": "beskärma",
    "beskärmanden": "beskärmande",
    "beskärmandena": "beskärmande",
    "beskärmandenas": "beskärmande",
    "beskärmandens": "beskärmande",
    "beskärmandes": "beskärmande",
    "beskärmandet": "beskärmande",
    "beskärmandets": "beskärmande",
    "beskärmar": "beskärma",
    "beskärmas": "beskärma",
    "beskärmat": "beskärma",
    "beskärmats": "beskärma",
    "beskärmelsen": "beskärmelse",
    "beskärmelsens": "beskärmelse",
    "beskärmelser": "beskärmelse",
    "beskärmelserna": "beskärmelse",
    "beskärmelsernas": "beskärmelse",
    "beskärmelsers": "beskärmelse",
    "beskärmelses": "beskärmelse",
    "beskärmet": "beskärm",
    "beskärmets": "beskärm",
    "beskärms": "beskärm",
    "beskärningar": "beskärning",
    "beskärningarna": "beskärning",
    "beskärningarnas": "beskärning",
    "beskärningars": "beskärning",
    "beskärningen": "beskärning",
    "beskärningens": "beskärning",
    "beskärnings": "beskärning",
    "beskärs": "beskära",
    "beskärt": "beskärd",
    "beskärts": "beskärd",
    "beskåd": "beskåda",
    "beskådad": "beskåda",
    "beskådade": "beskåda",
    "beskådades": "beskåda",
    "beskådads": "beskåda",
    "beskådande": "beskåda",
    "beskådandes": "beskådande",
    "beskådandet": "beskådande",
    "beskådandets": "beskådande",
    "beskådans": "beskådan",
    "beskådar": "beskåda",
    "beskådas": "beskåda",
    "beskådat": "beskåda",
    "beskådats": "beskåda",
    "besköt": "beskjuta",
    "besköte": "beskjuta",
    "beskötes": "beskjuta",
    "besköts": "beskjuta",
    "beslagar": "beslagare",
    "beslagaren": "beslagare",
    "beslagarens": "beslagare",
    "beslagares": "beslagare",
    "beslagarna": "beslagare",
    "beslagarnas": "beslagare",
    "beslagen": "beslag",
    "beslagens": "beslag",
    "beslaget": "beslag",
    "beslagets": "beslag",
    "beslagit": "beslå",
    "beslagits": "beslå",
    "beslagla": "beslaglägga",
    "beslaglade": "beslaglägga",
    "beslaglades": "beslaglägga",
    "beslaglagd": "beslaglägga",
    "beslaglagda": "beslaglägga",
    "beslaglagdas": "beslaglägga",
    "beslaglagde": "beslaglägga",
    "beslaglagdes": "beslaglägga",
    "beslaglagds": "beslaglägga",
    "beslaglagt": "beslaglägga",
    "beslaglagts": "beslaglägga",
    "beslaglas": "beslaglägga",
    "beslaglägg": "beslaglägga",
    "beslagläggande": "beslaglägga",
    "beslaglägganden": "beslagläggande",
    "beslagläggandena": "beslagläggande",
    "beslagläggandenas": "beslagläggande",
    "beslagläggandens": "beslagläggande",
    "beslagläggandes": "beslagläggande",
    "beslagläggandet": "beslagläggande",
    "beslagläggandets": "beslagläggande",
    "beslagläggas": "beslaglägga",
    "beslaglägger": "beslaglägga",
    "beslaglägges": "beslaglägga",
    "beslagläggs": "beslaglägga",
    "beslagna": "beslå",
    "beslagnas": "beslå",
    "beslagne": "beslå",
    "beslagnes": "beslå",
    "beslags": "beslag",
    "beslagsbanden": "beslagsband",
    "beslagsbandens": "beslagsband",
    "beslagsbandet": "beslagsband",
    "beslagsbandets": "beslagsband",
    "beslagsbands": "beslagsband",
    "beslagsrätten": "beslagsrätt",
    "beslagsrättens": "beslagsrätt",
    "beslagsrätts": "beslagsrätt",
    "beslagssmeden": "beslagssmed",
    "beslagssmedens": "beslagssmed",
    "beslagssmeder": "beslagssmed",
    "beslagssmederna": "beslagssmed",
    "beslagssmedernas": "beslagssmed",
    "beslagssmeders": "beslagssmed",
    "beslagssmeds": "beslagssmed",
    "beslagssmiden": "beslagssmide",
    "beslagssmidena": "beslagssmide",
    "beslagssmidenas": "beslagssmide",
    "beslagssmidens": "beslagssmide",
    "beslagssmides": "beslagssmide",
    "beslagssmidet": "beslagssmide",
    "beslagssmidets": "beslagssmide",
    "beslagtag": "beslagta",
    "beslagtaga": "beslagta",
    "beslagtagande": "beslagta",
    "beslagtaganden": "beslagtagande",
    "beslagtagandena": "beslagtagande",
    "beslagtagandenas": "beslagtagande",
    "beslagtagandens": "beslagtagande",
    "beslagtagandes": "beslagtagande",
    "beslagtagandet": "beslagtagande",
    "beslagtagandets": "beslagtagande",
    "beslagtagas": "beslagta",
    "beslagtage": "beslagta",
    "beslagtagen": "beslagta",
    "beslagtagens": "beslagta",
    "beslagtager": "beslagta",
    "beslagtages": "beslagta",
    "beslagtaget": "beslagta",
    "beslagtagets": "beslagta",
    "beslagtagit": "beslagta",
    "beslagtagits": "beslagta",
    "beslagtagna": "beslagta",
    "beslagtagnas": "beslagta",
    "beslagtagne": "beslagta",
    "beslagtagnes": "beslagta",
    "beslagtags": "beslagta",
    "beslagtar": "beslagta",
    "beslagtas": "beslagta",
    "beslagtog": "beslagta",
    "beslagtoge": "beslagta",
    "beslagtoges": "beslagta",
    "beslagtogs": "beslagta",
    "beslog": "beslå",
    "besloge": "beslå",
    "besloges": "beslå",
    "beslogs": "beslå",
    "beslut": "besluta",
    "beslutad": "besluta",
    "beslutade": "besluta",
    "beslutades": "besluta",
    "beslutads": "besluta",
    "beslutande": "besluta",
    "beslutanden": "beslutande",
    "beslutandena": "beslutande",
    "beslutandenas": "beslutande",
    "beslutandens": "beslutande",
    "beslutanderätten": "beslutanderätt",
    "beslutanderättens": "beslutanderätt",
    "beslutanderätts": "beslutanderätt",
    "beslutandes": "beslutande",
    "beslutandet": "beslutande",
    "beslutandets": "beslutande",
    "beslutar": "besluta",
    "beslutas": "besluta",
    "beslutat": "besluta",
    "beslutats": "besluta",
    "beslute": "besluta",
    "besluten": "besluta",
    "beslutenheten": "beslutenhet",
    "beslutenhetens": "beslutenhet",
    "beslutenhets": "beslutenhet",
    "beslutenliga": "beslutenlig",
    "beslutenligare": "beslutenlig",
    "beslutenligares": "beslutenlig",
    "beslutenligas": "beslutenlig",
    "beslutenligast": "beslutenlig",
    "beslutenligaste": "beslutenlig",
    "beslutenligastes": "beslutenlig",
    "beslutenligasts": "beslutenlig",
    "beslutenlige": "beslutenlig",
    "beslutenliges": "beslutenlig",
    "beslutenligheten": "beslutenlighet",
    "beslutenlighetens": "beslutenlighet",
    "beslutenlighets": "beslutenlighet",
    "beslutenligs": "beslutenlig",
    "beslutenligt": "beslutenlig",
    "beslutenligts": "beslutenlig",
    "beslutens": "besluten",
    "beslutes": "besluta",
    "beslutet": "besluten",
    "beslutets": "besluten",
    "beslutfattandes": "beslutfattande",
    "beslutfattandet": "beslutfattande",
    "beslutfattandets": "beslutfattande",
    "beslutfattar": "beslutfattare",
    "beslutfattaren": "beslutfattare",
    "beslutfattarens": "beslutfattare",
    "beslutfattares": "beslutfattare",
    "beslutfattarna": "beslutfattare",
    "beslutfattarnas": "beslutfattare",
    "beslutföra": "beslutför",
    "beslutförare": "beslutför",
    "beslutförares": "beslutför",
    "beslutföras": "beslutför",
    "beslutförast": "beslutför",
    "beslutföraste": "beslutför",
    "beslutförastes": "beslutför",
    "beslutförasts": "beslutför",
    "beslutföre": "beslutför",
    "beslutföres": "beslutför",
    "beslutförheten": "beslutförhet",
    "beslutförhetens": "beslutförhet",
    "beslutförhets": "beslutförhet",
    "beslutförs": "beslutför",
    "beslutfört": "beslutför",
    "beslutförts": "beslutför",
    "beslutit": "besluta",
    "beslutits": "besluta",
    "beslutmässiga": "beslutmässig",
    "beslutmässigare": "beslutmässig",
    "beslutmässigares": "beslutmässig",
    "beslutmässigas": "beslutmässig",
    "beslutmässigast": "beslutmässig",
    "beslutmässigaste": "beslutmässig",
    "beslutmässigastes": "beslutmässig",
    "beslutmässigasts": "beslutmässig",
    "beslutmässige": "beslutmässig",
    "beslutmässiges": "beslutmässig",
    "beslutmässigheten": "beslutmässighet",
    "beslutmässighetens": "beslutmässighet",
    "beslutmässighets": "beslutmässighet",
    "beslutmässigs": "beslutmässig",
    "beslutmässigt": "beslutmässig",
    "beslutmässigts": "beslutmässig",
    "beslutna": "besluten",
    "beslutnare": "besluten",
    "beslutnares": "besluten",
    "beslutnas": "besluten",
    "beslutnast": "besluten",
    "beslutnaste": "besluten",
    "beslutnastes": "besluten",
    "beslutnasts": "besluten",
    "beslutne": "besluten",
    "beslutnes": "besluten",
    "beslutnivåer": "beslutnivå",
    "beslutnivåerna": "beslutnivå",
    "beslutnivåernas": "beslutnivå",
    "beslutnivåers": "beslutnivå",
    "beslutnivån": "beslutnivå",
    "beslutnivåns": "beslutnivå",
    "beslutnivås": "beslutnivå",
    "besluts": "beslut",
    "beslutsamheten": "beslutsamhet",
    "beslutsamhetens": "beslutsamhet",
    "beslutsamheter": "beslutsamhet",
    "beslutsamheterna": "beslutsamhet",
    "beslutsamheternas": "beslutsamhet",
    "beslutsamheters": "beslutsamhet",
    "beslutsamhets": "beslutsamhet",
    "beslutsamma": "beslutsam",
    "beslutsammare": "beslutsam",
    "beslutsammares": "beslutsam",
    "beslutsammas": "beslutsam",
    "beslutsammast": "beslutsam",
    "beslutsammaste": "beslutsam",
    "beslutsammastes": "beslutsam",
    "beslutsammasts": "beslutsam",
    "beslutsamme": "beslutsam",
    "beslutsammes": "beslutsam",
    "beslutsams": "beslutsam",
    "beslutsamt": "beslutsam",
    "beslutsamts": "beslutsam",
    "beslutsenliga": "beslutsenlig",
    "beslutsenligare": "beslutsenlig",
    "beslutsenligares": "beslutsenlig",
    "beslutsenligas": "beslutsenlig",
    "beslutsenligast": "beslutsenlig",
    "beslutsenligaste": "beslutsenlig",
    "beslutsenligastes": "beslutsenlig",
    "beslutsenligasts": "beslutsenlig",
    "beslutsenlige": "beslutsenlig",
    "beslutsenliges": "beslutsenlig",
    "beslutsenligheten": "beslutsenlighet",
    "beslutsenlighetens": "beslutsenlighet",
    "beslutsenlighets": "beslutsenlighet",
    "beslutsenligs": "beslutsenlig",
    "beslutsenligt": "beslutsenlig",
    "beslutsenligts": "beslutsenlig",
    "beslutsfattandes": "beslutsfattande",
    "beslutsfattandet": "beslutsfattande",
    "beslutsfattandets": "beslutsfattande",
    "beslutsfattar": "beslutsfattare",
    "beslutsfattaren": "beslutsfattare",
    "beslutsfattarens": "beslutsfattare",
    "beslutsfattares": "beslutsfattare",
    "beslutsfattarna": "beslutsfattare",
    "beslutsfattarnas": "beslutsfattare",
    "beslutsföra": "beslutsför",
    "beslutsförare": "beslutsför",
    "beslutsförares": "beslutsför",
    "beslutsföras": "beslutsför",
    "beslutsförast": "beslutsför",
    "beslutsföraste": "beslutsför",
    "beslutsförastes": "beslutsför",
    "beslutsförasts": "beslutsför",
    "beslutsföre": "beslutsför",
    "beslutsföres": "beslutsför",
    "beslutsförheten": "beslutsförhet",
    "beslutsförhetens": "beslutsförhet",
    "beslutsförhets": "beslutsförhet",
    "beslutsförs": "beslutsför",
    "beslutsfört": "beslutsför",
    "beslutsförts": "beslutsför",
    "beslutshierarkien": "beslutshierarki",
    "beslutshierarkiens": "beslutshierarki",
    "beslutshierarkier": "beslutshierarki",
    "beslutshierarkierna": "beslutshierarki",
    "beslutshierarkiernas": "beslutshierarki",
    "beslutshierarkiers": "beslutshierarki",
    "beslutshierarkin": "beslutshierarki",
    "beslutshierarkins": "beslutshierarki",
    "beslutshierarkis": "beslutshierarki",
    "beslutskapabels": "beslutskapabel",
    "beslutskapabelt": "beslutskapabel",
    "beslutskapabelts": "beslutskapabel",
    "beslutskapabla": "beslutskapabel",
    "beslutskapablare": "beslutskapabel",
    "beslutskapablares": "beslutskapabel",
    "beslutskapablas": "beslutskapabel",
    "beslutskapablast": "beslutskapabel",
    "beslutskapablaste": "beslutskapabel",
    "beslutskapablastes": "beslutskapabel",
    "beslutskapablasts": "beslutskapabel",
    "beslutskapable": "beslutskapabel",
    "beslutskapables": "beslutskapabel",
    "beslutskorridoren": "beslutskorridor",
    "beslutskorridorens": "beslutskorridor",
    "beslutskorridorer": "beslutskorridor",
    "beslutskorridorerna": "beslutskorridor",
    "beslutskorridorernas": "beslutskorridor",
    "beslutskorridorers": "beslutskorridor",
    "beslutskorridors": "beslutskorridor",
    "beslutsmässiga": "beslutsmässig",
    "beslutsmässigare": "beslutsmässig",
    "beslutsmässigares": "beslutsmässig",
    "beslutsmässigas": "beslutsmässig",
    "beslutsmässigast": "beslutsmässig",
    "beslutsmässigaste": "beslutsmässig",
    "beslutsmässigastes": "beslutsmässig",
    "beslutsmässigasts": "beslutsmässig",
    "beslutsmässige": "beslutsmässig",
    "beslutsmässiges": "beslutsmässig",
    "beslutsmässigheten": "beslutsmässighet",
    "beslutsmässighetens": "beslutsmässighet",
    "beslutsmässighets": "beslutsmässighet",
    "beslutsmässigs": "beslutsmässig",
    "beslutsmässigt": "beslutsmässig",
    "beslutsmässigts": "beslutsmässig",
    "beslutsnivåer": "beslutsnivå",
    "beslutsnivåerna": "beslutsnivå",
    "beslutsnivåernas": "beslutsnivå",
    "beslutsnivåers": "beslutsnivå",
    "beslutsnivån": "beslutsnivå",
    "beslutsnivåns": "beslutsnivå",
    "beslutsnivås": "beslutsnivå",
    "beslutsprocessen": "beslutsprocess",
    "beslutsprocessens": "beslutsprocess",
    "beslutsprocesser": "beslutsprocess",
    "beslutsprocesserna": "beslutsprocess",
    "beslutsprocessernas": "beslutsprocess",
    "beslutsprocessers": "beslutsprocess",
    "beslutsrummen": "beslutsrum",
    "beslutsrummens": "beslutsrum",
    "beslutsrummet": "beslutsrum",
    "beslutsrummets": "beslutsrum",
    "beslutsrums": "beslutsrum",
    "beslutsrymden": "beslutsrymd",
    "beslutsrymdens": "beslutsrymd",
    "beslutsrymder": "beslutsrymd",
    "beslutsrymderna": "beslutsrymd",
    "beslutsrymdernas": "beslutsrymd",
    "beslutsrymders": "beslutsrymd",
    "beslutsrymds": "beslutsrymd",
    "beslutsunderlagen": "beslutsunderlag",
    "beslutsunderlagens": "beslutsunderlag",
    "beslutsunderlaget": "beslutsunderlag",
    "beslutsunderlagets": "beslutsunderlag",
    "beslutsunderlags": "beslutsunderlag",
    "beslutsångesten": "beslutsångest",
    "beslutsångestens": "beslutsångest",
    "beslutsångests": "beslutsångest",
    "besläktade": "besläktad",
    "besläktades": "besläktad",
    "besläktads": "besläktad",
    "besläktat": "besläktad",
    "besläktats": "besläktad",
    "beslående": "beslå",
    "beslåenden": "beslående",
    "beslåendena": "beslående",
    "beslåendenas": "beslående",
    "beslåendens": "beslående",
    "beslåendes": "beslående",
    "beslåendet": "beslående",
    "beslåendets": "beslående",
    "beslår": "beslå",
    "beslås": "beslå",
    "beslöj": "beslöja",
    "beslöjad": "beslöja",
    "beslöjade": "beslöjad",
    "beslöjades": "beslöjad",
    "beslöjads": "beslöjad",
    "beslöjande": "beslöja",
    "beslöjanden": "beslöjande",
    "beslöjandena": "beslöjande",
    "beslöjandenas": "beslöjande",
    "beslöjandens": "beslöjande",
    "beslöjandes": "beslöjande",
    "beslöjandet": "beslöjande",
    "beslöjandets": "beslöjande",
    "beslöjar": "beslöja",
    "beslöjas": "beslöja",
    "beslöjat": "beslöjad",
    "beslöjats": "beslöjad",
    "beslöt": "besluta",
    "beslöte": "besluta",
    "beslötes": "besluta",
    "beslöts": "besluta",
    "besmanen": "besman",
    "besmanens": "besman",
    "besmanet": "besman",
    "besmanets": "besman",
    "besmans": "besman",
    "besmanskrokar": "besmanskrok",
    "besmanskrokarna": "besmanskrok",
    "besmanskrokarnas": "besmanskrok",
    "besmanskrokars": "besmanskrok",
    "besmanskroken": "besmanskrok",
    "besmanskrokens": "besmanskrok",
    "besmanskroks": "besmanskrok",
    "besmitt": "besmitta",
    "besmittad": "besmitta",
    "besmittade": "besmitta",
    "besmittades": "besmitta",
    "besmittads": "besmitta",
    "besmittande": "besmitta",
    "besmittanden": "besmittande",
    "besmittandena": "besmittande",
    "besmittandenas": "besmittande",
    "besmittandens": "besmittande",
    "besmittandes": "besmittande",
    "besmittandet": "besmittande",
    "besmittandets": "besmittande",
    "besmittar": "besmitta",
    "besmittas": "besmitta",
    "besmittat": "besmitta",
    "besmittats": "besmitta",
    "besmittelsen": "besmittelse",
    "besmittelsens": "besmittelse",
    "besmittelser": "besmittelse",
    "besmittelserna": "besmittelse",
    "besmittelsernas": "besmittelse",
    "besmittelsers": "besmittelse",
    "besmittelses": "besmittelse",
    "besmord": "besmörja",
    "besmorda": "besmörja",
    "besmordas": "besmörja",
    "besmorde": "besmörja",
    "besmordes": "besmörja",
    "besmords": "besmörja",
    "besmort": "besmörja",
    "besmorts": "besmörja",
    "besmörj": "besmörja",
    "besmörjande": "besmörja",
    "besmörjanden": "besmörjande",
    "besmörjandena": "besmörjande",
    "besmörjandenas": "besmörjande",
    "besmörjandens": "besmörjande",
    "besmörjandes": "besmörjande",
    "besmörjandet": "besmörjande",
    "besmörjandets": "besmörjande",
    "besmörjas": "besmörja",
    "besmörjer": "besmörja",
    "besmörjes": "besmörja",
    "besmörjs": "besmörja",
    "besockrad": "besockra",
    "besockrade": "besockra",
    "besockrades": "besockra",
    "besockrads": "besockra",
    "besockrande": "besockra",
    "besockranden": "besockrande",
    "besockrandena": "besockrande",
    "besockrandenas": "besockrande",
    "besockrandens": "besockrande",
    "besockrandes": "besockrande",
    "besockrandet": "besockrande",
    "besockrandets": "besockrande",
    "besockrar": "besockra",
    "besockras": "besockra",
    "besockrat": "besockra",
    "besockrats": "besockra",
    "besold": "besolda",
    "besoldad": "besolda",
    "besoldade": "besolda",
    "besoldades": "besolda",
    "besoldads": "besolda",
    "besoldande": "besolda",
    "besoldanden": "besoldande",
    "besoldandena": "besoldande",
    "besoldandenas": "besoldande",
    "besoldandens": "besoldande",
    "besoldandes": "besoldande",
    "besoldandet": "besoldande",
    "besoldandets": "besoldande",
    "besoldar": "besolda",
    "besoldas": "besolda",
    "besoldat": "besolda",
    "besoldats": "besolda",
    "bespar": "bespara",
    "besparad": "bespara",
    "besparade": "bespara",
    "besparades": "bespara",
    "besparads": "bespara",
    "besparande": "bespara",
    "besparanden": "besparande",
    "besparandena": "besparande",
    "besparandenas": "besparande",
    "besparandens": "besparande",
    "besparandes": "besparande",
    "besparandet": "besparande",
    "besparandets": "besparande",
    "besparar": "bespara",
    "besparas": "bespara",
    "besparat": "bespara",
    "besparats": "bespara",
    "besparingar": "besparing",
    "besparingarna": "besparing",
    "besparingarnas": "besparing",
    "besparingars": "besparing",
    "besparingen": "besparing",
    "besparingens": "besparing",
    "besparings": "besparing",
    "besparingskraven": "besparingskrav",
    "besparingskravens": "besparingskrav",
    "besparingskravet": "besparingskrav",
    "besparingskravets": "besparingskrav",
    "besparingskravs": "besparingskrav",
    "besparingsskogar": "besparingsskog",
    "besparingsskogarna": "besparingsskog",
    "besparingsskogarnas": "besparingsskog",
    "besparingsskogars": "besparingsskog",
    "besparingsskogen": "besparingsskog",
    "besparingsskogens": "besparingsskog",
    "besparingsskogs": "besparingsskog",
    "bespars": "bespara",
    "bespej": "bespeja",
    "bespejad": "bespeja",
    "bespejade": "bespeja",
    "bespejades": "bespeja",
    "bespejads": "bespeja",
    "bespejande": "bespeja",
    "bespejanden": "bespejande",
    "bespejandena": "bespejande",
    "bespejandenas": "bespejande",
    "bespejandens": "bespejande",
    "bespejandes": "bespejande",
    "bespejandet": "bespejande",
    "bespejandets": "bespejande",
    "bespejar": "bespeja",
    "bespejas": "bespeja",
    "bespejat": "bespeja",
    "bespejats": "bespeja",
    "bespis": "bespisa",
    "bespisad": "bespisa",
    "bespisade": "bespisa",
    "bespisades": "bespisa",
    "bespisads": "bespisa",
    "bespisande": "bespisa",
    "bespisanden": "bespisande",
    "bespisandena": "bespisande",
    "bespisandenas": "bespisande",
    "bespisandens": "bespisande",
    "bespisandes": "bespisande",
    "bespisandet": "bespisande",
    "bespisandets": "bespisande",
    "bespisar": "bespisa",
    "bespisas": "bespisa",
    "bespisat": "bespisa",
    "bespisats": "bespisa",
    "bespisningar": "bespisning",
    "bespisningarna": "bespisning",
    "bespisningarnas": "bespisning",
    "bespisningars": "bespisning",
    "bespisningen": "bespisning",
    "bespisningens": "bespisning",
    "bespisnings": "bespisning",
    "bespolad": "bespola",
    "bespolade": "bespola",
    "bespolades": "bespola",
    "bespolads": "bespola",
    "bespolande": "bespola",
    "bespolanden": "bespolande",
    "bespolandena": "bespolande",
    "bespolandenas": "bespolande",
    "bespolandens": "bespolande",
    "bespolandes": "bespolande",
    "bespolandet": "bespolande",
    "bespolandets": "bespolande",
    "bespolar": "bespola",
    "bespolas": "bespola",
    "bespolat": "bespola",
    "bespolats": "bespola",
    "bespott": "bespotta",
    "bespottad": "bespotta",
    "bespottade": "bespotta",
    "bespottades": "bespotta",
    "bespottads": "bespotta",
    "bespottande": "bespotta",
    "bespottanden": "bespottande",
    "bespottandena": "bespottande",
    "bespottandenas": "bespottande",
    "bespottandens": "bespottande",
    "bespottandes": "bespottande",
    "bespottandet": "bespottande",
    "bespottandets": "bespottande",
    "bespottar": "bespotta",
    "bespottas": "bespotta",
    "bespottat": "bespotta",
    "bespottats": "bespotta",
    "bespottelsen": "bespottelse",
    "bespottelsens": "bespottelse",
    "bespottelser": "bespottelse",
    "bespottelserna": "bespottelse",
    "bespottelsernas": "bespottelse",
    "bespottelsers": "bespottelse",
    "bespottelses": "bespottelse",
    "besprutad": "bespruta",
    "besprutade": "bespruta",
    "besprutades": "bespruta",
    "besprutads": "bespruta",
    "besprutande": "bespruta",
    "besprutanden": "besprutande",
    "besprutandena": "besprutande",
    "besprutandenas": "besprutande",
    "besprutandens": "besprutande",
    "besprutandes": "besprutande",
    "besprutandet": "besprutande",
    "besprutandets": "besprutande",
    "besprutar": "bespruta",
    "besprutas": "bespruta",
    "besprutat": "bespruta",
    "besprutats": "bespruta",
    "besprutningar": "besprutning",
    "besprutningarna": "besprutning",
    "besprutningarnas": "besprutning",
    "besprutningars": "besprutning",
    "besprutningen": "besprutning",
    "besprutningens": "besprutning",
    "besprutnings": "besprutning",
    "besprutningsmedels": "besprutningsmedel",
    "besprutningsmedlen": "besprutningsmedel",
    "besprutningsmedlens": "besprutningsmedel",
    "besprutningsmedlet": "besprutningsmedel",
    "besprutningsmedlets": "besprutningsmedel",
    "besprutningsvätskan": "besprutningsvätska",
    "besprutningsvätskans": "besprutningsvätska",
    "besprutningsvätskas": "besprutningsvätska",
    "besprutningsvätske": "besprutningsvätska",
    "besprutningsvätskor": "besprutningsvätska",
    "besprutningsvätskorna": "besprutningsvätska",
    "besprutningsvätskornas": "besprutningsvätska",
    "besprutningsvätskors": "besprutningsvätska",
    "bessemerblåsningar": "bessemerblåsning",
    "bessemerblåsningarna": "bessemerblåsning",
    "bessemerblåsningarnas": "bessemerblåsning",
    "bessemerblåsningars": "bessemerblåsning",
    "bessemerblåsningen": "bessemerblåsning",
    "bessemerblåsningens": "bessemerblåsning",
    "bessemerblåsnings": "bessemerblåsning",
    "bessemermetodens": "bessemermetoden",
    "bessemerprocessens": "bessemerprocessen",
    "bessemerstålen": "bessemerstål",
    "bessemerstålens": "bessemerstål",
    "bessemerstålet": "bessemerstål",
    "bessemerstålets": "bessemerstål",
    "bessemerståls": "bessemerstål",
    "bessemerugnar": "bessemerugn",
    "bessemerugnarna": "bessemerugn",
    "bessemerugnarnas": "bessemerugn",
    "bessemerugnars": "bessemerugn",
    "bessemerugnen": "bessemerugn",
    "bessemerugnens": "bessemerugn",
    "bessemerugns": "bessemerugn",
    "besservissern": "besservisser",
    "besservisserna": "besservisser",
    "besservissernas": "besservisser",
    "besservisserns": "besservisser",
    "besservissers": "besservisser",
    "besservissrar": "besservisser",
    "besservissrarna": "besservisser",
    "besservissrarnas": "besservisser",
    "besservissrars": "besservisser",
    "besserwisserattityden": "besserwisserattityd",
    "besserwisserattitydens": "besserwisserattityd",
    "besserwisserattityder": "besserwisserattityd",
    "besserwisserattityderna": "besserwisserattityd",
    "besserwisserattitydernas": "besserwisserattityd",
    "besserwisserattityders": "besserwisserattityd",
    "besserwisserattityds": "besserwisserattityd",
    "besserwissern": "besserwisser",
    "besserwisserna": "besserwisser",
    "besserwissernas": "besserwisser",
    "besserwisserns": "besserwisser",
    "besserwissers": "besserwisser",
    "besserwissrar": "besserwisser",
    "besserwissrarna": "besserwisser",
    "besserwissrarnas": "besserwisser",
    "besserwissrars": "besserwisser",
    "bestack": "besticka",
    "bestacks": "besticka",
    "bestal": "bestjäla",
    "bestals": "bestjäla",
    "bestar": "best",
    "bestarna": "best",
    "bestarnas": "best",
    "bestars": "best",
    "besteg": "bestiga",
    "bestegs": "bestiga",
    "besten": "best",
    "bestens": "best",
    "bestialiska": "bestialisk",
    "bestialiskare": "bestialisk",
    "bestialiskares": "bestialisk",
    "bestialiskas": "bestialisk",
    "bestialiskast": "bestialisk",
    "bestialiskaste": "bestialisk",
    "bestialiskastes": "bestialisk",
    "bestialiskasts": "bestialisk",
    "bestialiske": "bestialisk",
    "bestialiskes": "bestialisk",
    "bestialisks": "bestialisk",
    "bestialiskt": "bestialisk",
    "bestialiskts": "bestialisk",
    "bestick": "besticka",
    "bestickande": "besticka",
    "bestickanden": "bestickande",
    "bestickandena": "bestickande",
    "bestickandenas": "bestickande",
    "bestickandens": "bestickande",
    "bestickandes": "bestickande",
    "bestickandet": "bestickande",
    "bestickandets": "bestickande",
    "bestickas": "besticka",
    "besticke": "besticka",
    "besticken": "bestick",
    "bestickens": "bestick",
    "besticker": "besticka",
    "bestickes": "besticka",
    "besticket": "bestick",
    "bestickets": "bestick",
    "bestickföringar": "bestickföring",
    "bestickföringarna": "bestickföring",
    "bestickföringarnas": "bestickföring",
    "bestickföringars": "bestickföring",
    "bestickföringen": "bestickföring",
    "bestickföringens": "bestickföring",
    "bestickförings": "bestickföring",
    "bestickliga": "besticklig",
    "bestickligare": "besticklig",
    "bestickligares": "besticklig",
    "bestickligas": "besticklig",
    "bestickligast": "besticklig",
    "bestickligaste": "besticklig",
    "bestickligastes": "besticklig",
    "bestickligasts": "besticklig",
    "besticklige": "besticklig",
    "bestickliges": "besticklig",
    "bestickligheten": "besticklighet",
    "besticklighetens": "besticklighet",
    "besticklighets": "besticklighet",
    "bestickligs": "besticklig",
    "bestickligt": "besticklig",
    "bestickligts": "besticklig",
    "bestickningar": "bestickning",
    "bestickningarna": "bestickning",
    "bestickningarnas": "bestickning",
    "bestickningars": "bestickning",
    "bestickningen": "bestickning",
    "bestickningens": "bestickning",
    "besticknings": "bestickning",
    "besticks": "besticka",
    "bestig": "bestiga",
    "bestigande": "bestiga",
    "bestiganden": "bestigande",
    "bestigandena": "bestigande",
    "bestigandenas": "bestigande",
    "bestigandens": "bestigande",
    "bestigandes": "bestigande",
    "bestigandet": "bestigande",
    "bestigandets": "bestigande",
    "bestigas": "bestiga",
    "bestige": "bestiga",
    "bestigen": "bestiga",
    "bestigens": "bestiga",
    "bestiger": "bestiga",
    "bestiges": "bestiga",
    "bestiget": "bestiga",
    "bestigets": "bestiga",
    "bestigit": "bestiga",
    "bestigits": "bestiga",
    "bestigna": "bestiga",
    "bestignas": "bestiga",
    "bestigne": "bestiga",
    "bestignes": "bestiga",
    "bestigningar": "bestigning",
    "bestigningarna": "bestigning",
    "bestigningarnas": "bestigning",
    "bestigningars": "bestigning",
    "bestigningen": "bestigning",
    "bestigningens": "bestigning",
    "bestignings": "bestigning",
    "bestigs": "bestiga",
    "bestjäl": "bestjäla",
    "bestjälande": "bestjäla",
    "bestjälanden": "bestjälande",
    "bestjälandena": "bestjälande",
    "bestjälandenas": "bestjälande",
    "bestjälandens": "bestjälande",
    "bestjälandes": "bestjälande",
    "bestjälandet": "bestjälande",
    "bestjälandets": "bestjälande",
    "bestjälas": "bestjäla",
    "bestjäle": "bestjäla",
    "bestjäles": "bestjäla",
    "bestjäls": "bestjäla",
    "bestod": "bestå",
    "bestode": "bestå",
    "bestodes": "bestå",
    "bestods": "bestå",
    "bestorm": "bestorma",
    "bestormad": "bestorma",
    "bestormade": "bestorma",
    "bestormades": "bestorma",
    "bestormads": "bestorma",
    "bestormande": "bestorma",
    "bestormanden": "bestormande",
    "bestormandena": "bestormande",
    "bestormandenas": "bestormande",
    "bestormandens": "bestormande",
    "bestormandes": "bestormande",
    "bestormandet": "bestormande",
    "bestormandets": "bestormande",
    "bestormar": "bestorma",
    "bestormas": "bestorma",
    "bestormat": "bestorma",
    "bestormats": "bestorma",
    "bestraff": "bestraffa",
    "bestraffad": "bestraffa",
    "bestraffade": "bestraffa",
    "bestraffades": "bestraffa",
    "bestraffads": "bestraffa",
    "bestraffande": "bestraffa",
    "bestraffanden": "bestraffande",
    "bestraffandena": "bestraffande",
    "bestraffandenas": "bestraffande",
    "bestraffandens": "bestraffande",
    "bestraffandes": "bestraffande",
    "bestraffandet": "bestraffande",
    "bestraffandets": "bestraffande",
    "bestraffar": "bestraffa",
    "bestraffas": "bestraffa",
    "bestraffat": "bestraffa",
    "bestraffats": "bestraffa",
    "bestraffningar": "bestraffning",
    "bestraffningarna": "bestraffning",
    "bestraffningarnas": "bestraffning",
    "bestraffningars": "bestraffning",
    "bestraffningen": "bestraffning",
    "bestraffningens": "bestraffning",
    "bestraffnings": "bestraffning",
    "bestred": "bestrida",
    "bestrede": "bestrida",
    "bestredes": "bestrida",
    "bestreds": "bestrida",
    "bestrid": "bestrida",
    "bestridande": "bestrida",
    "bestridanden": "bestridande",
    "bestridandena": "bestridande",
    "bestridandenas": "bestridande",
    "bestridandens": "bestridande",
    "bestridandes": "bestridande",
    "bestridandet": "bestridande",
    "bestridandets": "bestridande",
    "bestridas": "bestrida",
    "bestridd": "bestrida",
    "bestridda": "bestrida",
    "bestriddas": "bestrida",
    "bestridde": "bestrida",
    "bestriddes": "bestrida",
    "bestridds": "bestrida",
    "bestride": "bestrida",
    "bestriden": "bestrida",
    "bestridens": "bestrida",
    "bestrider": "bestrida",
    "bestrides": "bestrida",
    "bestridet": "bestrida",
    "bestridets": "bestrida",
    "bestridit": "bestrida",
    "bestridits": "bestrida",
    "bestridna": "bestrida",
    "bestridnas": "bestrida",
    "bestridne": "bestrida",
    "bestridnes": "bestrida",
    "bestrids": "bestrida",
    "bestritt": "bestrida",
    "bestritts": "bestrida",
    "bestruken": "bestryka",
    "bestrukens": "bestryka",
    "bestruket": "bestryka",
    "bestrukets": "bestryka",
    "bestrukit": "bestryka",
    "bestrukits": "bestryka",
    "bestrukna": "bestryka",
    "bestruknas": "bestryka",
    "bestrukne": "bestryka",
    "bestruknes": "bestryka",
    "bestryk": "bestryka",
    "bestrykande": "bestryka",
    "bestrykanden": "bestrykande",
    "bestrykandena": "bestrykande",
    "bestrykandenas": "bestrykande",
    "bestrykandens": "bestrykande",
    "bestrykandes": "bestrykande",
    "bestrykandet": "bestrykande",
    "bestrykandets": "bestrykande",
    "bestrykas": "bestryka",
    "bestryke": "bestryka",
    "bestryker": "bestryka",
    "bestrykes": "bestryka",
    "bestrykningar": "bestrykning",
    "bestrykningarna": "bestrykning",
    "bestrykningarnas": "bestrykning",
    "bestrykningars": "bestrykning",
    "bestrykningen": "bestrykning",
    "bestrykningens": "bestrykning",
    "bestryknings": "bestrykning",
    "bestryks": "bestryka",
    "bestrålad": "bestråla",
    "bestrålade": "bestråla",
    "bestrålades": "bestråla",
    "bestrålads": "bestråla",
    "bestrålande": "bestråla",
    "bestrålanden": "bestrålande",
    "bestrålandena": "bestrålande",
    "bestrålandenas": "bestrålande",
    "bestrålandens": "bestrålande",
    "bestrålandes": "bestrålande",
    "bestrålandet": "bestrålande",
    "bestrålandets": "bestrålande",
    "bestrålar": "bestråla",
    "bestrålas": "bestråla",
    "bestrålat": "bestråla",
    "bestrålats": "bestråla",
    "bestrålningar": "bestrålning",
    "bestrålningarna": "bestrålning",
    "bestrålningarnas": "bestrålning",
    "bestrålningars": "bestrålning",
    "bestrålningen": "bestrålning",
    "bestrålningens": "bestrålning",
    "bestrålnings": "bestrålning",
    "beströdd": "beströ",
    "beströdda": "beströ",
    "beströddas": "beströ",
    "beströdde": "beströ",
    "beströddes": "beströ",
    "beströdds": "beströ",
    "beströende": "beströ",
    "beströenden": "beströende",
    "beströendena": "beströende",
    "beströendenas": "beströende",
    "beströendens": "beströende",
    "beströendes": "beströende",
    "beströendet": "beströende",
    "beströendets": "beströende",
    "beströk": "bestryka",
    "beströke": "bestryka",
    "beströkes": "bestryka",
    "beströks": "bestryka",
    "beströr": "beströ",
    "beströs": "beströ",
    "bestrött": "beströ",
    "beströtts": "beströ",
    "bests": "best",
    "bestsellerförfattar": "bestsellerförfattare",
    "bestsellerförfattaren": "bestsellerförfattare",
    "bestsellerförfattarens": "bestsellerförfattare",
    "bestsellerförfattares": "bestsellerförfattare",
    "bestsellerförfattarna": "bestsellerförfattare",
    "bestsellerförfattarnas": "bestsellerförfattare",
    "bestsellern": "bestseller",
    "bestsellerna": "bestseller",
    "bestsellernas": "bestseller",
    "bestsellerns": "bestseller",
    "bestsellers": "bestseller",
    "bestsellrar": "bestseller",
    "bestsellrarna": "bestseller",
    "bestsellrarnas": "bestseller",
    "bestsellrars": "bestseller",
    "bestucke": "besticka",
    "bestucken": "besticka",
    "bestuckens": "besticka",
    "bestuckes": "besticka",
    "bestucket": "besticka",
    "bestuckets": "besticka",
    "bestuckit": "besticka",
    "bestuckits": "besticka",
    "bestuckna": "besticka",
    "bestucknas": "besticka",
    "bestuckne": "besticka",
    "bestucknes": "besticka",
    "bestule": "bestjäla",
    "bestulen": "bestjäla",
    "bestulens": "bestjäla",
    "bestules": "bestjäla",
    "bestulet": "bestjäla",
    "bestulets": "bestjäla",
    "bestulit": "bestjäla",
    "bestulits": "bestjäla",
    "bestulna": "bestjäla",
    "bestulnas": "bestjäla",
    "bestulne": "bestjäla",
    "bestulnes": "bestjäla",
    "bestyck": "bestycka",
    "bestyckad": "bestycka",
    "bestyckade": "bestycka",
    "bestyckades": "bestycka",
    "bestyckads": "bestycka",
    "bestyckande": "bestycka",
    "bestyckanden": "bestyckande",
    "bestyckandena": "bestyckande",
    "bestyckandenas": "bestyckande",
    "bestyckandens": "bestyckande",
    "bestyckandes": "bestyckande",
    "bestyckandet": "bestyckande",
    "bestyckandets": "bestyckande",
    "bestyckar": "bestycka",
    "bestyckas": "bestycka",
    "bestyckat": "bestycka",
    "bestyckats": "bestycka",
    "bestyckningar": "bestyckning",
    "bestyckningarna": "bestyckning",
    "bestyckningarnas": "bestyckning",
    "bestyckningars": "bestyckning",
    "bestyckningen": "bestyckning",
    "bestyckningens": "bestyckning",
    "bestycknings": "bestyckning",
    "bestyr": "bestyra",
    "bestyrande": "bestyra",
    "bestyranden": "bestyrande",
    "bestyrandena": "bestyrande",
    "bestyrandenas": "bestyrande",
    "bestyrandens": "bestyrande",
    "bestyrandes": "bestyrande",
    "bestyrandet": "bestyrande",
    "bestyrandets": "bestyrande",
    "bestyras": "bestyra",
    "bestyrd": "bestyra",
    "bestyrda": "bestyra",
    "bestyrdas": "bestyra",
    "bestyrde": "bestyra",
    "bestyrdes": "bestyra",
    "bestyrds": "bestyra",
    "bestyren": "bestyr",
    "bestyrens": "bestyr",
    "bestyres": "bestyra",
    "bestyret": "bestyr",
    "bestyrets": "bestyr",
    "bestyrk": "bestyrka",
    "bestyrkande": "bestyrka",
    "bestyrkanden": "bestyrkande",
    "bestyrkandena": "bestyrkande",
    "bestyrkandenas": "bestyrkande",
    "bestyrkandens": "bestyrkande",
    "bestyrkandes": "bestyrkande",
    "bestyrkandet": "bestyrkande",
    "bestyrkandets": "bestyrkande",
    "bestyrkas": "bestyrka",
    "bestyrker": "bestyrka",
    "bestyrkes": "bestyrka",
    "bestyrks": "bestyrka",
    "bestyrkt": "bestyrka",
    "bestyrkta": "bestyrka",
    "bestyrktas": "bestyrka",
    "bestyrkte": "bestyrka",
    "bestyrktes": "bestyrka",
    "bestyrkts": "bestyrka",
    "bestyrs": "bestyra",
    "bestyrt": "bestyra",
    "bestyrts": "bestyra",
    "beställ": "beställa",
    "beställande": "beställa",
    "beställanden": "beställande",
    "beställandena": "beställande",
    "beställandenas": "beställande",
    "beställandens": "beställande",
    "beställandes": "beställande",
    "beställandet": "beställande",
    "beställandets": "beställande",
    "beställar": "beställare",
    "beställaren": "beställare",
    "beställarens": "beställare",
    "beställares": "beställare",
    "beställarna": "beställare",
    "beställarnas": "beställare",
    "beställas": "beställa",
    "beställd": "beställa",
    "beställda": "beställa",
    "beställdas": "beställa",
    "beställde": "beställa",
    "beställdes": "beställa",
    "beställds": "beställa",
    "beställer": "beställa",
    "beställes": "beställa",
    "beställningar": "beställning",
    "beställningarna": "beställning",
    "beställningarnas": "beställning",
    "beställningars": "beställning",
    "beställningen": "beställning",
    "beställningens": "beställning",
    "beställnings": "beställning",
    "beställningsarbeten": "beställningsarbete",
    "beställningsarbetena": "beställningsarbete",
    "beställningsarbetenas": "beställningsarbete",
    "beställningsarbetens": "beställningsarbete",
    "beställningsarbetes": "beställningsarbete",
    "beställningsarbetet": "beställningsarbete",
    "beställningsarbetets": "beställningsarbete",
    "beställningsarbets": "beställningsarbete",
    "beställningsavgiften": "beställningsavgift",
    "beställningsavgiftens": "beställningsavgift",
    "beställningsavgifter": "beställningsavgift",
    "beställningsavgifterna": "beställningsavgift",
    "beställningsavgifternas": "beställningsavgift",
    "beställningsavgifters": "beställningsavgift",
    "beställningsavgifts": "beställningsavgift",
    "beställningsverken": "beställningsverk",
    "beställningsverkens": "beställningsverk",
    "beställningsverket": "beställningsverk",
    "beställningsverkets": "beställningsverk",
    "beställningsverks": "beställningsverk",
    "beställs": "beställa",
    "beställsamheten": "beställsamhet",
    "beställsamhetens": "beställsamhet",
    "beställsamhets": "beställsamhet",
    "beställsamma": "beställsam",
    "beställsammare": "beställsam",
    "beställsammares": "beställsam",
    "beställsammas": "beställsam",
    "beställsammast": "beställsam",
    "beställsammaste": "beställsam",
    "beställsammastes": "beställsam",
    "beställsammasts": "beställsam",
    "beställsamme": "beställsam",
    "beställsammes": "beställsam",
    "beställsams": "beställsam",
    "beställsamt": "beställsam",
    "beställsamts": "beställsam",
    "beställt": "beställa",
    "beställts": "beställa",
    "bestäm": "bestämma",
    "bestämbara": "bestämbar",
    "bestämbarare": "bestämbar",
    "bestämbarares": "bestämbar",
    "bestämbaras": "bestämbar",
    "bestämbarast": "bestämbar",
    "bestämbaraste": "bestämbar",
    "bestämbarastes": "bestämbar",
    "bestämbarasts": "bestämbar",
    "bestämbare": "bestämbar",
    "bestämbares": "bestämbar",
    "bestämbarheten": "bestämbarhet",
    "bestämbarhetens": "bestämbarhet",
    "bestämbarhets": "bestämbarhet",
    "bestämbars": "bestämbar",
    "bestämbart": "bestämbar",
    "bestämbarts": "bestämbar",
    "bestämd": "bestämma",
    "bestämda": "bestämma",
    "bestämdare": "bestämd",
    "bestämdares": "bestämd",
    "bestämdas": "bestämma",
    "bestämdast": "bestämd",
    "bestämdaste": "bestämd",
    "bestämdastes": "bestämd",
    "bestämdasts": "bestämd",
    "bestämde": "bestämma",
    "bestämdes": "bestämma",
    "bestämdheten": "bestämdhet",
    "bestämdhetens": "bestämdhet",
    "bestämdhets": "bestämdhet",
    "bestämds": "bestämma",
    "bestämmande": "bestämma",
    "bestämmanden": "bestämmande",
    "bestämmandena": "bestämmande",
    "bestämmandenas": "bestämmande",
    "bestämmandens": "bestämmande",
    "bestämmanderätten": "bestämmanderätt",
    "bestämmanderättens": "bestämmanderätt",
    "bestämmanderätts": "bestämmanderätt",
    "bestämmandes": "bestämmande",
    "bestämmandet": "bestämmande",
    "bestämmandets": "bestämmande",
    "bestämmas": "bestämma",
    "bestämmelsen": "bestämmelse",
    "bestämmelsens": "bestämmelse",
    "bestämmelseorten": "bestämmelseort",
    "bestämmelseortens": "bestämmelseort",
    "bestämmelseorter": "bestämmelseort",
    "bestämmelseorterna": "bestämmelseort",
    "bestämmelseorternas": "bestämmelseort",
    "bestämmelseorters": "bestämmelseort",
    "bestämmelseorts": "bestämmelseort",
    "bestämmelser": "bestämmelse",
    "bestämmelserna": "bestämmelse",
    "bestämmelsernas": "bestämmelse",
    "bestämmelsers": "bestämmelse",
    "bestämmelses": "bestämmelse",
    "bestämmer": "bestämma",
    "bestämningar": "bestämning",
    "bestämningarna": "bestämning",
    "bestämningarnas": "bestämning",
    "bestämningars": "bestämning",
    "bestämningen": "bestämning",
    "bestämningens": "bestämning",
    "bestämnings": "bestämning",
    "bestämningsorden": "bestämningsord",
    "bestämningsordens": "bestämningsord",
    "bestämningsordet": "bestämningsord",
    "bestämningsordets": "bestämningsord",
    "bestämningsords": "bestämningsord",
    "bestäms": "bestämma",
    "bestämt": "bestämma",
    "bestämts": "bestämma",
    "beständiga": "beständig",
    "beständigare": "beständig",
    "beständigares": "beständig",
    "beständigas": "beständig",
    "beständigast": "beständig",
    "beständigaste": "beständig",
    "beständigastes": "beständig",
    "beständigasts": "beständig",
    "beständige": "beständig",
    "beständiges": "beständig",
    "beständigheten": "beständighet",
    "beständighetens": "beständighet",
    "beständigheter": "beständighet",
    "beständigheterna": "beständighet",
    "beständigheternas": "beständighet",
    "beständigheters": "beständighet",
    "beständighets": "beständighet",
    "beständigs": "beständig",
    "beständigt": "beständig",
    "beständigts": "beständig",
    "bestänk": "bestänka",
    "bestänkande": "bestänka",
    "bestänkanden": "bestänkande",
    "bestänkandena": "bestänkande",
    "bestänkandenas": "bestänkande",
    "bestänkandens": "bestänkande",
    "bestänkandes": "bestänkande",
    "bestänkandet": "bestänkande",
    "bestänkandets": "bestänkande",
    "bestänkas": "bestänka",
    "bestänker": "bestänka",
    "bestänkes": "bestänka",
    "bestänks": "bestänka",
    "bestänkt": "bestänka",
    "bestänkta": "bestänka",
    "bestänktas": "bestänka",
    "bestänkte": "bestänka",
    "bestänktes": "bestänka",
    "bestänkts": "bestänka",
    "bestådd": "bestå",
    "bestådda": "bestå",
    "beståddas": "bestå",
    "bestådde": "bestå",
    "beståddes": "bestå",
    "bestådds": "bestå",
    "bestående": "bestå",
    "beståenden": "bestående",
    "beståendena": "bestående",
    "beståendenas": "bestående",
    "beståendens": "bestående",
    "beståendes": "bestående",
    "beståendet": "bestående",
    "beståendets": "bestående",
    "bestånden": "bestånd",
    "beståndens": "bestånd",
    "beståndet": "bestånd",
    "beståndets": "bestånd",
    "bestånds": "bestånd",
    "beståndsdelar": "beståndsdel",
    "beståndsdelarna": "beståndsdel",
    "beståndsdelarnas": "beståndsdel",
    "beståndsdelars": "beståndsdel",
    "beståndsdelen": "beståndsdel",
    "beståndsdelens": "beståndsdel",
    "beståndsdels": "beståndsdel",
    "beståndsmässiga": "beståndsmässig",
    "beståndsmässigare": "beståndsmässig",
    "beståndsmässigares": "beståndsmässig",
    "beståndsmässigas": "beståndsmässig",
    "beståndsmässigast": "beståndsmässig",
    "beståndsmässigaste": "beståndsmässig",
    "beståndsmässigastes": "beståndsmässig",
    "beståndsmässigasts": "beståndsmässig",
    "beståndsmässige": "beståndsmässig",
    "beståndsmässiges": "beståndsmässig",
    "beståndsmässigs": "beståndsmässig",
    "beståndsmässigt": "beståndsmässig",
    "beståndsmässigts": "beståndsmässig",
    "består": "bestå",
    "bestås": "bestå",
    "bestått": "bestå",
    "beståtts": "bestå",
    "bestörta": "bestört",
    "bestörtare": "bestört",
    "bestörtares": "bestört",
    "bestörtas": "bestört",
    "bestörtast": "bestört",
    "bestörtaste": "bestört",
    "bestörtastes": "bestört",
    "bestörtasts": "bestört",
    "bestörte": "bestört",
    "bestörtes": "bestört",
    "bestörtheten": "bestörthet",
    "bestörthetens": "bestörthet",
    "bestörthets": "bestörthet",
    "bestörtningar": "bestörtning",
    "bestörtningarna": "bestörtning",
    "bestörtningarnas": "bestörtning",
    "bestörtningars": "bestörtning",
    "bestörtningen": "bestörtning",
    "bestörtningens": "bestörtning",
    "bestörtnings": "bestörtning",
    "bestörts": "bestört",
    "besudlad": "besudla",
    "besudlade": "besudla",
    "besudlades": "besudla",
    "besudlads": "besudla",
    "besudlande": "besudla",
    "besudlanden": "besudlande",
    "besudlandena": "besudlande",
    "besudlandenas": "besudlande",
    "besudlandens": "besudlande",
    "besudlandes": "besudlande",
    "besudlandet": "besudlande",
    "besudlandets": "besudlande",
    "besudlar": "besudla",
    "besudlas": "besudla",
    "besudlat": "besudla",
    "besudlats": "besudla",
    "besutte": "besitta",
    "besutten": "besitta",
    "besuttenheten": "besuttenhet",
    "besuttenhetens": "besuttenhet",
    "besuttenhets": "besuttenhet",
    "besuttens": "besutten",
    "besuttes": "besitta",
    "besuttet": "besutten",
    "besuttets": "besutten",
    "besuttit": "besitta",
    "besuttits": "besitta",
    "besuttna": "besutten",
    "besuttnare": "besutten",
    "besuttnares": "besutten",
    "besuttnas": "besutten",
    "besuttnast": "besutten",
    "besuttnaste": "besutten",
    "besuttnastes": "besutten",
    "besuttnasts": "besutten",
    "besuttne": "besutten",
    "besuttnes": "besutten",
    "besvar": "besvara",
    "besvarad": "besvara",
    "besvarade": "besvara",
    "besvarades": "besvara",
    "besvarads": "besvara",
    "besvarande": "besvara",
    "besvaranden": "besvarande",
    "besvarandena": "besvarande",
    "besvarandenas": "besvarande",
    "besvarandens": "besvarande",
    "besvarandes": "besvarande",
    "besvarandet": "besvarande",
    "besvarandets": "besvarande",
    "besvarar": "besvara",
    "besvaras": "besvara",
    "besvarat": "besvara",
    "besvarats": "besvara",
    "besvikelsen": "besvikelse",
    "besvikelsens": "besvikelse",
    "besvikelser": "besvikelse",
    "besvikelserna": "besvikelse",
    "besvikelsernas": "besvikelse",
    "besvikelsers": "besvikelse",
    "besvikelses": "besvikelse",
    "besvikenheten": "besvikenhet",
    "besvikenhetens": "besvikenhet",
    "besvikenhets": "besvikenhet",
    "besvikens": "besviken",
    "besviket": "besviken",
    "besvikets": "besviken",
    "besvikna": "besviken",
    "besviknare": "besviken",
    "besviknares": "besviken",
    "besviknas": "besviken",
    "besviknast": "besviken",
    "besviknaste": "besviken",
    "besviknastes": "besviken",
    "besviknasts": "besviken",
    "besvikne": "besviken",
    "besviknes": "besviken",
    "besvor": "besvärja",
    "besvors": "besvärja",
    "besvure": "besvärja",
    "besvuren": "besvärja",
    "besvurens": "besvärja",
    "besvures": "besvärja",
    "besvuret": "besvärja",
    "besvurets": "besvärja",
    "besvurit": "besvärja",
    "besvurits": "besvärja",
    "besvurna": "besvärja",
    "besvurnas": "besvärja",
    "besvurne": "besvärja",
    "besvurnes": "besvärja",
    "besvär": "besvärja",
    "besvära": "besvärja",
    "besvärad": "besvära",
    "besvärade": "besvärad",
    "besvärades": "besvärad",
    "besvärads": "besvärad",
    "besvärande": "besvärja",
    "besväranden": "besvärande",
    "besvärandena": "besvärande",
    "besvärandenas": "besvärande",
    "besvärandens": "besvärande",
    "besvärandes": "besvärja",
    "besvärandet": "besvärande",
    "besvärandets": "besvärande",
    "besvärar": "besvära",
    "besväras": "besvärja",
    "besvärat": "besvärad",
    "besvärats": "besvärad",
    "besvären": "besvär",
    "besvärens": "besvär",
    "besväret": "besvär",
    "besvärets": "besvär",
    "besvärj": "besvärja",
    "besvärjande": "besvärja",
    "besvärjanden": "besvärjande",
    "besvärjandena": "besvärjande",
    "besvärjandenas": "besvärjande",
    "besvärjandens": "besvärjande",
    "besvärjandes": "besvärjande",
    "besvärjandet": "besvärjande",
    "besvärjandets": "besvärjande",
    "besvärjas": "besvärja",
    "besvärjd": "besvärja",
    "besvärjda": "besvärja",
    "besvärjdas": "besvärja",
    "besvärjde": "besvärja",
    "besvärjdes": "besvärja",
    "besvärjds": "besvärja",
    "besvärje": "besvärja",
    "besvärjelseformeln": "besvärjelseformel",
    "besvärjelseformelns": "besvärjelseformel",
    "besvärjelseformels": "besvärjelseformel",
    "besvärjelseformler": "besvärjelseformel",
    "besvärjelseformlerna": "besvärjelseformel",
    "besvärjelseformlernas": "besvärjelseformel",
    "besvärjelseformlers": "besvärjelseformel",
    "besvärjelsen": "besvärjelse",
    "besvärjelsens": "besvärjelse",
    "besvärjelser": "besvärjelse",
    "besvärjelserna": "besvärjelse",
    "besvärjelsernas": "besvärjelse",
    "besvärjelsers": "besvärjelse",
    "besvärjelses": "besvärjelse",
    "besvärjer": "besvärja",
    "besvärjes": "besvärja",
    "besvärjs": "besvärja",
    "besvärjt": "besvärja",
    "besvärjts": "besvärja",
    "besvärliga": "besvärlig",
    "besvärligare": "besvärlig",
    "besvärligares": "besvärlig",
    "besvärligas": "besvärlig",
    "besvärligast": "besvärlig",
    "besvärligaste": "besvärlig",
    "besvärligastes": "besvärlig",
    "besvärligasts": "besvärlig",
    "besvärlige": "besvärlig",
    "besvärliges": "besvärlig",
    "besvärligheten": "besvärlighet",
    "besvärlighetens": "besvärlighet",
    "besvärligheter": "besvärlighet",
    "besvärligheterna": "besvärlighet",
    "besvärligheternas": "besvärlighet",
    "besvärligheters": "besvärlighet",
    "besvärlighets": "besvärlighet",
    "besvärligs": "besvärlig",
    "besvärligt": "besvärlig",
    "besvärligts": "besvärlig",
    "besvärs": "besvär",
    "besvärsgrunden": "besvärsgrund",
    "besvärsgrundens": "besvärsgrund",
    "besvärsgrunder": "besvärsgrund",
    "besvärsgrunderna": "besvärsgrund",
    "besvärsgrundernas": "besvärsgrund",
    "besvärsgrunders": "besvärsgrund",
    "besvärsgrunds": "besvärsgrund",
    "besvärshandlingar": "besvärshandling",
    "besvärshandlingarna": "besvärshandling",
    "besvärshandlingarnas": "besvärshandling",
    "besvärshandlingars": "besvärshandling",
    "besvärshandlingen": "besvärshandling",
    "besvärshandlingens": "besvärshandling",
    "besvärshandlings": "besvärshandling",
    "besvärshänvisningar": "besvärshänvisning",
    "besvärshänvisningarna": "besvärshänvisning",
    "besvärshänvisningarnas": "besvärshänvisning",
    "besvärshänvisningars": "besvärshänvisning",
    "besvärshänvisningen": "besvärshänvisning",
    "besvärshänvisningens": "besvärshänvisning",
    "besvärshänvisnings": "besvärshänvisning",
    "besvärsinlag": "besvärsinlaga",
    "besvärsinlagan": "besvärsinlaga",
    "besvärsinlagans": "besvärsinlaga",
    "besvärsinlagas": "besvärsinlaga",
    "besvärsinlage": "besvärsinlaga",
    "besvärsinlagor": "besvärsinlaga",
    "besvärsinlagorna": "besvärsinlaga",
    "besvärsinlagornas": "besvärsinlaga",
    "besvärsinlagors": "besvärsinlaga",
    "besvärsinlags": "besvärsinlaga",
    "besvärsinstansen": "besvärsinstans",
    "besvärsinstansens": "besvärsinstans",
    "besvärsinstanser": "besvärsinstans",
    "besvärsinstanserna": "besvärsinstans",
    "besvärsinstansernas": "besvärsinstans",
    "besvärsinstansers": "besvärsinstans",
    "besvärsmyndigheten": "besvärsmyndighet",
    "besvärsmyndighetens": "besvärsmyndighet",
    "besvärsmyndigheter": "besvärsmyndighet",
    "besvärsmyndigheterna": "besvärsmyndighet",
    "besvärsmyndigheternas": "besvärsmyndighet",
    "besvärsmyndigheters": "besvärsmyndighet",
    "besvärsmyndighets": "besvärsmyndighet",
    "besvärsmålen": "besvärsmål",
    "besvärsmålens": "besvärsmål",
    "besvärsmålet": "besvärsmål",
    "besvärsmålets": "besvärsmål",
    "besvärsmåls": "besvärsmål",
    "besvärsrätten": "besvärsrätt",
    "besvärsrättens": "besvärsrätt",
    "besvärsrätts": "besvärsrätt",
    "besvärsskriften": "besvärsskrift",
    "besvärsskriftens": "besvärsskrift",
    "besvärsskrifter": "besvärsskrift",
    "besvärsskrifterna": "besvärsskrift",
    "besvärsskrifternas": "besvärsskrift",
    "besvärsskrifters": "besvärsskrift",
    "besvärsskrifts": "besvärsskrift",
    "besvärssubjekten": "besvärssubjekt",
    "besvärssubjektens": "besvärssubjekt",
    "besvärssubjektet": "besvärssubjekt",
    "besvärssubjektets": "besvärssubjekt",
    "besvärssubjekts": "besvärssubjekt",
    "besvärstiden": "besvärstid",
    "besvärstidens": "besvärstid",
    "besvärstider": "besvärstid",
    "besvärstiderna": "besvärstid",
    "besvärstidernas": "besvärstid",
    "besvärstiders": "besvärstid",
    "besvärstids": "besvärstid",
    "besvågrade": "besvågrad",
    "besvågrades": "besvågrad",
    "besvågrads": "besvågrad",
    "besvågrat": "besvågrad",
    "besvågrats": "besvågrad",
    "besynnerliga": "besynnerlig",
    "besynnerligare": "besynnerlig",
    "besynnerligares": "besynnerlig",
    "besynnerligas": "besynnerlig",
    "besynnerligast": "besynnerlig",
    "besynnerligaste": "besynnerlig",
    "besynnerligastes": "besynnerlig",
    "besynnerligasts": "besynnerlig",
    "besynnerlige": "besynnerlig",
    "besynnerliges": "besynnerlig",
    "besynnerligheten": "besynnerlighet",
    "besynnerlighetens": "besynnerlighet",
    "besynnerligheter": "besynnerlighet",
    "besynnerligheterna": "besynnerlighet",
    "besynnerligheternas": "besynnerlighet",
    "besynnerligheters": "besynnerlighet",
    "besynnerlighets": "besynnerlighet",
    "besynnerligs": "besynnerlig",
    "besynnerligt": "besynnerlig",
    "besynnerligts": "besynnerlig",
    "besätt": "besätta",
    "besättande": "besätta",
    "besättanden": "besättande",
    "besättandena": "besättande",
    "besättandenas": "besättande",
    "besättandens": "besättande",
    "besättandes": "besättande",
    "besättandet": "besättande",
    "besättandets": "besättande",
    "besättas": "besätta",
    "besätter": "besätta",
    "besättes": "besätta",
    "besättningar": "besättning",
    "besättningarna": "besättning",
    "besättningarnas": "besättning",
    "besättningars": "besättning",
    "besättningen": "besättning",
    "besättningens": "besättning",
    "besättnings": "besättning",
    "besättningsbanden": "besättningsband",
    "besättningsbandens": "besättningsband",
    "besättningsbandet": "besättningsband",
    "besättningsbandets": "besättningsband",
    "besättningsbands": "besättningsband",
    "besättningsmannen": "besättningsman",
    "besättningsmannens": "besättningsman",
    "besättningsmans": "besättningsman",
    "besättningsmedlemmar": "besättningsmedlem",
    "besättningsmedlemmarna": "besättningsmedlem",
    "besättningsmedlemmarnas": "besättningsmedlem",
    "besättningsmedlemmars": "besättningsmedlem",
    "besättningsmedlemmen": "besättningsmedlem",
    "besättningsmedlemmens": "besättningsmedlem",
    "besättningsmedlems": "besättningsmedlem",
    "besättningsmän": "besättningsman",
    "besättningsmännen": "besättningsman",
    "besättningsmännens": "besättningsman",
    "besättningsmäns": "besättningsman",
    "besätts": "besätta",
    "besådd": "beså",
    "besådda": "beså",
    "besåddas": "beså",
    "besådde": "beså",
    "besåddes": "beså",
    "besådds": "beså",
    "besående": "beså",
    "besåenden": "besående",
    "besåendena": "besående",
    "besåendenas": "besående",
    "besåendens": "besående",
    "besåendes": "besående",
    "besåendet": "besående",
    "besåendets": "besående",
    "besåg": "bese",
    "besåge": "bese",
    "besåges": "bese",
    "besågs": "bese",
    "besår": "beså",
    "besås": "beså",
    "besått": "beså",
    "besåtts": "beså",
    "besök": "besöka",
    "besökande": "besöka",
    "besökanden": "besökande",
    "besökandena": "besökande",
    "besökandenas": "besökande",
    "besökandens": "besökande",
    "besökandes": "besökande",
    "besökandet": "besökande",
    "besökandets": "besökande",
    "besökar": "besökare",
    "besökaren": "besökare",
    "besökarens": "besökare",
    "besökares": "besökare",
    "besökarna": "besökare",
    "besökarnas": "besökare",
    "besökas": "besöka",
    "besöken": "besök",
    "besökens": "besök",
    "besöker": "besöka",
    "besökes": "besöka",
    "besöket": "besök",
    "besökets": "besök",
    "besöks": "besöka",
    "besöksadressen": "besöksadress",
    "besöksadressens": "besöksadress",
    "besöksadresser": "besöksadress",
    "besöksadresserna": "besöksadress",
    "besöksadressernas": "besöksadress",
    "besöksadressers": "besöksadress",
    "besöksboken": "besöksbok",
    "besöksbokens": "besöksbok",
    "besöksboks": "besöksbok",
    "besöksböcker": "besöksbok",
    "besöksböckerna": "besöksbok",
    "besöksböckernas": "besöksbok",
    "besöksböckers": "besöksbok",
    "besöksdagar": "besöksdag",
    "besöksdagarna": "besöksdag",
    "besöksdagarnas": "besöksdag",
    "besöksdagars": "besöksdag",
    "besöksdagen": "besöksdag",
    "besöksdagens": "besöksdag",
    "besöksdags": "besöksdag",
    "besöksfåtöljen": "besöksfåtölj",
    "besöksfåtöljens": "besöksfåtölj",
    "besöksfåtöljer": "besöksfåtölj",
    "besöksfåtöljerna": "besöksfåtölj",
    "besöksfåtöljernas": "besöksfåtölj",
    "besöksfåtöljers": "besöksfåtölj",
    "besöksfåtöljs": "besöksfåtölj",
    "besöksförbuden": "besöksförbud",
    "besöksförbudens": "besöksförbud",
    "besöksförbudet": "besöksförbud",
    "besöksförbudets": "besöksförbud",
    "besöksförbuds": "besöksförbud",
    "besöksnäringar": "besöksnäring",
    "besöksnäringarna": "besöksnäring",
    "besöksnäringarnas": "besöksnäring",
    "besöksnäringars": "besöksnäring",
    "besöksnäringen": "besöksnäring",
    "besöksnäringens": "besöksnäring",
    "besöksnärings": "besöksnäring",
    "besöksrestriktionen": "besöksrestriktion",
    "besöksrestriktionens": "besöksrestriktion",
    "besöksrestriktioner": "besöksrestriktion",
    "besöksrestriktionerna": "besöksrestriktion",
    "besöksrestriktionernas": "besöksrestriktion",
    "besöksrestriktioners": "besöksrestriktion",
    "besöksrestriktions": "besöksrestriktion",
    "besöksstolar": "besöksstol",
    "besöksstolarna": "besöksstol",
    "besöksstolarnas": "besöksstol",
    "besöksstolars": "besöksstol",
    "besöksstolen": "besöksstol",
    "besöksstolens": "besöksstol",
    "besöksstols": "besöksstol",
    "besökstiden": "besökstid",
    "besökstidens": "besökstid",
    "besökstider": "besökstid",
    "besökstiderna": "besökstid",
    "besökstidernas": "besökstid",
    "besökstiders": "besökstid",
    "besökstids": "besökstid",
    "besökstoppen": "besökstopp",
    "besökstoppens": "besökstopp",
    "besökstoppet": "besökstopp",
    "besökstoppets": "besökstopp",
    "besökstopps": "besökstopp",
    "besökt": "besöka",
    "besökta": "besöka",
    "besöktas": "besöka",
    "besökte": "besöka",
    "besöktes": "besöka",
    "besökts": "besöka",
    "besörj": "besörja",
    "besörjande": "besörja",
    "besörjanden": "besörjande",
    "besörjandena": "besörjande",
    "besörjandenas": "besörjande",
    "besörjandens": "besörjande",
    "besörjandes": "besörjande",
    "besörjandet": "besörjande",
    "besörjandets": "besörjande",
    "besörjas": "besörja",
    "besörjd": "besörja",
    "besörjda": "besörja",
    "besörjdas": "besörja",
    "besörjde": "besörja",
    "besörjdes": "besörja",
    "besörjds": "besörja",
    "besörjer": "besörja",
    "besörjes": "besörja",
    "besörjs": "besörja",
    "besörjt": "besörja",
    "besörjts": "besörja",
    "bet": "bita",
    "betablockerar": "betablockerare",
    "betablockeraren": "betablockerare",
    "betablockerarens": "betablockerare",
    "betablockerares": "betablockerare",
    "betablockerarna": "betablockerare",
    "betablockerarnas": "betablockerare",
    "betad": "beta",
    "betade": "beta",
    "betades": "beta",
    "betads": "beta",
    "betag": "beta",
    "betaga": "beta",
    "betagande": "beta",
    "betaganden": "betagande",
    "betagandena": "betagande",
    "betagandenas": "betagande",
    "betagandens": "betagande",
    "betagandes": "betagande",
    "betagandet": "betagande",
    "betagandets": "betagande",
    "betagas": "beta",
    "betage": "beta",
    "betagen": "beta",
    "betagenheten": "betagenhet",
    "betagenhetens": "betagenhet",
    "betagenhets": "betagenhet",
    "betagens": "betagen",
    "betager": "beta",
    "betages": "beta",
    "betaget": "betagen",
    "betagets": "betagen",
    "betagit": "beta",
    "betagits": "beta",
    "betagna": "betagen",
    "betagnare": "betagen",
    "betagnares": "betagen",
    "betagnas": "betagen",
    "betagnast": "betagen",
    "betagnaste": "betagen",
    "betagnastes": "betagen",
    "betagnasts": "betagen",
    "betagne": "betagen",
    "betagnes": "betagen",
    "betags": "beta",
    "betal": "betala",
    "betalad": "betala",
    "betalade": "betala",
    "betalades": "betala",
    "betalads": "betala",
    "betalande": "betala",
    "betalanden": "betalande",
    "betalandena": "betalande",
    "betalandenas": "betalande",
    "betalandens": "betalande",
    "betalandes": "betalande",
    "betalandet": "betalande",
    "betalandets": "betalande",
    "betalar": "betala",
    "betalartikeln": "betalartikel",
    "betalartikelns": "betalartikel",
    "betalartikels": "betalartikel",
    "betalartiklar": "betalartikel",
    "betalartiklarna": "betalartikel",
    "betalartiklarnas": "betalartikel",
    "betalartiklars": "betalartikel",
    "betalas": "betala",
    "betalat": "betala",
    "betalats": "betala",
    "betalbara": "betalbar",
    "betalbarare": "betalbar",
    "betalbarares": "betalbar",
    "betalbaras": "betalbar",
    "betalbarast": "betalbar",
    "betalbaraste": "betalbar",
    "betalbarastes": "betalbar",
    "betalbarasts": "betalbar",
    "betalbare": "betalbar",
    "betalbares": "betalbar",
    "betalbarheten": "betalbarhet",
    "betalbarhetens": "betalbarhet",
    "betalbarhets": "betalbarhet",
    "betalbars": "betalbar",
    "betalbart": "betalbar",
    "betalbarts": "betalbar",
    "betald": "betala",
    "betalda": "betala",
    "betaldas": "betala",
    "betalde": "betala",
    "betaldes": "betala",
    "betalds": "betala",
    "betalkursen": "betalkurs",
    "betalkursens": "betalkurs",
    "betalkurser": "betalkurs",
    "betalkurserna": "betalkurs",
    "betalkursernas": "betalkurs",
    "betalkursers": "betalkurs",
    "betalningar": "betalning",
    "betalningarna": "betalning",
    "betalningarnas": "betalning",
    "betalningars": "betalning",
    "betalningen": "betalning",
    "betalningens": "betalning",
    "betalnings": "betalning",
    "betalningsanmärkningar": "betalningsanmärkning",
    "betalningsanmärkningarna": "betalningsanmärkning",
    "betalningsanmärkningarnas": "betalningsanmärkning",
    "betalningsanmärkningars": "betalningsanmärkning",
    "betalningsanmärkningen": "betalningsanmärkning",
    "betalningsanmärkningens": "betalningsanmärkning",
    "betalningsanmärknings": "betalningsanmärkning",
    "betalningsanstånden": "betalningsanstånd",
    "betalningsanståndens": "betalningsanstånd",
    "betalningsanståndet": "betalningsanstånd",
    "betalningsanståndets": "betalningsanstånd",
    "betalningsanstånds": "betalningsanstånd",
    "betalningsavtalen": "betalningsavtal",
    "betalningsavtalens": "betalningsavtal",
    "betalningsavtalet": "betalningsavtal",
    "betalningsavtalets": "betalningsavtal",
    "betalningsavtals": "betalningsavtal",
    "betalningsbalansen": "betalningsbalans",
    "betalningsbalansens": "betalningsbalans",
    "betalningsbalanser": "betalningsbalans",
    "betalningsbalanserna": "betalningsbalans",
    "betalningsbalansernas": "betalningsbalans",
    "betalningsbalansers": "betalningsbalans",
    "betalningsbevisen": "betalningsbevis",
    "betalningsbevisens": "betalningsbevis",
    "betalningsbeviset": "betalningsbevis",
    "betalningsbevisets": "betalningsbevis",
    "betalningsfria": "betalningsfri",
    "betalningsfriare": "betalningsfri",
    "betalningsfriares": "betalningsfri",
    "betalningsfrias": "betalningsfri",
    "betalningsfriast": "betalningsfri",
    "betalningsfriaste": "betalningsfri",
    "betalningsfriastes": "betalningsfri",
    "betalningsfriasts": "betalningsfri",
    "betalningsfrie": "betalningsfri",
    "betalningsfries": "betalningsfri",
    "betalningsfris": "betalningsfri",
    "betalningsfristen": "betalningsfrist",
    "betalningsfristens": "betalningsfrist",
    "betalningsfrister": "betalningsfrist",
    "betalningsfristerna": "betalningsfrist",
    "betalningsfristernas": "betalningsfrist",
    "betalningsfristers": "betalningsfrist",
    "betalningsfrists": "betalningsfrist",
    "betalningsfritt": "betalningsfri",
    "betalningsfritts": "betalningsfri",
    "betalningsförelägganden": "betalningsföreläggande",
    "betalningsföreläggandena": "betalningsföreläggande",
    "betalningsföreläggandenas": "betalningsföreläggande",
    "betalningsföreläggandens": "betalningsföreläggande",
    "betalningsföreläggandes": "betalningsföreläggande",
    "betalningsföreläggandet": "betalningsföreläggande",
    "betalningsföreläggandets": "betalningsföreläggande",
    "betalningsgilla": "betalningsgill",
    "betalningsgillare": "betalningsgill",
    "betalningsgillares": "betalningsgill",
    "betalningsgillas": "betalningsgill",
    "betalningsgillast": "betalningsgill",
    "betalningsgillaste": "betalningsgill",
    "betalningsgillastes": "betalningsgill",
    "betalningsgillasts": "betalningsgill",
    "betalningsgille": "betalningsgill",
    "betalningsgilles": "betalningsgill",
    "betalningsgills": "betalningsgill",
    "betalningsgillt": "betalningsgill",
    "betalningsgillts": "betalningsgill",
    "betalningsinställelsen": "betalningsinställelse",
    "betalningsinställelsens": "betalningsinställelse",
    "betalningsinställelser": "betalningsinställelse",
    "betalningsinställelserna": "betalningsinställelse",
    "betalningsinställelsernas": "betalningsinställelse",
    "betalningsinställelsers": "betalningsinställelse",
    "betalningsinställelses": "betalningsinställelse",
    "betalningsmedels": "betalningsmedel",
    "betalningsmedlen": "betalningsmedel",
    "betalningsmedlens": "betalningsmedel",
    "betalningsmedlet": "betalningsmedel",
    "betalningsmedlets": "betalningsmedel",
    "betalningsskyldiga": "betalningsskyldig",
    "betalningsskyldigare": "betalningsskyldig",
    "betalningsskyldigares": "betalningsskyldig",
    "betalningsskyldigas": "betalningsskyldig",
    "betalningsskyldigast": "betalningsskyldig",
    "betalningsskyldigaste": "betalningsskyldig",
    "betalningsskyldigastes": "betalningsskyldig",
    "betalningsskyldigasts": "betalningsskyldig",
    "betalningsskyldige": "betalningsskyldig",
    "betalningsskyldiges": "betalningsskyldig",
    "betalningsskyldigheten": "betalningsskyldighet",
    "betalningsskyldighetens": "betalningsskyldighet",
    "betalningsskyldighets": "betalningsskyldighet",
    "betalningsskyldigs": "betalningsskyldig",
    "betalningsskyldigt": "betalningsskyldig",
    "betalningsskyldigts": "betalningsskyldig",
    "betalningssäkrad": "betalningssäkra",
    "betalningssäkrade": "betalningssäkra",
    "betalningssäkrades": "betalningssäkra",
    "betalningssäkrads": "betalningssäkra",
    "betalningssäkrande": "betalningssäkra",
    "betalningssäkrandes": "betalningssäkra",
    "betalningssäkrar": "betalningssäkra",
    "betalningssäkras": "betalningssäkra",
    "betalningssäkrat": "betalningssäkra",
    "betalningssäkrats": "betalningssäkra",
    "betalningsterminen": "betalningstermin",
    "betalningsterminens": "betalningstermin",
    "betalningsterminer": "betalningstermin",
    "betalningsterminerna": "betalningstermin",
    "betalningsterminernas": "betalningstermin",
    "betalningsterminers": "betalningstermin",
    "betalningstermins": "betalningstermin",
    "betalningstiden": "betalningstid",
    "betalningstidens": "betalningstid",
    "betalningstider": "betalningstid",
    "betalningstiderna": "betalningstid",
    "betalningstidernas": "betalningstid",
    "betalningstiders": "betalningstid",
    "betalningstids": "betalningstid",
    "betalningsviljan": "betalningsvilja",
    "betalningsviljans": "betalningsvilja",
    "betalningsviljas": "betalningsvilja",
    "betalningsvilje": "betalningsvilja",
    "betalningsviljor": "betalningsvilja",
    "betalningsviljorna": "betalningsvilja",
    "betalningsviljornas": "betalningsvilja",
    "betalningsviljors": "betalningsvilja",
    "betalningsvillkoren": "betalningsvillkor",
    "betalningsvillkorens": "betalningsvillkor",
    "betalningsvillkoret": "betalningsvillkor",
    "betalningsvillkorets": "betalningsvillkor",
    "betalningsvillkors": "betalningsvillkor",
    "betalsexet": "betalsex",
    "betalsexets": "betalsex",
    "betalt": "betala",
    "betalte": "betala",
    "betaltes": "betala",
    "betalts": "betala",
    "betan": "beta",
    "betana": "beta",
    "betanas": "beta",
    "betande": "beta",
    "betanden": "betande",
    "betandena": "betande",
    "betandenas": "betande",
    "betandens": "betande",
    "betandes": "betande",
    "betandet": "betande",
    "betandets": "betande",
    "betans": "beta",
    "betapartikeln": "betapartikel",
    "betapartikelns": "betapartikel",
    "betapartikels": "betapartikel",
    "betapartiklar": "betapartikel",
    "betapartiklarna": "betapartikel",
    "betapartiklarnas": "betapartikel",
    "betapartiklars": "betapartikel",
    "betar": "bete",
    "betarna": "bete",
    "betarnas": "bete",
    "betars": "bete",
    "betas": "beta",
    "betastrålningar": "betastrålning",
    "betastrålningarna": "betastrålning",
    "betastrålningarnas": "betastrålning",
    "betastrålningars": "betastrålning",
    "betastrålningen": "betastrålning",
    "betastrålningens": "betastrålning",
    "betastrålnings": "betastrålning",
    "betat": "beta",
    "betatronen": "betatron",
    "betatronens": "betatron",
    "betatroner": "betatron",
    "betatronerna": "betatron",
    "betatronernas": "betatron",
    "betatroners": "betatron",
    "betatrons": "betatron",
    "betats": "beta",
    "bete": "beta",
    "betecknad": "beteckna",
    "betecknade": "beteckna",
    "betecknades": "beteckna",
    "betecknads": "beteckna",
    "betecknande": "beteckna",
    "betecknanden": "betecknande",
    "betecknandena": "betecknande",
    "betecknandenas": "betecknande",
    "betecknandens": "betecknande",
    "betecknandes": "betecknande",
    "betecknandet": "betecknande",
    "betecknandets": "betecknande",
    "betecknar": "beteckna",
    "betecknas": "beteckna",
    "betecknat": "beteckna",
    "betecknats": "beteckna",
    "beteckningar": "beteckning",
    "beteckningarna": "beteckning",
    "beteckningarnas": "beteckning",
    "beteckningars": "beteckning",
    "beteckningen": "beteckning",
    "beteckningens": "beteckning",
    "betecknings": "beteckning",
    "beteendeforskningar": "beteendeforskning",
    "beteendeforskningarna": "beteendeforskning",
    "beteendeforskningarnas": "beteendeforskning",
    "beteendeforskningars": "beteendeforskning",
    "beteendeforskningen": "beteendeforskning",
    "beteendeforskningens": "beteendeforskning",
    "beteendeforsknings": "beteendeforskning",
    "beteendemässiga": "beteendemässig",
    "beteendemässigare": "beteendemässig",
    "beteendemässigares": "beteendemässig",
    "beteendemässigas": "beteendemässig",
    "beteendemässigast": "beteendemässig",
    "beteendemässigaste": "beteendemässig",
    "beteendemässigastes": "beteendemässig",
    "beteendemässigasts": "beteendemässig",
    "beteendemässige": "beteendemässig",
    "beteendemässiges": "beteendemässig",
    "beteendemässigs": "beteendemässig",
    "beteendemässigt": "beteendemässig",
    "beteendemässigts": "beteendemässig",
    "beteendemönsterna": "beteendemönster",
    "beteendemönsternas": "beteendemönster",
    "beteendemönsters": "beteendemönster",
    "beteendemönstren": "beteendemönster",
    "beteendemönstrens": "beteendemönster",
    "beteendemönstret": "beteendemönster",
    "beteendemönstrets": "beteendemönster",
    "beteenden": "beteende",
    "beteendena": "beteende",
    "beteendenas": "beteende",
    "beteendens": "beteende",
    "beteendepsykologien": "beteendepsykologi",
    "beteendepsykologiens": "beteendepsykologi",
    "beteendepsykologin": "beteendepsykologi",
    "beteendepsykologins": "beteendepsykologi",
    "beteendepsykologis": "beteendepsykologi",
    "beteenderubbningar": "beteenderubbning",
    "beteenderubbningarna": "beteenderubbning",
    "beteenderubbningarnas": "beteenderubbning",
    "beteenderubbningars": "beteenderubbning",
    "beteenderubbningen": "beteenderubbning",
    "beteenderubbningens": "beteenderubbning",
    "beteenderubbnings": "beteenderubbning",
    "beteendes": "beteende",
    "beteendet": "beteende",
    "beteendeterapeuten": "beteendeterapeut",
    "beteendeterapeutens": "beteendeterapeut",
    "beteendeterapeuter": "beteendeterapeut",
    "beteendeterapeuterna": "beteendeterapeut",
    "beteendeterapeuternas": "beteendeterapeut",
    "beteendeterapeuters": "beteendeterapeut",
    "beteendeterapeuts": "beteendeterapeut",
    "beteendeterapien": "beteendeterapi",
    "beteendeterapiens": "beteendeterapi",
    "beteendeterapin": "beteendeterapi",
    "beteendeterapins": "beteendeterapi",
    "beteendeterapis": "beteendeterapi",
    "beteendets": "beteende",
    "beteendevetar": "beteendevetare",
    "beteendevetaren": "beteendevetare",
    "beteendevetarens": "beteendevetare",
    "beteendevetares": "beteendevetare",
    "beteendevetarna": "beteendevetare",
    "beteendevetarnas": "beteendevetare",
    "beteendevetenskapen": "beteendevetenskap",
    "beteendevetenskapens": "beteendevetenskap",
    "beteendevetenskaper": "beteendevetenskap",
    "beteendevetenskaperna": "beteendevetenskap",
    "beteendevetenskapernas": "beteendevetenskap",
    "beteendevetenskapers": "beteendevetenskap",
    "beteendevetenskaps": "beteendevetenskap",
    "betelbladen": "betelblad",
    "betelbladens": "betelblad",
    "betelbladet": "betelblad",
    "betelbladets": "betelblad",
    "betelblads": "betelblad",
    "beteln": "betel",
    "betelns": "betel",
    "betelnöten": "betelnöt",
    "betelnötens": "betelnöt",
    "betelnöts": "betelnöt",
    "betelnötter": "betelnöt",
    "betelnötterna": "betelnöt",
    "betelnötternas": "betelnöt",
    "betelnötters": "betelnöt",
    "betelpalmen": "betelpalm",
    "betelpalmens": "betelpalm",
    "betelpalmer": "betelpalm",
    "betelpalmerna": "betelpalm",
    "betelpalmernas": "betelpalm",
    "betelpalmers": "betelpalm",
    "betelpalms": "betelpalm",
    "betelpepparn": "betelpeppar",
    "betelpepparns": "betelpeppar",
    "betelpeppars": "betelpeppar",
    "betels": "betel",
    "beteltuggar": "beteltuggare",
    "beteltuggaren": "beteltuggare",
    "beteltuggarens": "beteltuggare",
    "beteltuggares": "beteltuggare",
    "beteltuggarna": "beteltuggare",
    "beteltuggarnas": "beteltuggare",
    "beteltuggningar": "beteltuggning",
    "beteltuggningarna": "beteltuggning",
    "beteltuggningarnas": "beteltuggning",
    "beteltuggningars": "beteltuggning",
    "beteltuggningen": "beteltuggning",
    "beteltuggningens": "beteltuggning",
    "beteltuggnings": "beteltuggning",
    "beten": "bete",
    "betena": "bete",
    "betenas": "bete",
    "betens": "bete",
    "betes": "bete",
    "betesgångar": "betesgång",
    "betesgångarna": "betesgång",
    "betesgångarnas": "betesgång",
    "betesgångars": "betesgång",
    "betesgången": "betesgång",
    "betesgångens": "betesgång",
    "betesgångs": "betesgång",
    "beteslanden": "betesland",
    "beteslandens": "betesland",
    "beteslandet": "betesland",
    "beteslandets": "betesland",
    "beteslands": "betesland",
    "betesmarken": "betesmark",
    "betesmarkens": "betesmark",
    "betesmarker": "betesmark",
    "betesmarkerna": "betesmark",
    "betesmarkernas": "betesmark",
    "betesmarkers": "betesmark",
    "betesmarks": "betesmark",
    "betesområden": "betesområde",
    "betesområdena": "betesområde",
    "betesområdenas": "betesområde",
    "betesområdens": "betesområde",
    "betesområdes": "betesområde",
    "betesområdet": "betesområde",
    "betesområdets": "betesområde",
    "betesplatsen": "betesplats",
    "betesplatsens": "betesplats",
    "betesplatser": "betesplats",
    "betesplatserna": "betesplats",
    "betesplatsernas": "betesplats",
    "betesplatsers": "betesplats",
    "betet": "bete",
    "betets": "bete",
    "beting": "betinga",
    "betingad": "betinga",
    "betingade": "betingad",
    "betingades": "betingad",
    "betingads": "betingad",
    "betingande": "betinga",
    "betinganden": "betingande",
    "betingandena": "betingande",
    "betingandenas": "betingande",
    "betingandens": "betingande",
    "betingandes": "betingande",
    "betingandet": "betingande",
    "betingandets": "betingande",
    "betingar": "betinga",
    "betingarna": "beting",
    "betingarnas": "beting",
    "betingars": "beting",
    "betingas": "betinga",
    "betingat": "betingad",
    "betingats": "betingad",
    "betingelsen": "betingelse",
    "betingelsens": "betingelse",
    "betingelser": "betingelse",
    "betingelserna": "betingelse",
    "betingelsernas": "betingelse",
    "betingelsers": "betingelse",
    "betingelses": "betingelse",
    "betingen": "beting",
    "betingens": "beting",
    "betinget": "beting",
    "betingets": "beting",
    "betingningar": "betingning",
    "betingningarna": "betingning",
    "betingningarnas": "betingning",
    "betingningars": "betingning",
    "betingningen": "betingning",
    "betingningens": "betingning",
    "betingnings": "betingning",
    "betings": "beting",
    "betingsarbeten": "betingsarbete",
    "betingsarbetena": "betingsarbete",
    "betingsarbetenas": "betingsarbete",
    "betingsarbetens": "betingsarbete",
    "betingsarbetes": "betingsarbete",
    "betingsarbetet": "betingsarbete",
    "betingsarbetets": "betingsarbete",
    "betingsarbets": "betingsarbete",
    "betingsläsningar": "betingsläsning",
    "betingsläsningarna": "betingsläsning",
    "betingsläsningarnas": "betingsläsning",
    "betingsläsningars": "betingsläsning",
    "betingsläsningen": "betingsläsning",
    "betingsläsningens": "betingsläsning",
    "betingsläsnings": "betingsläsning",
    "betitlad": "betitla",
    "betitlade": "betitla",
    "betitlades": "betitla",
    "betitlads": "betitla",
    "betitlande": "betitla",
    "betitlanden": "betitlande",
    "betitlandena": "betitlande",
    "betitlandenas": "betitlande",
    "betitlandens": "betitlande",
    "betitlandes": "betitlande",
    "betitlandet": "betitlande",
    "betitlandets": "betitlande",
    "betitlar": "betitla",
    "betitlas": "betitla",
    "betitlat": "betitla",
    "betitlats": "betitla",
    "betitt": "betitta",
    "betittad": "betitta",
    "betittade": "betitta",
    "betittades": "betitta",
    "betittads": "betitta",
    "betittande": "betitta",
    "betittanden": "betittande",
    "betittandena": "betittande",
    "betittandenas": "betittande",
    "betittandens": "betittande",
    "betittandes": "betittande",
    "betittandet": "betittande",
    "betittandets": "betittande",
    "betittar": "betitta",
    "betittas": "betitta",
    "betittat": "betitta",
    "betittats": "betitta",
    "betjän": "betjäna",
    "betjänad": "betjäna",
    "betjänade": "betjäna",
    "betjänades": "betjäna",
    "betjänads": "betjäna",
    "betjänande": "betjäna",
    "betjänanden": "betjänande",
    "betjänandena": "betjänande",
    "betjänandenas": "betjänande",
    "betjänandens": "betjänande",
    "betjänandes": "betjänande",
    "betjänandet": "betjänande",
    "betjänandets": "betjänande",
    "betjänar": "betjäna",
    "betjänas": "betjäna",
    "betjänat": "betjäna",
    "betjänats": "betjäna",
    "betjäningar": "betjäning",
    "betjäningarna": "betjäning",
    "betjäningarnas": "betjäning",
    "betjäningars": "betjäning",
    "betjäningen": "betjäning",
    "betjäningens": "betjäning",
    "betjänings": "betjäning",
    "betjäningsavgiften": "betjäningsavgift",
    "betjäningsavgiftens": "betjäningsavgift",
    "betjäningsavgifter": "betjäningsavgift",
    "betjäningsavgifterna": "betjäningsavgift",
    "betjäningsavgifternas": "betjäningsavgift",
    "betjäningsavgifters": "betjäningsavgift",
    "betjäningsavgifts": "betjäningsavgift",
    "betjänta": "betjänt",
    "betjäntare": "betjänt",
    "betjäntares": "betjänt",
    "betjäntas": "betjänt",
    "betjäntast": "betjänt",
    "betjäntaste": "betjänt",
    "betjäntastes": "betjänt",
    "betjäntasts": "betjänt",
    "betjänte": "betjänt",
    "betjänten": "betjänt",
    "betjäntens": "betjänt",
    "betjänter": "betjänt",
    "betjänterna": "betjänt",
    "betjänternas": "betjänt",
    "betjänters": "betjänt",
    "betjäntes": "betjänt",
    "betjänts": "betjänt",
    "betkampanjen": "betkampanj",
    "betkampanjens": "betkampanj",
    "betkampanjer": "betkampanj",
    "betkampanjerna": "betkampanj",
    "betkampanjernas": "betkampanj",
    "betkampanjers": "betkampanj",
    "betkampanjs": "betkampanj",
    "betmedels": "betmedel",
    "betmedlen": "betmedel",
    "betmedlens": "betmedel",
    "betmedlet": "betmedel",
    "betmedlets": "betmedel",
    "betningar": "betning",
    "betningarna": "betning",
    "betningarnas": "betning",
    "betningars": "betning",
    "betningen": "betning",
    "betningens": "betning",
    "betnings": "betning",
    "betog": "beta",
    "betoge": "beta",
    "betoges": "beta",
    "betogs": "beta",
    "betonad": "betona",
    "betonade": "betonad",
    "betonades": "betonad",
    "betonads": "betonad",
    "betonande": "betona",
    "betonanden": "betonande",
    "betonandena": "betonande",
    "betonandenas": "betonande",
    "betonandens": "betonande",
    "betonandes": "betonande",
    "betonandet": "betonande",
    "betonandets": "betonande",
    "betonar": "betona",
    "betonas": "betona",
    "betonat": "betonad",
    "betonats": "betonad",
    "betongbjälklagen": "betongbjälklag",
    "betongbjälklagens": "betongbjälklag",
    "betongbjälklaget": "betongbjälklag",
    "betongbjälklagets": "betongbjälklag",
    "betongbjälklags": "betongbjälklag",
    "betongblandar": "betongblandare",
    "betongblandaren": "betongblandare",
    "betongblandarens": "betongblandare",
    "betongblandares": "betongblandare",
    "betongblandarna": "betongblandare",
    "betongblandarnas": "betongblandare",
    "betongblocken": "betongblock",
    "betongblockens": "betongblock",
    "betongblocket": "betongblock",
    "betongblockets": "betongblock",
    "betongblocks": "betongblock",
    "betongbäddar": "betongbädd",
    "betongbäddarna": "betongbädd",
    "betongbäddarnas": "betongbädd",
    "betongbäddars": "betongbädd",
    "betongbädden": "betongbädd",
    "betongbäddens": "betongbädd",
    "betongbädds": "betongbädd",
    "betongen": "betong",
    "betongens": "betong",
    "betonger": "betong",
    "betongerad": "betongera",
    "betongerade": "betongera",
    "betongerades": "betongera",
    "betongerads": "betongera",
    "betongerande": "betongera",
    "betongeranden": "betongerande",
    "betongerandena": "betongerande",
    "betongerandenas": "betongerande",
    "betongerandens": "betongerande",
    "betongerandes": "betongerande",
    "betongerandet": "betongerande",
    "betongerandets": "betongerande",
    "betongerar": "betongera",
    "betongeras": "betongera",
    "betongerat": "betongera",
    "betongerats": "betongera",
    "betongerbara": "betongerbar",
    "betongerbarare": "betongerbar",
    "betongerbarares": "betongerbar",
    "betongerbaras": "betongerbar",
    "betongerbarast": "betongerbar",
    "betongerbaraste": "betongerbar",
    "betongerbarastes": "betongerbar",
    "betongerbarasts": "betongerbar",
    "betongerbare": "betongerbar",
    "betongerbares": "betongerbar",
    "betongerbarheten": "betongerbarhet",
    "betongerbarhetens": "betongerbarhet",
    "betongerbarhets": "betongerbarhet",
    "betongerbars": "betongerbar",
    "betongerbart": "betongerbar",
    "betongerbarts": "betongerbar",
    "betongeringar": "betongering",
    "betongeringarna": "betongering",
    "betongeringarnas": "betongering",
    "betongeringars": "betongering",
    "betongeringen": "betongering",
    "betongeringens": "betongering",
    "betongerings": "betongering",
    "betongerna": "betong",
    "betongernas": "betong",
    "betongers": "betong",
    "betonggolven": "betonggolv",
    "betonggolvens": "betonggolv",
    "betonggolvet": "betonggolv",
    "betonggolvets": "betonggolv",
    "betonggolvs": "betonggolv",
    "betonghinderna": "betonghinder",
    "betonghindernas": "betonghinder",
    "betonghinders": "betonghinder",
    "betonghindren": "betonghinder",
    "betonghindrens": "betonghinder",
    "betonghindret": "betonghinder",
    "betonghindrets": "betonghinder",
    "betonghäckar": "betonghäck",
    "betonghäckarna": "betonghäck",
    "betonghäckarnas": "betonghäck",
    "betonghäckars": "betonghäck",
    "betonghäcken": "betonghäck",
    "betonghäckens": "betonghäck",
    "betonghäcks": "betonghäck",
    "betongmaskinen": "betongmaskin",
    "betongmaskinens": "betongmaskin",
    "betongmaskiner": "betongmaskin",
    "betongmaskinerna": "betongmaskin",
    "betongmaskinernas": "betongmaskin",
    "betongmaskiners": "betongmaskin",
    "betongmaskins": "betongmaskin",
    "betongpartier": "betongparti",
    "betongpartierna": "betongparti",
    "betongpartiernas": "betongparti",
    "betongpartiers": "betongparti",
    "betongpartiet": "betongparti",
    "betongpartiets": "betongparti",
    "betongpartis": "betongparti",
    "betongpartit": "betongparti",
    "betongpartits": "betongparti",
    "betongpål": "betongpåle",
    "betongpålar": "betongpåle",
    "betongpålarna": "betongpåle",
    "betongpålarnas": "betongpåle",
    "betongpålars": "betongpåle",
    "betongpålen": "betongpåle",
    "betongpålens": "betongpåle",
    "betongpåles": "betongpåle",
    "betongpåls": "betongpåle",
    "betongs": "betong",
    "betongsuggan": "betongsugga",
    "betongsuggans": "betongsugga",
    "betongsuggas": "betongsugga",
    "betongsugge": "betongsugga",
    "betongsuggor": "betongsugga",
    "betongsuggorna": "betongsugga",
    "betongsuggornas": "betongsugga",
    "betongsuggors": "betongsugga",
    "betongvibratorer": "betongvibrator",
    "betongvibratorerna": "betongvibrator",
    "betongvibratorernas": "betongvibrator",
    "betongvibratorers": "betongvibrator",
    "betongvibratorn": "betongvibrator",
    "betongvibratorns": "betongvibrator",
    "betongvibrators": "betongvibrator",
    "betoningar": "betoning",
    "betoningarna": "betoning",
    "betoningarnas": "betoning",
    "betoningars": "betoning",
    "betoningen": "betoning",
    "betoningens": "betoning",
    "betonings": "betoning",
    "betor": "beta",
    "betorna": "beta",
    "betornas": "beta",
    "betors": "beta",
    "betrakt": "betrakta",
    "betraktad": "betrakta",
    "betraktade": "betrakta",
    "betraktades": "betrakta",
    "betraktads": "betrakta",
    "betraktande": "betrakta",
    "betraktandes": "betraktande",
    "betraktandet": "betraktande",
    "betraktandets": "betraktande",
    "betraktar": "betraktare",
    "betraktaren": "betraktare",
    "betraktarens": "betraktare",
    "betraktares": "betraktare",
    "betraktarna": "betraktare",
    "betraktarnas": "betraktare",
    "betraktas": "betrakta",
    "betraktat": "betrakta",
    "betraktats": "betrakta",
    "betraktelsen": "betraktelse",
    "betraktelsens": "betraktelse",
    "betraktelser": "betraktelse",
    "betraktelserna": "betraktelse",
    "betraktelsernas": "betraktelse",
    "betraktelsers": "betraktelse",
    "betraktelses": "betraktelse",
    "betraktelsesätten": "betraktelsesätt",
    "betraktelsesättens": "betraktelsesätt",
    "betraktelsesättet": "betraktelsesätt",
    "betraktelsesättets": "betraktelsesätt",
    "betraktelsesätts": "betraktelsesätt",
    "betrodd": "betro",
    "betrodda": "betrodd",
    "betroddare": "betrodd",
    "betroddares": "betrodd",
    "betroddas": "betrodd",
    "betroddast": "betrodd",
    "betroddaste": "betrodd",
    "betroddastes": "betrodd",
    "betroddasts": "betrodd",
    "betrodde": "betrodd",
    "betroddes": "betrodd",
    "betroddheten": "betroddhet",
    "betroddhetens": "betroddhet",
    "betroddhets": "betroddhet",
    "betrodds": "betrodd",
    "betroende": "betro",
    "betroenden": "betroende",
    "betroendena": "betroende",
    "betroendenas": "betroende",
    "betroendens": "betroende",
    "betroendes": "betroende",
    "betroendet": "betroende",
    "betroendets": "betroende",
    "betror": "betro",
    "betros": "betro",
    "betrott": "betrodd",
    "betrotts": "betrodd",
    "betryck": "betrycka",
    "betryckande": "betrycka",
    "betryckanden": "betryckande",
    "betryckandena": "betryckande",
    "betryckandenas": "betryckande",
    "betryckandens": "betryckande",
    "betryckandes": "betryckande",
    "betryckandet": "betryckande",
    "betryckandets": "betryckande",
    "betryckas": "betrycka",
    "betrycker": "betrycka",
    "betryckes": "betrycka",
    "betrycket": "betryck",
    "betryckets": "betryck",
    "betrycks": "betrycka",
    "betryckt": "betrycka",
    "betryckta": "betryckt",
    "betrycktare": "betryckt",
    "betrycktares": "betryckt",
    "betrycktas": "betryckt",
    "betrycktast": "betryckt",
    "betrycktaste": "betryckt",
    "betrycktastes": "betryckt",
    "betrycktasts": "betryckt",
    "betryckte": "betryckt",
    "betrycktes": "betryckt",
    "betrycktheten": "betryckthet",
    "betryckthetens": "betryckthet",
    "betryckthets": "betryckthet",
    "betryckts": "betryckt",
    "betrygg": "betrygga",
    "betryggad": "betrygga",
    "betryggade": "betrygga",
    "betryggades": "betrygga",
    "betryggads": "betrygga",
    "betryggande": "betrygga",
    "betrygganden": "betryggande",
    "betryggandena": "betryggande",
    "betryggandenas": "betryggande",
    "betryggandens": "betryggande",
    "betryggandes": "betryggande",
    "betryggandet": "betryggande",
    "betryggandets": "betryggande",
    "betryggar": "betrygga",
    "betryggas": "betrygga",
    "betryggat": "betrygga",
    "betryggats": "betrygga",
    "beträd": "beträda",
    "beträdande": "beträda",
    "beträdanden": "beträdande",
    "beträdandena": "beträdande",
    "beträdandenas": "beträdande",
    "beträdandens": "beträdande",
    "beträdandes": "beträdande",
    "beträdandet": "beträdande",
    "beträdandets": "beträdande",
    "beträdas": "beträda",
    "beträdd": "beträda",
    "beträdda": "beträda",
    "beträddas": "beträda",
    "beträdde": "beträda",
    "beträddes": "beträda",
    "beträdds": "beträda",
    "beträder": "beträda",
    "beträdes": "beträda",
    "beträds": "beträda",
    "beträff": "beträffa",
    "beträffad": "beträffa",
    "beträffade": "beträffa",
    "beträffades": "beträffa",
    "beträffads": "beträffa",
    "beträffande": "beträffa",
    "beträffanden": "beträffande",
    "beträffandena": "beträffande",
    "beträffandenas": "beträffande",
    "beträffandens": "beträffande",
    "beträffandes": "beträffande",
    "beträffandet": "beträffande",
    "beträffandets": "beträffande",
    "beträffar": "beträffa",
    "beträffas": "beträffa",
    "beträffat": "beträffa",
    "beträffats": "beträffa",
    "beträngda": "beträngd",
    "beträngdare": "beträngd",
    "beträngdares": "beträngd",
    "beträngdas": "beträngd",
    "beträngdast": "beträngd",
    "beträngdaste": "beträngd",
    "beträngdastes": "beträngd",
    "beträngdasts": "beträngd",
    "beträngde": "beträngd",
    "beträngdes": "beträngd",
    "beträngdheten": "beträngdhet",
    "beträngdhetens": "beträngdhet",
    "beträngdhets": "beträngdhet",
    "beträngds": "beträngd",
    "beträngt": "beträngd",
    "beträngts": "beträngd",
    "beträtt": "beträda",
    "beträtts": "beträda",
    "bets": "bitas",
    "betsad": "betsa",
    "betsade": "betsa",
    "betsades": "betsa",
    "betsads": "betsa",
    "betsande": "betsa",
    "betsanden": "betsande",
    "betsandena": "betsande",
    "betsandenas": "betsande",
    "betsandens": "betsande",
    "betsandes": "betsande",
    "betsandet": "betsande",
    "betsandets": "betsande",
    "betsar": "betsa",
    "betsas": "betsa",
    "betsat": "betsa",
    "betsats": "betsa",
    "betsels": "betsel",
    "betsen": "bets",
    "betsens": "bets",
    "betser": "bets",
    "betserna": "bets",
    "betsernas": "bets",
    "betsers": "bets",
    "betslad": "betsla",
    "betslade": "betsla",
    "betslades": "betsla",
    "betslads": "betsla",
    "betslande": "betsla",
    "betslanden": "betslande",
    "betslandena": "betslande",
    "betslandenas": "betslande",
    "betslandens": "betslande",
    "betslandes": "betslande",
    "betslandet": "betslande",
    "betslandets": "betslande",
    "betslar": "betsla",
    "betslas": "betsla",
    "betslat": "betsla",
    "betslats": "betsla",
    "betslen": "betsel",
    "betslens": "betsel",
    "betslet": "betsel",
    "betslets": "betsel",
    "betsmedels": "betsmedel",
    "betsmedlen": "betsmedel",
    "betsmedlens": "betsmedel",
    "betsmedlet": "betsmedel",
    "betsmedlets": "betsmedel",
    "betsningar": "betsning",
    "betsningarna": "betsning",
    "betsningarnas": "betsning",
    "betsningars": "betsning",
    "betsningen": "betsning",
    "betsningens": "betsning",
    "betsnings": "betsning",
    "betsockers": "betsocker",
    "betsockret": "betsocker",
    "betsockrets": "betsocker",
    "bett": "be",
    "bettel": "bettla",
    "betteln": "bettel",
    "bettelns": "bettel",
    "bettels": "bettel",
    "betten": "bett",
    "bettens": "bett",
    "bettet": "bett",
    "bettets": "bett",
    "bettlade": "bettla",
    "bettlades": "bettla",
    "bettlande": "bettla",
    "bettlanden": "bettlande",
    "bettlandena": "bettlande",
    "bettlandenas": "bettlande",
    "bettlandens": "bettlande",
    "bettlandes": "bettlande",
    "bettlandet": "bettlande",
    "bettlandets": "bettlande",
    "bettlar": "bettlare",
    "bettlaren": "bettlare",
    "bettlarens": "bettlare",
    "bettlares": "bettlare",
    "bettlarna": "bettlare",
    "bettlarnas": "bettlare",
    "bettlars": "bettel",
    "bettlas": "bettla",
    "bettlat": "bettla",
    "bettlats": "bettla",
    "bettleriet": "bettleri",
    "bettleriets": "bettleri",
    "bettleris": "bettleri",
    "bettlerit": "bettleri",
    "bettlerits": "bettleri",
    "betts": "bett",
    "betung": "betunga",
    "betungad": "betunga",
    "betungade": "betunga",
    "betungades": "betunga",
    "betungads": "betunga",
    "betungande": "betunga",
    "betunganden": "betungande",
    "betungandena": "betungande",
    "betungandenas": "betungande",
    "betungandens": "betungande",
    "betungandes": "betungande",
    "betungandet": "betungande",
    "betungandets": "betungande",
    "betungar": "betunga",
    "betungas": "betunga",
    "betungat": "betunga",
    "betungats": "betunga",
    "betuttade": "betuttad",
    "betuttades": "betuttad",
    "betuttads": "betuttad",
    "betuttat": "betuttad",
    "betuttats": "betuttad",
    "betvang": "betvinga",
    "betvangs": "betvinga",
    "betving": "betvinga",
    "betvingad": "betvinga",
    "betvingade": "betvinga",
    "betvingades": "betvinga",
    "betvingads": "betvinga",
    "betvingande": "betvinga",
    "betvinganden": "betvingande",
    "betvingandena": "betvingande",
    "betvingandenas": "betvingande",
    "betvingandens": "betvingande",
    "betvingandes": "betvingande",
    "betvingandet": "betvingande",
    "betvingandets": "betvingande",
    "betvingar": "betvinga",
    "betvingas": "betvinga",
    "betvingat": "betvinga",
    "betvingats": "betvinga",
    "betvinge": "betvinga",
    "betvinges": "betvinga",
    "betvivlad": "betvivla",
    "betvivlade": "betvivla",
    "betvivlades": "betvivla",
    "betvivlads": "betvivla",
    "betvivlande": "betvivla",
    "betvivlanden": "betvivlande",
    "betvivlandena": "betvivlande",
    "betvivlandenas": "betvivlande",
    "betvivlandens": "betvivlande",
    "betvivlandes": "betvivlande",
    "betvivlandet": "betvivlande",
    "betvivlandets": "betvivlande",
    "betvivlar": "betvivla",
    "betvivlas": "betvivla",
    "betvivlat": "betvivla",
    "betvivlats": "betvivla",
    "betvunge": "betvinga",
    "betvungen": "betvinga",
    "betvungens": "betvinga",
    "betvunges": "betvinga",
    "betvunget": "betvinga",
    "betvungets": "betvinga",
    "betvungit": "betvinga",
    "betvungits": "betvinga",
    "betvungna": "betvinga",
    "betvungnas": "betvinga",
    "betvungne": "betvinga",
    "betvungnes": "betvinga",
    "betyd": "betyda",
    "betydande": "betyda",
    "betydanden": "betydande",
    "betydandena": "betydande",
    "betydandenas": "betydande",
    "betydandens": "betydande",
    "betydandes": "betydande",
    "betydandet": "betydande",
    "betydandets": "betydande",
    "betydas": "betyda",
    "betydd": "betyda",
    "betydda": "betyda",
    "betyddas": "betyda",
    "betydde": "betyda",
    "betyddes": "betyda",
    "betydds": "betyda",
    "betydelsefattiga": "betydelsefattig",
    "betydelsefattigare": "betydelsefattig",
    "betydelsefattigares": "betydelsefattig",
    "betydelsefattigas": "betydelsefattig",
    "betydelsefattigast": "betydelsefattig",
    "betydelsefattigaste": "betydelsefattig",
    "betydelsefattigastes": "betydelsefattig",
    "betydelsefattigasts": "betydelsefattig",
    "betydelsefattige": "betydelsefattig",
    "betydelsefattiges": "betydelsefattig",
    "betydelsefattigs": "betydelsefattig",
    "betydelsefattigt": "betydelsefattig",
    "betydelsefattigts": "betydelsefattig",
    "betydelsefulla": "betydelsefull",
    "betydelsefullare": "betydelsefull",
    "betydelsefullares": "betydelsefull",
    "betydelsefullas": "betydelsefull",
    "betydelsefullast": "betydelsefull",
    "betydelsefullaste": "betydelsefull",
    "betydelsefullastes": "betydelsefull",
    "betydelsefullasts": "betydelsefull",
    "betydelsefulle": "betydelsefull",
    "betydelsefulles": "betydelsefull",
    "betydelsefullheten": "betydelsefullhet",
    "betydelsefullhetens": "betydelsefullhet",
    "betydelsefullhets": "betydelsefullhet",
    "betydelsefulls": "betydelsefull",
    "betydelsefullt": "betydelsefull",
    "betydelsefullts": "betydelsefull",
    "betydelseförskjutningar": "betydelseförskjutning",
    "betydelseförskjutningarna": "betydelseförskjutning",
    "betydelseförskjutningarnas": "betydelseförskjutning",
    "betydelseförskjutningars": "betydelseförskjutning",
    "betydelseförskjutningen": "betydelseförskjutning",
    "betydelseförskjutningens": "betydelseförskjutning",
    "betydelseförskjutnings": "betydelseförskjutning",
    "betydelseförändringar": "betydelseförändring",
    "betydelseförändringarna": "betydelseförändring",
    "betydelseförändringarnas": "betydelseförändring",
    "betydelseförändringars": "betydelseförändring",
    "betydelseförändringen": "betydelseförändring",
    "betydelseförändringens": "betydelseförändring",
    "betydelseförändrings": "betydelseförändring",
    "betydelseläran": "betydelselära",
    "betydelselärans": "betydelselära",
    "betydelseläras": "betydelselära",
    "betydelseläre": "betydelselära",
    "betydelseläro": "betydelselära",
    "betydelseläror": "betydelselära",
    "betydelselärorna": "betydelselära",
    "betydelselärornas": "betydelselära",
    "betydelselärors": "betydelselära",
    "betydelselösa": "betydelselös",
    "betydelselösare": "betydelselös",
    "betydelselösares": "betydelselös",
    "betydelselösas": "betydelselös",
    "betydelselösast": "betydelselös",
    "betydelselösaste": "betydelselös",
    "betydelselösastes": "betydelselös",
    "betydelselösasts": "betydelselös",
    "betydelselöse": "betydelselös",
    "betydelselöses": "betydelselös",
    "betydelselösheten": "betydelselöshet",
    "betydelselöshetens": "betydelselöshet",
    "betydelselöshets": "betydelselöshet",
    "betydelselöst": "betydelselös",
    "betydelselösts": "betydelselös",
    "betydelsemässiga": "betydelsemässig",
    "betydelsemässigare": "betydelsemässig",
    "betydelsemässigares": "betydelsemässig",
    "betydelsemässigas": "betydelsemässig",
    "betydelsemässigast": "betydelsemässig",
    "betydelsemässigaste": "betydelsemässig",
    "betydelsemässigastes": "betydelsemässig",
    "betydelsemässigasts": "betydelsemässig",
    "betydelsemässige": "betydelsemässig",
    "betydelsemässiges": "betydelsemässig",
    "betydelsemässigs": "betydelsemässig",
    "betydelsemässigt": "betydelsemässig",
    "betydelsemässigts": "betydelsemässig",
    "betydelsen": "betydelse",
    "betydelsens": "betydelse",
    "betydelsenyansen": "betydelsenyans",
    "betydelsenyansens": "betydelsenyans",
    "betydelsenyanser": "betydelsenyans",
    "betydelsenyanserna": "betydelsenyans",
    "betydelsenyansernas": "betydelsenyans",
    "betydelsenyansers": "betydelsenyans",
    "betydelser": "betydelse",
    "betydelserna": "betydelse",
    "betydelsernas": "betydelse",
    "betydelsers": "betydelse",
    "betydelses": "betydelse",
    "betydelseskikten": "betydelseskikt",
    "betydelseskiktens": "betydelseskikt",
    "betydelseskiktet": "betydelseskikt",
    "betydelseskiktets": "betydelseskikt",
    "betydelseskikts": "betydelseskikt",
    "betydelseutvecklingar": "betydelseutveckling",
    "betydelseutvecklingarna": "betydelseutveckling",
    "betydelseutvecklingarnas": "betydelseutveckling",
    "betydelseutvecklingars": "betydelseutveckling",
    "betydelseutvecklingen": "betydelseutveckling",
    "betydelseutvecklingens": "betydelseutveckling",
    "betydelseutvecklings": "betydelseutveckling",
    "betydenheten": "betydenhet",
    "betydenhetens": "betydenhet",
    "betydenheter": "betydenhet",
    "betydenheterna": "betydenhet",
    "betydenheternas": "betydenhet",
    "betydenheters": "betydenhet",
    "betydenhets": "betydenhet",
    "betyder": "betyda",
    "betydes": "betyda",
    "betydliga": "betydlig",
    "betydligare": "betydlig",
    "betydligares": "betydlig",
    "betydligas": "betydlig",
    "betydligast": "betydlig",
    "betydligaste": "betydlig",
    "betydligastes": "betydlig",
    "betydligasts": "betydlig",
    "betydlige": "betydlig",
    "betydliges": "betydlig",
    "betydligheten": "betydlighet",
    "betydlighetens": "betydlighet",
    "betydlighets": "betydlighet",
    "betydligs": "betydlig",
    "betydligt": "betydlig",
    "betydligts": "betydlig",
    "betyds": "betyda",
    "betyg": "betyga",
    "betygad": "betyga",
    "betygade": "betyga",
    "betygades": "betyga",
    "betygads": "betyga",
    "betygande": "betyga",
    "betyganden": "betygande",
    "betygandena": "betygande",
    "betygandenas": "betygande",
    "betygandens": "betygande",
    "betygandes": "betygande",
    "betygandet": "betygande",
    "betygandets": "betygande",
    "betygar": "betyga",
    "betygas": "betyga",
    "betygat": "betyga",
    "betygats": "betyga",
    "betygelsen": "betygelse",
    "betygelsens": "betygelse",
    "betygelser": "betygelse",
    "betygelserna": "betygelse",
    "betygelsernas": "betygelse",
    "betygelsers": "betygelse",
    "betygelses": "betygelse",
    "betygen": "betyg",
    "betygens": "betyg",
    "betyget": "betyg",
    "betygets": "betyg",
    "betygs": "betyg",
    "betygsatt": "betygsätta",
    "betygsatta": "betygsätta",
    "betygsattas": "betygsätta",
    "betygsatte": "betygsätta",
    "betygsattes": "betygsätta",
    "betygsatts": "betygsätta",
    "betygsavskriften": "betygsavskrift",
    "betygsavskriftens": "betygsavskrift",
    "betygsavskrifter": "betygsavskrift",
    "betygsavskrifterna": "betygsavskrift",
    "betygsavskrifternas": "betygsavskrift",
    "betygsavskrifters": "betygsavskrift",
    "betygsavskrifts": "betygsavskrift",
    "betygsfria": "betygsfri",
    "betygsfriare": "betygsfri",
    "betygsfriares": "betygsfri",
    "betygsfrias": "betygsfri",
    "betygsfriast": "betygsfri",
    "betygsfriaste": "betygsfri",
    "betygsfriastes": "betygsfri",
    "betygsfriasts": "betygsfri",
    "betygsfrie": "betygsfri",
    "betygsfries": "betygsfri",
    "betygsfris": "betygsfri",
    "betygsfritt": "betygsfri",
    "betygsfritts": "betygsfri",
    "betygsgraden": "betygsgrad",
    "betygsgradens": "betygsgrad",
    "betygsgrader": "betygsgrad",
    "betygsgraderna": "betygsgrad",
    "betygsgradernas": "betygsgrad",
    "betygsgraders": "betygsgrad",
    "betygsgrads": "betygsgrad",
    "betygshetsen": "betygshets",
    "betygshetsens": "betygshets",
    "betygsjäkten": "betygsjäkt",
    "betygsjäktens": "betygsjäkt",
    "betygsjäkts": "betygsjäkt",
    "betygskatalogen": "betygskatalog",
    "betygskatalogens": "betygskatalog",
    "betygskataloger": "betygskatalog",
    "betygskatalogerna": "betygskatalog",
    "betygskatalogernas": "betygskatalog",
    "betygskatalogers": "betygskatalog",
    "betygskatalogs": "betygskatalog",
    "betygsnämnden": "betygsnämnd",
    "betygsnämndens": "betygsnämnd",
    "betygsnämnder": "betygsnämnd",
    "betygsnämnderna": "betygsnämnd",
    "betygsnämndernas": "betygsnämnd",
    "betygsnämnders": "betygsnämnd",
    "betygsnämnds": "betygsnämnd",
    "betygsskal": "betygsskala",
    "betygsskalan": "betygsskala",
    "betygsskalans": "betygsskala",
    "betygsskalas": "betygsskala",
    "betygsskale": "betygsskala",
    "betygsskalor": "betygsskala",
    "betygsskalorna": "betygsskala",
    "betygsskalornas": "betygsskala",
    "betygsskalors": "betygsskala",
    "betygsskals": "betygsskala",
    "betygsätt": "betygsätta",
    "betygsättande": "betygsätta",
    "betygsättanden": "betygsättande",
    "betygsättandena": "betygsättande",
    "betygsättandenas": "betygsättande",
    "betygsättandens": "betygsättande",
    "betygsättandes": "betygsättande",
    "betygsättandet": "betygsättande",
    "betygsättandets": "betygsättande",
    "betygsättas": "betygsätta",
    "betygsätter": "betygsätta",
    "betygsättes": "betygsätta",
    "betygsättningar": "betygsättning",
    "betygsättningarna": "betygsättning",
    "betygsättningarnas": "betygsättning",
    "betygsättningars": "betygsättning",
    "betygsättningen": "betygsättning",
    "betygsättningens": "betygsättning",
    "betygsättnings": "betygsättning",
    "betygsätts": "betygsätta",
    "betytt": "betyda",
    "betytts": "betyda",
    "betäck": "betäcka",
    "betäckande": "betäcka",
    "betäckanden": "betäckande",
    "betäckandena": "betäckande",
    "betäckandenas": "betäckande",
    "betäckandens": "betäckande",
    "betäckandes": "betäckande",
    "betäckandet": "betäckande",
    "betäckandets": "betäckande",
    "betäckas": "betäcka",
    "betäcker": "betäcka",
    "betäckes": "betäcka",
    "betäckningar": "betäckning",
    "betäckningarna": "betäckning",
    "betäckningarnas": "betäckning",
    "betäckningars": "betäckning",
    "betäckningen": "betäckning",
    "betäckningens": "betäckning",
    "betäcknings": "betäckning",
    "betäcks": "betäcka",
    "betäckt": "betäcka",
    "betäckta": "betäcka",
    "betäcktas": "betäcka",
    "betäckte": "betäcka",
    "betäcktes": "betäcka",
    "betäckts": "betäcka",
    "betänk": "betänka",
    "betänkande": "betänka",
    "betänkanden": "betänkande",
    "betänkandena": "betänkande",
    "betänkandenas": "betänkande",
    "betänkandens": "betänkande",
    "betänkandes": "betänkande",
    "betänkandet": "betänkande",
    "betänkandets": "betänkande",
    "betänkas": "betänka",
    "betänker": "betänka",
    "betänkes": "betänka",
    "betänketiden": "betänketid",
    "betänketidens": "betänketid",
    "betänketider": "betänketid",
    "betänketiderna": "betänketid",
    "betänketidernas": "betänketid",
    "betänketiders": "betänketid",
    "betänketids": "betänketid",
    "betänkliga": "betänklig",
    "betänkligare": "betänklig",
    "betänkligares": "betänklig",
    "betänkligas": "betänklig",
    "betänkligast": "betänklig",
    "betänkligaste": "betänklig",
    "betänkligastes": "betänklig",
    "betänkligasts": "betänklig",
    "betänklige": "betänklig",
    "betänkliges": "betänklig",
    "betänkligheten": "betänklighet",
    "betänklighetens": "betänklighet",
    "betänkligheter": "betänklighet",
    "betänkligheterna": "betänklighet",
    "betänkligheternas": "betänklighet",
    "betänkligheters": "betänklighet",
    "betänklighets": "betänklighet",
    "betänkligs": "betänklig",
    "betänkligt": "betänklig",
    "betänkligts": "betänklig",
    "betänks": "betänka",
    "betänksamheten": "betänksamhet",
    "betänksamhetens": "betänksamhet",
    "betänksamhets": "betänksamhet",
    "betänksamma": "betänksam",
    "betänksammare": "betänksam",
    "betänksammares": "betänksam",
    "betänksammas": "betänksam",
    "betänksammast": "betänksam",
    "betänksammaste": "betänksam",
    "betänksammastes": "betänksam",
    "betänksammasts": "betänksam",
    "betänksamme": "betänksam",
    "betänksammes": "betänksam",
    "betänksams": "betänksam",
    "betänksamt": "betänksam",
    "betänksamts": "betänksam",
    "betänkt": "betänka",
    "betänkta": "betänkt",
    "betänktare": "betänkt",
    "betänktares": "betänkt",
    "betänktas": "betänkt",
    "betänktast": "betänkt",
    "betänktaste": "betänkt",
    "betänktastes": "betänkt",
    "betänktasts": "betänkt",
    "betänkte": "betänkt",
    "betänktes": "betänkt",
    "betänkts": "betänkt",
    "beundrad": "beundra",
    "beundrade": "beundra",
    "beundrades": "beundra",
    "beundrads": "beundra",
    "beundrande": "beundra",
    "beundranden": "beundrande",
    "beundrandena": "beundrande",
    "beundrandenas": "beundrande",
    "beundrandens": "beundrande",
    "beundrandes": "beundrande",
    "beundrandet": "beundrande",
    "beundrandets": "beundrande",
    "beundrans": "beundran",
    "beundransvärda": "beundransvärd",
    "beundransvärdare": "beundransvärd",
    "beundransvärdares": "beundransvärd",
    "beundransvärdas": "beundransvärd",
    "beundransvärdast": "beundransvärd",
    "beundransvärdaste": "beundransvärd",
    "beundransvärdastes": "beundransvärd",
    "beundransvärdasts": "beundransvärd",
    "beundransvärde": "beundransvärd",
    "beundransvärdes": "beundransvärd",
    "beundransvärdheten": "beundransvärdhet",
    "beundransvärdhetens": "beundransvärdhet",
    "beundransvärdhets": "beundransvärdhet",
    "beundransvärds": "beundransvärd",
    "beundransvärt": "beundransvärd",
    "beundransvärts": "beundransvärd",
    "beundrar": "beundrare",
    "beundraren": "beundrare",
    "beundrarens": "beundrare",
    "beundrares": "beundrare",
    "beundrarinnan": "beundrarinna",
    "beundrarinnans": "beundrarinna",
    "beundrarinnas": "beundrarinna",
    "beundrarinne": "beundrarinna",
    "beundrarinnor": "beundrarinna",
    "beundrarinnorna": "beundrarinna",
    "beundrarinnornas": "beundrarinna",
    "beundrarinnors": "beundrarinna",
    "beundrarna": "beundrare",
    "beundrarnas": "beundrare",
    "beundras": "beundra",
    "beundrat": "beundra",
    "beundrats": "beundra",
    "bevak": "bevaka",
    "bevakad": "bevaka",
    "bevakade": "bevaka",
    "bevakades": "bevaka",
    "bevakads": "bevaka",
    "bevakande": "bevaka",
    "bevakanden": "bevakande",
    "bevakandena": "bevakande",
    "bevakandenas": "bevakande",
    "bevakandens": "bevakande",
    "bevakandes": "bevakande",
    "bevakandet": "bevakande",
    "bevakandets": "bevakande",
    "bevakar": "bevaka",
    "bevakas": "bevaka",
    "bevakat": "bevaka",
    "bevakats": "bevaka",
    "bevakningar": "bevakning",
    "bevakningarna": "bevakning",
    "bevakningarnas": "bevakning",
    "bevakningars": "bevakning",
    "bevakningen": "bevakning",
    "bevakningens": "bevakning",
    "bevaknings": "bevakning",
    "bevakningsinlag": "bevakningsinlaga",
    "bevakningsinlagan": "bevakningsinlaga",
    "bevakningsinlagans": "bevakningsinlaga",
    "bevakningsinlagas": "bevakningsinlaga",
    "bevakningsinlage": "bevakningsinlaga",
    "bevakningsinlagor": "bevakningsinlaga",
    "bevakningsinlagorna": "bevakningsinlaga",
    "bevakningsinlagornas": "bevakningsinlaga",
    "bevakningsinlagors": "bevakningsinlaga",
    "bevakningsinlags": "bevakningsinlaga",
    "bevakningskedjan": "bevakningskedja",
    "bevakningskedjans": "bevakningskedja",
    "bevakningskedjas": "bevakningskedja",
    "bevakningskedje": "bevakningskedja",
    "bevakningskedjor": "bevakningskedja",
    "bevakningskedjorna": "bevakningskedja",
    "bevakningskedjornas": "bevakningskedja",
    "bevakningskedjors": "bevakningskedja",
    "bevakningsområden": "bevakningsområde",
    "bevakningsområdena": "bevakningsområde",
    "bevakningsområdenas": "bevakningsområde",
    "bevakningsområdens": "bevakningsområde",
    "bevakningsområdes": "bevakningsområde",
    "bevakningsområdet": "bevakningsområde",
    "bevakningsområdets": "bevakningsområde",
    "bevakningsuppdragen": "bevakningsuppdrag",
    "bevakningsuppdragens": "bevakningsuppdrag",
    "bevakningsuppdraget": "bevakningsuppdrag",
    "bevakningsuppdragets": "bevakningsuppdrag",
    "bevakningsuppdrags": "bevakningsuppdrag",
    "bevandrade": "bevandrad",
    "bevandrades": "bevandrad",
    "bevandrads": "bevandrad",
    "bevandrat": "bevandrad",
    "bevandrats": "bevandrad",
    "bevar": "bevara",
    "bevarad": "bevara",
    "bevarade": "bevara",
    "bevarades": "bevara",
    "bevarads": "bevara",
    "bevarande": "bevara",
    "bevaranden": "bevarande",
    "bevarandena": "bevarande",
    "bevarandenas": "bevarande",
    "bevarandens": "bevarande",
    "bevarandes": "bevarande",
    "bevarandet": "bevarande",
    "bevarandets": "bevarande",
    "bevarar": "bevara",
    "bevaras": "bevara",
    "bevarat": "bevara",
    "bevarats": "bevara",
    "bevattn": "bevattna",
    "bevattnad": "bevattna",
    "bevattnade": "bevattna",
    "bevattnades": "bevattna",
    "bevattnads": "bevattna",
    "bevattnande": "bevattna",
    "bevattnanden": "bevattnande",
    "bevattnandena": "bevattnande",
    "bevattnandenas": "bevattnande",
    "bevattnandens": "bevattnande",
    "bevattnandes": "bevattnande",
    "bevattnandet": "bevattnande",
    "bevattnandets": "bevattnande",
    "bevattnar": "bevattna",
    "bevattnas": "bevattna",
    "bevattnat": "bevattna",
    "bevattnats": "bevattna",
    "bevattningar": "bevattning",
    "bevattningarna": "bevattning",
    "bevattningarnas": "bevattning",
    "bevattningars": "bevattning",
    "bevattningen": "bevattning",
    "bevattningens": "bevattning",
    "bevattnings": "bevattning",
    "bevattningsanläggningar": "bevattningsanläggning",
    "bevattningsanläggningarna": "bevattningsanläggning",
    "bevattningsanläggningarnas": "bevattningsanläggning",
    "bevattningsanläggningars": "bevattningsanläggning",
    "bevattningsanläggningen": "bevattningsanläggning",
    "bevattningsanläggningens": "bevattningsanläggning",
    "bevattningsanläggnings": "bevattningsanläggning",
    "bevattningsregeln": "bevattningsregel",
    "bevattningsregelns": "bevattningsregel",
    "bevattningsregels": "bevattningsregel",
    "bevattningsregler": "bevattningsregel",
    "bevattningsreglerna": "bevattningsregel",
    "bevattningsreglernas": "bevattningsregel",
    "bevattningsreglers": "bevattningsregel",
    "bevek": "beveka",
    "bevekad": "beveka",
    "bevekade": "beveka",
    "bevekades": "beveka",
    "bevekads": "beveka",
    "bevekande": "beveka",
    "bevekanden": "bevekande",
    "bevekandena": "bevekande",
    "bevekandenas": "bevekande",
    "bevekandens": "bevekande",
    "bevekandes": "bevekande",
    "bevekandet": "bevekande",
    "bevekandets": "bevekande",
    "bevekar": "beveka",
    "bevekas": "beveka",
    "bevekat": "beveka",
    "bevekats": "beveka",
    "bevekelsegrunden": "bevekelsegrund",
    "bevekelsegrundens": "bevekelsegrund",
    "bevekelsegrunder": "bevekelsegrund",
    "bevekelsegrunderna": "bevekelsegrund",
    "bevekelsegrundernas": "bevekelsegrund",
    "bevekelsegrunders": "bevekelsegrund",
    "bevekelsegrunds": "bevekelsegrund",
    "bevekelsen": "bevekelse",
    "bevekelsens": "bevekelse",
    "bevekelser": "bevekelse",
    "bevekelserna": "bevekelse",
    "bevekelsernas": "bevekelse",
    "bevekelsers": "bevekelse",
    "bevekelses": "bevekelse",
    "beveker": "beveka",
    "bevekes": "beveka",
    "beveks": "beveka",
    "bevekt": "beveka",
    "bevekta": "beveka",
    "bevektas": "beveka",
    "bevekte": "beveka",
    "bevektes": "beveka",
    "bevekts": "beveka",
    "bevilj": "bevilja",
    "beviljad": "bevilja",
    "beviljade": "bevilja",
    "beviljades": "bevilja",
    "beviljads": "bevilja",
    "beviljande": "bevilja",
    "beviljanden": "beviljande",
    "beviljandena": "beviljande",
    "beviljandenas": "beviljande",
    "beviljandens": "beviljande",
    "beviljandes": "beviljande",
    "beviljandet": "beviljande",
    "beviljandets": "beviljande",
    "beviljar": "bevilja",
    "beviljas": "bevilja",
    "beviljat": "bevilja",
    "beviljats": "bevilja",
    "bevillningar": "bevillning",
    "bevillningarna": "bevillning",
    "bevillningarnas": "bevillning",
    "bevillningars": "bevillning",
    "bevillningen": "bevillning",
    "bevillningens": "bevillning",
    "bevillnings": "bevillning",
    "bevillningsavgiften": "bevillningsavgift",
    "bevillningsavgiftens": "bevillningsavgift",
    "bevillningsavgifter": "bevillningsavgift",
    "bevillningsavgifterna": "bevillningsavgift",
    "bevillningsavgifternas": "bevillningsavgift",
    "bevillningsavgifters": "bevillningsavgift",
    "bevillningsavgifts": "bevillningsavgift",
    "bevillningsutskotten": "bevillningsutskott",
    "bevillningsutskottens": "bevillningsutskott",
    "bevillningsutskottet": "bevillningsutskott",
    "bevillningsutskottets": "bevillningsutskott",
    "bevillningsutskotts": "bevillningsutskott",
    "bevingade": "bevingad",
    "bevingades": "bevingad",
    "bevingads": "bevingad",
    "bevingat": "bevingad",
    "bevingats": "bevingad",
    "bevisad": "bevisa",
    "bevisade": "bevisa",
    "bevisades": "bevisa",
    "bevisads": "bevisa",
    "bevisande": "bevisa",
    "bevisanden": "bevisande",
    "bevisandena": "bevisande",
    "bevisandenas": "bevisande",
    "bevisandens": "bevisande",
    "bevisandes": "bevisande",
    "bevisandet": "bevisande",
    "bevisandets": "bevisande",
    "bevisar": "bevisa",
    "bevisas": "bevisa",
    "bevisat": "bevisa",
    "bevisats": "bevisa",
    "bevisbara": "bevisbar",
    "bevisbarare": "bevisbar",
    "bevisbarares": "bevisbar",
    "bevisbaras": "bevisbar",
    "bevisbarast": "bevisbar",
    "bevisbaraste": "bevisbar",
    "bevisbarastes": "bevisbar",
    "bevisbarasts": "bevisbar",
    "bevisbare": "bevisbar",
    "bevisbares": "bevisbar",
    "bevisbarheten": "bevisbarhet",
    "bevisbarhetens": "bevisbarhet",
    "bevisbarhets": "bevisbarhet",
    "bevisbars": "bevisbar",
    "bevisbart": "bevisbar",
    "bevisbarts": "bevisbar",
    "bevisbördan": "bevisbörda",
    "bevisbördans": "bevisbörda",
    "bevisbördas": "bevisbörda",
    "bevisbörde": "bevisbörda",
    "bevisbördor": "bevisbörda",
    "bevisbördorna": "bevisbörda",
    "bevisbördornas": "bevisbörda",
    "bevisbördors": "bevisbörda",
    "bevisen": "bevis",
    "bevisens": "bevis",
    "beviset": "bevis",
    "bevisets": "bevis",
    "bevisföringar": "bevisföring",
    "bevisföringarna": "bevisföring",
    "bevisföringarnas": "bevisföring",
    "bevisföringars": "bevisföring",
    "bevisföringen": "bevisföring",
    "bevisföringens": "bevisföring",
    "bevisförings": "bevisföring",
    "bevisförvanskningar": "bevisförvanskning",
    "bevisförvanskningarna": "bevisförvanskning",
    "bevisförvanskningarnas": "bevisförvanskning",
    "bevisförvanskningars": "bevisförvanskning",
    "bevisförvanskningen": "bevisförvanskning",
    "bevisförvanskningens": "bevisförvanskning",
    "bevisförvansknings": "bevisförvanskning",
    "beviskedjan": "beviskedja",
    "beviskedjans": "beviskedja",
    "beviskedjas": "beviskedja",
    "beviskedje": "beviskedja",
    "beviskedjor": "beviskedja",
    "beviskedjorna": "beviskedja",
    "beviskedjornas": "beviskedja",
    "beviskedjors": "beviskedja",
    "beviskraften": "beviskraft",
    "beviskraftens": "beviskraft",
    "beviskrafter": "beviskraft",
    "beviskrafterna": "beviskraft",
    "beviskrafternas": "beviskraft",
    "beviskrafters": "beviskraft",
    "beviskraftiga": "beviskraftig",
    "beviskraftigare": "beviskraftig",
    "beviskraftigares": "beviskraftig",
    "beviskraftigas": "beviskraftig",
    "beviskraftigast": "beviskraftig",
    "beviskraftigaste": "beviskraftig",
    "beviskraftigastes": "beviskraftig",
    "beviskraftigasts": "beviskraftig",
    "beviskraftige": "beviskraftig",
    "beviskraftiges": "beviskraftig",
    "beviskraftigheten": "beviskraftighet",
    "beviskraftighetens": "beviskraftighet",
    "beviskraftighets": "beviskraftighet",
    "beviskraftigs": "beviskraftig",
    "beviskraftigt": "beviskraftig",
    "beviskraftigts": "beviskraftig",
    "beviskrafts": "beviskraft",
    "beviskraven": "beviskrav",
    "beviskravens": "beviskrav",
    "beviskravet": "beviskrav",
    "beviskravets": "beviskrav",
    "beviskravs": "beviskrav",
    "bevisliga": "bevislig",
    "bevisligare": "bevislig",
    "bevisligares": "bevislig",
    "bevisligas": "bevislig",
    "bevisligast": "bevislig",
    "bevisligaste": "bevislig",
    "bevisligastes": "bevislig",
    "bevisligasts": "bevislig",
    "bevislige": "bevislig",
    "bevisliges": "bevislig",
    "bevisligheten": "bevislighet",
    "bevislighetens": "bevislighet",
    "bevislighets": "bevislighet",
    "bevisligs": "bevislig",
    "bevisligt": "bevislig",
    "bevisligts": "bevislig",
    "bevismaterialen": "bevismaterial",
    "bevismaterialens": "bevismaterial",
    "bevismaterialet": "bevismaterial",
    "bevismaterialets": "bevismaterial",
    "bevismaterials": "bevismaterial",
    "bevismedels": "bevismedel",
    "bevismedlen": "bevismedel",
    "bevismedlens": "bevismedel",
    "bevismedlet": "bevismedel",
    "bevismedlets": "bevismedel",
    "bevismässiga": "bevismässig",
    "bevismässigare": "bevismässig",
    "bevismässigares": "bevismässig",
    "bevismässigas": "bevismässig",
    "bevismässigast": "bevismässig",
    "bevismässigaste": "bevismässig",
    "bevismässigastes": "bevismässig",
    "bevismässigasts": "bevismässig",
    "bevismässige": "bevismässig",
    "bevismässiges": "bevismässig",
    "bevismässigs": "bevismässig",
    "bevismässigt": "bevismässig",
    "bevismässigts": "bevismässig",
    "bevisningar": "bevisning",
    "bevisningarna": "bevisning",
    "bevisningarnas": "bevisning",
    "bevisningars": "bevisning",
    "bevisningen": "bevisning",
    "bevisningens": "bevisning",
    "bevisnings": "bevisning",
    "bevisprövningar": "bevisprövning",
    "bevisprövningarna": "bevisprövning",
    "bevisprövningarnas": "bevisprövning",
    "bevisprövningars": "bevisprövning",
    "bevisprövningen": "bevisprövning",
    "bevisprövningens": "bevisprövning",
    "bevisprövnings": "bevisprövning",
    "bevisskyldiga": "bevisskyldig",
    "bevisskyldigare": "bevisskyldig",
    "bevisskyldigares": "bevisskyldig",
    "bevisskyldigas": "bevisskyldig",
    "bevisskyldigast": "bevisskyldig",
    "bevisskyldigaste": "bevisskyldig",
    "bevisskyldigastes": "bevisskyldig",
    "bevisskyldigasts": "bevisskyldig",
    "bevisskyldige": "bevisskyldig",
    "bevisskyldiges": "bevisskyldig",
    "bevisskyldigheten": "bevisskyldighet",
    "bevisskyldighetens": "bevisskyldighet",
    "bevisskyldighets": "bevisskyldighet",
    "bevisskyldigs": "bevisskyldig",
    "bevisskyldigt": "bevisskyldig",
    "bevisskyldigts": "bevisskyldig",
    "bevissäkringar": "bevissäkring",
    "bevissäkringarna": "bevissäkring",
    "bevissäkringarnas": "bevissäkring",
    "bevissäkringars": "bevissäkring",
    "bevissäkringen": "bevissäkring",
    "bevissäkringens": "bevissäkring",
    "bevissäkrings": "bevissäkring",
    "bevist": "bevista",
    "bevistad": "bevista",
    "bevistade": "bevista",
    "bevistades": "bevista",
    "bevistads": "bevista",
    "bevistande": "bevista",
    "bevistanden": "bevistande",
    "bevistandena": "bevistande",
    "bevistandenas": "bevistande",
    "bevistandens": "bevistande",
    "bevistandes": "bevistande",
    "bevistandet": "bevistande",
    "bevistandets": "bevistande",
    "bevistar": "bevista",
    "bevistas": "bevista",
    "bevistat": "bevista",
    "bevistats": "bevista",
    "bevisvärden": "bevisvärde",
    "bevisvärdena": "bevisvärde",
    "bevisvärdenas": "bevisvärde",
    "bevisvärdens": "bevisvärde",
    "bevisvärderingar": "bevisvärdering",
    "bevisvärderingarna": "bevisvärdering",
    "bevisvärderingarnas": "bevisvärdering",
    "bevisvärderingars": "bevisvärdering",
    "bevisvärderingen": "bevisvärdering",
    "bevisvärderingens": "bevisvärdering",
    "bevisvärderings": "bevisvärdering",
    "bevisvärdes": "bevisvärde",
    "bevisvärdet": "bevisvärde",
    "bevisvärdets": "bevisvärde",
    "bevittnad": "bevittna",
    "bevittnade": "bevittna",
    "bevittnades": "bevittna",
    "bevittnads": "bevittna",
    "bevittnande": "bevittna",
    "bevittnanden": "bevittnande",
    "bevittnandena": "bevittnande",
    "bevittnandenas": "bevittnande",
    "bevittnandens": "bevittnande",
    "bevittnandes": "bevittnande",
    "bevittnandet": "bevittnande",
    "bevittnandets": "bevittnande",
    "bevittnar": "bevittna",
    "bevittnas": "bevittna",
    "bevittnat": "bevittna",
    "bevittnats": "bevittna",
    "bevuxens": "bevuxen",
    "bevuxet": "bevuxen",
    "bevuxets": "bevuxen",
    "bevuxna": "bevuxen",
    "bevuxnare": "bevuxen",
    "bevuxnares": "bevuxen",
    "bevuxnas": "bevuxen",
    "bevuxnast": "bevuxen",
    "bevuxnaste": "bevuxen",
    "bevuxnastes": "bevuxen",
    "bevuxnasts": "bevuxen",
    "bevuxne": "bevuxen",
    "bevuxnes": "bevuxen",
    "beväpnad": "beväpna",
    "beväpnade": "beväpna",
    "beväpnades": "beväpna",
    "beväpnads": "beväpna",
    "beväpnae": "beväpna",
    "beväpnaes": "beväpna",
    "beväpnande": "beväpna",
    "beväpnanden": "beväpnande",
    "beväpnandena": "beväpnande",
    "beväpnandenas": "beväpnande",
    "beväpnandens": "beväpnande",
    "beväpnandes": "beväpnande",
    "beväpnandet": "beväpnande",
    "beväpnandets": "beväpnande",
    "beväpnar": "beväpna",
    "beväpnas": "beväpna",
    "beväpnat": "beväpna",
    "beväpnats": "beväpna",
    "beväpningar": "beväpning",
    "beväpningarna": "beväpning",
    "beväpningarnas": "beväpning",
    "beväpningars": "beväpning",
    "beväpningen": "beväpning",
    "beväpningens": "beväpning",
    "beväpnings": "beväpning",
    "beväpnt": "beväpna",
    "beväpnts": "beväpna",
    "bevärad": "bevära",
    "bevärade": "bevära",
    "bevärades": "bevära",
    "bevärads": "bevära",
    "bevärande": "bevära",
    "beväranden": "bevärande",
    "bevärandena": "bevärande",
    "bevärandenas": "bevärande",
    "bevärandens": "bevärande",
    "bevärandes": "bevärande",
    "bevärandet": "bevärande",
    "bevärandets": "bevärande",
    "bevärar": "bevära",
    "beväras": "bevära",
    "bevärat": "bevära",
    "bevärats": "bevära",
    "bevärdigad": "bevärdiga",
    "bevärdigade": "bevärdiga",
    "bevärdigades": "bevärdiga",
    "bevärdigads": "bevärdiga",
    "bevärdigande": "bevärdiga",
    "bevärdiganden": "bevärdigande",
    "bevärdigandena": "bevärdigande",
    "bevärdigandenas": "bevärdigande",
    "bevärdigandens": "bevärdigande",
    "bevärdigandes": "bevärdigande",
    "bevärdigandet": "bevärdigande",
    "bevärdigandets": "bevärdigande",
    "bevärdigar": "bevärdiga",
    "bevärdigas": "bevärdiga",
    "bevärdigat": "bevärdiga",
    "bevärdigats": "bevärdiga",
    "beväringar": "beväring",
    "beväringarna": "beväring",
    "beväringarnas": "beväring",
    "beväringars": "beväring",
    "beväringen": "beväring",
    "beväringens": "beväring",
    "bevärings": "beväring",
    "beväxta": "beväxt",
    "beväxtare": "beväxt",
    "beväxtares": "beväxt",
    "beväxtas": "beväxt",
    "beväxtast": "beväxt",
    "beväxtaste": "beväxt",
    "beväxtastes": "beväxt",
    "beväxtasts": "beväxt",
    "beväxte": "beväxt",
    "beväxtes": "beväxt",
    "beväxts": "beväxt",
    "bevågenheten": "bevågenhet",
    "bevågenhetens": "bevågenhet",
    "bevågenheter": "bevågenhet",
    "bevågenheterna": "bevågenhet",
    "bevågenheternas": "bevågenhet",
    "bevågenheters": "bevågenhet",
    "bevågenhets": "bevågenhet",
    "bevågens": "bevågen",
    "bevåget": "bevågen",
    "bevågets": "bevågen",
    "bevågna": "bevågen",
    "bevågnare": "bevågen",
    "bevågnares": "bevågen",
    "bevågnas": "bevågen",
    "bevågnast": "bevågen",
    "bevågnaste": "bevågen",
    "bevågnastes": "bevågen",
    "bevågnasts": "bevågen",
    "bevågne": "bevågen",
    "bevågnes": "bevågen",
    "beziquen": "bezique",
    "beziquens": "bezique",
    "beziques": "bezique",
    "bh-ar": "bh",
    "bh-arna": "bh",
    "bh-arnas": "bh",
    "bh-ars": "bh",
    "bh-en": "bh",
    "bh-ens": "bh",
    "bh-n": "bh",
    "bh-ns": "bh",
    "bh-s": "bh",
    "bh:ar": "bh",
    "bh:arna": "bh",
    "bh:arnas": "bh",
    "bh:ars": "bh",
    "bh:en": "bh",
    "bh:ens": "bh",
    "bh:n": "bh",
    "bh:ns": "bh",
    "bh:s": "bh",
    "bhar": "bh",
    "bharna": "bh",
    "bharnas": "bh",
    "bhars": "bh",
    "bhen": "bh",
    "bhens": "bh",
    "bhn": "bh",
    "bhns": "bh",
    "bhs": "bh",
    "bhutanesen": "bhutanes",
    "bhutanesens": "bhutanes",
    "bhutaneser": "bhutanes",
    "bhutaneserna": "bhutanes",
    "bhutanesernas": "bhutanes",
    "bhutanesers": "bhutanes",
    "bhutanesiska": "bhutanesisk",
    "bhutanesiskan": "bhutanesiska",
    "bhutanesiskans": "bhutanesiska",
    "bhutanesiskare": "bhutanesisk",
    "bhutanesiskares": "bhutanesisk",
    "bhutanesiskas": "bhutanesiska",
    "bhutanesiskast": "bhutanesisk",
    "bhutanesiskaste": "bhutanesisk",
    "bhutanesiskastes": "bhutanesisk",
    "bhutanesiskasts": "bhutanesisk",
    "bhutanesiske": "bhutanesiska",
    "bhutanesiskes": "bhutanesisk",
    "bhutanesiskor": "bhutanesiska",
    "bhutanesiskorna": "bhutanesiska",
    "bhutanesiskornas": "bhutanesiska",
    "bhutanesiskors": "bhutanesiska",
    "bhutanesisks": "bhutanesisk",
    "bhutanesiskt": "bhutanesisk",
    "bhutanesiskts": "bhutanesisk",
    "biaccenten": "biaccent",
    "biaccentens": "biaccent",
    "biaccenter": "biaccent",
    "biaccenterna": "biaccent",
    "biaccenternas": "biaccent",
    "biaccenters": "biaccent",
    "biaccents": "biaccent",
    "biasen": "bias",
    "biasens": "bias",
    "biaser": "bias",
    "biaserna": "bias",
    "biasernas": "bias",
    "biasers": "bias",
    "biaveln": "biavel",
    "biavelns": "biavel",
    "biavels": "biavel",
    "biavsikten": "biavsikt",
    "biavsiktens": "biavsikt",
    "biavsikter": "biavsikt",
    "biavsikterna": "biavsikt",
    "biavsikternas": "biavsikt",
    "biavsikters": "biavsikt",
    "biavsikts": "biavsikt",
    "bibanan": "bibana",
    "bibanans": "bibana",
    "bibanas": "bibana",
    "bibane": "bibana",
    "bibanor": "bibana",
    "bibanorna": "bibana",
    "bibanornas": "bibana",
    "bibanors": "bibana",
    "bibehåll": "bibehålla",
    "bibehållande": "bibehålla",
    "bibehållanden": "bibehållande",
    "bibehållandena": "bibehållande",
    "bibehållandenas": "bibehållande",
    "bibehållandens": "bibehållande",
    "bibehållandes": "bibehållande",
    "bibehållandet": "bibehållande",
    "bibehållandets": "bibehållande",
    "bibehållas": "bibehålla",
    "bibehålle": "bibehålla",
    "bibehållen": "bibehålla",
    "bibehållens": "bibehållen",
    "bibehåller": "bibehålla",
    "bibehålles": "bibehålla",
    "bibehållet": "bibehållen",
    "bibehållets": "bibehållen",
    "bibehållit": "bibehålla",
    "bibehållits": "bibehålla",
    "bibehållna": "bibehållen",
    "bibehållnare": "bibehållen",
    "bibehållnares": "bibehållen",
    "bibehållnas": "bibehållen",
    "bibehållnast": "bibehållen",
    "bibehållnaste": "bibehållen",
    "bibehållnastes": "bibehållen",
    "bibehållnasts": "bibehållen",
    "bibehållne": "bibehållen",
    "bibehållnes": "bibehållen",
    "bibehålls": "bibehålla",
    "bibehöll": "bibehålla",
    "bibehölle": "bibehålla",
    "bibehölles": "bibehålla",
    "bibehölls": "bibehålla",
    "bibelcitaten": "bibelcitat",
    "bibelcitatens": "bibelcitat",
    "bibelcitatet": "bibelcitat",
    "bibelcitatets": "bibelcitat",
    "bibelcitats": "bibelcitat",
    "bibelförklaringar": "bibelförklaring",
    "bibelförklaringarna": "bibelförklaring",
    "bibelförklaringarnas": "bibelförklaring",
    "bibelförklaringars": "bibelförklaring",
    "bibelförklaringen": "bibelförklaring",
    "bibelförklaringens": "bibelförklaring",
    "bibelförklarings": "bibelförklaring",
    "bibelhandskriften": "bibelhandskrift",
    "bibelhandskriftens": "bibelhandskrift",
    "bibelhandskrifter": "bibelhandskrift",
    "bibelhandskrifterna": "bibelhandskrift",
    "bibelhandskrifternas": "bibelhandskrift",
    "bibelhandskrifters": "bibelhandskrift",
    "bibelhandskrifts": "bibelhandskrift",
    "bibelkanoner": "bibelkanon",
    "bibelkanonerna": "bibelkanon",
    "bibelkanonernas": "bibelkanon",
    "bibelkanoners": "bibelkanon",
    "bibelkanons": "bibelkanon",
    "bibelkommissionen": "bibelkommission",
    "bibelkommissionens": "bibelkommission",
    "bibelkommissioner": "bibelkommission",
    "bibelkommissionerna": "bibelkommission",
    "bibelkommissionernas": "bibelkommission",
    "bibelkommissioners": "bibelkommission",
    "bibelkommissions": "bibelkommission",
    "bibelkonkordansen": "bibelkonkordans",
    "bibelkonkordansens": "bibelkonkordans",
    "bibelkonkordanser": "bibelkonkordans",
    "bibelkonkordanserna": "bibelkonkordans",
    "bibelkonkordansernas": "bibelkonkordans",
    "bibelkonkordansers": "bibelkonkordans",
    "bibelkristenheten": "bibelkristenhet",
    "bibelkristenhetens": "bibelkristenhet",
    "bibelkristenhets": "bibelkristenhet",
    "bibelkristens": "bibelkristen",
    "bibelkristet": "bibelkristen",
    "bibelkristets": "bibelkristen",
    "bibelkristna": "bibelkristen",
    "bibelkristnare": "bibelkristen",
    "bibelkristnares": "bibelkristen",
    "bibelkristnas": "bibelkristen",
    "bibelkristnast": "bibelkristen",
    "bibelkristnaste": "bibelkristen",
    "bibelkristnastes": "bibelkristen",
    "bibelkristnasts": "bibelkristen",
    "bibelkristne": "bibelkristen",
    "bibelkristnes": "bibelkristen",
    "bibelkritiken": "bibelkritik",
    "bibelkritikens": "bibelkritik",
    "bibelkritiks": "bibelkritik",
    "bibelkunniga": "bibelkunnig",
    "bibelkunnigare": "bibelkunnig",
    "bibelkunnigares": "bibelkunnig",
    "bibelkunnigas": "bibelkunnig",
    "bibelkunnigast": "bibelkunnig",
    "bibelkunnigaste": "bibelkunnig",
    "bibelkunnigastes": "bibelkunnig",
    "bibelkunnigasts": "bibelkunnig",
    "bibelkunnige": "bibelkunnig",
    "bibelkunniges": "bibelkunnig",
    "bibelkunnigheten": "bibelkunnighet",
    "bibelkunnighetens": "bibelkunnighet",
    "bibelkunnighets": "bibelkunnighet",
    "bibelkunnigs": "bibelkunnig",
    "bibelkunnigt": "bibelkunnig",
    "bibelkunnigts": "bibelkunnig",
    "bibeln": "bibel",
    "bibelns": "bibel",
    "bibelorden": "bibelord",
    "bibelordens": "bibelord",
    "bibelordet": "bibelord",
    "bibelordets": "bibelord",
    "bibelords": "bibelord",
    "bibels": "bibel",
    "bibelsamtalen": "bibelsamtal",
    "bibelsamtalens": "bibelsamtal",
    "bibelsamtalet": "bibelsamtal",
    "bibelsamtalets": "bibelsamtal",
    "bibelsamtals": "bibelsamtal",
    "bibelsprängda": "bibelsprängd",
    "bibelsprängdare": "bibelsprängd",
    "bibelsprängdares": "bibelsprängd",
    "bibelsprängdas": "bibelsprängd",
    "bibelsprängdast": "bibelsprängd",
    "bibelsprängdaste": "bibelsprängd",
    "bibelsprängdastes": "bibelsprängd",
    "bibelsprängdasts": "bibelsprängd",
    "bibelsprängde": "bibelsprängd",
    "bibelsprängdes": "bibelsprängd",
    "bibelsprängdheten": "bibelsprängdhet",
    "bibelsprängdhetens": "bibelsprängdhet",
    "bibelsprängdhets": "bibelsprängdhet",
    "bibelsprängds": "bibelsprängd",
    "bibelsprängt": "bibelsprängd",
    "bibelsprängts": "bibelsprängd",
    "bibelspråken": "bibelspråk",
    "bibelspråkens": "bibelspråk",
    "bibelspråket": "bibelspråk",
    "bibelspråkets": "bibelspråk",
    "bibelspråks": "bibelspråk",
    "bibelsällskapen": "bibelsällskap",
    "bibelsällskapens": "bibelsällskap",
    "bibelsällskapet": "bibelsällskap",
    "bibelsällskapets": "bibelsällskap",
    "bibelsällskaps": "bibelsällskap",
    "bibeltexten": "bibeltext",
    "bibeltextens": "bibeltext",
    "bibeltexter": "bibeltext",
    "bibeltexterna": "bibeltext",
    "bibeltexternas": "bibeltext",
    "bibeltexters": "bibeltext",
    "bibeltexts": "bibeltext",
    "bibeltrogenheten": "bibeltrogenhet",
    "bibeltrogenhetens": "bibeltrogenhet",
    "bibeltrogenhets": "bibeltrogenhet",
    "bibeltrogens": "bibeltrogen",
    "bibeltroget": "bibeltrogen",
    "bibeltrogets": "bibeltrogen",
    "bibeltrogna": "bibeltrogen",
    "bibeltrognare": "bibeltrogen",
    "bibeltrognares": "bibeltrogen",
    "bibeltrognas": "bibeltrogen",
    "bibeltrognast": "bibeltrogen",
    "bibeltrognaste": "bibeltrogen",
    "bibeltrognastes": "bibeltrogen",
    "bibeltrognasts": "bibeltrogen",
    "bibeltrogne": "bibeltrogen",
    "bibeltrognes": "bibeltrogen",
    "bibelversar": "bibelvers",
    "bibelversarna": "bibelvers",
    "bibelversarnas": "bibelvers",
    "bibelversars": "bibelvers",
    "bibelversen": "bibelvers",
    "bibelversens": "bibelvers",
    "bibelverser": "bibelvers",
    "bibelverserna": "bibelvers",
    "bibelversernas": "bibelvers",
    "bibelversers": "bibelvers",
    "bibelöversättningar": "bibelöversättning",
    "bibelöversättningarna": "bibelöversättning",
    "bibelöversättningarnas": "bibelöversättning",
    "bibelöversättningars": "bibelöversättning",
    "bibelöversättningen": "bibelöversättning",
    "bibelöversättningens": "bibelöversättning",
    "bibelöversättnings": "bibelöversättning",
    "bibetydelsen": "bibetydelse",
    "bibetydelsens": "bibetydelse",
    "bibetydelser": "bibetydelse",
    "bibetydelserna": "bibetydelse",
    "bibetydelsernas": "bibetydelse",
    "bibetydelsers": "bibetydelse",
    "bibetydelses": "bibetydelse",
    "biblar": "bibel",
    "biblarna": "bibel",
    "biblarnas": "bibel",
    "biblars": "bibel",
    "biblicismen": "biblicism",
    "biblicismens": "biblicism",
    "biblicismer": "biblicism",
    "biblicismerna": "biblicism",
    "biblicismernas": "biblicism",
    "biblicismers": "biblicism",
    "biblicisms": "biblicism",
    "biblicistiska": "biblicistisk",
    "biblicistiskas": "biblicistisk",
    "biblicistiske": "biblicistisk",
    "biblicistiskes": "biblicistisk",
    "biblicistisks": "biblicistisk",
    "biblicistiskt": "biblicistisk",
    "biblicistiskts": "biblicistisk",
    "bibliofilen": "bibliofil",
    "bibliofilens": "bibliofil",
    "bibliofiler": "bibliofil",
    "bibliofilerna": "bibliofil",
    "bibliofilernas": "bibliofil",
    "bibliofilers": "bibliofil",
    "bibliofils": "bibliofil",
    "bibliofilupplagan": "bibliofilupplaga",
    "bibliofilupplagans": "bibliofilupplaga",
    "bibliofilupplagas": "bibliofilupplaga",
    "bibliofilupplage": "bibliofilupplaga",
    "bibliofilupplagor": "bibliofilupplaga",
    "bibliofilupplagorna": "bibliofilupplaga",
    "bibliofilupplagornas": "bibliofilupplaga",
    "bibliofilupplagors": "bibliofilupplaga",
    "bibliografen": "bibliograf",
    "bibliografens": "bibliograf",
    "bibliografer": "bibliograf",
    "bibliograferna": "bibliograf",
    "bibliografernas": "bibliograf",
    "bibliografers": "bibliograf",
    "bibliografien": "bibliografi",
    "bibliografiens": "bibliografi",
    "bibliografier": "bibliografi",
    "bibliografierna": "bibliografi",
    "bibliografiernas": "bibliografi",
    "bibliografiers": "bibliografi",
    "bibliografin": "bibliografi",
    "bibliografins": "bibliografi",
    "bibliografis": "bibliografi",
    "bibliografiska": "bibliografisk",
    "bibliografiskare": "bibliografisk",
    "bibliografiskares": "bibliografisk",
    "bibliografiskas": "bibliografisk",
    "bibliografiskast": "bibliografisk",
    "bibliografiskaste": "bibliografisk",
    "bibliografiskastes": "bibliografisk",
    "bibliografiskasts": "bibliografisk",
    "bibliografiske": "bibliografisk",
    "bibliografiskes": "bibliografisk",
    "bibliografisks": "bibliografisk",
    "bibliografiskt": "bibliografisk",
    "bibliografiskts": "bibliografisk",
    "bibliografs": "bibliograf",
    "bibliomanen": "biblioman",
    "bibliomanens": "biblioman",
    "bibliomaner": "biblioman",
    "bibliomanerna": "biblioman",
    "bibliomanernas": "biblioman",
    "bibliomaners": "biblioman",
    "bibliomanien": "bibliomani",
    "bibliomaniens": "bibliomani",
    "bibliomanin": "bibliomani",
    "bibliomanins": "bibliomani",
    "bibliomanis": "bibliomani",
    "bibliomans": "biblioman",
    "bibliometrien": "bibliometri",
    "bibliometriens": "bibliometri",
    "bibliometrin": "bibliometri",
    "bibliometrins": "bibliometri",
    "bibliometris": "bibliometri",
    "bibliotekarien": "bibliotekarie",
    "bibliotekariens": "bibliotekarie",
    "bibliotekarier": "bibliotekarie",
    "bibliotekarierna": "bibliotekarie",
    "bibliotekariernas": "bibliotekarie",
    "bibliotekariers": "bibliotekarie",
    "bibliotekaries": "bibliotekarie",
    "biblioteken": "bibliotek",
    "bibliotekens": "bibliotek",
    "biblioteket": "bibliotek",
    "bibliotekets": "bibliotek",
    "biblioteks": "bibliotek",
    "biblioteksavgiften": "biblioteksavgift",
    "biblioteksavgiftens": "biblioteksavgift",
    "biblioteksavgifter": "biblioteksavgift",
    "biblioteksavgifterna": "biblioteksavgift",
    "biblioteksavgifternas": "biblioteksavgift",
    "biblioteksavgifters": "biblioteksavgift",
    "biblioteksavgifts": "biblioteksavgift",
    "biblioteksbanden": "biblioteksband",
    "biblioteksbandens": "biblioteksband",
    "biblioteksbandet": "biblioteksband",
    "biblioteksbandets": "biblioteksband",
    "biblioteksbands": "biblioteksband",
    "biblioteksbelysningar": "biblioteksbelysning",
    "biblioteksbelysningarna": "biblioteksbelysning",
    "biblioteksbelysningarnas": "biblioteksbelysning",
    "biblioteksbelysningars": "biblioteksbelysning",
    "biblioteksbelysningen": "biblioteksbelysning",
    "biblioteksbelysningens": "biblioteksbelysning",
    "biblioteksbelysnings": "biblioteksbelysning",
    "biblioteksborden": "biblioteksbord",
    "biblioteksbordens": "biblioteksbord",
    "biblioteksbordet": "biblioteksbord",
    "biblioteksbordets": "biblioteksbord",
    "biblioteksbords": "biblioteksbord",
    "biblioteksbranden": "biblioteksbrand",
    "biblioteksbrandens": "biblioteksbrand",
    "biblioteksbrands": "biblioteksbrand",
    "biblioteksbränder": "biblioteksbrand",
    "biblioteksbränderna": "biblioteksbrand",
    "biblioteksbrändernas": "biblioteksbrand",
    "biblioteksbränders": "biblioteksbrand",
    "bibliotekshögskolan": "bibliotekshögskola",
    "bibliotekshögskolans": "bibliotekshögskola",
    "bibliotekshögskolas": "bibliotekshögskola",
    "bibliotekshögskole": "bibliotekshögskola",
    "bibliotekshögskolor": "bibliotekshögskola",
    "bibliotekshögskolorna": "bibliotekshögskola",
    "bibliotekshögskolornas": "bibliotekshögskola",
    "bibliotekshögskolors": "bibliotekshögskola",
    "bibliotekskatalogen": "bibliotekskatalog",
    "bibliotekskatalogens": "bibliotekskatalog",
    "bibliotekskataloger": "bibliotekskatalog",
    "bibliotekskatalogerna": "bibliotekskatalog",
    "bibliotekskatalogernas": "bibliotekskatalog",
    "bibliotekskatalogers": "bibliotekskatalog",
    "bibliotekskatalogs": "bibliotekskatalog",
    "bibliotekslånen": "bibliotekslån",
    "bibliotekslånens": "bibliotekslån",
    "bibliotekslånet": "bibliotekslån",
    "bibliotekslånets": "bibliotekslån",
    "bibliotekslåns": "bibliotekslån",
    "bibliska": "biblisk",
    "bibliskare": "biblisk",
    "bibliskares": "biblisk",
    "bibliskas": "biblisk",
    "bibliskast": "biblisk",
    "bibliskaste": "biblisk",
    "bibliskastes": "biblisk",
    "bibliskasts": "biblisk",
    "bibliske": "biblisk",
    "bibliskes": "biblisk",
    "biblisks": "biblisk",
    "bibliskt": "biblisk",
    "bibliskts": "biblisk",
    "biblom": "biblomma",
    "biblomman": "biblomma",
    "biblommans": "biblomma",
    "biblommas": "biblomma",
    "biblomme": "biblomma",
    "biblommor": "biblomma",
    "biblommorna": "biblomma",
    "biblommornas": "biblomma",
    "biblommors": "biblomma",
    "bibloms": "biblomma",
    "bibragt": "bibringa",
    "bibragte": "bibringa",
    "bibragtes": "bibringa",
    "bibragts": "bibringa",
    "bibring": "bibringa",
    "bibringad": "bibringa",
    "bibringade": "bibringa",
    "bibringades": "bibringa",
    "bibringads": "bibringa",
    "bibringande": "bibringa",
    "bibringanden": "bibringande",
    "bibringandena": "bibringande",
    "bibringandenas": "bibringande",
    "bibringandens": "bibringande",
    "bibringandes": "bibringande",
    "bibringandet": "bibringande",
    "bibringandets": "bibringande",
    "bibringar": "bibringa",
    "bibringas": "bibringa",
    "bibringat": "bibringa",
    "bibringats": "bibringa",
    "bibröden": "bibröd",
    "bibrödens": "bibröd",
    "bibrödet": "bibröd",
    "bibrödets": "bibröd",
    "bibröds": "bibröd",
    "bicepsar": "biceps",
    "bicepsarna": "biceps",
    "bicepsarnas": "biceps",
    "bicepsars": "biceps",
    "bicepsen": "biceps",
    "bicepsens": "biceps",
    "bicepsmuskeln": "bicepsmuskel",
    "bicepsmuskelns": "bicepsmuskel",
    "bicepsmuskels": "bicepsmuskel",
    "bicepsmuskler": "bicepsmuskel",
    "bicepsmusklerna": "bicepsmuskel",
    "bicepsmusklernas": "bicepsmuskel",
    "bicepsmusklers": "bicepsmuskel",
    "bicepssen": "bicepssena",
    "bicepssenan": "bicepssena",
    "bicepssenans": "bicepssena",
    "bicepssenas": "bicepssena",
    "bicepssene": "bicepssena",
    "bicepssenor": "bicepssena",
    "bicepssenorna": "bicepssena",
    "bicepssenornas": "bicepssena",
    "bicepssenors": "bicepssena",
    "bicepssens": "bicepssena",
    "bid": "bida",
    "bidad": "bida",
    "bidade": "bida",
    "bidades": "bida",
    "bidads": "bida",
    "bidande": "bida",
    "bidanden": "bidande",
    "bidandena": "bidande",
    "bidandenas": "bidande",
    "bidandens": "bidande",
    "bidandes": "bidande",
    "bidandet": "bidande",
    "bidandets": "bidande",
    "bidans": "bidan",
    "bidar": "bida",
    "bidas": "bida",
    "bidat": "bida",
    "bidats": "bida",
    "bidevindar": "bidevindare",
    "bidevindaren": "bidevindare",
    "bidevindarens": "bidevindare",
    "bidevindares": "bidevindare",
    "bidevindarna": "bidevindare",
    "bidevindarnas": "bidevindare",
    "bidevindsegels": "bidevindsegel",
    "bidevindseglar": "bidevindseglare",
    "bidevindseglaren": "bidevindseglare",
    "bidevindseglarens": "bidevindseglare",
    "bidevindseglares": "bidevindseglare",
    "bidevindseglarna": "bidevindseglare",
    "bidevindseglarnas": "bidevindseglare",
    "bidevindseglen": "bidevindsegel",
    "bidevindseglens": "bidevindsegel",
    "bidevindseglet": "bidevindsegel",
    "bidevindseglets": "bidevindsegel",
    "bidrag": "bidra",
    "bidraga": "bidra",
    "bidragande": "bidra",
    "bidraganden": "bidragande",
    "bidragandena": "bidragande",
    "bidragandenas": "bidragande",
    "bidragandens": "bidragande",
    "bidragandes": "bidragande",
    "bidragandet": "bidragande",
    "bidragandets": "bidragande",
    "bidragas": "bidra",
    "bidrage": "bidra",
    "bidragen": "bidrag",
    "bidragens": "bidrag",
    "bidrager": "bidra",
    "bidrages": "bidra",
    "bidraget": "bidrag",
    "bidragets": "bidrag",
    "bidragit": "bidra",
    "bidragits": "bidra",
    "bidragna": "bidra",
    "bidragnas": "bidra",
    "bidragne": "bidra",
    "bidragnes": "bidra",
    "bidrags": "bidrag",
    "bidragsdelar": "bidragsdel",
    "bidragsdelarna": "bidragsdel",
    "bidragsdelarnas": "bidragsdel",
    "bidragsdelars": "bidragsdel",
    "bidragsdelen": "bidragsdel",
    "bidragsdelens": "bidragsdel",
    "bidragsdels": "bidragsdel",
    "bidragsfusken": "bidragsfusk",
    "bidragsfuskens": "bidragsfusk",
    "bidragsfusket": "bidragsfusk",
    "bidragsfuskets": "bidragsfusk",
    "bidragsfusks": "bidragsfusk",
    "bidragsförskotten": "bidragsförskott",
    "bidragsförskottens": "bidragsförskott",
    "bidragsförskottet": "bidragsförskott",
    "bidragsförskottets": "bidragsförskott",
    "bidragsförskotts": "bidragsförskott",
    "bidragsgivar": "bidragsgivare",
    "bidragsgivaren": "bidragsgivare",
    "bidragsgivarens": "bidragsgivare",
    "bidragsgivares": "bidragsgivare",
    "bidragsgivarna": "bidragsgivare",
    "bidragsgivarnas": "bidragsgivare",
    "bidragsskyldigheten": "bidragsskyldighet",
    "bidragsskyldighetens": "bidragsskyldighet",
    "bidragsskyldigheter": "bidragsskyldighet",
    "bidragsskyldigheterna": "bidragsskyldighet",
    "bidragsskyldigheternas": "bidragsskyldighet",
    "bidragsskyldigheters": "bidragsskyldighet",
    "bidragsskyldighets": "bidragsskyldighet",
    "bidrar": "bidra",
    "bidras": "bidra",
    "bidrog": "bidra",
    "bidroge": "bidra",
    "bidroges": "bidra",
    "bidrogs": "bidra",
    "bidrottningar": "bidrottning",
    "bidrottningarna": "bidrottning",
    "bidrottningarnas": "bidrottning",
    "bidrottningars": "bidrottning",
    "bidrottningen": "bidrottning",
    "bidrottningens": "bidrottning",
    "bidrottnings": "bidrottning",
    "bidéer": "bidé",
    "bidéerna": "bidé",
    "bidéernas": "bidé",
    "bidéers": "bidé",
    "bidén": "bidé",
    "bidéns": "bidé",
    "bidés": "bidé",
    "biedermeierstilar": "biedermeierstil",
    "biedermeierstilarna": "biedermeierstil",
    "biedermeierstilarnas": "biedermeierstil",
    "biedermeierstilars": "biedermeierstil",
    "biedermeierstilen": "biedermeierstil",
    "biedermeierstilens": "biedermeierstil",
    "biedermeierstils": "biedermeierstil",
    "bieffekten": "bieffekt",
    "bieffektens": "bieffekt",
    "bieffekter": "bieffekt",
    "bieffekterna": "bieffekt",
    "bieffekternas": "bieffekt",
    "bieffekters": "bieffekt",
    "bieffekts": "bieffekt",
    "bien": "bi",
    "bienna": "bienn",
    "biennalen": "biennal",
    "biennalens": "biennal",
    "biennaler": "biennal",
    "biennalerna": "biennal",
    "biennalernas": "biennal",
    "biennalers": "biennal",
    "biennals": "biennal",
    "biennare": "bienn",
    "biennares": "bienn",
    "biennas": "bienn",
    "biennast": "bienn",
    "biennaste": "bienn",
    "biennastes": "bienn",
    "biennasts": "bienn",
    "bienne": "bienn",
    "biennes": "bienn",
    "bienns": "bienn",
    "biens": "bi",
    "bient": "bienn",
    "bients": "bienn",
    "biet": "bi",
    "biets": "bi",
    "bifall": "bifalla",
    "bifallande": "bifalla",
    "bifallanden": "bifallande",
    "bifallandena": "bifallande",
    "bifallandenas": "bifallande",
    "bifallandens": "bifallande",
    "bifallandes": "bifallande",
    "bifallandet": "bifallande",
    "bifallandets": "bifallande",
    "bifallas": "bifalla",
    "bifalle": "bifalla",
    "bifallen": "bifalla",
    "bifallens": "bifalla",
    "bifaller": "bifalla",
    "bifalles": "bifalla",
    "bifallet": "bifalla",
    "bifallets": "bifalla",
    "bifallit": "bifalla",
    "bifallits": "bifalla",
    "bifallna": "bifalla",
    "bifallnas": "bifalla",
    "bifallne": "bifalla",
    "bifallnes": "bifalla",
    "bifalls": "bifalla",
    "bifallsropen": "bifallsrop",
    "bifallsropens": "bifallsrop",
    "bifallsropet": "bifallsrop",
    "bifallsropets": "bifallsrop",
    "bifallsrops": "bifallsrop",
    "bifallsstormar": "bifallsstorm",
    "bifallsstormarna": "bifallsstorm",
    "bifallsstormarnas": "bifallsstorm",
    "bifallsstormars": "bifallsstorm",
    "bifallsstormen": "bifallsstorm",
    "bifallsstormens": "bifallsstorm",
    "bifallsstorms": "bifallsstorm",
    "bifenylen": "bifenyl",
    "bifenylens": "bifenyl",
    "bifenyler": "bifenyl",
    "bifenylerna": "bifenyl",
    "bifenylernas": "bifenyl",
    "bifenylers": "bifenyl",
    "bifenylet": "bifenyl",
    "bifenylets": "bifenyl",
    "bifenyls": "bifenyl",
    "biffar": "biff",
    "biffarna": "biff",
    "biffarnas": "biff",
    "biffars": "biff",
    "biffdjuren": "biffdjur",
    "biffdjurens": "biffdjur",
    "biffdjuret": "biffdjur",
    "biffdjurets": "biffdjur",
    "biffdjurs": "biffdjur",
    "biffen": "biff",
    "biffens": "biff",
    "biffiga": "biffig",
    "biffigare": "biffig",
    "biffigares": "biffig",
    "biffigas": "biffig",
    "biffigast": "biffig",
    "biffigaste": "biffig",
    "biffigastes": "biffig",
    "biffigasts": "biffig",
    "biffige": "biffig",
    "biffiges": "biffig",
    "biffigheten": "biffighet",
    "biffighetens": "biffighet",
    "biffighets": "biffighet",
    "biffigs": "biffig",
    "biffigt": "biffig",
    "biffigts": "biffig",
    "biffkon": "biffko",
    "biffkons": "biffko",
    "biffkor": "biffko",
    "biffkorna": "biffko",
    "biffkornas": "biffko",
    "biffkors": "biffko",
    "biffkos": "biffko",
    "biffraden": "biffrad",
    "biffradens": "biffrad",
    "biffrader": "biffrad",
    "biffraderna": "biffrad",
    "biffradernas": "biffrad",
    "biffraders": "biffrad",
    "biffrads": "biffrad",
    "biffs": "biff",
    "biffstekar": "biffstek",
    "biffstekarna": "biffstek",
    "biffstekarnas": "biffstek",
    "biffstekars": "biffstek",
    "biffsteken": "biffstek",
    "biffstekens": "biffstek",
    "biffsteks": "biffstek",
    "bifiguren": "bifigur",
    "bifigurens": "bifigur",
    "bifigurer": "bifigur",
    "bifigurerna": "bifigur",
    "bifigurernas": "bifigur",
    "bifigurers": "bifigur",
    "bifigurs": "bifigur",
    "bifilara": "bifilar",
    "bifilarare": "bifilar",
    "bifilarares": "bifilar",
    "bifilaras": "bifilar",
    "bifilarast": "bifilar",
    "bifilaraste": "bifilar",
    "bifilarastes": "bifilar",
    "bifilarasts": "bifilar",
    "bifilare": "bifilar",
    "bifilares": "bifilar",
    "bifilars": "bifilar",
    "bifilart": "bifilar",
    "bifilarts": "bifilar",
    "bifilära": "bifilär",
    "bifilärare": "bifilär",
    "bifilärares": "bifilär",
    "bifiläras": "bifilär",
    "bifilärast": "bifilär",
    "bifiläraste": "bifilär",
    "bifilärastes": "bifilär",
    "bifilärasts": "bifilär",
    "bifiläre": "bifilär",
    "bifiläres": "bifilär",
    "bifilärs": "bifilär",
    "bifilärt": "bifilär",
    "bifilärts": "bifilär",
    "bifloden": "biflod",
    "biflodens": "biflod",
    "bifloder": "biflod",
    "bifloderna": "biflod",
    "biflodernas": "biflod",
    "bifloders": "biflod",
    "biflods": "biflod",
    "biflöden": "biflöde",
    "biflödena": "biflöde",
    "biflödenas": "biflöde",
    "biflödens": "biflöde",
    "biflödes": "biflöde",
    "biflödet": "biflöde",
    "biflödets": "biflöde",
    "bifog": "bifoga",
    "bifogad": "bifoga",
    "bifogade": "bifoga",
    "bifogades": "bifoga",
    "bifogads": "bifoga",
    "bifogande": "bifoga",
    "bifoganden": "bifogande",
    "bifogandena": "bifogande",
    "bifogandenas": "bifogande",
    "bifogandens": "bifogande",
    "bifogandes": "bifogande",
    "bifogandet": "bifogande",
    "bifogandets": "bifogande",
    "bifogar": "bifoga",
    "bifogas": "bifoga",
    "bifogat": "bifoga",
    "bifogats": "bifoga",
    "bifokalglasen": "bifokalglas",
    "bifokalglasens": "bifokalglas",
    "bifokalglaset": "bifokalglas",
    "bifokalglasets": "bifokalglas",
    "bifurkationen": "bifurkation",
    "bifurkationens": "bifurkation",
    "bifurkationer": "bifurkation",
    "bifurkationerna": "bifurkation",
    "bifurkationernas": "bifurkation",
    "bifurkationers": "bifurkation",
    "bifurkations": "bifurkation",
    "biföll": "bifalla",
    "bifölle": "bifalla",
    "bifölles": "bifalla",
    "bifölls": "bifalla",
    "bigamien": "bigami",
    "bigamiens": "bigami",
    "bigamin": "bigami",
    "bigamins": "bigami",
    "bigamis": "bigami",
    "bigamisten": "bigamist",
    "bigamistens": "bigamist",
    "bigamister": "bigamist",
    "bigamisterna": "bigamist",
    "bigamisternas": "bigamist",
    "bigamisters": "bigamist",
    "bigamists": "bigamist",
    "bigarråer": "bigarrå",
    "bigarråerna": "bigarrå",
    "bigarråernas": "bigarrå",
    "bigarråers": "bigarrå",
    "bigarrån": "bigarrå",
    "bigarråns": "bigarrå",
    "bigarrås": "bigarrå",
    "bigat": "bigata",
    "bigatan": "bigata",
    "bigatans": "bigata",
    "bigatas": "bigata",
    "bigate": "bigata",
    "bigator": "bigata",
    "bigatorna": "bigata",
    "bigatornas": "bigata",
    "bigators": "bigata",
    "bigats": "bigata",
    "bigifter": "bigift",
    "bigifterna": "bigift",
    "bigifternas": "bigift",
    "bigifters": "bigift",
    "bigiftet": "bigift",
    "bigiftets": "bigift",
    "bigifts": "bigift",
    "bigotta": "bigott",
    "bigottare": "bigott",
    "bigottares": "bigott",
    "bigottas": "bigott",
    "bigottast": "bigott",
    "bigottaste": "bigott",
    "bigottastes": "bigott",
    "bigottasts": "bigott",
    "bigotte": "bigott",
    "bigotterier": "bigotteri",
    "bigotterierna": "bigotteri",
    "bigotteriernas": "bigotteri",
    "bigotteriers": "bigotteri",
    "bigotteriet": "bigotteri",
    "bigotteriets": "bigotteri",
    "bigotteris": "bigotteri",
    "bigotterit": "bigotteri",
    "bigotterits": "bigotteri",
    "bigottes": "bigott",
    "bigotts": "bigott",
    "bigrammen": "bigram",
    "bigrammens": "bigram",
    "bigrammet": "bigram",
    "bigrammets": "bigram",
    "bigrams": "bigram",
    "bigårdar": "bigård",
    "bigårdarna": "bigård",
    "bigårdarnas": "bigård",
    "bigårdars": "bigård",
    "bigården": "bigård",
    "bigårdens": "bigård",
    "bigårds": "bigård",
    "bihandlingar": "bihandling",
    "bihandlingarna": "bihandling",
    "bihandlingarnas": "bihandling",
    "bihandlingars": "bihandling",
    "bihandlingen": "bihandling",
    "bihandlingens": "bihandling",
    "bihandlings": "bihandling",
    "bihangen": "bihang",
    "bihangens": "bihang",
    "bihanget": "bihang",
    "bihangets": "bihang",
    "bihangs": "bihang",
    "bihusen": "bihus",
    "bihusens": "bihus",
    "bihuset": "bihus",
    "bihusets": "bihus",
    "bihustrun": "bihustru",
    "bihustruns": "bihustru",
    "bihustrur": "bihustru",
    "bihustrurna": "bihustru",
    "bihustrurnas": "bihustru",
    "bihustrurs": "bihustru",
    "bihustrus": "bihustru",
    "bihuv": "bihuva",
    "bihuvan": "bihuva",
    "bihuvans": "bihuva",
    "bihuvas": "bihuva",
    "bihuve": "bihuva",
    "bihuvor": "bihuva",
    "bihuvorna": "bihuva",
    "bihuvornas": "bihuva",
    "bihuvors": "bihuva",
    "bihuvs": "bihuva",
    "bihål": "bihåla",
    "bihålan": "bihåla",
    "bihålans": "bihåla",
    "bihålas": "bihåla",
    "bihåle": "bihåla",
    "bihåleinflammationen": "bihåleinflammation",
    "bihåleinflammationens": "bihåleinflammation",
    "bihåleinflammationer": "bihåleinflammation",
    "bihåleinflammationerna": "bihåleinflammation",
    "bihåleinflammationernas": "bihåleinflammation",
    "bihåleinflammationers": "bihåleinflammation",
    "bihåleinflammations": "bihåleinflammation",
    "bihålor": "bihåla",
    "bihålorna": "bihåla",
    "bihålornas": "bihåla",
    "bihålors": "bihåla",
    "bihåls": "bihåla",
    "biinkomsten": "biinkomst",
    "biinkomstens": "biinkomst",
    "biinkomster": "biinkomst",
    "biinkomsterna": "biinkomst",
    "biinkomsternas": "biinkomst",
    "biinkomsters": "biinkomst",
    "biinkomsts": "biinkomst",
    "bijouteri": "bijouterier",
    "bijouterierna": "bijouterier",
    "bijouteriernas": "bijouterier",
    "bijouteriers": "bijouterier",
    "bikarbonaten": "bikarbonat",
    "bikarbonatens": "bikarbonat",
    "bikarbonatet": "bikarbonat",
    "bikarbonatets": "bikarbonat",
    "bikarbonats": "bikarbonat",
    "bikinin": "bikini",
    "bikinina": "bikini",
    "bikininas": "bikini",
    "bikinins": "bikini",
    "bikinis": "bikini",
    "bikinisarna": "bikini",
    "bikinisarnas": "bikini",
    "bikinisen": "bikini",
    "bikinisens": "bikini",
    "biklövar": "biklöv",
    "biklövarna": "biklöv",
    "biklövarnas": "biklöv",
    "biklövars": "biklöv",
    "biklöven": "biklöv",
    "biklövens": "biklöv",
    "biklövs": "biklöv",
    "bikonkava": "bikonkav",
    "bikonkavare": "bikonkav",
    "bikonkavares": "bikonkav",
    "bikonkavas": "bikonkav",
    "bikonkavast": "bikonkav",
    "bikonkavaste": "bikonkav",
    "bikonkavastes": "bikonkav",
    "bikonkavasts": "bikonkav",
    "bikonkave": "bikonkav",
    "bikonkaves": "bikonkav",
    "bikonkavs": "bikonkav",
    "bikonkavt": "bikonkav",
    "bikonkavts": "bikonkav",
    "bikonvexa": "bikonvex",
    "bikonvexare": "bikonvex",
    "bikonvexares": "bikonvex",
    "bikonvexas": "bikonvex",
    "bikonvexast": "bikonvex",
    "bikonvexaste": "bikonvex",
    "bikonvexastes": "bikonvex",
    "bikonvexasts": "bikonvex",
    "bikonvexe": "bikonvex",
    "bikonvexes": "bikonvex",
    "bikonvext": "bikonvex",
    "bikonvexts": "bikonvex",
    "bikron": "bikrona",
    "bikronan": "bikrona",
    "bikronans": "bikrona",
    "bikronas": "bikrona",
    "bikrone": "bikrona",
    "bikronor": "bikrona",
    "bikronorna": "bikrona",
    "bikronornas": "bikrona",
    "bikronors": "bikrona",
    "bikrons": "bikrona",
    "bikt": "bikta",
    "biktad": "bikta",
    "biktade": "bikta",
    "biktades": "bikta",
    "biktads": "bikta",
    "biktande": "bikta",
    "biktanden": "biktande",
    "biktandena": "biktande",
    "biktandenas": "biktande",
    "biktandens": "biktande",
    "biktandes": "biktande",
    "biktandet": "biktande",
    "biktandets": "biktande",
    "biktar": "bikta",
    "biktas": "bikta",
    "biktat": "bikta",
    "biktats": "bikta",
    "biktbarnen": "biktbarn",
    "biktbarnens": "biktbarn",
    "biktbarnet": "biktbarn",
    "biktbarnets": "biktbarn",
    "biktbarns": "biktbarn",
    "bikten": "bikt",
    "biktens": "bikt",
    "bikter": "bikt",
    "bikterna": "bikt",
    "bikternas": "bikt",
    "bikters": "bikt",
    "biktfader": "biktfar",
    "biktfadern": "biktfar",
    "biktfaderns": "biktfar",
    "biktfaders": "biktfar",
    "biktfars": "biktfar",
    "biktfasder": "biktfar",
    "biktfäder": "biktfar",
    "biktfäderna": "biktfar",
    "biktfädernas": "biktfar",
    "biktfäders": "biktfar",
    "bikts": "bikt",
    "biktstolar": "biktstol",
    "biktstolarna": "biktstol",
    "biktstolarnas": "biktstol",
    "biktstolars": "biktstol",
    "biktstolen": "biktstol",
    "biktstolens": "biktstol",
    "biktstols": "biktstol",
    "bikup": "bikupa",
    "bikupan": "bikupa",
    "bikupans": "bikupa",
    "bikupas": "bikupa",
    "bikupe": "bikupa",
    "bikupor": "bikupa",
    "bikuporna": "bikupa",
    "bikupornas": "bikupa",
    "bikupors": "bikupa",
    "bikups": "bikupa",
    "bikvadraten": "bikvadrat",
    "bikvadratens": "bikvadrat",
    "bikvadrater": "bikvadrat",
    "bikvadraterna": "bikvadrat",
    "bikvadraternas": "bikvadrat",
    "bikvadraters": "bikvadrat",
    "bikvadrats": "bikvadrat",
    "bil": "bila",
    "bila": "bilägga",
    "bilabiala": "bilabial",
    "bilabialare": "bilabial",
    "bilabialares": "bilabial",
    "bilabialas": "bilabial",
    "bilabialast": "bilabial",
    "bilabialaste": "bilabial",
    "bilabialastes": "bilabial",
    "bilabialasts": "bilabial",
    "bilabiale": "bilabial",
    "bilabiales": "bilabial",
    "bilabials": "bilabial",
    "bilabialt": "bilabial",
    "bilabialts": "bilabial",
    "bilaccisen": "bilaccis",
    "bilaccisens": "bilaccis",
    "bilacciser": "bilaccis",
    "bilacciserna": "bilaccis",
    "bilaccisernas": "bilaccis",
    "bilaccisers": "bilaccis",
    "bilad": "bila",
    "bilade": "bilägga",
    "bilades": "bilägga",
    "bilads": "bila",
    "bilaffären": "bilaffär",
    "bilaffärens": "bilaffär",
    "bilaffärer": "bilaffär",
    "bilaffärerna": "bilaffär",
    "bilaffärernas": "bilaffär",
    "bilaffärers": "bilaffär",
    "bilaffärs": "bilaffär",
    "bilag": "bilaga",
    "bilagan": "bilaga",
    "bilagans": "bilaga",
    "bilagas": "bilaga",
    "bilagd": "bilägga",
    "bilagda": "bilägga",
    "bilagdas": "bilägga",
    "bilagde": "bilägga",
    "bilagdes": "bilägga",
    "bilagds": "bilägga",
    "bilage": "bilaga",
    "bilagor": "bilaga",
    "bilagorna": "bilaga",
    "bilagornas": "bilaga",
    "bilagors": "bilaga",
    "bilags": "bilaga",
    "bilagt": "bilägga",
    "bilagts": "bilägga",
    "bilan": "bila",
    "bilande": "bila",
    "bilanden": "bilande",
    "bilandena": "bilande",
    "bilandenas": "bilande",
    "bilandens": "bilande",
    "bilandes": "bilande",
    "bilandet": "bilande",
    "bilandets": "bilande",
    "bilans": "bila",
    "bilantennen": "bilantenn",
    "bilantennens": "bilantenn",
    "bilantenner": "bilantenn",
    "bilantennerna": "bilantenn",
    "bilantennernas": "bilantenn",
    "bilantenners": "bilantenn",
    "bilantenns": "bilantenn",
    "bilar": "bila",
    "bilarna": "bil",
    "bilarnas": "bil",
    "bilars": "bil",
    "bilas": "bilägga",
    "bilat": "bila",
    "bilaterala": "bilateral",
    "bilateralare": "bilateral",
    "bilateralares": "bilateral",
    "bilateralas": "bilateral",
    "bilateralast": "bilateral",
    "bilateralaste": "bilateral",
    "bilateralastes": "bilateral",
    "bilateralasts": "bilateral",
    "bilaterale": "bilateral",
    "bilaterales": "bilateral",
    "bilaterals": "bilateral",
    "bilateralt": "bilateral",
    "bilateralts": "bilateral",
    "bilats": "bila",
    "bilbanan": "bilbana",
    "bilbanans": "bilbana",
    "bilbanas": "bilbana",
    "bilbane": "bilbana",
    "bilbanor": "bilbana",
    "bilbanorna": "bilbana",
    "bilbanornas": "bilbana",
    "bilbanors": "bilbana",
    "bilbatterier": "bilbatteri",
    "bilbatterierna": "bilbatteri",
    "bilbatteriernas": "bilbatteri",
    "bilbatteriers": "bilbatteri",
    "bilbatteriet": "bilbatteri",
    "bilbatteriets": "bilbatteri",
    "bilbatteris": "bilbatteri",
    "bilbatterit": "bilbatteri",
    "bilbatterits": "bilbatteri",
    "bilbesiktningar": "bilbesiktning",
    "bilbesiktningarna": "bilbesiktning",
    "bilbesiktningarnas": "bilbesiktning",
    "bilbesiktningars": "bilbesiktning",
    "bilbesiktningen": "bilbesiktning",
    "bilbesiktningens": "bilbesiktning",
    "bilbesiktnings": "bilbesiktning",
    "bilbokéer": "bilboké",
    "bilbokéerna": "bilboké",
    "bilbokéernas": "bilboké",
    "bilbokéers": "bilboké",
    "bilbokén": "bilboké",
    "bilbokéns": "bilboké",
    "bilbokés": "bilboké",
    "bilbranden": "bilbrand",
    "bilbrandens": "bilbrand",
    "bilbrands": "bilbrand",
    "bilbranschen": "bilbransch",
    "bilbranschens": "bilbransch",
    "bilbranschs": "bilbransch",
    "bilbromsar": "bilbroms",
    "bilbromsarna": "bilbroms",
    "bilbromsarnas": "bilbroms",
    "bilbromsars": "bilbroms",
    "bilbromsen": "bilbroms",
    "bilbromsens": "bilbroms",
    "bilbränder": "bilbrand",
    "bilbränderna": "bilbrand",
    "bilbrändernas": "bilbrand",
    "bilbränders": "bilbrand",
    "bilburens": "bilburen",
    "bilburet": "bilburen",
    "bilburets": "bilburen",
    "bilburna": "bilburen",
    "bilburnare": "bilburen",
    "bilburnares": "bilburen",
    "bilburnas": "bilburen",
    "bilburnast": "bilburen",
    "bilburnaste": "bilburen",
    "bilburnastes": "bilburen",
    "bilburnasts": "bilburen",
    "bilburne": "bilburen",
    "bilburnes": "bilburen",
    "bilbyggerier": "bilbyggeri",
    "bilbyggerierna": "bilbyggeri",
    "bilbyggeriernas": "bilbyggeri",
    "bilbyggeriers": "bilbyggeri",
    "bilbyggeriet": "bilbyggeri",
    "bilbyggeriets": "bilbyggeri",
    "bilbyggeris": "bilbyggeri",
    "bilbyggerit": "bilbyggeri",
    "bilbyggerits": "bilbyggeri",
    "bilbälten": "bilbälte",
    "bilbältena": "bilbälte",
    "bilbältenas": "bilbälte",
    "bilbältens": "bilbälte",
    "bilbältes": "bilbälte",
    "bilbältet": "bilbälte",
    "bilbältets": "bilbälte",
    "bild": "bilda",
    "bildad": "bilda",
    "bildade": "bildad",
    "bildades": "bildad",
    "bildads": "bildad",
    "bildammsugar": "bildammsugare",
    "bildammsugaren": "bildammsugare",
    "bildammsugarens": "bildammsugare",
    "bildammsugares": "bildammsugare",
    "bildammsugarna": "bildammsugare",
    "bildammsugarnas": "bildammsugare",
    "bildande": "bilda",
    "bildanden": "bildande",
    "bildandena": "bildande",
    "bildandenas": "bildande",
    "bildandens": "bildande",
    "bildandes": "bildande",
    "bildandet": "bildande",
    "bildandets": "bildande",
    "bildar": "bilda",
    "bildas": "bilda",
    "bildat": "bildad",
    "bildats": "bildad",
    "bildbanden": "bildband",
    "bildbandens": "bildband",
    "bildbandet": "bildband",
    "bildbandets": "bildband",
    "bildbands": "bildband",
    "bildbara": "bildbar",
    "bildbarare": "bildbar",
    "bildbarares": "bildbar",
    "bildbaras": "bildbar",
    "bildbarast": "bildbar",
    "bildbaraste": "bildbar",
    "bildbarastes": "bildbar",
    "bildbarasts": "bildbar",
    "bildbare": "bildbar",
    "bildbares": "bildbar",
    "bildbarheten": "bildbarhet",
    "bildbarhetens": "bildbarhet",
    "bildbarhets": "bildbarhet",
    "bildbars": "bildbar",
    "bildbart": "bildbar",
    "bildbarts": "bildbar",
    "bildberättelsen": "bildberättelse",
    "bildberättelsens": "bildberättelse",
    "bildberättelser": "bildberättelse",
    "bildberättelserna": "bildberättelse",
    "bildberättelsernas": "bildberättelse",
    "bildberättelsers": "bildberättelse",
    "bildberättelses": "bildberättelse",
    "bilddyrkans": "bilddyrkan",
    "bilden": "bild",
    "bildens": "bild",
    "bilder": "bild",
    "bilderboken": "bilderbok",
    "bilderbokens": "bilderbok",
    "bilderboks": "bilderbok",
    "bilderböcker": "bilderbok",
    "bilderböckerna": "bilderbok",
    "bilderböckernas": "bilderbok",
    "bilderböckers": "bilderbok",
    "bilderna": "bild",
    "bildernas": "bild",
    "bilders": "bild",
    "bildflöden": "bildflöde",
    "bildflödena": "bildflöde",
    "bildflödenas": "bildflöde",
    "bildflödens": "bildflöde",
    "bildflödes": "bildflöde",
    "bildflödet": "bildflöde",
    "bildflödets": "bildflöde",
    "bildgåt": "bildgåta",
    "bildgåtan": "bildgåta",
    "bildgåtans": "bildgåta",
    "bildgåtas": "bildgåta",
    "bildgåte": "bildgåta",
    "bildgåtor": "bildgåta",
    "bildgåtorna": "bildgåta",
    "bildgåtornas": "bildgåta",
    "bildgåtors": "bildgåta",
    "bildgåts": "bildgåta",
    "bildhuggar": "bildhuggare",
    "bildhuggaren": "bildhuggare",
    "bildhuggarens": "bildhuggare",
    "bildhuggares": "bildhuggare",
    "bildhuggarna": "bildhuggare",
    "bildhuggarnas": "bildhuggare",
    "bildhuggerier": "bildhuggeri",
    "bildhuggerierna": "bildhuggeri",
    "bildhuggeriernas": "bildhuggeri",
    "bildhuggeriers": "bildhuggeri",
    "bildhuggeriet": "bildhuggeri",
    "bildhuggeriets": "bildhuggeri",
    "bildhuggeris": "bildhuggeri",
    "bildhuggerit": "bildhuggeri",
    "bildhuggerits": "bildhuggeri",
    "bildhållningar": "bildhållning",
    "bildhållningarna": "bildhållning",
    "bildhållningarnas": "bildhållning",
    "bildhållningars": "bildhållning",
    "bildhållningen": "bildhållning",
    "bildhållningens": "bildhållning",
    "bildhållnings": "bildhållning",
    "bildkart": "bildkarta",
    "bildkartan": "bildkarta",
    "bildkartans": "bildkarta",
    "bildkartas": "bildkarta",
    "bildkarte": "bildkarta",
    "bildkartor": "bildkarta",
    "bildkartorna": "bildkarta",
    "bildkartornas": "bildkarta",
    "bildkartors": "bildkarta",
    "bildkarts": "bildkarta",
    "bildkonsten": "bildkonst",
    "bildkonstens": "bildkonst",
    "bildkonster": "bildkonst",
    "bildkonsterna": "bildkonst",
    "bildkonsternas": "bildkonst",
    "bildkonsters": "bildkonst",
    "bildkonsts": "bildkonst",
    "bildkryssen": "bildkryss",
    "bildkryssens": "bildkryss",
    "bildkrysset": "bildkryss",
    "bildkryssets": "bildkryss",
    "bildliga": "bildlig",
    "bildligare": "bildlig",
    "bildligares": "bildlig",
    "bildligas": "bildlig",
    "bildligast": "bildlig",
    "bildligaste": "bildlig",
    "bildligastes": "bildlig",
    "bildligasts": "bildlig",
    "bildlige": "bildlig",
    "bildliges": "bildlig",
    "bildligheten": "bildlighet",
    "bildlighetens": "bildlighet",
    "bildlighets": "bildlighet",
    "bildligs": "bildlig",
    "bildligt": "bildlig",
    "bildligts": "bildlig",
    "bildlika": "bildlik",
    "bildlikare": "bildlik",
    "bildlikares": "bildlik",
    "bildlikas": "bildlik",
    "bildlikast": "bildlik",
    "bildlikaste": "bildlik",
    "bildlikastes": "bildlik",
    "bildlikasts": "bildlik",
    "bildlike": "bildlik",
    "bildlikes": "bildlik",
    "bildlikheten": "bildlikhet",
    "bildlikhetens": "bildlikhet",
    "bildlikhets": "bildlikhet",
    "bildliks": "bildlik",
    "bildlikt": "bildlik",
    "bildlikts": "bildlik",
    "bildmaterialen": "bildmaterial",
    "bildmaterialens": "bildmaterial",
    "bildmaterialet": "bildmaterial",
    "bildmaterialets": "bildmaterial",
    "bildmaterials": "bildmaterial",
    "bildmonitorer": "bildmonitor",
    "bildmonitorerna": "bildmonitor",
    "bildmonitorernas": "bildmonitor",
    "bildmonitorers": "bildmonitor",
    "bildmonitorn": "bildmonitor",
    "bildmonitorns": "bildmonitor",
    "bildmonitors": "bildmonitor",
    "bildmässiga": "bildmässig",
    "bildmässigare": "bildmässig",
    "bildmässigares": "bildmässig",
    "bildmässigas": "bildmässig",
    "bildmässigast": "bildmässig",
    "bildmässigaste": "bildmässig",
    "bildmässigastes": "bildmässig",
    "bildmässigasts": "bildmässig",
    "bildmässige": "bildmässig",
    "bildmässiges": "bildmässig",
    "bildmässigheten": "bildmässighet",
    "bildmässighetens": "bildmässighet",
    "bildmässighets": "bildmässighet",
    "bildmässigs": "bildmässig",
    "bildmässigt": "bildmässig",
    "bildmässigts": "bildmässig",
    "bildningar": "bildning",
    "bildningarna": "bildning",
    "bildningarnas": "bildning",
    "bildningars": "bildning",
    "bildningen": "bildning",
    "bildningens": "bildning",
    "bildnings": "bildning",
    "bildningsaristokraten": "bildningsaristokrat",
    "bildningsaristokratens": "bildningsaristokrat",
    "bildningsaristokrater": "bildningsaristokrat",
    "bildningsaristokraterna": "bildningsaristokrat",
    "bildningsaristokraternas": "bildningsaristokrat",
    "bildningsaristokraters": "bildningsaristokrat",
    "bildningsaristokrats": "bildningsaristokrat",
    "bildningsfelen": "bildningsfel",
    "bildningsfelens": "bildningsfel",
    "bildningsfelet": "bildningsfel",
    "bildningsfelets": "bildningsfel",
    "bildningsfels": "bildningsfel",
    "bildningsförbunden": "bildningsförbund",
    "bildningsförbundens": "bildningsförbund",
    "bildningsförbundet": "bildningsförbund",
    "bildningsförbundets": "bildningsförbund",
    "bildningsförbunds": "bildningsförbund",
    "bildningshögfärden": "bildningshögfärd",
    "bildningshögfärdens": "bildningshögfärd",
    "bildningshögfärds": "bildningshögfärd",
    "bildningsmässiga": "bildningsmässig",
    "bildningsmässigare": "bildningsmässig",
    "bildningsmässigares": "bildningsmässig",
    "bildningsmässigas": "bildningsmässig",
    "bildningsmässigast": "bildningsmässig",
    "bildningsmässigaste": "bildningsmässig",
    "bildningsmässigastes": "bildningsmässig",
    "bildningsmässigasts": "bildningsmässig",
    "bildningsmässige": "bildningsmässig",
    "bildningsmässiges": "bildningsmässig",
    "bildningsmässigs": "bildningsmässig",
    "bildningsmässigt": "bildningsmässig",
    "bildningsmässigts": "bildningsmässig",
    "bildningsnivåer": "bildningsnivå",
    "bildningsnivåerna": "bildningsnivå",
    "bildningsnivåernas": "bildningsnivå",
    "bildningsnivåers": "bildningsnivå",
    "bildningsnivån": "bildningsnivå",
    "bildningsnivåns": "bildningsnivå",
    "bildningsnivås": "bildningsnivå",
    "bildningsorganisationen": "bildningsorganisation",
    "bildningsorganisationens": "bildningsorganisation",
    "bildningsorganisationer": "bildningsorganisation",
    "bildningsorganisationerna": "bildningsorganisation",
    "bildningsorganisationernas": "bildningsorganisation",
    "bildningsorganisationers": "bildningsorganisation",
    "bildningsorganisations": "bildningsorganisation",
    "bildningsromanen": "bildningsroman",
    "bildningsromanens": "bildningsroman",
    "bildningsromaner": "bildningsroman",
    "bildningsromanerna": "bildningsroman",
    "bildningsromanernas": "bildningsroman",
    "bildningsromaners": "bildningsroman",
    "bildningsromans": "bildningsroman",
    "bildningstörsten": "bildningstörst",
    "bildningstörstens": "bildningstörst",
    "bildningstörsts": "bildningstörst",
    "bildningsverksamheten": "bildningsverksamhet",
    "bildningsverksamhetens": "bildningsverksamhet",
    "bildningsverksamheter": "bildningsverksamhet",
    "bildningsverksamheterna": "bildningsverksamhet",
    "bildningsverksamheternas": "bildningsverksamhet",
    "bildningsverksamheters": "bildningsverksamhet",
    "bildningsverksamhets": "bildningsverksamhet",
    "bildningsvärmen": "bildningsvärme",
    "bildningsvärmens": "bildningsvärme",
    "bildningsvärmes": "bildningsvärme",
    "bildningsvärmet": "bildningsvärme",
    "bildningsvärmets": "bildningsvärme",
    "bildprakten": "bildprakt",
    "bildpraktens": "bildprakt",
    "bildprakts": "bildprakt",
    "bildradion": "bildradio",
    "bildradions": "bildradio",
    "bildradios": "bildradio",
    "bildredaktören": "bildredaktör",
    "bildredaktörens": "bildredaktör",
    "bildredaktörer": "bildredaktör",
    "bildredaktörerna": "bildredaktör",
    "bildredaktörernas": "bildredaktör",
    "bildredaktörers": "bildredaktör",
    "bildredaktörn": "bildredaktör",
    "bildredaktörns": "bildredaktör",
    "bildredaktörs": "bildredaktör",
    "bildreportagen": "bildreportage",
    "bildreportagens": "bildreportage",
    "bildreportages": "bildreportage",
    "bildreportaget": "bildreportage",
    "bildreportagets": "bildreportage",
    "bildrull": "bildrulle",
    "bildrullar": "bildrulle",
    "bildrullarna": "bildrulle",
    "bildrullarnas": "bildrulle",
    "bildrullars": "bildrulle",
    "bildrullen": "bildrulle",
    "bildrullens": "bildrulle",
    "bildrulles": "bildrulle",
    "bildrulls": "bildrulle",
    "bildrutan": "bildruta",
    "bildrutans": "bildruta",
    "bildrutas": "bildruta",
    "bildrute": "bildruta",
    "bildrutor": "bildruta",
    "bildrutorna": "bildruta",
    "bildrutornas": "bildruta",
    "bildrutors": "bildruta",
    "bildrören": "bildrör",
    "bildrörens": "bildrör",
    "bildröret": "bildrör",
    "bildrörets": "bildrör",
    "bildrörs": "bildrör",
    "bilds": "bild",
    "bildsignalen": "bildsignal",
    "bildsignalens": "bildsignal",
    "bildsignaler": "bildsignal",
    "bildsignalerna": "bildsignal",
    "bildsignalernas": "bildsignal",
    "bildsignalers": "bildsignal",
    "bildsignals": "bildsignal",
    "bildskriften": "bildskrift",
    "bildskriftens": "bildskrift",
    "bildskrifter": "bildskrift",
    "bildskrifterna": "bildskrift",
    "bildskrifternas": "bildskrift",
    "bildskrifters": "bildskrift",
    "bildskrifts": "bildskrift",
    "bildskärmar": "bildskärm",
    "bildskärmarna": "bildskärm",
    "bildskärmarnas": "bildskärm",
    "bildskärmars": "bildskärm",
    "bildskärmen": "bildskärm",
    "bildskärmens": "bildskärm",
    "bildskärms": "bildskärm",
    "bildskärpan": "bildskärpa",
    "bildskärpans": "bildskärpa",
    "bildskärpas": "bildskärpa",
    "bildsköna": "bildskön",
    "bildskönare": "bildskön",
    "bildskönares": "bildskön",
    "bildskönas": "bildskön",
    "bildskönast": "bildskön",
    "bildskönaste": "bildskön",
    "bildskönastes": "bildskön",
    "bildskönasts": "bildskön",
    "bildsköne": "bildskön",
    "bildskönes": "bildskön",
    "bildskönheten": "bildskönhet",
    "bildskönhetens": "bildskönhet",
    "bildskönhets": "bildskönhet",
    "bildsköns": "bildskön",
    "bildskönt": "bildskön",
    "bildskönts": "bildskön",
    "bildsnidar": "bildsnidare",
    "bildsnidaren": "bildsnidare",
    "bildsnidarens": "bildsnidare",
    "bildsnidares": "bildsnidare",
    "bildsnidarna": "bildsnidare",
    "bildsnidarnas": "bildsnidare",
    "bildsniderier": "bildsnideri",
    "bildsniderierna": "bildsnideri",
    "bildsnideriernas": "bildsnideri",
    "bildsnideriers": "bildsnideri",
    "bildsnideriet": "bildsnideri",
    "bildsnideriets": "bildsnideri",
    "bildsnideris": "bildsnideri",
    "bildsniderit": "bildsnideri",
    "bildsniderits": "bildsnideri",
    "bildspelen": "bildspel",
    "bildspelens": "bildspel",
    "bildspelet": "bildspel",
    "bildspelets": "bildspel",
    "bildspels": "bildspel",
    "bildspråken": "bildspråk",
    "bildspråkens": "bildspråk",
    "bildspråket": "bildspråk",
    "bildspråkets": "bildspråk",
    "bildspråks": "bildspråk",
    "bildstenar": "bildsten",
    "bildstenarna": "bildsten",
    "bildstenarnas": "bildsten",
    "bildstenars": "bildsten",
    "bildstenen": "bildsten",
    "bildstenens": "bildsten",
    "bildstens": "bildsten",
    "bildstoden": "bildstod",
    "bildstodens": "bildstod",
    "bildstoder": "bildstod",
    "bildstoderna": "bildstod",
    "bildstodernas": "bildstod",
    "bildstoders": "bildstod",
    "bildstods": "bildstod",
    "bildstormar": "bildstormare",
    "bildstormaren": "bildstormare",
    "bildstormarens": "bildstormare",
    "bildstormares": "bildstormare",
    "bildstormarna": "bildstormare",
    "bildstormarnas": "bildstormare",
    "bildstriden": "bildstrid",
    "bildstridens": "bildstrid",
    "bildstrider": "bildstrid",
    "bildstriderna": "bildstrid",
    "bildstridernas": "bildstrid",
    "bildstriders": "bildstrid",
    "bildstrids": "bildstrid",
    "bildsviten": "bildsvit",
    "bildsvitens": "bildsvit",
    "bildsviter": "bildsvit",
    "bildsviterna": "bildsvit",
    "bildsviternas": "bildsvit",
    "bildsviters": "bildsvit",
    "bildsvits": "bildsvit",
    "bildtelefonen": "bildtelefon",
    "bildtelefonens": "bildtelefon",
    "bildtelefoner": "bildtelefon",
    "bildtelefonerna": "bildtelefon",
    "bildtelefonernas": "bildtelefon",
    "bildtelefoners": "bildtelefon",
    "bildtelefons": "bildtelefon",
    "bildtelegrafien": "bildtelegrafi",
    "bildtelegrafiens": "bildtelegrafi",
    "bildtelegrafin": "bildtelegrafi",
    "bildtelegrafins": "bildtelegrafi",
    "bildtelegrafis": "bildtelegrafi",
    "bildtexten": "bildtext",
    "bildtextens": "bildtext",
    "bildtexter": "bildtext",
    "bildtexterna": "bildtext",
    "bildtexternas": "bildtext",
    "bildtexters": "bildtext",
    "bildtexts": "bildtext",
    "bildtolkningar": "bildtolkning",
    "bildtolkningarna": "bildtolkning",
    "bildtolkningarnas": "bildtolkning",
    "bildtolkningars": "bildtolkning",
    "bildtolkningen": "bildtolkning",
    "bildtolkningens": "bildtolkning",
    "bildtolknings": "bildtolkning",
    "bildvävnaden": "bildvävnad",
    "bildvävnadens": "bildvävnad",
    "bildvävnader": "bildvävnad",
    "bildvävnaderna": "bildvävnad",
    "bildvävnadernas": "bildvävnad",
    "bildvävnaders": "bildvävnad",
    "bildvävnads": "bildvävnad",
    "bildäcken": "bildäck",
    "bildäckens": "bildäck",
    "bildäcket": "bildäck",
    "bildäckets": "bildäck",
    "bildäcks": "bildäck",
    "bildöverföringar": "bildöverföring",
    "bildöverföringarna": "bildöverföring",
    "bildöverföringarnas": "bildöverföring",
    "bildöverföringars": "bildöverföring",
    "bildöverföringen": "bildöverföring",
    "bildöverföringens": "bildöverföring",
    "bildöverförings": "bildöverföring",
    "bile": "bila",
    "bilen": "bil",
    "bilens": "bil",
    "bilfabriken": "bilfabrik",
    "bilfabrikens": "bilfabrik",
    "bilfabriker": "bilfabrik",
    "bilfabrikerna": "bilfabrik",
    "bilfabrikernas": "bilfabrik",
    "bilfabrikers": "bilfabrik",
    "bilfabriks": "bilfabrik",
    "bilfria": "bilfri",
    "bilfriare": "bilfri",
    "bilfriares": "bilfri",
    "bilfrias": "bilfri",
    "bilfriast": "bilfri",
    "bilfriaste": "bilfri",
    "bilfriastes": "bilfri",
    "bilfriasts": "bilfri",
    "bilfrie": "bilfri",
    "bilfries": "bilfri",
    "bilfris": "bilfri",
    "bilfritt": "bilfri",
    "bilfritts": "bilfri",
    "bilfärjan": "bilfärja",
    "bilfärjans": "bilfärja",
    "bilfärjas": "bilfärja",
    "bilfärje": "bilfärja",
    "bilfärjor": "bilfärja",
    "bilfärjorna": "bilfärja",
    "bilfärjornas": "bilfärja",
    "bilfärjors": "bilfärja",
    "bilförar": "bilförare",
    "bilföraren": "bilförare",
    "bilförarens": "bilförare",
    "bilförares": "bilförare",
    "bilförarna": "bilförare",
    "bilförarnas": "bilförare",
    "bilförsäkringar": "bilförsäkring",
    "bilförsäkringarna": "bilförsäkring",
    "bilförsäkringarnas": "bilförsäkring",
    "bilförsäkringars": "bilförsäkring",
    "bilförsäkringen": "bilförsäkring",
    "bilförsäkringens": "bilförsäkring",
    "bilförsäkrings": "bilförsäkring",
    "bilförsäljar": "bilförsäljare",
    "bilförsäljaren": "bilförsäljare",
    "bilförsäljarens": "bilförsäljare",
    "bilförsäljares": "bilförsäljare",
    "bilförsäljarna": "bilförsäljare",
    "bilförsäljarnas": "bilförsäljare",
    "bilgolven": "bilgolv",
    "bilgolvens": "bilgolv",
    "bilgolvet": "bilgolv",
    "bilgolvets": "bilgolv",
    "bilgolvs": "bilgolv",
    "bilhammar": "bilhammare",
    "bilhammaren": "bilhammare",
    "bilhammarens": "bilhammare",
    "bilhammares": "bilhammare",
    "bilhammarna": "bilhammare",
    "bilhammarnas": "bilhammare",
    "bilhjulen": "bilhjul",
    "bilhjulens": "bilhjul",
    "bilhjulet": "bilhjul",
    "bilhjulets": "bilhjul",
    "bilhjuls": "bilhjul",
    "bilhögtalar": "bilhögtalare",
    "bilhögtalaren": "bilhögtalare",
    "bilhögtalarens": "bilhögtalare",
    "bilhögtalares": "bilhögtalare",
    "bilhögtalarna": "bilhögtalare",
    "bilhögtalarnas": "bilhögtalare",
    "bilindustrien": "bilindustri",
    "bilindustriens": "bilindustri",
    "bilindustrier": "bilindustri",
    "bilindustrierna": "bilindustri",
    "bilindustriernas": "bilindustri",
    "bilindustriers": "bilindustri",
    "bilindustrin": "bilindustri",
    "bilindustrins": "bilindustri",
    "bilindustris": "bilindustri",
    "bilinguala": "bilingual",
    "bilingualare": "bilingual",
    "bilingualares": "bilingual",
    "bilingualas": "bilingual",
    "bilingualast": "bilingual",
    "bilingualaste": "bilingual",
    "bilingualastes": "bilingual",
    "bilingualasts": "bilingual",
    "bilinguale": "bilingual",
    "bilinguales": "bilingual",
    "bilingualismen": "bilingualism",
    "bilingualismens": "bilingualism",
    "bilingualismer": "bilingualism",
    "bilingualismerna": "bilingualism",
    "bilingualismernas": "bilingualism",
    "bilingualismers": "bilingualism",
    "bilingualisms": "bilingualism",
    "bilinguals": "bilingual",
    "bilingualt": "bilingual",
    "bilingualts": "bilingual",
    "bilismen": "bilism",
    "bilismens": "bilism",
    "bilismer": "bilism",
    "bilismerna": "bilism",
    "bilismernas": "bilism",
    "bilismers": "bilism",
    "bilisms": "bilism",
    "bilisten": "bilist",
    "bilistens": "bilist",
    "bilister": "bilist",
    "bilisterna": "bilist",
    "bilisternas": "bilist",
    "bilisters": "bilist",
    "bilistiska": "bilistisk",
    "bilistiskas": "bilistisk",
    "bilistiske": "bilistisk",
    "bilistiskes": "bilistisk",
    "bilistisks": "bilistisk",
    "bilistiskt": "bilistisk",
    "bilistiskts": "bilistisk",
    "bilists": "bilist",
    "biljardbollar": "biljardboll",
    "biljardbollarna": "biljardboll",
    "biljardbollarnas": "biljardboll",
    "biljardbollars": "biljardboll",
    "biljardbollen": "biljardboll",
    "biljardbollens": "biljardboll",
    "biljardbolls": "biljardboll",
    "biljardborden": "biljardbord",
    "biljardbordens": "biljardbord",
    "biljardbordet": "biljardbord",
    "biljardbordets": "biljardbord",
    "biljardbords": "biljardbord",
    "biljarden": "biljard",
    "biljardens": "biljard",
    "biljarder": "biljard",
    "biljarderna": "biljard",
    "biljardernas": "biljard",
    "biljarders": "biljard",
    "biljardkäppar": "biljardkäpp",
    "biljardkäpparna": "biljardkäpp",
    "biljardkäpparnas": "biljardkäpp",
    "biljardkäppars": "biljardkäpp",
    "biljardkäppen": "biljardkäpp",
    "biljardkäppens": "biljardkäpp",
    "biljardkäpps": "biljardkäpp",
    "biljardköer": "biljardkö",
    "biljardköerna": "biljardkö",
    "biljardköernas": "biljardkö",
    "biljardköers": "biljardkö",
    "biljardkön": "biljardkö",
    "biljardköns": "biljardkö",
    "biljardkös": "biljardkö",
    "biljards": "biljard",
    "biljardsalongen": "biljardsalong",
    "biljardsalongens": "biljardsalong",
    "biljardsalonger": "biljardsalong",
    "biljardsalongerna": "biljardsalong",
    "biljardsalongernas": "biljardsalong",
    "biljardsalongers": "biljardsalong",
    "biljardsalongs": "biljardsalong",
    "biljardspelen": "biljardspel",
    "biljardspelens": "biljardspel",
    "biljardspelet": "biljardspel",
    "biljardspelets": "biljardspel",
    "biljardspels": "biljardspel",
    "biljettautomaten": "biljettautomat",
    "biljettautomatens": "biljettautomat",
    "biljettautomater": "biljettautomat",
    "biljettautomaterna": "biljettautomat",
    "biljettautomaternas": "biljettautomat",
    "biljettautomaters": "biljettautomat",
    "biljettautomats": "biljettautomat",
    "biljettboken": "biljettbok",
    "biljettbokens": "biljettbok",
    "biljettbokningar": "biljettbokning",
    "biljettbokningarna": "biljettbokning",
    "biljettbokningarnas": "biljettbokning",
    "biljettbokningars": "biljettbokning",
    "biljettbokningen": "biljettbokning",
    "biljettbokningens": "biljettbokning",
    "biljettboknings": "biljettbokning",
    "biljettboks": "biljettbok",
    "biljettböcker": "biljettbok",
    "biljettböckerna": "biljettbok",
    "biljettböckernas": "biljettbok",
    "biljettböckers": "biljettbok",
    "biljetten": "biljett",
    "biljettens": "biljett",
    "biljetter": "biljett",
    "biljetterna": "biljett",
    "biljetternas": "biljett",
    "biljetters": "biljett",
    "biljettexpeditionen": "biljettexpedition",
    "biljettexpeditionens": "biljettexpedition",
    "biljettexpeditioner": "biljettexpedition",
    "biljettexpeditionerna": "biljettexpedition",
    "biljettexpeditionernas": "biljettexpedition",
    "biljettexpeditioners": "biljettexpedition",
    "biljettexpeditions": "biljettexpedition",
    "biljettfick": "biljettficka",
    "biljettfickan": "biljettficka",
    "biljettfickans": "biljettficka",
    "biljettfickas": "biljettficka",
    "biljettficke": "biljettficka",
    "biljettfickor": "biljettficka",
    "biljettfickorna": "biljettficka",
    "biljettfickornas": "biljettficka",
    "biljettfickors": "biljettficka",
    "biljettficks": "biljettficka",
    "biljettförsäljar": "biljettförsäljare",
    "biljettförsäljaren": "biljettförsäljare",
    "biljettförsäljarens": "biljettförsäljare",
    "biljettförsäljares": "biljettförsäljare",
    "biljettförsäljarna": "biljettförsäljare",
    "biljettförsäljarnas": "biljettförsäljare",
    "biljettförsäljningar": "biljettförsäljning",
    "biljettförsäljningarna": "biljettförsäljning",
    "biljettförsäljningarnas": "biljettförsäljning",
    "biljettförsäljningars": "biljettförsäljning",
    "biljettförsäljningen": "biljettförsäljning",
    "biljettförsäljningens": "biljettförsäljning",
    "biljettförsäljnings": "biljettförsäljning",
    "biljetthäften": "biljetthäfte",
    "biljetthäftena": "biljetthäfte",
    "biljetthäftenas": "biljetthäfte",
    "biljetthäftens": "biljetthäfte",
    "biljetthäftes": "biljetthäfte",
    "biljetthäftet": "biljetthäfte",
    "biljetthäftets": "biljetthäfte",
    "biljetthärvan": "biljetthärva",
    "biljetthärvans": "biljetthärva",
    "biljetthärvas": "biljetthärva",
    "biljetthärve": "biljetthärva",
    "biljetthärvor": "biljetthärva",
    "biljetthärvorna": "biljetthärva",
    "biljetthärvornas": "biljetthärva",
    "biljetthärvors": "biljetthärva",
    "biljettinkomsten": "biljettinkomst",
    "biljettinkomstens": "biljettinkomst",
    "biljettinkomster": "biljettinkomst",
    "biljettinkomsterna": "biljettinkomst",
    "biljettinkomsternas": "biljettinkomst",
    "biljettinkomsters": "biljettinkomst",
    "biljettinkomsts": "biljettinkomst",
    "biljettkontoren": "biljettkontor",
    "biljettkontorens": "biljettkontor",
    "biljettkontoret": "biljettkontor",
    "biljettkontorets": "biljettkontor",
    "biljettkontors": "biljettkontor",
    "biljettkontrollen": "biljettkontroll",
    "biljettkontrollens": "biljettkontroll",
    "biljettkontroller": "biljettkontroll",
    "biljettkontrollerna": "biljettkontroll",
    "biljettkontrollernas": "biljettkontroll",
    "biljettkontrollers": "biljettkontroll",
    "biljettkontrolls": "biljettkontroll",
    "biljettköpen": "biljettköp",
    "biljettköpens": "biljettköp",
    "biljettköpet": "biljettköp",
    "biljettköpets": "biljettköp",
    "biljettköps": "biljettköp",
    "biljettluck": "biljettlucka",
    "biljettluckan": "biljettlucka",
    "biljettluckans": "biljettlucka",
    "biljettluckas": "biljettlucka",
    "biljettlucke": "biljettlucka",
    "biljettluckor": "biljettlucka",
    "biljettluckorna": "biljettlucka",
    "biljettluckornas": "biljettlucka",
    "biljettluckors": "biljettlucka",
    "biljettlucks": "biljettlucka",
    "biljettmaskinen": "biljettmaskin",
    "biljettmaskinens": "biljettmaskin",
    "biljettmaskiner": "biljettmaskin",
    "biljettmaskinerna": "biljettmaskin",
    "biljettmaskinernas": "biljettmaskin",
    "biljettmaskiners": "biljettmaskin",
    "biljettmaskins": "biljettmaskin",
    "biljetts": "biljett",
    "biljettviseringar": "biljettvisering",
    "biljettviseringarna": "biljettvisering",
    "biljettviseringarnas": "biljettvisering",
    "biljettviseringars": "biljettvisering",
    "biljettviseringen": "biljettvisering",
    "biljettviseringens": "biljettvisering",
    "biljettviserings": "biljettvisering",
    "biljettänger": "biljettång",
    "biljettängerna": "biljettång",
    "biljettängernas": "biljettång",
    "biljettängers": "biljettång",
    "biljettången": "biljettång",
    "biljettångens": "biljettång",
    "biljettångs": "biljettång",
    "biljonen": "biljon",
    "biljonens": "biljon",
    "biljoner": "biljon",
    "biljonerna": "biljon",
    "biljonernas": "biljon",
    "biljoners": "biljon",
    "biljons": "biljon",
    "biljonte": "biljon",
    "biljontes": "biljon",
    "biljuden": "biljud",
    "biljudens": "biljud",
    "biljudet": "biljud",
    "biljudets": "biljud",
    "biljuds": "biljud",
    "bilkart": "bilkarta",
    "bilkartan": "bilkarta",
    "bilkartans": "bilkarta",
    "bilkartas": "bilkarta",
    "bilkarte": "bilkarta",
    "bilkartor": "bilkarta",
    "bilkartorna": "bilkarta",
    "bilkartornas": "bilkarta",
    "bilkartors": "bilkarta",
    "bilkarts": "bilkarta",
    "bilklädseln": "bilklädsel",
    "bilklädselns": "bilklädsel",
    "bilklädsels": "bilklädsel",
    "bilklädslar": "bilklädsel",
    "bilklädslarna": "bilklädsel",
    "bilklädslarnas": "bilklädsel",
    "bilklädslars": "bilklädsel",
    "bilkraschen": "bilkrasch",
    "bilkraschens": "bilkrasch",
    "bilkrascher": "bilkrasch",
    "bilkrascherna": "bilkrasch",
    "bilkraschernas": "bilkrasch",
    "bilkraschers": "bilkrasch",
    "bilkraschs": "bilkrasch",
    "bilkrockar": "bilkrock",
    "bilkrockarna": "bilkrock",
    "bilkrockarnas": "bilkrock",
    "bilkrockars": "bilkrock",
    "bilkrocken": "bilkrock",
    "bilkrockens": "bilkrock",
    "bilkrocks": "bilkrock",
    "bilkupéer": "bilkupé",
    "bilkupéerna": "bilkupé",
    "bilkupéernas": "bilkupé",
    "bilkupéers": "bilkupé",
    "bilkupén": "bilkupé",
    "bilkupéns": "bilkupé",
    "bilkupés": "bilkupé",
    "bilkåren": "bilkår",
    "bilkårens": "bilkår",
    "bilkårer": "bilkår",
    "bilkårerna": "bilkår",
    "bilkårernas": "bilkår",
    "bilkårers": "bilkår",
    "bilkåristen": "bilkårist",
    "bilkåristens": "bilkårist",
    "bilkårister": "bilkårist",
    "bilkåristerna": "bilkårist",
    "bilkåristernas": "bilkårist",
    "bilkåristers": "bilkårist",
    "bilkårists": "bilkårist",
    "bilkårs": "bilkår",
    "bilköer": "bilkö",
    "bilköerna": "bilkö",
    "bilköernas": "bilkö",
    "bilköers": "bilkö",
    "bilkön": "bilkö",
    "bilköns": "bilkö",
    "bilköpen": "bilköp",
    "bilköpens": "bilköp",
    "bilköpet": "bilköp",
    "bilköpets": "bilköp",
    "bilköps": "bilköp",
    "bilkörningar": "bilkörning",
    "bilkörningarna": "bilkörning",
    "bilkörningarnas": "bilkörning",
    "bilkörningars": "bilkörning",
    "bilkörningen": "bilkörning",
    "bilkörningens": "bilkörning",
    "bilkörnings": "bilkörning",
    "bilkös": "bilkö",
    "bill": "billa",
    "billamp": "billampa",
    "billampan": "billampa",
    "billampans": "billampa",
    "billampas": "billampa",
    "billampe": "billampa",
    "billampor": "billampa",
    "billamporna": "billampa",
    "billampornas": "billampa",
    "billampors": "billampa",
    "billamps": "billampa",
    "billan": "billa",
    "billans": "billa",
    "billar": "bill",
    "billarna": "bill",
    "billarnas": "bill",
    "billars": "bill",
    "billas": "billa",
    "billasten": "billast",
    "billastens": "billast",
    "billaster": "billast",
    "billasterna": "billast",
    "billasternas": "billast",
    "billasters": "billast",
    "billasts": "billast",
    "bille": "billa",
    "billen": "bill",
    "billens": "bill",
    "biller": "bill",
    "billerna": "bill",
    "billernas": "bill",
    "billers": "bill",
    "billiarden": "billiard",
    "billiardens": "billiard",
    "billiarder": "billiard",
    "billiarderna": "billiard",
    "billiardernas": "billiard",
    "billiarders": "billiard",
    "billiards": "billiard",
    "billiga": "billig",
    "billigare": "billig",
    "billigares": "billig",
    "billigas": "billig",
    "billigast": "billig",
    "billigaste": "billig",
    "billigastes": "billig",
    "billigasts": "billig",
    "billige": "billig",
    "billiges": "billig",
    "billigheten": "billighet",
    "billighetens": "billighet",
    "billigheter": "billighet",
    "billigheterna": "billighet",
    "billigheternas": "billighet",
    "billigheters": "billighet",
    "billighets": "billighet",
    "billighetsupplagan": "billighetsupplaga",
    "billighetsupplagans": "billighetsupplaga",
    "billighetsupplagas": "billighetsupplaga",
    "billighetsupplage": "billighetsupplaga",
    "billighetsupplagor": "billighetsupplaga",
    "billighetsupplagorna": "billighetsupplaga",
    "billighetsupplagornas": "billighetsupplaga",
    "billighetsupplagors": "billighetsupplaga",
    "billigs": "billig",
    "billigt": "billig",
    "billigts": "billig",
    "billionen": "billion",
    "billionens": "billion",
    "billioner": "billion",
    "billionerna": "billion",
    "billionernas": "billion",
    "billioners": "billion",
    "billions": "billion",
    "billionte": "billion",
    "billiontes": "billion",
    "billjusen": "billjus",
    "billjusens": "billjus",
    "billjuset": "billjus",
    "billjusets": "billjus",
    "billor": "billa",
    "billorna": "billa",
    "billornas": "billa",
    "billors": "billa",
    "billotsar": "billots",
    "billotsarna": "billots",
    "billotsarnas": "billots",
    "billotsars": "billots",
    "billotsen": "billots",
    "billotsens": "billots",
    "bills": "billa",
    "billykt": "billykta",
    "billyktan": "billykta",
    "billyktans": "billykta",
    "billyktas": "billykta",
    "billykte": "billykta",
    "billyktor": "billykta",
    "billyktorna": "billykta",
    "billyktornas": "billykta",
    "billyktors": "billykta",
    "billykts": "billykta",
    "billånen": "billån",
    "billånens": "billån",
    "billånet": "billån",
    "billånets": "billån",
    "billåns": "billån",
    "billåsen": "billås",
    "billåsens": "billås",
    "billåset": "billås",
    "billåsets": "billås",
    "bilmaskinen": "bilmaskin",
    "bilmaskinens": "bilmaskin",
    "bilmaskiner": "bilmaskin",
    "bilmaskinerna": "bilmaskin",
    "bilmaskinernas": "bilmaskin",
    "bilmaskiners": "bilmaskin",
    "bilmaskins": "bilmaskin",
    "bilmekanikern": "bilmekaniker",
    "bilmekanikerna": "bilmekaniker",
    "bilmekanikernas": "bilmekaniker",
    "bilmekanikerns": "bilmekaniker",
    "bilmekanikers": "bilmekaniker",
    "bilmotorer": "bilmotor",
    "bilmotorerna": "bilmotor",
    "bilmotorernas": "bilmotor",
    "bilmotorers": "bilmotor",
    "bilmotorn": "bilmotor",
    "bilmotorns": "bilmotor",
    "bilmotors": "bilmotor",
    "bilmärken": "bilmärke",
    "bilmärkena": "bilmärke",
    "bilmärkenas": "bilmärke",
    "bilmärkens": "bilmärke",
    "bilmärkes": "bilmärke",
    "bilmärket": "bilmärke",
    "bilmärkets": "bilmärke",
    "bilnavigatorer": "bilnavigator",
    "bilnavigatorerna": "bilnavigator",
    "bilnavigatorernas": "bilnavigator",
    "bilnavigatorers": "bilnavigator",
    "bilnavigatorn": "bilnavigator",
    "bilnavigatorns": "bilnavigator",
    "bilnavigators": "bilnavigator",
    "bilningen": "bilning",
    "bilningens": "bilning",
    "bilnings": "bilning",
    "bilnummerna": "bilnummer",
    "bilnummernas": "bilnummer",
    "bilnummers": "bilnummer",
    "bilnumren": "bilnummer",
    "bilnumrens": "bilnummer",
    "bilnumret": "bilnummer",
    "bilnumrets": "bilnummer",
    "bilnyckeln": "bilnyckel",
    "bilnyckelns": "bilnyckel",
    "bilnyckels": "bilnyckel",
    "bilnycklar": "bilnyckel",
    "bilnycklarna": "bilnyckel",
    "bilnycklarnas": "bilnyckel",
    "bilnycklars": "bilnyckel",
    "bilolyck": "bilolycka",
    "bilolyckan": "bilolycka",
    "bilolyckans": "bilolycka",
    "bilolyckas": "bilolycka",
    "bilolycke": "bilolycka",
    "bilolyckor": "bilolycka",
    "bilolyckorna": "bilolycka",
    "bilolyckornas": "bilolycka",
    "bilolyckors": "bilolycka",
    "bilolycks": "bilolycka",
    "bilor": "bila",
    "bilorna": "bila",
    "bilornas": "bila",
    "bilors": "bila",
    "bilparken": "bilpark",
    "bilparkens": "bilpark",
    "bilparker": "bilpark",
    "bilparkeringar": "bilparkering",
    "bilparkeringarna": "bilparkering",
    "bilparkeringarnas": "bilparkering",
    "bilparkeringars": "bilparkering",
    "bilparkeringen": "bilparkering",
    "bilparkeringens": "bilparkering",
    "bilparkerings": "bilparkering",
    "bilparkerna": "bilpark",
    "bilparkernas": "bilpark",
    "bilparkers": "bilpark",
    "bilparks": "bilpark",
    "bilplåtar": "bilplåt",
    "bilplåtarna": "bilplåt",
    "bilplåtarnas": "bilplåt",
    "bilplåtars": "bilplåt",
    "bilplåten": "bilplåt",
    "bilplåtens": "bilplåt",
    "bilplåts": "bilplåt",
    "bilprovningar": "bilprovning",
    "bilprovningarna": "bilprovning",
    "bilprovningarnas": "bilprovning",
    "bilprovningars": "bilprovning",
    "bilprovningen": "bilprovning",
    "bilprovningens": "bilprovning",
    "bilprovnings": "bilprovning",
    "bilradioapparaten": "bilradioapparat",
    "bilradioapparatens": "bilradioapparat",
    "bilradioapparater": "bilradioapparat",
    "bilradioapparaterna": "bilradioapparat",
    "bilradioapparaternas": "bilradioapparat",
    "bilradioapparaters": "bilradioapparat",
    "bilradioapparats": "bilradioapparat",
    "bilradion": "bilradio",
    "bilradions": "bilradio",
    "bilradior": "bilradio",
    "bilradiorna": "bilradio",
    "bilradiornas": "bilradio",
    "bilradiors": "bilradio",
    "bilradios": "bilradio",
    "bilrallyn": "bilrally",
    "bilrallyna": "bilrally",
    "bilrallynas": "bilrally",
    "bilrallyns": "bilrally",
    "bilrallys": "bilrally",
    "bilrallyt": "bilrally",
    "bilrallyts": "bilrally",
    "bilrattar": "bilratt",
    "bilrattarna": "bilratt",
    "bilrattarnas": "bilratt",
    "bilrattars": "bilratt",
    "bilratten": "bilratt",
    "bilrattens": "bilratt",
    "bilratts": "bilratt",
    "bilregisterna": "bilregister",
    "bilregisternas": "bilregister",
    "bilregisters": "bilregister",
    "bilregistren": "bilregister",
    "bilregistrens": "bilregister",
    "bilregistret": "bilregister",
    "bilregistrets": "bilregister",
    "bilrengöringar": "bilrengöring",
    "bilrengöringarna": "bilrengöring",
    "bilrengöringarnas": "bilrengöring",
    "bilrengöringars": "bilrengöring",
    "bilrengöringen": "bilrengöring",
    "bilrengöringens": "bilrengöring",
    "bilrengörings": "bilrengöring",
    "bilringar": "bilring",
    "bilringarna": "bilring",
    "bilringarnas": "bilring",
    "bilringars": "bilring",
    "bilringen": "bilring",
    "bilringens": "bilring",
    "bilrings": "bilring",
    "bilrockar": "bilrock",
    "bilrockarna": "bilrock",
    "bilrockarnas": "bilrock",
    "bilrockars": "bilrock",
    "bilrocken": "bilrock",
    "bilrockens": "bilrock",
    "bilrocks": "bilrock",
    "bilrutan": "bilruta",
    "bilrutans": "bilruta",
    "bilrutas": "bilruta",
    "bilrute": "bilruta",
    "bilrutor": "bilruta",
    "bilrutorna": "bilruta",
    "bilrutornas": "bilruta",
    "bilrutors": "bilruta",
    "bils": "bila",
    "bilschampon": "bilschampo",
    "bilschampona": "bilschampo",
    "bilschamponas": "bilschampo",
    "bilschampons": "bilschampo",
    "bilschampos": "bilschampo",
    "bilschamposvampar": "bilschamposvamp",
    "bilschamposvamparna": "bilschamposvamp",
    "bilschamposvamparnas": "bilschamposvamp",
    "bilschamposvampars": "bilschamposvamp",
    "bilschamposvampen": "bilschamposvamp",
    "bilschamposvampens": "bilschamposvamp",
    "bilschamposvamps": "bilschamposvamp",
    "bilschampot": "bilschampo",
    "bilschampots": "bilschampo",
    "bilsjuk": "bilsjuka",
    "bilsjuka": "bilsjuk",
    "bilsjukan": "bilsjuka",
    "bilsjukans": "bilsjuka",
    "bilsjukare": "bilsjuk",
    "bilsjukares": "bilsjuk",
    "bilsjukas": "bilsjuka",
    "bilsjukast": "bilsjuk",
    "bilsjukaste": "bilsjuk",
    "bilsjukastes": "bilsjuk",
    "bilsjukasts": "bilsjuk",
    "bilsjuke": "bilsjuka",
    "bilsjukes": "bilsjuk",
    "bilsjukheten": "bilsjukhet",
    "bilsjukhetens": "bilsjukhet",
    "bilsjukhets": "bilsjukhet",
    "bilsjukor": "bilsjuka",
    "bilsjukorna": "bilsjuka",
    "bilsjukornas": "bilsjuka",
    "bilsjukors": "bilsjuka",
    "bilsjuks": "bilsjuka",
    "bilsjukt": "bilsjuk",
    "bilsjukts": "bilsjuk",
    "bilskatten": "bilskatt",
    "bilskattens": "bilskatt",
    "bilskatter": "bilskatt",
    "bilskatterna": "bilskatt",
    "bilskatternas": "bilskatt",
    "bilskatters": "bilskatt",
    "bilskatts": "bilskatt",
    "bilskojar": "bilskojare",
    "bilskojaren": "bilskojare",
    "bilskojarens": "bilskojare",
    "bilskojares": "bilskojare",
    "bilskojarna": "bilskojare",
    "bilskojarnas": "bilskojare",
    "bilskolan": "bilskola",
    "bilskolans": "bilskola",
    "bilskolas": "bilskola",
    "bilskole": "bilskola",
    "bilskolor": "bilskola",
    "bilskolorna": "bilskola",
    "bilskolornas": "bilskola",
    "bilskolors": "bilskola",
    "bilsläpkärran": "bilsläpkärra",
    "bilsläpkärrans": "bilsläpkärra",
    "bilsläpkärras": "bilsläpkärra",
    "bilsläpkärre": "bilsläpkärra",
    "bilsläpkärror": "bilsläpkärra",
    "bilsläpkärrorna": "bilsläpkärra",
    "bilsläpkärrornas": "bilsläpkärra",
    "bilsläpkärrors": "bilsläpkärra",
    "bilspackels": "bilspackel",
    "bilspacklen": "bilspackel",
    "bilspacklens": "bilspackel",
    "bilspacklet": "bilspackel",
    "bilspacklets": "bilspackel",
    "bilstölden": "bilstöld",
    "bilstöldens": "bilstöld",
    "bilstölder": "bilstöld",
    "bilstölderna": "bilstöld",
    "bilstöldernas": "bilstöld",
    "bilstölders": "bilstöld",
    "bilstölds": "bilstöld",
    "bilsäten": "bilsäte",
    "bilsätena": "bilsäte",
    "bilsätenas": "bilsäte",
    "bilsätens": "bilsäte",
    "bilsätes": "bilsäte",
    "bilsätet": "bilsäte",
    "bilsätets": "bilsäte",
    "biltaken": "biltak",
    "biltakens": "biltak",
    "biltaket": "biltak",
    "biltakets": "biltak",
    "biltaks": "biltak",
    "biltelefonen": "biltelefon",
    "biltelefonens": "biltelefon",
    "biltelefoner": "biltelefon",
    "biltelefonerna": "biltelefon",
    "biltelefonernas": "biltelefon",
    "biltelefoners": "biltelefon",
    "biltelefons": "biltelefon",
    "biltillverkar": "biltillverkare",
    "biltillverkaren": "biltillverkare",
    "biltillverkarens": "biltillverkare",
    "biltillverkares": "biltillverkare",
    "biltillverkarna": "biltillverkare",
    "biltillverkarnas": "biltillverkare",
    "biltillverkningar": "biltillverkning",
    "biltillverkningarna": "biltillverkning",
    "biltillverkningarnas": "biltillverkning",
    "biltillverkningars": "biltillverkning",
    "biltillverkningen": "biltillverkning",
    "biltillverkningens": "biltillverkning",
    "biltillverknings": "biltillverkning",
    "biltoga": "biltog",
    "biltogare": "biltog",
    "biltogares": "biltog",
    "biltogas": "biltog",
    "biltogast": "biltog",
    "biltogaste": "biltog",
    "biltogastes": "biltog",
    "biltogasts": "biltog",
    "biltoge": "biltog",
    "biltoges": "biltog",
    "biltogs": "biltog",
    "biltogt": "biltog",
    "biltogts": "biltog",
    "biltrafiken": "biltrafik",
    "biltrafikens": "biltrafik",
    "biltrafiks": "biltrafik",
    "biltunlar": "biltunnel",
    "biltunlarna": "biltunnel",
    "biltunlarnas": "biltunnel",
    "biltunlars": "biltunnel",
    "biltunneln": "biltunnel",
    "biltunnelns": "biltunnel",
    "biltunnels": "biltunnel",
    "biltunnlar": "biltunnel",
    "biltunnlarna": "biltunnel",
    "biltunnlarnas": "biltunnel",
    "biltunnlars": "biltunnel",
    "bilturen": "biltur",
    "bilturens": "biltur",
    "bilturer": "biltur",
    "bilturerna": "biltur",
    "bilturernas": "biltur",
    "bilturers": "biltur",
    "bilturs": "biltur",
    "biltvättar": "biltvätt",
    "biltvättarna": "biltvätt",
    "biltvättarnas": "biltvätt",
    "biltvättars": "biltvätt",
    "biltvättborst": "biltvättborste",
    "biltvättborstar": "biltvättborste",
    "biltvättborstarna": "biltvättborste",
    "biltvättborstarnas": "biltvättborste",
    "biltvättborstars": "biltvättborste",
    "biltvättborsten": "biltvättborste",
    "biltvättborstens": "biltvättborste",
    "biltvättborstes": "biltvättborste",
    "biltvätten": "biltvätt",
    "biltvättens": "biltvätt",
    "biltvätts": "biltvätt",
    "biltävlingar": "biltävling",
    "biltävlingarna": "biltävling",
    "biltävlingarnas": "biltävling",
    "biltävlingars": "biltävling",
    "biltävlingen": "biltävling",
    "biltävlingens": "biltävling",
    "biltävlings": "biltävling",
    "bilvaxer": "bilvax",
    "bilvaxerna": "bilvax",
    "bilvaxernas": "bilvax",
    "bilvaxers": "bilvax",
    "bilvaxet": "bilvax",
    "bilvaxets": "bilvax",
    "bilverkstaden": "bilverkstad",
    "bilverkstadens": "bilverkstad",
    "bilverkstads": "bilverkstad",
    "bilverkstan": "bilverkstad",
    "bilverkstans": "bilverkstad",
    "bilverkstäder": "bilverkstad",
    "bilverkstäderna": "bilverkstad",
    "bilverkstädernas": "bilverkstad",
    "bilverkstäders": "bilverkstad",
    "bilvägar": "bilväg",
    "bilvägarna": "bilväg",
    "bilvägarnas": "bilväg",
    "bilvägars": "bilväg",
    "bilvägen": "bilväg",
    "bilvägens": "bilväg",
    "bilvägs": "bilväg",
    "bilyx": "bilyxa",
    "bilyxan": "bilyxa",
    "bilyxans": "bilyxa",
    "bilyxas": "bilyxa",
    "bilyxe": "bilyxa",
    "bilyxor": "bilyxa",
    "bilyxorna": "bilyxa",
    "bilyxornas": "bilyxa",
    "bilyxors": "bilyxa",
    "bilägar": "bilägare",
    "bilägaren": "bilägare",
    "bilägarens": "bilägare",
    "bilägares": "bilägare",
    "bilägarna": "bilägare",
    "bilägarnas": "bilägare",
    "bilägerna": "biläger",
    "bilägernas": "biläger",
    "bilägers": "biläger",
    "bilägg": "bilägga",
    "biläggande": "bilägga",
    "bilägganden": "biläggande",
    "biläggandena": "biläggande",
    "biläggandenas": "biläggande",
    "biläggandens": "biläggande",
    "biläggandes": "biläggande",
    "biläggandet": "biläggande",
    "biläggandets": "biläggande",
    "biläggas": "bilägga",
    "bilägger": "bilägga",
    "bilägges": "bilägga",
    "biläggs": "bilägga",
    "bilägren": "biläger",
    "bilägrens": "biläger",
    "bilägret": "biläger",
    "bilägrets": "biläger",
    "bilåkningar": "bilåkning",
    "bilåkningarna": "bilåkning",
    "bilåkningarnas": "bilåkning",
    "bilåkningars": "bilåkning",
    "bilåkningen": "bilåkning",
    "bilåkningens": "bilåkning",
    "bilåknings": "bilåkning",
    "bimetallen": "bimetall",
    "bimetallens": "bimetall",
    "bimetaller": "bimetall",
    "bimetallerna": "bimetall",
    "bimetallernas": "bimetall",
    "bimetallers": "bimetall",
    "bimetallismen": "bimetallism",
    "bimetallismens": "bimetallism",
    "bimetallismer": "bimetallism",
    "bimetallismerna": "bimetallism",
    "bimetallismernas": "bimetallism",
    "bimetallismers": "bimetallism",
    "bimetallisms": "bimetallism",
    "bimetalls": "bimetall",
    "bimån": "bimåne",
    "bimånar": "bimåne",
    "bimånarna": "bimåne",
    "bimånarnas": "bimåne",
    "bimånars": "bimåne",
    "bimånen": "bimåne",
    "bimånens": "bimåne",
    "bimånes": "bimåne",
    "bimåns": "bimåne",
    "bin": "bi",
    "bina": "bi",
    "binamnen": "binamn",
    "binamnens": "binamn",
    "binamnet": "binamn",
    "binamnets": "binamn",
    "binamns": "binamn",
    "binas": "bi",
    "bind": "binda",
    "bindan": "binda",
    "bindande": "binda",
    "bindanden": "bindande",
    "bindandena": "bindande",
    "bindandenas": "bindande",
    "bindandens": "bindande",
    "bindandes": "bindande",
    "bindandet": "bindande",
    "bindandets": "bindande",
    "bindans": "binda",
    "bindar": "bindare",
    "bindaren": "bindare",
    "bindarens": "bindare",
    "bindares": "bindare",
    "bindarna": "bindare",
    "bindarnas": "bindare",
    "bindas": "binda",
    "bindbjälk": "bindbjälke",
    "bindbjälkar": "bindbjälke",
    "bindbjälkarna": "bindbjälke",
    "bindbjälkarnas": "bindbjälke",
    "bindbjälkars": "bindbjälke",
    "bindbjälken": "bindbjälke",
    "bindbjälkens": "bindbjälke",
    "bindbjälkes": "bindbjälke",
    "bindbjälks": "bindbjälke",
    "binde": "binda",
    "bindehinnan": "bindehinna",
    "bindehinnans": "bindehinna",
    "bindehinnas": "bindehinna",
    "bindehinne": "bindehinna",
    "bindehinneinflammationen": "bindehinneinflammation",
    "bindehinneinflammationens": "bindehinneinflammation",
    "bindehinneinflammationer": "bindehinneinflammation",
    "bindehinneinflammationerna": "bindehinneinflammation",
    "bindehinneinflammationernas": "bindehinneinflammation",
    "bindehinneinflammationers": "bindehinneinflammation",
    "bindehinneinflammations": "bindehinneinflammation",
    "bindehinnor": "bindehinna",
    "bindehinnorna": "bindehinna",
    "bindehinnornas": "bindehinna",
    "bindehinnors": "bindehinna",
    "bindeln": "bindel",
    "bindelns": "bindel",
    "bindels": "bindel",
    "bindemedels": "bindemedel",
    "bindemedlen": "bindemedel",
    "bindemedlens": "bindemedel",
    "bindemedlet": "bindemedel",
    "bindemedlets": "bindemedel",
    "binden": "bind",
    "bindens": "bind",
    "bindenyckeln": "bindenyckel",
    "bindenyckelns": "bindenyckel",
    "bindenyckels": "bindenyckel",
    "bindenycklar": "bindenyckel",
    "bindenycklarna": "bindenyckel",
    "bindenycklarnas": "bindenyckel",
    "bindenycklars": "bindenyckel",
    "bindeorden": "bindeord",
    "bindeordens": "bindeord",
    "bindeordet": "bindeord",
    "bindeordets": "bindeord",
    "bindeords": "bindeord",
    "binder": "binda",
    "binderier": "binderi",
    "binderierna": "binderi",
    "binderiernas": "binderi",
    "binderiers": "binderi",
    "binderiet": "binderi",
    "binderiets": "binderi",
    "binderis": "binderi",
    "binderit": "binderi",
    "binderits": "binderi",
    "bindes": "binda",
    "bindestrecken": "bindestreck",
    "bindestreckens": "bindestreck",
    "bindestrecket": "bindestreck",
    "bindestreckets": "bindestreck",
    "bindestrecks": "bindestreck",
    "bindesubstansen": "bindesubstans",
    "bindesubstansens": "bindesubstans",
    "bindesubstanser": "bindesubstans",
    "bindesubstanserna": "bindesubstans",
    "bindesubstansernas": "bindesubstans",
    "bindesubstansers": "bindesubstans",
    "bindesäckar": "bindesäck",
    "bindesäckarna": "bindesäck",
    "bindesäckarnas": "bindesäck",
    "bindesäckars": "bindesäck",
    "bindesäcken": "bindesäck",
    "bindesäckens": "bindesäck",
    "bindesäcks": "bindesäck",
    "bindet": "bind",
    "bindets": "bind",
    "bindevokalen": "bindevokal",
    "bindevokalens": "bindevokal",
    "bindevokaler": "bindevokal",
    "bindevokalerna": "bindevokal",
    "bindevokalernas": "bindevokal",
    "bindevokalers": "bindevokal",
    "bindevokals": "bindevokal",
    "bindgalenheten": "bindgalenhet",
    "bindgalenhetens": "bindgalenhet",
    "bindgalenhets": "bindgalenhet",
    "bindgalens": "bindgalen",
    "bindgalet": "bindgalen",
    "bindgalets": "bindgalen",
    "bindgalna": "bindgalen",
    "bindgalnare": "bindgalen",
    "bindgalnares": "bindgalen",
    "bindgalnas": "bindgalen",
    "bindgalnast": "bindgalen",
    "bindgalnaste": "bindgalen",
    "bindgalnastes": "bindgalen",
    "bindgalnasts": "bindgalen",
    "bindgalne": "bindgalen",
    "bindgalnes": "bindgalen",
    "bindgarnen": "bindgarn",
    "bindgarnens": "bindgarn",
    "bindgarnet": "bindgarn",
    "bindgarnets": "bindgarn",
    "bindgarns": "bindgarn",
    "bindlar": "bindel",
    "bindlarna": "bindel",
    "bindlarnas": "bindel",
    "bindlars": "bindel",
    "bindningar": "bindning",
    "bindningarna": "bindning",
    "bindningarnas": "bindning",
    "bindningars": "bindning",
    "bindningen": "bindning",
    "bindningens": "bindning",
    "bindnings": "bindning",
    "bindnålar": "bindnål",
    "bindnålarna": "bindnål",
    "bindnålarnas": "bindnål",
    "bindnålars": "bindnål",
    "bindnålen": "bindnål",
    "bindnålens": "bindnål",
    "bindnåls": "bindnål",
    "bindor": "binda",
    "bindorna": "binda",
    "bindornas": "binda",
    "bindors": "binda",
    "binds": "binda",
    "bindsels": "bindsel",
    "bindslen": "bindsle",
    "bindslena": "bindsle",
    "bindslenas": "bindsle",
    "bindslens": "bindsle",
    "bindsles": "bindsle",
    "bindslet": "bindsle",
    "bindslets": "bindsle",
    "bindstenar": "bindsten",
    "bindstenarna": "bindsten",
    "bindstenarnas": "bindsten",
    "bindstenars": "bindsten",
    "bindstenen": "bindsten",
    "bindstenens": "bindsten",
    "bindstens": "bindsten",
    "bindsul": "bindsula",
    "bindsulan": "bindsula",
    "bindsulans": "bindsula",
    "bindsulas": "bindsula",
    "bindsule": "bindsula",
    "bindsulor": "bindsula",
    "bindsulorna": "bindsula",
    "bindsulornas": "bindsula",
    "bindsulors": "bindsula",
    "bindsuls": "bindsula",
    "bindvävar": "bindväv",
    "bindvävarna": "bindväv",
    "bindvävarnas": "bindväv",
    "bindvävars": "bindväv",
    "bindväven": "bindväv",
    "bindvävens": "bindväv",
    "bindvävs": "bindväv",
    "bindvävshinnan": "bindvävshinna",
    "bindvävshinnans": "bindvävshinna",
    "bindvävshinnas": "bindvävshinna",
    "bindvävshinne": "bindvävshinna",
    "bindvävshinnor": "bindvävshinna",
    "bindvävshinnorna": "bindvävshinna",
    "bindvävshinnornas": "bindvävshinna",
    "bindvävshinnors": "bindvävshinna",
    "bindvävskapseln": "bindvävskapsel",
    "bindvävskapselns": "bindvävskapsel",
    "bindvävskapsels": "bindvävskapsel",
    "bindvävskapslar": "bindvävskapsel",
    "bindvävskapslarna": "bindvävskapsel",
    "bindvävskapslarnas": "bindvävskapsel",
    "bindvävskapslars": "bindvävskapsel",
    "bindvävssäckar": "bindvävssäck",
    "bindvävssäckarna": "bindvävssäck",
    "bindvävssäckarnas": "bindvävssäck",
    "bindvävssäckars": "bindvävssäck",
    "bindvävssäcken": "bindvävssäck",
    "bindvävssäckens": "bindvävssäck",
    "bindvävssäcks": "bindvävssäck",
    "bindvävstrådar": "bindvävstråd",
    "bindvävstrådarna": "bindvävstråd",
    "bindvävstrådarnas": "bindvävstråd",
    "bindvävstrådars": "bindvävstråd",
    "bindvävstråden": "bindvävstråd",
    "bindvävstrådens": "bindvävstråd",
    "bindvävstråds": "bindvävstråd",
    "bindämnen": "bindämne",
    "bindämnena": "bindämne",
    "bindämnenas": "bindämne",
    "bindämnens": "bindämne",
    "bindämnes": "bindämne",
    "bindämnet": "bindämne",
    "bindämnets": "bindämne",
    "bing": "binge",
    "bingan": "binga",
    "bingans": "binga",
    "bingar": "binge",
    "bingarna": "binge",
    "bingarnas": "binge",
    "bingars": "binge",
    "bingas": "binga",
    "binge": "binga",
    "bingeln": "bingel",
    "bingelns": "bingel",
    "bingels": "bingel",
    "bingen": "binge",
    "bingens": "binge",
    "binges": "binge",
    "binglar": "bingel",
    "binglarna": "bingel",
    "binglarnas": "bingel",
    "binglars": "bingel",
    "bingobrick": "bingobricka",
    "bingobrickan": "bingobricka",
    "bingobrickans": "bingobricka",
    "bingobrickas": "bingobricka",
    "bingobricke": "bingobricka",
    "bingobrickor": "bingobricka",
    "bingobrickorna": "bingobricka",
    "bingobrickornas": "bingobricka",
    "bingobrickors": "bingobricka",
    "bingobricks": "bingobricka",
    "bingon": "bingo",
    "bingons": "bingo",
    "bingor": "binga",
    "bingorna": "binga",
    "bingornas": "binga",
    "bingors": "binga",
    "bingos": "bingo",
    "bingosugenheten": "bingosugenhet",
    "bingosugenhetens": "bingosugenhet",
    "bingosugenhets": "bingosugenhet",
    "bingosugens": "bingosugen",
    "bingosuget": "bingosugen",
    "bingosugets": "bingosugen",
    "bingosugna": "bingosugen",
    "bingosugnare": "bingosugen",
    "bingosugnares": "bingosugen",
    "bingosugnas": "bingosugen",
    "bingosugnast": "bingosugen",
    "bingosugnaste": "bingosugen",
    "bingosugnastes": "bingosugen",
    "bingosugnasts": "bingosugen",
    "bingosugne": "bingosugen",
    "bingosugnes": "bingosugen",
    "bings": "binge",
    "binjurar": "binjure",
    "binjurarna": "binjure",
    "binjurarnas": "binjure",
    "binjurars": "binjure",
    "binjurebarken": "binjurebark",
    "binjurebarkens": "binjurebark",
    "binjurebarks": "binjurebark",
    "binjuren": "binjure",
    "binjurens": "binjure",
    "binjures": "binjure",
    "bink": "binka",
    "binkan": "binka",
    "binkans": "binka",
    "binkas": "binka",
    "binke": "binka",
    "binkor": "binka",
    "binkorna": "binka",
    "binkornas": "binka",
    "binkors": "binka",
    "binks": "binka",
    "binnikemaskar": "binnikemask",
    "binnikemaskarna": "binnikemask",
    "binnikemaskarnas": "binnikemask",
    "binnikemaskars": "binnikemask",
    "binnikemasken": "binnikemask",
    "binnikemaskens": "binnikemask",
    "binnikemasks": "binnikemask",
    "binokeln": "binokel",
    "binokelns": "binokel",
    "binokels": "binokel",
    "binoklar": "binokel",
    "binoklarna": "binokel",
    "binoklarnas": "binokel",
    "binoklars": "binokel",
    "binokler": "binokel",
    "binoklerna": "binokel",
    "binoklernas": "binokel",
    "binoklers": "binokel",
    "binokulära": "binokulär",
    "binokulärare": "binokulär",
    "binokulärares": "binokulär",
    "binokuläras": "binokulär",
    "binokulärast": "binokulär",
    "binokuläraste": "binokulär",
    "binokulärastes": "binokulär",
    "binokulärasts": "binokulär",
    "binokuläre": "binokulär",
    "binokuläres": "binokulär",
    "binokulärs": "binokulär",
    "binokulärt": "binokulär",
    "binokulärts": "binokulär",
    "binomen": "binom",
    "binomens": "binom",
    "binomet": "binom",
    "binomets": "binom",
    "binoms": "binom",
    "bins": "bi",
    "binära": "binär",
    "binärare": "binär",
    "binärares": "binär",
    "binäras": "binär",
    "binärast": "binär",
    "binäraste": "binär",
    "binärastes": "binär",
    "binärasts": "binär",
    "binäre": "binär",
    "binäres": "binär",
    "binäringar": "binäring",
    "binäringarna": "binäring",
    "binäringarnas": "binäring",
    "binäringars": "binäring",
    "binäringen": "binäring",
    "binäringens": "binäring",
    "binärings": "binäring",
    "binärs": "binär",
    "binärt": "binär",
    "binärts": "binär",
    "biobanken": "biobank",
    "biobankens": "biobank",
    "biobanker": "biobank",
    "biobankerna": "biobank",
    "biobankernas": "biobank",
    "biobankers": "biobank",
    "biobankningen": "biobankning",
    "biobankningens": "biobankning",
    "biobanknings": "biobankning",
    "biobanks": "biobank",
    "biobesöken": "biobesök",
    "biobesökens": "biobesök",
    "biobesöket": "biobesök",
    "biobesökets": "biobesök",
    "biobesöks": "biobesök",
    "biobiljetten": "biobiljett",
    "biobiljettens": "biobiljett",
    "biobiljetter": "biobiljett",
    "biobiljetterna": "biobiljett",
    "biobiljetternas": "biobiljett",
    "biobiljetters": "biobiljett",
    "biobiljetts": "biobiljett",
    "biobränslen": "biobränsle",
    "biobränslena": "biobränsle",
    "biobränslenas": "biobränsle",
    "biobränslens": "biobränsle",
    "biobränsles": "biobränsle",
    "biobränslet": "biobränsle",
    "biobränslets": "biobränsle",
    "biociden": "biocid",
    "biocidens": "biocid",
    "biocider": "biocid",
    "biociderna": "biocid",
    "biocidernas": "biocid",
    "biociders": "biocid",
    "biocids": "biocid",
    "biodlar": "biodlare",
    "biodlaren": "biodlare",
    "biodlarens": "biodlare",
    "biodlares": "biodlare",
    "biodlarna": "biodlare",
    "biodlarnas": "biodlare",
    "biodlingar": "biodling",
    "biodlingarna": "biodling",
    "biodlingarnas": "biodling",
    "biodlingars": "biodling",
    "biodlingen": "biodling",
    "biodlingens": "biodling",
    "biodlings": "biodling",
    "biodrivmedels": "biodrivmedel",
    "biodrivmedlen": "biodrivmedel",
    "biodrivmedlens": "biodrivmedel",
    "biodrivmedlet": "biodrivmedel",
    "biodrivmedlets": "biodrivmedel",
    "biodukar": "bioduk",
    "biodukarna": "bioduk",
    "biodukarnas": "bioduk",
    "biodukars": "bioduk",
    "bioduken": "bioduk",
    "biodukens": "bioduk",
    "bioduks": "bioduk",
    "biodynamiken": "biodynamik",
    "biodynamikens": "biodynamik",
    "biodynamiks": "biodynamik",
    "biodynamiska": "biodynamisk",
    "biodynamiskare": "biodynamisk",
    "biodynamiskares": "biodynamisk",
    "biodynamiskas": "biodynamisk",
    "biodynamiskast": "biodynamisk",
    "biodynamiskaste": "biodynamisk",
    "biodynamiskastes": "biodynamisk",
    "biodynamiskasts": "biodynamisk",
    "biodynamiske": "biodynamisk",
    "biodynamiskes": "biodynamisk",
    "biodynamisks": "biodynamisk",
    "biodynamiskt": "biodynamisk",
    "biodynamiskts": "biodynamisk",
    "biofysiken": "biofysik",
    "biofysikens": "biofysik",
    "biofysiks": "biofysik",
    "biofysiska": "biofysisk",
    "biofysiskare": "biofysisk",
    "biofysiskares": "biofysisk",
    "biofysiskas": "biofysisk",
    "biofysiskast": "biofysisk",
    "biofysiskaste": "biofysisk",
    "biofysiskastes": "biofysisk",
    "biofysiskasts": "biofysisk",
    "biofysiske": "biofysisk",
    "biofysiskes": "biofysisk",
    "biofysisks": "biofysisk",
    "biofysiskt": "biofysisk",
    "biofysiskts": "biofysisk",
    "bioföreställningar": "bioföreställning",
    "bioföreställningarna": "bioföreställning",
    "bioföreställningarnas": "bioföreställning",
    "bioföreställningars": "bioföreställning",
    "bioföreställningen": "bioföreställning",
    "bioföreställningens": "bioföreställning",
    "bioföreställnings": "bioföreställning",
    "biogena": "biogen",
    "biogenare": "biogen",
    "biogenares": "biogen",
    "biogenas": "biogen",
    "biogenast": "biogen",
    "biogenaste": "biogen",
    "biogenastes": "biogen",
    "biogenasts": "biogen",
    "biogene": "biogen",
    "biogenes": "biogen",
    "biogenesen": "biogenes",
    "biogenesens": "biogenes",
    "biogenetiska": "biogenetisk",
    "biogenetiskare": "biogenetisk",
    "biogenetiskares": "biogenetisk",
    "biogenetiskas": "biogenetisk",
    "biogenetiskast": "biogenetisk",
    "biogenetiskaste": "biogenetisk",
    "biogenetiskastes": "biogenetisk",
    "biogenetiskasts": "biogenetisk",
    "biogenetiske": "biogenetisk",
    "biogenetiskes": "biogenetisk",
    "biogenetisks": "biogenetisk",
    "biogenetiskt": "biogenetisk",
    "biogenetiskts": "biogenetisk",
    "biogens": "biogen",
    "biogent": "biogen",
    "biogents": "biogen",
    "biogeografien": "biogeografi",
    "biogeografiens": "biogeografi",
    "biogeografin": "biogeografi",
    "biogeografins": "biogeografi",
    "biogeografis": "biogeografi",
    "biografbyråer": "biografbyrå",
    "biografbyråerna": "biografbyrå",
    "biografbyråernas": "biografbyrå",
    "biografbyråers": "biografbyrå",
    "biografbyrån": "biografbyrå",
    "biografbyråns": "biografbyrå",
    "biografbyrås": "biografbyrå",
    "biografen": "biograf",
    "biografens": "biograf",
    "biografer": "biograf",
    "biograferad": "biografera",
    "biograferade": "biografera",
    "biograferades": "biografera",
    "biograferads": "biografera",
    "biograferande": "biografera",
    "biograferanden": "biograferande",
    "biograferandena": "biograferande",
    "biograferandenas": "biograferande",
    "biograferandens": "biograferande",
    "biograferandes": "biograferande",
    "biograferandet": "biograferande",
    "biograferandets": "biograferande",
    "biograferar": "biografera",
    "biograferas": "biografera",
    "biograferat": "biografera",
    "biograferats": "biografera",
    "biograferbara": "biograferbar",
    "biograferbarare": "biograferbar",
    "biograferbarares": "biograferbar",
    "biograferbaras": "biograferbar",
    "biograferbarast": "biograferbar",
    "biograferbaraste": "biograferbar",
    "biograferbarastes": "biograferbar",
    "biograferbarasts": "biograferbar",
    "biograferbare": "biograferbar",
    "biograferbares": "biograferbar",
    "biograferbarheten": "biograferbarhet",
    "biograferbarhetens": "biograferbarhet",
    "biograferbarhets": "biograferbarhet",
    "biograferbars": "biograferbar",
    "biograferbart": "biograferbar",
    "biograferbarts": "biograferbar",
    "biograferingar": "biografering",
    "biograferingarna": "biografering",
    "biograferingarnas": "biografering",
    "biograferingars": "biografering",
    "biograferingen": "biografering",
    "biograferingens": "biografering",
    "biograferings": "biografering",
    "biograferna": "biograf",
    "biografernas": "biograf",
    "biografers": "biograf",
    "biografföreståndar": "biografföreståndare",
    "biografföreståndaren": "biografföreståndare",
    "biografföreståndarens": "biografföreståndare",
    "biografföreståndares": "biografföreståndare",
    "biografföreståndarna": "biografföreståndare",
    "biografföreståndarnas": "biografföreståndare",
    "biografien": "biografi",
    "biografiens": "biografi",
    "biografier": "biografi",
    "biografierna": "biografi",
    "biografiernas": "biografi",
    "biografiers": "biografi",
    "biografin": "biografi",
    "biografins": "biografi",
    "biografis": "biografi",
    "biografiska": "biografisk",
    "biografiskare": "biografisk",
    "biografiskares": "biografisk",
    "biografiskas": "biografisk",
    "biografiskast": "biografisk",
    "biografiskaste": "biografisk",
    "biografiskastes": "biografisk",
    "biografiskasts": "biografisk",
    "biografiske": "biografisk",
    "biografiskes": "biografisk",
    "biografisks": "biografisk",
    "biografiskt": "biografisk",
    "biografiskts": "biografisk",
    "biografmässiga": "biografmässig",
    "biografmässigare": "biografmässig",
    "biografmässigares": "biografmässig",
    "biografmässigas": "biografmässig",
    "biografmässigast": "biografmässig",
    "biografmässigaste": "biografmässig",
    "biografmässigastes": "biografmässig",
    "biografmässigasts": "biografmässig",
    "biografmässige": "biografmässig",
    "biografmässiges": "biografmässig",
    "biografmässigs": "biografmässig",
    "biografmässigt": "biografmässig",
    "biografmässigts": "biografmässig",
    "biograforgeln": "biograforgel",
    "biograforgelns": "biograforgel",
    "biograforgels": "biograforgel",
    "biograforglar": "biograforgel",
    "biograforglarna": "biograforgel",
    "biograforglarnas": "biograforgel",
    "biograforglars": "biograforgel",
    "biografpubliken": "biografpublik",
    "biografpublikens": "biografpublik",
    "biografpubliks": "biografpublik",
    "biografs": "biograf",
    "biografteatern": "biografteater",
    "biografteaterns": "biografteater",
    "biografteaters": "biografteater",
    "biografteatrar": "biografteater",
    "biografteatrarna": "biografteater",
    "biografteatrarnas": "biografteater",
    "biografteatrars": "biografteater",
    "biokemien": "biokemi",
    "biokemiens": "biokemi",
    "biokemin": "biokemi",
    "biokemins": "biokemi",
    "biokemis": "biokemi",
    "biokemiska": "biokemisk",
    "biokemiskare": "biokemisk",
    "biokemiskares": "biokemisk",
    "biokemiskas": "biokemisk",
    "biokemiskast": "biokemisk",
    "biokemiskaste": "biokemisk",
    "biokemiskastes": "biokemisk",
    "biokemiskasts": "biokemisk",
    "biokemiske": "biokemisk",
    "biokemiskes": "biokemisk",
    "biokemisks": "biokemisk",
    "biokemiskt": "biokemisk",
    "biokemiskts": "biokemisk",
    "biokemisten": "biokemist",
    "biokemistens": "biokemist",
    "biokemister": "biokemist",
    "biokemisterna": "biokemist",
    "biokemisternas": "biokemist",
    "biokemisters": "biokemist",
    "biokemists": "biokemist",
    "bioklimatologien": "bioklimatologi",
    "bioklimatologiens": "bioklimatologi",
    "bioklimatologin": "bioklimatologi",
    "bioklimatologins": "bioklimatologi",
    "bioklimatologis": "bioklimatologi",
    "biokronologien": "biokronologi",
    "biokronologiens": "biokronologi",
    "biokronologin": "biokronologi",
    "biokronologins": "biokronologi",
    "biokronologis": "biokronologi",
    "biologen": "biolog",
    "biologens": "biolog",
    "biologer": "biolog",
    "biologerna": "biolog",
    "biologernas": "biolog",
    "biologers": "biolog",
    "biologien": "biologi",
    "biologiens": "biologi",
    "biologin": "biologi",
    "biologins": "biologi",
    "biologis": "biologi",
    "biologiska": "biologisk",
    "biologiskare": "biologisk",
    "biologiskares": "biologisk",
    "biologiskas": "biologisk",
    "biologiskast": "biologisk",
    "biologiskaste": "biologisk",
    "biologiskastes": "biologisk",
    "biologiskasts": "biologisk",
    "biologiske": "biologisk",
    "biologiskes": "biologisk",
    "biologisks": "biologisk",
    "biologiskt": "biologisk",
    "biologiskts": "biologisk",
    "biologs": "biolog",
    "biomassan": "biomassa",
    "biomassans": "biomassa",
    "biomassas": "biomassa",
    "biomasse": "biomassa",
    "biomassor": "biomassa",
    "biomassorna": "biomassa",
    "biomassornas": "biomassa",
    "biomassors": "biomassa",
    "biomedicinen": "biomedicin",
    "biomedicinens": "biomedicin",
    "biomedicins": "biomedicin",
    "biometrien": "biometri",
    "biometriens": "biometri",
    "biometrin": "biometri",
    "biometrins": "biometri",
    "biometris": "biometri",
    "biomständigheten": "biomständighet",
    "biomständighetens": "biomständighet",
    "biomständigheter": "biomständighet",
    "biomständigheterna": "biomständighet",
    "biomständigheternas": "biomständighet",
    "biomständigheters": "biomständighet",
    "biomständighets": "biomständighet",
    "bion": "bio",
    "bions": "bio",
    "biopremiären": "biopremiär",
    "biopremiärens": "biopremiär",
    "biopremiärer": "biopremiär",
    "biopremiärerna": "biopremiär",
    "biopremiärernas": "biopremiär",
    "biopremiärers": "biopremiär",
    "biopremiärs": "biopremiär",
    "bioreaktorer": "bioreaktor",
    "bioreaktorerna": "bioreaktor",
    "bioreaktorernas": "bioreaktor",
    "bioreaktorers": "bioreaktor",
    "bioreaktorn": "bioreaktor",
    "bioreaktorns": "bioreaktor",
    "bioreaktors": "bioreaktor",
    "biorytmen": "biorytm",
    "biorytmens": "biorytm",
    "biorytms": "biorytm",
    "bios": "bio",
    "biosalongen": "biosalong",
    "biosalongens": "biosalong",
    "biosalonger": "biosalong",
    "biosalongerna": "biosalong",
    "biosalongernas": "biosalong",
    "biosalongers": "biosalong",
    "biosalongs": "biosalong",
    "biosfären": "biosfär",
    "biosfärens": "biosfär",
    "biosfärer": "biosfär",
    "biosfärerna": "biosfär",
    "biosfärernas": "biosfär",
    "biosfärers": "biosfär",
    "biosfärs": "biosfär",
    "biotekniken": "bioteknik",
    "bioteknikens": "bioteknik",
    "biotekniker": "bioteknik",
    "bioteknikerna": "bioteknik",
    "bioteknikernas": "bioteknik",
    "bioteknikers": "bioteknik",
    "biotekniks": "bioteknik",
    "biotekniska": "bioteknisk",
    "biotekniskare": "bioteknisk",
    "biotekniskares": "bioteknisk",
    "biotekniskas": "bioteknisk",
    "biotekniskast": "bioteknisk",
    "biotekniskaste": "bioteknisk",
    "biotekniskastes": "bioteknisk",
    "biotekniskasts": "bioteknisk",
    "biotekniske": "bioteknisk",
    "biotekniskes": "bioteknisk",
    "bioteknisks": "bioteknisk",
    "biotekniskt": "bioteknisk",
    "biotekniskts": "bioteknisk",
    "biotiska": "biotisk",
    "biotiskare": "biotisk",
    "biotiskares": "biotisk",
    "biotiskas": "biotisk",
    "biotiskast": "biotisk",
    "biotiskaste": "biotisk",
    "biotiskastes": "biotisk",
    "biotiskasts": "biotisk",
    "biotiske": "biotisk",
    "biotiskes": "biotisk",
    "biotisks": "biotisk",
    "biotiskt": "biotisk",
    "biotiskts": "biotisk",
    "biotopen": "biotop",
    "biotopens": "biotop",
    "biotoper": "biotop",
    "biotoperna": "biotop",
    "biotopernas": "biotop",
    "biotopers": "biotop",
    "biotops": "biotop",
    "biotypen": "biotyp",
    "biotypens": "biotyp",
    "biotyper": "biotyp",
    "biotyperna": "biotyp",
    "biotypernas": "biotyp",
    "biotypers": "biotyp",
    "biotyps": "biotyp",
    "bipersonen": "biperson",
    "bipersonens": "biperson",
    "bipersoner": "biperson",
    "bipersonerna": "biperson",
    "bipersonernas": "biperson",
    "bipersoners": "biperson",
    "bipersons": "biperson",
    "biplanen": "biplan",
    "biplanens": "biplan",
    "biplanet": "biplan",
    "biplaneten": "biplanet",
    "biplanetens": "biplanet",
    "biplaneter": "biplanet",
    "biplaneterna": "biplanet",
    "biplaneternas": "biplanet",
    "biplaneters": "biplanet",
    "biplanets": "biplanet",
    "biplans": "biplan",
    "bipolariteten": "bipolaritet",
    "bipolaritetens": "bipolaritet",
    "bipolariteter": "bipolaritet",
    "bipolariteterna": "bipolaritet",
    "bipolariteternas": "bipolaritet",
    "bipolariteters": "bipolaritet",
    "bipolaritets": "bipolaritet",
    "bipolära": "bipolär",
    "bipolärare": "bipolär",
    "bipolärares": "bipolär",
    "bipoläras": "bipolär",
    "bipolärast": "bipolär",
    "bipoläraste": "bipolär",
    "bipolärastes": "bipolär",
    "bipolärasts": "bipolär",
    "bipoläre": "bipolär",
    "bipoläres": "bipolär",
    "bipolärs": "bipolär",
    "bipolärt": "bipolär",
    "bipolärts": "bipolär",
    "biprodukten": "biprodukt",
    "biproduktens": "biprodukt",
    "biprodukter": "biprodukt",
    "biprodukterna": "biprodukt",
    "biprodukternas": "biprodukt",
    "biprodukters": "biprodukt",
    "biprodukts": "biprodukt",
    "bir": "bira",
    "biran": "bira",
    "birans": "bira",
    "biras": "bira",
    "birdien": "birdie",
    "birdiens": "birdie",
    "birdies": "birdie",
    "birdiesarna": "birdie",
    "birdiesarnas": "birdie",
    "birdiesen": "birdie",
    "birdiesens": "birdie",
    "bire": "bira",
    "biremen": "birem",
    "biremens": "birem",
    "biremer": "birem",
    "biremerna": "birem",
    "biremernas": "birem",
    "biremers": "birem",
    "birems": "birem",
    "biret": "bir",
    "birets": "bir",
    "birfilar": "birfilare",
    "birfilaren": "birfilare",
    "birfilarens": "birfilare",
    "birfilares": "birfilare",
    "birfilarna": "birfilare",
    "birfilarnas": "birfilare",
    "birollen": "biroll",
    "birollens": "biroll",
    "biroller": "biroll",
    "birollerna": "biroll",
    "birollernas": "biroll",
    "birollers": "biroll",
    "birolls": "biroll",
    "biror": "bira",
    "birorna": "bira",
    "birornas": "bira",
    "birors": "bira",
    "biroten": "birot",
    "birotens": "birot",
    "birots": "birot",
    "birs": "bira",
    "birötter": "birot",
    "birötterna": "birot",
    "birötternas": "birot",
    "birötters": "birot",
    "bisaken": "bisak",
    "bisakens": "bisak",
    "bisaker": "bisak",
    "bisakerna": "bisak",
    "bisakernas": "bisak",
    "bisakers": "bisak",
    "bisaks": "bisak",
    "bisamen": "bisam",
    "bisamens": "bisam",
    "bisamhällen": "bisamhälle",
    "bisamhällena": "bisamhälle",
    "bisamhällenas": "bisamhälle",
    "bisamhällens": "bisamhälle",
    "bisamhälles": "bisamhälle",
    "bisamhället": "bisamhälle",
    "bisamhällets": "bisamhälle",
    "bisamhälls": "bisamhälle",
    "bisamox": "bisamoxe",
    "bisamoxar": "bisamoxe",
    "bisamoxarna": "bisamoxe",
    "bisamoxarnas": "bisamoxe",
    "bisamoxars": "bisamoxe",
    "bisamoxen": "bisamoxe",
    "bisamoxens": "bisamoxe",
    "bisamoxes": "bisamoxe",
    "bisamrått": "bisamråtta",
    "bisamråttan": "bisamråtta",
    "bisamråttans": "bisamråtta",
    "bisamråttas": "bisamråtta",
    "bisamråtte": "bisamråtta",
    "bisamråttor": "bisamråtta",
    "bisamråttorna": "bisamråtta",
    "bisamråttornas": "bisamråtta",
    "bisamråttors": "bisamråtta",
    "bisamråtts": "bisamråtta",
    "bisams": "bisam",
    "bisamsvinen": "bisamsvin",
    "bisamsvinens": "bisamsvin",
    "bisamsvinet": "bisamsvin",
    "bisamsvinets": "bisamsvin",
    "bisamsvins": "bisamsvin",
    "bisarra": "bisarr",
    "bisarrare": "bisarr",
    "bisarrares": "bisarr",
    "bisarras": "bisarr",
    "bisarrast": "bisarr",
    "bisarraste": "bisarr",
    "bisarrastes": "bisarr",
    "bisarrasts": "bisarr",
    "bisarre": "bisarr",
    "bisarrerier": "bisarreri",
    "bisarrerierna": "bisarreri",
    "bisarreriernas": "bisarreri",
    "bisarreriers": "bisarreri",
    "bisarreriet": "bisarreri",
    "bisarreriets": "bisarreri",
    "bisarreris": "bisarreri",
    "bisarrerit": "bisarreri",
    "bisarrerits": "bisarreri",
    "bisarres": "bisarr",
    "bisarrheten": "bisarrhet",
    "bisarrhetens": "bisarrhet",
    "bisarrhets": "bisarrhet",
    "bisarrs": "bisarr",
    "bisarrt": "bisarr",
    "bisarrts": "bisarr",
    "bisatsen": "bisats",
    "bisatsens": "bisats",
    "bisatser": "bisats",
    "bisatserna": "bisats",
    "bisatsernas": "bisats",
    "bisatsers": "bisats",
    "bisatsordföljden": "bisatsordföljd",
    "bisatsordföljdens": "bisatsordföljd",
    "bisatsordföljder": "bisatsordföljd",
    "bisatsordföljderna": "bisatsordföljd",
    "bisatsordföljdernas": "bisatsordföljd",
    "bisatsordföljders": "bisatsordföljd",
    "bisatsordföljds": "bisatsordföljd",
    "bisatt": "bisätta",
    "bisatta": "bisätta",
    "bisattas": "bisätta",
    "bisatte": "bisätta",
    "bisattes": "bisätta",
    "bisatts": "bisätta",
    "bischoffen": "bischoff",
    "bischoffens": "bischoff",
    "bischoffs": "bischoff",
    "bisektrisen": "bisektris",
    "bisektrisens": "bisektris",
    "bisektriser": "bisektris",
    "bisektriserna": "bisektris",
    "bisektrisernas": "bisektris",
    "bisektrisers": "bisektris",
    "bisexualiteten": "bisexualitet",
    "bisexualitetens": "bisexualitet",
    "bisexualiteter": "bisexualitet",
    "bisexualiteterna": "bisexualitet",
    "bisexualiteternas": "bisexualitet",
    "bisexualiteters": "bisexualitet",
    "bisexualitets": "bisexualitet",
    "bisexuella": "bisexuell",
    "bisexuellare": "bisexuell",
    "bisexuellares": "bisexuell",
    "bisexuellas": "bisexuell",
    "bisexuellast": "bisexuell",
    "bisexuellaste": "bisexuell",
    "bisexuellastes": "bisexuell",
    "bisexuellasts": "bisexuell",
    "bisexuelle": "bisexuell",
    "bisexuelles": "bisexuell",
    "bisexuells": "bisexuell",
    "bisexuellt": "bisexuell",
    "bisexuellts": "bisexuell",
    "bisittar": "bisittare",
    "bisittaren": "bisittare",
    "bisittarens": "bisittare",
    "bisittares": "bisittare",
    "bisittarna": "bisittare",
    "bisittarnas": "bisittare",
    "biskopar": "biskop",
    "biskoparna": "biskop",
    "biskoparnas": "biskop",
    "biskopars": "biskop",
    "biskopen": "biskop",
    "biskopens": "biskop",
    "biskopliga": "biskoplig",
    "biskopligare": "biskoplig",
    "biskopligares": "biskoplig",
    "biskopligas": "biskoplig",
    "biskopligast": "biskoplig",
    "biskopligaste": "biskoplig",
    "biskopligastes": "biskoplig",
    "biskopligasts": "biskoplig",
    "biskoplige": "biskoplig",
    "biskopliges": "biskoplig",
    "biskopligheten": "biskoplighet",
    "biskoplighetens": "biskoplighet",
    "biskoplighets": "biskoplighet",
    "biskopligs": "biskoplig",
    "biskopligt": "biskoplig",
    "biskopligts": "biskoplig",
    "biskops": "biskop",
    "biskopsdömen": "biskopsdöme",
    "biskopsdömena": "biskopsdöme",
    "biskopsdömenas": "biskopsdöme",
    "biskopsdömens": "biskopsdöme",
    "biskopsdömes": "biskopsdöme",
    "biskopsdömet": "biskopsdöme",
    "biskopsdömets": "biskopsdöme",
    "biskopskorsen": "biskopskors",
    "biskopskorsens": "biskopskors",
    "biskopskorset": "biskopskors",
    "biskopskorsets": "biskopskors",
    "biskopskräckl": "biskopskräckla",
    "biskopskräcklan": "biskopskräckla",
    "biskopskräcklans": "biskopskräckla",
    "biskopskräcklas": "biskopskräckla",
    "biskopskräckle": "biskopskräckla",
    "biskopskräcklor": "biskopskräckla",
    "biskopskräcklorna": "biskopskräckla",
    "biskopskräcklornas": "biskopskräckla",
    "biskopskräcklors": "biskopskräckla",
    "biskopskräckls": "biskopskräckla",
    "biskopskräkl": "biskopskräkla",
    "biskopskräklan": "biskopskräkla",
    "biskopskräklans": "biskopskräkla",
    "biskopskräklas": "biskopskräkla",
    "biskopskräkle": "biskopskräkla",
    "biskopskräklor": "biskopskräkla",
    "biskopskräklorna": "biskopskräkla",
    "biskopskräklornas": "biskopskräkla",
    "biskopskräklors": "biskopskräkla",
    "biskopskräkls": "biskopskräkla",
    "biskopsmöss": "biskopsmössa",
    "biskopsmössan": "biskopsmössa",
    "biskopsmössans": "biskopsmössa",
    "biskopsmössas": "biskopsmössa",
    "biskopsmösse": "biskopsmössa",
    "biskopsmössor": "biskopsmössa",
    "biskopsmössorna": "biskopsmössa",
    "biskopsmössornas": "biskopsmössa",
    "biskopsmössors": "biskopsmössa",
    "biskopsmöten": "biskopsmöte",
    "biskopsmötena": "biskopsmöte",
    "biskopsmötenas": "biskopsmöte",
    "biskopsmötens": "biskopsmöte",
    "biskopsmötes": "biskopsmöte",
    "biskopsmötet": "biskopsmöte",
    "biskopsmötets": "biskopsmöte",
    "biskopsskrudar": "biskopsskrud",
    "biskopsskrudarna": "biskopsskrud",
    "biskopsskrudarnas": "biskopsskrud",
    "biskopsskrudars": "biskopsskrud",
    "biskopsskruden": "biskopsskrud",
    "biskopsskrudens": "biskopsskrud",
    "biskopsskruds": "biskopsskrud",
    "biskopsstavar": "biskopsstav",
    "biskopsstavarna": "biskopsstav",
    "biskopsstavarnas": "biskopsstav",
    "biskopsstavars": "biskopsstav",
    "biskopsstaven": "biskopsstav",
    "biskopsstavens": "biskopsstav",
    "biskopsstavs": "biskopsstav",
    "biskopsvisitationen": "biskopsvisitation",
    "biskopsvisitationens": "biskopsvisitation",
    "biskopsvisitationer": "biskopsvisitation",
    "biskopsvisitationerna": "biskopsvisitation",
    "biskopsvisitationernas": "biskopsvisitation",
    "biskopsvisitationers": "biskopsvisitation",
    "biskopsvisitations": "biskopsvisitation",
    "biskvien": "biskvi",
    "biskviens": "biskvi",
    "biskvier": "biskvi",
    "biskvierna": "biskvi",
    "biskviernas": "biskvi",
    "biskviers": "biskvi",
    "biskvin": "biskvi",
    "biskvins": "biskvi",
    "biskvis": "biskvi",
    "bisköldkörteln": "bisköldkörtel",
    "bisköldkörtelns": "bisköldkörtel",
    "bisköldkörtels": "bisköldkörtel",
    "bisköldkörtlar": "bisköldkörtel",
    "bisköldkörtlarna": "bisköldkörtel",
    "bisköldkörtlarnas": "bisköldkörtel",
    "bisköldkörtlars": "bisköldkörtel",
    "biskötseln": "biskötsel",
    "biskötselns": "biskötsel",
    "biskötsels": "biskötsel",
    "bismaken": "bismak",
    "bismakens": "bismak",
    "bismaker": "bismak",
    "bismakerna": "bismak",
    "bismakernas": "bismak",
    "bismakers": "bismak",
    "bismaks": "bismak",
    "bisolar": "bisol",
    "bisolarna": "bisol",
    "bisolarnas": "bisol",
    "bisolars": "bisol",
    "bisolen": "bisol",
    "bisolens": "bisol",
    "bisols": "bisol",
    "bisonen": "bison",
    "bisonens": "bison",
    "bisonox": "bisonoxe",
    "bisonoxar": "bisonoxe",
    "bisonoxarna": "bisonoxe",
    "bisonoxarnas": "bisonoxe",
    "bisonoxars": "bisonoxe",
    "bisonoxen": "bisonoxe",
    "bisonoxens": "bisonoxe",
    "bisonoxes": "bisonoxe",
    "bisons": "bison",
    "bispar": "bisp",
    "bisparna": "bisp",
    "bisparnas": "bisp",
    "bispars": "bisp",
    "bispen": "bisp",
    "bispens": "bisp",
    "bisprang": "bispringa",
    "bisprangs": "bispringa",
    "bispring": "bispringa",
    "bispringande": "bispringa",
    "bispringanden": "bispringande",
    "bispringandena": "bispringande",
    "bispringandenas": "bispringande",
    "bispringandens": "bispringande",
    "bispringandes": "bispringande",
    "bispringandet": "bispringande",
    "bispringandets": "bispringande",
    "bispringas": "bispringa",
    "bispringe": "bispringa",
    "bispringer": "bispringa",
    "bispringes": "bispringa",
    "bisprings": "bispringa",
    "bisprunge": "bispringa",
    "bisprungen": "bispringa",
    "bisprungens": "bispringa",
    "bisprunges": "bispringa",
    "bisprunget": "bispringa",
    "bisprungets": "bispringa",
    "bisprungit": "bispringa",
    "bisprungits": "bispringa",
    "bisprungna": "bispringa",
    "bisprungnas": "bispringa",
    "bisprungne": "bispringa",
    "bisprungnes": "bispringa",
    "bisps": "bisp",
    "bissauguineanen": "bissauguinean",
    "bissauguineanens": "bissauguinean",
    "bissauguineaner": "bissauguinean",
    "bissauguineanerna": "bissauguinean",
    "bissauguineanernas": "bissauguinean",
    "bissauguineaners": "bissauguinean",
    "bissauguineans": "bissauguinean",
    "bissauguineanska": "bissauguineansk",
    "bissauguineanskan": "bissauguineanska",
    "bissauguineanskans": "bissauguineanska",
    "bissauguineanskare": "bissauguineansk",
    "bissauguineanskares": "bissauguineansk",
    "bissauguineanskas": "bissauguineanska",
    "bissauguineanskast": "bissauguineansk",
    "bissauguineanskaste": "bissauguineansk",
    "bissauguineanskastes": "bissauguineansk",
    "bissauguineanskasts": "bissauguineansk",
    "bissauguineanske": "bissauguineanska",
    "bissauguineanskes": "bissauguineansk",
    "bissauguineanskor": "bissauguineanska",
    "bissauguineanskorna": "bissauguineanska",
    "bissauguineanskornas": "bissauguineanska",
    "bissauguineanskors": "bissauguineanska",
    "bissauguineansks": "bissauguineansk",
    "bissauguineanskt": "bissauguineansk",
    "bissauguineanskts": "bissauguineansk",
    "bisserad": "bissera",
    "bisserade": "bissera",
    "bisserades": "bissera",
    "bisserads": "bissera",
    "bisserande": "bissera",
    "bisseranden": "bisserande",
    "bisserandena": "bisserande",
    "bisserandenas": "bisserande",
    "bisserandens": "bisserande",
    "bisserandes": "bisserande",
    "bisserandet": "bisserande",
    "bisserandets": "bisserande",
    "bisserar": "bissera",
    "bisseras": "bissera",
    "bisserat": "bissera",
    "bisserats": "bissera",
    "bisserbara": "bisserbar",
    "bisserbarare": "bisserbar",
    "bisserbarares": "bisserbar",
    "bisserbaras": "bisserbar",
    "bisserbarast": "bisserbar",
    "bisserbaraste": "bisserbar",
    "bisserbarastes": "bisserbar",
    "bisserbarasts": "bisserbar",
    "bisserbare": "bisserbar",
    "bisserbares": "bisserbar",
    "bisserbarheten": "bisserbarhet",
    "bisserbarhetens": "bisserbarhet",
    "bisserbarhets": "bisserbarhet",
    "bisserbars": "bisserbar",
    "bisserbart": "bisserbar",
    "bisserbarts": "bisserbar",
    "bisseringar": "bissering",
    "bisseringarna": "bissering",
    "bisseringarnas": "bissering",
    "bisseringars": "bissering",
    "bisseringen": "bissering",
    "bisseringens": "bissering",
    "bisserings": "bissering",
    "bisterheten": "bisterhet",
    "bisterhetens": "bisterhet",
    "bisterhets": "bisterhet",
    "bisters": "bister",
    "bistert": "bister",
    "bisterts": "bister",
    "bisticken": "bistick",
    "bistickens": "bistick",
    "bisticket": "bistick",
    "bistickets": "bistick",
    "bisticks": "bistick",
    "bistingen": "bisting",
    "bistingens": "bisting",
    "bistinget": "bisting",
    "bistingets": "bisting",
    "bistings": "bisting",
    "bistockar": "bistock",
    "bistockarna": "bistock",
    "bistockarnas": "bistock",
    "bistockars": "bistock",
    "bistocken": "bistock",
    "bistockens": "bistock",
    "bistocks": "bistock",
    "bistod": "bistå",
    "bistode": "bistå",
    "bistodes": "bistå",
    "bistods": "bistå",
    "bistra": "bister",
    "bistrare": "bister",
    "bistrares": "bister",
    "bistras": "bister",
    "bistrast": "bister",
    "bistraste": "bister",
    "bistrastes": "bister",
    "bistrasts": "bister",
    "bistre": "bister",
    "bistres": "bister",
    "bistroer": "bistro",
    "bistroerna": "bistro",
    "bistroernas": "bistro",
    "bistroers": "bistro",
    "bistron": "bistro",
    "bistrons": "bistro",
    "bistros": "bistro",
    "bisträck": "bisträcka",
    "bisträckande": "bisträcka",
    "bisträckanden": "bisträckande",
    "bisträckandena": "bisträckande",
    "bisträckandenas": "bisträckande",
    "bisträckandens": "bisträckande",
    "bisträckandes": "bisträckande",
    "bisträckandet": "bisträckande",
    "bisträckandets": "bisträckande",
    "bisträckas": "bisträcka",
    "bisträcker": "bisträcka",
    "bisträckes": "bisträcka",
    "bisträcks": "bisträcka",
    "bisträckt": "bisträcka",
    "bisträckta": "bisträcka",
    "bisträcktas": "bisträcka",
    "bisträckte": "bisträcka",
    "bisträcktes": "bisträcka",
    "bisträckts": "bisträcka",
    "bisturien": "bisturi",
    "bisturiens": "bisturi",
    "bisturier": "bisturi",
    "bisturierna": "bisturi",
    "bisturiernas": "bisturi",
    "bisturiers": "bisturi",
    "bisturin": "bisturi",
    "bisturins": "bisturi",
    "bisturis": "bisturi",
    "bistyngen": "bistyng",
    "bistyngens": "bistyng",
    "bistynget": "bistyng",
    "bistyngets": "bistyng",
    "bistyngs": "bistyng",
    "bistående": "bistå",
    "biståenden": "bistående",
    "biståendena": "bistående",
    "biståendenas": "bistående",
    "biståendens": "bistående",
    "biståendes": "bistående",
    "biståendet": "bistående",
    "biståendets": "bistående",
    "biståndet": "bistånd",
    "biståndets": "bistånd",
    "bistånds": "bistånd",
    "biståndsförvaltningar": "biståndsförvaltning",
    "biståndsförvaltningarna": "biståndsförvaltning",
    "biståndsförvaltningarnas": "biståndsförvaltning",
    "biståndsförvaltningars": "biståndsförvaltning",
    "biståndsförvaltningen": "biståndsförvaltning",
    "biståndsförvaltningens": "biståndsförvaltning",
    "biståndsförvaltnings": "biståndsförvaltning",
    "biståndslandet": "biståndsland",
    "biståndslandets": "biståndsland",
    "biståndslands": "biståndsland",
    "biståndsländer": "biståndsland",
    "biståndsländerna": "biståndsland",
    "biståndsländernas": "biståndsland",
    "biståndsländers": "biståndsland",
    "biståndsministern": "biståndsminister",
    "biståndsministerns": "biståndsminister",
    "biståndsministers": "biståndsminister",
    "biståndsministrar": "biståndsminister",
    "biståndsministrarna": "biståndsminister",
    "biståndsministrarnas": "biståndsminister",
    "biståndsministrars": "biståndsminister",
    "biståndsmålen": "biståndsmål",
    "biståndsmålens": "biståndsmål",
    "biståndsmålet": "biståndsmål",
    "biståndsmålets": "biståndsmål",
    "biståndsmåls": "biståndsmål",
    "biståndsorganen": "biståndsorgan",
    "biståndsorganens": "biståndsorgan",
    "biståndsorganet": "biståndsorgan",
    "biståndsorganets": "biståndsorgan",
    "biståndsorgans": "biståndsorgan",
    "biståndspolitiken": "biståndspolitik",
    "biståndspolitikens": "biståndspolitik",
    "biståndspolitiks": "biståndspolitik",
    "biståndspolitiska": "biståndspolitisk",
    "biståndspolitiskas": "biståndspolitisk",
    "biståndspolitiske": "biståndspolitisk",
    "biståndspolitiskes": "biståndspolitisk",
    "biståndspolitisks": "biståndspolitisk",
    "biståndspolitiskt": "biståndspolitisk",
    "biståndspolitiskts": "biståndspolitisk",
    "biståndsprogrammen": "biståndsprogram",
    "biståndsprogrammens": "biståndsprogram",
    "biståndsprogrammet": "biståndsprogram",
    "biståndsprogrammets": "biståndsprogram",
    "biståndsprograms": "biståndsprogram",
    "biståndsprojekten": "biståndsprojekt",
    "biståndsprojektens": "biståndsprojekt",
    "biståndsprojektet": "biståndsprojekt",
    "biståndsprojektets": "biståndsprojekt",
    "biståndsprojekts": "biståndsprojekt",
    "biståndsskeppen": "biståndsskepp",
    "biståndsskeppens": "biståndsskepp",
    "biståndsskeppet": "biståndsskepp",
    "biståndsskeppets": "biståndsskepp",
    "biståndsskepps": "biståndsskepp",
    "bistår": "bistå",
    "bistås": "bistå",
    "bistått": "bistå",
    "biståtts": "bistå",
    "bisvärmar": "bisvärm",
    "bisvärmarna": "bisvärm",
    "bisvärmarnas": "bisvärm",
    "bisvärmars": "bisvärm",
    "bisvärmen": "bisvärm",
    "bisvärmens": "bisvärm",
    "bisvärms": "bisvärm",
    "bisyssl": "bisyssla",
    "bisysslan": "bisyssla",
    "bisysslans": "bisyssla",
    "bisysslas": "bisyssla",
    "bisyssle": "bisyssla",
    "bisysslo": "bisyssla",
    "bisysslor": "bisyssla",
    "bisysslorna": "bisyssla",
    "bisysslornas": "bisyssla",
    "bisysslors": "bisyssla",
    "bisätt": "bisätta",
    "bisättande": "bisätta",
    "bisättanden": "bisättande",
    "bisättandena": "bisättande",
    "bisättandenas": "bisättande",
    "bisättandens": "bisättande",
    "bisättandes": "bisättande",
    "bisättandet": "bisättande",
    "bisättandets": "bisättande",
    "bisättas": "bisätta",
    "bisätter": "bisätta",
    "bisättes": "bisätta",
    "bisättningar": "bisättning",
    "bisättningarna": "bisättning",
    "bisättningarnas": "bisättning",
    "bisättningars": "bisättning",
    "bisättningen": "bisättning",
    "bisättningens": "bisättning",
    "bisättnings": "bisättning",
    "bisätts": "bisätta",
    "bit": "bita",
    "bitad": "bita",
    "bitade": "bita",
    "bitades": "bita",
    "bitads": "bita",
    "bitande": "bita",
    "bitanden": "bitande",
    "bitandena": "bitande",
    "bitandenas": "bitande",
    "bitandens": "bitande",
    "bitandes": "bitande",
    "bitandet": "bitande",
    "bitandets": "bitande",
    "bitank": "bitanke",
    "bitankar": "bitanke",
    "bitankarna": "bitanke",
    "bitankarnas": "bitanke",
    "bitankars": "bitanke",
    "bitanken": "bitanke",
    "bitankens": "bitanke",
    "bitankes": "bitanke",
    "bitanks": "bitanke",
    "bitar": "bita",
    "bitarna": "bit",
    "bitarnas": "bit",
    "bitars": "bit",
    "bitas": "bita",
    "bitat": "bita",
    "bitats": "bita",
    "bite": "bita",
    "biteckens": "bitecken",
    "bitecknen": "bitecken",
    "bitecknens": "bitecken",
    "bitecknet": "bitecken",
    "bitecknets": "bitecken",
    "biten": "bita",
    "bitens": "biten",
    "biter": "bita",
    "bites": "bita",
    "bitestikeln": "bitestikel",
    "bitestikelns": "bitestikel",
    "bitestikels": "bitestikel",
    "bitestiklar": "bitestikel",
    "bitestiklarna": "bitestikel",
    "bitestiklarnas": "bitestikel",
    "bitestiklars": "bitestikel",
    "bitet": "biten",
    "bitets": "biten",
    "bitit": "bita",
    "bitits": "bitas",
    "bitmärken": "bitmärke",
    "bitmärkena": "bitmärke",
    "bitmärkenas": "bitmärke",
    "bitmärkens": "bitmärke",
    "bitmärkes": "bitmärke",
    "bitmärket": "bitmärke",
    "bitmärkets": "bitmärke",
    "bitna": "biten",
    "bitnare": "biten",
    "bitnares": "biten",
    "bitnas": "biten",
    "bitnast": "biten",
    "bitnaste": "biten",
    "bitnastes": "biten",
    "bitnasts": "biten",
    "bitne": "biten",
    "bitnes": "biten",
    "bitonen": "biton",
    "bitonens": "biton",
    "bitoner": "biton",
    "bitonerna": "biton",
    "bitonernas": "biton",
    "bitoners": "biton",
    "bitons": "biton",
    "bitrycket": "bitryck",
    "bitryckets": "bitryck",
    "bitrycks": "bitryck",
    "biträd": "biträda",
    "biträdande": "biträda",
    "biträdanden": "biträdande",
    "biträdandena": "biträdande",
    "biträdandenas": "biträdande",
    "biträdandens": "biträdande",
    "biträdandes": "biträdande",
    "biträdandet": "biträdande",
    "biträdandets": "biträdande",
    "biträdas": "biträda",
    "biträdd": "biträda",
    "biträdda": "biträda",
    "biträddas": "biträda",
    "biträdde": "biträda",
    "biträddes": "biträda",
    "biträdds": "biträda",
    "biträden": "biträde",
    "biträdena": "biträde",
    "biträdenas": "biträde",
    "biträdens": "biträde",
    "biträder": "biträda",
    "biträdes": "biträde",
    "biträdet": "biträde",
    "biträdets": "biträde",
    "biträds": "biträda",
    "biträtt": "biträda",
    "biträtts": "biträda",
    "bits": "bitas",
    "bitsen": "bits",
    "bitsens": "bits",
    "bitset": "bits",
    "bitsets": "bits",
    "bitshållar": "bitshållare",
    "bitshållaren": "bitshållare",
    "bitshållarens": "bitshållare",
    "bitshållares": "bitshållare",
    "bitshållarna": "bitshållare",
    "bitshållarnas": "bitshållare",
    "bitska": "bitsk",
    "bitskare": "bitsk",
    "bitskares": "bitsk",
    "bitskas": "bitsk",
    "bitskast": "bitsk",
    "bitskaste": "bitsk",
    "bitskastes": "bitsk",
    "bitskasts": "bitsk",
    "bitske": "bitsk",
    "bitskes": "bitsk",
    "bitskheten": "bitskhet",
    "bitskhetens": "bitskhet",
    "bitskhets": "bitskhet",
    "bitsks": "bitsk",
    "bitskt": "bitsk",
    "bitskts": "bitsk",
    "bitsockers": "bitsocker",
    "bitsockret": "bitsocker",
    "bitsockrets": "bitsocker",
    "bitsåren": "bitsår",
    "bitsårens": "bitsår",
    "bitsåret": "bitsår",
    "bitsårets": "bitsår",
    "bitsårs": "bitsår",
    "bittelilla": "bitteliten",
    "bittelillas": "bitteliten",
    "bittelille": "bitteliten",
    "bittelilles": "bitteliten",
    "bittelitenheten": "bittelitenhet",
    "bittelitenhetens": "bittelitenhet",
    "bittelitenhets": "bittelitenhet",
    "bittelitens": "bitteliten",
    "bittelitet": "bitteliten",
    "bittelitets": "bitteliten",
    "bitterheten": "bitterhet",
    "bitterhetens": "bitterhet",
    "bitterheter": "bitterhet",
    "bitterheterna": "bitterhet",
    "bitterheternas": "bitterhet",
    "bitterheters": "bitterhet",
    "bitterhets": "bitterhet",
    "bitterkalla": "bitterkall",
    "bitterkallare": "bitterkall",
    "bitterkallares": "bitterkall",
    "bitterkallas": "bitterkall",
    "bitterkallast": "bitterkall",
    "bitterkallaste": "bitterkall",
    "bitterkallastes": "bitterkall",
    "bitterkallasts": "bitterkall",
    "bitterkalle": "bitterkall",
    "bitterkalles": "bitterkall",
    "bitterkalls": "bitterkall",
    "bitterkallt": "bitterkall",
    "bitterkallts": "bitterkall",
    "bitterljuva": "bitterljuv",
    "bitterljuvare": "bitterljuv",
    "bitterljuvares": "bitterljuv",
    "bitterljuvas": "bitterljuv",
    "bitterljuvast": "bitterljuv",
    "bitterljuvaste": "bitterljuv",
    "bitterljuvastes": "bitterljuv",
    "bitterljuvasts": "bitterljuv",
    "bitterljuve": "bitterljuv",
    "bitterljuves": "bitterljuv",
    "bitterljuvheten": "bitterljuvhet",
    "bitterljuvhetens": "bitterljuvhet",
    "bitterljuvhets": "bitterljuvhet",
    "bitterljuvs": "bitterljuv",
    "bitterljuvt": "bitterljuv",
    "bitterljuvts": "bitterljuv",
    "bittermandeln": "bittermandel",
    "bittermandelns": "bittermandel",
    "bittermandeloljan": "bittermandelolja",
    "bittermandeloljans": "bittermandelolja",
    "bittermandeloljas": "bittermandelolja",
    "bittermandelolje": "bittermandelolja",
    "bittermandels": "bittermandel",
    "bittermandlar": "bittermandel",
    "bittermandlarna": "bittermandel",
    "bittermandlarnas": "bittermandel",
    "bittermandlars": "bittermandel",
    "bitters": "bitter",
    "bittersalta": "bittersalt",
    "bittersaltare": "bittersalt",
    "bittersaltares": "bittersalt",
    "bittersaltas": "bittersalt",
    "bittersaltast": "bittersalt",
    "bittersaltaste": "bittersalt",
    "bittersaltastes": "bittersalt",
    "bittersaltasts": "bittersalt",
    "bittersalte": "bittersalt",
    "bittersaltes": "bittersalt",
    "bittersaltet": "bittersalt",
    "bittersaltets": "bittersalt",
    "bittersalts": "bittersalt",
    "bittersöt": "bittersöta",
    "bittersöta": "bittersöt",
    "bittersötan": "bittersöta",
    "bittersötans": "bittersöta",
    "bittersötare": "bittersöt",
    "bittersötares": "bittersöt",
    "bittersötas": "bittersöta",
    "bittersötast": "bittersöt",
    "bittersötaste": "bittersöt",
    "bittersötastes": "bittersöt",
    "bittersötasts": "bittersöt",
    "bittersöte": "bittersöta",
    "bittersötes": "bittersöt",
    "bittersötor": "bittersöta",
    "bittersötorna": "bittersöta",
    "bittersötornas": "bittersöta",
    "bittersötors": "bittersöta",
    "bittersöts": "bittersöta",
    "bittersött": "bittersöt",
    "bittersötts": "bittersöt",
    "bittert": "bitter",
    "bitterts": "bitter",
    "bittervattens": "bittervatten",
    "bittervattnet": "bittervatten",
    "bittervattnets": "bittervatten",
    "bittesmå": "bitteliten",
    "bittesmås": "bitteliten",
    "bittra": "bitter",
    "bittrare": "bitter",
    "bittrares": "bitter",
    "bittras": "bitter",
    "bittrast": "bitter",
    "bittraste": "bitter",
    "bittrastes": "bitter",
    "bittrasts": "bitter",
    "bittre": "bitter",
    "bittres": "bitter",
    "bitumens": "bitumen",
    "bituminet": "bitumen",
    "bituminets": "bitumen",
    "bituminösa": "bituminös",
    "bituminösare": "bituminös",
    "bituminösares": "bituminös",
    "bituminösas": "bituminös",
    "bituminösast": "bituminös",
    "bituminösaste": "bituminös",
    "bituminösastes": "bituminös",
    "bituminösasts": "bituminös",
    "bituminöse": "bituminös",
    "bituminöses": "bituminös",
    "bituminöst": "bituminös",
    "bituminösts": "bituminös",
    "bitvargar": "bitvarg",
    "bitvargarna": "bitvarg",
    "bitvargarnas": "bitvarg",
    "bitvargars": "bitvarg",
    "bitvargen": "bitvarg",
    "bitvargens": "bitvarg",
    "bitvargs": "bitvarg",
    "bivacken": "bivack",
    "bivackens": "bivack",
    "bivacker": "bivack",
    "bivackerad": "bivackera",
    "bivackerade": "bivackera",
    "bivackerades": "bivackera",
    "bivackerads": "bivackera",
    "bivackerande": "bivackera",
    "bivackeranden": "bivackerande",
    "bivackerandena": "bivackerande",
    "bivackerandenas": "bivackerande",
    "bivackerandens": "bivackerande",
    "bivackerandes": "bivackerande",
    "bivackerandet": "bivackerande",
    "bivackerandets": "bivackerande",
    "bivackerar": "bivackera",
    "bivackeras": "bivackera",
    "bivackerat": "bivackera",
    "bivackerats": "bivackera",
    "bivackerbara": "bivackerbar",
    "bivackerbarare": "bivackerbar",
    "bivackerbarares": "bivackerbar",
    "bivackerbaras": "bivackerbar",
    "bivackerbarast": "bivackerbar",
    "bivackerbaraste": "bivackerbar",
    "bivackerbarastes": "bivackerbar",
    "bivackerbarasts": "bivackerbar",
    "bivackerbare": "bivackerbar",
    "bivackerbares": "bivackerbar",
    "bivackerbarheten": "bivackerbarhet",
    "bivackerbarhetens": "bivackerbarhet",
    "bivackerbarhets": "bivackerbarhet",
    "bivackerbars": "bivackerbar",
    "bivackerbart": "bivackerbar",
    "bivackerbarts": "bivackerbar",
    "bivackeringar": "bivackering",
    "bivackeringarna": "bivackering",
    "bivackeringarnas": "bivackering",
    "bivackeringars": "bivackering",
    "bivackeringen": "bivackering",
    "bivackeringens": "bivackering",
    "bivackerings": "bivackering",
    "bivackerna": "bivack",
    "bivackernas": "bivack",
    "bivackers": "bivack",
    "bivacks": "bivack",
    "bivaxer": "bivax",
    "bivaxerna": "bivax",
    "bivaxernas": "bivax",
    "bivaxers": "bivax",
    "bivaxet": "bivax",
    "bivaxets": "bivax",
    "biverkans": "biverkan",
    "biverkningar": "biverkning",
    "biverkningarna": "biverkning",
    "biverkningarnas": "biverkning",
    "biverkningars": "biverkning",
    "biverkningen": "biverkning",
    "biverkningens": "biverkning",
    "biverknings": "biverkning",
    "biverkningsfallen": "biverkningsfall",
    "biverkningsfallens": "biverkningsfall",
    "biverkningsfallet": "biverkningsfall",
    "biverkningsfallets": "biverkningsfall",
    "biverkningsfalls": "biverkningsfall",
    "biverkningsrapporten": "biverkningsrapport",
    "biverkningsrapportens": "biverkningsrapport",
    "biverkningsrapporter": "biverkningsrapport",
    "biverkningsrapporterna": "biverkningsrapport",
    "biverkningsrapporternas": "biverkningsrapport",
    "biverkningsrapporters": "biverkningsrapport",
    "biverkningsrapports": "biverkningsrapport",
    "bivråkar": "bivråk",
    "bivråkarna": "bivråk",
    "bivråkarnas": "bivråk",
    "bivråkars": "bivråk",
    "bivråken": "bivråk",
    "bivråkens": "bivråk",
    "bivråks": "bivråk",
    "bivägar": "biväg",
    "bivägarna": "biväg",
    "bivägarnas": "biväg",
    "bivägars": "biväg",
    "bivägen": "biväg",
    "bivägens": "biväg",
    "bivägs": "biväg",
    "biyngels": "biyngel",
    "biynglen": "biyngel",
    "biynglens": "biyngel",
    "biynglet": "biyngel",
    "biynglets": "biyngel",
    "bizzabitar": "bizzabit",
    "bizzabitarna": "bizzabit",
    "bizzabitarnas": "bizzabit",
    "bizzabitars": "bizzabit",
    "bizzabiten": "bizzabit",
    "bizzabitens": "bizzabit",
    "bizzabits": "bizzabit",
    "biämnen": "biämne",
    "biämnena": "biämne",
    "biämnenas": "biämne",
    "biämnens": "biämne",
    "biämnes": "biämne",
    "biämnet": "biämne",
    "biämnets": "biämne",
    "biätar": "biätare",
    "biätaren": "biätare",
    "biätarens": "biätare",
    "biätares": "biätare",
    "biätarna": "biätare",
    "biätarnas": "biätare",
    "bjud": "bjuda",
    "bjudande": "bjuda",
    "bjudanden": "bjudande",
    "bjudandena": "bjudande",
    "bjudandenas": "bjudande",
    "bjudandens": "bjudande",
    "bjudandes": "bjudande",
    "bjudandet": "bjudande",
    "bjudandets": "bjudande",
    "bjudas": "bjuda",
    "bjudcigarren": "bjudcigarr",
    "bjudcigarrens": "bjudcigarr",
    "bjudcigarrer": "bjudcigarr",
    "bjudcigarrerna": "bjudcigarr",
    "bjudcigarrernas": "bjudcigarr",
    "bjudcigarrers": "bjudcigarr",
    "bjudcigarrs": "bjudcigarr",
    "bjude": "bjuda",
    "bjuden": "bjuda",
    "bjudens": "bjuda",
    "bjuder": "bjuda",
    "bjudes": "bjuda",
    "bjudet": "bjuda",
    "bjudets": "bjuda",
    "bjudit": "bjuda",
    "bjudits": "bjuda",
    "bjudna": "bjuda",
    "bjudnas": "bjuda",
    "bjudne": "bjuda",
    "bjudnes": "bjuda",
    "bjudningar": "bjudning",
    "bjudningarna": "bjudning",
    "bjudningarnas": "bjudning",
    "bjudningars": "bjudning",
    "bjudningen": "bjudning",
    "bjudningens": "bjudning",
    "bjudnings": "bjudning",
    "bjuds": "bjuda",
    "bjuggen": "bjugg",
    "bjuggens": "bjugg",
    "bjugget": "bjugg",
    "bjuggets": "bjugg",
    "bjuggs": "bjugg",
    "bjuss": "bjussa",
    "bjussad": "bjussa",
    "bjussade": "bjussa",
    "bjussades": "bjussa",
    "bjussads": "bjussa",
    "bjussande": "bjussa",
    "bjussanden": "bjussande",
    "bjussandena": "bjussande",
    "bjussandenas": "bjussande",
    "bjussandens": "bjussande",
    "bjussandes": "bjussande",
    "bjussandet": "bjussande",
    "bjussandets": "bjussande",
    "bjussar": "bjussa",
    "bjussas": "bjussa",
    "bjussat": "bjussa",
    "bjussats": "bjussa",
    "bjäbb": "bjäbba",
    "bjäbbade": "bjäbba",
    "bjäbbades": "bjäbba",
    "bjäbbande": "bjäbba",
    "bjäbbanden": "bjäbbande",
    "bjäbbandena": "bjäbbande",
    "bjäbbandenas": "bjäbbande",
    "bjäbbandens": "bjäbbande",
    "bjäbbandes": "bjäbbande",
    "bjäbbandet": "bjäbbande",
    "bjäbbandets": "bjäbbande",
    "bjäbbar": "bjäbba",
    "bjäbbas": "bjäbba",
    "bjäbbat": "bjäbba",
    "bjäbbats": "bjäbba",
    "bjäbbet": "bjäbb",
    "bjäbbets": "bjäbb",
    "bjäbbiga": "bjäbbig",
    "bjäbbigare": "bjäbbig",
    "bjäbbigares": "bjäbbig",
    "bjäbbigas": "bjäbbig",
    "bjäbbigast": "bjäbbig",
    "bjäbbigaste": "bjäbbig",
    "bjäbbigastes": "bjäbbig",
    "bjäbbigasts": "bjäbbig",
    "bjäbbige": "bjäbbig",
    "bjäbbiges": "bjäbbig",
    "bjäbbigheten": "bjäbbighet",
    "bjäbbighetens": "bjäbbighet",
    "bjäbbigheter": "bjäbbighet",
    "bjäbbigheterna": "bjäbbighet",
    "bjäbbigheternas": "bjäbbighet",
    "bjäbbigheters": "bjäbbighet",
    "bjäbbighets": "bjäbbighet",
    "bjäbbigs": "bjäbbig",
    "bjäbbigt": "bjäbbig",
    "bjäbbigts": "bjäbbig",
    "bjäbbs": "bjäbb",
    "bjäfset": "bjäfs",
    "bjäfsets": "bjäfs",
    "bjälk": "bjälke",
    "bjälkar": "bjälke",
    "bjälkarna": "bjälke",
    "bjälkarnas": "bjälke",
    "bjälkars": "bjälke",
    "bjälken": "bjälke",
    "bjälkens": "bjälke",
    "bjälkes": "bjälke",
    "bjälkhuvuden": "bjälkhuvud",
    "bjälkhuvudena": "bjälkhuvud",
    "bjälkhuvudenas": "bjälkhuvud",
    "bjälkhuvudens": "bjälkhuvud",
    "bjälkhuvudet": "bjälkhuvud",
    "bjälkhuvudets": "bjälkhuvud",
    "bjälkhuvuds": "bjälkhuvud",
    "bjälklagen": "bjälklag",
    "bjälklagens": "bjälklag",
    "bjälklaget": "bjälklag",
    "bjälklagets": "bjälklag",
    "bjälklags": "bjälklag",
    "bjälks": "bjälke",
    "bjälkverken": "bjälkverk",
    "bjälkverkens": "bjälkverk",
    "bjälkverket": "bjälkverk",
    "bjälkverkets": "bjälkverk",
    "bjälkverks": "bjälkverk",
    "bjäller": "bjällra",
    "bjällerklangen": "bjällerklang",
    "bjällerklangens": "bjällerklang",
    "bjällerklangs": "bjällerklang",
    "bjällkon": "bjällko",
    "bjällkons": "bjällko",
    "bjällkor": "bjällko",
    "bjällkorna": "bjällko",
    "bjällkornas": "bjällko",
    "bjällkors": "bjällko",
    "bjällkos": "bjällko",
    "bjällran": "bjällra",
    "bjällrans": "bjällra",
    "bjällras": "bjällra",
    "bjällre": "bjällra",
    "bjällror": "bjällra",
    "bjällrorna": "bjällra",
    "bjällrornas": "bjällra",
    "bjällrors": "bjällra",
    "bjärta": "bjärt",
    "bjärtare": "bjärt",
    "bjärtares": "bjärt",
    "bjärtas": "bjärt",
    "bjärtast": "bjärt",
    "bjärtaste": "bjärt",
    "bjärtastes": "bjärt",
    "bjärtasts": "bjärt",
    "bjärte": "bjärt",
    "bjärtes": "bjärt",
    "bjärtgröna": "bjärtgrön",
    "bjärtgrönare": "bjärtgrön",
    "bjärtgrönares": "bjärtgrön",
    "bjärtgrönas": "bjärtgrön",
    "bjärtgrönast": "bjärtgrön",
    "bjärtgrönaste": "bjärtgrön",
    "bjärtgrönastes": "bjärtgrön",
    "bjärtgrönasts": "bjärtgrön",
    "bjärtgröne": "bjärtgrön",
    "bjärtgrönes": "bjärtgrön",
    "bjärtgröns": "bjärtgrön",
    "bjärtgrönt": "bjärtgrön",
    "bjärtgrönts": "bjärtgrön",
    "bjärtheten": "bjärthet",
    "bjärthetens": "bjärthet",
    "bjärthets": "bjärthet",
    "bjärts": "bjärt",
    "bjässar": "bjässe",
    "bjässarna": "bjässe",
    "bjässarnas": "bjässe",
    "bjässars": "bjässe",
    "bjässen": "bjässe",
    "bjässens": "bjässe",
    "bjässes": "bjässe",
    "bjöd": "bjuda",
    "bjöde": "bjuda",
    "bjödes": "bjuda",
    "bjöds": "bjuda",
    "björkar": "björk",
    "björkarna": "björk",
    "björkarnas": "björk",
    "björkars": "björk",
    "björkbladen": "björkblad",
    "björkbladens": "björkblad",
    "björkbladet": "björkblad",
    "björkbladets": "björkblad",
    "björkblads": "björkblad",
    "björken": "björk",
    "björkens": "björk",
    "björkes": "björke",
    "björket": "björke",
    "björkets": "björke",
    "björkgränsen": "björkgräns",
    "björkgränsens": "björkgräns",
    "björklagen": "björklag",
    "björklagens": "björklag",
    "björklags": "björklag",
    "björklöven": "björklöv",
    "björklövens": "björklöv",
    "björklövet": "björklöv",
    "björklövets": "björklöv",
    "björklövs": "björklöv",
    "björkn": "björkna",
    "björknan": "björkna",
    "björknans": "björkna",
    "björknas": "björkna",
    "björkne": "björkna",
    "björknor": "björkna",
    "björknorna": "björkna",
    "björknornas": "björkna",
    "björknors": "björkna",
    "björkns": "björkna",
    "björknävern": "björknäver",
    "björknäverns": "björknäver",
    "björknävers": "björknäver",
    "björknävrar": "björknäver",
    "björknävrarna": "björknäver",
    "björknävrarnas": "björknäver",
    "björknävrars": "björknäver",
    "björkregionen": "björkregion",
    "björkregionens": "björkregion",
    "björkregioner": "björkregion",
    "björkregionerna": "björkregion",
    "björkregionernas": "björkregion",
    "björkregioners": "björkregion",
    "björkregions": "björkregion",
    "björkrisen": "björkris",
    "björkrisens": "björkris",
    "björkriset": "björkris",
    "björkrisets": "björkris",
    "björks": "björk",
    "björksaven": "björksav",
    "björksavens": "björksav",
    "björksavs": "björksav",
    "björkslyet": "björksly",
    "björkslyets": "björksly",
    "björkslys": "björksly",
    "björkslyt": "björksly",
    "björkslyts": "björksly",
    "björksoppar": "björksopp",
    "björksopparna": "björksopp",
    "björksopparnas": "björksopp",
    "björksoppars": "björksopp",
    "björksoppen": "björksopp",
    "björksoppens": "björksopp",
    "björksopps": "björksopp",
    "björktrastar": "björktrast",
    "björktrastarna": "björktrast",
    "björktrastarnas": "björktrast",
    "björktrastars": "björktrast",
    "björktrasten": "björktrast",
    "björktrastens": "björktrast",
    "björktrasts": "björktrast",
    "björkveden": "björkved",
    "björkvedens": "björkved",
    "björkveds": "björkved",
    "björn": "björna",
    "björnad": "björna",
    "björnade": "björna",
    "björnades": "björna",
    "björnads": "björna",
    "björnande": "björna",
    "björnanden": "björnande",
    "björnandena": "björnande",
    "björnandenas": "björnande",
    "björnandens": "björnande",
    "björnandes": "björnande",
    "björnandet": "björnande",
    "björnandets": "björnande",
    "björnar": "björna",
    "björnarna": "björn",
    "björnarnas": "björn",
    "björnars": "björn",
    "björnas": "björna",
    "björnat": "björna",
    "björnats": "björna",
    "björnbindsels": "björnbindsel",
    "björnbindslen": "björnbindsle",
    "björnbindslena": "björnbindsle",
    "björnbindslenas": "björnbindsle",
    "björnbindslens": "björnbindsle",
    "björnbindsles": "björnbindsle",
    "björnbindslet": "björnbindsle",
    "björnbindslets": "björnbindsle",
    "björnbären": "björnbär",
    "björnbärens": "björnbär",
    "björnbäret": "björnbär",
    "björnbärets": "björnbär",
    "björnbärs": "björnbär",
    "björnbärsbusk": "björnbärsbuske",
    "björnbärsbuskar": "björnbärsbuske",
    "björnbärsbuskarna": "björnbärsbuske",
    "björnbärsbuskarnas": "björnbärsbuske",
    "björnbärsbuskars": "björnbärsbuske",
    "björnbärsbusken": "björnbärsbuske",
    "björnbärsbuskens": "björnbärsbuske",
    "björnbärsbuskes": "björnbärsbuske",
    "björnen": "björn",
    "björnens": "björn",
    "björnflok": "björnfloka",
    "björnflokan": "björnfloka",
    "björnflokans": "björnfloka",
    "björnflokas": "björnfloka",
    "björnfloke": "björnfloka",
    "björnflokor": "björnfloka",
    "björnflokorna": "björnfloka",
    "björnflokornas": "björnfloka",
    "björnflokors": "björnfloka",
    "björnfloks": "björnfloka",
    "björnhallonen": "björnhallon",
    "björnhallonens": "björnhallon",
    "björnhallonet": "björnhallon",
    "björnhallonets": "björnhallon",
    "björnhallons": "björnhallon",
    "björnhon": "björnhona",
    "björnhonan": "björnhona",
    "björnhonans": "björnhona",
    "björnhonas": "björnhona",
    "björnhone": "björnhona",
    "björnhonor": "björnhona",
    "björnhonorna": "björnhona",
    "björnhonornas": "björnhona",
    "björnhonors": "björnhona",
    "björnhons": "björnhona",
    "björnhundar": "björnhund",
    "björnhundarna": "björnhund",
    "björnhundarnas": "björnhund",
    "björnhundars": "björnhund",
    "björnhunden": "björnhund",
    "björnhundens": "björnhund",
    "björnhunds": "björnhund",
    "björninnan": "björninna",
    "björninnans": "björninna",
    "björninnas": "björninna",
    "björninne": "björninna",
    "björninnor": "björninna",
    "björninnorna": "björninna",
    "björninnornas": "björninna",
    "björninnors": "björninna",
    "björnjakten": "björnjakt",
    "björnjaktens": "björnjakt",
    "björnjakter": "björnjakt",
    "björnjakterna": "björnjakt",
    "björnjakternas": "björnjakt",
    "björnjakters": "björnjakt",
    "björnjakts": "björnjakt",
    "björnlok": "björnloka",
    "björnlokan": "björnloka",
    "björnlokans": "björnloka",
    "björnlokas": "björnloka",
    "björnloke": "björnloka",
    "björnlokor": "björnloka",
    "björnlokorna": "björnloka",
    "björnlokornas": "björnloka",
    "björnlokors": "björnloka",
    "björnloks": "björnloka",
    "björnmossan": "björnmossa",
    "björnmossans": "björnmossa",
    "björnmossas": "björnmossa",
    "björnramar": "björnram",
    "björnramarna": "björnram",
    "björnramarnas": "björnram",
    "björnramars": "björnram",
    "björnramen": "björnram",
    "björnramens": "björnram",
    "björnrams": "björnram",
    "björns": "björn",
    "björnskallen": "björnskall",
    "björnskallens": "björnskall",
    "björnskallet": "björnskall",
    "björnskallets": "björnskall",
    "björnskalls": "björnskall",
    "björnskinnen": "björnskinn",
    "björnskinnens": "björnskinn",
    "björnskinnet": "björnskinn",
    "björnskinnets": "björnskinn",
    "björnskinns": "björnskinn",
    "björnskinnsmöss": "björnskinnsmössa",
    "björnskinnsmössan": "björnskinnsmössa",
    "björnskinnsmössans": "björnskinnsmössa",
    "björnskinnsmössas": "björnskinnsmössa",
    "björnskinnsmösse": "björnskinnsmössa",
    "björnskinnsmössor": "björnskinnsmössa",
    "björnskinnsmössorna": "björnskinnsmössa",
    "björnskinnsmössornas": "björnskinnsmössa",
    "björnskinnsmössors": "björnskinnsmössa",
    "björntjänsten": "björntjänst",
    "björntjänstens": "björntjänst",
    "björntjänster": "björntjänst",
    "björntjänsterna": "björntjänst",
    "björntjänsternas": "björntjänst",
    "björntjänsters": "björntjänst",
    "björntjänsts": "björntjänst",
    "björntråden": "björntråd",
    "björntrådens": "björntråd",
    "björntråds": "björntråd",
    "blacka": "black",
    "blackar": "black",
    "blackare": "black",
    "blackares": "black",
    "blackarna": "black",
    "blackarnas": "black",
    "blackars": "black",
    "blackas": "black",
    "blackast": "black",
    "blackaste": "black",
    "blackastes": "black",
    "blackasts": "black",
    "blacke": "black",
    "blacken": "black",
    "blackens": "black",
    "blackes": "black",
    "blackheten": "blackhet",
    "blackhetens": "blackhet",
    "blackhets": "blackhet",
    "blackiga": "blackig",
    "blackigare": "blackig",
    "blackigares": "blackig",
    "blackigas": "blackig",
    "blackigast": "blackig",
    "blackigaste": "blackig",
    "blackigastes": "blackig",
    "blackigasts": "blackig",
    "blackige": "blackig",
    "blackiges": "blackig",
    "blackigheten": "blackighet",
    "blackighetens": "blackighet",
    "blackighets": "blackighet",
    "blackigs": "blackig",
    "blackigt": "blackig",
    "blackigts": "blackig",
    "blackouten": "blackout",
    "blackoutens": "blackout",
    "blackouter": "blackout",
    "blackouterna": "blackout",
    "blackouternas": "blackout",
    "blackouters": "blackout",
    "blackouts": "blackout",
    "blacks": "black",
    "blackt": "black",
    "blackts": "black",
    "blad": "blada",
    "bladad": "blada",
    "bladade": "blada",
    "bladades": "blada",
    "bladads": "blada",
    "bladande": "blada",
    "bladanden": "bladande",
    "bladandena": "bladande",
    "bladandenas": "bladande",
    "bladandens": "bladande",
    "bladandes": "bladande",
    "bladandet": "bladande",
    "bladandets": "bladande",
    "bladar": "blada",
    "bladas": "blada",
    "bladat": "blada",
    "bladats": "blada",
    "bladbagg": "bladbagge",
    "bladbaggar": "bladbagge",
    "bladbaggarna": "bladbagge",
    "bladbaggarnas": "bladbagge",
    "bladbaggars": "bladbagge",
    "bladbaggen": "bladbagge",
    "bladbaggens": "bladbagge",
    "bladbagges": "bladbagge",
    "bladbaggs": "bladbagge",
    "bladbyten": "bladbyte",
    "bladbytena": "bladbyte",
    "bladbytenas": "bladbyte",
    "bladbytens": "bladbyte",
    "bladbytes": "bladbyte",
    "bladbytet": "bladbyte",
    "bladbytets": "bladbyte",
    "bladder": "bladdra",
    "bladders": "bladder",
    "bladdrade": "bladdra",
    "bladdrades": "bladdra",
    "bladdrande": "bladdra",
    "bladdranden": "bladdrande",
    "bladdrandena": "bladdrande",
    "bladdrandenas": "bladdrande",
    "bladdrandens": "bladdrande",
    "bladdrandes": "bladdrande",
    "bladdrandet": "bladdrande",
    "bladdrandets": "bladdrande",
    "bladdrar": "bladdra",
    "bladdras": "bladdra",
    "bladdrat": "bladdra",
    "bladdrats": "bladdra",
    "bladdret": "bladder",
    "bladdrets": "bladder",
    "bladen": "blad",
    "bladens": "blad",
    "bladet": "blad",
    "bladets": "blad",
    "bladfoten": "bladfot",
    "bladfotens": "bladfot",
    "bladfotingar": "bladfoting",
    "bladfotingarna": "bladfoting",
    "bladfotingarnas": "bladfoting",
    "bladfotingars": "bladfoting",
    "bladfotingen": "bladfoting",
    "bladfotingens": "bladfoting",
    "bladfotings": "bladfoting",
    "bladfots": "bladfot",
    "bladfötter": "bladfot",
    "bladfötterna": "bladfot",
    "bladfötternas": "bladfot",
    "bladfötters": "bladfot",
    "bladguldet": "bladguld",
    "bladguldets": "bladguld",
    "bladgulds": "bladguld",
    "bladiga": "bladig",
    "bladigare": "bladig",
    "bladigares": "bladig",
    "bladigas": "bladig",
    "bladigast": "bladig",
    "bladigaste": "bladig",
    "bladigastes": "bladig",
    "bladigasts": "bladig",
    "bladige": "bladig",
    "bladiges": "bladig",
    "bladigs": "bladig",
    "bladigt": "bladig",
    "bladigts": "bladig",
    "bladkransar": "bladkrans",
    "bladkransarna": "bladkrans",
    "bladkransarnas": "bladkrans",
    "bladkransars": "bladkrans",
    "bladkransen": "bladkrans",
    "bladkransens": "bladkrans",
    "bladkålen": "bladkål",
    "bladkålens": "bladkål",
    "bladkåls": "bladkål",
    "bladlopp": "bladloppa",
    "bladloppan": "bladloppa",
    "bladloppans": "bladloppa",
    "bladloppas": "bladloppa",
    "bladloppe": "bladloppa",
    "bladloppor": "bladloppa",
    "bladlopporna": "bladloppa",
    "bladloppornas": "bladloppa",
    "bladloppors": "bladloppa",
    "bladlopps": "bladloppa",
    "bladlusen": "bladlus",
    "bladlusens": "bladlus",
    "bladlängden": "bladlängd",
    "bladlängdens": "bladlängd",
    "bladlängder": "bladlängd",
    "bladlängderna": "bladlängd",
    "bladlängdernas": "bladlängd",
    "bladlängders": "bladlängd",
    "bladlängds": "bladlängd",
    "bladlöss": "bladlus",
    "bladlössen": "bladlus",
    "bladlössens": "bladlus",
    "bladmag": "bladmage",
    "bladmagar": "bladmage",
    "bladmagarna": "bladmage",
    "bladmagarnas": "bladmage",
    "bladmagars": "bladmage",
    "bladmagen": "bladmage",
    "bladmagens": "bladmage",
    "bladmages": "bladmage",
    "bladmags": "bladmage",
    "bladmetallen": "bladmetall",
    "bladmetallens": "bladmetall",
    "bladmetalls": "bladmetall",
    "bladminerar": "bladminerare",
    "bladmineraren": "bladminerare",
    "bladminerarens": "bladminerare",
    "bladminerares": "bladminerare",
    "bladminerarna": "bladminerare",
    "bladminerarnas": "bladminerare",
    "bladmoss": "bladmossa",
    "bladmossan": "bladmossa",
    "bladmossans": "bladmossa",
    "bladmossas": "bladmossa",
    "bladmosse": "bladmossa",
    "bladmossor": "bladmossa",
    "bladmossorna": "bladmossa",
    "bladmossornas": "bladmossa",
    "bladmossors": "bladmossa",
    "bladmögels": "bladmögel",
    "bladmöglet": "bladmögel",
    "bladmöglets": "bladmögel",
    "bladningar": "bladning",
    "bladningarna": "bladning",
    "bladningarnas": "bladning",
    "bladningars": "bladning",
    "bladningen": "bladning",
    "bladningens": "bladning",
    "bladnings": "bladning",
    "bladrullsjukan": "bladrullsjuka",
    "bladrullsjukans": "bladrullsjuka",
    "bladrullsjukas": "bladrullsjuka",
    "bladrullsjuke": "bladrullsjuka",
    "bladrullsjuks": "bladrullsjuka",
    "bladrötts": "bladrött",
    "blads": "blad",
    "bladsilvers": "bladsilver",
    "bladsilvret": "bladsilver",
    "bladsilvrets": "bladsilver",
    "bladskärarmyr": "bladskärarmyra",
    "bladskärarmyran": "bladskärarmyra",
    "bladskärarmyrans": "bladskärarmyra",
    "bladskärarmyras": "bladskärarmyra",
    "bladskärarmyre": "bladskärarmyra",
    "bladskärarmyror": "bladskärarmyra",
    "bladskärarmyrorna": "bladskärarmyra",
    "bladskärarmyrornas": "bladskärarmyra",
    "bladskärarmyrors": "bladskärarmyra",
    "bladskärarmyrs": "bladskärarmyra",
    "bladspänningen": "bladspänning",
    "bladspänningens": "bladspänning",
    "bladspännings": "bladspänning",
    "bladstekeln": "bladstekel",
    "bladstekelns": "bladstekel",
    "bladstekels": "bladstekel",
    "bladsteklar": "bladstekel",
    "bladsteklarna": "bladstekel",
    "bladsteklarnas": "bladstekel",
    "bladsteklars": "bladstekel",
    "bladställningar": "bladställning",
    "bladställningarna": "bladställning",
    "bladställningarnas": "bladställning",
    "bladställningars": "bladställning",
    "bladställningen": "bladställning",
    "bladställningens": "bladställning",
    "bladställnings": "bladställning",
    "bladverket": "bladverk",
    "bladverkets": "bladverk",
    "bladverks": "bladverk",
    "blaff": "blaffa",
    "blaffan": "blaffa",
    "blaffans": "blaffa",
    "blaffas": "blaffa",
    "blaffe": "blaffa",
    "blaffor": "blaffa",
    "blafforna": "blaffa",
    "blaffornas": "blaffa",
    "blaffors": "blaffa",
    "blaffs": "blaffa",
    "blaggarnet": "blaggarn",
    "blaggarnets": "blaggarn",
    "blaggarns": "blaggarn",
    "blaj": "blaja",
    "blajade": "blaja",
    "blajades": "blaja",
    "blajande": "blaja",
    "blajanden": "blajande",
    "blajandena": "blajande",
    "blajandenas": "blajande",
    "blajandens": "blajande",
    "blajandes": "blajande",
    "blajandet": "blajande",
    "blajandets": "blajande",
    "blajar": "blaja",
    "blajas": "blaja",
    "blajat": "blaja",
    "blajats": "blaja",
    "blajet": "blaj",
    "blajets": "blaj",
    "blajs": "blaj",
    "blamagen": "blamage",
    "blamagens": "blamage",
    "blamager": "blamage",
    "blamagerna": "blamage",
    "blamagernas": "blamage",
    "blamagers": "blamage",
    "blamages": "blamage",
    "blamanta": "blamant",
    "blamantare": "blamant",
    "blamantares": "blamant",
    "blamantas": "blamant",
    "blamantast": "blamant",
    "blamantaste": "blamant",
    "blamantastes": "blamant",
    "blamantasts": "blamant",
    "blamante": "blamant",
    "blamantes": "blamant",
    "blamants": "blamant",
    "blamen": "blam",
    "blamens": "blam",
    "blamer": "blam",
    "blamerna": "blam",
    "blamernas": "blam",
    "blamers": "blam",
    "blams": "blam",
    "blancherad": "blanchera",
    "blancherade": "blanchera",
    "blancherades": "blanchera",
    "blancherads": "blanchera",
    "blancherande": "blanchera",
    "blancheranden": "blancherande",
    "blancherandena": "blancherande",
    "blancherandenas": "blancherande",
    "blancherandens": "blancherande",
    "blancherandes": "blancherande",
    "blancherandet": "blancherande",
    "blancherandets": "blancherande",
    "blancherar": "blanchera",
    "blancheras": "blanchera",
    "blancherat": "blanchera",
    "blancherats": "blanchera",
    "blancherbara": "blancherbar",
    "blancherbarare": "blancherbar",
    "blancherbarares": "blancherbar",
    "blancherbaras": "blancherbar",
    "blancherbarast": "blancherbar",
    "blancherbaraste": "blancherbar",
    "blancherbarastes": "blancherbar",
    "blancherbarasts": "blancherbar",
    "blancherbare": "blancherbar",
    "blancherbares": "blancherbar",
    "blancherbarheten": "blancherbarhet",
    "blancherbarhetens": "blancherbarhet",
    "blancherbarhets": "blancherbarhet",
    "blancherbars": "blancherbar",
    "blancherbart": "blancherbar",
    "blancherbarts": "blancherbar",
    "blancheringar": "blanchering",
    "blancheringarna": "blanchering",
    "blancheringarnas": "blanchering",
    "blancheringars": "blanchering",
    "blancheringen": "blanchering",
    "blancheringens": "blanchering",
    "blancherings": "blanchering",
    "blancmangéer": "blancmangé",
    "blancmangéerna": "blancmangé",
    "blancmangéernas": "blancmangé",
    "blancmangéers": "blancmangé",
    "blancmangén": "blancmangé",
    "blancmangéns": "blancmangé",
    "blancmangés": "blancmangé",
    "bland": "blanda",
    "blandad": "blanda",
    "blandade": "blandad",
    "blandades": "blandad",
    "blandads": "blandad",
    "blandande": "blanda",
    "blandanden": "blandande",
    "blandandena": "blandande",
    "blandandenas": "blandande",
    "blandandens": "blandande",
    "blandandes": "blandande",
    "blandandet": "blandande",
    "blandandets": "blandande",
    "blandar": "blandare",
    "blandaren": "blandare",
    "blandarens": "blandare",
    "blandares": "blandare",
    "blandarna": "blandare",
    "blandarnas": "blandare",
    "blandas": "blanda",
    "blandat": "blandad",
    "blandats": "blandad",
    "blanddrickan": "blanddricka",
    "blanddrickans": "blanddricka",
    "blanddrickas": "blanddricka",
    "blanddrickat": "blanddricka",
    "blanddrickats": "blanddricka",
    "blanddrycken": "blanddryck",
    "blanddryckens": "blanddryck",
    "blanddrycks": "blanddryck",
    "blandekonomien": "blandekonomi",
    "blandekonomiens": "blandekonomi",
    "blandekonomier": "blandekonomi",
    "blandekonomierna": "blandekonomi",
    "blandekonomiernas": "blandekonomi",
    "blandekonomiers": "blandekonomi",
    "blandekonomin": "blandekonomi",
    "blandekonomins": "blandekonomi",
    "blandekonomis": "blandekonomi",
    "blandfoders": "blandfoder",
    "blandfodret": "blandfoder",
    "blandfodrets": "blandfoder",
    "blandformen": "blandform",
    "blandformens": "blandform",
    "blandformer": "blandform",
    "blandformerna": "blandform",
    "blandformernas": "blandform",
    "blandformers": "blandform",
    "blandforms": "blandform",
    "blandfärgen": "blandfärg",
    "blandfärgens": "blandfärg",
    "blandfärger": "blandfärg",
    "blandfärgerna": "blandfärg",
    "blandfärgernas": "blandfärg",
    "blandfärgers": "blandfärg",
    "blandfärgs": "blandfärg",
    "blandningar": "blandning",
    "blandningarna": "blandning",
    "blandningarnas": "blandning",
    "blandningars": "blandning",
    "blandningen": "blandning",
    "blandningens": "blandning",
    "blandnings": "blandning",
    "blandningsförhållanden": "blandningsförhållande",
    "blandningsförhållandena": "blandningsförhållande",
    "blandningsförhållandenas": "blandningsförhållande",
    "blandningsförhållandens": "blandningsförhållande",
    "blandningsförhållandes": "blandningsförhållande",
    "blandningsförhållandet": "blandningsförhållande",
    "blandningsförhållandets": "blandningsförhållande",
    "blandningskranar": "blandningskran",
    "blandningskranarna": "blandningskran",
    "blandningskranarnas": "blandningskran",
    "blandningskranars": "blandningskran",
    "blandningskranen": "blandningskran",
    "blandningskranens": "blandningskran",
    "blandningskrans": "blandningskran",
    "blandrasen": "blandras",
    "blandrasens": "blandras",
    "blandraser": "blandras",
    "blandraserna": "blandras",
    "blandrasernas": "blandras",
    "blandrasers": "blandras",
    "blandrashundar": "blandrashund",
    "blandrashundarna": "blandrashund",
    "blandrashundarnas": "blandrashund",
    "blandrashundars": "blandrashund",
    "blandrashunden": "blandrashund",
    "blandrashundens": "blandrashund",
    "blandrashunds": "blandrashund",
    "blandskogar": "blandskog",
    "blandskogarna": "blandskog",
    "blandskogarnas": "blandskog",
    "blandskogars": "blandskog",
    "blandskogen": "blandskog",
    "blandskogens": "blandskog",
    "blandskogs": "blandskog",
    "blandspråken": "blandspråk",
    "blandspråkens": "blandspråk",
    "blandspråket": "blandspråk",
    "blandspråkets": "blandspråk",
    "blandspråks": "blandspråk",
    "blandsäden": "blandsäd",
    "blandsädens": "blandsäd",
    "blandsädes": "blandsäd",
    "blandsäds": "blandsäd",
    "blandtypen": "blandtyp",
    "blandtypens": "blandtyp",
    "blandtyper": "blandtyp",
    "blandtyperna": "blandtyp",
    "blandtypernas": "blandtyp",
    "blandtypers": "blandtyp",
    "blandtyps": "blandtyp",
    "blandvattens": "blandvatten",
    "blandvattnen": "blandvatten",
    "blandvattnens": "blandvatten",
    "blandvattnet": "blandvatten",
    "blandvattnets": "blandvatten",
    "blandäktenskapen": "blandäktenskap",
    "blandäktenskapens": "blandäktenskap",
    "blandäktenskapet": "blandäktenskap",
    "blandäktenskapets": "blandäktenskap",
    "blandäktenskaps": "blandäktenskap",
    "blank": "blanka",
    "blanka": "blank",
    "blankad": "blanka",
    "blankade": "blanka",
    "blankades": "blanka",
    "blankads": "blanka",
    "blankan": "blanka",
    "blankande": "blanka",
    "blankanden": "blankande",
    "blankandena": "blankande",
    "blankandenas": "blankande",
    "blankandens": "blankande",
    "blankandes": "blankande",
    "blankandet": "blankande",
    "blankandets": "blankande",
    "blankans": "blanka",
    "blankar": "blanka",
    "blankare": "blank",
    "blankares": "blank",
    "blankas": "blanka",
    "blankast": "blank",
    "blankaste": "blank",
    "blankastes": "blank",
    "blankasts": "blank",
    "blankat": "blanka",
    "blankats": "blanka",
    "blankborst": "blankborste",
    "blankborstar": "blankborste",
    "blankborstarna": "blankborste",
    "blankborstarnas": "blankborste",
    "blankborstars": "blankborste",
    "blankborsten": "blankborste",
    "blankborstens": "blankborste",
    "blankborstes": "blankborste",
    "blanke": "blanka",
    "blankes": "blank",
    "blanketten": "blankett",
    "blankettens": "blankett",
    "blanketter": "blankett",
    "blanketterna": "blankett",
    "blanketternas": "blankett",
    "blanketters": "blankett",
    "blankettraseriet": "blankettraseri",
    "blankettraseriets": "blankettraseri",
    "blankettraseris": "blankettraseri",
    "blankettraserit": "blankettraseri",
    "blankettraserits": "blankettraseri",
    "blanketts": "blankett",
    "blankettskåpen": "blankettskåp",
    "blankettskåpens": "blankettskåp",
    "blankettskåpet": "blankettskåp",
    "blankettskåpets": "blankettskåp",
    "blankettskåps": "blankettskåp",
    "blankgalvade": "blankgalvad",
    "blankgalvades": "blankgalvad",
    "blankgalvads": "blankgalvad",
    "blankgalvat": "blankgalvad",
    "blankgalvats": "blankgalvad",
    "blankheten": "blankhet",
    "blankhetens": "blankhet",
    "blankhets": "blankhet",
    "blankisen": "blankis",
    "blankisens": "blankis",
    "blanklaxar": "blanklax",
    "blanklaxarna": "blanklax",
    "blanklaxarnas": "blanklax",
    "blanklaxars": "blanklax",
    "blanklaxen": "blanklax",
    "blanklaxens": "blanklax",
    "blankläders": "blankläder",
    "blanklädret": "blankläder",
    "blanklädrets": "blankläder",
    "blankningar": "blankning",
    "blankningarna": "blankning",
    "blankningarnas": "blankning",
    "blankningars": "blankning",
    "blankningen": "blankning",
    "blankningens": "blankning",
    "blanknings": "blankning",
    "blankoaccepten": "blankoaccept",
    "blankoacceptens": "blankoaccept",
    "blankoaccepter": "blankoaccept",
    "blankoaccepterna": "blankoaccept",
    "blankoaccepternas": "blankoaccept",
    "blankoaccepters": "blankoaccept",
    "blankoaccepts": "blankoaccept",
    "blankocheckar": "blankocheck",
    "blankocheckarna": "blankocheck",
    "blankocheckarnas": "blankocheck",
    "blankocheckars": "blankocheck",
    "blankochecken": "blankocheck",
    "blankocheckens": "blankocheck",
    "blankochecker": "blankocheck",
    "blankocheckerna": "blankocheck",
    "blankocheckernas": "blankocheck",
    "blankocheckers": "blankocheck",
    "blankochecks": "blankocheck",
    "blankofullmakten": "blankofullmakt",
    "blankofullmaktens": "blankofullmakt",
    "blankofullmakter": "blankofullmakt",
    "blankofullmakterna": "blankofullmakt",
    "blankofullmakternas": "blankofullmakt",
    "blankofullmakters": "blankofullmakt",
    "blankofullmakts": "blankofullmakt",
    "blankoförsäljningar": "blankoförsäljning",
    "blankoförsäljningarna": "blankoförsäljning",
    "blankoförsäljningarnas": "blankoförsäljning",
    "blankoförsäljningars": "blankoförsäljning",
    "blankoförsäljningen": "blankoförsäljning",
    "blankoförsäljningens": "blankoförsäljning",
    "blankoförsäljnings": "blankoförsäljning",
    "blankokrediten": "blankokredit",
    "blankokreditens": "blankokredit",
    "blankokrediter": "blankokredit",
    "blankokrediterna": "blankokredit",
    "blankokrediternas": "blankokredit",
    "blankokrediters": "blankokredit",
    "blankokredits": "blankokredit",
    "blankor": "blanka",
    "blankorna": "blanka",
    "blankornas": "blanka",
    "blankors": "blanka",
    "blankotransporten": "blankotransport",
    "blankotransportens": "blankotransport",
    "blankotransporter": "blankotransport",
    "blankotransporterna": "blankotransport",
    "blankotransporternas": "blankotransport",
    "blankotransporters": "blankotransport",
    "blankotransports": "blankotransport",
    "blankoväxeln": "blankoväxel",
    "blankoväxelns": "blankoväxel",
    "blankoväxels": "blankoväxel",
    "blankoväxlar": "blankoväxel",
    "blankoväxlarna": "blankoväxel",
    "blankoväxlarnas": "blankoväxel",
    "blankoväxlars": "blankoväxel",
    "blankoöverlåtelsen": "blankoöverlåtelse",
    "blankoöverlåtelsens": "blankoöverlåtelse",
    "blankoöverlåtelses": "blankoöverlåtelse",
    "blankpolerad": "blankpolera",
    "blankpolerade": "blankpolera",
    "blankpolerades": "blankpolera",
    "blankpolerads": "blankpolera",
    "blankpolerande": "blankpolera",
    "blankpoleranden": "blankpolerande",
    "blankpolerandena": "blankpolerande",
    "blankpolerandenas": "blankpolerande",
    "blankpolerandens": "blankpolerande",
    "blankpolerandes": "blankpolerande",
    "blankpolerandet": "blankpolerande",
    "blankpolerandets": "blankpolerande",
    "blankpolerar": "blankpolera",
    "blankpoleras": "blankpolera",
    "blankpolerat": "blankpolera",
    "blankpolerats": "blankpolera",
    "blankpolerbara": "blankpolerbar",
    "blankpolerbarare": "blankpolerbar",
    "blankpolerbarares": "blankpolerbar",
    "blankpolerbaras": "blankpolerbar",
    "blankpolerbarast": "blankpolerbar",
    "blankpolerbaraste": "blankpolerbar",
    "blankpolerbarastes": "blankpolerbar",
    "blankpolerbarasts": "blankpolerbar",
    "blankpolerbare": "blankpolerbar",
    "blankpolerbares": "blankpolerbar",
    "blankpolerbarheten": "blankpolerbarhet",
    "blankpolerbarhetens": "blankpolerbarhet",
    "blankpolerbarhets": "blankpolerbarhet",
    "blankpolerbars": "blankpolerbar",
    "blankpolerbart": "blankpolerbar",
    "blankpolerbarts": "blankpolerbar",
    "blankpoleringar": "blankpolering",
    "blankpoleringarna": "blankpolering",
    "blankpoleringarnas": "blankpolering",
    "blankpoleringars": "blankpolering",
    "blankpoleringen": "blankpolering",
    "blankpoleringens": "blankpolering",
    "blankpolerings": "blankpolering",
    "blankputsade": "blankputsad",
    "blankputsades": "blankputsad",
    "blankputsads": "blankputsad",
    "blankputsat": "blankputsad",
    "blankputsats": "blankputsad",
    "blanks": "blanka",
    "blanksejar": "blanksej",
    "blanksejarna": "blanksej",
    "blanksejarnas": "blanksej",
    "blanksejars": "blanksej",
    "blanksejen": "blanksej",
    "blanksejens": "blanksej",
    "blanksejs": "blanksej",
    "blankskinnet": "blankskinn",
    "blankskinnets": "blankskinn",
    "blankskinns": "blankskinn",
    "blankslitens": "blanksliten",
    "blankslitet": "blanksliten",
    "blankslitets": "blanksliten",
    "blankslitna": "blanksliten",
    "blankslitnare": "blanksliten",
    "blankslitnares": "blanksliten",
    "blankslitnas": "blanksliten",
    "blankslitnast": "blanksliten",
    "blankslitnaste": "blanksliten",
    "blankslitnastes": "blanksliten",
    "blankslitnasts": "blanksliten",
    "blankslitne": "blanksliten",
    "blankslitnes": "blanksliten",
    "blanksmörjan": "blanksmörja",
    "blanksmörjans": "blanksmörja",
    "blanksmörjas": "blanksmörja",
    "blanksmörje": "blanksmörja",
    "blanksmörjor": "blanksmörja",
    "blanksmörjorna": "blanksmörja",
    "blanksmörjornas": "blanksmörja",
    "blanksmörjors": "blanksmörja",
    "blanksvärtan": "blanksvärta",
    "blanksvärtans": "blanksvärta",
    "blanksvärtas": "blanksvärta",
    "blankt": "blank",
    "blankts": "blank",
    "blankvattens": "blankvatten",
    "blankvattnen": "blankvatten",
    "blankvattnens": "blankvatten",
    "blankvattnet": "blankvatten",
    "blankvattnets": "blankvatten",
    "blankversen": "blankvers",
    "blankversens": "blankvers",
    "blankålar": "blankål",
    "blankålarna": "blankål",
    "blankålarnas": "blankål",
    "blankålars": "blankål",
    "blankålen": "blankål",
    "blankålens": "blankål",
    "blankåls": "blankål",
    "blarr": "blarra",
    "blarrade": "blarra",
    "blarrades": "blarra",
    "blarrande": "blarra",
    "blarranden": "blarrande",
    "blarrandena": "blarrande",
    "blarrandenas": "blarrande",
    "blarrandens": "blarrande",
    "blarrandes": "blarrande",
    "blarrandet": "blarrande",
    "blarrandets": "blarrande",
    "blarrar": "blarra",
    "blarras": "blarra",
    "blarrat": "blarra",
    "blarrats": "blarra",
    "blarret": "blarr",
    "blarrets": "blarr",
    "blarrs": "blarr",
    "blaserade": "blaserad",
    "blaserades": "blaserad",
    "blaserads": "blaserad",
    "blaserat": "blaserad",
    "blaserats": "blaserad",
    "blasfemien": "blasfemi",
    "blasfemiens": "blasfemi",
    "blasfemier": "blasfemi",
    "blasfemierna": "blasfemi",
    "blasfemiernas": "blasfemi",
    "blasfemiers": "blasfemi",
    "blasfemin": "blasfemi",
    "blasfemins": "blasfemi",
    "blasfemis": "blasfemi",
    "blasfemiska": "blasfemisk",
    "blasfemiskare": "blasfemisk",
    "blasfemiskares": "blasfemisk",
    "blasfemiskas": "blasfemisk",
    "blasfemiskast": "blasfemisk",
    "blasfemiskaste": "blasfemisk",
    "blasfemiskastes": "blasfemisk",
    "blasfemiskasts": "blasfemisk",
    "blasfemiske": "blasfemisk",
    "blasfemiskes": "blasfemisk",
    "blasfemisks": "blasfemisk",
    "blasfemiskt": "blasfemisk",
    "blasfemiskts": "blasfemisk",
    "blask": "blaska",
    "blaskade": "blaska",
    "blaskades": "blaska",
    "blaskan": "blaska",
    "blaskande": "blaska",
    "blaskanden": "blaskande",
    "blaskandena": "blaskande",
    "blaskandenas": "blaskande",
    "blaskandens": "blaskande",
    "blaskandes": "blaskande",
    "blaskandet": "blaskande",
    "blaskandets": "blaskande",
    "blaskans": "blaska",
    "blaskar": "blaska",
    "blaskas": "blaska",
    "blaskat": "blaska",
    "blaskats": "blaska",
    "blaske": "blaska",
    "blasket": "blask",
    "blaskets": "blask",
    "blaskiga": "blaskig",
    "blaskigare": "blaskig",
    "blaskigares": "blaskig",
    "blaskigas": "blaskig",
    "blaskigast": "blaskig",
    "blaskigaste": "blaskig",
    "blaskigastes": "blaskig",
    "blaskigasts": "blaskig",
    "blaskige": "blaskig",
    "blaskiges": "blaskig",
    "blaskigheten": "blaskighet",
    "blaskighetens": "blaskighet",
    "blaskighets": "blaskighet",
    "blaskigs": "blaskig",
    "blaskigt": "blaskig",
    "blaskigts": "blaskig",
    "blaskor": "blaska",
    "blaskorna": "blaska",
    "blaskornas": "blaska",
    "blaskors": "blaska",
    "blasks": "blask",
    "blasoneringar": "blasonering",
    "blasoneringarna": "blasonering",
    "blasoneringarnas": "blasonering",
    "blasoneringars": "blasonering",
    "blasoneringen": "blasonering",
    "blasoneringens": "blasonering",
    "blasonerings": "blasonering",
    "blasten": "blast",
    "blastens": "blast",
    "blasts": "blast",
    "blattar": "blatte",
    "blattarna": "blatte",
    "blattarnas": "blatte",
    "blattars": "blatte",
    "blatten": "blatte",
    "blattens": "blatte",
    "blattes": "blatte",
    "blazern": "blazer",
    "blazerns": "blazer",
    "blazers": "blazer",
    "blazrar": "blazer",
    "blazrarna": "blazer",
    "blazrarnas": "blazer",
    "blazrars": "blazer",
    "bleckblåsinstrumenten": "bleckblåsinstrument",
    "bleckblåsinstrumentens": "bleckblåsinstrument",
    "bleckblåsinstrumentet": "bleckblåsinstrument",
    "bleckblåsinstrumentets": "bleckblåsinstrument",
    "bleckblåsinstruments": "bleckblåsinstrument",
    "bleckburkar": "bleckburk",
    "bleckburkarna": "bleckburk",
    "bleckburkarnas": "bleckburk",
    "bleckburkars": "bleckburk",
    "bleckburken": "bleckburk",
    "bleckburkens": "bleckburk",
    "bleckburks": "bleckburk",
    "blecken": "bleck",
    "bleckens": "bleck",
    "blecket": "bleck",
    "bleckets": "bleck",
    "bleckmusiken": "bleckmusik",
    "bleckmusikens": "bleckmusik",
    "bleckmusiks": "bleckmusik",
    "bleckplåtar": "bleckplåt",
    "bleckplåtarna": "bleckplåt",
    "bleckplåtarnas": "bleckplåt",
    "bleckplåtars": "bleckplåt",
    "bleckplåten": "bleckplåt",
    "bleckplåtens": "bleckplåt",
    "bleckplåts": "bleckplåt",
    "blecks": "bleck",
    "bleckslagar": "bleckslagare",
    "bleckslagaren": "bleckslagare",
    "bleckslagarens": "bleckslagare",
    "bleckslagares": "bleckslagare",
    "bleckslagarna": "bleckslagare",
    "bleckslagarnas": "bleckslagare",
    "bleckslagerier": "bleckslageri",
    "bleckslagerierna": "bleckslageri",
    "bleckslageriernas": "bleckslageri",
    "bleckslageriers": "bleckslageri",
    "bleckslageriet": "bleckslageri",
    "bleckslageriets": "bleckslageri",
    "bleckslageris": "bleckslageri",
    "bleckslagerit": "bleckslageri",
    "bleckslagerits": "bleckslageri",
    "blecksmaken": "blecksmak",
    "blecksmakens": "blecksmak",
    "blecksmaks": "blecksmak",
    "blek": "bleka",
    "bleka": "blek",
    "blekande": "bleka",
    "blekanden": "blekande",
    "blekandena": "blekande",
    "blekandenas": "blekande",
    "blekandens": "blekande",
    "blekandes": "blekande",
    "blekandet": "blekande",
    "blekandets": "blekande",
    "blekansikten": "blekansikte",
    "blekansiktena": "blekansikte",
    "blekansiktenas": "blekansikte",
    "blekansiktens": "blekansikte",
    "blekansiktes": "blekansikte",
    "blekansiktet": "blekansikte",
    "blekansiktets": "blekansikte",
    "blekansikts": "blekansikte",
    "blekare": "blek",
    "blekares": "blek",
    "blekas": "bleka",
    "blekast": "blek",
    "blekaste": "blek",
    "blekastes": "blek",
    "blekasts": "blek",
    "bleke": "blek",
    "bleken": "bleke",
    "blekens": "bleke",
    "bleker": "bleka",
    "blekerier": "blekeri",
    "blekerierna": "blekeri",
    "blekeriernas": "blekeri",
    "blekeriers": "blekeri",
    "blekeriet": "blekeri",
    "blekeriets": "blekeri",
    "blekeris": "blekeri",
    "blekerit": "blekeri",
    "blekerits": "blekeri",
    "blekes": "bleke",
    "bleket": "bleke",
    "blekets": "bleke",
    "blekfeta": "blekfet",
    "blekfetare": "blekfet",
    "blekfetares": "blekfet",
    "blekfetas": "blekfet",
    "blekfetast": "blekfet",
    "blekfetaste": "blekfet",
    "blekfetastes": "blekfet",
    "blekfetasts": "blekfet",
    "blekfete": "blekfet",
    "blekfetes": "blekfet",
    "blekfetheten": "blekfethet",
    "blekfethetens": "blekfethet",
    "blekfethets": "blekfethet",
    "blekfets": "blekfet",
    "blekfett": "blekfet",
    "blekfetts": "blekfet",
    "blekfisar": "blekfis",
    "blekfisarna": "blekfis",
    "blekfisarnas": "blekfis",
    "blekfisars": "blekfis",
    "blekfisen": "blekfis",
    "blekfisens": "blekfis",
    "blekglaserade": "blekglaserad",
    "blekglaserades": "blekglaserad",
    "blekglaserads": "blekglaserad",
    "blekglaserat": "blekglaserad",
    "blekglaserats": "blekglaserad",
    "blekheten": "blekhet",
    "blekhetens": "blekhet",
    "blekheter": "blekhet",
    "blekheterna": "blekhet",
    "blekheternas": "blekhet",
    "blekheters": "blekhet",
    "blekhets": "blekhet",
    "blekingar": "bleking",
    "blekingarna": "bleking",
    "blekingarnas": "bleking",
    "blekingars": "bleking",
    "blekingen": "bleking",
    "blekingens": "bleking",
    "blekings": "bleking",
    "blekingsek": "blekingseka",
    "blekingsekan": "blekingseka",
    "blekingsekans": "blekingseka",
    "blekingsekas": "blekingseka",
    "blekingseke": "blekingseka",
    "blekingsekor": "blekingseka",
    "blekingsekorna": "blekingseka",
    "blekingsekornas": "blekingseka",
    "blekingsekors": "blekingseka",
    "blekingseks": "blekingseka",
    "blekingsk": "blekingska",
    "blekingska": "blekingsk",
    "blekingskan": "blekingska",
    "blekingskans": "blekingska",
    "blekingskare": "blekingsk",
    "blekingskares": "blekingsk",
    "blekingskas": "blekingska",
    "blekingskast": "blekingsk",
    "blekingskaste": "blekingsk",
    "blekingskastes": "blekingsk",
    "blekingskasts": "blekingsk",
    "blekingske": "blekingska",
    "blekingskes": "blekingsk",
    "blekingskor": "blekingska",
    "blekingskorna": "blekingska",
    "blekingskornas": "blekingska",
    "blekingskors": "blekingska",
    "blekingsks": "blekingsk",
    "blekingskt": "blekingsk",
    "blekingskts": "blekingsk",
    "blekjorden": "blekjord",
    "blekjordens": "blekjord",
    "blekjords": "blekjord",
    "bleklagda": "bleklagd",
    "bleklagdare": "bleklagd",
    "bleklagdares": "bleklagd",
    "bleklagdas": "bleklagd",
    "bleklagdast": "bleklagd",
    "bleklagdaste": "bleklagd",
    "bleklagdastes": "bleklagd",
    "bleklagdasts": "bleklagd",
    "bleklagde": "bleklagd",
    "bleklagdes": "bleklagd",
    "bleklagdheten": "bleklagdhet",
    "bleklagdhetens": "bleklagdhet",
    "bleklagdhets": "bleklagdhet",
    "bleklagds": "bleklagd",
    "bleklagt": "bleklagd",
    "bleklagts": "bleklagd",
    "blekmedels": "blekmedel",
    "blekmedlen": "blekmedel",
    "blekmedlens": "blekmedel",
    "blekmedlet": "blekmedel",
    "blekmedlets": "blekmedel",
    "bleknad": "blekna",
    "bleknade": "blekna",
    "bleknades": "blekna",
    "bleknads": "blekna",
    "bleknande": "blekna",
    "bleknanden": "bleknande",
    "bleknandena": "bleknande",
    "bleknandenas": "bleknande",
    "bleknandens": "bleknande",
    "bleknandes": "bleknande",
    "bleknandet": "bleknande",
    "bleknandets": "bleknande",
    "bleknar": "blekna",
    "bleknas": "blekna",
    "bleknat": "blekna",
    "bleknats": "blekna",
    "blekningar": "blekning",
    "blekningarna": "blekning",
    "blekningarnas": "blekning",
    "blekningars": "blekning",
    "blekningen": "blekning",
    "blekningens": "blekning",
    "bleknings": "blekning",
    "bleknosar": "bleknos",
    "bleknosarna": "bleknos",
    "bleknosarnas": "bleknos",
    "bleknosars": "bleknos",
    "bleknosen": "bleknos",
    "bleknosens": "bleknos",
    "bleks": "bleka",
    "bleksellerin": "blekselleri",
    "bleksellerins": "blekselleri",
    "blekselleris": "blekselleri",
    "bleksiktiga": "bleksiktig",
    "bleksiktigare": "bleksiktig",
    "bleksiktigares": "bleksiktig",
    "bleksiktigas": "bleksiktig",
    "bleksiktigast": "bleksiktig",
    "bleksiktigaste": "bleksiktig",
    "bleksiktigastes": "bleksiktig",
    "bleksiktigasts": "bleksiktig",
    "bleksiktige": "bleksiktig",
    "bleksiktiges": "bleksiktig",
    "bleksiktigheten": "bleksiktighet",
    "bleksiktighetens": "bleksiktighet",
    "bleksiktighets": "bleksiktighet",
    "bleksiktigs": "bleksiktig",
    "bleksiktigt": "bleksiktig",
    "bleksiktigts": "bleksiktig",
    "bleksoten": "bleksot",
    "bleksotens": "bleksot",
    "bleksots": "bleksot",
    "blekt": "bleka",
    "blekta": "bleka",
    "blektas": "bleka",
    "blekte": "bleka",
    "blektes": "bleka",
    "blekts": "bleka",
    "blekvätskan": "blekvätska",
    "blekvätskans": "blekvätska",
    "blekvätskas": "blekvätska",
    "blekvätske": "blekvätska",
    "blekvätskor": "blekvätska",
    "blekvätskorna": "blekvätska",
    "blekvätskornas": "blekvätska",
    "blekvätskors": "blekvätska",
    "blem": "blemma",
    "blemman": "blemma",
    "blemmans": "blemma",
    "blemmas": "blemma",
    "blemme": "blemma",
    "blemmor": "blemma",
    "blemmorna": "blemma",
    "blemmornas": "blemma",
    "blemmors": "blemma",
    "blems": "blemma",
    "blesserad": "blessera",
    "blesserade": "blessera",
    "blesserades": "blessera",
    "blesserads": "blessera",
    "blesserande": "blessera",
    "blesseranden": "blesserande",
    "blesserandena": "blesserande",
    "blesserandenas": "blesserande",
    "blesserandens": "blesserande",
    "blesserandes": "blesserande",
    "blesserandet": "blesserande",
    "blesserandets": "blesserande",
    "blesserar": "blessera",
    "blesseras": "blessera",
    "blesserat": "blessera",
    "blesserats": "blessera",
    "blesserbara": "blesserbar",
    "blesserbarare": "blesserbar",
    "blesserbarares": "blesserbar",
    "blesserbaras": "blesserbar",
    "blesserbarast": "blesserbar",
    "blesserbaraste": "blesserbar",
    "blesserbarastes": "blesserbar",
    "blesserbarasts": "blesserbar",
    "blesserbare": "blesserbar",
    "blesserbares": "blesserbar",
    "blesserbarheten": "blesserbarhet",
    "blesserbarhetens": "blesserbarhet",
    "blesserbarhets": "blesserbarhet",
    "blesserbars": "blesserbar",
    "blesserbart": "blesserbar",
    "blesserbarts": "blesserbar",
    "blesseringar": "blessering",
    "blesseringarna": "blessering",
    "blesseringarnas": "blessering",
    "blesseringars": "blessering",
    "blesseringen": "blessering",
    "blesseringens": "blessering",
    "blesserings": "blessering",
    "blessyren": "blessyr",
    "blessyrens": "blessyr",
    "blessyrer": "blessyr",
    "blessyrerna": "blessyr",
    "blessyrernas": "blessyr",
    "blessyrers": "blessyr",
    "blessyrs": "blessyr",
    "blev": "bli",
    "bleve": "bli",
    "blick": "blicka",
    "blickade": "blicka",
    "blickades": "blicka",
    "blickande": "blicka",
    "blickanden": "blickande",
    "blickandena": "blickande",
    "blickandenas": "blickande",
    "blickandens": "blickande",
    "blickandes": "blickande",
    "blickandet": "blickande",
    "blickandets": "blickande",
    "blickar": "blicka",
    "blickarna": "blick",
    "blickarnas": "blick",
    "blickars": "blick",
    "blickas": "blicka",
    "blickat": "blicka",
    "blickats": "blicka",
    "blicken": "blick",
    "blickens": "blick",
    "blickfälten": "blickfält",
    "blickfältens": "blickfält",
    "blickfältet": "blickfält",
    "blickfältets": "blickfält",
    "blickfälts": "blickfält",
    "blickfången": "blickfång",
    "blickfångens": "blickfång",
    "blickfånget": "blickfång",
    "blickfångets": "blickfång",
    "blickfångs": "blickfång",
    "blickpunkten": "blickpunkt",
    "blickpunktens": "blickpunkt",
    "blickpunkts": "blickpunkt",
    "blicks": "blick",
    "blid": "blida",
    "blida": "blid",
    "blidan": "blida",
    "blidans": "blida",
    "blidare": "blid",
    "blidares": "blid",
    "blidas": "blida",
    "blidast": "blid",
    "blidaste": "blid",
    "blidastes": "blid",
    "blidasts": "blid",
    "blide": "blida",
    "blides": "blid",
    "blidgraden": "blidgrad",
    "blidgradens": "blidgrad",
    "blidgrader": "blidgrad",
    "blidgraderna": "blidgrad",
    "blidgradernas": "blidgrad",
    "blidgraders": "blidgrad",
    "blidgrads": "blidgrad",
    "blidheten": "blidhet",
    "blidhetens": "blidhet",
    "blidhets": "blidhet",
    "blidk": "blidka",
    "blidkad": "blidka",
    "blidkade": "blidka",
    "blidkades": "blidka",
    "blidkads": "blidka",
    "blidkande": "blidka",
    "blidkanden": "blidkande",
    "blidkandena": "blidkande",
    "blidkandenas": "blidkande",
    "blidkandens": "blidkande",
    "blidkandes": "blidkande",
    "blidkandet": "blidkande",
    "blidkandets": "blidkande",
    "blidkar": "blidka",
    "blidkas": "blidka",
    "blidkat": "blidka",
    "blidkats": "blidka",
    "blidor": "blida",
    "blidorna": "blida",
    "blidornas": "blida",
    "blidors": "blida",
    "blids": "blida",
    "blidvintern": "blidvinter",
    "blidvinterns": "blidvinter",
    "blidvinters": "blidvinter",
    "blidvintrar": "blidvinter",
    "blidvintrarna": "blidvinter",
    "blidvintrarnas": "blidvinter",
    "blidvintrars": "blidvinter",
    "blidväderna": "blidväder",
    "blidvädernas": "blidväder",
    "blidväders": "blidväder",
    "blidvädren": "blidväder",
    "blidvädrens": "blidväder",
    "blidvädret": "blidväder",
    "blidvädrets": "blidväder",
    "blienden": "bliende",
    "bliendena": "bliende",
    "bliendenas": "bliende",
    "bliendens": "bliende",
    "bliendes": "bliende",
    "bliendet": "bliende",
    "bliendets": "bliende",
    "blig": "bliga",
    "bligade": "bliga",
    "bligades": "bliga",
    "bligande": "bliga",
    "bliganden": "bligande",
    "bligandena": "bligande",
    "bligandenas": "bligande",
    "bligandens": "bligande",
    "bligandes": "bligande",
    "bligandet": "bligande",
    "bligandets": "bligande",
    "bligar": "bliga",
    "bligas": "bliga",
    "bligat": "bliga",
    "bligats": "bliga",
    "bliget": "blig",
    "bligets": "blig",
    "bligs": "blig",
    "blind": "blinda",
    "blinda": "blind",
    "blindalfabeten": "blindalfabet",
    "blindalfabetens": "blindalfabet",
    "blindalfabetet": "blindalfabet",
    "blindalfabetets": "blindalfabet",
    "blindalfabets": "blindalfabet",
    "blindan": "blinda",
    "blindans": "blinda",
    "blindare": "blind",
    "blindares": "blind",
    "blindas": "blinda",
    "blindast": "blind",
    "blindaste": "blind",
    "blindastes": "blind",
    "blindasts": "blind",
    "blindbockar": "blindbock",
    "blindbockarna": "blindbock",
    "blindbockarnas": "blindbock",
    "blindbockars": "blindbock",
    "blindbocken": "blindbock",
    "blindbockens": "blindbock",
    "blindbocks": "blindbock",
    "blindbottens": "blindbotten",
    "blindbottnar": "blindbotten",
    "blindbottnarna": "blindbotten",
    "blindbottnarnas": "blindbotten",
    "blindbottnars": "blindbotten",
    "blindbottnen": "blindbotten",
    "blindbottnens": "blindbotten",
    "blindbromsar": "blindbroms",
    "blindbromsarna": "blindbroms",
    "blindbromsarnas": "blindbroms",
    "blindbromsars": "blindbroms",
    "blindbromsen": "blindbroms",
    "blindbromsens": "blindbroms",
    "blinddörrar": "blinddörr",
    "blinddörrarna": "blinddörr",
    "blinddörrarnas": "blinddörr",
    "blinddörrars": "blinddörr",
    "blinddörren": "blinddörr",
    "blinddörrens": "blinddörr",
    "blinddörrs": "blinddörr",
    "blinde": "blinda",
    "blinderad": "blindera",
    "blinderade": "blindera",
    "blinderades": "blindera",
    "blinderads": "blindera",
    "blinderande": "blindera",
    "blinderanden": "blinderande",
    "blinderandena": "blinderande",
    "blinderandenas": "blinderande",
    "blinderandens": "blinderande",
    "blinderandes": "blinderande",
    "blinderandet": "blinderande",
    "blinderandets": "blinderande",
    "blinderar": "blindera",
    "blinderas": "blindera",
    "blinderat": "blindera",
    "blinderats": "blindera",
    "blinderbara": "blinderbar",
    "blinderbarare": "blinderbar",
    "blinderbarares": "blinderbar",
    "blinderbaras": "blinderbar",
    "blinderbarast": "blinderbar",
    "blinderbaraste": "blinderbar",
    "blinderbarastes": "blinderbar",
    "blinderbarasts": "blinderbar",
    "blinderbare": "blinderbar",
    "blinderbares": "blinderbar",
    "blinderbarheten": "blinderbarhet",
    "blinderbarhetens": "blinderbarhet",
    "blinderbarhets": "blinderbarhet",
    "blinderbars": "blinderbar",
    "blinderbart": "blinderbar",
    "blinderbarts": "blinderbar",
    "blinderingar": "blindering",
    "blinderingarna": "blindering",
    "blinderingarnas": "blindering",
    "blinderingars": "blindering",
    "blinderingen": "blindering",
    "blinderingens": "blindering",
    "blinderings": "blindering",
    "blindes": "blind",
    "blindflygningar": "blindflygning",
    "blindflygningarna": "blindflygning",
    "blindflygningarnas": "blindflygning",
    "blindflygningars": "blindflygning",
    "blindflygningen": "blindflygning",
    "blindflygningens": "blindflygning",
    "blindflygnings": "blindflygning",
    "blindfönsterna": "blindfönster",
    "blindfönsternas": "blindfönster",
    "blindfönsters": "blindfönster",
    "blindfönstren": "blindfönster",
    "blindfönstrens": "blindfönster",
    "blindfönstret": "blindfönster",
    "blindfönstrets": "blindfönster",
    "blindgat": "blindgata",
    "blindgatan": "blindgata",
    "blindgatans": "blindgata",
    "blindgatas": "blindgata",
    "blindgate": "blindgata",
    "blindgator": "blindgata",
    "blindgatorna": "blindgata",
    "blindgatornas": "blindgata",
    "blindgators": "blindgata",
    "blindgats": "blindgata",
    "blindgångar": "blindgångare",
    "blindgångaren": "blindgångare",
    "blindgångarens": "blindgångare",
    "blindgångares": "blindgångare",
    "blindgångarna": "blindgångare",
    "blindgångarnas": "blindgångare",
    "blindheten": "blindhet",
    "blindhetens": "blindhet",
    "blindhets": "blindhet",
    "blindhundar": "blindhund",
    "blindhundarna": "blindhund",
    "blindhundarnas": "blindhund",
    "blindhundars": "blindhund",
    "blindhunden": "blindhund",
    "blindhundens": "blindhund",
    "blindhunds": "blindhund",
    "blindkart": "blindkarta",
    "blindkartan": "blindkarta",
    "blindkartans": "blindkarta",
    "blindkartas": "blindkarta",
    "blindkarte": "blindkarta",
    "blindkartor": "blindkarta",
    "blindkartorna": "blindkarta",
    "blindkartornas": "blindkarta",
    "blindkartors": "blindkarta",
    "blindkarts": "blindkarta",
    "blindlandningar": "blindlandning",
    "blindlandningarna": "blindlandning",
    "blindlandningarnas": "blindlandning",
    "blindlandningars": "blindlandning",
    "blindlandningen": "blindlandning",
    "blindlandningens": "blindlandning",
    "blindlandnings": "blindlandning",
    "blindlykt": "blindlykta",
    "blindlyktan": "blindlykta",
    "blindlyktans": "blindlykta",
    "blindlyktas": "blindlykta",
    "blindlykte": "blindlykta",
    "blindlyktor": "blindlykta",
    "blindlyktorna": "blindlykta",
    "blindlyktornas": "blindlykta",
    "blindlyktors": "blindlykta",
    "blindlykts": "blindlykta",
    "blindnässel": "blindnässla",
    "blindnässlan": "blindnässla",
    "blindnässlans": "blindnässla",
    "blindnässlas": "blindnässla",
    "blindnässle": "blindnässla",
    "blindnässlor": "blindnässla",
    "blindnässlorna": "blindnässla",
    "blindnässlornas": "blindnässla",
    "blindnässlors": "blindnässla",
    "blindor": "blinda",
    "blindorna": "blinda",
    "blindornas": "blinda",
    "blindors": "blinda",
    "blindpartier": "blindparti",
    "blindpartierna": "blindparti",
    "blindpartiernas": "blindparti",
    "blindpartiers": "blindparti",
    "blindpartiet": "blindparti",
    "blindpartiets": "blindparti",
    "blindpartis": "blindparti",
    "blindpartit": "blindparti",
    "blindpartits": "blindparti",
    "blindpassagerar": "blindpassagerare",
    "blindpassageraren": "blindpassagerare",
    "blindpassagerarens": "blindpassagerare",
    "blindpassagerares": "blindpassagerare",
    "blindpassagerarna": "blindpassagerare",
    "blindpassagerarnas": "blindpassagerare",
    "blindpatronen": "blindpatron",
    "blindpatronens": "blindpatron",
    "blindpatroner": "blindpatron",
    "blindpatronerna": "blindpatron",
    "blindpatronernas": "blindpatron",
    "blindpatroners": "blindpatron",
    "blindpatrons": "blindpatron",
    "blindpip": "blindpipa",
    "blindpipan": "blindpipa",
    "blindpipans": "blindpipa",
    "blindpipas": "blindpipa",
    "blindpipe": "blindpipa",
    "blindpipor": "blindpipa",
    "blindpiporna": "blindpipa",
    "blindpipornas": "blindpipa",
    "blindpipors": "blindpipa",
    "blindpips": "blindpipa",
    "blindpress": "blindpressa",
    "blindpressad": "blindpressa",
    "blindpressade": "blindpressa",
    "blindpressades": "blindpressa",
    "blindpressads": "blindpressa",
    "blindpressande": "blindpressa",
    "blindpressanden": "blindpressande",
    "blindpressandena": "blindpressande",
    "blindpressandenas": "blindpressande",
    "blindpressandens": "blindpressande",
    "blindpressandes": "blindpressande",
    "blindpressandet": "blindpressande",
    "blindpressandets": "blindpressande",
    "blindpressar": "blindpressa",
    "blindpressas": "blindpressa",
    "blindpressat": "blindpressa",
    "blindpressats": "blindpressa",
    "blindpressningar": "blindpressning",
    "blindpressningarna": "blindpressning",
    "blindpressningarnas": "blindpressning",
    "blindpressningars": "blindpressning",
    "blindpressningen": "blindpressning",
    "blindpressningens": "blindpressning",
    "blindpressnings": "blindpressning",
    "blindrotar": "blindrote",
    "blindrotarna": "blindrote",
    "blindrotarnas": "blindrote",
    "blindrotars": "blindrote",
    "blindroten": "blindrote",
    "blindrotens": "blindrote",
    "blindrotes": "blindrote",
    "blindrån": "blindrå",
    "blindråns": "blindrå",
    "blindrår": "blindrå",
    "blindrårna": "blindrå",
    "blindrårnas": "blindrå",
    "blindrårs": "blindrå",
    "blindrås": "blindrå",
    "blinds": "blinda",
    "blindschacket": "blindschack",
    "blindschackets": "blindschack",
    "blindschacks": "blindschack",
    "blindskolan": "blindskola",
    "blindskolans": "blindskola",
    "blindskolas": "blindskola",
    "blindskole": "blindskola",
    "blindskolor": "blindskola",
    "blindskolorna": "blindskola",
    "blindskolornas": "blindskola",
    "blindskolors": "blindskola",
    "blindskriften": "blindskrift",
    "blindskriftens": "blindskrift",
    "blindskrifts": "blindskrift",
    "blindskären": "blindskär",
    "blindskärens": "blindskär",
    "blindskäret": "blindskär",
    "blindskärets": "blindskär",
    "blindskärs": "blindskär",
    "blindspåren": "blindspår",
    "blindspårens": "blindspår",
    "blindspåret": "blindspår",
    "blindspårets": "blindspår",
    "blindspårs": "blindspår",
    "blindstyren": "blindstyre",
    "blindstyrena": "blindstyre",
    "blindstyrenas": "blindstyre",
    "blindstyrens": "blindstyre",
    "blindstyres": "blindstyre",
    "blindstyret": "blindstyre",
    "blindstyrets": "blindstyre",
    "blindtarmar": "blindtarm",
    "blindtarmarna": "blindtarm",
    "blindtarmarnas": "blindtarm",
    "blindtarmars": "blindtarm",
    "blindtarmen": "blindtarm",
    "blindtarmens": "blindtarm",
    "blindtarms": "blindtarm",
    "blindtarmsinflammationen": "blindtarmsinflammation",
    "blindtarmsinflammationens": "blindtarmsinflammation",
    "blindtarmsinflammationer": "blindtarmsinflammation",
    "blindtarmsinflammationerna": "blindtarmsinflammation",
    "blindtarmsinflammationernas": "blindtarmsinflammation",
    "blindtarmsinflammationers": "blindtarmsinflammation",
    "blindtarmsinflammations": "blindtarmsinflammation",
    "blindtarmsoperationen": "blindtarmsoperation",
    "blindtarmsoperationens": "blindtarmsoperation",
    "blindtarmsoperationer": "blindtarmsoperation",
    "blindtarmsoperationerna": "blindtarmsoperation",
    "blindtarmsoperationernas": "blindtarmsoperation",
    "blindtarmsoperationers": "blindtarmsoperation",
    "blindtarmsoperations": "blindtarmsoperation",
    "blindtrycken": "blindtryck",
    "blindtryckens": "blindtryck",
    "blindtrycket": "blindtryck",
    "blindtryckets": "blindtryck",
    "blindtrycks": "blindtryck",
    "blinien": "blini",
    "bliniens": "blini",
    "blinier": "blini",
    "blinierna": "blini",
    "bliniernas": "blini",
    "bliniers": "blini",
    "blinin": "blini",
    "blinins": "blini",
    "blinis": "blini",
    "blink": "blinka",
    "blinkade": "blinka",
    "blinkades": "blinka",
    "blinkande": "blinka",
    "blinkanden": "blinkande",
    "blinkandena": "blinkande",
    "blinkandenas": "blinkande",
    "blinkandens": "blinkande",
    "blinkandes": "blinkande",
    "blinkandet": "blinkande",
    "blinkandets": "blinkande",
    "blinkar": "blinka",
    "blinkarna": "blink",
    "blinkarnas": "blink",
    "blinkars": "blink",
    "blinkas": "blinka",
    "blinkat": "blinka",
    "blinkats": "blinka",
    "blinken": "blink",
    "blinkens": "blink",
    "blinkern": "blinker",
    "blinkerns": "blinker",
    "blinkers": "blinker",
    "blinkersarna": "blinker",
    "blinkersarnas": "blinker",
    "blinkersen": "blinker",
    "blinkersens": "blinker",
    "blinket": "blink",
    "blinkets": "blink",
    "blinkfyrar": "blinkfyr",
    "blinkfyrarna": "blinkfyr",
    "blinkfyrarnas": "blinkfyr",
    "blinkfyrars": "blinkfyr",
    "blinkfyren": "blinkfyr",
    "blinkfyrens": "blinkfyr",
    "blinkfyrs": "blinkfyr",
    "blinkhinnan": "blinkhinna",
    "blinkhinnans": "blinkhinna",
    "blinkhinnas": "blinkhinna",
    "blinkhinne": "blinkhinna",
    "blinkhinnor": "blinkhinna",
    "blinkhinnorna": "blinkhinna",
    "blinkhinnornas": "blinkhinna",
    "blinkhinnors": "blinkhinna",
    "blinkljusen": "blinkljus",
    "blinkljusens": "blinkljus",
    "blinkljuset": "blinkljus",
    "blinkljusets": "blinkljus",
    "blinkrar": "blinker",
    "blinkrarna": "blinker",
    "blinkrarnas": "blinker",
    "blinkrars": "blinker",
    "blinks": "blink",
    "blinningar": "blinning",
    "blinningarna": "blinning",
    "blinningarnas": "blinning",
    "blinningars": "blinning",
    "blinningen": "blinning",
    "blinningens": "blinning",
    "blinnings": "blinning",
    "blint": "blind",
    "blints": "blind",
    "blipar": "blip",
    "bliparna": "blip",
    "bliparnas": "blip",
    "blipars": "blip",
    "blipen": "blip",
    "blipens": "blip",
    "blippar": "blipp",
    "blipparna": "blipp",
    "blipparnas": "blipp",
    "blippars": "blipp",
    "blippen": "blipp",
    "blippens": "blipp",
    "blipps": "blipp",
    "blips": "blip",
    "blir": "bli",
    "blitt": "blid",
    "blitts": "blid",
    "bliv": "bli",
    "bliva": "bli",
    "blivande": "bli",
    "blivanden": "blivande",
    "blivandena": "blivande",
    "blivandenas": "blivande",
    "blivandens": "blivande",
    "blivandes": "blivande",
    "blivandet": "blivande",
    "blivandets": "blivande",
    "blive": "bli",
    "bliven": "bli",
    "blivens": "bli",
    "bliver": "bli",
    "blivet": "bli",
    "blivets": "bli",
    "blivit": "bli",
    "blivna": "bli",
    "blivnas": "bli",
    "blivne": "bli",
    "blivnes": "bli",
    "blixtanfallen": "blixtanfall",
    "blixtanfallens": "blixtanfall",
    "blixtanfallet": "blixtanfall",
    "blixtanfallets": "blixtanfall",
    "blixtanfalls": "blixtanfall",
    "blixtar": "blixt",
    "blixtarna": "blixt",
    "blixtarnas": "blixt",
    "blixtars": "blixt",
    "blixtbelysningar": "blixtbelysning",
    "blixtbelysningarna": "blixtbelysning",
    "blixtbelysningarnas": "blixtbelysning",
    "blixtbelysningars": "blixtbelysning",
    "blixtbelysningen": "blixtbelysning",
    "blixtbelysningens": "blixtbelysning",
    "blixtbelysnings": "blixtbelysning",
    "blixtbesöken": "blixtbesök",
    "blixtbesökens": "blixtbesök",
    "blixtbesöket": "blixtbesök",
    "blixtbesökets": "blixtbesök",
    "blixtbesöks": "blixtbesök",
    "blixten": "blixt",
    "blixtens": "blixt",
    "blixtfotograferad": "blixtfotografera",
    "blixtfotograferade": "blixtfotografera",
    "blixtfotograferades": "blixtfotografera",
    "blixtfotograferads": "blixtfotografera",
    "blixtfotograferande": "blixtfotografera",
    "blixtfotograferanden": "blixtfotograferande",
    "blixtfotograferandena": "blixtfotograferande",
    "blixtfotograferandenas": "blixtfotograferande",
    "blixtfotograferandens": "blixtfotograferande",
    "blixtfotograferandes": "blixtfotograferande",
    "blixtfotograferandet": "blixtfotograferande",
    "blixtfotograferandets": "blixtfotograferande",
    "blixtfotograferar": "blixtfotografera",
    "blixtfotograferas": "blixtfotografera",
    "blixtfotograferat": "blixtfotografera",
    "blixtfotograferats": "blixtfotografera",
    "blixtfotograferbara": "blixtfotograferbar",
    "blixtfotograferbarare": "blixtfotograferbar",
    "blixtfotograferbarares": "blixtfotograferbar",
    "blixtfotograferbaras": "blixtfotograferbar",
    "blixtfotograferbarast": "blixtfotograferbar",
    "blixtfotograferbaraste": "blixtfotograferbar",
    "blixtfotograferbarastes": "blixtfotograferbar",
    "blixtfotograferbarasts": "blixtfotograferbar",
    "blixtfotograferbare": "blixtfotograferbar",
    "blixtfotograferbares": "blixtfotograferbar",
    "blixtfotograferbarheten": "blixtfotograferbarhet",
    "blixtfotograferbarhetens": "blixtfotograferbarhet",
    "blixtfotograferbarhets": "blixtfotograferbarhet",
    "blixtfotograferbars": "blixtfotograferbar",
    "blixtfotograferbart": "blixtfotograferbar",
    "blixtfotograferbarts": "blixtfotograferbar",
    "blixtfotograferingar": "blixtfotografering",
    "blixtfotograferingarna": "blixtfotografering",
    "blixtfotograferingarnas": "blixtfotografering",
    "blixtfotograferingars": "blixtfotografering",
    "blixtfotograferingen": "blixtfotografering",
    "blixtfotograferingens": "blixtfotografering",
    "blixtfotograferings": "blixtfotografering",
    "blixtfoton": "blixtfoto",
    "blixtfotona": "blixtfoto",
    "blixtfotonas": "blixtfoto",
    "blixtfotons": "blixtfoto",
    "blixtfotos": "blixtfoto",
    "blixtfotot": "blixtfoto",
    "blixtfotots": "blixtfoto",
    "blixtfyrar": "blixtfyr",
    "blixtfyrarna": "blixtfyr",
    "blixtfyrarnas": "blixtfyr",
    "blixtfyrars": "blixtfyr",
    "blixtfyren": "blixtfyr",
    "blixtfyrens": "blixtfyr",
    "blixtfyrs": "blixtfyr",
    "blixthalkan": "blixthalka",
    "blixthalkans": "blixthalka",
    "blixthalkas": "blixthalka",
    "blixtkrigen": "blixtkrig",
    "blixtkrigens": "blixtkrig",
    "blixtkriget": "blixtkrig",
    "blixtkrigets": "blixtkrig",
    "blixtkrigs": "blixtkrig",
    "blixtlamp": "blixtlampa",
    "blixtlampan": "blixtlampa",
    "blixtlampans": "blixtlampa",
    "blixtlampas": "blixtlampa",
    "blixtlampe": "blixtlampa",
    "blixtlampor": "blixtlampa",
    "blixtlamporna": "blixtlampa",
    "blixtlampornas": "blixtlampa",
    "blixtlampors": "blixtlampa",
    "blixtlamps": "blixtlampa",
    "blixtljuset": "blixtljus",
    "blixtljusets": "blixtljus",
    "blixtlåsen": "blixtlås",
    "blixtlåsens": "blixtlås",
    "blixtlåset": "blixtlås",
    "blixtlåsets": "blixtlås",
    "blixtnedslagen": "blixtnedslag",
    "blixtnedslagens": "blixtnedslag",
    "blixtnedslaget": "blixtnedslag",
    "blixtnedslagets": "blixtnedslag",
    "blixtnedslags": "blixtnedslag",
    "blixtpatronen": "blixtpatron",
    "blixtpatronens": "blixtpatron",
    "blixtpatroner": "blixtpatron",
    "blixtpatronerna": "blixtpatron",
    "blixtpatronernas": "blixtpatron",
    "blixtpatroners": "blixtpatron",
    "blixtpatrons": "blixtpatron",
    "blixtpulvers": "blixtpulver",
    "blixtpulvret": "blixtpulver",
    "blixtpulvrets": "blixtpulver",
    "blixtrade": "blixtra",
    "blixtrades": "blixtra",
    "blixtrande": "blixtra",
    "blixtranden": "blixtrande",
    "blixtrandena": "blixtrande",
    "blixtrandenas": "blixtrande",
    "blixtrandens": "blixtrande",
    "blixtrandes": "blixtrande",
    "blixtrandet": "blixtrande",
    "blixtrandets": "blixtrande",
    "blixtrar": "blixtra",
    "blixtras": "blixtra",
    "blixtrat": "blixtra",
    "blixtrats": "blixtra",
    "blixts": "blixt",
    "blixtsamtalen": "blixtsamtal",
    "blixtsamtalens": "blixtsamtal",
    "blixtsamtalet": "blixtsamtal",
    "blixtsamtalets": "blixtsamtal",
    "blixtsamtals": "blixtsamtal",
    "blixtsnabba": "blixtsnabb",
    "blixtsnabbare": "blixtsnabb",
    "blixtsnabbares": "blixtsnabb",
    "blixtsnabbas": "blixtsnabb",
    "blixtsnabbast": "blixtsnabb",
    "blixtsnabbaste": "blixtsnabb",
    "blixtsnabbastes": "blixtsnabb",
    "blixtsnabbasts": "blixtsnabb",
    "blixtsnabbe": "blixtsnabb",
    "blixtsnabbes": "blixtsnabb",
    "blixtsnabbheten": "blixtsnabbhet",
    "blixtsnabbhetens": "blixtsnabbhet",
    "blixtsnabbhets": "blixtsnabbhet",
    "blixtsnabbs": "blixtsnabb",
    "blixtsnabbt": "blixtsnabb",
    "blixtsnabbts": "blixtsnabb",
    "blixtutryckningar": "blixtutryckning",
    "blixtutryckningarna": "blixtutryckning",
    "blixtutryckningarnas": "blixtutryckning",
    "blixtutryckningars": "blixtutryckning",
    "blixtutryckningen": "blixtutryckning",
    "blixtutryckningens": "blixtutryckning",
    "blixtutrycknings": "blixtutryckning",
    "blixtvisiten": "blixtvisit",
    "blixtvisitens": "blixtvisit",
    "blixtvisiter": "blixtvisit",
    "blixtvisiterna": "blixtvisit",
    "blixtvisiternas": "blixtvisit",
    "blixtvisiters": "blixtvisit",
    "blixtvisits": "blixtvisit",
    "block": "blocka",
    "blockad": "blocka",
    "blockadbrotten": "blockadbrott",
    "blockadbrottens": "blockadbrott",
    "blockadbrottet": "blockadbrott",
    "blockadbrottets": "blockadbrott",
    "blockadbrotts": "blockadbrott",
    "blockadbrytar": "blockadbrytare",
    "blockadbrytaren": "blockadbrytare",
    "blockadbrytarens": "blockadbrytare",
    "blockadbrytares": "blockadbrytare",
    "blockadbrytarna": "blockadbrytare",
    "blockadbrytarnas": "blockadbrytare",
    "blockade": "blocka",
    "blockaden": "blockad",
    "blockadens": "blockad",
    "blockader": "blockad",
    "blockaderna": "blockad",
    "blockadernas": "blockad",
    "blockaders": "blockad",
    "blockades": "blocka",
    "blockads": "blockad",
    "blockalmanack": "blockalmanacka",
    "blockalmanackan": "blockalmanacka",
    "blockalmanackans": "blockalmanacka",
    "blockalmanackas": "blockalmanacka",
    "blockalmanacke": "blockalmanacka",
    "blockalmanacken": "blockalmanack",
    "blockalmanackens": "blockalmanack",
    "blockalmanacker": "blockalmanack",
    "blockalmanackerna": "blockalmanack",
    "blockalmanackernas": "blockalmanack",
    "blockalmanackers": "blockalmanack",
    "blockalmanackor": "blockalmanacka",
    "blockalmanackorna": "blockalmanacka",
    "blockalmanackornas": "blockalmanacka",
    "blockalmanackors": "blockalmanacka",
    "blockalmanacks": "blockalmanacka",
    "blockande": "blocka",
    "blockanden": "blockande",
    "blockandena": "blockande",
    "blockandenas": "blockande",
    "blockandens": "blockande",
    "blockandes": "blockande",
    "blockandet": "blockande",
    "blockandets": "blockande",
    "blockar": "blocka",
    "blockas": "blocka",
    "blockat": "blocka",
    "blockats": "blocka",
    "blockbildningar": "blockbildning",
    "blockbildningarna": "blockbildning",
    "blockbildningarnas": "blockbildning",
    "blockbildningars": "blockbildning",
    "blockbildningen": "blockbildning",
    "blockbildningens": "blockbildning",
    "blockbildnings": "blockbildning",
    "blockchokladen": "blockchoklad",
    "blockchokladens": "blockchoklad",
    "blockchoklads": "blockchoklad",
    "blockdiagrammen": "blockdiagram",
    "blockdiagrammens": "blockdiagram",
    "blockdiagrammet": "blockdiagram",
    "blockdiagrammets": "blockdiagram",
    "blockdiagrams": "blockdiagram",
    "blocken": "block",
    "blockens": "block",
    "blockerad": "blockera",
    "blockerade": "blockera",
    "blockerades": "blockera",
    "blockerads": "blockera",
    "blockerande": "blockera",
    "blockeranden": "blockerande",
    "blockerandena": "blockerande",
    "blockerandenas": "blockerande",
    "blockerandens": "blockerande",
    "blockerandes": "blockerande",
    "blockerandet": "blockerande",
    "blockerandets": "blockerande",
    "blockerar": "blockera",
    "blockeras": "blockera",
    "blockerat": "blockera",
    "blockerats": "blockera",
    "blockerbara": "blockerbar",
    "blockerbarare": "blockerbar",
    "blockerbarares": "blockerbar",
    "blockerbaras": "blockerbar",
    "blockerbarast": "blockerbar",
    "blockerbaraste": "blockerbar",
    "blockerbarastes": "blockerbar",
    "blockerbarasts": "blockerbar",
    "blockerbare": "blockerbar",
    "blockerbares": "blockerbar",
    "blockerbarheten": "blockerbarhet",
    "blockerbarhetens": "blockerbarhet",
    "blockerbarhets": "blockerbarhet",
    "blockerbars": "blockerbar",
    "blockerbart": "blockerbar",
    "blockerbarts": "blockerbar",
    "blockeringar": "blockering",
    "blockeringarna": "blockering",
    "blockeringarnas": "blockering",
    "blockeringars": "blockering",
    "blockeringen": "blockering",
    "blockeringens": "blockering",
    "blockerings": "blockering",
    "blocket": "block",
    "blockets": "block",
    "blockflöjten": "blockflöjt",
    "blockflöjtens": "blockflöjt",
    "blockflöjter": "blockflöjt",
    "blockflöjterna": "blockflöjt",
    "blockflöjternas": "blockflöjt",
    "blockflöjters": "blockflöjt",
    "blockflöjts": "blockflöjt",
    "blockgränsen": "blockgräns",
    "blockgränsens": "blockgräns",
    "blockgränser": "blockgräns",
    "blockgränserna": "blockgräns",
    "blockgränsernas": "blockgräns",
    "blockgränsers": "blockgräns",
    "blockhusen": "blockhus",
    "blockhusens": "blockhus",
    "blockhuset": "blockhus",
    "blockhusets": "blockhus",
    "blockiga": "blockig",
    "blockigare": "blockig",
    "blockigares": "blockig",
    "blockigas": "blockig",
    "blockigast": "blockig",
    "blockigaste": "blockig",
    "blockigastes": "blockig",
    "blockigasts": "blockig",
    "blockige": "blockig",
    "blockiges": "blockig",
    "blockigheten": "blockighet",
    "blockighetens": "blockighet",
    "blockighets": "blockighet",
    "blockigs": "blockig",
    "blockigt": "blockig",
    "blockigts": "blockig",
    "blockmarken": "blockmark",
    "blockmarkens": "blockmark",
    "blockmarks": "blockmark",
    "blockpolitiken": "blockpolitik",
    "blockpolitikens": "blockpolitik",
    "blockpolitiks": "blockpolitik",
    "blockpolitiska": "blockpolitisk",
    "blockpolitiskas": "blockpolitisk",
    "blockpolitiske": "blockpolitisk",
    "blockpolitiskes": "blockpolitisk",
    "blockpolitisks": "blockpolitisk",
    "blockpolitiskt": "blockpolitisk",
    "blockpolitiskts": "blockpolitisk",
    "blocks": "block",
    "blocksignalen": "blocksignal",
    "blocksignalens": "blocksignal",
    "blocksignaler": "blocksignal",
    "blocksignalerna": "blocksignal",
    "blocksignalernas": "blocksignal",
    "blocksignalers": "blocksignal",
    "blocksignals": "blocksignal",
    "blockskivan": "blockskiva",
    "blockskivans": "blockskiva",
    "blockskivas": "blockskiva",
    "blockskive": "blockskiva",
    "blockskivor": "blockskiva",
    "blockskivorna": "blockskiva",
    "blockskivornas": "blockskiva",
    "blockskivors": "blockskiva",
    "blocksystemen": "blocksystem",
    "blocksystemens": "blocksystem",
    "blocksystemet": "blocksystem",
    "blocksystemets": "blocksystem",
    "blocksystems": "blocksystem",
    "blocktaljan": "blocktalja",
    "blocktaljans": "blocktalja",
    "blocktaljas": "blocktalja",
    "blocktalje": "blocktalja",
    "blocktaljor": "blocktalja",
    "blocktaljorna": "blocktalja",
    "blocktaljornas": "blocktalja",
    "blocktaljors": "blocktalja",
    "blocktriss": "blocktrissa",
    "blocktrissan": "blocktrissa",
    "blocktrissans": "blocktrissa",
    "blocktrissas": "blocktrissa",
    "blocktrisse": "blocktrissa",
    "blocktrissor": "blocktrissa",
    "blocktrissorna": "blocktrissa",
    "blocktrissornas": "blocktrissa",
    "blocktrissors": "blocktrissa",
    "blocktygen": "blocktyg",
    "blocktygens": "blocktyg",
    "blocktyget": "blocktyg",
    "blocktygets": "blocktyg",
    "blocktygs": "blocktyg",
    "blockvagnar": "blockvagn",
    "blockvagnarna": "blockvagn",
    "blockvagnarnas": "blockvagn",
    "blockvagnars": "blockvagn",
    "blockvagnen": "blockvagn",
    "blockvagnens": "blockvagn",
    "blockvagns": "blockvagn",
    "blockämnen": "blockämne",
    "blockämnena": "blockämne",
    "blockämnenas": "blockämne",
    "blockämnens": "blockämne",
    "blockämnes": "blockämne",
    "blockämnet": "blockämne",
    "blockämnets": "blockämne",
    "blod": "bloda",
    "blodad": "bloda",
    "blodade": "bloda",
    "blodades": "bloda",
    "blodads": "bloda",
    "blodande": "bloda",
    "blodanden": "blodande",
    "blodandena": "blodande",
    "blodandenas": "blodande",
    "blodandens": "blodande",
    "blodandes": "blodande",
    "blodandet": "blodande",
    "blodandets": "blodande",
    "blodapelsinen": "blodapelsin",
    "blodapelsinens": "blodapelsin",
    "blodapelsiner": "blodapelsin",
    "blodapelsinerna": "blodapelsin",
    "blodapelsinernas": "blodapelsin",
    "blodapelsiners": "blodapelsin",
    "blodapelsins": "blodapelsin",
    "blodar": "bloda",
    "blodas": "bloda",
    "blodat": "bloda",
    "blodats": "bloda",
    "blodbaden": "blodbad",
    "blodbadens": "blodbad",
    "blodbadet": "blodbad",
    "blodbadets": "blodbad",
    "blodbads": "blodbad",
    "blodbanken": "blodbank",
    "blodbankens": "blodbank",
    "blodbanker": "blodbank",
    "blodbankerna": "blodbank",
    "blodbankernas": "blodbank",
    "blodbankers": "blodbank",
    "blodbanks": "blodbank",
    "blodbefläckade": "blodbefläckad",
    "blodbefläckades": "blodbefläckad",
    "blodbefläckads": "blodbefläckad",
    "blodbefläckat": "blodbefläckad",
    "blodbefläckats": "blodbefläckad",
    "blodblås": "blodblåsa",
    "blodblåsan": "blodblåsa",
    "blodblåsans": "blodblåsa",
    "blodblåsas": "blodblåsa",
    "blodblåse": "blodblåsa",
    "blodblåsor": "blodblåsa",
    "blodblåsorna": "blodblåsa",
    "blodblåsornas": "blodblåsa",
    "blodblåsors": "blodblåsa",
    "blodbokar": "blodbok",
    "blodbokarna": "blodbok",
    "blodbokarnas": "blodbok",
    "blodbokars": "blodbok",
    "blodboken": "blodbok",
    "blodbokens": "blodbok",
    "blodboks": "blodbok",
    "blodbristen": "blodbrist",
    "blodbristens": "blodbrist",
    "blodbrists": "blodbrist",
    "blodcellen": "blodcell",
    "blodcellens": "blodcell",
    "blodceller": "blodcell",
    "blodcellerna": "blodcell",
    "blodcellernas": "blodcell",
    "blodcellers": "blodcell",
    "blodcells": "blodcell",
    "blodcirkulationen": "blodcirkulation",
    "blodcirkulationens": "blodcirkulation",
    "blodcirkulationer": "blodcirkulation",
    "blodcirkulationerna": "blodcirkulation",
    "blodcirkulationernas": "blodcirkulation",
    "blodcirkulationers": "blodcirkulation",
    "blodcirkulations": "blodcirkulation",
    "bloddopingar": "bloddoping",
    "bloddopingarna": "bloddoping",
    "bloddopingarnas": "bloddoping",
    "bloddopingars": "bloddoping",
    "bloddopingen": "bloddoping",
    "bloddopingens": "bloddoping",
    "bloddopings": "bloddoping",
    "bloden": "blod",
    "blodens": "blod",
    "blodet": "blod",
    "blodets": "blod",
    "blodfattiga": "blodfattig",
    "blodfattigare": "blodfattig",
    "blodfattigares": "blodfattig",
    "blodfattigas": "blodfattig",
    "blodfattigast": "blodfattig",
    "blodfattigaste": "blodfattig",
    "blodfattigastes": "blodfattig",
    "blodfattigasts": "blodfattig",
    "blodfattige": "blodfattig",
    "blodfattiges": "blodfattig",
    "blodfattigheten": "blodfattighet",
    "blodfattighetens": "blodfattighet",
    "blodfattighets": "blodfattighet",
    "blodfattigs": "blodfattig",
    "blodfattigt": "blodfattig",
    "blodfattigts": "blodfattig",
    "blodfläckar": "blodfläck",
    "blodfläckarna": "blodfläck",
    "blodfläckarnas": "blodfläck",
    "blodfläckars": "blodfläck",
    "blodfläcken": "blodfläck",
    "blodfläckens": "blodfläck",
    "blodfläcks": "blodfläck",
    "blodflöden": "blodflöde",
    "blodflödena": "blodflöde",
    "blodflödenas": "blodflöde",
    "blodflödens": "blodflöde",
    "blodflödes": "blodflöde",
    "blodflödet": "blodflöde",
    "blodflödets": "blodflöde",
    "blodfulla": "blodfull",
    "blodfullare": "blodfull",
    "blodfullares": "blodfull",
    "blodfullas": "blodfull",
    "blodfullast": "blodfull",
    "blodfullaste": "blodfull",
    "blodfullastes": "blodfull",
    "blodfullasts": "blodfull",
    "blodfulle": "blodfull",
    "blodfulles": "blodfull",
    "blodfullheten": "blodfullhet",
    "blodfullhetens": "blodfullhet",
    "blodfullhets": "blodfullhet",
    "blodfulls": "blodfull",
    "blodfullt": "blodfull",
    "blodfullts": "blodfull",
    "blodfärgämnen": "blodfärgämne",
    "blodfärgämnena": "blodfärgämne",
    "blodfärgämnenas": "blodfärgämne",
    "blodfärgämnens": "blodfärgämne",
    "blodfärgämnes": "blodfärgämne",
    "blodfärgämnet": "blodfärgämne",
    "blodfärgämnets": "blodfärgämne",
    "blodförgiftningar": "blodförgiftning",
    "blodförgiftningarna": "blodförgiftning",
    "blodförgiftningarnas": "blodförgiftning",
    "blodförgiftningars": "blodförgiftning",
    "blodförgiftningen": "blodförgiftning",
    "blodförgiftningens": "blodförgiftning",
    "blodförgiftnings": "blodförgiftning",
    "blodgivar": "blodgivare",
    "blodgivaren": "blodgivare",
    "blodgivarens": "blodgivare",
    "blodgivares": "blodgivare",
    "blodgivarna": "blodgivare",
    "blodgivarnas": "blodgivare",
    "blodgivningen": "blodgivning",
    "blodgivningens": "blodgivning",
    "blodgivnings": "blodgivning",
    "blodgruppen": "blodgrupp",
    "blodgruppens": "blodgrupp",
    "blodgrupper": "blodgrupp",
    "blodgrupperna": "blodgrupp",
    "blodgruppernas": "blodgrupp",
    "blodgruppers": "blodgrupp",
    "blodgrupps": "blodgrupp",
    "blodgången": "blodgång",
    "blodgångens": "blodgång",
    "blodgångs": "blodgång",
    "blodhost": "blodhosta",
    "blodhostan": "blodhosta",
    "blodhostans": "blodhosta",
    "blodhostas": "blodhosta",
    "blodhoste": "blodhosta",
    "blodhundar": "blodhund",
    "blodhundarna": "blodhund",
    "blodhundarnas": "blodhund",
    "blodhundars": "blodhund",
    "blodhunden": "blodhund",
    "blodhundens": "blodhund",
    "blodhunds": "blodhund",
    "blodiga": "blodig",
    "blodigare": "blodig",
    "blodigares": "blodig",
    "blodigas": "blodig",
    "blodigast": "blodig",
    "blodigaste": "blodig",
    "blodigastes": "blodig",
    "blodigasts": "blodig",
    "blodige": "blodig",
    "blodigeln": "blodigel",
    "blodigelns": "blodigel",
    "blodigels": "blodigel",
    "blodiges": "blodig",
    "blodigheten": "blodighet",
    "blodighetens": "blodighet",
    "blodigheter": "blodighet",
    "blodigheterna": "blodighet",
    "blodigheternas": "blodighet",
    "blodigheters": "blodighet",
    "blodighets": "blodighet",
    "blodiglar": "blodigel",
    "blodiglarna": "blodigel",
    "blodiglarnas": "blodigel",
    "blodiglars": "blodigel",
    "blodigs": "blodig",
    "blodigt": "blodig",
    "blodigts": "blodig",
    "blodkorvar": "blodkorv",
    "blodkorvarna": "blodkorv",
    "blodkorvarnas": "blodkorv",
    "blodkorvars": "blodkorv",
    "blodkorven": "blodkorv",
    "blodkorvens": "blodkorv",
    "blodkorvs": "blodkorv",
    "blodkroppar": "blodkropp",
    "blodkropparna": "blodkropp",
    "blodkropparnas": "blodkropp",
    "blodkroppars": "blodkropp",
    "blodkroppen": "blodkropp",
    "blodkroppens": "blodkropp",
    "blodkropps": "blodkropp",
    "blodkräftan": "blodkräfta",
    "blodkräftans": "blodkräfta",
    "blodkräftas": "blodkräfta",
    "blodkräkningar": "blodkräkning",
    "blodkräkningarna": "blodkräkning",
    "blodkräkningarnas": "blodkräkning",
    "blodkräkningars": "blodkräkning",
    "blodkräkningen": "blodkräkning",
    "blodkräkningens": "blodkräkning",
    "blodkräknings": "blodkräkning",
    "blodkärlen": "blodkärl",
    "blodkärlens": "blodkärl",
    "blodkärlet": "blodkärl",
    "blodkärlets": "blodkärl",
    "blodkärls": "blodkärl",
    "blodkärlsbråcken": "blodkärlsbråck",
    "blodkärlsbråckens": "blodkärlsbråck",
    "blodkärlsbråcket": "blodkärlsbråck",
    "blodkärlsbråckets": "blodkärlsbråck",
    "blodkärlsbråcks": "blodkärlsbråck",
    "blodledar": "blodledare",
    "blodledaren": "blodledare",
    "blodledarens": "blodledare",
    "blodledares": "blodledare",
    "blodledarna": "blodledare",
    "blodledarnas": "blodledare",
    "blodlutsaltet": "blodlutsalt",
    "blodlutsaltets": "blodlutsalt",
    "blodlutsalts": "blodlutsalt",
    "blodlutssaltet": "blodlutssalt",
    "blodlutssaltets": "blodlutssalt",
    "blodlutssalts": "blodlutssalt",
    "blodlösa": "blodlös",
    "blodlösare": "blodlös",
    "blodlösares": "blodlös",
    "blodlösas": "blodlös",
    "blodlösast": "blodlös",
    "blodlösaste": "blodlös",
    "blodlösastes": "blodlös",
    "blodlösasts": "blodlös",
    "blodlöse": "blodlös",
    "blodlöses": "blodlös",
    "blodlösheten": "blodlöshet",
    "blodlöshetens": "blodlöshet",
    "blodlöshets": "blodlöshet",
    "blodlöst": "blodlös",
    "blodlösts": "blodlös",
    "blodmaten": "blodmat",
    "blodmatens": "blodmat",
    "blodmats": "blodmat",
    "blodnäv": "blodnäva",
    "blodnävan": "blodnäva",
    "blodnävans": "blodnäva",
    "blodnävas": "blodnäva",
    "blodnäve": "blodnäva",
    "blodnävor": "blodnäva",
    "blodnävorna": "blodnäva",
    "blodnävornas": "blodnäva",
    "blodnävors": "blodnäva",
    "blodnävs": "blodnäva",
    "blodomloppet": "blodomlopp",
    "blodomloppets": "blodomlopp",
    "blodomlopps": "blodomlopp",
    "blodpaltar": "blodpalt",
    "blodpaltarna": "blodpalt",
    "blodpaltarnas": "blodpalt",
    "blodpaltars": "blodpalt",
    "blodpalten": "blodpalt",
    "blodpaltens": "blodpalt",
    "blodpalts": "blodpalt",
    "blodplasman": "blodplasma",
    "blodplasmans": "blodplasma",
    "blodplasmas": "blodplasma",
    "blodplasmat": "blodplasma",
    "blodplasmats": "blodplasma",
    "blodplättar": "blodplätt",
    "blodplättarna": "blodplätt",
    "blodplättarnas": "blodplätt",
    "blodplättars": "blodplätt",
    "blodplätten": "blodplätt",
    "blodplättens": "blodplätt",
    "blodplätts": "blodplätt",
    "blodproppar": "blodpropp",
    "blodpropparna": "blodpropp",
    "blodpropparnas": "blodpropp",
    "blodproppars": "blodpropp",
    "blodproppen": "blodpropp",
    "blodproppens": "blodpropp",
    "blodpropps": "blodpropp",
    "blodproteiner": "blodprotein",
    "blodproteinerna": "blodprotein",
    "blodproteinernas": "blodprotein",
    "blodproteiners": "blodprotein",
    "blodproteinet": "blodprotein",
    "blodproteinets": "blodprotein",
    "blodproteins": "blodprotein",
    "blodproven": "blodprov",
    "blodprovens": "blodprov",
    "blodprover": "blodprov",
    "blodproverna": "blodprov",
    "blodprovernas": "blodprov",
    "blodprovers": "blodprov",
    "blodprovet": "blodprov",
    "blodprovets": "blodprov",
    "blodprovs": "blodprov",
    "blodpuddingar": "blodpudding",
    "blodpuddingarna": "blodpudding",
    "blodpuddingarnas": "blodpudding",
    "blodpuddingars": "blodpudding",
    "blodpuddingen": "blodpudding",
    "blodpuddingens": "blodpudding",
    "blodpuddings": "blodpudding",
    "blodpuddingsbitar": "blodpuddingsbit",
    "blodpuddingsbitarna": "blodpuddingsbit",
    "blodpuddingsbitarnas": "blodpuddingsbit",
    "blodpuddingsbitars": "blodpuddingsbit",
    "blodpuddingsbiten": "blodpuddingsbit",
    "blodpuddingsbitens": "blodpuddingsbit",
    "blodpuddingsbits": "blodpuddingsbit",
    "blodpumpar": "blodpump",
    "blodpumparna": "blodpump",
    "blodpumparnas": "blodpump",
    "blodpumpars": "blodpump",
    "blodpumpen": "blodpump",
    "blodpumpens": "blodpump",
    "blodpumps": "blodpump",
    "blodpölar": "blodpöl",
    "blodpölarna": "blodpöl",
    "blodpölarnas": "blodpöl",
    "blodpölars": "blodpöl",
    "blodpölen": "blodpöl",
    "blodpölens": "blodpöl",
    "blodpöls": "blodpöl",
    "blodranden": "blodrand",
    "blodrandens": "blodrand",
    "blodrands": "blodrand",
    "blodregnet": "blodregn",
    "blodregnets": "blodregn",
    "blodregns": "blodregn",
    "blodrisk": "blodriska",
    "blodriskan": "blodriska",
    "blodriskans": "blodriska",
    "blodriskas": "blodriska",
    "blodriske": "blodriska",
    "blodriskor": "blodriska",
    "blodriskorna": "blodriska",
    "blodriskornas": "blodriska",
    "blodriskors": "blodriska",
    "blodroten": "blodrot",
    "blodrotens": "blodrot",
    "blodrots": "blodrot",
    "blodränder": "blodrand",
    "blodränderna": "blodrand",
    "blodrändernas": "blodrand",
    "blodränders": "blodrand",
    "blodröda": "blodröd",
    "blodrödare": "blodröd",
    "blodrödares": "blodröd",
    "blodrödas": "blodröd",
    "blodrödast": "blodröd",
    "blodrödaste": "blodröd",
    "blodrödastes": "blodröd",
    "blodrödasts": "blodröd",
    "blodröde": "blodröd",
    "blodrödes": "blodröd",
    "blodröds": "blodröd",
    "blodrött": "blodröd",
    "blodrötts": "blodröd",
    "blods": "blod",
    "blodsbanden": "blodsband",
    "blodsbandens": "blodsband",
    "blodsbandet": "blodsband",
    "blodsbandets": "blodsband",
    "blodsbands": "blodsband",
    "blodsdiamanten": "blodsdiamant",
    "blodsdiamantens": "blodsdiamant",
    "blodsdiamanter": "blodsdiamant",
    "blodsdiamanterna": "blodsdiamant",
    "blodsdiamanternas": "blodsdiamant",
    "blodsdiamanters": "blodsdiamant",
    "blodsdiamants": "blodsdiamant",
    "blodsdropp": "blodsdroppe",
    "blodsdroppar": "blodsdroppe",
    "blodsdropparna": "blodsdroppe",
    "blodsdropparnas": "blodsdroppe",
    "blodsdroppars": "blodsdroppe",
    "blodsdroppen": "blodsdroppe",
    "blodsdroppens": "blodsdroppe",
    "blodsdroppes": "blodsdroppe",
    "blodsdropps": "blodsdroppe",
    "blodsdåden": "blodsdåd",
    "blodsdådens": "blodsdåd",
    "blodsdådet": "blodsdåd",
    "blodsdådets": "blodsdåd",
    "blodsdåds": "blodsdåd",
    "blodserumet": "blodserum",
    "blodserumets": "blodserum",
    "blodserums": "blodserum",
    "blodshämnden": "blodshämnd",
    "blodshämndens": "blodshämnd",
    "blodshämnds": "blodshämnd",
    "blodsjukdomar": "blodsjukdom",
    "blodsjukdomarna": "blodsjukdom",
    "blodsjukdomarnas": "blodsjukdom",
    "blodsjukdomars": "blodsjukdom",
    "blodsjukdomen": "blodsjukdom",
    "blodsjukdomens": "blodsjukdom",
    "blodsjukdoms": "blodsjukdom",
    "blodskammen": "blodskam",
    "blodskammens": "blodskam",
    "blodskams": "blodskam",
    "blodsmystiken": "blodsmystik",
    "blodsmystikens": "blodsmystik",
    "blodsmystiks": "blodsmystik",
    "blodsockers": "blodsocker",
    "blodsockersvack": "blodsockersvacka",
    "blodsockersvackan": "blodsockersvacka",
    "blodsockersvackans": "blodsockersvacka",
    "blodsockersvackas": "blodsockersvacka",
    "blodsockersvacke": "blodsockersvacka",
    "blodsockersvackor": "blodsockersvacka",
    "blodsockersvackorna": "blodsockersvacka",
    "blodsockersvackornas": "blodsockersvacka",
    "blodsockersvackors": "blodsockersvacka",
    "blodsockersvacks": "blodsockersvacka",
    "blodsockret": "blodsocker",
    "blodsockrets": "blodsocker",
    "blodspenningar": "blodspenning",
    "blodspenningarna": "blodspenning",
    "blodspenningarnas": "blodspenning",
    "blodspenningars": "blodspenning",
    "blodspenningen": "blodspenning",
    "blodspenningens": "blodspenning",
    "blodspennings": "blodspenning",
    "blodspottningar": "blodspottning",
    "blodspottningarna": "blodspottning",
    "blodspottningarnas": "blodspottning",
    "blodspottningars": "blodspottning",
    "blodspottningen": "blodspottning",
    "blodspottningens": "blodspottning",
    "blodspottnings": "blodspottning",
    "blodsprängda": "blodsprängd",
    "blodsprängdare": "blodsprängd",
    "blodsprängdares": "blodsprängd",
    "blodsprängdas": "blodsprängd",
    "blodsprängdast": "blodsprängd",
    "blodsprängdaste": "blodsprängd",
    "blodsprängdastes": "blodsprängd",
    "blodsprängdasts": "blodsprängd",
    "blodsprängde": "blodsprängd",
    "blodsprängdes": "blodsprängd",
    "blodsprängdheten": "blodsprängdhet",
    "blodsprängdhetens": "blodsprängdhet",
    "blodsprängdhets": "blodsprängdhet",
    "blodsprängds": "blodsprängd",
    "blodsprängt": "blodsprängd",
    "blodsprängts": "blodsprängd",
    "blodstallningar": "blodstallning",
    "blodstallningarna": "blodstallning",
    "blodstallningarnas": "blodstallning",
    "blodstallningars": "blodstallning",
    "blodstallningen": "blodstallning",
    "blodstallningens": "blodstallning",
    "blodstallnings": "blodstallning",
    "blodstenen": "blodsten",
    "blodstenens": "blodsten",
    "blodstens": "blodsten",
    "blodstensmalmen": "blodstensmalm",
    "blodstensmalmens": "blodstensmalm",
    "blodstensmalms": "blodstensmalm",
    "blodstillningar": "blodstillning",
    "blodstillningarna": "blodstillning",
    "blodstillningarnas": "blodstillning",
    "blodstillningars": "blodstillning",
    "blodstillningen": "blodstillning",
    "blodstillningens": "blodstillning",
    "blodstillnings": "blodstillning",
    "blodstinna": "blodstinn",
    "blodstinnare": "blodstinn",
    "blodstinnares": "blodstinn",
    "blodstinnas": "blodstinn",
    "blodstinnast": "blodstinn",
    "blodstinnaste": "blodstinn",
    "blodstinnastes": "blodstinn",
    "blodstinnasts": "blodstinn",
    "blodstinne": "blodstinn",
    "blodstinnes": "blodstinn",
    "blodstinnheten": "blodstinnhet",
    "blodstinnhetens": "blodstinnhet",
    "blodstinnhets": "blodstinnhet",
    "blodstinns": "blodstinn",
    "blodstint": "blodstinn",
    "blodstints": "blodstinn",
    "blodstockningar": "blodstockning",
    "blodstockningarna": "blodstockning",
    "blodstockningarnas": "blodstockning",
    "blodstockningars": "blodstockning",
    "blodstockningen": "blodstockning",
    "blodstockningens": "blodstockning",
    "blodstocknings": "blodstockning",
    "blodstänkta": "blodstänkt",
    "blodstänktare": "blodstänkt",
    "blodstänktares": "blodstänkt",
    "blodstänktas": "blodstänkt",
    "blodstänktast": "blodstänkt",
    "blodstänktaste": "blodstänkt",
    "blodstänktastes": "blodstänkt",
    "blodstänktasts": "blodstänkt",
    "blodstänkte": "blodstänkt",
    "blodstänktes": "blodstänkt",
    "blodstänkts": "blodstänkt",
    "blodstörtningar": "blodstörtning",
    "blodstörtningarna": "blodstörtning",
    "blodstörtningarnas": "blodstörtning",
    "blodstörtningars": "blodstörtning",
    "blodstörtningen": "blodstörtning",
    "blodstörtningens": "blodstörtning",
    "blodstörtnings": "blodstörtning",
    "blodsugar": "blodsugare",
    "blodsugaren": "blodsugare",
    "blodsugarens": "blodsugare",
    "blodsugares": "blodsugare",
    "blodsugarna": "blodsugare",
    "blodsugarnas": "blodsugare",
    "blodsutgjutelsen": "blodsutgjutelse",
    "blodsutgjutelsens": "blodsutgjutelse",
    "blodsutgjutelser": "blodsutgjutelse",
    "blodsutgjutelserna": "blodsutgjutelse",
    "blodsutgjutelsernas": "blodsutgjutelse",
    "blodsutgjutelsers": "blodsutgjutelse",
    "blodsutgjutelses": "blodsutgjutelse",
    "blodsvettningar": "blodsvettning",
    "blodsvettningarna": "blodsvettning",
    "blodsvettningarnas": "blodsvettning",
    "blodsvettningars": "blodsvettning",
    "blodsvettningen": "blodsvettning",
    "blodsvettningens": "blodsvettning",
    "blodsvettnings": "blodsvettning",
    "blodsvulsten": "blodsvulst",
    "blodsvulstens": "blodsvulst",
    "blodsvulster": "blodsvulst",
    "blodsvulsterna": "blodsvulst",
    "blodsvulsternas": "blodsvulst",
    "blodsvulsters": "blodsvulst",
    "blodsvulsts": "blodsvulst",
    "blodsystemen": "blodsystem",
    "blodsystemens": "blodsystem",
    "blodsystemet": "blodsystem",
    "blodsystemets": "blodsystem",
    "blodsystems": "blodsystem",
    "blodsänkan": "blodsänka",
    "blodsänkans": "blodsänka",
    "blodsänkas": "blodsänka",
    "blodtappningar": "blodtappning",
    "blodtappningarna": "blodtappning",
    "blodtappningarnas": "blodtappning",
    "blodtappningars": "blodtappning",
    "blodtappningen": "blodtappning",
    "blodtappningens": "blodtappning",
    "blodtappnings": "blodtappning",
    "blodtransfusionen": "blodtransfusion",
    "blodtransfusionens": "blodtransfusion",
    "blodtransfusioner": "blodtransfusion",
    "blodtransfusionerna": "blodtransfusion",
    "blodtransfusionernas": "blodtransfusion",
    "blodtransfusioners": "blodtransfusion",
    "blodtransfusions": "blodtransfusion",
    "blodtrycken": "blodtryck",
    "blodtryckens": "blodtryck",
    "blodtrycket": "blodtryck",
    "blodtryckets": "blodtryck",
    "blodtrycks": "blodtryck",
    "blodtypen": "blodtyp",
    "blodtypens": "blodtyp",
    "blodtyper": "blodtyp",
    "blodtyperna": "blodtyp",
    "blodtypernas": "blodtyp",
    "blodtypers": "blodtyp",
    "blodtyps": "blodtyp",
    "blodtörsten": "blodtörst",
    "blodtörstens": "blodtörst",
    "blodtörstiga": "blodtörstig",
    "blodtörstigare": "blodtörstig",
    "blodtörstigares": "blodtörstig",
    "blodtörstigas": "blodtörstig",
    "blodtörstigast": "blodtörstig",
    "blodtörstigaste": "blodtörstig",
    "blodtörstigastes": "blodtörstig",
    "blodtörstigasts": "blodtörstig",
    "blodtörstige": "blodtörstig",
    "blodtörstiges": "blodtörstig",
    "blodtörstigheten": "blodtörstighet",
    "blodtörstighetens": "blodtörstighet",
    "blodtörstighets": "blodtörstighet",
    "blodtörstigs": "blodtörstig",
    "blodtörstigt": "blodtörstig",
    "blodtörstigts": "blodtörstig",
    "blodtörsts": "blodtörst",
    "blodutgjutningar": "blodutgjutning",
    "blodutgjutningarna": "blodutgjutning",
    "blodutgjutningarnas": "blodutgjutning",
    "blodutgjutningars": "blodutgjutning",
    "blodutgjutningen": "blodutgjutning",
    "blodutgjutningens": "blodutgjutning",
    "blodutgjutnings": "blodutgjutning",
    "blodvallningar": "blodvallning",
    "blodvallningarna": "blodvallning",
    "blodvallningarnas": "blodvallning",
    "blodvallningars": "blodvallning",
    "blodvallningen": "blodvallning",
    "blodvallningens": "blodvallning",
    "blodvallnings": "blodvallning",
    "blodvattens": "blodvatten",
    "blodvattnet": "blodvatten",
    "blodvattnets": "blodvatten",
    "blodviten": "blodvite",
    "blodvitena": "blodvite",
    "blodvitenas": "blodvite",
    "blodvitens": "blodvite",
    "blodvites": "blodvite",
    "blodvitet": "blodvite",
    "blodvitets": "blodvite",
    "blodvärden": "blodvärde",
    "blodvärdena": "blodvärde",
    "blodvärdenas": "blodvärde",
    "blodvärdens": "blodvärde",
    "blodvärdes": "blodvärde",
    "blodvärdet": "blodvärde",
    "blodvärdets": "blodvärde",
    "blodvätskan": "blodvätska",
    "blodvätskans": "blodvätska",
    "blodvätskas": "blodvätska",
    "blodvätske": "blodvätska",
    "blodvågen": "blodvåg",
    "blodvågens": "blodvåg",
    "blodvågor": "blodvåg",
    "blodvågorna": "blodvåg",
    "blodvågornas": "blodvåg",
    "blodvågors": "blodvåg",
    "blodvågs": "blodvåg",
    "blodådern": "blodåder",
    "blodåderns": "blodåder",
    "blodåders": "blodåder",
    "blodådra": "blodåder",
    "blodådran": "blodåder",
    "blodådrans": "blodåder",
    "blodådras": "blodåder",
    "blodådre": "blodåder",
    "blodådror": "blodåder",
    "blodådrorna": "blodåder",
    "blodådrornas": "blodåder",
    "blodådrors": "blodåder",
    "blodöverfyllnaden": "blodöverfyllnad",
    "blodöverfyllnadens": "blodöverfyllnad",
    "blodöverfyllnader": "blodöverfyllnad",
    "blodöverfyllnaderna": "blodöverfyllnad",
    "blodöverfyllnadernas": "blodöverfyllnad",
    "blodöverfyllnaders": "blodöverfyllnad",
    "blodöverfyllnads": "blodöverfyllnad",
    "blodöverföringar": "blodöverföring",
    "blodöverföringarna": "blodöverföring",
    "blodöverföringarnas": "blodöverföring",
    "blodöverföringars": "blodöverföring",
    "blodöverföringen": "blodöverföring",
    "blodöverföringens": "blodöverföring",
    "blodöverförings": "blodöverföring",
    "blogg": "blogga",
    "bloggad": "blogga",
    "bloggade": "blogga",
    "bloggades": "blogga",
    "bloggads": "blogga",
    "bloggande": "blogga",
    "blogganden": "bloggande",
    "bloggandena": "bloggande",
    "bloggandenas": "bloggande",
    "bloggandens": "bloggande",
    "bloggandes": "bloggande",
    "bloggandet": "bloggande",
    "bloggandets": "bloggande",
    "bloggar": "bloggare",
    "bloggaren": "bloggare",
    "bloggarens": "bloggare",
    "bloggares": "bloggare",
    "bloggarna": "bloggare",
    "bloggarnas": "bloggare",
    "bloggars": "blogg",
    "bloggas": "blogga",
    "bloggat": "blogga",
    "bloggats": "blogga",
    "bloggen": "blogg",
    "bloggens": "blogg",
    "blogginläggen": "blogginlägg",
    "blogginläggens": "blogginlägg",
    "blogginlägget": "blogginlägg",
    "blogginläggets": "blogginlägg",
    "blogginläggs": "blogginlägg",
    "bloggosfären": "bloggosfär",
    "bloggosfärens": "bloggosfär",
    "bloggosfärer": "bloggosfär",
    "bloggosfärerna": "bloggosfär",
    "bloggosfärernas": "bloggosfär",
    "bloggosfärers": "bloggosfär",
    "bloggosfärs": "bloggosfär",
    "bloggs": "blogg",
    "blom": "blomma",
    "blomaxeln": "blomaxel",
    "blomaxelns": "blomaxel",
    "blomaxels": "blomaxel",
    "blomaxlar": "blomaxel",
    "blomaxlarna": "blomaxel",
    "blomaxlarnas": "blomaxel",
    "blomaxlars": "blomaxel",
    "blombefruktningar": "blombefruktning",
    "blombefruktningarna": "blombefruktning",
    "blombefruktningarnas": "blombefruktning",
    "blombefruktningars": "blombefruktning",
    "blombefruktningen": "blombefruktning",
    "blombefruktningens": "blombefruktning",
    "blombefruktnings": "blombefruktning",
    "blombladen": "blomblad",
    "blombladens": "blomblad",
    "blombladet": "blomblad",
    "blombladets": "blomblad",
    "blomblads": "blomblad",
    "blomborden": "blombord",
    "blombordens": "blombord",
    "blombordet": "blombord",
    "blombordets": "blombord",
    "blombords": "blombord",
    "blombottens": "blombotten",
    "blombottnar": "blombotten",
    "blombottnarna": "blombotten",
    "blombottnarnas": "blombotten",
    "blombottnars": "blombotten",
    "blombottnen": "blombotten",
    "blombottnens": "blombotten",
    "blombuketten": "blombukett",
    "blombukettens": "blombukett",
    "blombuketter": "blombukett",
    "blombuketterna": "blombukett",
    "blombuketternas": "blombukett",
    "blombuketters": "blombukett",
    "blombuketts": "blombukett",
    "blomdoften": "blomdoft",
    "blomdoftens": "blomdoft",
    "blomdofter": "blomdoft",
    "blomdofterna": "blomdoft",
    "blomdofternas": "blomdoft",
    "blomdofters": "blomdoft",
    "blomdofts": "blomdoft",
    "blomfaten": "blomfat",
    "blomfatens": "blomfat",
    "blomfatet": "blomfat",
    "blomfatets": "blomfat",
    "blomfats": "blomfat",
    "blomfjällen": "blomfjäll",
    "blomfjällens": "blomfjäll",
    "blomfjället": "blomfjäll",
    "blomfjällets": "blomfjäll",
    "blomfjälls": "blomfjäll",
    "blomflockar": "blomflock",
    "blomflockarna": "blomflock",
    "blomflockarnas": "blomflock",
    "blomflockars": "blomflock",
    "blomflocken": "blomflock",
    "blomflockens": "blomflock",
    "blomflocks": "blomflock",
    "blomfoderna": "blomfoder",
    "blomfodernas": "blomfoder",
    "blomfoders": "blomfoder",
    "blomfodren": "blomfoder",
    "blomfodrens": "blomfoder",
    "blomfodret": "blomfoder",
    "blomfodrets": "blomfoder",
    "blomformen": "blomform",
    "blomformens": "blomform",
    "blomformer": "blomform",
    "blomformerna": "blomform",
    "blomformernas": "blomform",
    "blomformers": "blomform",
    "blomforms": "blomform",
    "blomfäst": "blomfäste",
    "blomfästen": "blomfäste",
    "blomfästena": "blomfäste",
    "blomfästenas": "blomfäste",
    "blomfästens": "blomfäste",
    "blomfästes": "blomfäste",
    "blomfästet": "blomfäste",
    "blomfästets": "blomfäste",
    "blomholkar": "blomholk",
    "blomholkarna": "blomholk",
    "blomholkarnas": "blomholk",
    "blomholkars": "blomholk",
    "blomholken": "blomholk",
    "blomholkens": "blomholk",
    "blomholks": "blomholk",
    "blomhuvuden": "blomhuvud",
    "blomhuvudena": "blomhuvud",
    "blomhuvudenas": "blomhuvud",
    "blomhuvudens": "blomhuvud",
    "blomhuvudet": "blomhuvud",
    "blomhuvudets": "blomhuvud",
    "blomhuvuds": "blomhuvud",
    "blomhyllen": "blomhylle",
    "blomhyllena": "blomhylle",
    "blomhyllenas": "blomhylle",
    "blomhyllens": "blomhylle",
    "blomhylles": "blomhylle",
    "blomhyllet": "blomhylle",
    "blomhyllets": "blomhylle",
    "blomhylls": "blomhylle",
    "blomhängen": "blomhänge",
    "blomhängena": "blomhänge",
    "blomhängenas": "blomhänge",
    "blomhängens": "blomhänge",
    "blomhänges": "blomhänge",
    "blomhänget": "blomhänge",
    "blomhängets": "blomhänge",
    "blomhängs": "blomhänge",
    "blomhölsterna": "blomhölster",
    "blomhölsternas": "blomhölster",
    "blomhölsters": "blomhölster",
    "blomhölstren": "blomhölster",
    "blomhölstrens": "blomhölster",
    "blomhölstret": "blomhölster",
    "blomhölstrets": "blomhölster",
    "blomjorden": "blomjord",
    "blomjordens": "blomjord",
    "blomjords": "blomjord",
    "blomkalkar": "blomkalk",
    "blomkalkarna": "blomkalk",
    "blomkalkarnas": "blomkalk",
    "blomkalkars": "blomkalk",
    "blomkalken": "blomkalk",
    "blomkalkens": "blomkalk",
    "blomkalks": "blomkalk",
    "blomklas": "blomklase",
    "blomklasar": "blomklase",
    "blomklasarna": "blomklase",
    "blomklasarnas": "blomklase",
    "blomklasars": "blomklase",
    "blomklasen": "blomklase",
    "blomklasens": "blomklase",
    "blomklases": "blomklase",
    "blomklädda": "blomklädd",
    "blomkläddare": "blomklädd",
    "blomkläddares": "blomklädd",
    "blomkläddas": "blomklädd",
    "blomkläddast": "blomklädd",
    "blomkläddaste": "blomklädd",
    "blomkläddastes": "blomklädd",
    "blomkläddasts": "blomklädd",
    "blomklädde": "blomklädd",
    "blomkläddes": "blomklädd",
    "blomklädds": "blomklädd",
    "blomklätt": "blomklädd",
    "blomklätts": "blomklädd",
    "blomknipp": "blomknippe",
    "blomknippen": "blomknippe",
    "blomknippena": "blomknippe",
    "blomknippenas": "blomknippe",
    "blomknippens": "blomknippe",
    "blomknippes": "blomknippe",
    "blomknippet": "blomknippe",
    "blomknippets": "blomknippe",
    "blomknipps": "blomknippe",
    "blomknoppar": "blomknopp",
    "blomknopparna": "blomknopp",
    "blomknopparnas": "blomknopp",
    "blomknoppars": "blomknopp",
    "blomknoppen": "blomknopp",
    "blomknoppens": "blomknopp",
    "blomknopps": "blomknopp",
    "blomkolvar": "blomkolv",
    "blomkolvarna": "blomkolv",
    "blomkolvarnas": "blomkolv",
    "blomkolvars": "blomkolv",
    "blomkolven": "blomkolv",
    "blomkolvens": "blomkolv",
    "blomkolvs": "blomkolv",
    "blomkorgar": "blomkorg",
    "blomkorgarna": "blomkorg",
    "blomkorgarnas": "blomkorg",
    "blomkorgars": "blomkorg",
    "blomkorgen": "blomkorg",
    "blomkorgens": "blomkorg",
    "blomkorgs": "blomkorg",
    "blomkransar": "blomkrans",
    "blomkransarna": "blomkrans",
    "blomkransarnas": "blomkrans",
    "blomkransars": "blomkrans",
    "blomkransen": "blomkrans",
    "blomkransens": "blomkrans",
    "blomkron": "blomkrona",
    "blomkronan": "blomkrona",
    "blomkronans": "blomkrona",
    "blomkronas": "blomkrona",
    "blomkrone": "blomkrona",
    "blomkronor": "blomkrona",
    "blomkronorna": "blomkrona",
    "blomkronornas": "blomkrona",
    "blomkronors": "blomkrona",
    "blomkrons": "blomkrona",
    "blomkruk": "blomkruka",
    "blomkrukan": "blomkruka",
    "blomkrukans": "blomkruka",
    "blomkrukas": "blomkruka",
    "blomkruke": "blomkruka",
    "blomkrukor": "blomkruka",
    "blomkrukorna": "blomkruka",
    "blomkrukornas": "blomkruka",
    "blomkrukors": "blomkruka",
    "blomkruks": "blomkruka",
    "blomkvastar": "blomkvast",
    "blomkvastarna": "blomkvast",
    "blomkvastarnas": "blomkvast",
    "blomkvastars": "blomkvast",
    "blomkvasten": "blomkvast",
    "blomkvastens": "blomkvast",
    "blomkvasts": "blomkvast",
    "blomkäppar": "blomkäpp",
    "blomkäpparna": "blomkäpp",
    "blomkäpparnas": "blomkäpp",
    "blomkäppars": "blomkäpp",
    "blomkäppen": "blomkäpp",
    "blomkäppens": "blomkäpp",
    "blomkäpps": "blomkäpp",
    "blomkålen": "blomkål",
    "blomkålens": "blomkål",
    "blomkåls": "blomkål",
    "blomkålshuvuden": "blomkålshuvud",
    "blomkålshuvudena": "blomkålshuvud",
    "blomkålshuvudenas": "blomkålshuvud",
    "blomkålshuvudens": "blomkålshuvud",
    "blomkålshuvudet": "blomkålshuvud",
    "blomkålshuvudets": "blomkålshuvud",
    "blomkålshuvuds": "blomkålshuvud",
    "blomkålssvampar": "blomkålssvamp",
    "blomkålssvamparna": "blomkålssvamp",
    "blomkålssvamparnas": "blomkålssvamp",
    "blomkålssvampars": "blomkålssvamp",
    "blomkålssvampen": "blomkålssvamp",
    "blomkålssvampens": "blomkålssvamp",
    "blomkålssvamps": "blomkålssvamp",
    "blomkålsöras": "blomkålsöra",
    "blomkålsörat": "blomkålsöra",
    "blomkålsörats": "blomkålsöra",
    "blomkålsöron": "blomkålsöra",
    "blomkålsöronen": "blomkålsöra",
    "blomkålsöronens": "blomkålsöra",
    "blomkålsörons": "blomkålsöra",
    "blommade": "blomma",
    "blommades": "blomma",
    "blomman": "blomma",
    "blommande": "blomma",
    "blommanden": "blommande",
    "blommandena": "blommande",
    "blommandenas": "blommande",
    "blommandens": "blommande",
    "blommandes": "blommande",
    "blommandet": "blommande",
    "blommandets": "blommande",
    "blommans": "blomma",
    "blommar": "blomma",
    "blommas": "blomma",
    "blommat": "blomma",
    "blommats": "blomma",
    "blomme": "blomma",
    "blommen": "blom",
    "blommens": "blom",
    "blommerade": "blommerad",
    "blommerades": "blommerad",
    "blommerads": "blommerad",
    "blommerat": "blommerad",
    "blommerats": "blommerad",
    "blommiga": "blommig",
    "blommigare": "blommig",
    "blommigares": "blommig",
    "blommigas": "blommig",
    "blommigast": "blommig",
    "blommigaste": "blommig",
    "blommigastes": "blommig",
    "blommigasts": "blommig",
    "blommige": "blommig",
    "blommiges": "blommig",
    "blommigheten": "blommighet",
    "blommighetens": "blommighet",
    "blommigheter": "blommighet",
    "blommigheterna": "blommighet",
    "blommigheternas": "blommighet",
    "blommigheters": "blommighet",
    "blommighets": "blommighet",
    "blommigs": "blommig",
    "blommigt": "blommig",
    "blommigts": "blommig",
    "blommograferad": "blommografera",
    "blommograferade": "blommografera",
    "blommograferades": "blommografera",
    "blommograferads": "blommografera",
    "blommograferande": "blommografera",
    "blommograferanden": "blommograferande",
    "blommograferandena": "blommograferande",
    "blommograferandenas": "blommograferande",
    "blommograferandens": "blommograferande",
    "blommograferandes": "blommograferande",
    "blommograferandet": "blommograferande",
    "blommograferandets": "blommograferande",
    "blommograferar": "blommografera",
    "blommograferas": "blommografera",
    "blommograferat": "blommografera",
    "blommograferats": "blommografera",
    "blommograferbara": "blommograferbar",
    "blommograferbarare": "blommograferbar",
    "blommograferbarares": "blommograferbar",
    "blommograferbaras": "blommograferbar",
    "blommograferbarast": "blommograferbar",
    "blommograferbaraste": "blommograferbar",
    "blommograferbarastes": "blommograferbar",
    "blommograferbarasts": "blommograferbar",
    "blommograferbare": "blommograferbar",
    "blommograferbares": "blommograferbar",
    "blommograferbarheten": "blommograferbarhet",
    "blommograferbarhetens": "blommograferbarhet",
    "blommograferbarhets": "blommograferbarhet",
    "blommograferbars": "blommograferbar",
    "blommograferbart": "blommograferbar",
    "blommograferbarts": "blommograferbar",
    "blommograferingar": "blommografering",
    "blommograferingarna": "blommografering",
    "blommograferingarnas": "blommografering",
    "blommograferingars": "blommografering",
    "blommograferingen": "blommografering",
    "blommograferingens": "blommografering",
    "blommograferings": "blommografering",
    "blommogrammen": "blommogram",
    "blommogrammens": "blommogram",
    "blommogrammet": "blommogram",
    "blommogrammets": "blommogram",
    "blommograms": "blommogram",
    "blommor": "blomma",
    "blommorna": "blomma",
    "blommornas": "blomma",
    "blommors": "blomma",
    "blommönsterna": "blommönster",
    "blommönsternas": "blommönster",
    "blommönsters": "blommönster",
    "blommönstren": "blommönster",
    "blommönstrens": "blommönster",
    "blommönstret": "blommönster",
    "blommönstrets": "blommönster",
    "blomningar": "blomning",
    "blomningarna": "blomning",
    "blomningarnas": "blomning",
    "blomningars": "blomning",
    "blomningen": "blomning",
    "blomningens": "blomning",
    "blomnings": "blomning",
    "blomningstiden": "blomningstid",
    "blomningstidens": "blomningstid",
    "blomningstider": "blomningstid",
    "blomningstiderna": "blomningstid",
    "blomningstidernas": "blomningstid",
    "blomningstiders": "blomningstid",
    "blomningstids": "blomningstid",
    "blomplant": "blomplanta",
    "blomplantan": "blomplanta",
    "blomplantans": "blomplanta",
    "blomplantas": "blomplanta",
    "blomplante": "blomplanta",
    "blomplantor": "blomplanta",
    "blomplantorna": "blomplanta",
    "blomplantornas": "blomplanta",
    "blomplantors": "blomplanta",
    "blomplants": "blomplanta",
    "bloms": "blomma",
    "blomskaften": "blomskaft",
    "blomskaftens": "blomskaft",
    "blomskaftet": "blomskaft",
    "blomskaftets": "blomskaft",
    "blomskafts": "blomskaft",
    "blomsten": "blomst",
    "blomstens": "blomst",
    "blomster": "blomstra",
    "blomsteraffären": "blomsteraffär",
    "blomsteraffärens": "blomsteraffär",
    "blomsteraffärer": "blomsteraffär",
    "blomsteraffärerna": "blomsteraffär",
    "blomsteraffärernas": "blomsteraffär",
    "blomsteraffärers": "blomsteraffär",
    "blomsteraffärs": "blomsteraffär",
    "blomsterborden": "blomsterbord",
    "blomsterbordens": "blomsterbord",
    "blomsterbordet": "blomsterbord",
    "blomsterbordets": "blomsterbord",
    "blomsterbords": "blomsterbord",
    "blomsterbäddar": "blomsterbädd",
    "blomsterbäddarna": "blomsterbädd",
    "blomsterbäddarnas": "blomsterbädd",
    "blomsterbäddars": "blomsterbädd",
    "blomsterbädden": "blomsterbädd",
    "blomsterbäddens": "blomsterbädd",
    "blomsterbädds": "blomsterbädd",
    "blomsterförmedlingar": "blomsterförmedling",
    "blomsterförmedlingarna": "blomsterförmedling",
    "blomsterförmedlingarnas": "blomsterförmedling",
    "blomsterförmedlingars": "blomsterförmedling",
    "blomsterförmedlingen": "blomsterförmedling",
    "blomsterförmedlingens": "blomsterförmedling",
    "blomsterförmedlings": "blomsterförmedling",
    "blomsterhandeln": "blomsterhandel",
    "blomsterhandelns": "blomsterhandel",
    "blomsterhandels": "blomsterhandel",
    "blomsterhandlar": "blomsterhandlare",
    "blomsterhandlaren": "blomsterhandlare",
    "blomsterhandlarens": "blomsterhandlare",
    "blomsterhandlares": "blomsterhandlare",
    "blomsterhandlarna": "blomsterhandlare",
    "blomsterhandlarnas": "blomsterhandlare",
    "blomsterhandlars": "blomsterhandel",
    "blomsterhonungen": "blomsterhonung",
    "blomsterhonungens": "blomsterhonung",
    "blomsterhonungs": "blomsterhonung",
    "blomsterklädda": "blomsterklädd",
    "blomsterkläddare": "blomsterklädd",
    "blomsterkläddares": "blomsterklädd",
    "blomsterkläddas": "blomsterklädd",
    "blomsterkläddast": "blomsterklädd",
    "blomsterkläddaste": "blomsterklädd",
    "blomsterkläddastes": "blomsterklädd",
    "blomsterkläddasts": "blomsterklädd",
    "blomsterklädde": "blomsterklädd",
    "blomsterkläddes": "blomsterklädd",
    "blomsterklädds": "blomsterklädd",
    "blomsterklätt": "blomsterklädd",
    "blomsterklätts": "blomsterklädd",
    "blomsterkvastar": "blomsterkvast",
    "blomsterkvastarna": "blomsterkvast",
    "blomsterkvastarnas": "blomsterkvast",
    "blomsterkvastars": "blomsterkvast",
    "blomsterkvasten": "blomsterkvast",
    "blomsterkvastens": "blomsterkvast",
    "blomsterkvasts": "blomsterkvast",
    "blomsterlökar": "blomsterlök",
    "blomsterlökarna": "blomsterlök",
    "blomsterlökarnas": "blomsterlök",
    "blomsterlökars": "blomsterlök",
    "blomsterlöken": "blomsterlök",
    "blomsterlökens": "blomsterlök",
    "blomsterlöks": "blomsterlök",
    "blomstermånaden": "blomstermånad",
    "blomstermånadens": "blomstermånad",
    "blomstermånader": "blomstermånad",
    "blomstermånaderna": "blomstermånad",
    "blomstermånadernas": "blomstermånad",
    "blomstermånaders": "blomstermånad",
    "blomstermånads": "blomstermånad",
    "blomsterna": "blomster",
    "blomsternas": "blomster",
    "blomsters": "blomster",
    "blomstersmyck": "blomstersmycka",
    "blomstersmyckad": "blomstersmycka",
    "blomstersmyckade": "blomstersmycka",
    "blomstersmyckades": "blomstersmycka",
    "blomstersmyckads": "blomstersmycka",
    "blomstersmyckande": "blomstersmycka",
    "blomstersmyckandes": "blomstersmycka",
    "blomstersmyckar": "blomstersmycka",
    "blomstersmyckas": "blomstersmycka",
    "blomstersmyckat": "blomstersmycka",
    "blomstersmyckats": "blomstersmycka",
    "blomsterspråket": "blomsterspråk",
    "blomsterspråkets": "blomsterspråk",
    "blomsterspråks": "blomsterspråk",
    "blomstertiden": "blomstertid",
    "blomstertidens": "blomstertid",
    "blomstertider": "blomstertid",
    "blomstertiderna": "blomstertid",
    "blomstertidernas": "blomstertid",
    "blomstertiders": "blomstertid",
    "blomstertids": "blomstertid",
    "blomsterträdgårdar": "blomsterträdgård",
    "blomsterträdgårdarna": "blomsterträdgård",
    "blomsterträdgårdarnas": "blomsterträdgård",
    "blomsterträdgårdars": "blomsterträdgård",
    "blomsterträdgården": "blomsterträdgård",
    "blomsterträdgårdens": "blomsterträdgård",
    "blomsterträdgårds": "blomsterträdgård",
    "blomsteruppsatsen": "blomsteruppsats",
    "blomsteruppsatsens": "blomsteruppsats",
    "blomsteruppsatser": "blomsteruppsats",
    "blomsteruppsatserna": "blomsteruppsats",
    "blomsteruppsatsernas": "blomsteruppsats",
    "blomsteruppsatsers": "blomsteruppsats",
    "blomstervasen": "blomstervas",
    "blomstervasens": "blomstervas",
    "blomstervaser": "blomstervas",
    "blomstervaserna": "blomstervas",
    "blomstervasernas": "blomstervas",
    "blomstervasers": "blomstervas",
    "blomsterängar": "blomsteräng",
    "blomsterängarna": "blomsteräng",
    "blomsterängarnas": "blomsteräng",
    "blomsterängars": "blomsteräng",
    "blomsterängen": "blomsteräng",
    "blomsterängens": "blomsteräng",
    "blomsterängs": "blomsteräng",
    "blomstjälkar": "blomstjälk",
    "blomstjälkarna": "blomstjälk",
    "blomstjälkarnas": "blomstjälk",
    "blomstjälkars": "blomstjälk",
    "blomstjälken": "blomstjälk",
    "blomstjälkens": "blomstjälk",
    "blomstjälks": "blomstjälk",
    "blomstoftet": "blomstoft",
    "blomstoftets": "blomstoft",
    "blomstofts": "blomstoft",
    "blomstrade": "blomstra",
    "blomstrades": "blomstra",
    "blomstrande": "blomstra",
    "blomstranden": "blomstrande",
    "blomstrandena": "blomstrande",
    "blomstrandenas": "blomstrande",
    "blomstrandens": "blomstrande",
    "blomstrandes": "blomstrande",
    "blomstrandet": "blomstrande",
    "blomstrandets": "blomstrande",
    "blomstrar": "blomstra",
    "blomstras": "blomstra",
    "blomstrat": "blomstra",
    "blomstrats": "blomstra",
    "blomstren": "blomster",
    "blomstrens": "blomster",
    "blomstret": "blomster",
    "blomstrets": "blomster",
    "blomstringar": "blomstring",
    "blomstringarna": "blomstring",
    "blomstringarnas": "blomstring",
    "blomstringars": "blomstring",
    "blomstringen": "blomstring",
    "blomstringens": "blomstring",
    "blomstrings": "blomstring",
    "blomstringstiden": "blomstringstid",
    "blomstringstidens": "blomstringstid",
    "blomstringstider": "blomstringstid",
    "blomstringstiderna": "blomstringstid",
    "blomstringstidernas": "blomstringstid",
    "blomstringstiders": "blomstringstid",
    "blomstringstids": "blomstringstid",
    "blomsts": "blomst",
    "blomställningar": "blomställning",
    "blomställningarna": "blomställning",
    "blomställningarnas": "blomställning",
    "blomställningars": "blomställning",
    "blomställningen": "blomställning",
    "blomställningens": "blomställning",
    "blomställnings": "blomställning",
    "blomvasen": "blomvas",
    "blomvasens": "blomvas",
    "blomvaser": "blomvas",
    "blomvaserna": "blomvas",
    "blomvasernas": "blomvas",
    "blomvasers": "blomvas",
    "blomvassen": "blomvass",
    "blomvassens": "blomvass",
    "blomväxten": "blomväxt",
    "blomväxtens": "blomväxt",
    "blomväxter": "blomväxt",
    "blomväxterna": "blomväxt",
    "blomväxternas": "blomväxt",
    "blomväxters": "blomväxt",
    "blomväxts": "blomväxt",
    "blonda": "blond",
    "blondare": "blond",
    "blondares": "blond",
    "blondas": "blond",
    "blondast": "blond",
    "blondaste": "blond",
    "blondastes": "blond",
    "blondasts": "blond",
    "blonde": "blond",
    "blonden": "blond",
    "blondens": "blond",
    "blonder": "blond",
    "blonderad": "blondera",
    "blonderade": "blondera",
    "blonderades": "blondera",
    "blonderads": "blondera",
    "blonderande": "blondera",
    "blonderanden": "blonderande",
    "blonderandena": "blonderande",
    "blonderandenas": "blonderande",
    "blonderandens": "blonderande",
    "blonderandes": "blonderande",
    "blonderandet": "blonderande",
    "blonderandets": "blonderande",
    "blonderar": "blondera",
    "blonderas": "blondera",
    "blonderat": "blondera",
    "blonderats": "blondera",
    "blonderbara": "blonderbar",
    "blonderbarare": "blonderbar",
    "blonderbarares": "blonderbar",
    "blonderbaras": "blonderbar",
    "blonderbarast": "blonderbar",
    "blonderbaraste": "blonderbar",
    "blonderbarastes": "blonderbar",
    "blonderbarasts": "blonderbar",
    "blonderbare": "blonderbar",
    "blonderbares": "blonderbar",
    "blonderbarheten": "blonderbarhet",
    "blonderbarhetens": "blonderbarhet",
    "blonderbarhets": "blonderbarhet",
    "blonderbars": "blonderbar",
    "blonderbart": "blonderbar",
    "blonderbarts": "blonderbar",
    "blonderingar": "blondering",
    "blonderingarna": "blondering",
    "blonderingarnas": "blondering",
    "blonderingars": "blondering",
    "blonderingen": "blondering",
    "blonderingens": "blondering",
    "blonderings": "blondering",
    "blonderna": "blond",
    "blondernas": "blond",
    "blonders": "blond",
    "blondes": "blond",
    "blondheten": "blondhet",
    "blondhetens": "blondhet",
    "blondhets": "blondhet",
    "blondinen": "blondin",
    "blondinens": "blondin",
    "blondiner": "blondin",
    "blondinerna": "blondin",
    "blondinernas": "blondin",
    "blondiners": "blondin",
    "blondins": "blondin",
    "blonds": "blond",
    "blont": "blond",
    "blonts": "blond",
    "bloss": "blossa",
    "blossade": "blossa",
    "blossades": "blossa",
    "blossande": "blossa",
    "blossanden": "blossande",
    "blossandena": "blossande",
    "blossandenas": "blossande",
    "blossandens": "blossande",
    "blossandes": "blossande",
    "blossandet": "blossande",
    "blossandets": "blossande",
    "blossar": "blossa",
    "blossas": "blossa",
    "blossat": "blossa",
    "blossats": "blossa",
    "blossen": "bloss",
    "blossens": "bloss",
    "blosset": "bloss",
    "blossets": "bloss",
    "blot": "blota",
    "blotade": "blota",
    "blotades": "blota",
    "blotande": "blota",
    "blotanden": "blotande",
    "blotandena": "blotande",
    "blotandenas": "blotande",
    "blotandens": "blotande",
    "blotandes": "blotande",
    "blotandet": "blotande",
    "blotandets": "blotande",
    "blotar": "blota",
    "blotas": "blota",
    "blotat": "blota",
    "blotats": "blota",
    "bloten": "blot",
    "blotens": "blot",
    "blotet": "blot",
    "blotets": "blot",
    "blots": "blot",
    "blott": "blotta",
    "blotta": "blott",
    "blottad": "blotta",
    "blottade": "blotta",
    "blottades": "blotta",
    "blottads": "blotta",
    "blottan": "blotta",
    "blottande": "blotta",
    "blottanden": "blottande",
    "blottandena": "blottande",
    "blottandenas": "blottande",
    "blottandens": "blottande",
    "blottandes": "blottande",
    "blottandet": "blottande",
    "blottandets": "blottande",
    "blottans": "blotta",
    "blottar": "blottare",
    "blottaren": "blottare",
    "blottarens": "blottare",
    "blottares": "blottare",
    "blottarna": "blottare",
    "blottarnas": "blottare",
    "blottas": "blotta",
    "blottat": "blotta",
    "blottats": "blotta",
    "blotte": "blotta",
    "blottes": "blott",
    "blottla": "blottlägga",
    "blottlade": "blottlägga",
    "blottlades": "blottlägga",
    "blottlagd": "blottlägga",
    "blottlagda": "blottlägga",
    "blottlagdas": "blottlägga",
    "blottlagde": "blottlägga",
    "blottlagdes": "blottlägga",
    "blottlagds": "blottlägga",
    "blottlagt": "blottlägga",
    "blottlagts": "blottlägga",
    "blottlas": "blottlägga",
    "blottlägg": "blottlägga",
    "blottläggande": "blottlägga",
    "blottlägganden": "blottläggande",
    "blottläggandena": "blottläggande",
    "blottläggandenas": "blottläggande",
    "blottläggandens": "blottläggande",
    "blottläggandes": "blottläggande",
    "blottläggandet": "blottläggande",
    "blottläggandets": "blottläggande",
    "blottläggas": "blottlägga",
    "blottlägger": "blottlägga",
    "blottlägges": "blottlägga",
    "blottläggs": "blottlägga",
    "blottor": "blotta",
    "blottorna": "blotta",
    "blottornas": "blotta",
    "blottors": "blotta",
    "blotts": "blotta",
    "blottställda": "blottställd",
    "blottställdare": "blottställd",
    "blottställdares": "blottställd",
    "blottställdas": "blottställd",
    "blottställdast": "blottställd",
    "blottställdaste": "blottställd",
    "blottställdastes": "blottställd",
    "blottställdasts": "blottställd",
    "blottställde": "blottställd",
    "blottställdes": "blottställd",
    "blottställdheten": "blottställdhet",
    "blottställdhetens": "blottställdhet",
    "blottställdhets": "blottställdhet",
    "blottställds": "blottställd",
    "blottställt": "blottställd",
    "blottställts": "blottställd",
    "bludder": "bluddra",
    "bludders": "bludder",
    "bluddrade": "bluddra",
    "bluddrades": "bluddra",
    "bluddrande": "bluddra",
    "bluddranden": "bluddrande",
    "bluddrandena": "bluddrande",
    "bluddrandenas": "bluddrande",
    "bluddrandens": "bluddrande",
    "bluddrandes": "bluddrande",
    "bluddrandet": "bluddrande",
    "bluddrandets": "bluddrande",
    "bluddrar": "bluddra",
    "bluddras": "bluddra",
    "bluddrat": "bluddra",
    "bluddrats": "bluddra",
    "bluddret": "bludder",
    "bluddrets": "bludder",
    "bluesen": "blues",
    "bluesens": "blues",
    "bluff": "bluffa",
    "bluffad": "bluffa",
    "bluffade": "bluffa",
    "bluffades": "bluffa",
    "bluffads": "bluffa",
    "bluffande": "bluffa",
    "bluffanden": "bluffande",
    "bluffandena": "bluffande",
    "bluffandenas": "bluffande",
    "bluffandens": "bluffande",
    "bluffandes": "bluffande",
    "bluffandet": "bluffande",
    "bluffandets": "bluffande",
    "bluffar": "bluffa",
    "bluffarna": "bluff",
    "bluffarnas": "bluff",
    "bluffars": "bluff",
    "bluffas": "bluffa",
    "bluffat": "bluffa",
    "bluffats": "bluffa",
    "bluffbyggen": "bluffbygge",
    "bluffbyggena": "bluffbygge",
    "bluffbyggenas": "bluffbygge",
    "bluffbyggens": "bluffbygge",
    "bluffbygges": "bluffbygge",
    "bluffbygget": "bluffbygge",
    "bluffbyggets": "bluffbygge",
    "bluffen": "bluff",
    "bluffens": "bluff",
    "bluffmakar": "bluffmakare",
    "bluffmakaren": "bluffmakare",
    "bluffmakarens": "bluffmakare",
    "bluffmakares": "bluffmakare",
    "bluffmakarna": "bluffmakare",
    "bluffmakarnas": "bluffmakare",
    "bluffs": "bluff",
    "blund": "blunda",
    "blundade": "blunda",
    "blundades": "blunda",
    "blundande": "blunda",
    "blundanden": "blundande",
    "blundandena": "blundande",
    "blundandenas": "blundande",
    "blundandens": "blundande",
    "blundandes": "blundande",
    "blundandet": "blundande",
    "blundandets": "blundande",
    "blundar": "blunda",
    "blundas": "blunda",
    "blundat": "blunda",
    "blundats": "blunda",
    "blunddock": "blunddocka",
    "blunddockan": "blunddocka",
    "blunddockans": "blunddocka",
    "blunddockas": "blunddocka",
    "blunddocke": "blunddocka",
    "blunddockor": "blunddocka",
    "blunddockorna": "blunddocka",
    "blunddockornas": "blunddocka",
    "blunddockors": "blunddocka",
    "blunddocks": "blunddocka",
    "blunden": "blund",
    "blundens": "blund",
    "blundern": "blunder",
    "blunderns": "blunder",
    "blunders": "blunder",
    "blundrar": "blunder",
    "blundrarna": "blunder",
    "blundrarnas": "blunder",
    "blundrars": "blunder",
    "blunds": "blund",
    "blusar": "blus",
    "blusarna": "blus",
    "blusarnas": "blus",
    "blusars": "blus",
    "blusen": "blus",
    "blusens": "blus",
    "bly": "blya",
    "blyacetaten": "blyacetat",
    "blyacetatens": "blyacetat",
    "blyacetater": "blyacetat",
    "blyacetaterna": "blyacetat",
    "blyacetaternas": "blyacetat",
    "blyacetaters": "blyacetat",
    "blyacetatet": "blyacetat",
    "blyacetatets": "blyacetat",
    "blyacetats": "blyacetat",
    "blyackumulatorer": "blyackumulator",
    "blyackumulatorerna": "blyackumulator",
    "blyackumulatorernas": "blyackumulator",
    "blyackumulatorers": "blyackumulator",
    "blyackumulatorn": "blyackumulator",
    "blyackumulatorns": "blyackumulator",
    "blyackumulators": "blyackumulator",
    "blyad": "blya",
    "blyade": "blya",
    "blyades": "blya",
    "blyads": "blya",
    "blyande": "blya",
    "blyanden": "blyande",
    "blyandena": "blyande",
    "blyandenas": "blyande",
    "blyandens": "blyande",
    "blyandes": "blyande",
    "blyandet": "blyande",
    "blyandets": "blyande",
    "blyar": "blya",
    "blyas": "blya",
    "blyask": "blyaska",
    "blyaskan": "blyaska",
    "blyaskans": "blyaska",
    "blyaskas": "blyaska",
    "blyat": "blya",
    "blyats": "blya",
    "blyaziden": "blyazid",
    "blyazidens": "blyazid",
    "blyazider": "blyazid",
    "blyaziderna": "blyazid",
    "blyazidernas": "blyazid",
    "blyaziders": "blyazid",
    "blyazids": "blyazid",
    "blybatterier": "blybatteri",
    "blybatterierna": "blybatteri",
    "blybatteriernas": "blybatteri",
    "blybatteriers": "blybatteri",
    "blybatteriet": "blybatteri",
    "blybatteriets": "blybatteri",
    "blybatteris": "blybatteri",
    "blybatterit": "blybatteri",
    "blybatterits": "blybatteri",
    "blyblom": "blyblomma",
    "blyblomman": "blyblomma",
    "blyblommans": "blyblomma",
    "blyblommas": "blyblomma",
    "blyblomme": "blyblomma",
    "blyblommor": "blyblomma",
    "blyblommorna": "blyblomma",
    "blyblommornas": "blyblomma",
    "blyblommors": "blyblomma",
    "blybloms": "blyblomma",
    "blydaggar": "blydagg",
    "blydaggarna": "blydagg",
    "blydaggarnas": "blydagg",
    "blydaggars": "blydagg",
    "blydaggen": "blydagg",
    "blydaggens": "blydagg",
    "blydaggs": "blydagg",
    "blyertsar": "blyerts",
    "blyertsarna": "blyerts",
    "blyertsarnas": "blyerts",
    "blyertsars": "blyerts",
    "blyertsen": "blyerts",
    "blyertsens": "blyerts",
    "blyertsgråa": "blyertsgrå",
    "blyertsgråare": "blyertsgrå",
    "blyertsgråares": "blyertsgrå",
    "blyertsgråas": "blyertsgrå",
    "blyertsgråast": "blyertsgrå",
    "blyertsgråaste": "blyertsgrå",
    "blyertsgråastes": "blyertsgrå",
    "blyertsgråasts": "blyertsgrå",
    "blyertsgråe": "blyertsgrå",
    "blyertsgråes": "blyertsgrå",
    "blyertsgrås": "blyertsgrå",
    "blyertsgrått": "blyertsgrå",
    "blyertsgråtts": "blyertsgrå",
    "blyertspenn": "blyertspenna",
    "blyertspennan": "blyertspenna",
    "blyertspennans": "blyertspenna",
    "blyertspennas": "blyertspenna",
    "blyertspenne": "blyertspenna",
    "blyertspennor": "blyertspenna",
    "blyertspennorna": "blyertspenna",
    "blyertspennornas": "blyertspenna",
    "blyertspennors": "blyertspenna",
    "blyertspenns": "blyertspenna",
    "blyet": "bly",
    "blyets": "bly",
    "blyfolien": "blyfolie",
    "blyfoliens": "blyfolie",
    "blyfolier": "blyfolie",
    "blyfolierna": "blyfolie",
    "blyfoliernas": "blyfolie",
    "blyfoliers": "blyfolie",
    "blyfolies": "blyfolie",
    "blyfoliet": "blyfolie",
    "blyfoliets": "blyfolie",
    "blyfria": "blyfri",
    "blyfriare": "blyfri",
    "blyfriares": "blyfri",
    "blyfrias": "blyfri",
    "blyfriast": "blyfri",
    "blyfriaste": "blyfri",
    "blyfriastes": "blyfri",
    "blyfriasts": "blyfri",
    "blyfrie": "blyfri",
    "blyfries": "blyfri",
    "blyfris": "blyfri",
    "blyfritt": "blyfri",
    "blyfritts": "blyfri",
    "blyfärgen": "blyfärg",
    "blyfärgens": "blyfärg",
    "blyfärger": "blyfärg",
    "blyfärgerna": "blyfärg",
    "blyfärgernas": "blyfärg",
    "blyfärgers": "blyfärg",
    "blyfärgs": "blyfärg",
    "blyföreningar": "blyförening",
    "blyföreningarna": "blyförening",
    "blyföreningarnas": "blyförening",
    "blyföreningars": "blyförening",
    "blyföreningen": "blyförening",
    "blyföreningens": "blyförening",
    "blyförenings": "blyförening",
    "blyförgiftade": "blyförgiftad",
    "blyförgiftades": "blyförgiftad",
    "blyförgiftads": "blyförgiftad",
    "blyförgiftat": "blyförgiftad",
    "blyförgiftats": "blyförgiftad",
    "blyförgiftningar": "blyförgiftning",
    "blyförgiftningarna": "blyförgiftning",
    "blyförgiftningarnas": "blyförgiftning",
    "blyförgiftningars": "blyförgiftning",
    "blyförgiftningen": "blyförgiftning",
    "blyförgiftningens": "blyförgiftning",
    "blyförgiftnings": "blyförgiftning",
    "blyga": "blyg",
    "blygare": "blyg",
    "blygares": "blyg",
    "blygas": "blyg",
    "blygast": "blyg",
    "blygaste": "blyg",
    "blygastes": "blyg",
    "blygasts": "blyg",
    "blygdbenen": "blygdben",
    "blygdbenens": "blygdben",
    "blygdbenet": "blygdben",
    "blygdbenets": "blygdben",
    "blygdbens": "blygdben",
    "blygden": "blygd",
    "blygdens": "blygd",
    "blygdes": "blygas",
    "blygdläppar": "blygdläpp",
    "blygdläpparna": "blygdläpp",
    "blygdläpparnas": "blygdläpp",
    "blygdläppars": "blygdläpp",
    "blygdläppen": "blygdläpp",
    "blygdläppens": "blygdläpp",
    "blygdläpps": "blygdläpp",
    "blygds": "blygd",
    "blyge": "blyg",
    "blyges": "blygas",
    "blygheten": "blyghet",
    "blyghetens": "blyghet",
    "blygheter": "blyghet",
    "blygheterna": "blyghet",
    "blygheternas": "blyghet",
    "blygheters": "blyghet",
    "blyghets": "blyghet",
    "blyglansen": "blyglans",
    "blyglansens": "blyglans",
    "blyglaset": "blyglas",
    "blyglasets": "blyglas",
    "blygleten": "blyglete",
    "blygletens": "blyglete",
    "blygletes": "blyglete",
    "blygletet": "blyglete",
    "blygletets": "blyglete",
    "blygråa": "blygrå",
    "blygråare": "blygrå",
    "blygråares": "blygrå",
    "blygråas": "blygrå",
    "blygråast": "blygrå",
    "blygråaste": "blygrå",
    "blygråastes": "blygrå",
    "blygråasts": "blygrå",
    "blygråe": "blygrå",
    "blygråes": "blygrå",
    "blygrås": "blygrå",
    "blygrått": "blygrå",
    "blygråtts": "blygrå",
    "blygs": "blygas",
    "blygsamheten": "blygsamhet",
    "blygsamhetens": "blygsamhet",
    "blygsamheter": "blygsamhet",
    "blygsamheterna": "blygsamhet",
    "blygsamheternas": "blygsamhet",
    "blygsamheters": "blygsamhet",
    "blygsamhets": "blygsamhet",
    "blygsamma": "blygsam",
    "blygsammare": "blygsam",
    "blygsammares": "blygsam",
    "blygsammas": "blygsam",
    "blygsammast": "blygsam",
    "blygsammaste": "blygsam",
    "blygsammastes": "blygsam",
    "blygsammasts": "blygsam",
    "blygsamme": "blygsam",
    "blygsammes": "blygsam",
    "blygsams": "blygsam",
    "blygsamt": "blygsam",
    "blygsamts": "blygsam",
    "blygseln": "blygsel",
    "blygselns": "blygsel",
    "blygsels": "blygsel",
    "blygt": "blyg",
    "blygts": "blygas",
    "blygults": "blygult",
    "blyhalten": "blyhalt",
    "blyhaltens": "blyhalt",
    "blyhalter": "blyhalt",
    "blyhalterna": "blyhalt",
    "blyhalternas": "blyhalt",
    "blyhalters": "blyhalt",
    "blyhaltiga": "blyhaltig",
    "blyhaltigare": "blyhaltig",
    "blyhaltigares": "blyhaltig",
    "blyhaltigas": "blyhaltig",
    "blyhaltigast": "blyhaltig",
    "blyhaltigaste": "blyhaltig",
    "blyhaltigastes": "blyhaltig",
    "blyhaltigasts": "blyhaltig",
    "blyhaltige": "blyhaltig",
    "blyhaltiges": "blyhaltig",
    "blyhaltigs": "blyhaltig",
    "blyhaltigt": "blyhaltig",
    "blyhaltigts": "blyhaltig",
    "blyhalts": "blyhalt",
    "blykul": "blykula",
    "blykulan": "blykula",
    "blykulans": "blykula",
    "blykulas": "blykula",
    "blykule": "blykula",
    "blykulor": "blykula",
    "blykulorna": "blykula",
    "blykulornas": "blykula",
    "blykulors": "blykula",
    "blykuls": "blykula",
    "blykölar": "blyköl",
    "blykölarna": "blyköl",
    "blykölarnas": "blyköl",
    "blykölars": "blyköl",
    "blykölen": "blyköl",
    "blykölens": "blyköl",
    "blyköls": "blyköl",
    "blyloden": "blylod",
    "blylodens": "blylod",
    "blylodet": "blylod",
    "blylodets": "blylod",
    "blylods": "blylod",
    "blymanteln": "blymantel",
    "blymantelns": "blymantel",
    "blymantels": "blymantel",
    "blymantlar": "blymantel",
    "blymantlarna": "blymantel",
    "blymantlarnas": "blymantel",
    "blymantlars": "blymantel",
    "blymönjan": "blymönja",
    "blymönjans": "blymönja",
    "blymönjas": "blymönja",
    "blyoxiden": "blyoxid",
    "blyoxidens": "blyoxid",
    "blyoxider": "blyoxid",
    "blyoxiderna": "blyoxid",
    "blyoxidernas": "blyoxid",
    "blyoxiders": "blyoxid",
    "blyoxids": "blyoxid",
    "blys": "bly",
    "blysalvan": "blysalva",
    "blysalvans": "blysalva",
    "blysalvas": "blysalva",
    "blysockers": "blysocker",
    "blysockret": "blysocker",
    "blysockrets": "blysocker",
    "blyt": "bly",
    "blytetraetylen": "blytetraetyl",
    "blytetraetylens": "blytetraetyl",
    "blytetraetyls": "blytetraetyl",
    "blyts": "bly",
    "blytunga": "blytung",
    "blytungare": "blytung",
    "blytungares": "blytung",
    "blytungas": "blytung",
    "blytungast": "blytung",
    "blytungaste": "blytung",
    "blytungastes": "blytung",
    "blytungasts": "blytung",
    "blytunge": "blytung",
    "blytunges": "blytung",
    "blytungheten": "blytunghet",
    "blytunghetens": "blytunghet",
    "blytunghets": "blytunghet",
    "blytungs": "blytung",
    "blytungt": "blytung",
    "blytungts": "blytung",
    "blytyngden": "blytyngd",
    "blytyngdens": "blytyngd",
    "blytyngder": "blytyngd",
    "blytyngderna": "blytyngd",
    "blytyngdernas": "blytyngd",
    "blytyngders": "blytyngd",
    "blytyngds": "blytyngd",
    "blyvattens": "blyvatten",
    "blyvattnet": "blyvatten",
    "blyvattnets": "blyvatten",
    "blyvitts": "blyvitt",
    "blyättikan": "blyättika",
    "blyättikans": "blyättika",
    "blyättikas": "blyättika",
    "bläck": "bläcka",
    "bläckad": "bläcka",
    "bläckade": "bläcka",
    "bläckades": "bläcka",
    "bläckads": "bläcka",
    "bläckan": "bläcka",
    "bläckande": "bläcka",
    "bläckanden": "bläckande",
    "bläckandena": "bläckande",
    "bläckandenas": "bläckande",
    "bläckandens": "bläckande",
    "bläckandes": "bläckande",
    "bläckandet": "bläckande",
    "bläckandets": "bläckande",
    "bläckans": "bläcka",
    "bläckar": "bläcka",
    "bläckas": "bläcka",
    "bläckat": "bläcka",
    "bläckats": "bläcka",
    "bläckblås": "bläckblåsa",
    "bläckblåsan": "bläckblåsa",
    "bläckblåsans": "bläckblåsa",
    "bläckblåsas": "bläckblåsa",
    "bläckblåse": "bläckblåsa",
    "bläckblåsor": "bläckblåsa",
    "bläckblåsorna": "bläckblåsa",
    "bläckblåsornas": "bläckblåsa",
    "bläckblåsors": "bläckblåsa",
    "bläcke": "bläcka",
    "bläcket": "bläck",
    "bläckets": "bläck",
    "bläckfiskar": "bläckfisk",
    "bläckfiskarna": "bläckfisk",
    "bläckfiskarnas": "bläckfisk",
    "bläckfiskars": "bläckfisk",
    "bläckfisken": "bläckfisk",
    "bläckfiskens": "bläckfisk",
    "bläckfisks": "bläckfisk",
    "bläckhornen": "bläckhorn",
    "bläckhornens": "bläckhorn",
    "bläckhornet": "bläckhorn",
    "bläckhornets": "bläckhorn",
    "bläckhorns": "bläckhorn",
    "bläckkörteln": "bläckkörtel",
    "bläckkörtelns": "bläckkörtel",
    "bläckkörtels": "bläckkörtel",
    "bläckkörtlar": "bläckkörtel",
    "bläckkörtlarna": "bläckkörtel",
    "bläckkörtlarnas": "bläckkörtel",
    "bläckkörtlars": "bläckkörtel",
    "bläckor": "bläcka",
    "bläckorna": "bläcka",
    "bläckornas": "bläcka",
    "bläckors": "bläcka",
    "bläckpenn": "bläckpenna",
    "bläckpennan": "bläckpenna",
    "bläckpennans": "bläckpenna",
    "bläckpennas": "bläckpenna",
    "bläckpenne": "bläckpenna",
    "bläckpennor": "bläckpenna",
    "bläckpennorna": "bläckpenna",
    "bläckpennornas": "bläckpenna",
    "bläckpennors": "bläckpenna",
    "bläckpenns": "bläckpenna",
    "bläckplumpar": "bläckplump",
    "bläckplumparna": "bläckplump",
    "bläckplumparnas": "bläckplump",
    "bläckplumpars": "bläckplump",
    "bläckplumpen": "bläckplump",
    "bläckplumpens": "bläckplump",
    "bläckplumps": "bläckplump",
    "bläckpulvers": "bläckpulver",
    "bläckpulvret": "bläckpulver",
    "bläckpulvrets": "bläckpulver",
    "bläcks": "bläcka",
    "bläcksuddar": "bläcksuddare",
    "bläcksuddaren": "bläcksuddare",
    "bläcksuddarens": "bläcksuddare",
    "bläcksuddares": "bläcksuddare",
    "bläcksuddarna": "bläcksuddare",
    "bläcksuddarnas": "bläcksuddare",
    "bläcksvampar": "bläcksvamp",
    "bläcksvamparna": "bläcksvamp",
    "bläcksvamparnas": "bläcksvamp",
    "bläcksvampars": "bläcksvamp",
    "bläcksvampen": "bläcksvamp",
    "bläcksvampens": "bläcksvamp",
    "bläcksvamps": "bläcksvamp",
    "bläcksäckar": "bläcksäck",
    "bläcksäckarna": "bläcksäck",
    "bläcksäckarnas": "bläcksäck",
    "bläcksäckars": "bläcksäck",
    "bläcksäcken": "bläcksäck",
    "bläcksäckens": "bläcksäck",
    "bläcksäcks": "bläcksäck",
    "bläd": "bläda",
    "blädad": "bläda",
    "blädade": "bläda",
    "blädades": "bläda",
    "blädads": "bläda",
    "blädande": "bläda",
    "blädanden": "blädande",
    "blädandena": "blädande",
    "blädandenas": "blädande",
    "blädandens": "blädande",
    "blädandes": "blädande",
    "blädandet": "blädande",
    "blädandets": "blädande",
    "blädar": "bläda",
    "blädas": "bläda",
    "blädat": "bläda",
    "blädats": "bläda",
    "blädder": "bläddra",
    "blädderblocken": "blädderblock",
    "blädderblockens": "blädderblock",
    "blädderblocket": "blädderblock",
    "blädderblockets": "blädderblock",
    "blädderblocks": "blädderblock",
    "blädderboken": "blädderbok",
    "blädderbokens": "blädderbok",
    "blädderboks": "blädderbok",
    "blädderböcker": "blädderbok",
    "blädderböckerna": "blädderbok",
    "blädderböckernas": "blädderbok",
    "blädderböckers": "blädderbok",
    "bläddr": "bläddra",
    "bläddrad": "bläddra",
    "bläddrade": "bläddra",
    "bläddrades": "bläddra",
    "bläddrads": "bläddra",
    "bläddran": "bläddra",
    "bläddrande": "bläddra",
    "bläddranden": "bläddrande",
    "bläddrandena": "bläddrande",
    "bläddrandenas": "bläddrande",
    "bläddrandens": "bläddrande",
    "bläddrandes": "bläddrande",
    "bläddrandet": "bläddrande",
    "bläddrandets": "bläddrande",
    "bläddrans": "bläddra",
    "bläddrar": "bläddra",
    "bläddras": "bläddra",
    "bläddrat": "bläddra",
    "bläddrats": "bläddra",
    "bläddre": "bläddra",
    "bläddror": "bläddra",
    "bläddrorna": "bläddra",
    "bläddrornas": "bläddra",
    "bläddrors": "bläddra",
    "bläddrs": "bläddra",
    "bländ": "blända",
    "bländad": "blända",
    "bländade": "blända",
    "bländades": "blända",
    "bländads": "blända",
    "bländande": "blända",
    "bländanden": "bländande",
    "bländandena": "bländande",
    "bländandenas": "bländande",
    "bländandens": "bländande",
    "bländandes": "bländande",
    "bländandet": "bländande",
    "bländandets": "bländande",
    "bländar": "bländare",
    "bländaren": "bländare",
    "bländarens": "bländare",
    "bländares": "bländare",
    "bländarna": "bländare",
    "bländarnas": "bländare",
    "bländas": "blända",
    "bländat": "blända",
    "bländats": "blända",
    "bländen": "blände",
    "bländena": "blände",
    "bländenas": "blände",
    "bländens": "blände",
    "bländes": "blände",
    "bländet": "blände",
    "bländets": "blände",
    "bländfria": "bländfri",
    "bländfriare": "bländfri",
    "bländfriares": "bländfri",
    "bländfrias": "bländfri",
    "bländfriast": "bländfri",
    "bländfriaste": "bländfri",
    "bländfriastes": "bländfri",
    "bländfriasts": "bländfri",
    "bländfrie": "bländfri",
    "bländfries": "bländfri",
    "bländfris": "bländfri",
    "bländfritt": "bländfri",
    "bländfritts": "bländfri",
    "bländningar": "bländning",
    "bländningarna": "bländning",
    "bländningarnas": "bländning",
    "bländningars": "bländning",
    "bländningen": "bländning",
    "bländningens": "bländning",
    "bländnings": "bländning",
    "bländrisken": "bländrisk",
    "bländriskens": "bländrisk",
    "bländrisker": "bländrisk",
    "bländriskerna": "bländrisk",
    "bländriskernas": "bländrisk",
    "bländriskers": "bländrisk",
    "bländrisks": "bländrisk",
    "bländskivan": "bländskiva",
    "bländskivans": "bländskiva",
    "bländskivas": "bländskiva",
    "bländskive": "bländskiva",
    "bländskivor": "bländskiva",
    "bländskivorna": "bländskiva",
    "bländskivornas": "bländskiva",
    "bländskivors": "bländskiva",
    "bländskydden": "bländskydd",
    "bländskyddens": "bländskydd",
    "bländskyddet": "bländskydd",
    "bländskyddets": "bländskydd",
    "bländskydds": "bländskydd",
    "bländverken": "bländverk",
    "bländverkens": "bländverk",
    "bländverket": "bländverk",
    "bländverkets": "bländverk",
    "bländverks": "bländverk",
    "bländvita": "bländvit",
    "bländvitare": "bländvit",
    "bländvitares": "bländvit",
    "bländvitas": "bländvit",
    "bländvitast": "bländvit",
    "bländvitaste": "bländvit",
    "bländvitastes": "bländvit",
    "bländvitasts": "bländvit",
    "bländvite": "bländvit",
    "bländvites": "bländvit",
    "bländvits": "bländvit",
    "bländvitt": "bländvit",
    "bländvitts": "bländvit",
    "bläng": "blänga",
    "blängande": "blänga",
    "blänganden": "blängande",
    "blängandena": "blängande",
    "blängandenas": "blängande",
    "blängandens": "blängande",
    "blängandes": "blängande",
    "blängandet": "blängande",
    "blängandets": "blängande",
    "blängar": "bläng",
    "blängarna": "bläng",
    "blängarnas": "bläng",
    "blängars": "bläng",
    "blängde": "blänga",
    "blängen": "bläng",
    "blängens": "bläng",
    "blänger": "blänga",
    "blängs": "bläng",
    "blängt": "blänga",
    "blänk": "blänka",
    "blänkande": "blänka",
    "blänkanden": "blänkande",
    "blänkandena": "blänkande",
    "blänkandenas": "blänkande",
    "blänkandens": "blänkande",
    "blänkandes": "blänkande",
    "blänkandet": "blänkande",
    "blänkandets": "blänkande",
    "blänkar": "blänkare",
    "blänkaren": "blänkare",
    "blänkarens": "blänkare",
    "blänkares": "blänkare",
    "blänkarna": "blänkare",
    "blänkarnas": "blänkare",
    "blänkars": "blänk",
    "blänkas": "blänka",
    "blänken": "blänke",
    "blänkena": "blänke",
    "blänkenas": "blänke",
    "blänkens": "blänke",
    "blänker": "blänka",
    "blänkes": "blänke",
    "blänket": "blänke",
    "blänkets": "blänke",
    "blänkfyrar": "blänkfyr",
    "blänkfyrarna": "blänkfyr",
    "blänkfyrarnas": "blänkfyr",
    "blänkfyrars": "blänkfyr",
    "blänkfyren": "blänkfyr",
    "blänkfyrens": "blänkfyr",
    "blänkfyrs": "blänkfyr",
    "blänks": "blänke",
    "blänkt": "blänka",
    "blänkte": "blänka",
    "blänktes": "blänka",
    "blänkts": "blänka",
    "bläsanden": "bläsand",
    "bläsandens": "bläsand",
    "bläsands": "bläsand",
    "bläsar": "bläs",
    "bläsarna": "bläs",
    "bläsarnas": "bläs",
    "bläsars": "bläs",
    "bläsbockar": "bläsbock",
    "bläsbockarna": "bläsbock",
    "bläsbockarnas": "bläsbock",
    "bläsbockars": "bläsbock",
    "bläsbocken": "bläsbock",
    "bläsbockens": "bläsbock",
    "bläsbocks": "bläsbock",
    "bläsen": "bläs",
    "bläsens": "bläs",
    "bläsgäss": "bläsgås",
    "bläsgässen": "bläsgås",
    "bläsgässens": "bläsgås",
    "bläsgåsen": "bläsgås",
    "bläsgåsens": "bläsgås",
    "bläst": "blästa",
    "blästad": "blästa",
    "blästade": "blästa",
    "blästades": "blästa",
    "blästads": "blästa",
    "blästande": "blästa",
    "blästanden": "blästande",
    "blästandena": "blästande",
    "blästandenas": "blästande",
    "blästandens": "blästande",
    "blästandes": "blästande",
    "blästandet": "blästande",
    "blästandets": "blästande",
    "blästar": "blästa",
    "blästas": "blästa",
    "blästat": "blästa",
    "blästats": "blästa",
    "bläster": "blästra",
    "blästern": "bläster",
    "blästerns": "bläster",
    "blästerrören": "blästerrör",
    "blästerrörens": "blästerrör",
    "blästerröret": "blästerrör",
    "blästerrörets": "blästerrör",
    "blästerrörs": "blästerrör",
    "blästers": "bläster",
    "blästerugnar": "blästerugn",
    "blästerugnarna": "blästerugn",
    "blästerugnarnas": "blästerugn",
    "blästerugnars": "blästerugn",
    "blästerugnen": "blästerugn",
    "blästerugnens": "blästerugn",
    "blästerugns": "blästerugn",
    "blästrad": "blästra",
    "blästrade": "blästra",
    "blästrades": "blästra",
    "blästrads": "blästra",
    "blästrande": "blästra",
    "blästranden": "blästrande",
    "blästrandena": "blästrande",
    "blästrandenas": "blästrande",
    "blästrandens": "blästrande",
    "blästrandes": "blästrande",
    "blästrandet": "blästrande",
    "blästrandets": "blästrande",
    "blästrar": "blästra",
    "blästrarna": "bläster",
    "blästrarnas": "bläster",
    "blästrars": "bläster",
    "blästras": "blästra",
    "blästrat": "blästra",
    "blästrats": "blästra",
    "bläsänder": "bläsand",
    "bläsänderna": "bläsand",
    "bläsändernas": "bläsand",
    "bläsänders": "bläsand",
    "blåa": "blå",
    "blåaktiga": "blåaktig",
    "blåaktigare": "blåaktig",
    "blåaktigares": "blåaktig",
    "blåaktigas": "blåaktig",
    "blåaktigast": "blåaktig",
    "blåaktigaste": "blåaktig",
    "blåaktigastes": "blåaktig",
    "blåaktigasts": "blåaktig",
    "blåaktige": "blåaktig",
    "blåaktiges": "blåaktig",
    "blåaktigheten": "blåaktighet",
    "blåaktighetens": "blåaktighet",
    "blåaktighets": "blåaktighet",
    "blåaktigs": "blåaktig",
    "blåaktigt": "blåaktig",
    "blåaktigts": "blåaktig",
    "blåanlupens": "blåanlupen",
    "blåanlupet": "blåanlupen",
    "blåanlupets": "blåanlupen",
    "blåanlupna": "blåanlupen",
    "blåanlupnare": "blåanlupen",
    "blåanlupnares": "blåanlupen",
    "blåanlupnas": "blåanlupen",
    "blåanlupnast": "blåanlupen",
    "blåanlupnaste": "blåanlupen",
    "blåanlupnastes": "blåanlupen",
    "blåanlupnasts": "blåanlupen",
    "blåanlupne": "blåanlupen",
    "blåanlupnes": "blåanlupen",
    "blåare": "blå",
    "blåares": "blå",
    "blåas": "blå",
    "blåast": "blå",
    "blåaste": "blå",
    "blåastes": "blå",
    "blåasts": "blå",
    "blåblodiga": "blåblodig",
    "blåblodigare": "blåblodig",
    "blåblodigares": "blåblodig",
    "blåblodigas": "blåblodig",
    "blåblodigast": "blåblodig",
    "blåblodigaste": "blåblodig",
    "blåblodigastes": "blåblodig",
    "blåblodigasts": "blåblodig",
    "blåblodige": "blåblodig",
    "blåblodiges": "blåblodig",
    "blåblodigheten": "blåblodighet",
    "blåblodighetens": "blåblodighet",
    "blåblodighets": "blåblodighet",
    "blåblodigs": "blåblodig",
    "blåblodigt": "blåblodig",
    "blåblodigts": "blåblodig",
    "blåbären": "blåbär",
    "blåbärens": "blåbär",
    "blåbäret": "blåbär",
    "blåbärets": "blåbär",
    "blåbärs": "blåbär",
    "blåbärspannkak": "blåbärspannkaka",
    "blåbärspannkakan": "blåbärspannkaka",
    "blåbärspannkakans": "blåbärspannkaka",
    "blåbärspannkakas": "blåbärspannkaka",
    "blåbärspannkake": "blåbärspannkaka",
    "blåbärspannkakor": "blåbärspannkaka",
    "blåbärspannkakorna": "blåbärspannkaka",
    "blåbärspannkakornas": "blåbärspannkaka",
    "blåbärspannkakors": "blåbärspannkaka",
    "blåbärspannkaks": "blåbärspannkaka",
    "blåbärsplockar": "blåbärsplockare",
    "blåbärsplockaren": "blåbärsplockare",
    "blåbärsplockarens": "blåbärsplockare",
    "blåbärsplockares": "blåbärsplockare",
    "blåbärsplockarna": "blåbärsplockare",
    "blåbärsplockarnas": "blåbärsplockare",
    "blåbärsrisen": "blåbärsris",
    "blåbärsrisens": "blåbärsris",
    "blåbärsriset": "blåbärsris",
    "blåbärsrisets": "blåbärsris",
    "blåbärssaften": "blåbärssaft",
    "blåbärssaftens": "blåbärssaft",
    "blåbärssafts": "blåbärssaft",
    "blåbärssoppan": "blåbärssoppa",
    "blåbärssoppans": "blåbärssoppa",
    "blåbärssoppas": "blåbärssoppa",
    "blåbärssylten": "blåbärssylt",
    "blåbärssyltens": "blåbärssylt",
    "blåbärssylts": "blåbärssylt",
    "blåduv": "blåduva",
    "blåduvan": "blåduva",
    "blåduvans": "blåduva",
    "blåduvas": "blåduva",
    "blåduve": "blåduva",
    "blåduvor": "blåduva",
    "blåduvorna": "blåduva",
    "blåduvornas": "blåduva",
    "blåduvors": "blåduva",
    "blåduvs": "blåduva",
    "blådårar": "blådåre",
    "blådårarna": "blådåre",
    "blådårarnas": "blådåre",
    "blådårars": "blådåre",
    "blådåren": "blådåre",
    "blådårens": "blådåre",
    "blådåres": "blådåre",
    "blåe": "blå",
    "blåelden": "blåeld",
    "blåeldens": "blåeld",
    "blåelds": "blåeld",
    "blåelsen": "blåelse",
    "blåelsens": "blåelse",
    "blåelses": "blåelse",
    "blåes": "blå",
    "blåfrusens": "blåfrusen",
    "blåfruset": "blåfrusen",
    "blåfrusets": "blåfrusen",
    "blåfrusna": "blåfrusen",
    "blåfrusnare": "blåfrusen",
    "blåfrusnares": "blåfrusen",
    "blåfrusnas": "blåfrusen",
    "blåfrusnast": "blåfrusen",
    "blåfrusnaste": "blåfrusen",
    "blåfrusnastes": "blåfrusen",
    "blåfrusnasts": "blåfrusen",
    "blåfrusne": "blåfrusen",
    "blåfrusnes": "blåfrusen",
    "blåförskjutningen": "blåförskjutning",
    "blåförskjutningens": "blåförskjutning",
    "blåförskjutnings": "blåförskjutning",
    "blågröna": "blågrön",
    "blågrönalgen": "blågrönalg",
    "blågrönalgens": "blågrönalg",
    "blågrönalger": "blågrönalg",
    "blågrönalgerna": "blågrönalg",
    "blågrönalgernas": "blågrönalg",
    "blågrönalgers": "blågrönalg",
    "blågrönalgs": "blågrönalg",
    "blågrönare": "blågrön",
    "blågrönares": "blågrön",
    "blågrönas": "blågrön",
    "blågrönast": "blågrön",
    "blågrönaste": "blågrön",
    "blågrönastes": "blågrön",
    "blågrönasts": "blågrön",
    "blågröne": "blågrön",
    "blågrönes": "blågrön",
    "blågröns": "blågrön",
    "blågrönt": "blågrön",
    "blågrönts": "blågrön",
    "blågula": "blågul",
    "blågulare": "blågul",
    "blågulares": "blågul",
    "blågulas": "blågul",
    "blågulast": "blågul",
    "blågulaste": "blågul",
    "blågulastes": "blågul",
    "blågulasts": "blågul",
    "blågule": "blågul",
    "blågules": "blågul",
    "blåguls": "blågul",
    "blågult": "blågul",
    "blågults": "blågul",
    "blåhajar": "blåhaj",
    "blåhajarna": "blåhaj",
    "blåhajarnas": "blåhaj",
    "blåhajars": "blåhaj",
    "blåhajen": "blåhaj",
    "blåhajens": "blåhaj",
    "blåhajs": "blåhaj",
    "blåhakar": "blåhake",
    "blåhakarna": "blåhake",
    "blåhakarnas": "blåhake",
    "blåhakars": "blåhake",
    "blåhaken": "blåhake",
    "blåhakens": "blåhake",
    "blåhakes": "blåhake",
    "blåhallonen": "blåhallon",
    "blåhallonens": "blåhallon",
    "blåhallonet": "blåhallon",
    "blåhallonets": "blåhallon",
    "blåhallons": "blåhallon",
    "blåhjonen": "blåhjon",
    "blåhjonens": "blåhjon",
    "blåhjonet": "blåhjon",
    "blåhjonets": "blåhjon",
    "blåhjons": "blåhjon",
    "blåholtsen": "blåholts",
    "blåholtsens": "blåholts",
    "blåholtset": "blåholts",
    "blåholtsets": "blåholts",
    "blåisen": "blåis",
    "blåisens": "blåis",
    "blåjack": "blåjacka",
    "blåjackan": "blåjacka",
    "blåjackans": "blåjacka",
    "blåjackas": "blåjacka",
    "blåjacke": "blåjacka",
    "blåjackor": "blåjacka",
    "blåjackorna": "blåjacka",
    "blåjackornas": "blåjacka",
    "blåjackors": "blåjacka",
    "blåjacks": "blåjacka",
    "blåjorden": "blåjord",
    "blåjordens": "blåjord",
    "blåjords": "blåjord",
    "blåklintar": "blåklint",
    "blåklintarna": "blåklint",
    "blåklintarnas": "blåklint",
    "blåklintars": "blåklint",
    "blåklinten": "blåklint",
    "blåklintens": "blåklint",
    "blåklints": "blåklint",
    "blåklock": "blåklocka",
    "blåklockan": "blåklocka",
    "blåklockans": "blåklocka",
    "blåklockas": "blåklocka",
    "blåklocke": "blåklocka",
    "blåklockor": "blåklocka",
    "blåklockorna": "blåklocka",
    "blåklockornas": "blåklocka",
    "blåklockors": "blåklocka",
    "blåklocks": "blåklocka",
    "blåkläderna": "blåkläder",
    "blåklädernas": "blåkläder",
    "blåkläders": "blåkläder",
    "blåklädes": "blåkläder",
    "blåkläds": "blåkläder",
    "blåkopian": "blåkopia",
    "blåkopians": "blåkopia",
    "blåkopias": "blåkopia",
    "blåkopie": "blåkopia",
    "blåkopierad": "blåkopiera",
    "blåkopierade": "blåkopiera",
    "blåkopierades": "blåkopiera",
    "blåkopierads": "blåkopiera",
    "blåkopierande": "blåkopiera",
    "blåkopieranden": "blåkopierande",
    "blåkopierandena": "blåkopierande",
    "blåkopierandenas": "blåkopierande",
    "blåkopierandens": "blåkopierande",
    "blåkopierandes": "blåkopierande",
    "blåkopierandet": "blåkopierande",
    "blåkopierandets": "blåkopierande",
    "blåkopierar": "blåkopiera",
    "blåkopieras": "blåkopiera",
    "blåkopierat": "blåkopiera",
    "blåkopierats": "blåkopiera",
    "blåkopierbara": "blåkopierbar",
    "blåkopierbarare": "blåkopierbar",
    "blåkopierbarares": "blåkopierbar",
    "blåkopierbaras": "blåkopierbar",
    "blåkopierbarast": "blåkopierbar",
    "blåkopierbaraste": "blåkopierbar",
    "blåkopierbarastes": "blåkopierbar",
    "blåkopierbarasts": "blåkopierbar",
    "blåkopierbare": "blåkopierbar",
    "blåkopierbares": "blåkopierbar",
    "blåkopierbarheten": "blåkopierbarhet",
    "blåkopierbarhetens": "blåkopierbarhet",
    "blåkopierbarhets": "blåkopierbarhet",
    "blåkopierbars": "blåkopierbar",
    "blåkopierbart": "blåkopierbar",
    "blåkopierbarts": "blåkopierbar",
    "blåkopieringar": "blåkopiering",
    "blåkopieringarna": "blåkopiering",
    "blåkopieringarnas": "blåkopiering",
    "blåkopieringars": "blåkopiering",
    "blåkopieringen": "blåkopiering",
    "blåkopieringens": "blåkopiering",
    "blåkopierings": "blåkopiering",
    "blåkopior": "blåkopia",
    "blåkopiorna": "blåkopia",
    "blåkopiornas": "blåkopia",
    "blåkopiors": "blåkopia",
    "blåkråk": "blåkråka",
    "blåkråkan": "blåkråka",
    "blåkråkans": "blåkråka",
    "blåkråkas": "blåkråka",
    "blåkråke": "blåkråka",
    "blåkråkor": "blåkråka",
    "blåkråkorna": "blåkråka",
    "blåkråkornas": "blåkråka",
    "blåkråkors": "blåkråka",
    "blåkråks": "blåkråka",
    "blåkålen": "blåkål",
    "blåkålens": "blåkål",
    "blåkåls": "blåkål",
    "blåkör": "blåköra",
    "blåkörande": "blåköra",
    "blåköranden": "blåkörande",
    "blåkörandena": "blåkörande",
    "blåkörandenas": "blåkörande",
    "blåkörandens": "blåkörande",
    "blåkörandes": "blåkörande",
    "blåkörandet": "blåkörande",
    "blåkörandets": "blåkörande",
    "blåköras": "blåköra",
    "blåkörd": "blåköra",
    "blåkörda": "blåköra",
    "blåkördas": "blåköra",
    "blåkörde": "blåköra",
    "blåkördes": "blåköra",
    "blåkörds": "blåköra",
    "blåköres": "blåköra",
    "blåkörs": "blåköra",
    "blåkört": "blåköra",
    "blåkörts": "blåköra",
    "blåleran": "blålera",
    "blålerans": "blålera",
    "blåleras": "blålera",
    "blåljug": "blåljuga",
    "blåljugande": "blåljuga",
    "blåljugandes": "blåljuga",
    "blåljugas": "blåljuga",
    "blåljuge": "blåljuga",
    "blåljugen": "blåljuga",
    "blåljugens": "blåljuga",
    "blåljuger": "blåljuga",
    "blåljuges": "blåljuga",
    "blåljuget": "blåljuga",
    "blåljugets": "blåljuga",
    "blåljugit": "blåljuga",
    "blåljugits": "blåljuga",
    "blåljugna": "blåljuga",
    "blåljugnas": "blåljuga",
    "blåljugne": "blåljuga",
    "blåljugnes": "blåljuga",
    "blåljugs": "blåljuga",
    "blåljög": "blåljuga",
    "blåljöge": "blåljuga",
    "blåljöges": "blåljuga",
    "blåljögs": "blåljuga",
    "blålusernen": "blålusern",
    "blålusernens": "blålusern",
    "blåluserner": "blålusern",
    "blålusernerna": "blålusern",
    "blålusernernas": "blålusern",
    "blåluserners": "blålusern",
    "blåluserns": "blålusern",
    "blåmesar": "blåmes",
    "blåmesarna": "blåmes",
    "blåmesarnas": "blåmes",
    "blåmesars": "blåmes",
    "blåmesen": "blåmes",
    "blåmesens": "blåmes",
    "blåmussel": "blåmussla",
    "blåmusseronen": "blåmusseron",
    "blåmusseronens": "blåmusseron",
    "blåmusseroner": "blåmusseron",
    "blåmusseronerna": "blåmusseron",
    "blåmusseronernas": "blåmusseron",
    "blåmusseroners": "blåmusseron",
    "blåmusserons": "blåmusseron",
    "blåmusslan": "blåmussla",
    "blåmusslans": "blåmussla",
    "blåmusslas": "blåmussla",
    "blåmussle": "blåmussla",
    "blåmusslor": "blåmussla",
    "blåmusslorna": "blåmussla",
    "blåmusslornas": "blåmussla",
    "blåmusslors": "blåmussla",
    "blåmärken": "blåmärke",
    "blåmärkena": "blåmärke",
    "blåmärkenas": "blåmärke",
    "blåmärkens": "blåmärke",
    "blåmärkes": "blåmärke",
    "blåmärket": "blåmärke",
    "blåmärkets": "blåmärke",
    "blåmålade": "blåmålad",
    "blåmålades": "blåmålad",
    "blåmålads": "blåmålad",
    "blåmålat": "blåmålad",
    "blåmålats": "blåmålad",
    "blånade": "blåna",
    "blånaden": "blånad",
    "blånadens": "blånad",
    "blånader": "blånad",
    "blånaderna": "blånad",
    "blånadernas": "blånad",
    "blånaders": "blånad",
    "blånades": "blåna",
    "blånads": "blånad",
    "blånande": "blåna",
    "blånanden": "blånande",
    "blånandena": "blånande",
    "blånandenas": "blånande",
    "blånandens": "blånande",
    "blånandes": "blånande",
    "blånandet": "blånande",
    "blånandets": "blånande",
    "blånar": "blåna",
    "blånas": "blåna",
    "blånat": "blåna",
    "blånats": "blåna",
    "blånekade": "blåneka",
    "blånekades": "blåneka",
    "blånekande": "blåneka",
    "blånekanden": "blånekande",
    "blånekandena": "blånekande",
    "blånekandenas": "blånekande",
    "blånekandens": "blånekande",
    "blånekandes": "blånekande",
    "blånekandet": "blånekande",
    "blånekandets": "blånekande",
    "blånekar": "blåneka",
    "blånekas": "blåneka",
    "blånekat": "blåneka",
    "blånekats": "blåneka",
    "blånorna": "blånor",
    "blånornas": "blånor",
    "blånors": "blånor",
    "blåpenn": "blåpenna",
    "blåpennan": "blåpenna",
    "blåpennans": "blåpenna",
    "blåpennas": "blåpenna",
    "blåpenne": "blåpenna",
    "blåpennor": "blåpenna",
    "blåpennorna": "blåpenna",
    "blåpennornas": "blåpenna",
    "blåpennors": "blåpenna",
    "blåpenns": "blåpenna",
    "blåregnet": "blåregn",
    "blåregnets": "blåregn",
    "blåregns": "blåregn",
    "blårävar": "blåräv",
    "blårävarna": "blåräv",
    "blårävarnas": "blåräv",
    "blårävars": "blåräv",
    "blåräven": "blåräv",
    "blårävens": "blåräv",
    "blårävs": "blåräv",
    "blåröda": "blåröd",
    "blårödare": "blåröd",
    "blårödares": "blåröd",
    "blårödas": "blåröd",
    "blårödast": "blåröd",
    "blårödaste": "blåröd",
    "blårödastes": "blåröd",
    "blårödasts": "blåröd",
    "blåröde": "blåröd",
    "blårödes": "blåröd",
    "blåröds": "blåröd",
    "blårött": "blåröd",
    "blårötts": "blåröd",
    "blås": "blåsa",
    "blåsan": "blåsa",
    "blåsande": "blåsa",
    "blåsanden": "blåsande",
    "blåsandena": "blåsande",
    "blåsandenas": "blåsande",
    "blåsandens": "blåsande",
    "blåsandes": "blåsande",
    "blåsandet": "blåsande",
    "blåsandets": "blåsande",
    "blåsans": "blåsa",
    "blåsar": "blåsare",
    "blåsaren": "blåsare",
    "blåsarens": "blåsare",
    "blåsares": "blåsare",
    "blåsarna": "blåsare",
    "blåsarnas": "blåsare",
    "blåsas": "blåsa",
    "blåsbälgar": "blåsbälg",
    "blåsbälgarna": "blåsbälg",
    "blåsbälgarnas": "blåsbälg",
    "blåsbälgars": "blåsbälg",
    "blåsbälgen": "blåsbälg",
    "blåsbälgens": "blåsbälg",
    "blåsbälgs": "blåsbälg",
    "blåse": "blåsa",
    "blåser": "blåsa",
    "blåses": "blåsa",
    "blåsfotingar": "blåsfoting",
    "blåsfotingarna": "blåsfoting",
    "blåsfotingarnas": "blåsfoting",
    "blåsfotingars": "blåsfoting",
    "blåsfotingen": "blåsfoting",
    "blåsfotingens": "blåsfoting",
    "blåsfotings": "blåsfoting",
    "blåshalsar": "blåshals",
    "blåshalsarna": "blåshals",
    "blåshalsarnas": "blåshals",
    "blåshalsars": "blåshals",
    "blåshalsen": "blåshals",
    "blåshalsens": "blåshals",
    "blåshalskörteln": "blåshalskörtel",
    "blåshalskörtelns": "blåshalskörtel",
    "blåshalskörtels": "blåshalskörtel",
    "blåshalskörtlar": "blåshalskörtel",
    "blåshalskörtlarna": "blåshalskörtel",
    "blåshalskörtlarnas": "blåshalskörtel",
    "blåshalskörtlars": "blåshalskörtel",
    "blåshålen": "blåshål",
    "blåshålens": "blåshål",
    "blåshålet": "blåshål",
    "blåshålets": "blåshål",
    "blåshåls": "blåshål",
    "blåsiga": "blåsig",
    "blåsigare": "blåsig",
    "blåsigares": "blåsig",
    "blåsigas": "blåsig",
    "blåsigast": "blåsig",
    "blåsigaste": "blåsig",
    "blåsigastes": "blåsig",
    "blåsigasts": "blåsig",
    "blåsige": "blåsig",
    "blåsiges": "blåsig",
    "blåsigs": "blåsig",
    "blåsigt": "blåsig",
    "blåsigts": "blåsig",
    "blåsinstrumenten": "blåsinstrument",
    "blåsinstrumentens": "blåsinstrument",
    "blåsinstrumentet": "blåsinstrument",
    "blåsinstrumentets": "blåsinstrument",
    "blåsinstruments": "blåsinstrument",
    "blåsipp": "blåsippa",
    "blåsippan": "blåsippa",
    "blåsippans": "blåsippa",
    "blåsippas": "blåsippa",
    "blåsippe": "blåsippa",
    "blåsippor": "blåsippa",
    "blåsipporna": "blåsippa",
    "blåsippornas": "blåsippa",
    "blåsippors": "blåsippa",
    "blåsipps": "blåsippa",
    "blåsjukan": "blåsjuka",
    "blåsjukans": "blåsjuka",
    "blåsjukas": "blåsjuka",
    "blåsjuke": "blåsjuka",
    "blåsjuks": "blåsjuka",
    "blåskatarren": "blåskatarr",
    "blåskatarrens": "blåskatarr",
    "blåskatarrer": "blåskatarr",
    "blåskatarrerna": "blåskatarr",
    "blåskatarrernas": "blåskatarr",
    "blåskatarrers": "blåskatarr",
    "blåskatarrs": "blåskatarr",
    "blåslamp": "blåslampa",
    "blåslampan": "blåslampa",
    "blåslampans": "blåslampa",
    "blåslampas": "blåslampa",
    "blåslampe": "blåslampa",
    "blåslampor": "blåslampa",
    "blåslamporna": "blåslampa",
    "blåslampornas": "blåslampa",
    "blåslampors": "blåslampa",
    "blåslamps": "blåslampa",
    "blåsljuden": "blåsljud",
    "blåsljudens": "blåsljud",
    "blåsljudet": "blåsljud",
    "blåsljudets": "blåsljud",
    "blåsljuds": "blåsljud",
    "blåsmaskar": "blåsmask",
    "blåsmaskarna": "blåsmask",
    "blåsmaskarnas": "blåsmask",
    "blåsmaskars": "blåsmask",
    "blåsmasken": "blåsmask",
    "blåsmaskens": "blåsmask",
    "blåsmasks": "blåsmask",
    "blåsningar": "blåsning",
    "blåsningarna": "blåsning",
    "blåsningarnas": "blåsning",
    "blåsningars": "blåsning",
    "blåsningen": "blåsning",
    "blåsningens": "blåsning",
    "blåsnings": "blåsning",
    "blåsor": "blåsa",
    "blåsorkestern": "blåsorkester",
    "blåsorkesterns": "blåsorkester",
    "blåsorkesters": "blåsorkester",
    "blåsorkestrar": "blåsorkester",
    "blåsorkestrarna": "blåsorkester",
    "blåsorkestrarnas": "blåsorkester",
    "blåsorkestrars": "blåsorkester",
    "blåsorna": "blåsa",
    "blåsornas": "blåsa",
    "blåsors": "blåsa",
    "blåspistolen": "blåspistol",
    "blåspistolens": "blåspistol",
    "blåspistoler": "blåspistol",
    "blåspistolerna": "blåspistol",
    "blåspistolernas": "blåspistol",
    "blåspistolers": "blåspistol",
    "blåspistols": "blåspistol",
    "blåspriten": "blåsprit",
    "blåspritens": "blåsprit",
    "blåsprits": "blåsprit",
    "blåsrören": "blåsrör",
    "blåsrörens": "blåsrör",
    "blåsröret": "blåsrör",
    "blåsrörets": "blåsrör",
    "blåsrörs": "blåsrör",
    "blåsstenar": "blåssten",
    "blåsstenarna": "blåssten",
    "blåsstenarnas": "blåssten",
    "blåsstenars": "blåssten",
    "blåsstenen": "blåssten",
    "blåsstenens": "blåssten",
    "blåsstens": "blåssten",
    "blåst": "blåsa",
    "blåsta": "blåst",
    "blåstare": "blåst",
    "blåstares": "blåst",
    "blåstas": "blåst",
    "blåstast": "blåst",
    "blåstaste": "blåst",
    "blåstastes": "blåst",
    "blåstasts": "blåst",
    "blåste": "blåst",
    "blåsten": "blåst",
    "blåstens": "blåst",
    "blåstes": "blåst",
    "blåstheten": "blåsthet",
    "blåsthetens": "blåsthet",
    "blåsthets": "blåsthet",
    "blåstrump": "blåstrumpa",
    "blåstrumpan": "blåstrumpa",
    "blåstrumpans": "blåstrumpa",
    "blåstrumpas": "blåstrumpa",
    "blåstrumpe": "blåstrumpa",
    "blåstrumpor": "blåstrumpa",
    "blåstrumporna": "blåstrumpa",
    "blåstrumpornas": "blåstrumpa",
    "blåstrumpors": "blåstrumpa",
    "blåstrumps": "blåstrumpa",
    "blåsts": "blåst",
    "blåställen": "blåställ",
    "blåställens": "blåställ",
    "blåstället": "blåställ",
    "blåställets": "blåställ",
    "blåställs": "blåställ",
    "blåstången": "blåstång",
    "blåstångens": "blåstång",
    "blåstångs": "blåstång",
    "blåsura": "blåsur",
    "blåsurare": "blåsur",
    "blåsurares": "blåsur",
    "blåsuras": "blåsur",
    "blåsurast": "blåsur",
    "blåsuraste": "blåsur",
    "blåsurastes": "blåsur",
    "blåsurasts": "blåsur",
    "blåsure": "blåsur",
    "blåsures": "blåsur",
    "blåsurs": "blåsur",
    "blåsurt": "blåsur",
    "blåsurts": "blåsur",
    "blåsväderna": "blåsväder",
    "blåsvädernas": "blåsväder",
    "blåsväders": "blåsväder",
    "blåsvädren": "blåsväder",
    "blåsvädrens": "blåsväder",
    "blåsvädret": "blåsväder",
    "blåsvädrets": "blåsväder",
    "blåsyran": "blåsyra",
    "blåsyrans": "blåsyra",
    "blåsyras": "blåsyra",
    "blåsyre": "blåsyra",
    "blåsörten": "blåsört",
    "blåsörtens": "blåsört",
    "blåsörts": "blåsört",
    "blåtir": "blåtira",
    "blåtiran": "blåtira",
    "blåtirans": "blåtira",
    "blåtiras": "blåtira",
    "blåtire": "blåtira",
    "blåtiror": "blåtira",
    "blåtirorna": "blåtira",
    "blåtirornas": "blåtira",
    "blåtirors": "blåtira",
    "blåtirs": "blåtira",
    "blåträet": "blåträ",
    "blåträets": "blåträ",
    "blåträs": "blåträ",
    "blåträt": "blåträ",
    "blåträts": "blåträ",
    "blått": "blå",
    "blåtts": "blå",
    "blåtåteln": "blåtåtel",
    "blåtåtelns": "blåtåtel",
    "blåtåtels": "blåtåtel",
    "blåvalar": "blåval",
    "blåvalarna": "blåval",
    "blåvalarnas": "blåval",
    "blåvalars": "blåval",
    "blåvalen": "blåval",
    "blåvalens": "blåval",
    "blåvals": "blåval",
    "blåvarma": "blåvarm",
    "blåvarmare": "blåvarm",
    "blåvarmares": "blåvarm",
    "blåvarmas": "blåvarm",
    "blåvarmast": "blåvarm",
    "blåvarmaste": "blåvarm",
    "blåvarmastes": "blåvarm",
    "blåvarmasts": "blåvarm",
    "blåvarme": "blåvarm",
    "blåvarmes": "blåvarm",
    "blåvarms": "blåvarm",
    "blåvarmt": "blåvarm",
    "blåvarmts": "blåvarm",
    "blåveden": "blåved",
    "blåvedens": "blåved",
    "blåveds": "blåved",
    "blåving": "blåvinge",
    "blåvingar": "blåvinge",
    "blåvingarna": "blåvinge",
    "blåvingarnas": "blåvinge",
    "blåvingars": "blåvinge",
    "blåvingen": "blåvinge",
    "blåvingens": "blåvinge",
    "blåvinges": "blåvinge",
    "blåvings": "blåvinge",
    "blåvioletta": "blåviolett",
    "blåviolettare": "blåviolett",
    "blåviolettares": "blåviolett",
    "blåviolettas": "blåviolett",
    "blåviolettast": "blåviolett",
    "blåviolettaste": "blåviolett",
    "blåviolettastes": "blåviolett",
    "blåviolettasts": "blåviolett",
    "blåviolette": "blåviolett",
    "blåviolettes": "blåviolett",
    "blåvioletts": "blåviolett",
    "blåvita": "blåvit",
    "blåvitare": "blåvit",
    "blåvitares": "blåvit",
    "blåvitas": "blåvit",
    "blåvitast": "blåvit",
    "blåvitaste": "blåvit",
    "blåvitastes": "blåvit",
    "blåvitasts": "blåvit",
    "blåvite": "blåvit",
    "blåvites": "blåvit",
    "blåvitlingar": "blåvitling",
    "blåvitlingarna": "blåvitling",
    "blåvitlingarnas": "blåvitling",
    "blåvitlingars": "blåvitling",
    "blåvitlingen": "blåvitling",
    "blåvitlingens": "blåvitling",
    "blåvitlings": "blåvitling",
    "blåvits": "blåvit",
    "blåvitt": "blåvit",
    "blåvitts": "blåvit",
    "blåvärmen": "blåvärme",
    "blåvärmens": "blåvärme",
    "blåvärmes": "blåvärme",
    "blåögda": "blåögd",
    "blåögdare": "blåögd",
    "blåögdares": "blåögd",
    "blåögdas": "blåögd",
    "blåögdast": "blåögd",
    "blåögdaste": "blåögd",
    "blåögdastes": "blåögd",
    "blåögdasts": "blåögd",
    "blåögde": "blåögd",
    "blåögdes": "blåögd",
    "blåögdheten": "blåögdhet",
    "blåögdhetens": "blåögdhet",
    "blåögdhets": "blåögdhet",
    "blåögds": "blåögd",
    "blåögt": "blåögd",
    "blåögts": "blåögd",
    "blöd": "blöda",
    "blödande": "blöda",
    "blödanden": "blödande",
    "blödandena": "blödande",
    "blödandenas": "blödande",
    "blödandens": "blödande",
    "blödandes": "blödande",
    "blödandet": "blödande",
    "blödandets": "blödande",
    "blödar": "blödare",
    "blödaren": "blödare",
    "blödarens": "blödare",
    "blödares": "blödare",
    "blödarna": "blödare",
    "blödarnas": "blödare",
    "blödarsjukan": "blödarsjuka",
    "blödarsjukans": "blödarsjuka",
    "blödarsjukas": "blödarsjuka",
    "blödarsjuke": "blödarsjuka",
    "blödarsjuks": "blödarsjuka",
    "blödas": "blöda",
    "blödd": "blöda",
    "blödda": "blöda",
    "blöddas": "blöda",
    "blödde": "blöda",
    "blöddes": "blöda",
    "blödds": "blöda",
    "blöder": "blöda",
    "blödes": "blöda",
    "blödiga": "blödig",
    "blödigare": "blödig",
    "blödigares": "blödig",
    "blödigas": "blödig",
    "blödigast": "blödig",
    "blödigaste": "blödig",
    "blödigastes": "blödig",
    "blödigasts": "blödig",
    "blödige": "blödig",
    "blödiges": "blödig",
    "blödigheten": "blödighet",
    "blödighetens": "blödighet",
    "blödigheter": "blödighet",
    "blödigheterna": "blödighet",
    "blödigheternas": "blödighet",
    "blödigheters": "blödighet",
    "blödighets": "blödighet",
    "blödigs": "blödig",
    "blödigt": "blödig",
    "blödigts": "blödig",
    "blödningar": "blödning",
    "blödningarna": "blödning",
    "blödningarnas": "blödning",
    "blödningars": "blödning",
    "blödningen": "blödning",
    "blödningens": "blödning",
    "blödnings": "blödning",
    "blöds": "blöda",
    "blöj": "blöja",
    "blöjan": "blöja",
    "blöjans": "blöja",
    "blöjas": "blöja",
    "blöjbyten": "blöjbyte",
    "blöjbytena": "blöjbyte",
    "blöjbytenas": "blöjbyte",
    "blöjbytens": "blöjbyte",
    "blöjbytes": "blöjbyte",
    "blöjbytet": "blöjbyte",
    "blöjbytets": "blöjbyte",
    "blöje": "blöja",
    "blöjor": "blöja",
    "blöjorna": "blöja",
    "blöjornas": "blöja",
    "blöjors": "blöja",
    "blöjs": "blöja",
    "blöt": "blöta",
    "blöta": "blöt",
    "blötan": "blöta",
    "blötande": "blöta",
    "blötanden": "blötande",
    "blötandena": "blötande",
    "blötandenas": "blötande",
    "blötandens": "blötande",
    "blötandes": "blötande",
    "blötandet": "blötande",
    "blötandets": "blötande",
    "blötans": "blöta",
    "blötare": "blöt",
    "blötares": "blöt",
    "blötas": "blöta",
    "blötast": "blöt",
    "blötaste": "blöt",
    "blötastes": "blöt",
    "blötasts": "blöt",
    "blötdjuren": "blötdjur",
    "blötdjurens": "blötdjur",
    "blötdjuret": "blötdjur",
    "blötdjurets": "blötdjur",
    "blötdjurs": "blötdjur",
    "blöte": "blöt",
    "blöter": "blöta",
    "blötes": "blöta",
    "blötfoders": "blötfoder",
    "blötfodret": "blötfoder",
    "blötfodrets": "blötfoder",
    "blötheten": "blöthet",
    "blöthetens": "blöthet",
    "blöthets": "blöthet",
    "blötla": "blötlägga",
    "blötlade": "blötlägga",
    "blötlades": "blötlägga",
    "blötlagd": "blötlägga",
    "blötlagda": "blötlägga",
    "blötlagdas": "blötlägga",
    "blötlagde": "blötlägga",
    "blötlagdes": "blötlägga",
    "blötlagds": "blötlägga",
    "blötlagt": "blötlägga",
    "blötlagts": "blötlägga",
    "blötlas": "blötlägga",
    "blötlägg": "blötlägga",
    "blötläggande": "blötlägga",
    "blötlägganden": "blötläggande",
    "blötläggandena": "blötläggande",
    "blötläggandenas": "blötläggande",
    "blötläggandens": "blötläggande",
    "blötläggandes": "blötläggande",
    "blötläggandet": "blötläggande",
    "blötläggandets": "blötläggande",
    "blötläggas": "blötlägga",
    "blötlägger": "blötlägga",
    "blötlägges": "blötlägga",
    "blötläggningar": "blötläggning",
    "blötläggningarna": "blötläggning",
    "blötläggningarnas": "blötläggning",
    "blötläggningars": "blötläggning",
    "blötläggningen": "blötläggning",
    "blötläggningens": "blötläggning",
    "blötläggnings": "blötläggning",
    "blötläggningsmedels": "blötläggningsmedel",
    "blötläggningsmedlen": "blötläggningsmedel",
    "blötläggningsmedlens": "blötläggningsmedel",
    "blötläggningsmedlet": "blötläggningsmedel",
    "blötläggningsmedlets": "blötläggningsmedel",
    "blötläggs": "blötlägga",
    "blötnade": "blötna",
    "blötnades": "blötna",
    "blötnande": "blötna",
    "blötnanden": "blötnande",
    "blötnandena": "blötnande",
    "blötnandenas": "blötnande",
    "blötnandens": "blötnande",
    "blötnandes": "blötnande",
    "blötnandet": "blötnande",
    "blötnandets": "blötnande",
    "blötnar": "blötna",
    "blötnas": "blötna",
    "blötnat": "blötna",
    "blötnats": "blötna",
    "blötrötan": "blötröta",
    "blötrötans": "blötröta",
    "blötrötas": "blötröta",
    "blötröte": "blötröta",
    "blöts": "blöta",
    "blötsnön": "blötsnö",
    "blötsnöns": "blötsnö",
    "blötsnös": "blötsnö",
    "blött": "blöta",
    "blötta": "blöta",
    "blöttas": "blöta",
    "blötte": "blöta",
    "blöttes": "blöta",
    "blötts": "blöta",
    "boan": "boa",
    "boans": "boa",
    "boaormar": "boaorm",
    "boaormarna": "boaorm",
    "boaormarnas": "boaorm",
    "boaormars": "boaorm",
    "boaormen": "boaorm",
    "boaormens": "boaorm",
    "boaorms": "boaorm",
    "boarden": "board",
    "boardens": "board",
    "boardingcarden": "boardingcard",
    "boardingcardens": "boardingcard",
    "boardingcardet": "boardingcard",
    "boardingcardets": "boardingcard",
    "boardingcards": "boardingcard",
    "boards": "board",
    "boas": "boa",
    "boaserad": "boasera",
    "boaserade": "boasera",
    "boaserades": "boasera",
    "boaserads": "boasera",
    "boaserande": "boasera",
    "boaseranden": "boaserande",
    "boaserandena": "boaserande",
    "boaserandenas": "boaserande",
    "boaserandens": "boaserande",
    "boaserandes": "boaserande",
    "boaserandet": "boaserande",
    "boaserandets": "boaserande",
    "boaserar": "boasera",
    "boaseras": "boasera",
    "boaserat": "boasera",
    "boaserats": "boasera",
    "boaserbara": "boaserbar",
    "boaserbarare": "boaserbar",
    "boaserbarares": "boaserbar",
    "boaserbaras": "boaserbar",
    "boaserbarast": "boaserbar",
    "boaserbaraste": "boaserbar",
    "boaserbarastes": "boaserbar",
    "boaserbarasts": "boaserbar",
    "boaserbare": "boaserbar",
    "boaserbares": "boaserbar",
    "boaserbarheten": "boaserbarhet",
    "boaserbarhetens": "boaserbarhet",
    "boaserbarhets": "boaserbarhet",
    "boaserbars": "boaserbar",
    "boaserbart": "boaserbar",
    "boaserbarts": "boaserbar",
    "boaseringar": "boasering",
    "boaseringarna": "boasering",
    "boaseringarnas": "boasering",
    "boaseringars": "boasering",
    "boaseringen": "boasering",
    "boaseringens": "boasering",
    "boaserings": "boasering",
    "bobar": "bob",
    "bobarna": "bob",
    "bobarnas": "bob",
    "bobars": "bob",
    "bobb": "bobba",
    "bobbad": "bobba",
    "bobbade": "bobba",
    "bobbades": "bobba",
    "bobbads": "bobba",
    "bobban": "bobba",
    "bobbande": "bobba",
    "bobbanden": "bobbande",
    "bobbandena": "bobbande",
    "bobbandenas": "bobbande",
    "bobbandens": "bobbande",
    "bobbandes": "bobbande",
    "bobbandet": "bobbande",
    "bobbandets": "bobbande",
    "bobbans": "bobba",
    "bobbar": "bobba",
    "bobbarna": "bobb",
    "bobbarnas": "bobb",
    "bobbars": "bobb",
    "bobbas": "bobba",
    "bobbat": "bobba",
    "bobbats": "bobba",
    "bobbe": "bobba",
    "bobben": "bobb",
    "bobbens": "bobb",
    "bobbor": "bobba",
    "bobborna": "bobba",
    "bobbornas": "bobba",
    "bobbors": "bobba",
    "bobbs": "bobba",
    "boben": "bob",
    "bobens": "bob",
    "bobinen": "bobin",
    "bobinens": "bobin",
    "bobiner": "bobin",
    "bobinerna": "bobin",
    "bobinernas": "bobin",
    "bobiners": "bobin",
    "bobins": "bobin",
    "bobollar": "boboll",
    "bobollarna": "boboll",
    "bobollarnas": "boboll",
    "bobollars": "boboll",
    "bobollen": "boboll",
    "bobollens": "boboll",
    "bobolls": "boboll",
    "bobs": "bob",
    "bobsleighar": "bobsleigh",
    "bobsleigharna": "bobsleigh",
    "bobsleigharnas": "bobsleigh",
    "bobsleighars": "bobsleigh",
    "bobsleighen": "bobsleigh",
    "bobsleighens": "bobsleigh",
    "bobsleighs": "bobsleigh",
    "bobsleighsarna": "bobsleigh",
    "bobsleighsarnas": "bobsleigh",
    "bobsleighsen": "bobsleigh",
    "bobsleighsens": "bobsleigh",
    "boccian": "boccia",
    "boccians": "boccia",
    "boccias": "boccia",
    "bock": "bocka",
    "bockad": "bocka",
    "bockade": "bocka",
    "bockades": "bocka",
    "bockads": "bocka",
    "bockande": "bocka",
    "bockanden": "bockande",
    "bockandena": "bockande",
    "bockandenas": "bockande",
    "bockandens": "bockande",
    "bockandes": "bockande",
    "bockandet": "bockande",
    "bockandets": "bockande",
    "bockar": "bocka",
    "bockarna": "bock",
    "bockarnas": "bock",
    "bockars": "bock",
    "bockas": "bocka",
    "bockat": "bocka",
    "bockats": "bocka",
    "bockbenta": "bockbent",
    "bockbentare": "bockbent",
    "bockbentares": "bockbent",
    "bockbentas": "bockbent",
    "bockbentast": "bockbent",
    "bockbentaste": "bockbent",
    "bockbentastes": "bockbent",
    "bockbentasts": "bockbent",
    "bockbente": "bockbent",
    "bockbentes": "bockbent",
    "bockbentheten": "bockbenthet",
    "bockbenthetens": "bockbenthet",
    "bockbenthets": "bockbenthet",
    "bockbents": "bockbent",
    "bockbladen": "bockblad",
    "bockbladens": "bockblad",
    "bockbladet": "bockblad",
    "bockbladets": "bockblad",
    "bockblads": "bockblad",
    "bockbroar": "bockbro",
    "bockbroarna": "bockbro",
    "bockbroarnas": "bockbro",
    "bockbroars": "bockbro",
    "bockbron": "bockbro",
    "bockbrons": "bockbro",
    "bockbros": "bockbro",
    "bocken": "bock",
    "bockens": "bock",
    "bockfoten": "bockfot",
    "bockfotens": "bockfot",
    "bockfots": "bockfot",
    "bockfötter": "bockfot",
    "bockfötterna": "bockfot",
    "bockfötternas": "bockfot",
    "bockfötters": "bockfot",
    "bockhornen": "bockhorn",
    "bockhornens": "bockhorn",
    "bockhornet": "bockhorn",
    "bockhornets": "bockhorn",
    "bockhorns": "bockhorn",
    "bockhornsklövern": "bockhornsklöver",
    "bockhornsklöverns": "bockhornsklöver",
    "bockhornsklövers": "bockhornsklöver",
    "bockningar": "bockning",
    "bockningarna": "bockning",
    "bockningarnas": "bockning",
    "bockningars": "bockning",
    "bockningen": "bockning",
    "bockningens": "bockning",
    "bocknings": "bockning",
    "bockproven": "bockprov",
    "bockprovens": "bockprov",
    "bockprovet": "bockprov",
    "bockprovets": "bockprov",
    "bockprovs": "bockprov",
    "bocks": "bock",
    "bockskäggen": "bockskägg",
    "bockskäggens": "bockskägg",
    "bockskägget": "bockskägg",
    "bockskäggets": "bockskägg",
    "bockskäggs": "bockskägg",
    "bocktörnes": "bocktörne",
    "bocktörnet": "bocktörne",
    "bocktörnets": "bocktörne",
    "bockverktygen": "bockverktyg",
    "bockverktygens": "bockverktyg",
    "bockverktyget": "bockverktyg",
    "bockverktygets": "bockverktyg",
    "bockverktygs": "bockverktyg",
    "bockvinkeln": "bockvinkel",
    "bockvinkelns": "bockvinkel",
    "bockvinkels": "bockvinkel",
    "bockvinklar": "bockvinkel",
    "bockvinklarna": "bockvinkel",
    "bockvinklarnas": "bockvinkel",
    "bockvinklars": "bockvinkel",
    "bockölet": "bocköl",
    "bockölets": "bocköl",
    "bocköls": "bocköl",
    "bodar": "bod",
    "bodarna": "bod",
    "bodarnas": "bod",
    "bodars": "bod",
    "bodbetjänten": "bodbetjänt",
    "bodbetjäntens": "bodbetjänt",
    "bodbetjänter": "bodbetjänt",
    "bodbetjänterna": "bodbetjänt",
    "bodbetjänternas": "bodbetjänt",
    "bodbetjänters": "bodbetjänt",
    "bodbetjänts": "bodbetjänt",
    "bodd": "bo",
    "bodda": "bo",
    "boddas": "bo",
    "bodde": "bo",
    "boddes": "bo",
    "bodds": "bo",
    "bodeg": "bodega",
    "bodegan": "bodega",
    "bodegans": "bodega",
    "bodegas": "bodega",
    "bodege": "bodega",
    "bodegor": "bodega",
    "bodegorna": "bodega",
    "bodegornas": "bodega",
    "bodegors": "bodega",
    "bodegs": "bodega",
    "bodelningar": "bodelning",
    "bodelningarna": "bodelning",
    "bodelningarnas": "bodelning",
    "bodelningars": "bodelning",
    "bodelningen": "bodelning",
    "bodelningens": "bodelning",
    "bodelnings": "bodelning",
    "boden": "bod",
    "bodens": "bod",
    "bodknoddar": "bodknodd",
    "bodknoddarna": "bodknodd",
    "bodknoddarnas": "bodknodd",
    "bodknoddars": "bodknodd",
    "bodknodden": "bodknodd",
    "bodknoddens": "bodknodd",
    "bodknodds": "bodknodd",
    "bodmerier": "bodmeri",
    "bodmerierna": "bodmeri",
    "bodmeriernas": "bodmeri",
    "bodmeriers": "bodmeri",
    "bodmeriet": "bodmeri",
    "bodmeriets": "bodmeri",
    "bodmeris": "bodmeri",
    "bodmerit": "bodmeri",
    "bodmerits": "bodmeri",
    "bodräkten": "bodräkt",
    "bodräktens": "bodräkt",
    "bodräkts": "bodräkt",
    "bods": "bod",
    "bodybuildingar": "bodybuilding",
    "bodybuildingarna": "bodybuilding",
    "bodybuildingarnas": "bodybuilding",
    "bodybuildingars": "bodybuilding",
    "bodybuildingen": "bodybuilding",
    "bodybuildingens": "bodybuilding",
    "bodybuildings": "bodybuilding",
    "boen": "bo",
    "boende": "bo",
    "boendeformen": "boendeform",
    "boendeformens": "boendeform",
    "boendeformer": "boendeform",
    "boendeformerna": "boendeform",
    "boendeformernas": "boendeform",
    "boendeformers": "boendeform",
    "boendeforms": "boendeform",
    "boendekostnaden": "boendekostnad",
    "boendekostnadens": "boendekostnad",
    "boendekostnader": "boendekostnad",
    "boendekostnaderna": "boendekostnad",
    "boendekostnadernas": "boendekostnad",
    "boendekostnaders": "boendekostnad",
    "boendekostnads": "boendekostnad",
    "boenden": "boende",
    "boendena": "boende",
    "boendenas": "boende",
    "boendens": "boende",
    "boendes": "boende",
    "boendet": "boende",
    "boendets": "boende",
    "boens": "bo",
    "boern": "boer",
    "boerna": "boer",
    "boernas": "boer",
    "boerns": "boer",
    "boers": "boer",
    "boet": "bo",
    "boets": "bo",
    "boetten": "boett",
    "boettens": "boett",
    "boetter": "boett",
    "boetterna": "boett",
    "boetternas": "boett",
    "boetters": "boett",
    "boetts": "boett",
    "bofasta": "bofast",
    "bofastare": "bofast",
    "bofastares": "bofast",
    "bofastas": "bofast",
    "bofastast": "bofast",
    "bofastaste": "bofast",
    "bofastastes": "bofast",
    "bofastasts": "bofast",
    "bofaste": "bofast",
    "bofastes": "bofast",
    "bofastheten": "bofasthet",
    "bofasthetens": "bofasthet",
    "bofasthets": "bofasthet",
    "bofasts": "bofast",
    "bofinkar": "bofink",
    "bofinkarna": "bofink",
    "bofinkarnas": "bofink",
    "bofinkars": "bofink",
    "bofinken": "bofink",
    "bofinkens": "bofink",
    "bofinks": "bofink",
    "bofälliga": "bofällig",
    "bofälligare": "bofällig",
    "bofälligares": "bofällig",
    "bofälligas": "bofällig",
    "bofälligast": "bofällig",
    "bofälligaste": "bofällig",
    "bofälligastes": "bofällig",
    "bofälligasts": "bofällig",
    "bofällige": "bofällig",
    "bofälliges": "bofällig",
    "bofälligheten": "bofällighet",
    "bofällighetens": "bofällighet",
    "bofällighets": "bofällighet",
    "bofälligs": "bofällig",
    "bofälligt": "bofällig",
    "bofälligts": "bofällig",
    "bogankar": "bogankare",
    "bogankaren": "bogankare",
    "bogankarens": "bogankare",
    "bogankares": "bogankare",
    "bogankaret": "bogankare",
    "bogankarets": "bogankare",
    "bogankarna": "bogankare",
    "bogankarnas": "bogankare",
    "bogar": "bog",
    "bogarna": "bog",
    "bogarnas": "bog",
    "bogars": "bog",
    "bogbladen": "bogblad",
    "bogbladens": "bogblad",
    "bogbladet": "bogblad",
    "bogbladets": "bogblad",
    "bogblads": "bogblad",
    "bogbrutens": "bogbruten",
    "bogbrutet": "bogbruten",
    "bogbrutets": "bogbruten",
    "bogbrutna": "bogbruten",
    "bogbrutnare": "bogbruten",
    "bogbrutnares": "bogbruten",
    "bogbrutnas": "bogbruten",
    "bogbrutnast": "bogbruten",
    "bogbrutnaste": "bogbruten",
    "bogbrutnastes": "bogbruten",
    "bogbrutnasts": "bogbruten",
    "bogbrutne": "bogbruten",
    "bogbrutnes": "bogbruten",
    "bogen": "bog",
    "bogens": "bog",
    "boggier": "boggi",
    "boggierna": "boggi",
    "boggiernas": "boggi",
    "boggiers": "boggi",
    "boggin": "boggi",
    "boggins": "boggi",
    "boggis": "boggi",
    "boghalta": "boghalt",
    "boghaltare": "boghalt",
    "boghaltares": "boghalt",
    "boghaltas": "boghalt",
    "boghaltast": "boghalt",
    "boghaltaste": "boghalt",
    "boghaltastes": "boghalt",
    "boghaltasts": "boghalt",
    "boghalte": "boghalt",
    "boghaltes": "boghalt",
    "boghalts": "boghalt",
    "boghöjden": "boghöjd",
    "boghöjdens": "boghöjd",
    "boghöjder": "boghöjd",
    "boghöjderna": "boghöjd",
    "boghöjdernas": "boghöjd",
    "boghöjders": "boghöjd",
    "boghöjds": "boghöjd",
    "bogpropellern": "bogpropeller",
    "bogpropellerns": "bogpropeller",
    "bogpropellers": "bogpropeller",
    "bogpropellrar": "bogpropeller",
    "bogpropellrarna": "bogpropeller",
    "bogpropellrarnas": "bogpropeller",
    "bogpropellrars": "bogpropeller",
    "bogs": "bog",
    "bogserad": "bogsera",
    "bogserade": "bogsera",
    "bogserades": "bogsera",
    "bogserads": "bogsera",
    "bogserande": "bogsera",
    "bogseranden": "bogserande",
    "bogserandena": "bogserande",
    "bogserandenas": "bogserande",
    "bogserandens": "bogserande",
    "bogserandes": "bogserande",
    "bogserandet": "bogserande",
    "bogserandets": "bogserande",
    "bogserar": "bogserare",
    "bogseraren": "bogserare",
    "bogserarens": "bogserare",
    "bogserares": "bogserare",
    "bogserarna": "bogserare",
    "bogserarnas": "bogserare",
    "bogseras": "bogsera",
    "bogserat": "bogsera",
    "bogserats": "bogsera",
    "bogserbara": "bogserbar",
    "bogserbarare": "bogserbar",
    "bogserbarares": "bogserbar",
    "bogserbaras": "bogserbar",
    "bogserbarast": "bogserbar",
    "bogserbaraste": "bogserbar",
    "bogserbarastes": "bogserbar",
    "bogserbarasts": "bogserbar",
    "bogserbare": "bogserbar",
    "bogserbares": "bogserbar",
    "bogserbarheten": "bogserbarhet",
    "bogserbarhetens": "bogserbarhet",
    "bogserbarhets": "bogserbarhet",
    "bogserbars": "bogserbar",
    "bogserbart": "bogserbar",
    "bogserbarts": "bogserbar",
    "bogserbåtar": "bogserbåt",
    "bogserbåtarna": "bogserbåt",
    "bogserbåtarnas": "bogserbåt",
    "bogserbåtars": "bogserbåt",
    "bogserbåten": "bogserbåt",
    "bogserbåtens": "bogserbåt",
    "bogserbåts": "bogserbåt",
    "bogsergalg": "bogsergalge",
    "bogsergalgar": "bogsergalge",
    "bogsergalgarna": "bogsergalge",
    "bogsergalgarnas": "bogsergalge",
    "bogsergalgars": "bogsergalge",
    "bogsergalgen": "bogsergalge",
    "bogsergalgens": "bogsergalge",
    "bogsergalges": "bogsergalge",
    "bogsergalgs": "bogsergalge",
    "bogseringar": "bogsering",
    "bogseringarna": "bogsering",
    "bogseringarnas": "bogsering",
    "bogseringars": "bogsering",
    "bogseringen": "bogsering",
    "bogseringens": "bogsering",
    "bogserings": "bogsering",
    "bogserlin": "bogserlina",
    "bogserlinan": "bogserlina",
    "bogserlinans": "bogserlina",
    "bogserlinas": "bogserlina",
    "bogserline": "bogserlina",
    "bogserlinor": "bogserlina",
    "bogserlinorna": "bogserlina",
    "bogserlinornas": "bogserlina",
    "bogserlinors": "bogserlina",
    "bogserlins": "bogserlina",
    "bogsersläpen": "bogsersläp",
    "bogsersläpens": "bogsersläp",
    "bogsersläpet": "bogsersläp",
    "bogsersläpets": "bogsersläp",
    "bogsersläps": "bogsersläp",
    "bogsertrossar": "bogsertross",
    "bogsertrossarna": "bogsertross",
    "bogsertrossarnas": "bogsertross",
    "bogsertrossars": "bogsertross",
    "bogsertrossen": "bogsertross",
    "bogsertrossens": "bogsertross",
    "bogspröten": "bogspröt",
    "bogsprötens": "bogspröt",
    "bogsprötet": "bogspröt",
    "bogsprötets": "bogspröt",
    "bogspröts": "bogspröt",
    "bogvisiren": "bogvisir",
    "bogvisirens": "bogvisir",
    "bogvisiret": "bogvisir",
    "bogvisirets": "bogvisir",
    "bogvisirs": "bogvisir",
    "bohagen": "bohag",
    "bohagens": "bohag",
    "bohaget": "bohag",
    "bohagets": "bohag",
    "bohags": "bohag",
    "bohemen": "bohem",
    "bohemens": "bohem",
    "bohemer": "bohem",
    "bohemerna": "bohem",
    "bohemernas": "bohem",
    "bohemers": "bohem",
    "bohemiska": "bohemisk",
    "bohemiskare": "bohemisk",
    "bohemiskares": "bohemisk",
    "bohemiskas": "bohemisk",
    "bohemiskast": "bohemisk",
    "bohemiskaste": "bohemisk",
    "bohemiskastes": "bohemisk",
    "bohemiskasts": "bohemisk",
    "bohemiske": "bohemisk",
    "bohemiskes": "bohemisk",
    "bohemisks": "bohemisk",
    "bohemiskt": "bohemisk",
    "bohemiskts": "bohemisk",
    "bohems": "bohem",
    "bohusek": "bohuseka",
    "bohusekan": "bohuseka",
    "bohusekans": "bohuseka",
    "bohusekas": "bohuseka",
    "bohuseke": "bohuseka",
    "bohusekor": "bohuseka",
    "bohusekorna": "bohuseka",
    "bohusekornas": "bohuseka",
    "bohusekors": "bohuseka",
    "bohuseks": "bohuseka",
    "bohusläningar": "bohusläning",
    "bohusläningarna": "bohusläning",
    "bohusläningarnas": "bohusläning",
    "bohusläningars": "bohusläning",
    "bohusläningen": "bohusläning",
    "bohusläningens": "bohusläning",
    "bohuslänings": "bohusläning",
    "bohuslänningar": "bohuslänning",
    "bohuslänningarna": "bohuslänning",
    "bohuslänningarnas": "bohuslänning",
    "bohuslänningars": "bohuslänning",
    "bohuslänningen": "bohuslänning",
    "bohuslänningens": "bohuslänning",
    "bohuslännings": "bohuslänning",
    "bohuslänsk": "bohuslänska",
    "bohuslänska": "bohuslänsk",
    "bohuslänskan": "bohuslänska",
    "bohuslänskans": "bohuslänska",
    "bohuslänskare": "bohuslänsk",
    "bohuslänskares": "bohuslänsk",
    "bohuslänskas": "bohuslänska",
    "bohuslänskast": "bohuslänsk",
    "bohuslänskaste": "bohuslänsk",
    "bohuslänskastes": "bohuslänsk",
    "bohuslänskasts": "bohuslänsk",
    "bohuslänske": "bohuslänska",
    "bohuslänskes": "bohuslänsk",
    "bohuslänskor": "bohuslänska",
    "bohuslänskorna": "bohuslänska",
    "bohuslänskornas": "bohuslänska",
    "bohuslänskors": "bohuslänska",
    "bohuslänsks": "bohuslänsk",
    "bohuslänskt": "bohuslänsk",
    "bohuslänskts": "bohuslänsk",
    "boj": "boja",
    "bojan": "boja",
    "bojans": "boja",
    "bojar": "boj",
    "bojaren": "bojar",
    "bojarens": "bojar",
    "bojarer": "bojar",
    "bojarerna": "bojar",
    "bojarernas": "bojar",
    "bojarers": "bojar",
    "bojarna": "boj",
    "bojarnas": "boj",
    "bojars": "bojar",
    "bojas": "boja",
    "boje": "boja",
    "bojen": "boj",
    "bojens": "boj",
    "bojer": "boj",
    "bojerna": "boj",
    "bojernas": "boj",
    "bojers": "boj",
    "bojkott": "bojkotta",
    "bojkottad": "bojkotta",
    "bojkottade": "bojkotta",
    "bojkottades": "bojkotta",
    "bojkottads": "bojkotta",
    "bojkottande": "bojkotta",
    "bojkottanden": "bojkottande",
    "bojkottandena": "bojkottande",
    "bojkottandenas": "bojkottande",
    "bojkottandens": "bojkottande",
    "bojkottandes": "bojkottande",
    "bojkottandet": "bojkottande",
    "bojkottandets": "bojkottande",
    "bojkottar": "bojkotta",
    "bojkottas": "bojkotta",
    "bojkottat": "bojkotta",
    "bojkottats": "bojkotta",
    "bojkotten": "bojkott",
    "bojkottens": "bojkott",
    "bojkotter": "bojkott",
    "bojkotterna": "bojkott",
    "bojkotternas": "bojkott",
    "bojkotters": "bojkott",
    "bojkotts": "bojkott",
    "bojor": "boja",
    "bojorna": "boja",
    "bojornas": "boja",
    "bojors": "boja",
    "bojs": "boja",
    "bok": "boka",
    "bokad": "boka",
    "bokade": "boka",
    "bokades": "boka",
    "bokads": "boka",
    "bokande": "boka",
    "bokanden": "bokande",
    "bokandena": "bokande",
    "bokandenas": "bokande",
    "bokandens": "bokande",
    "bokandes": "bokande",
    "bokandet": "bokande",
    "bokandets": "bokande",
    "bokanmälans": "bokanmälan",
    "bokanmälningar": "bokanmälan",
    "bokanmälningarna": "bokanmälan",
    "bokanmälningarnas": "bokanmälan",
    "bokanmälningars": "bokanmälan",
    "bokar": "boka",
    "bokarna": "bok",
    "bokarnas": "bok",
    "bokars": "bok",
    "bokas": "boka",
    "bokat": "boka",
    "bokats": "boka",
    "bokauktionen": "bokauktion",
    "bokauktionens": "bokauktion",
    "bokauktioner": "bokauktion",
    "bokauktionerna": "bokauktion",
    "bokauktionernas": "bokauktion",
    "bokauktioners": "bokauktion",
    "bokauktions": "bokauktion",
    "bokbanden": "bokband",
    "bokbandens": "bokband",
    "bokbandet": "bokband",
    "bokbandets": "bokband",
    "bokbands": "bokband",
    "bokbindar": "bokbindare",
    "bokbindaren": "bokbindare",
    "bokbindarens": "bokbindare",
    "bokbindares": "bokbindare",
    "bokbindarna": "bokbindare",
    "bokbindarnas": "bokbindare",
    "bokbinderier": "bokbinderi",
    "bokbinderierna": "bokbinderi",
    "bokbinderiernas": "bokbinderi",
    "bokbinderiers": "bokbinderi",
    "bokbinderiet": "bokbinderi",
    "bokbinderiets": "bokbinderi",
    "bokbinderis": "bokbinderi",
    "bokbinderit": "bokbinderi",
    "bokbinderits": "bokbinderi",
    "bokbindningar": "bokbindning",
    "bokbindningarna": "bokbindning",
    "bokbindningarnas": "bokbindning",
    "bokbindningars": "bokbindning",
    "bokbindningen": "bokbindning",
    "bokbindningens": "bokbindning",
    "bokbindnings": "bokbindning",
    "bokbussar": "bokbuss",
    "bokbussarna": "bokbuss",
    "bokbussarnas": "bokbuss",
    "bokbussars": "bokbuss",
    "bokbussen": "bokbuss",
    "bokbussens": "bokbuss",
    "bokdammar": "bokdamm",
    "bokdammarna": "bokdamm",
    "bokdammarnas": "bokdamm",
    "bokdammars": "bokdamm",
    "bokdammen": "bokdamm",
    "bokdammens": "bokdamm",
    "bokdamms": "bokdamm",
    "boken": "bok",
    "bokenheten": "bokenhet",
    "bokenhetens": "bokenhet",
    "bokenhets": "bokenhet",
    "bokens": "boken",
    "bokes": "boke",
    "boket": "boken",
    "bokets": "boken",
    "bokfilmen": "bokfilm",
    "bokfilmens": "bokfilm",
    "bokfilmer": "bokfilm",
    "bokfilmerna": "bokfilm",
    "bokfilmernas": "bokfilm",
    "bokfilmers": "bokfilm",
    "bokfilms": "bokfilm",
    "bokfloden": "bokflod",
    "bokflodens": "bokflod",
    "bokfloder": "bokflod",
    "bokfloderna": "bokflod",
    "bokflodernas": "bokflod",
    "bokfloders": "bokflod",
    "bokflods": "bokflod",
    "bokformaten": "bokformat",
    "bokformatens": "bokformat",
    "bokformatet": "bokformat",
    "bokformatets": "bokformat",
    "bokformats": "bokformat",
    "bokformen": "bokform",
    "bokformens": "bokform",
    "bokforms": "bokform",
    "bokför": "bokföra",
    "bokförande": "bokföra",
    "bokföranden": "bokförande",
    "bokförandena": "bokförande",
    "bokförandenas": "bokförande",
    "bokförandens": "bokförande",
    "bokförandes": "bokförande",
    "bokförandet": "bokförande",
    "bokförandets": "bokförande",
    "bokföras": "bokföra",
    "bokförd": "bokföra",
    "bokförda": "bokföra",
    "bokfördas": "bokföra",
    "bokförde": "bokföra",
    "bokfördes": "bokföra",
    "bokförds": "bokföra",
    "bokföres": "bokföra",
    "bokföringar": "bokföring",
    "bokföringarna": "bokföring",
    "bokföringarnas": "bokföring",
    "bokföringars": "bokföring",
    "bokföringen": "bokföring",
    "bokföringens": "bokföring",
    "bokförings": "bokföring",
    "bokföringsbrotten": "bokföringsbrott",
    "bokföringsbrottens": "bokföringsbrott",
    "bokföringsbrottet": "bokföringsbrott",
    "bokföringsbrottets": "bokföringsbrott",
    "bokföringsbrotts": "bokföringsbrott",
    "bokföringsmässiga": "bokföringsmässig",
    "bokföringsmässigare": "bokföringsmässig",
    "bokföringsmässigares": "bokföringsmässig",
    "bokföringsmässigas": "bokföringsmässig",
    "bokföringsmässigast": "bokföringsmässig",
    "bokföringsmässigaste": "bokföringsmässig",
    "bokföringsmässigastes": "bokföringsmässig",
    "bokföringsmässigasts": "bokföringsmässig",
    "bokföringsmässige": "bokföringsmässig",
    "bokföringsmässiges": "bokföringsmässig",
    "bokföringsmässigheten": "bokföringsmässighet",
    "bokföringsmässighetens": "bokföringsmässighet",
    "bokföringsmässighets": "bokföringsmässighet",
    "bokföringsmässigs": "bokföringsmässig",
    "bokföringsmässigt": "bokföringsmässig",
    "bokföringsmässigts": "bokföringsmässig",
    "bokföringsplikten": "bokföringsplikt",
    "bokföringspliktens": "bokföringsplikt",
    "bokföringsplikts": "bokföringsplikt",
    "bokföringsskyldiga": "bokföringsskyldig",
    "bokföringsskyldigare": "bokföringsskyldig",
    "bokföringsskyldigares": "bokföringsskyldig",
    "bokföringsskyldigas": "bokföringsskyldig",
    "bokföringsskyldigast": "bokföringsskyldig",
    "bokföringsskyldigaste": "bokföringsskyldig",
    "bokföringsskyldigastes": "bokföringsskyldig",
    "bokföringsskyldigasts": "bokföringsskyldig",
    "bokföringsskyldige": "bokföringsskyldig",
    "bokföringsskyldiges": "bokföringsskyldig",
    "bokföringsskyldigheten": "bokföringsskyldighet",
    "bokföringsskyldighetens": "bokföringsskyldighet",
    "bokföringsskyldigheter": "bokföringsskyldighet",
    "bokföringsskyldigheterna": "bokföringsskyldighet",
    "bokföringsskyldigheternas": "bokföringsskyldighet",
    "bokföringsskyldigheters": "bokföringsskyldighet",
    "bokföringsskyldighets": "bokföringsskyldighet",
    "bokföringsskyldigs": "bokföringsskyldig",
    "bokföringsskyldigt": "bokföringsskyldig",
    "bokföringsskyldigts": "bokföringsskyldig",
    "bokföringsåren": "bokföringsår",
    "bokföringsårens": "bokföringsår",
    "bokföringsåret": "bokföringsår",
    "bokföringsårets": "bokföringsår",
    "bokföringsårs": "bokföringsår",
    "bokförlagen": "bokförlag",
    "bokförlagens": "bokförlag",
    "bokförlaget": "bokförlag",
    "bokförlagets": "bokförlag",
    "bokförlags": "bokförlag",
    "bokförläggar": "bokförläggare",
    "bokförläggaren": "bokförläggare",
    "bokförläggarens": "bokförläggare",
    "bokförläggares": "bokförläggare",
    "bokförläggarna": "bokförläggare",
    "bokförläggarnas": "bokförläggare",
    "bokförs": "bokföra",
    "bokfört": "bokföra",
    "bokförts": "bokföra",
    "bokhandeln": "bokhandel",
    "bokhandelns": "bokhandel",
    "bokhandels": "bokhandel",
    "bokhandlar": "bokhandlare",
    "bokhandlaren": "bokhandlare",
    "bokhandlarens": "bokhandlare",
    "bokhandlares": "bokhandlare",
    "bokhandlarna": "bokhandlare",
    "bokhandlarnas": "bokhandlare",
    "bokhandlars": "bokhandel",
    "bokhantverket": "bokhantverk",
    "bokhantverkets": "bokhantverk",
    "bokhantverks": "bokhantverk",
    "bokhyll": "bokhylla",
    "bokhyllan": "bokhylla",
    "bokhyllans": "bokhylla",
    "bokhyllas": "bokhylla",
    "bokhylle": "bokhylla",
    "bokhyllor": "bokhylla",
    "bokhyllorna": "bokhylla",
    "bokhyllornas": "bokhylla",
    "bokhyllors": "bokhylla",
    "bokhylls": "bokhylla",
    "bokhållar": "bokhållare",
    "bokhållaren": "bokhållare",
    "bokhållarens": "bokhållare",
    "bokhållares": "bokhållare",
    "bokhållarna": "bokhållare",
    "bokhållarnas": "bokhållare",
    "bokkass": "bokkasse",
    "bokkassar": "bokkasse",
    "bokkassarna": "bokkasse",
    "bokkassarnas": "bokkasse",
    "bokkassars": "bokkasse",
    "bokkassen": "bokkasse",
    "bokkassens": "bokkasse",
    "bokkasses": "bokkasse",
    "bokklubbar": "bokklubb",
    "bokklubbarna": "bokklubb",
    "bokklubbarnas": "bokklubb",
    "bokklubbars": "bokklubb",
    "bokklubben": "bokklubb",
    "bokklubbens": "bokklubb",
    "bokklubbs": "bokklubb",
    "bokliga": "boklig",
    "bokligare": "boklig",
    "bokligares": "boklig",
    "bokligas": "boklig",
    "bokligast": "boklig",
    "bokligaste": "boklig",
    "bokligastes": "boklig",
    "bokligasts": "boklig",
    "boklige": "boklig",
    "bokliges": "boklig",
    "bokligheten": "boklighet",
    "boklighetens": "boklighet",
    "boklighets": "boklighet",
    "bokligs": "boklig",
    "bokligt": "boklig",
    "bokligts": "boklig",
    "boklärda": "boklärd",
    "boklärdare": "boklärd",
    "boklärdares": "boklärd",
    "boklärdas": "boklärd",
    "boklärdast": "boklärd",
    "boklärdaste": "boklärd",
    "boklärdastes": "boklärd",
    "boklärdasts": "boklärd",
    "boklärde": "boklärd",
    "boklärdes": "boklärd",
    "boklärdheten": "boklärdhet",
    "boklärdhetens": "boklärdhet",
    "boklärdhets": "boklärdhet",
    "boklärds": "boklärd",
    "boklärt": "boklärd",
    "boklärts": "boklärd",
    "boklåd": "boklåda",
    "boklådan": "boklåda",
    "boklådans": "boklåda",
    "boklådas": "boklåda",
    "boklåde": "boklåda",
    "boklådor": "boklåda",
    "boklådorna": "boklåda",
    "boklådornas": "boklåda",
    "boklådors": "boklåda",
    "boklåds": "boklåda",
    "boklånen": "boklån",
    "boklånens": "boklån",
    "boklånet": "boklån",
    "boklånets": "boklån",
    "boklåns": "boklån",
    "bokmagasinen": "bokmagasin",
    "bokmagasinens": "bokmagasin",
    "bokmagasinet": "bokmagasin",
    "bokmagasinets": "bokmagasin",
    "bokmagasins": "bokmagasin",
    "bokmalar": "bokmal",
    "bokmalarna": "bokmal",
    "bokmalarnas": "bokmal",
    "bokmalars": "bokmal",
    "bokmalen": "bokmal",
    "bokmalens": "bokmal",
    "bokmals": "bokmal",
    "bokmarknaden": "bokmarknad",
    "bokmarknadens": "bokmarknad",
    "bokmarknader": "bokmarknad",
    "bokmarknaderna": "bokmarknad",
    "bokmarknadernas": "bokmarknad",
    "bokmarknaders": "bokmarknad",
    "bokmarknads": "bokmarknad",
    "bokmärken": "bokmärke",
    "bokmärkena": "bokmärke",
    "bokmärkenas": "bokmärke",
    "bokmärkens": "bokmärke",
    "bokmärkes": "bokmärke",
    "bokmärket": "bokmärke",
    "bokmärkets": "bokmärke",
    "bokmäss": "bokmässa",
    "bokmässan": "bokmässa",
    "bokmässans": "bokmässa",
    "bokmässas": "bokmässa",
    "bokmässe": "bokmässa",
    "bokmässor": "bokmässa",
    "bokmässorna": "bokmässa",
    "bokmässornas": "bokmässa",
    "bokmässors": "bokmässa",
    "bokmålet": "bokmål",
    "bokmålets": "bokmål",
    "bokmåls": "bokmål",
    "bokna": "boken",
    "boknade": "bokna",
    "boknades": "bokna",
    "boknande": "bokna",
    "boknanden": "boknande",
    "boknandena": "boknande",
    "boknandenas": "boknande",
    "boknandens": "boknande",
    "boknandes": "boknande",
    "boknandet": "boknande",
    "boknandets": "boknande",
    "boknar": "bokna",
    "boknare": "boken",
    "boknares": "boken",
    "boknas": "bokna",
    "boknast": "boken",
    "boknaste": "boken",
    "boknastes": "boken",
    "boknasts": "boken",
    "boknat": "bokna",
    "boknats": "bokna",
    "bokne": "boken",
    "boknes": "boken",
    "bokningar": "bokning",
    "bokningarna": "bokning",
    "bokningarnas": "bokning",
    "bokningars": "bokning",
    "bokningen": "bokning",
    "bokningens": "bokning",
    "boknings": "bokning",
    "bokollonen": "bokollon",
    "bokollonens": "bokollon",
    "bokollonet": "bokollon",
    "bokollonets": "bokollon",
    "bokollons": "bokollon",
    "bokomslagen": "bokomslag",
    "bokomslagens": "bokomslag",
    "bokomslaget": "bokomslag",
    "bokomslagets": "bokomslag",
    "bokomslags": "bokomslag",
    "bokraden": "bokrad",
    "bokradens": "bokrad",
    "bokrader": "bokrad",
    "bokraderna": "bokrad",
    "bokradernas": "bokrad",
    "bokraders": "bokrad",
    "bokrads": "bokrad",
    "bokrull": "bokrulle",
    "bokrullar": "bokrulle",
    "bokrullarna": "bokrulle",
    "bokrullarnas": "bokrulle",
    "bokrullars": "bokrulle",
    "bokrullen": "bokrulle",
    "bokrullens": "bokrulle",
    "bokrulles": "bokrulle",
    "bokrulls": "bokrulle",
    "bokryggar": "bokrygg",
    "bokryggarna": "bokrygg",
    "bokryggarnas": "bokrygg",
    "bokryggars": "bokrygg",
    "bokryggen": "bokrygg",
    "bokryggens": "bokrygg",
    "bokryggs": "bokrygg",
    "boks": "bok",
    "boksamlar": "boksamlare",
    "boksamlaren": "boksamlare",
    "boksamlarens": "boksamlare",
    "boksamlares": "boksamlare",
    "boksamlarna": "boksamlare",
    "boksamlarnas": "boksamlare",
    "boksamlingar": "boksamling",
    "boksamlingarna": "boksamling",
    "boksamlingarnas": "boksamling",
    "boksamlingars": "boksamling",
    "boksamlingen": "boksamling",
    "boksamlingens": "boksamling",
    "boksamlings": "boksamling",
    "boksidan": "boksida",
    "boksidans": "boksida",
    "boksidas": "boksida",
    "bokside": "boksida",
    "boksides": "boksida",
    "boksidor": "boksida",
    "boksidorna": "boksida",
    "boksidornas": "boksida",
    "boksidors": "boksida",
    "bokskogar": "bokskog",
    "bokskogarna": "bokskog",
    "bokskogarnas": "bokskog",
    "bokskogars": "bokskog",
    "bokskogen": "bokskog",
    "bokskogens": "bokskog",
    "bokskogs": "bokskog",
    "boksluten": "bokslut",
    "bokslutens": "bokslut",
    "bokslutet": "bokslut",
    "bokslutets": "bokslut",
    "boksluts": "bokslut",
    "bokstaven": "bokstav",
    "bokstavens": "bokstav",
    "bokstaverad": "bokstavera",
    "bokstaverade": "bokstavera",
    "bokstaverades": "bokstavera",
    "bokstaverads": "bokstavera",
    "bokstaverande": "bokstavera",
    "bokstaveranden": "bokstaverande",
    "bokstaverandena": "bokstaverande",
    "bokstaverandenas": "bokstaverande",
    "bokstaverandens": "bokstaverande",
    "bokstaverandes": "bokstaverande",
    "bokstaverandet": "bokstaverande",
    "bokstaverandets": "bokstaverande",
    "bokstaverar": "bokstavera",
    "bokstaveras": "bokstavera",
    "bokstaverat": "bokstavera",
    "bokstaverats": "bokstavera",
    "bokstaverbara": "bokstaverbar",
    "bokstaverbarare": "bokstaverbar",
    "bokstaverbarares": "bokstaverbar",
    "bokstaverbaras": "bokstaverbar",
    "bokstaverbarast": "bokstaverbar",
    "bokstaverbaraste": "bokstaverbar",
    "bokstaverbarastes": "bokstaverbar",
    "bokstaverbarasts": "bokstaverbar",
    "bokstaverbare": "bokstaverbar",
    "bokstaverbares": "bokstaverbar",
    "bokstaverbarheten": "bokstaverbarhet",
    "bokstaverbarhetens": "bokstaverbarhet",
    "bokstaverbarhets": "bokstaverbarhet",
    "bokstaverbars": "bokstaverbar",
    "bokstaverbart": "bokstaverbar",
    "bokstaverbarts": "bokstaverbar",
    "bokstaveringar": "bokstavering",
    "bokstaveringarna": "bokstavering",
    "bokstaveringarnas": "bokstavering",
    "bokstaveringars": "bokstavering",
    "bokstaveringen": "bokstavering",
    "bokstaveringens": "bokstavering",
    "bokstaverings": "bokstavering",
    "bokstavliga": "bokstavlig",
    "bokstavligare": "bokstavlig",
    "bokstavligares": "bokstavlig",
    "bokstavligas": "bokstavlig",
    "bokstavligast": "bokstavlig",
    "bokstavligaste": "bokstavlig",
    "bokstavligastes": "bokstavlig",
    "bokstavligasts": "bokstavlig",
    "bokstavlige": "bokstavlig",
    "bokstavliges": "bokstavlig",
    "bokstavligheten": "bokstavlighet",
    "bokstavlighetens": "bokstavlighet",
    "bokstavligheter": "bokstavlighet",
    "bokstavligheterna": "bokstavlighet",
    "bokstavligheternas": "bokstavlighet",
    "bokstavligheters": "bokstavlighet",
    "bokstavlighets": "bokstavlighet",
    "bokstavligs": "bokstavlig",
    "bokstavligt": "bokstavlig",
    "bokstavligts": "bokstavlig",
    "bokstavs": "bokstav",
    "bokstavsbarnen": "bokstavsbarn",
    "bokstavsbarnens": "bokstavsbarn",
    "bokstavsbarnet": "bokstavsbarn",
    "bokstavsbarnets": "bokstavsbarn",
    "bokstavsbarns": "bokstavsbarn",
    "bokstavsbeteckningar": "bokstavsbeteckning",
    "bokstavsbeteckningarna": "bokstavsbeteckning",
    "bokstavsbeteckningarnas": "bokstavsbeteckning",
    "bokstavsbeteckningars": "bokstavsbeteckning",
    "bokstavsbeteckningen": "bokstavsbeteckning",
    "bokstavsbeteckningens": "bokstavsbeteckning",
    "bokstavsbetecknings": "bokstavsbeteckning",
    "bokstavsföljden": "bokstavsföljd",
    "bokstavsföljdens": "bokstavsföljd",
    "bokstavsföljder": "bokstavsföljd",
    "bokstavsföljderna": "bokstavsföljd",
    "bokstavsföljdernas": "bokstavsföljd",
    "bokstavsföljders": "bokstavsföljd",
    "bokstavsföljds": "bokstavsföljd",
    "bokstavsinspirationen": "bokstavsinspiration",
    "bokstavsinspirationens": "bokstavsinspiration",
    "bokstavsinspirationer": "bokstavsinspiration",
    "bokstavsinspirationerna": "bokstavsinspiration",
    "bokstavsinspirationernas": "bokstavsinspiration",
    "bokstavsinspirationers": "bokstavsinspiration",
    "bokstavsinspirations": "bokstavsinspiration",
    "bokstavsmystiken": "bokstavsmystik",
    "bokstavsmystikens": "bokstavsmystik",
    "bokstavsmystiks": "bokstavsmystik",
    "bokstavsordningar": "bokstavsordning",
    "bokstavsordningarna": "bokstavsordning",
    "bokstavsordningarnas": "bokstavsordning",
    "bokstavsordningars": "bokstavsordning",
    "bokstavsordningen": "bokstavsordning",
    "bokstavsordningens": "bokstavsordning",
    "bokstavsordnings": "bokstavsordning",
    "bokstavsrimmen": "bokstavsrim",
    "bokstavsrimmens": "bokstavsrim",
    "bokstavsrimmet": "bokstavsrim",
    "bokstavsrimmets": "bokstavsrim",
    "bokstavsrims": "bokstavsrim",
    "bokstavsskriften": "bokstavsskrift",
    "bokstavsskriftens": "bokstavsskrift",
    "bokstavsskrifts": "bokstavsskrift",
    "bokstavsstansar": "bokstavsstans",
    "bokstavsstansarna": "bokstavsstans",
    "bokstavsstansarnas": "bokstavsstans",
    "bokstavsstansars": "bokstavsstans",
    "bokstavsstansen": "bokstavsstans",
    "bokstavsstansens": "bokstavsstans",
    "bokstavsteckens": "bokstavstecken",
    "bokstavstecknen": "bokstavstecken",
    "bokstavstecknens": "bokstavstecken",
    "bokstavstecknet": "bokstavstecken",
    "bokstavstecknets": "bokstavstecken",
    "bokstavstrogenheten": "bokstavstrogenhet",
    "bokstavstrogenhetens": "bokstavstrogenhet",
    "bokstavstrogenhets": "bokstavstrogenhet",
    "bokstavstrogens": "bokstavstrogen",
    "bokstavstroget": "bokstavstrogen",
    "bokstavstrogets": "bokstavstrogen",
    "bokstavstrogna": "bokstavstrogen",
    "bokstavstrognare": "bokstavstrogen",
    "bokstavstrognares": "bokstavstrogen",
    "bokstavstrognas": "bokstavstrogen",
    "bokstavstrognast": "bokstavstrogen",
    "bokstavstrognaste": "bokstavstrogen",
    "bokstavstrognastes": "bokstavstrogen",
    "bokstavstrognasts": "bokstavstrogen",
    "bokstavstrogne": "bokstavstrogen",
    "bokstavstrognes": "bokstavstrogen",
    "bokstavstron": "bokstavstro",
    "bokstavstrons": "bokstavstro",
    "bokstavstros": "bokstavstro",
    "bokstavsträlar": "bokstavsträl",
    "bokstavsträlarna": "bokstavsträl",
    "bokstavsträlarnas": "bokstavsträl",
    "bokstavsträlars": "bokstavsträl",
    "bokstavsträlen": "bokstavsträl",
    "bokstavsträlens": "bokstavsträl",
    "bokstavsträls": "bokstavsträl",
    "bokstipendie": "bokstipendium",
    "bokstipendier": "bokstipendium",
    "bokstipendierna": "bokstipendium",
    "bokstipendiernas": "bokstipendium",
    "bokstipendiers": "bokstipendium",
    "bokstipendiet": "bokstipendium",
    "bokstipendiets": "bokstipendium",
    "bokstipendiums": "bokstipendium",
    "bokstäver": "bokstav",
    "bokstäverna": "bokstav",
    "bokstävernas": "bokstav",
    "bokstävers": "bokstav",
    "bokstöden": "bokstöd",
    "bokstödens": "bokstöd",
    "bokstödet": "bokstöd",
    "bokstödets": "bokstöd",
    "bokstöds": "bokstöd",
    "boksynta": "boksynt",
    "boksyntare": "boksynt",
    "boksyntares": "boksynt",
    "boksyntas": "boksynt",
    "boksyntast": "boksynt",
    "boksyntaste": "boksynt",
    "boksyntastes": "boksynt",
    "boksyntasts": "boksynt",
    "boksynte": "boksynt",
    "boksyntes": "boksynt",
    "boksyntheten": "boksynthet",
    "boksynthetens": "boksynthet",
    "boksynthets": "boksynthet",
    "boksynts": "boksynt",
    "boktiteln": "boktitel",
    "boktitelns": "boktitel",
    "boktitels": "boktitel",
    "boktitlar": "boktitel",
    "boktitlarna": "boktitel",
    "boktitlarnas": "boktitel",
    "boktitlars": "boktitel",
    "boktornen": "boktorn",
    "boktornens": "boktorn",
    "boktornet": "boktorn",
    "boktornets": "boktorn",
    "boktorns": "boktorn",
    "boktryckar": "boktryckare",
    "boktryckaren": "boktryckare",
    "boktryckarens": "boktryckare",
    "boktryckares": "boktryckare",
    "boktryckarkonsten": "boktryckarkonst",
    "boktryckarkonstens": "boktryckarkonst",
    "boktryckarkonsts": "boktryckarkonst",
    "boktryckarna": "boktryckare",
    "boktryckarnas": "boktryckare",
    "boktryckerier": "boktryckeri",
    "boktryckerierna": "boktryckeri",
    "boktryckeriernas": "boktryckeri",
    "boktryckeriers": "boktryckeri",
    "boktryckeriet": "boktryckeri",
    "boktryckeriets": "boktryckeri",
    "boktryckeris": "boktryckeri",
    "boktryckerit": "boktryckeri",
    "boktryckerits": "boktryckeri",
    "boktrycket": "boktryck",
    "boktryckets": "boktryck",
    "boktrycks": "boktryck",
    "boktrycksstilar": "boktrycksstil",
    "boktrycksstilarna": "boktrycksstil",
    "boktrycksstilarnas": "boktrycksstil",
    "boktrycksstilars": "boktrycksstil",
    "boktrycksstilen": "boktrycksstil",
    "boktrycksstilens": "boktrycksstil",
    "boktrycksstils": "boktrycksstil",
    "bokvalen": "bokval",
    "bokvalens": "bokval",
    "bokvalet": "bokval",
    "bokvalets": "bokval",
    "bokvals": "bokval",
    "bokverken": "bokverk",
    "bokverkens": "bokverk",
    "bokverket": "bokverk",
    "bokverkets": "bokverk",
    "bokverks": "bokverk",
    "bol": "bola",
    "bolade": "bola",
    "bolades": "bola",
    "bolagen": "bolag",
    "bolagens": "bolag",
    "bolaget": "bolag",
    "bolagets": "bolag",
    "bolags": "bolag",
    "bolagsmannen": "bolagsman",
    "bolagsmannens": "bolagsman",
    "bolagsmans": "bolagsman",
    "bolagsmän": "bolagsman",
    "bolagsmännen": "bolagsman",
    "bolagsmännens": "bolagsman",
    "bolagsmäns": "bolagsman",
    "bolagsordningar": "bolagsordning",
    "bolagsordningarna": "bolagsordning",
    "bolagsordningarnas": "bolagsordning",
    "bolagsordningars": "bolagsordning",
    "bolagsordningen": "bolagsordning",
    "bolagsordningens": "bolagsordning",
    "bolagsordnings": "bolagsordning",
    "bolagsskogar": "bolagsskog",
    "bolagsskogarna": "bolagsskog",
    "bolagsskogarnas": "bolagsskog",
    "bolagsskogars": "bolagsskog",
    "bolagsskogen": "bolagsskog",
    "bolagsskogens": "bolagsskog",
    "bolagsskogs": "bolagsskog",
    "bolagsstyrelsen": "bolagsstyrelse",
    "bolagsstyrelsens": "bolagsstyrelse",
    "bolagsstyrelser": "bolagsstyrelse",
    "bolagsstyrelserna": "bolagsstyrelse",
    "bolagsstyrelsernas": "bolagsstyrelse",
    "bolagsstyrelsers": "bolagsstyrelse",
    "bolagsstyrelses": "bolagsstyrelse",
    "bolagsstämman": "bolagsstämma",
    "bolagsstämmans": "bolagsstämma",
    "bolagsstämmas": "bolagsstämma",
    "bolagsstämme": "bolagsstämma",
    "bolagsstämmo": "bolagsstämma",
    "bolagsstämmor": "bolagsstämma",
    "bolagsstämmorna": "bolagsstämma",
    "bolagsstämmornas": "bolagsstämma",
    "bolagsstämmors": "bolagsstämma",
    "bolagsägar": "bolagsägare",
    "bolagsägaren": "bolagsägare",
    "bolagsägarens": "bolagsägare",
    "bolagsägares": "bolagsägare",
    "bolagsägarna": "bolagsägare",
    "bolagsägarnas": "bolagsägare",
    "bolande": "bola",
    "bolanden": "bolande",
    "bolandena": "bolande",
    "bolandenas": "bolande",
    "bolandens": "bolande",
    "bolandes": "bolande",
    "bolandet": "bolande",
    "bolandets": "bolande",
    "bolar": "bolare",
    "bolaren": "bolare",
    "bolarens": "bolare",
    "bolares": "bolare",
    "bolarna": "bolare",
    "bolarnas": "bolare",
    "bolas": "bola",
    "bolat": "bola",
    "bolats": "bola",
    "bolen": "bol",
    "bolens": "bol",
    "boleroer": "bolero",
    "boleroerna": "bolero",
    "boleroernas": "bolero",
    "boleroers": "bolero",
    "boleron": "bolero",
    "bolerons": "bolero",
    "boleror": "bolero",
    "bolerorna": "bolero",
    "bolerornas": "bolero",
    "bolerors": "bolero",
    "boleros": "bolero",
    "bolet": "bol",
    "bolets": "bol",
    "boliden": "bolid",
    "bolidens": "bolid",
    "bolider": "bolid",
    "boliderna": "bolid",
    "bolidernas": "bolid",
    "boliders": "bolid",
    "bolids": "bolid",
    "bolinen": "bolin",
    "bolinens": "bolin",
    "boliner": "bolin",
    "bolinerna": "bolin",
    "bolinernas": "bolin",
    "boliners": "bolin",
    "bolins": "bolin",
    "bolivianen": "bolivian",
    "bolivianens": "bolivian",
    "bolivianer": "bolivian",
    "bolivianerna": "bolivian",
    "bolivianernas": "bolivian",
    "bolivianers": "bolivian",
    "bolivians": "bolivian",
    "bolivianska": "boliviansk",
    "bolivianskan": "bolivianska",
    "bolivianskans": "bolivianska",
    "bolivianskare": "boliviansk",
    "bolivianskares": "boliviansk",
    "bolivianskas": "bolivianska",
    "bolivianskast": "boliviansk",
    "bolivianskaste": "boliviansk",
    "bolivianskastes": "boliviansk",
    "bolivianskasts": "boliviansk",
    "bolivianske": "bolivianska",
    "bolivianskes": "boliviansk",
    "bolivianskor": "bolivianska",
    "bolivianskorna": "bolivianska",
    "bolivianskornas": "bolivianska",
    "bolivianskors": "bolivianska",
    "boliviansks": "boliviansk",
    "bolivianskt": "boliviansk",
    "bolivianskts": "boliviansk",
    "boll": "bolla",
    "bollad": "bolla",
    "bollade": "bolla",
    "bollades": "bolla",
    "bollads": "bolla",
    "bollande": "bolla",
    "bollanden": "bollande",
    "bollandena": "bollande",
    "bollandenas": "bollande",
    "bollandens": "bollande",
    "bollandes": "bollande",
    "bollandet": "bollande",
    "bollandets": "bollande",
    "bollar": "bolla",
    "bollarna": "boll",
    "bollarnas": "boll",
    "bollars": "boll",
    "bollas": "bolla",
    "bollat": "bolla",
    "bollats": "bolla",
    "bollbehandlingar": "bollbehandling",
    "bollbehandlingarna": "bollbehandling",
    "bollbehandlingarnas": "bollbehandling",
    "bollbehandlingars": "bollbehandling",
    "bollbehandlingen": "bollbehandling",
    "bollbehandlingens": "bollbehandling",
    "bollbehandlings": "bollbehandling",
    "bollen": "boll",
    "bollens": "boll",
    "bollhaven": "bollhav",
    "bollhavens": "bollhav",
    "bollhavet": "bollhav",
    "bollhavets": "bollhav",
    "bollhavs": "bollhav",
    "bollkall": "bollkalle",
    "bollkallar": "bollkalle",
    "bollkallarna": "bollkalle",
    "bollkallarnas": "bollkalle",
    "bollkallars": "bollkalle",
    "bollkallen": "bollkalle",
    "bollkallens": "bollkalle",
    "bollkalles": "bollkalle",
    "bollkalls": "bollkalle",
    "bollningar": "bollning",
    "bollningarna": "bollning",
    "bollningarnas": "bollning",
    "bollningars": "bollning",
    "bollningen": "bollning",
    "bollningens": "bollning",
    "bollnings": "bollning",
    "bollplanen": "bollplan",
    "bollplanens": "bollplan",
    "bollplaner": "bollplan",
    "bollplanerna": "bollplan",
    "bollplanernas": "bollplan",
    "bollplaners": "bollplan",
    "bollplanken": "bollplank",
    "bollplankens": "bollplank",
    "bollplanket": "bollplank",
    "bollplankets": "bollplank",
    "bollplanks": "bollplank",
    "bollplans": "bollplan",
    "bollpojk": "bollpojke",
    "bollpojkar": "bollpojke",
    "bollpojkarna": "bollpojke",
    "bollpojkarnas": "bollpojke",
    "bollpojkars": "bollpojke",
    "bollpojken": "bollpojke",
    "bollpojkens": "bollpojke",
    "bollpojkes": "bollpojke",
    "bollpojks": "bollpojke",
    "bolls": "boll",
    "bollsinnes": "bollsinne",
    "bollsinnet": "bollsinne",
    "bollsinnets": "bollsinne",
    "bollspelar": "bollspelare",
    "bollspelaren": "bollspelare",
    "bollspelarens": "bollspelare",
    "bollspelares": "bollspelare",
    "bollspelarna": "bollspelare",
    "bollspelarnas": "bollspelare",
    "bollspelen": "bollspel",
    "bollspelens": "bollspel",
    "bollspelet": "bollspel",
    "bollspelets": "bollspel",
    "bollspels": "bollspel",
    "bollträet": "bollträ",
    "bollträets": "bollträ",
    "bollträn": "bollträ",
    "bollträna": "bollträ",
    "bolltränas": "bollträ",
    "bollträns": "bollträ",
    "bollträs": "bollträ",
    "bollträt": "bollträ",
    "bollträts": "bollträ",
    "bolm": "bolma",
    "bolmade": "bolma",
    "bolmades": "bolma",
    "bolmande": "bolma",
    "bolmanden": "bolmande",
    "bolmandena": "bolmande",
    "bolmandenas": "bolmande",
    "bolmandens": "bolmande",
    "bolmandes": "bolmande",
    "bolmandet": "bolmande",
    "bolmandets": "bolmande",
    "bolmar": "bolma",
    "bolmas": "bolma",
    "bolmat": "bolma",
    "bolmats": "bolma",
    "bolmörten": "bolmört",
    "bolmörtens": "bolmört",
    "bolmörts": "bolmört",
    "bolmörtsskivlingar": "bolmörtsskivling",
    "bolmörtsskivlingarna": "bolmörtsskivling",
    "bolmörtsskivlingarnas": "bolmörtsskivling",
    "bolmörtsskivlingars": "bolmörtsskivling",
    "bolmörtsskivlingen": "bolmörtsskivling",
    "bolmörtsskivlingens": "bolmörtsskivling",
    "bolmörtsskivlings": "bolmörtsskivling",
    "bols": "bol",
    "bolsjeviken": "bolsjevik",
    "bolsjevikens": "bolsjevik",
    "bolsjeviker": "bolsjevik",
    "bolsjevikerna": "bolsjevik",
    "bolsjevikernas": "bolsjevik",
    "bolsjevikers": "bolsjevik",
    "bolsjeviks": "bolsjevik",
    "bolsjevismen": "bolsjevism",
    "bolsjevismens": "bolsjevism",
    "bolsjevismer": "bolsjevism",
    "bolsjevismerna": "bolsjevism",
    "bolsjevismernas": "bolsjevism",
    "bolsjevismers": "bolsjevism",
    "bolsjevisms": "bolsjevism",
    "bolsjevistiska": "bolsjevistisk",
    "bolsjevistiskare": "bolsjevistisk",
    "bolsjevistiskares": "bolsjevistisk",
    "bolsjevistiskas": "bolsjevistisk",
    "bolsjevistiskast": "bolsjevistisk",
    "bolsjevistiskaste": "bolsjevistisk",
    "bolsjevistiskastes": "bolsjevistisk",
    "bolsjevistiskasts": "bolsjevistisk",
    "bolsjevistiske": "bolsjevistisk",
    "bolsjevistiskes": "bolsjevistisk",
    "bolsjevistisks": "bolsjevistisk",
    "bolsjevistiskt": "bolsjevistisk",
    "bolsjevistiskts": "bolsjevistisk",
    "bolstern": "bolster",
    "bolsterna": "bolster",
    "bolsternas": "bolster",
    "bolsterns": "bolster",
    "bolsters": "bolster",
    "bolsterstockar": "bolsterstock",
    "bolsterstockarna": "bolsterstock",
    "bolsterstockarnas": "bolsterstock",
    "bolsterstockars": "bolsterstock",
    "bolsterstocken": "bolsterstock",
    "bolsterstockens": "bolsterstock",
    "bolsterstocks": "bolsterstock",
    "bolstervagnar": "bolstervagn",
    "bolstervagnarna": "bolstervagn",
    "bolstervagnarnas": "bolstervagn",
    "bolstervagnars": "bolstervagn",
    "bolstervagnen": "bolstervagn",
    "bolstervagnens": "bolstervagn",
    "bolstervagns": "bolstervagn",
    "bolstervaren": "bolstervar",
    "bolstervarens": "bolstervar",
    "bolstervaret": "bolstervar",
    "bolstervarets": "bolstervar",
    "bolstervars": "bolstervar",
    "bolstrar": "bolster",
    "bolstrarna": "bolster",
    "bolstrarnas": "bolster",
    "bolstrars": "bolster",
    "bolstren": "bolster",
    "bolstrens": "bolster",
    "bolstret": "bolster",
    "bolstrets": "bolster",
    "bolånekrisen": "bolånekris",
    "bolånekrisens": "bolånekris",
    "bolånekriser": "bolånekris",
    "bolånekriserna": "bolånekris",
    "bolånekrisernas": "bolånekris",
    "bolånekrisers": "bolånekris",
    "bolånekunden": "bolånekund",
    "bolånekundens": "bolånekund",
    "bolånekunder": "bolånekund",
    "bolånekunderna": "bolånekund",
    "bolånekundernas": "bolånekund",
    "bolånekunders": "bolånekund",
    "bolånekunds": "bolånekund",
    "bolånen": "bolån",
    "bolånens": "bolån",
    "bolåneräntan": "bolåneränta",
    "bolåneräntans": "bolåneränta",
    "bolåneräntas": "bolåneränta",
    "bolåneränte": "bolåneränta",
    "bolåneräntor": "bolåneränta",
    "bolåneräntorna": "bolåneränta",
    "bolåneräntornas": "bolåneränta",
    "bolåneräntors": "bolåneränta",
    "bolånet": "bolån",
    "bolånets": "bolån",
    "bolåns": "bolån",
    "bom": "bomma",
    "bomaterialen": "bomaterial",
    "bomaterialens": "bomaterial",
    "bomaterialet": "bomaterial",
    "bomaterialets": "bomaterial",
    "bomaterials": "bomaterial",
    "bomb": "bomber",
    "bombad": "bomba",
    "bombade": "bombad",
    "bombades": "bombad",
    "bombads": "bombad",
    "bombande": "bomba",
    "bombanden": "bombande",
    "bombandena": "bombande",
    "bombandenas": "bombande",
    "bombandens": "bombande",
    "bombandes": "bombande",
    "bombandet": "bombande",
    "bombandets": "bombande",
    "bombanfallen": "bombanfall",
    "bombanfallens": "bombanfall",
    "bombanfallet": "bombanfall",
    "bombanfallets": "bombanfall",
    "bombanfalls": "bombanfall",
    "bombar": "bombare",
    "bombardemangen": "bombardemang",
    "bombardemangens": "bombardemang",
    "bombardemanget": "bombardemang",
    "bombardemangets": "bombardemang",
    "bombardemangs": "bombardemang",
    "bombarderad": "bombardera",
    "bombarderade": "bombardera",
    "bombarderades": "bombardera",
    "bombarderads": "bombardera",
    "bombarderande": "bombardera",
    "bombarderanden": "bombarderande",
    "bombarderandena": "bombarderande",
    "bombarderandenas": "bombarderande",
    "bombarderandens": "bombarderande",
    "bombarderandes": "bombarderande",
    "bombarderandet": "bombarderande",
    "bombarderandets": "bombarderande",
    "bombarderar": "bombardera",
    "bombarderas": "bombardera",
    "bombarderat": "bombardera",
    "bombarderats": "bombardera",
    "bombarderbara": "bombarderbar",
    "bombarderbarare": "bombarderbar",
    "bombarderbarares": "bombarderbar",
    "bombarderbaras": "bombarderbar",
    "bombarderbarast": "bombarderbar",
    "bombarderbaraste": "bombarderbar",
    "bombarderbarastes": "bombarderbar",
    "bombarderbarasts": "bombarderbar",
    "bombarderbare": "bombarderbar",
    "bombarderbares": "bombarderbar",
    "bombarderbarheten": "bombarderbarhet",
    "bombarderbarhetens": "bombarderbarhet",
    "bombarderbarhets": "bombarderbarhet",
    "bombarderbars": "bombarderbar",
    "bombarderbart": "bombarderbar",
    "bombarderbarts": "bombarderbar",
    "bombarderingar": "bombardering",
    "bombarderingarna": "bombardering",
    "bombarderingarnas": "bombardering",
    "bombarderingars": "bombardering",
    "bombarderingen": "bombardering",
    "bombarderingens": "bombardering",
    "bombarderings": "bombardering",
    "bombaren": "bombare",
    "bombarens": "bombare",
    "bombares": "bombare",
    "bombarna": "bombare",
    "bombarnas": "bombare",
    "bombas": "bomba",
    "bombasmen": "bombasm",
    "bombasmens": "bombasm",
    "bombasmer": "bombasm",
    "bombasmerna": "bombasm",
    "bombasmernas": "bombasm",
    "bombasmers": "bombasm",
    "bombasms": "bombasm",
    "bombastiska": "bombastisk",
    "bombastiskare": "bombastisk",
    "bombastiskares": "bombastisk",
    "bombastiskas": "bombastisk",
    "bombastiskast": "bombastisk",
    "bombastiskaste": "bombastisk",
    "bombastiskastes": "bombastisk",
    "bombastiskasts": "bombastisk",
    "bombastiske": "bombastisk",
    "bombastiskes": "bombastisk",
    "bombastisks": "bombastisk",
    "bombastiskt": "bombastisk",
    "bombastiskts": "bombastisk",
    "bombat": "bombad",
    "bombats": "bombad",
    "bombattacken": "bombattack",
    "bombattackens": "bombattack",
    "bombattacker": "bombattack",
    "bombattackerna": "bombattack",
    "bombattackernas": "bombattack",
    "bombattackers": "bombattack",
    "bombattacks": "bombattack",
    "bombattentaten": "bombattentat",
    "bombattentatens": "bombattentat",
    "bombattentatet": "bombattentat",
    "bombattentatets": "bombattentat",
    "bombattentats": "bombattentat",
    "bomben": "bomb",
    "bombens": "bomb",
    "bomber": "bomb",
    "bomberingar": "bombering",
    "bomberingarna": "bombering",
    "bomberingarnas": "bombering",
    "bomberingars": "bombering",
    "bomberingen": "bombering",
    "bomberingens": "bombering",
    "bomberings": "bombering",
    "bomberna": "bomber",
    "bombernas": "bomber",
    "bombers": "bomber",
    "bombfasta": "bombfast",
    "bombfastare": "bombfast",
    "bombfastares": "bombfast",
    "bombfastas": "bombfast",
    "bombfastast": "bombfast",
    "bombfastaste": "bombfast",
    "bombfastastes": "bombfast",
    "bombfastasts": "bombfast",
    "bombfaste": "bombfast",
    "bombfastes": "bombfast",
    "bombfastheten": "bombfasthet",
    "bombfasthetens": "bombfasthet",
    "bombfasthets": "bombfasthet",
    "bombfasts": "bombfast",
    "bombflyget": "bombflyg",
    "bombflygets": "bombflyg",
    "bombflygs": "bombflyg",
    "bombfällningar": "bombfällning",
    "bombfällningarna": "bombfällning",
    "bombfällningarnas": "bombfällning",
    "bombfällningars": "bombfällning",
    "bombfällningen": "bombfällning",
    "bombfällningens": "bombfällning",
    "bombfällnings": "bombfällning",
    "bombhoten": "bombhot",
    "bombhotens": "bombhot",
    "bombhotet": "bombhot",
    "bombhotets": "bombhot",
    "bombhots": "bombhot",
    "bombkratern": "bombkrater",
    "bombkraterns": "bombkrater",
    "bombkraters": "bombkrater",
    "bombkratrar": "bombkrater",
    "bombkratrarna": "bombkrater",
    "bombkratrarnas": "bombkrater",
    "bombkratrars": "bombkrater",
    "bombkrigen": "bombkrig",
    "bombkrigens": "bombkrig",
    "bombkriget": "bombkrig",
    "bombkrigets": "bombkrig",
    "bombkrigs": "bombkrig",
    "bombmatt": "bombmatta",
    "bombmattan": "bombmatta",
    "bombmattans": "bombmatta",
    "bombmattas": "bombmatta",
    "bombmatte": "bombmatta",
    "bombmattor": "bombmatta",
    "bombmattorna": "bombmatta",
    "bombmattornas": "bombmatta",
    "bombmattors": "bombmatta",
    "bombmatts": "bombmatta",
    "bombnedslagen": "bombnedslag",
    "bombnedslagens": "bombnedslag",
    "bombnedslaget": "bombnedslag",
    "bombnedslagets": "bombnedslag",
    "bombnedslags": "bombnedslag",
    "bombningar": "bombning",
    "bombningarna": "bombning",
    "bombningarnas": "bombning",
    "bombningars": "bombning",
    "bombningen": "bombning",
    "bombningens": "bombning",
    "bombnings": "bombning",
    "bomboffers": "bomboffer",
    "bomboffren": "bomboffer",
    "bomboffrens": "bomboffer",
    "bomboffret": "bomboffer",
    "bomboffrets": "bomboffer",
    "bombplanen": "bombplan",
    "bombplanens": "bombplan",
    "bombplanet": "bombplan",
    "bombplanets": "bombplan",
    "bombplans": "bombplan",
    "bombraiden": "bombraid",
    "bombraidens": "bombraid",
    "bombraider": "bombraid",
    "bombraiderna": "bombraid",
    "bombraidernas": "bombraid",
    "bombraiders": "bombraid",
    "bombraids": "bombraid",
    "bombräden": "bombräd",
    "bombrädens": "bombräd",
    "bombräder": "bombräd",
    "bombräderna": "bombräd",
    "bombrädernas": "bombräd",
    "bombräders": "bombräd",
    "bombräds": "bombräd",
    "bombs": "bomber",
    "bombsikten": "bombsikte",
    "bombsiktena": "bombsikte",
    "bombsiktenas": "bombsikte",
    "bombsiktens": "bombsikte",
    "bombsiktes": "bombsikte",
    "bombsiktet": "bombsikte",
    "bombsiktets": "bombsikte",
    "bombsäkerheten": "bombsäkerhet",
    "bombsäkerhetens": "bombsäkerhet",
    "bombsäkerhets": "bombsäkerhet",
    "bombsäkers": "bombsäker",
    "bombsäkert": "bombsäker",
    "bombsäkerts": "bombsäker",
    "bombsäkra": "bombsäker",
    "bombsäkrare": "bombsäker",
    "bombsäkrares": "bombsäker",
    "bombsäkras": "bombsäker",
    "bombsäkrast": "bombsäker",
    "bombsäkraste": "bombsäker",
    "bombsäkrastes": "bombsäker",
    "bombsäkrasts": "bombsäker",
    "bombsäkre": "bombsäker",
    "bombsäkres": "bombsäker",
    "bombtillverkningar": "bombtillverkning",
    "bombtillverkningarna": "bombtillverkning",
    "bombtillverkningarnas": "bombtillverkning",
    "bombtillverkningars": "bombtillverkning",
    "bombtillverkningen": "bombtillverkning",
    "bombtillverkningens": "bombtillverkning",
    "bombtillverknings": "bombtillverkning",
    "bommad": "bomma",
    "bommade": "bomma",
    "bommades": "bomma",
    "bommads": "bomma",
    "bommande": "bomma",
    "bommanden": "bommande",
    "bommandena": "bommande",
    "bommandenas": "bommande",
    "bommandens": "bommande",
    "bommandes": "bommande",
    "bommandet": "bommande",
    "bommandets": "bommande",
    "bommar": "bomma",
    "bommarna": "bom",
    "bommarnas": "bom",
    "bommars": "bom",
    "bommas": "bomma",
    "bommat": "bomma",
    "bommats": "bomma",
    "bommen": "bom",
    "bommens": "bom",
    "bomoljan": "bomolja",
    "bomoljans": "bomolja",
    "bomoljas": "bomolja",
    "bomolje": "bomolja",
    "boms": "bom",
    "bomsadeln": "bomsadel",
    "bomsadelns": "bomsadel",
    "bomsadels": "bomsadel",
    "bomsadlar": "bomsadel",
    "bomsadlarna": "bomsadel",
    "bomsadlarnas": "bomsadel",
    "bomsadlars": "bomsadel",
    "bomsegels": "bomsegel",
    "bomseglen": "bomsegel",
    "bomseglens": "bomsegel",
    "bomseglet": "bomsegel",
    "bomseglets": "bomsegel",
    "bomullen": "bomull",
    "bomullens": "bomull",
    "bomulls": "bomull",
    "bomullsbalar": "bomullsbal",
    "bomullsbalarna": "bomullsbal",
    "bomullsbalarnas": "bomullsbal",
    "bomullsbalars": "bomullsbal",
    "bomullsbalen": "bomullsbal",
    "bomullsbalens": "bomullsbal",
    "bomullsbals": "bomullsbal",
    "bomullsbanden": "bomullsband",
    "bomullsbandens": "bomullsband",
    "bomullsbandet": "bomullsband",
    "bomullsbandets": "bomullsband",
    "bomullsbands": "bomullsband",
    "bomullsbusk": "bomullsbuske",
    "bomullsbuskar": "bomullsbuske",
    "bomullsbuskarna": "bomullsbuske",
    "bomullsbuskarnas": "bomullsbuske",
    "bomullsbuskars": "bomullsbuske",
    "bomullsbusken": "bomullsbuske",
    "bomullsbuskens": "bomullsbuske",
    "bomullsbuskes": "bomullsbuske",
    "bomullsflanellen": "bomullsflanell",
    "bomullsflanellens": "bomullsflanell",
    "bomullsflaneller": "bomullsflanell",
    "bomullsflanellerna": "bomullsflanell",
    "bomullsflanellernas": "bomullsflanell",
    "bomullsflanellers": "bomullsflanell",
    "bomullsflanellet": "bomullsflanell",
    "bomullsflanellets": "bomullsflanell",
    "bomullsflanells": "bomullsflanell",
    "bomullsfröen": "bomullsfrö",
    "bomullsfröens": "bomullsfrö",
    "bomullsfröet": "bomullsfrö",
    "bomullsfröets": "bomullsfrö",
    "bomullsfrökak": "bomullsfrökaka",
    "bomullsfrökakan": "bomullsfrökaka",
    "bomullsfrökakans": "bomullsfrökaka",
    "bomullsfrökakas": "bomullsfrökaka",
    "bomullsfrökake": "bomullsfrökaka",
    "bomullsfrökakor": "bomullsfrökaka",
    "bomullsfrökakorna": "bomullsfrökaka",
    "bomullsfrökakornas": "bomullsfrökaka",
    "bomullsfrökakors": "bomullsfrökaka",
    "bomullsfrökaks": "bomullsfrökaka",
    "bomullsfrön": "bomullsfrö",
    "bomullsfröna": "bomullsfrö",
    "bomullsfrönas": "bomullsfrö",
    "bomullsfröns": "bomullsfrö",
    "bomullsfröoljan": "bomullsfröolja",
    "bomullsfröoljans": "bomullsfröolja",
    "bomullsfröoljas": "bomullsfröolja",
    "bomullsfröolje": "bomullsfröolja",
    "bomullsfrös": "bomullsfrö",
    "bomullsfröt": "bomullsfrö",
    "bomullsfröts": "bomullsfrö",
    "bomullsklänningar": "bomullsklänning",
    "bomullsklänningarna": "bomullsklänning",
    "bomullsklänningarnas": "bomullsklänning",
    "bomullsklänningars": "bomullsklänning",
    "bomullsklänningen": "bomullsklänning",
    "bomullsklänningens": "bomullsklänning",
    "bomullsklännings": "bomullsklänning",
    "bomullskrutet": "bomullskrut",
    "bomullskrutets": "bomullskrut",
    "bomullskruts": "bomullskrut",
    "bomullspinn": "bomullspinne",
    "bomullspinnar": "bomullspinne",
    "bomullspinnarna": "bomullspinne",
    "bomullspinnarnas": "bomullspinne",
    "bomullspinnars": "bomullspinne",
    "bomullspinnen": "bomullspinne",
    "bomullspinnens": "bomullspinne",
    "bomullspinnes": "bomullspinne",
    "bomullspinns": "bomullspinne",
    "bomullsplantagen": "bomullsplantage",
    "bomullsplantagens": "bomullsplantage",
    "bomullsplantager": "bomullsplantage",
    "bomullsplantagerna": "bomullsplantage",
    "bomullsplantagernas": "bomullsplantage",
    "bomullsplantagers": "bomullsplantage",
    "bomullsplantages": "bomullsplantage",
    "bomullsplockar": "bomullsplockare",
    "bomullsplockaren": "bomullsplockare",
    "bomullsplockarens": "bomullsplockare",
    "bomullsplockares": "bomullsplockare",
    "bomullsplockarna": "bomullsplockare",
    "bomullsplockarnas": "bomullsplockare",
    "bomullsservetten": "bomullsservett",
    "bomullsservettens": "bomullsservett",
    "bomullsservetter": "bomullsservett",
    "bomullsservetterna": "bomullsservett",
    "bomullsservetternas": "bomullsservett",
    "bomullsservetters": "bomullsservett",
    "bomullsservetts": "bomullsservett",
    "bomullsskjort": "bomullsskjorta",
    "bomullsskjortan": "bomullsskjorta",
    "bomullsskjortans": "bomullsskjorta",
    "bomullsskjortas": "bomullsskjorta",
    "bomullsskjorte": "bomullsskjorta",
    "bomullsskjortor": "bomullsskjorta",
    "bomullsskjortorna": "bomullsskjorta",
    "bomullsskjortornas": "bomullsskjorta",
    "bomullsskjortors": "bomullsskjorta",
    "bomullsskjorts": "bomullsskjorta",
    "bomullstopsar": "bomullstops",
    "bomullstopsarna": "bomullstops",
    "bomullstopsarnas": "bomullstops",
    "bomullstopsars": "bomullstops",
    "bomullstopsen": "bomullstops",
    "bomullstopsens": "bomullstops",
    "bomullstrassels": "bomullstrassel",
    "bomullstrasslet": "bomullstrassel",
    "bomullstrasslets": "bomullstrassel",
    "bomullstrikån": "bomullstrikå",
    "bomullstrikåns": "bomullstrikå",
    "bomullstrikås": "bomullstrikå",
    "bomullstussar": "bomullstuss",
    "bomullstussarna": "bomullstuss",
    "bomullstussarnas": "bomullstuss",
    "bomullstussars": "bomullstuss",
    "bomullstussen": "bomullstuss",
    "bomullstussens": "bomullstuss",
    "bomullstygen": "bomullstyg",
    "bomullstygens": "bomullstyg",
    "bomullstyger": "bomullstyg",
    "bomullstygerna": "bomullstyg",
    "bomullstygernas": "bomullstyg",
    "bomullstygers": "bomullstyg",
    "bomullstyget": "bomullstyg",
    "bomullstygets": "bomullstyg",
    "bomullstygs": "bomullstyg",
    "bomullsvävnaden": "bomullsvävnad",
    "bomullsvävnadens": "bomullsvävnad",
    "bomullsvävnader": "bomullsvävnad",
    "bomullsvävnaderna": "bomullsvävnad",
    "bomullsvävnadernas": "bomullsvävnad",
    "bomullsvävnaders": "bomullsvävnad",
    "bomullsvävnads": "bomullsvävnad",
    "bomullsväxten": "bomullsväxt",
    "bomullsväxtens": "bomullsväxt",
    "bomullsväxter": "bomullsväxt",
    "bomullsväxterna": "bomullsväxt",
    "bomullsväxternas": "bomullsväxt",
    "bomullsväxters": "bomullsväxt",
    "bomullsväxts": "bomullsväxt",
    "bomärken": "bomärke",
    "bomärkena": "bomärke",
    "bomärkenas": "bomärke",
    "bomärkens": "bomärke",
    "bomärkes": "bomärke",
    "bomärket": "bomärke",
    "bomärkets": "bomärke",
    "bon": "bona",
    "bona": "bo",
    "bonad": "bona",
    "bonade": "bona",
    "bonaden": "bonad",
    "bonadens": "bonad",
    "bonader": "bonad",
    "bonaderna": "bonad",
    "bonadernas": "bonad",
    "bonaders": "bonad",
    "bonades": "bona",
    "bonads": "bonad",
    "bonande": "bona",
    "bonanden": "bonande",
    "bonandena": "bonande",
    "bonandenas": "bonande",
    "bonandens": "bonande",
    "bonandes": "bonande",
    "bonandet": "bonande",
    "bonandets": "bonande",
    "bonar": "bona",
    "bonas": "bona",
    "bonat": "bona",
    "bonats": "bona",
    "bonbonjären": "bonbonjär",
    "bonbonjärens": "bonbonjär",
    "bonbonjärer": "bonbonjär",
    "bonbonjärerna": "bonbonjär",
    "bonbonjärernas": "bonbonjär",
    "bonbonjärers": "bonbonjär",
    "bonbonjärs": "bonbonjär",
    "bond": "bonde",
    "bondbön": "bondböna",
    "bondbönan": "bondböna",
    "bondbönans": "bondböna",
    "bondbönas": "bondböna",
    "bondböne": "bondböna",
    "bondbönor": "bondböna",
    "bondbönorna": "bondböna",
    "bondbönornas": "bondböna",
    "bondbönors": "bondböna",
    "bondböns": "bondböna",
    "bonddryga": "bonddryg",
    "bonddrygare": "bonddryg",
    "bonddrygares": "bonddryg",
    "bonddrygas": "bonddryg",
    "bonddrygast": "bonddryg",
    "bonddrygaste": "bonddryg",
    "bonddrygastes": "bonddryg",
    "bonddrygasts": "bonddryg",
    "bonddryge": "bonddryg",
    "bonddryges": "bonddryg",
    "bonddrygheten": "bonddryghet",
    "bonddryghetens": "bonddryghet",
    "bonddryghets": "bonddryghet",
    "bonddrygs": "bonddryg",
    "bonddrygt": "bonddryg",
    "bonddrygts": "bonddryg",
    "bonddrängar": "bonddräng",
    "bonddrängarna": "bonddräng",
    "bonddrängarnas": "bonddräng",
    "bonddrängars": "bonddräng",
    "bonddrängen": "bonddräng",
    "bonddrängens": "bonddräng",
    "bonddrängs": "bonddräng",
    "bondearméer": "bondearmé",
    "bondearméerna": "bondearmé",
    "bondearméernas": "bondearmé",
    "bondearméers": "bondearmé",
    "bondearmén": "bondearmé",
    "bondearméns": "bondearmé",
    "bondearmés": "bondearmé",
    "bondebefolkningar": "bondebefolkning",
    "bondebefolkningarna": "bondebefolkning",
    "bondebefolkningarnas": "bondebefolkning",
    "bondebefolkningars": "bondebefolkning",
    "bondebefolkningen": "bondebefolkning",
    "bondebefolkningens": "bondebefolkning",
    "bondebefolknings": "bondebefolkning",
    "bondefreden": "bondefred",
    "bondefredens": "bondefred",
    "bondefreder": "bondefred",
    "bondefrederna": "bondefred",
    "bondefredernas": "bondefred",
    "bondefreders": "bondefred",
    "bondefreds": "bondefred",
    "bondegenerationen": "bondegeneration",
    "bondegenerationens": "bondegeneration",
    "bondegenerationer": "bondegeneration",
    "bondegenerationerna": "bondegeneration",
    "bondegenerationernas": "bondegeneration",
    "bondegenerationers": "bondegeneration",
    "bondegenerations": "bondegeneration",
    "bondehemmanen": "bondehemman",
    "bondehemmanens": "bondehemman",
    "bondehemmanet": "bondehemman",
    "bondehemmanets": "bondehemman",
    "bondehemmans": "bondehemman",
    "bondehärar": "bondehär",
    "bondehärarna": "bondehär",
    "bondehärarnas": "bondehär",
    "bondehärars": "bondehär",
    "bondehären": "bondehär",
    "bondehärens": "bondehär",
    "bondehärs": "bondehär",
    "bondekulturen": "bondekultur",
    "bondekulturens": "bondekultur",
    "bondekulturer": "bondekultur",
    "bondekulturerna": "bondekultur",
    "bondekulturernas": "bondekultur",
    "bondekulturers": "bondekultur",
    "bondekulturs": "bondekultur",
    "bonden": "bonde",
    "bondens": "bonde",
    "bondepraktik": "bondepraktika",
    "bondepraktikan": "bondepraktika",
    "bondepraktikans": "bondepraktika",
    "bondepraktikas": "bondepraktika",
    "bondepraktike": "bondepraktika",
    "bondepraktikor": "bondepraktika",
    "bondepraktikorna": "bondepraktika",
    "bondepraktikornas": "bondepraktika",
    "bondepraktikors": "bondepraktika",
    "bondepraktiks": "bondepraktika",
    "bondeprotesten": "bondeprotest",
    "bondeprotestens": "bondeprotest",
    "bondeprotester": "bondeprotest",
    "bondeprotesterna": "bondeprotest",
    "bondeprotesternas": "bondeprotest",
    "bondeprotesters": "bondeprotest",
    "bondeprotests": "bondeprotest",
    "bondes": "bonde",
    "bondesamhällen": "bondesamhälle",
    "bondesamhällena": "bondesamhälle",
    "bondesamhällenas": "bondesamhälle",
    "bondesamhällens": "bondesamhälle",
    "bondesamhälles": "bondesamhälle",
    "bondesamhället": "bondesamhälle",
    "bondesamhällets": "bondesamhälle",
    "bondesamhälls": "bondesamhälle",
    "bondesjälen": "bondesjäl",
    "bondesjälens": "bondesjäl",
    "bondesjäls": "bondesjäl",
    "bondeskogar": "bondeskog",
    "bondeskogarna": "bondeskog",
    "bondeskogarnas": "bondeskog",
    "bondeskogars": "bondeskog",
    "bondeskogen": "bondeskog",
    "bondeskogens": "bondeskog",
    "bondeskogs": "bondeskog",
    "bondeståndet": "bondestånd",
    "bondeståndets": "bondestånd",
    "bondestånds": "bondestånd",
    "bondetågen": "bondetåg",
    "bondetågens": "bondetåg",
    "bondetåget": "bondetåg",
    "bondetågets": "bondetåg",
    "bondetågs": "bondetåg",
    "bondeupproren": "bondeuppror",
    "bondeupprorens": "bondeuppror",
    "bondeupproret": "bondeuppror",
    "bondeupprorets": "bondeuppror",
    "bondeupprors": "bondeuppror",
    "bondfamiljen": "bondfamilj",
    "bondfamiljens": "bondfamilj",
    "bondfamiljer": "bondfamilj",
    "bondfamiljerna": "bondfamilj",
    "bondfamiljernas": "bondfamilj",
    "bondfamiljers": "bondfamilj",
    "bondfamiljs": "bondfamilj",
    "bondflick": "bondflicka",
    "bondflickan": "bondflicka",
    "bondflickans": "bondflicka",
    "bondflickas": "bondflicka",
    "bondflicke": "bondflicka",
    "bondflickor": "bondflicka",
    "bondflickorna": "bondflicka",
    "bondflickornas": "bondflicka",
    "bondflickors": "bondflicka",
    "bondflicks": "bondflicka",
    "bondfångar": "bondfångare",
    "bondfångaren": "bondfångare",
    "bondfångarens": "bondfångare",
    "bondfångares": "bondfångare",
    "bondfångarna": "bondfångare",
    "bondfångarnas": "bondfångare",
    "bondförnuftet": "bondförnuft",
    "bondförnuftets": "bondförnuft",
    "bondförnufts": "bondförnuft",
    "bondförståndet": "bondförstånd",
    "bondförståndets": "bondförstånd",
    "bondförstånds": "bondförstånd",
    "bondförsöken": "bondförsök",
    "bondförsökens": "bondförsök",
    "bondförsöket": "bondförsök",
    "bondförsökets": "bondförsök",
    "bondförsöks": "bondförsök",
    "bondgårdar": "bondgård",
    "bondgårdarna": "bondgård",
    "bondgårdarnas": "bondgård",
    "bondgårdars": "bondgård",
    "bondgården": "bondgård",
    "bondgårdens": "bondgård",
    "bondgårds": "bondgård",
    "bondhustrun": "bondhustru",
    "bondhustruns": "bondhustru",
    "bondhustrur": "bondhustru",
    "bondhustrurna": "bondhustru",
    "bondhustrurnas": "bondhustru",
    "bondhustrurs": "bondhustru",
    "bondhustrus": "bondhustru",
    "bondkalasen": "bondkalas",
    "bondkalasens": "bondkalas",
    "bondkalaset": "bondkalas",
    "bondkalasets": "bondkalas",
    "bondkatten": "bondkatt",
    "bondkattens": "bondkatt",
    "bondkatter": "bondkatt",
    "bondkatterna": "bondkatt",
    "bondkatternas": "bondkatt",
    "bondkatters": "bondkatt",
    "bondkatts": "bondkatt",
    "bondkomiken": "bondkomik",
    "bondkomikens": "bondkomik",
    "bondkomikern": "bondkomiker",
    "bondkomikerna": "bondkomiker",
    "bondkomikernas": "bondkomiker",
    "bondkomikerns": "bondkomiker",
    "bondkomikers": "bondkomiker",
    "bondkomiks": "bondkomik",
    "bondlandet": "bondland",
    "bondlandets": "bondland",
    "bondlands": "bondland",
    "bondlurkar": "bondlurk",
    "bondlurkarna": "bondlurk",
    "bondlurkarnas": "bondlurk",
    "bondlurkars": "bondlurk",
    "bondlurken": "bondlurk",
    "bondlurkens": "bondlurk",
    "bondlurks": "bondlurk",
    "bondläppar": "bondläpp",
    "bondläpparna": "bondläpp",
    "bondläpparnas": "bondläpp",
    "bondläppars": "bondläpp",
    "bondläppen": "bondläpp",
    "bondläppens": "bondläpp",
    "bondläpps": "bondläpp",
    "bondmor": "bondmora",
    "bondmoran": "bondmora",
    "bondmorans": "bondmora",
    "bondmoras": "bondmora",
    "bondmore": "bondmora",
    "bondmoror": "bondmora",
    "bondmororna": "bondmora",
    "bondmorornas": "bondmora",
    "bondmorors": "bondmora",
    "bondmors": "bondmora",
    "bondnek": "bondneka",
    "bondnekad": "bondneka",
    "bondnekade": "bondneka",
    "bondnekades": "bondneka",
    "bondnekads": "bondneka",
    "bondnekande": "bondneka",
    "bondnekanden": "bondnekande",
    "bondnekandena": "bondnekande",
    "bondnekandenas": "bondnekande",
    "bondnekandens": "bondnekande",
    "bondnekandes": "bondnekande",
    "bondnekandet": "bondnekande",
    "bondnekandets": "bondnekande",
    "bondnekar": "bondneka",
    "bondnekas": "bondneka",
    "bondnekat": "bondneka",
    "bondnekats": "bondneka",
    "bondpermissionen": "bondpermission",
    "bondpermissionens": "bondpermission",
    "bondpermissioner": "bondpermission",
    "bondpermissionerna": "bondpermission",
    "bondpermissionernas": "bondpermission",
    "bondpermissioners": "bondpermission",
    "bondpermissions": "bondpermission",
    "bonds": "bonde",
    "bondska": "bondsk",
    "bondskare": "bondsk",
    "bondskares": "bondsk",
    "bondskas": "bondsk",
    "bondskast": "bondsk",
    "bondskaste": "bondsk",
    "bondskastes": "bondsk",
    "bondskasts": "bondsk",
    "bondske": "bondsk",
    "bondskes": "bondsk",
    "bondskheten": "bondskhet",
    "bondskhetens": "bondskhet",
    "bondskhets": "bondskhet",
    "bondsks": "bondsk",
    "bondskt": "bondsk",
    "bondskts": "bondsk",
    "bondsluga": "bondslug",
    "bondslugare": "bondslug",
    "bondslugares": "bondslug",
    "bondslugas": "bondslug",
    "bondslugast": "bondslug",
    "bondslugaste": "bondslug",
    "bondslugastes": "bondslug",
    "bondslugasts": "bondslug",
    "bondsluge": "bondslug",
    "bondsluges": "bondslug",
    "bondslugheten": "bondslughet",
    "bondslughetens": "bondslughet",
    "bondslughets": "bondslughet",
    "bondslugs": "bondslug",
    "bondslugt": "bondslug",
    "bondslugts": "bondslug",
    "bondtolv": "bondtolva",
    "bondtolvan": "bondtolva",
    "bondtolvans": "bondtolva",
    "bondtolvas": "bondtolva",
    "bondtolve": "bondtolva",
    "bondtolvor": "bondtolva",
    "bondtolvorna": "bondtolva",
    "bondtolvornas": "bondtolva",
    "bondtolvors": "bondtolva",
    "bondtolvs": "bondtolva",
    "bondturen": "bondtur",
    "bondturens": "bondtur",
    "bondturs": "bondtur",
    "bondvisch": "bondvischa",
    "bondvischan": "bondvischa",
    "bondvischans": "bondvischa",
    "bondvischas": "bondvischa",
    "bondvische": "bondvischa",
    "bondvischor": "bondvischa",
    "bondvischorna": "bondvischa",
    "bondvischornas": "bondvischa",
    "bondvischors": "bondvischa",
    "bondångern": "bondånger",
    "bondångerns": "bondånger",
    "bondångers": "bondånger",
    "bong": "bonga",
    "bongad": "bonga",
    "bongade": "bonga",
    "bongades": "bonga",
    "bongads": "bonga",
    "bongande": "bonga",
    "bonganden": "bongande",
    "bongandena": "bongande",
    "bongandenas": "bongande",
    "bongandens": "bongande",
    "bongandes": "bongande",
    "bongandet": "bongande",
    "bongandets": "bongande",
    "bongar": "bonga",
    "bongarna": "bong",
    "bongarnas": "bong",
    "bongars": "bong",
    "bongas": "bonga",
    "bongat": "bonga",
    "bongats": "bonga",
    "bongen": "bong",
    "bongens": "bong",
    "bongotrum": "bongotrumma",
    "bongotrumman": "bongotrumma",
    "bongotrummans": "bongotrumma",
    "bongotrummas": "bongotrumma",
    "bongotrumme": "bongotrumma",
    "bongotrummor": "bongotrumma",
    "bongotrummorna": "bongotrumma",
    "bongotrummornas": "bongotrumma",
    "bongotrummors": "bongotrumma",
    "bongotrums": "bongotrumma",
    "bongs": "bong",
    "boningar": "boning",
    "boningarna": "boning",
    "boningarnas": "boning",
    "boningars": "boning",
    "boningen": "boning",
    "boningens": "boning",
    "bonings": "boning",
    "boningshusen": "boningshus",
    "boningshusens": "boningshus",
    "boningshuset": "boningshus",
    "boningshusets": "boningshus",
    "boniterad": "bonitera",
    "boniterade": "bonitera",
    "boniterades": "bonitera",
    "boniterads": "bonitera",
    "boniterande": "bonitera",
    "boniteranden": "boniterande",
    "boniterandena": "boniterande",
    "boniterandenas": "boniterande",
    "boniterandens": "boniterande",
    "boniterandes": "boniterande",
    "boniterandet": "boniterande",
    "boniterandets": "boniterande",
    "boniterar": "bonitera",
    "boniteras": "bonitera",
    "boniterat": "bonitera",
    "boniterats": "bonitera",
    "boniterbara": "boniterbar",
    "boniterbarare": "boniterbar",
    "boniterbarares": "boniterbar",
    "boniterbaras": "boniterbar",
    "boniterbarast": "boniterbar",
    "boniterbaraste": "boniterbar",
    "boniterbarastes": "boniterbar",
    "boniterbarasts": "boniterbar",
    "boniterbare": "boniterbar",
    "boniterbares": "boniterbar",
    "boniterbarheten": "boniterbarhet",
    "boniterbarhetens": "boniterbarhet",
    "boniterbarhets": "boniterbarhet",
    "boniterbars": "boniterbar",
    "boniterbart": "boniterbar",
    "boniterbarts": "boniterbar",
    "boniteringar": "bonitering",
    "boniteringarna": "bonitering",
    "boniteringarnas": "bonitering",
    "boniteringars": "bonitering",
    "boniteringen": "bonitering",
    "boniteringens": "bonitering",
    "boniterings": "bonitering",
    "boniteten": "bonitet",
    "bonitetens": "bonitet",
    "boniteter": "bonitet",
    "boniteterna": "bonitet",
    "boniteternas": "bonitet",
    "boniteters": "bonitet",
    "bonitets": "bonitet",
    "bonjouren": "bonjour",
    "bonjourens": "bonjour",
    "bonjourer": "bonjour",
    "bonjourerna": "bonjour",
    "bonjourernas": "bonjour",
    "bonjourers": "bonjour",
    "bonjours": "bonjour",
    "bonmoten": "bonmot",
    "bonmotens": "bonmot",
    "bonmoter": "bonmot",
    "bonmoterna": "bonmot",
    "bonmoternas": "bonmot",
    "bonmoters": "bonmot",
    "bonmotet": "bonmot",
    "bonmotets": "bonmot",
    "bonmots": "bonmot",
    "bonnetten": "bonnett",
    "bonnettens": "bonnett",
    "bonnetter": "bonnett",
    "bonnetterna": "bonnett",
    "bonnetternas": "bonnett",
    "bonnetters": "bonnett",
    "bonnetts": "bonnett",
    "bons": "bo",
    "bonusar": "bonus",
    "bonusarna": "bonus",
    "bonusarnas": "bonus",
    "bonusars": "bonus",
    "bonusen": "bonus",
    "bonusens": "bonus",
    "bonusklassen": "bonusklass",
    "bonusklassens": "bonusklass",
    "bonusklasser": "bonusklass",
    "bonusklasserna": "bonusklass",
    "bonusklassernas": "bonusklass",
    "bonusklassers": "bonusklass",
    "bonusregeln": "bonusregel",
    "bonusregelns": "bonusregel",
    "bonusregels": "bonusregel",
    "bonusregler": "bonusregel",
    "bonusreglerna": "bonusregel",
    "bonusreglernas": "bonusregel",
    "bonusreglers": "bonusregel",
    "bonussystemen": "bonussystem",
    "bonussystemens": "bonussystem",
    "bonussystemet": "bonussystem",
    "bonussystemets": "bonussystem",
    "bonussystems": "bonussystem",
    "bonvaxet": "bonvax",
    "bonvaxets": "bonvax",
    "bookmakern": "bookmaker",
    "bookmakerna": "bookmaker",
    "bookmakernas": "bookmaker",
    "bookmakerns": "bookmaker",
    "bookmakers": "bookmaker",
    "bookmakersarna": "bookmaker",
    "bookmakersarnas": "bookmaker",
    "bookmakersen": "bookmaker",
    "bookmakersens": "bookmaker",
    "boomade": "booma",
    "boomades": "booma",
    "boomande": "booma",
    "boomanden": "boomande",
    "boomandena": "boomande",
    "boomandenas": "boomande",
    "boomandens": "boomande",
    "boomandes": "boomande",
    "boomandet": "boomande",
    "boomandets": "boomande",
    "boomar": "booma",
    "boomarna": "boom",
    "boomarnas": "boom",
    "boomars": "boom",
    "boomas": "booma",
    "boomat": "booma",
    "boomats": "booma",
    "boomen": "boom",
    "boomens": "boom",
    "boomer": "boom",
    "boomerna": "boom",
    "boomernas": "boom",
    "boomers": "boom",
    "booms": "boom",
    "boomåren": "boomår",
    "boomårens": "boomår",
    "boomåret": "boomår",
    "boomårets": "boomår",
    "boomårs": "boomår",
    "boor": "boa",
    "boorna": "boa",
    "boornas": "boa",
    "boors": "boa",
    "boot": "boota",
    "bootad": "boota",
    "bootade": "boota",
    "bootades": "boota",
    "bootads": "boota",
    "bootande": "boota",
    "bootandes": "boota",
    "bootar": "boota",
    "bootas": "boota",
    "bootat": "boota",
    "bootats": "boota",
    "bootsen": "boots",
    "bootsens": "boots",
    "boplatsen": "boplats",
    "boplatsens": "boplats",
    "boplatser": "boplats",
    "boplatserna": "boplats",
    "boplatsernas": "boplats",
    "boplatsers": "boplats",
    "boplatsgrävningar": "boplatsgrävning",
    "boplatsgrävningarna": "boplatsgrävning",
    "boplatsgrävningarnas": "boplatsgrävning",
    "boplatsgrävningars": "boplatsgrävning",
    "boplatsgrävningen": "boplatsgrävning",
    "boplatsgrävningens": "boplatsgrävning",
    "boplatsgrävnings": "boplatsgrävning",
    "boprisen": "bopris",
    "boprisens": "bopris",
    "bopriser": "bopris",
    "bopriserna": "bopris",
    "boprisernas": "bopris",
    "boprisers": "bopris",
    "bopriset": "bopris",
    "boprisets": "bopris",
    "bor": "bo",
    "boraxen": "borax",
    "boraxens": "borax",
    "bord": "borda",
    "bordad": "borda",
    "bordade": "borda",
    "bordades": "borda",
    "bordads": "borda",
    "bordande": "borda",
    "bordanden": "bordande",
    "bordandena": "bordande",
    "bordandenas": "bordande",
    "bordandens": "bordande",
    "bordandes": "bordande",
    "bordandet": "bordande",
    "bordandets": "bordande",
    "bordar": "borda",
    "bordas": "borda",
    "bordat": "borda",
    "bordats": "borda",
    "borddansen": "borddans",
    "borddansens": "borddans",
    "borddanser": "borddans",
    "borddanserna": "borddans",
    "borddansernas": "borddans",
    "borddansers": "borddans",
    "borddukar": "bordduk",
    "borddukarna": "bordduk",
    "borddukarnas": "bordduk",
    "borddukars": "bordduk",
    "bordduken": "bordduk",
    "borddukens": "bordduk",
    "bordduks": "bordduk",
    "borde": "böra",
    "bordeauxen": "bordeaux",
    "bordeauxens": "bordeaux",
    "bordeauxer": "bordeaux",
    "bordeauxerna": "bordeaux",
    "bordeauxernas": "bordeaux",
    "bordeauxers": "bordeaux",
    "bordeauxvätskan": "bordeauxvätska",
    "bordeauxvätskans": "bordeauxvätska",
    "bordeauxvätskas": "bordeauxvätska",
    "bordeauxvätske": "bordeauxvätska",
    "bordellen": "bordell",
    "bordellens": "bordell",
    "bordeller": "bordell",
    "bordellerna": "bordell",
    "bordellernas": "bordell",
    "bordellers": "bordell",
    "bordells": "bordell",
    "borden": "bord",
    "bordens": "bord",
    "bordes": "böra",
    "bordet": "bord",
    "bordets": "bord",
    "bordhyveln": "bordhyvel",
    "bordhyvelns": "bordhyvel",
    "bordhyvels": "bordhyvel",
    "bordhyvlar": "bordhyvel",
    "bordhyvlarna": "bordhyvel",
    "bordhyvlarnas": "bordhyvel",
    "bordhyvlars": "bordhyvel",
    "bordla": "bordlägga",
    "bordlade": "bordlägga",
    "bordlades": "bordlägga",
    "bordlagd": "bordlägga",
    "bordlagda": "bordlägga",
    "bordlagdas": "bordlägga",
    "bordlagde": "bordlägga",
    "bordlagdes": "bordlägga",
    "bordlagds": "bordlägga",
    "bordlagt": "bordlägga",
    "bordlagts": "bordlägga",
    "bordlas": "bordlägga",
    "bordlägg": "bordlägga",
    "bordläggande": "bordlägga",
    "bordlägganden": "bordläggande",
    "bordläggandena": "bordläggande",
    "bordläggandenas": "bordläggande",
    "bordläggandens": "bordläggande",
    "bordläggandes": "bordläggande",
    "bordläggandet": "bordläggande",
    "bordläggandets": "bordläggande",
    "bordläggas": "bordlägga",
    "bordlägger": "bordlägga",
    "bordlägges": "bordlägga",
    "bordläggningar": "bordläggning",
    "bordläggningarna": "bordläggning",
    "bordläggningarnas": "bordläggning",
    "bordläggningars": "bordläggning",
    "bordläggningen": "bordläggning",
    "bordläggningens": "bordläggning",
    "bordläggnings": "bordläggning",
    "bordläggningsplena": "bordläggningsplenum",
    "bordläggningsplenana": "bordläggningsplenum",
    "bordläggningsplenanas": "bordläggningsplenum",
    "bordläggningsplenas": "bordläggningsplenum",
    "bordläggningsplenumen": "bordläggningsplenum",
    "bordläggningsplenumens": "bordläggningsplenum",
    "bordläggningsplenumet": "bordläggningsplenum",
    "bordläggningsplenumets": "bordläggningsplenum",
    "bordläggningsplenums": "bordläggningsplenum",
    "bordläggs": "bordlägga",
    "bordlöpar": "bordlöpare",
    "bordlöparen": "bordlöpare",
    "bordlöparens": "bordlöpare",
    "bordlöpares": "bordlöpare",
    "bordlöparna": "bordlöpare",
    "bordlöparnas": "bordlöpare",
    "bords": "bord",
    "bordsamtalen": "bordsamtal",
    "bordsamtalens": "bordsamtal",
    "bordsamtalet": "bordsamtal",
    "bordsamtalets": "bordsamtal",
    "bordsamtals": "bordsamtal",
    "bordsbenen": "bordsben",
    "bordsbenens": "bordsben",
    "bordsbenet": "bordsben",
    "bordsbenets": "bordsben",
    "bordsbens": "bordsben",
    "bordsbeställningar": "bordsbeställning",
    "bordsbeställningarna": "bordsbeställning",
    "bordsbeställningarnas": "bordsbeställning",
    "bordsbeställningars": "bordsbeställning",
    "bordsbeställningen": "bordsbeställning",
    "bordsbeställningens": "bordsbeställning",
    "bordsbeställnings": "bordsbeställning",
    "bordsbönen": "bordsbön",
    "bordsbönens": "bordsbön",
    "bordsböner": "bordsbön",
    "bordsbönerna": "bordsbön",
    "bordsbönernas": "bordsbön",
    "bordsböners": "bordsbön",
    "bordsböns": "bordsbön",
    "bordsdamen": "bordsdam",
    "bordsdamens": "bordsdam",
    "bordsdamer": "bordsdam",
    "bordsdamerna": "bordsdam",
    "bordsdamernas": "bordsdam",
    "bordsdamers": "bordsdam",
    "bordsdams": "bordsdam",
    "bordsdrycken": "bordsdryck",
    "bordsdryckens": "bordsdryck",
    "bordsdrycker": "bordsdryck",
    "bordsdryckerna": "bordsdryck",
    "bordsdryckernas": "bordsdryck",
    "bordsdryckers": "bordsdryck",
    "bordsdrycks": "bordsdryck",
    "bordservisen": "bordservis",
    "bordservisens": "bordservis",
    "bordserviser": "bordservis",
    "bordserviserna": "bordservis",
    "bordservisernas": "bordservis",
    "bordservisers": "bordservis",
    "bordsfiltar": "bordsfilt",
    "bordsfiltarna": "bordsfilt",
    "bordsfiltarnas": "bordsfilt",
    "bordsfiltars": "bordsfilt",
    "bordsfilten": "bordsfilt",
    "bordsfiltens": "bordsfilt",
    "bordsfilts": "bordsfilt",
    "bordsilvers": "bordsilver",
    "bordsilvret": "bordsilver",
    "bordsilvrets": "bordsilver",
    "bordskanten": "bordskant",
    "bordskantens": "bordskant",
    "bordskanter": "bordskant",
    "bordskanterna": "bordskant",
    "bordskanternas": "bordskant",
    "bordskanters": "bordskant",
    "bordskants": "bordskant",
    "bordskavaljeren": "bordskavaljer",
    "bordskavaljerens": "bordskavaljer",
    "bordskavaljerer": "bordskavaljer",
    "bordskavaljererna": "bordskavaljer",
    "bordskavaljerernas": "bordskavaljer",
    "bordskavaljerers": "bordskavaljer",
    "bordskavaljern": "bordskavaljer",
    "bordskavaljerns": "bordskavaljer",
    "bordskavaljers": "bordskavaljer",
    "bordskicken": "bordskick",
    "bordskickens": "bordskick",
    "bordskicket": "bordskick",
    "bordskickets": "bordskick",
    "bordskicks": "bordskick",
    "bordskivan": "bordskiva",
    "bordskivans": "bordskiva",
    "bordskivas": "bordskiva",
    "bordskive": "bordskiva",
    "bordskivor": "bordskiva",
    "bordskivorna": "bordskiva",
    "bordskivornas": "bordskiva",
    "bordskivors": "bordskiva",
    "bordsknivar": "bordskniv",
    "bordsknivarna": "bordskniv",
    "bordsknivarnas": "bordskniv",
    "bordsknivars": "bordskniv",
    "bordskniven": "bordskniv",
    "bordsknivens": "bordskniv",
    "bordsknivs": "bordskniv",
    "bordskrydd": "bordskrydda",
    "bordskryddan": "bordskrydda",
    "bordskryddans": "bordskrydda",
    "bordskryddas": "bordskrydda",
    "bordskrydde": "bordskrydda",
    "bordskryddor": "bordskrydda",
    "bordskryddorna": "bordskrydda",
    "bordskryddornas": "bordskrydda",
    "bordskryddors": "bordskrydda",
    "bordskrydds": "bordskrydda",
    "bordslinnes": "bordslinne",
    "bordslinnet": "bordslinne",
    "bordslinnets": "bordslinne",
    "bordsmargariner": "bordsmargarin",
    "bordsmargarinerna": "bordsmargarin",
    "bordsmargarinernas": "bordsmargarin",
    "bordsmargariners": "bordsmargarin",
    "bordsmargarinet": "bordsmargarin",
    "bordsmargarinets": "bordsmargarin",
    "bordsmargarins": "bordsmargarin",
    "bordssaltet": "bordssalt",
    "bordssaltets": "bordssalt",
    "bordssalts": "bordssalt",
    "bordssamtalen": "bordssamtal",
    "bordssamtalens": "bordssamtal",
    "bordssamtalet": "bordssamtal",
    "bordssamtalets": "bordssamtal",
    "bordssamtals": "bordssamtal",
    "bordsservisen": "bordsservis",
    "bordsservisens": "bordsservis",
    "bordsserviser": "bordsservis",
    "bordsserviserna": "bordsservis",
    "bordsservisernas": "bordsservis",
    "bordsservisers": "bordsservis",
    "bordssilvers": "bordssilver",
    "bordssilvret": "bordssilver",
    "bordssilvrets": "bordssilver",
    "bordsskicken": "bordsskick",
    "bordsskickens": "bordsskick",
    "bordsskicket": "bordsskick",
    "bordsskickets": "bordsskick",
    "bordsskicks": "bordsskick",
    "bordsskivan": "bordsskiva",
    "bordsskivans": "bordsskiva",
    "bordsskivas": "bordsskiva",
    "bordsskive": "bordsskiva",
    "bordsskivor": "bordsskiva",
    "bordsskivorna": "bordsskiva",
    "bordsskivornas": "bordsskiva",
    "bordsskivors": "bordsskiva",
    "bordsspegeln": "bordsspegel",
    "bordsspegelns": "bordsspegel",
    "bordsspegels": "bordsspegel",
    "bordsspeglar": "bordsspegel",
    "bordsspeglarna": "bordsspegel",
    "bordsspeglarnas": "bordsspegel",
    "bordsspeglars": "bordsspegel",
    "bordsstudsar": "bordsstudsare",
    "bordsstudsaren": "bordsstudsare",
    "bordsstudsarens": "bordsstudsare",
    "bordsstudsares": "bordsstudsare",
    "bordsstudsarna": "bordsstudsare",
    "bordsstudsarnas": "bordsstudsare",
    "bordsställen": "bordsställ",
    "bordsställens": "bordsställ",
    "bordsstället": "bordsställ",
    "bordsställets": "bordsställ",
    "bordsställs": "bordsställ",
    "bordssällskapen": "bordssällskap",
    "bordssällskapens": "bordssällskap",
    "bordssällskapet": "bordssällskap",
    "bordssällskapets": "bordssällskap",
    "bordssällskaps": "bordssällskap",
    "bordstudsar": "bordstudsare",
    "bordstudsaren": "bordstudsare",
    "bordstudsarens": "bordstudsare",
    "bordstudsares": "bordstudsare",
    "bordstudsarna": "bordstudsare",
    "bordstudsarnas": "bordstudsare",
    "bordsuppsatsen": "bordsuppsats",
    "bordsuppsatsens": "bordsuppsats",
    "bordsuppsatser": "bordsuppsats",
    "bordsuppsatserna": "bordsuppsats",
    "bordsuppsatsernas": "bordsuppsats",
    "bordsuppsatsers": "bordsuppsats",
    "bordsvattens": "bordsvatten",
    "bordsvattnen": "bordsvatten",
    "bordsvattnens": "bordsvatten",
    "bordsvattnet": "bordsvatten",
    "bordsvattnets": "bordsvatten",
    "bordtennisborden": "bordtennisbord",
    "bordtennisbordens": "bordtennisbord",
    "bordtennisbordet": "bordtennisbord",
    "bordtennisbordets": "bordtennisbord",
    "bordtennisbords": "bordtennisbord",
    "bordtennisen": "bordtennis",
    "bordtennisens": "bordtennis",
    "bordtennisrackar": "bordtennisrack",
    "bordtennisrackarna": "bordtennisrack",
    "bordtennisrackarnas": "bordtennisrack",
    "bordtennisrackars": "bordtennisrack",
    "bordtennisracken": "bordtennisrack",
    "bordtennisrackens": "bordtennisrack",
    "bordtennisracket": "bordtennisrack",
    "bordtennisracketar": "bordtennisracket",
    "bordtennisracketarna": "bordtennisracket",
    "bordtennisracketarnas": "bordtennisracket",
    "bordtennisracketars": "bordtennisracket",
    "bordtennisracketen": "bordtennisracket",
    "bordtennisracketens": "bordtennisracket",
    "bordtennisrackets": "bordtennisracket",
    "bordtennisracks": "bordtennisrack",
    "boreala": "boreal",
    "borealare": "boreal",
    "borealares": "boreal",
    "borealas": "boreal",
    "borealast": "boreal",
    "borealaste": "boreal",
    "borealastes": "boreal",
    "borealasts": "boreal",
    "boreale": "boreal",
    "boreales": "boreal",
    "boreals": "boreal",
    "borealt": "boreal",
    "borealts": "boreal",
    "boren": "bor",
    "borens": "boren",
    "boret": "boren",
    "borets": "boren",
    "borg": "borga",
    "borgad": "borga",
    "borgade": "borga",
    "borgades": "borga",
    "borgads": "borga",
    "borgande": "borga",
    "borganden": "borgande",
    "borgandena": "borgande",
    "borgandenas": "borgande",
    "borgandens": "borgande",
    "borgandes": "borgande",
    "borgandet": "borgande",
    "borgandets": "borgande",
    "borgar": "borgare",
    "borgarbeväpningar": "borgarbeväpning",
    "borgarbeväpningarna": "borgarbeväpning",
    "borgarbeväpningarnas": "borgarbeväpning",
    "borgarbeväpningars": "borgarbeväpning",
    "borgarbeväpningen": "borgarbeväpning",
    "borgarbeväpningens": "borgarbeväpning",
    "borgarbeväpnings": "borgarbeväpning",
    "borgarbreven": "borgarbrev",
    "borgarbrevens": "borgarbrev",
    "borgarbrevet": "borgarbrev",
    "borgarbrevets": "borgarbrev",
    "borgarbrevs": "borgarbrev",
    "borgardömen": "borgardöme",
    "borgardömena": "borgardöme",
    "borgardömenas": "borgardöme",
    "borgardömens": "borgardöme",
    "borgardömes": "borgardöme",
    "borgardömet": "borgardöme",
    "borgardömets": "borgardöme",
    "borgaren": "borgare",
    "borgarens": "borgare",
    "borgares": "borgare",
    "borgargarden": "borgargarde",
    "borgargardena": "borgargarde",
    "borgargardenas": "borgargarde",
    "borgargardens": "borgargarde",
    "borgargardes": "borgargarde",
    "borgargardet": "borgargarde",
    "borgargardets": "borgargarde",
    "borgarklassen": "borgarklass",
    "borgarklassens": "borgarklass",
    "borgarklasser": "borgarklass",
    "borgarklasserna": "borgarklass",
    "borgarklassernas": "borgarklass",
    "borgarklassers": "borgarklass",
    "borgarna": "borgare",
    "borgarnas": "borgare",
    "borgarpressen": "borgarpress",
    "borgarpressens": "borgarpress",
    "borgarråden": "borgarråd",
    "borgarrådens": "borgarråd",
    "borgarrådet": "borgarråd",
    "borgarrådets": "borgarråd",
    "borgarråds": "borgarråd",
    "borgars": "borg",
    "borgarskolan": "borgarskola",
    "borgarskolans": "borgarskola",
    "borgarskolas": "borgarskola",
    "borgarskole": "borgarskola",
    "borgarskolor": "borgarskola",
    "borgarskolorna": "borgarskola",
    "borgarskolornas": "borgarskola",
    "borgarskolors": "borgarskola",
    "borgarståndet": "borgarstånd",
    "borgarståndets": "borgarstånd",
    "borgarstånds": "borgarstånd",
    "borgas": "borga",
    "borgat": "borga",
    "borgats": "borga",
    "borgen": "borg",
    "borgens": "borgen",
    "borgensförbindelsen": "borgensförbindelse",
    "borgensförbindelsens": "borgensförbindelse",
    "borgensförbindelser": "borgensförbindelse",
    "borgensförbindelserna": "borgensförbindelse",
    "borgensförbindelsernas": "borgensförbindelse",
    "borgensförbindelsers": "borgensförbindelse",
    "borgensförbindelses": "borgensförbindelse",
    "borgenslånen": "borgenslån",
    "borgenslånens": "borgenslån",
    "borgenslånet": "borgenslån",
    "borgenslånets": "borgenslån",
    "borgenslåns": "borgenslån",
    "borgensmannen": "borgensman",
    "borgensmannens": "borgensman",
    "borgensmans": "borgensman",
    "borgensmän": "borgensman",
    "borgensmännen": "borgensman",
    "borgensmännens": "borgensman",
    "borgensmäns": "borgensman",
    "borgenssumman": "borgenssumma",
    "borgenssummans": "borgenssumma",
    "borgenssummas": "borgenssumma",
    "borgenssumme": "borgenssumma",
    "borgenssummor": "borgenssumma",
    "borgenssummorna": "borgenssumma",
    "borgenssummornas": "borgenssumma",
    "borgenssummors": "borgenssumma",
    "borgensåtaganden": "borgensåtagande",
    "borgensåtagandena": "borgensåtagande",
    "borgensåtagandenas": "borgensåtagande",
    "borgensåtagandens": "borgensåtagande",
    "borgensåtagandes": "borgensåtagande",
    "borgensåtagandet": "borgensåtagande",
    "borgensåtagandets": "borgensåtagande",
    "borgenären": "borgenär",
    "borgenärens": "borgenär",
    "borgenärer": "borgenär",
    "borgenärerna": "borgenär",
    "borgenärernas": "borgenär",
    "borgenärers": "borgenär",
    "borgenärs": "borgenär",
    "borgenärseden": "borgenärsed",
    "borgenärsedens": "borgenärsed",
    "borgenärseder": "borgenärsed",
    "borgenärsederna": "borgenärsed",
    "borgenärsedernas": "borgenärsed",
    "borgenärseders": "borgenärsed",
    "borgenärseds": "borgenärsed",
    "borgerliga": "borgerlig",
    "borgerligare": "borgerlig",
    "borgerligares": "borgerlig",
    "borgerligas": "borgerlig",
    "borgerligast": "borgerlig",
    "borgerligaste": "borgerlig",
    "borgerligastes": "borgerlig",
    "borgerligasts": "borgerlig",
    "borgerlige": "borgerlig",
    "borgerliges": "borgerlig",
    "borgerligheten": "borgerlighet",
    "borgerlighetens": "borgerlighet",
    "borgerligheter": "borgerlighet",
    "borgerligheterna": "borgerlighet",
    "borgerligheternas": "borgerlighet",
    "borgerligheters": "borgerlighet",
    "borgerlighets": "borgerlighet",
    "borgerligs": "borgerlig",
    "borgerligt": "borgerlig",
    "borgerligts": "borgerlig",
    "borgerskapen": "borgerskap",
    "borgerskapens": "borgerskap",
    "borgerskapet": "borgerskap",
    "borgerskapets": "borgerskap",
    "borgerskaps": "borgerskap",
    "borgfreden": "borgfred",
    "borgfredens": "borgfred",
    "borgfreder": "borgfred",
    "borgfrederna": "borgfred",
    "borgfredernas": "borgfred",
    "borgfreders": "borgfred",
    "borgfreds": "borgfred",
    "borggårdar": "borggård",
    "borggårdarna": "borggård",
    "borggårdarnas": "borggård",
    "borggårdars": "borggård",
    "borggården": "borggård",
    "borggårdens": "borggård",
    "borggårds": "borggård",
    "borgisen": "borgis",
    "borgisens": "borgis",
    "borgmästar": "borgmästare",
    "borgmästaren": "borgmästare",
    "borgmästarens": "borgmästare",
    "borgmästares": "borgmästare",
    "borgmästarna": "borgmästare",
    "borgmästarnas": "borgmästare",
    "borgruinen": "borgruin",
    "borgruinens": "borgruin",
    "borgruiner": "borgruin",
    "borgruinerna": "borgruin",
    "borgruinernas": "borgruin",
    "borgruiners": "borgruin",
    "borgruins": "borgruin",
    "borgs": "borg",
    "borick": "boricka",
    "borickan": "boricka",
    "borickans": "boricka",
    "borickas": "boricka",
    "boricke": "boricka",
    "borickor": "boricka",
    "borickorna": "boricka",
    "borickornas": "boricka",
    "borickors": "boricka",
    "boricks": "boricka",
    "borkarbiden": "borkarbid",
    "borkarbidens": "borkarbid",
    "borkarbider": "borkarbid",
    "borkarbiderna": "borkarbid",
    "borkarbidernas": "borkarbid",
    "borkarbiders": "borkarbid",
    "borkarbids": "borkarbid",
    "borna": "boren",
    "bornare": "boren",
    "bornares": "boren",
    "bornas": "boren",
    "bornast": "boren",
    "bornaste": "boren",
    "bornastes": "boren",
    "bornasts": "boren",
    "borne": "boren",
    "bornerade": "bornerad",
    "bornerades": "bornerad",
    "bornerads": "bornerad",
    "bornerande": "bornera",
    "borneranden": "bornerande",
    "bornerandena": "bornerande",
    "bornerandenas": "bornerande",
    "bornerandens": "bornerande",
    "bornerandes": "bornerande",
    "bornerandet": "bornerande",
    "bornerandets": "bornerande",
    "bornerar": "bornera",
    "borneras": "bornera",
    "bornerat": "bornerad",
    "bornerats": "bornerad",
    "borneringar": "bornering",
    "borneringarna": "bornering",
    "borneringarnas": "bornering",
    "borneringars": "bornering",
    "borneringen": "bornering",
    "borneringens": "bornering",
    "bornerings": "bornering",
    "bornes": "boren",
    "bornyren": "bornyr",
    "bornyrens": "bornyr",
    "bornyrs": "bornyr",
    "borr": "borra",
    "borrad": "borra",
    "borrade": "borra",
    "borrades": "borra",
    "borrads": "borra",
    "borrande": "borra",
    "borranden": "borrande",
    "borrandena": "borrande",
    "borrandenas": "borrande",
    "borrandens": "borrande",
    "borrandes": "borrande",
    "borrandet": "borrande",
    "borrandets": "borrande",
    "borrar": "borra",
    "borrarna": "borr",
    "borrarnas": "borr",
    "borrars": "borr",
    "borras": "borra",
    "borrat": "borra",
    "borrats": "borra",
    "borrchuckar": "borrchuck",
    "borrchuckarna": "borrchuck",
    "borrchuckarnas": "borrchuck",
    "borrchuckars": "borrchuck",
    "borrchucken": "borrchuck",
    "borrchuckens": "borrchuck",
    "borrchucks": "borrchuck",
    "borrdiametern": "borrdiameter",
    "borrdiameterns": "borrdiameter",
    "borrdiameters": "borrdiameter",
    "borrdiametrar": "borrdiameter",
    "borrdiametrarna": "borrdiameter",
    "borrdiametrarnas": "borrdiameter",
    "borrdiametrars": "borrdiameter",
    "borren": "borr",
    "borrens": "borr",
    "borret": "borr",
    "borrets": "borr",
    "borrhammar": "borrhammare",
    "borrhammaren": "borrhammare",
    "borrhammarens": "borrhammare",
    "borrhammares": "borrhammare",
    "borrhammarna": "borrhammare",
    "borrhammarnas": "borrhammare",
    "borrhålen": "borrhål",
    "borrhålens": "borrhål",
    "borrhålet": "borrhål",
    "borrhålets": "borrhål",
    "borrhåls": "borrhål",
    "borrhålsväggar": "borrhålsvägg",
    "borrhålsväggarna": "borrhålsvägg",
    "borrhålsväggarnas": "borrhålsvägg",
    "borrhålsväggars": "borrhålsvägg",
    "borrhålsväggen": "borrhålsvägg",
    "borrhålsväggens": "borrhålsvägg",
    "borrhålsväggs": "borrhålsvägg",
    "borrjiggar": "borrjigg",
    "borrjiggarna": "borrjigg",
    "borrjiggarnas": "borrjigg",
    "borrjiggars": "borrjigg",
    "borrjiggen": "borrjigg",
    "borrjiggens": "borrjigg",
    "borrjiggs": "borrjigg",
    "borrklink": "borrklinka",
    "borrklinkan": "borrklinka",
    "borrklinkans": "borrklinka",
    "borrklinkas": "borrklinka",
    "borrklinke": "borrklinka",
    "borrklinkor": "borrklinka",
    "borrklinkorna": "borrklinka",
    "borrklinkornas": "borrklinka",
    "borrklinkors": "borrklinka",
    "borrklinks": "borrklinka",
    "borrkron": "borrkrona",
    "borrkronan": "borrkrona",
    "borrkronans": "borrkrona",
    "borrkronas": "borrkrona",
    "borrkrone": "borrkrona",
    "borrkronor": "borrkrona",
    "borrkronorna": "borrkrona",
    "borrkronornas": "borrkrona",
    "borrkronors": "borrkrona",
    "borrkrons": "borrkrona",
    "borrkärn": "borrkärna",
    "borrkärnan": "borrkärna",
    "borrkärnans": "borrkärna",
    "borrkärnas": "borrkärna",
    "borrkärne": "borrkärna",
    "borrkärnor": "borrkärna",
    "borrkärnorna": "borrkärna",
    "borrkärnornas": "borrkärna",
    "borrkärnors": "borrkärna",
    "borrkärns": "borrkärna",
    "borrlängden": "borrlängd",
    "borrlängdens": "borrlängd",
    "borrlängder": "borrlängd",
    "borrlängderna": "borrlängd",
    "borrlängdernas": "borrlängd",
    "borrlängders": "borrlängd",
    "borrlängds": "borrlängd",
    "borrmaskinen": "borrmaskin",
    "borrmaskinens": "borrmaskin",
    "borrmaskiner": "borrmaskin",
    "borrmaskinerna": "borrmaskin",
    "borrmaskinernas": "borrmaskin",
    "borrmaskiners": "borrmaskin",
    "borrmaskins": "borrmaskin",
    "borrmussel": "borrmussla",
    "borrmusslan": "borrmussla",
    "borrmusslans": "borrmussla",
    "borrmusslas": "borrmussla",
    "borrmussle": "borrmussla",
    "borrmusslor": "borrmussla",
    "borrmusslorna": "borrmussla",
    "borrmusslornas": "borrmussla",
    "borrmusslors": "borrmussla",
    "borrningar": "borrning",
    "borrningarna": "borrning",
    "borrningarnas": "borrning",
    "borrningars": "borrning",
    "borrningen": "borrning",
    "borrningens": "borrning",
    "borrnings": "borrning",
    "borrningsolyck": "borrningsolycka",
    "borrningsolyckan": "borrningsolycka",
    "borrningsolyckans": "borrningsolycka",
    "borrningsolyckas": "borrningsolycka",
    "borrningsolycke": "borrningsolycka",
    "borrningsolyckor": "borrningsolycka",
    "borrningsolyckorna": "borrningsolycka",
    "borrningsolyckornas": "borrningsolycka",
    "borrningsolyckors": "borrningsolycka",
    "borrningsolycks": "borrningsolycka",
    "borrplattformar": "borrplattform",
    "borrplattformarna": "borrplattform",
    "borrplattformarnas": "borrplattform",
    "borrplattformars": "borrplattform",
    "borrplattformen": "borrplattform",
    "borrplattformens": "borrplattform",
    "borrplattforms": "borrplattform",
    "borrs": "borr",
    "borrspindeln": "borrspindel",
    "borrspindelns": "borrspindel",
    "borrspindels": "borrspindel",
    "borrspindlar": "borrspindel",
    "borrspindlarna": "borrspindel",
    "borrspindlarnas": "borrspindel",
    "borrspindlars": "borrspindel",
    "borrspånen": "borrspån",
    "borrspånens": "borrspån",
    "borrspånet": "borrspån",
    "borrspånets": "borrspån",
    "borrspåns": "borrspån",
    "borrstålen": "borrstål",
    "borrstålens": "borrstål",
    "borrstålet": "borrstål",
    "borrstålets": "borrstål",
    "borrståls": "borrstål",
    "borrsvängar": "borrsväng",
    "borrsvängarna": "borrsväng",
    "borrsvängarnas": "borrsväng",
    "borrsvängars": "borrsväng",
    "borrsvängen": "borrsväng",
    "borrsvängens": "borrsväng",
    "borrsvängs": "borrsväng",
    "borrtornen": "borrtorn",
    "borrtornens": "borrtorn",
    "borrtornet": "borrtorn",
    "borrtornets": "borrtorn",
    "borrtorns": "borrtorn",
    "bors": "bor",
    "borsjtjen": "borsjtj",
    "borsjtjens": "borsjtj",
    "borsjtjs": "borsjtj",
    "borst": "borste",
    "borstad": "borsta",
    "borstade": "borsta",
    "borstades": "borsta",
    "borstads": "borsta",
    "borstande": "borsta",
    "borstanden": "borstande",
    "borstandena": "borstande",
    "borstandenas": "borstande",
    "borstandens": "borstande",
    "borstandes": "borstande",
    "borstandet": "borstande",
    "borstandets": "borstande",
    "borstar": "borste",
    "borstarna": "borste",
    "borstarnas": "borste",
    "borstars": "borste",
    "borstas": "borsta",
    "borstat": "borsta",
    "borstats": "borsta",
    "borstbindar": "borstbindare",
    "borstbindaren": "borstbindare",
    "borstbindarens": "borstbindare",
    "borstbindares": "borstbindare",
    "borstbindarna": "borstbindare",
    "borstbindarnas": "borstbindare",
    "borstbinderier": "borstbinderi",
    "borstbinderierna": "borstbinderi",
    "borstbinderiernas": "borstbinderi",
    "borstbinderiers": "borstbinderi",
    "borstbinderiet": "borstbinderi",
    "borstbinderiets": "borstbinderi",
    "borstbinderis": "borstbinderi",
    "borstbinderit": "borstbinderi",
    "borstbinderits": "borstbinderi",
    "borsten": "borste",
    "borstens": "borste",
    "borstes": "borste",
    "borstet": "borst",
    "borstets": "borst",
    "borstgarnityren": "borstgarnityr",
    "borstgarnityrens": "borstgarnityr",
    "borstgarnityret": "borstgarnityr",
    "borstgarnityrets": "borstgarnityr",
    "borstgarnityrs": "borstgarnityr",
    "borstgräsen": "borstgräs",
    "borstgräsens": "borstgräs",
    "borstgräset": "borstgräs",
    "borstgräsets": "borstgräs",
    "borstiga": "borstig",
    "borstigare": "borstig",
    "borstigares": "borstig",
    "borstigas": "borstig",
    "borstigast": "borstig",
    "borstigaste": "borstig",
    "borstigastes": "borstig",
    "borstigasts": "borstig",
    "borstige": "borstig",
    "borstiges": "borstig",
    "borstigheten": "borstighet",
    "borstighetens": "borstighet",
    "borstighets": "borstighet",
    "borstigs": "borstig",
    "borstigt": "borstig",
    "borstigts": "borstig",
    "borstlösa": "borstlös",
    "borstlösare": "borstlös",
    "borstlösares": "borstlös",
    "borstlösas": "borstlös",
    "borstlösast": "borstlös",
    "borstlösaste": "borstlös",
    "borstlösastes": "borstlös",
    "borstlösasts": "borstlös",
    "borstlöse": "borstlös",
    "borstlöses": "borstlös",
    "borstlösheten": "borstlöshet",
    "borstlöshetens": "borstlöshet",
    "borstlöshets": "borstlöshet",
    "borstlöst": "borstlös",
    "borstlösts": "borstlös",
    "borstmaskar": "borstmask",
    "borstmaskarna": "borstmask",
    "borstmaskarnas": "borstmask",
    "borstmaskars": "borstmask",
    "borstmasken": "borstmask",
    "borstmaskens": "borstmask",
    "borstmasks": "borstmask",
    "borstnaten": "borstnate",
    "borstnatens": "borstnate",
    "borstnates": "borstnate",
    "borstnejlik": "borstnejlika",
    "borstnejlikan": "borstnejlika",
    "borstnejlikans": "borstnejlika",
    "borstnejlikas": "borstnejlika",
    "borstnejlike": "borstnejlika",
    "borstnejlikor": "borstnejlika",
    "borstnejlikorna": "borstnejlika",
    "borstnejlikornas": "borstnejlika",
    "borstnejlikors": "borstnejlika",
    "borstnejliks": "borstnejlika",
    "borstningar": "borstning",
    "borstningarna": "borstning",
    "borstningarnas": "borstning",
    "borstningars": "borstning",
    "borstningen": "borstning",
    "borstningens": "borstning",
    "borstnings": "borstning",
    "borsts": "borst",
    "borstsvansar": "borstsvans",
    "borstsvansarna": "borstsvans",
    "borstsvansarnas": "borstsvans",
    "borstsvansars": "borstsvans",
    "borstsvansen": "borstsvans",
    "borstsvansens": "borstsvans",
    "borstviskar": "borstviskare",
    "borstviskaren": "borstviskare",
    "borstviskarens": "borstviskare",
    "borstviskares": "borstviskare",
    "borstviskarna": "borstviskare",
    "borstviskarnas": "borstviskare",
    "borsyran": "borsyra",
    "borsyrans": "borsyra",
    "borsyras": "borsyra",
    "borsyre": "borsyra",
    "bort": "böra",
    "bortaförsäkringar": "bortaförsäkring",
    "bortaförsäkringarna": "bortaförsäkring",
    "bortaförsäkringarnas": "bortaförsäkring",
    "bortaförsäkringars": "bortaförsäkring",
    "bortaförsäkringen": "bortaförsäkring",
    "bortaförsäkringens": "bortaförsäkring",
    "bortaförsäkrings": "bortaförsäkring",
    "bortalagen": "bortalag",
    "bortalagens": "bortalag",
    "bortalaget": "bortalag",
    "bortalagets": "bortalag",
    "bortalags": "bortalag",
    "bortamatchen": "bortamatch",
    "bortamatchens": "bortamatch",
    "bortamatcher": "bortamatch",
    "bortamatcherna": "bortamatch",
    "bortamatchernas": "bortamatch",
    "bortamatchers": "bortamatch",
    "bortamatchs": "bortamatch",
    "bortaplanen": "bortaplan",
    "bortaplanens": "bortaplan",
    "bortaplaner": "bortaplan",
    "bortaplanerna": "bortaplan",
    "bortaplanernas": "bortaplan",
    "bortaplaners": "bortaplan",
    "bortaplans": "bortaplan",
    "bortarbet": "bortarbeta",
    "bortarbetade": "bortarbeta",
    "bortarbetades": "bortarbeta",
    "bortarbetande": "bortarbeta",
    "bortarbetanden": "bortarbetande",
    "bortarbetandena": "bortarbetande",
    "bortarbetandenas": "bortarbetande",
    "bortarbetandens": "bortarbetande",
    "bortarbetandes": "bortarbetande",
    "bortarbetandet": "bortarbetande",
    "bortarbetandets": "bortarbetande",
    "bortarbetar": "bortarbeta",
    "bortarbetas": "bortarbeta",
    "bortarbetat": "bortarbeta",
    "bortarbetats": "bortarbeta",
    "bortasegern": "bortaseger",
    "bortasegerns": "bortaseger",
    "bortasegers": "bortaseger",
    "bortasegrar": "bortaseger",
    "bortasegrarna": "bortaseger",
    "bortasegrarnas": "bortaseger",
    "bortasegrars": "bortaseger",
    "bortavaron": "bortavaro",
    "bortavarons": "bortavaro",
    "bortavaros": "bortavaro",
    "bortbjudens": "bortbjuden",
    "bortbjudet": "bortbjuden",
    "bortbjudets": "bortbjuden",
    "bortbjudna": "bortbjuden",
    "bortbjudnare": "bortbjuden",
    "bortbjudnares": "bortbjuden",
    "bortbjudnas": "bortbjuden",
    "bortbjudnast": "bortbjuden",
    "bortbjudnaste": "bortbjuden",
    "bortbjudnastes": "bortbjuden",
    "bortbjudnasts": "bortbjuden",
    "bortbjudne": "bortbjuden",
    "bortbjudnes": "bortbjuden",
    "bortblåsta": "bortblåst",
    "bortblåstas": "bortblåst",
    "bortblåste": "bortblåst",
    "bortblåstes": "bortblåst",
    "bortblåsts": "bortblåst",
    "bortbytingar": "bortbyting",
    "bortbytingarna": "bortbyting",
    "bortbytingarnas": "bortbyting",
    "bortbytingars": "bortbyting",
    "bortbytingen": "bortbyting",
    "bortbytingens": "bortbyting",
    "bortbytings": "bortbyting",
    "bortdrev": "bortdriva",
    "bortdrevs": "bortdriva",
    "bortdriv": "bortdriva",
    "bortdrivande": "bortdriva",
    "bortdrivanden": "bortdrivande",
    "bortdrivandena": "bortdrivande",
    "bortdrivandenas": "bortdrivande",
    "bortdrivandens": "bortdrivande",
    "bortdrivandes": "bortdrivande",
    "bortdrivandet": "bortdrivande",
    "bortdrivandets": "bortdrivande",
    "bortdrivas": "bortdriva",
    "bortdrive": "bortdriva",
    "bortdriver": "bortdriva",
    "bortdrives": "bortdriva",
    "bortdrivit": "bortdriva",
    "bortdrivits": "bortdriva",
    "bortdrivs": "bortdriva",
    "bortdöenden": "bortdöende",
    "bortdöendena": "bortdöende",
    "bortdöendenas": "bortdöende",
    "bortdöendens": "bortdöende",
    "bortdöendes": "bortdöende",
    "bortdöendet": "bortdöende",
    "bortdöendets": "bortdöende",
    "bortdömningar": "bortdömning",
    "bortdömningarna": "bortdömning",
    "bortdömningarnas": "bortdömning",
    "bortdömningars": "bortdömning",
    "bortdömningen": "bortdömning",
    "bortdömningens": "bortdömning",
    "bortdömnings": "bortdömning",
    "bortersta": "bortre",
    "borterstas": "bortre",
    "borterste": "bortre",
    "borterstes": "bortre",
    "bortfall": "bortfalla",
    "bortfallande": "bortfalla",
    "bortfallanden": "bortfallande",
    "bortfallandena": "bortfallande",
    "bortfallandenas": "bortfallande",
    "bortfallandens": "bortfallande",
    "bortfallandes": "bortfallande",
    "bortfallandet": "bortfallande",
    "bortfallandets": "bortfallande",
    "bortfallas": "bortfalla",
    "bortfalle": "bortfalla",
    "bortfallen": "bortfalla",
    "bortfallens": "bortfalla",
    "bortfaller": "bortfalla",
    "bortfalles": "bortfalla",
    "bortfallet": "bortfalla",
    "bortfallets": "bortfalla",
    "bortfallit": "bortfalla",
    "bortfallits": "bortfalla",
    "bortfallna": "bortfalla",
    "bortfallnas": "bortfalla",
    "bortfallne": "bortfalla",
    "bortfallnes": "bortfalla",
    "bortfalls": "bortfalla",
    "bortflugens": "bortflugen",
    "bortfluget": "bortflugen",
    "bortflugets": "bortflugen",
    "bortflugna": "bortflugen",
    "bortflugnas": "bortflugen",
    "bortflugne": "bortflugen",
    "bortflugnes": "bortflugen",
    "bortföll": "bortfalla",
    "bortfölle": "bortfalla",
    "bortfölles": "bortfalla",
    "bortfölls": "bortfalla",
    "bortför": "bortföra",
    "bortförande": "bortföra",
    "bortföranden": "bortförande",
    "bortförandena": "bortförande",
    "bortförandenas": "bortförande",
    "bortförandens": "bortförande",
    "bortförandes": "bortförande",
    "bortförandet": "bortförande",
    "bortförandets": "bortförande",
    "bortföras": "bortföra",
    "bortförd": "bortföra",
    "bortförda": "bortföra",
    "bortfördas": "bortföra",
    "bortförde": "bortföra",
    "bortfördes": "bortföra",
    "bortförds": "bortföra",
    "bortföres": "bortföra",
    "bortförklar": "bortförklara",
    "bortförklarade": "bortförklara",
    "bortförklarades": "bortförklara",
    "bortförklarande": "bortförklara",
    "bortförklaranden": "bortförklarande",
    "bortförklarandena": "bortförklarande",
    "bortförklarandenas": "bortförklarande",
    "bortförklarandens": "bortförklarande",
    "bortförklarandes": "bortförklarande",
    "bortförklarandet": "bortförklarande",
    "bortförklarandets": "bortförklarande",
    "bortförklarar": "bortförklara",
    "bortförklaras": "bortförklara",
    "bortförklarat": "bortförklara",
    "bortförklarats": "bortförklara",
    "bortförklaringar": "bortförklaring",
    "bortförklaringarna": "bortförklaring",
    "bortförklaringarnas": "bortförklaring",
    "bortförklaringars": "bortförklaring",
    "bortförklaringen": "bortförklaring",
    "bortförklaringens": "bortförklaring",
    "bortförklarings": "bortförklaring",
    "bortförs": "bortföra",
    "bortfört": "bortföra",
    "bortförts": "bortföra",
    "bortgick": "bortgå",
    "bortgicks": "bortgå",
    "bortginge": "bortgå",
    "bortginges": "bortgå",
    "bortglömda": "bortglömd",
    "bortglömdare": "bortglömd",
    "bortglömdares": "bortglömd",
    "bortglömdas": "bortglömd",
    "bortglömdast": "bortglömd",
    "bortglömdaste": "bortglömd",
    "bortglömdastes": "bortglömd",
    "bortglömdasts": "bortglömd",
    "bortglömde": "bortglömd",
    "bortglömdes": "bortglömd",
    "bortglömdheten": "bortglömdhet",
    "bortglömdhetens": "bortglömdhet",
    "bortglömdhets": "bortglömdhet",
    "bortglömds": "bortglömd",
    "bortglömt": "bortglömd",
    "bortglömts": "bortglömd",
    "bortgående": "bortgå",
    "bortgåenden": "bortgående",
    "bortgåendena": "bortgående",
    "bortgåendenas": "bortgående",
    "bortgåendens": "bortgående",
    "bortgåendes": "bortgående",
    "bortgåendet": "bortgående",
    "bortgåendets": "bortgående",
    "bortgången": "bortgång",
    "bortgångens": "bortgång",
    "bortgångs": "bortgång",
    "bortgår": "bortgå",
    "bortgås": "bortgå",
    "bortgått": "bortgå",
    "bortgåtts": "bortgå",
    "bortkastade": "bortkastad",
    "bortkastades": "bortkastad",
    "bortkastads": "bortkastad",
    "bortkastat": "bortkastad",
    "bortkastats": "bortkastad",
    "bortkommenheten": "bortkommenhet",
    "bortkommenhetens": "bortkommenhet",
    "bortkommenhets": "bortkommenhet",
    "bortkommens": "bortkommen",
    "bortkommet": "bortkommen",
    "bortkommets": "bortkommen",
    "bortkomna": "bortkommen",
    "bortkomnare": "bortkommen",
    "bortkomnares": "bortkommen",
    "bortkomnas": "bortkommen",
    "bortkomnast": "bortkommen",
    "bortkomnaste": "bortkommen",
    "bortkomnastes": "bortkommen",
    "bortkomnasts": "bortkommen",
    "bortkomne": "bortkommen",
    "bortkomnes": "bortkommen",
    "bortlov": "bortlova",
    "bortlovade": "bortlova",
    "bortlovades": "bortlova",
    "bortlovande": "bortlova",
    "bortlovanden": "bortlovande",
    "bortlovandena": "bortlovande",
    "bortlovandenas": "bortlovande",
    "bortlovandens": "bortlovande",
    "bortlovandes": "bortlovande",
    "bortlovandet": "bortlovande",
    "bortlovandets": "bortlovande",
    "bortlovar": "bortlova",
    "bortlovas": "bortlova",
    "bortlovat": "bortlova",
    "bortlovats": "bortlova",
    "bortmonterad": "bortmontera",
    "bortmonterade": "bortmontera",
    "bortmonterades": "bortmontera",
    "bortmonterads": "bortmontera",
    "bortmonterande": "bortmontera",
    "bortmonterandes": "bortmontera",
    "bortmonterar": "bortmontera",
    "bortmonteras": "bortmontera",
    "bortmonterat": "bortmontera",
    "bortmonterats": "bortmontera",
    "bortmot": "bortmota",
    "bortmotade": "bortmota",
    "bortmotades": "bortmota",
    "bortmotande": "bortmota",
    "bortmotanden": "bortmotande",
    "bortmotandena": "bortmotande",
    "bortmotandenas": "bortmotande",
    "bortmotandens": "bortmotande",
    "bortmotandes": "bortmotande",
    "bortmotandet": "bortmotande",
    "bortmotandets": "bortmotande",
    "bortmotar": "bortmota",
    "bortmotas": "bortmota",
    "bortmotat": "bortmota",
    "bortmotats": "bortmota",
    "bortodlingar": "bortodling",
    "bortodlingarna": "bortodling",
    "bortodlingarnas": "bortodling",
    "bortodlingars": "bortodling",
    "bortodlingen": "bortodling",
    "bortodlingens": "bortodling",
    "bortodlings": "bortodling",
    "bortopererade": "bortoperera",
    "bortopererades": "bortoperera",
    "bortopererande": "bortoperera",
    "bortopereranden": "bortopererande",
    "bortopererandena": "bortopererande",
    "bortopererandenas": "bortopererande",
    "bortopererandens": "bortopererande",
    "bortopererandes": "bortopererande",
    "bortopererandet": "bortopererande",
    "bortopererandets": "bortopererande",
    "bortopererar": "bortoperera",
    "bortopereras": "bortoperera",
    "bortopererat": "bortoperera",
    "bortopererats": "bortoperera",
    "bortovaron": "bortovaro",
    "bortovarons": "bortovaro",
    "bortovaros": "bortovaro",
    "bortrann": "bortrinna",
    "bortranns": "bortrinna",
    "bortrationaliserade": "bortrationalisera",
    "bortrationaliserades": "bortrationalisera",
    "bortrationaliserande": "bortrationalisera",
    "bortrationaliseranden": "bortrationaliserande",
    "bortrationaliserandena": "bortrationaliserande",
    "bortrationaliserandenas": "bortrationaliserande",
    "bortrationaliserandens": "bortrationaliserande",
    "bortrationaliserandes": "bortrationaliserande",
    "bortrationaliserandet": "bortrationaliserande",
    "bortrationaliserandets": "bortrationaliserande",
    "bortrationaliserar": "bortrationalisera",
    "bortrationaliseras": "bortrationalisera",
    "bortrationaliserat": "bortrationalisera",
    "bortrationaliserats": "bortrationalisera",
    "bortrationaliseringar": "bortrationalisering",
    "bortrationaliseringarna": "bortrationalisering",
    "bortrationaliseringarnas": "bortrationalisering",
    "bortrationaliseringars": "bortrationalisering",
    "bortrationaliseringen": "bortrationalisering",
    "bortrationaliseringens": "bortrationalisering",
    "bortrationaliserings": "bortrationalisering",
    "bortres": "bortre",
    "bortresonerad": "bortresonera",
    "bortresonerade": "bortresonera",
    "bortresonerades": "bortresonera",
    "bortresonerads": "bortresonera",
    "bortresonerande": "bortresonera",
    "bortresoneranden": "bortresonerande",
    "bortresonerandena": "bortresonerande",
    "bortresonerandenas": "bortresonerande",
    "bortresonerandens": "bortresonerande",
    "bortresonerandes": "bortresonerande",
    "bortresonerandet": "bortresonerande",
    "bortresonerandets": "bortresonerande",
    "bortresonerar": "bortresonera",
    "bortresoneras": "bortresonera",
    "bortresonerat": "bortresonera",
    "bortresonerats": "bortresonera",
    "bortresonerbara": "bortresonerbar",
    "bortresonerbarare": "bortresonerbar",
    "bortresonerbarares": "bortresonerbar",
    "bortresonerbaras": "bortresonerbar",
    "bortresonerbarast": "bortresonerbar",
    "bortresonerbaraste": "bortresonerbar",
    "bortresonerbarastes": "bortresonerbar",
    "bortresonerbarasts": "bortresonerbar",
    "bortresonerbare": "bortresonerbar",
    "bortresonerbares": "bortresonerbar",
    "bortresonerbarheten": "bortresonerbarhet",
    "bortresonerbarhetens": "bortresonerbarhet",
    "bortresonerbarhets": "bortresonerbarhet",
    "bortresonerbars": "bortresonerbar",
    "bortresonerbart": "bortresonerbar",
    "bortresonerbarts": "bortresonerbar",
    "bortresoneringar": "bortresonering",
    "bortresoneringarna": "bortresonering",
    "bortresoneringarnas": "bortresonering",
    "bortresoneringars": "bortresonering",
    "bortresoneringen": "bortresonering",
    "bortresoneringens": "bortresonering",
    "bortresonerings": "bortresonering",
    "bortresta": "bortrest",
    "bortrestare": "bortrest",
    "bortrestares": "bortrest",
    "bortrestas": "bortrest",
    "bortrestast": "bortrest",
    "bortrestaste": "bortrest",
    "bortrestastes": "bortrest",
    "bortrestasts": "bortrest",
    "bortreste": "bortrest",
    "bortrestes": "bortrest",
    "bortrestheten": "bortresthet",
    "bortresthetens": "bortresthet",
    "bortresthets": "bortresthet",
    "bortrests": "bortrest",
    "bortrinn": "bortrinna",
    "bortrinnande": "bortrinna",
    "bortrinnanden": "bortrinnande",
    "bortrinnandena": "bortrinnande",
    "bortrinnandenas": "bortrinnande",
    "bortrinnandens": "bortrinnande",
    "bortrinnandes": "bortrinnande",
    "bortrinnandet": "bortrinnande",
    "bortrinnandets": "bortrinnande",
    "bortrinnas": "bortrinna",
    "bortrinne": "bortrinna",
    "bortrinner": "bortrinna",
    "bortrinnes": "bortrinna",
    "bortrinns": "bortrinna",
    "bortrunna": "bortrinna",
    "bortrunnas": "bortrinna",
    "bortrunne": "bortrinna",
    "bortrunnen": "bortrinna",
    "bortrunnens": "bortrinna",
    "bortrunnes": "bortrinna",
    "bortrunnet": "bortrinna",
    "bortrunnets": "bortrinna",
    "bortrunnit": "bortrinna",
    "bortrunnits": "bortrinna",
    "bortryckta": "bortryckt",
    "bortrycktas": "bortryckt",
    "bortryckte": "bortryckt",
    "bortrycktes": "bortryckt",
    "bortryckts": "bortryckt",
    "borträkn": "borträkna",
    "borträknade": "borträkna",
    "borträknades": "borträkna",
    "borträknande": "borträkna",
    "borträknanden": "borträknande",
    "borträknandena": "borträknande",
    "borträknandenas": "borträknande",
    "borträknandens": "borträknande",
    "borträknandes": "borträknande",
    "borträknandet": "borträknande",
    "borträknandets": "borträknande",
    "borträknar": "borträkna",
    "borträknas": "borträkna",
    "borträknat": "borträkna",
    "borträknats": "borträkna",
    "borträng": "bortränga",
    "borträngande": "bortränga",
    "borträngandes": "bortränga",
    "borträngas": "bortränga",
    "borträngd": "bortränga",
    "borträngda": "bortränga",
    "borträngdas": "bortränga",
    "borträngde": "bortränga",
    "borträngdes": "bortränga",
    "borträngds": "bortränga",
    "bortränger": "bortränga",
    "bortränges": "bortränga",
    "borträngs": "bortränga",
    "borträngt": "bortränga",
    "borträngts": "bortränga",
    "bortröv": "bortröva",
    "bortrövad": "bortröva",
    "bortrövade": "bortröva",
    "bortrövades": "bortröva",
    "bortrövads": "bortröva",
    "bortrövande": "bortröva",
    "bortrövanden": "bortrövande",
    "bortrövandena": "bortrövande",
    "bortrövandenas": "bortrövande",
    "bortrövandens": "bortrövande",
    "bortrövandes": "bortrövande",
    "bortrövandet": "bortrövande",
    "bortrövandets": "bortrövande",
    "bortrövar": "bortröva",
    "bortrövas": "bortröva",
    "bortrövat": "bortröva",
    "bortrövats": "bortröva",
    "borts": "böra",
    "bortsedd": "bortse",
    "bortsedda": "bortse",
    "bortseddas": "bortse",
    "bortsedde": "bortse",
    "bortseddes": "bortse",
    "bortsedds": "bortse",
    "bortseende": "bortse",
    "bortseenden": "bortseende",
    "bortseendena": "bortseende",
    "bortseendenas": "bortseende",
    "bortseendens": "bortseende",
    "bortseendes": "bortseende",
    "bortseendet": "bortseende",
    "bortseendets": "bortseende",
    "bortser": "bortse",
    "bortses": "bortse",
    "bortsett": "bortse",
    "bortsetts": "bortse",
    "bortsidan": "bortsida",
    "bortsidans": "bortsida",
    "bortsidas": "bortsida",
    "bortskrivningar": "bortskrivning",
    "bortskrivningarna": "bortskrivning",
    "bortskrivningarnas": "bortskrivning",
    "bortskrivningars": "bortskrivning",
    "bortskrivningen": "bortskrivning",
    "bortskrivningens": "bortskrivning",
    "bortskrivnings": "bortskrivning",
    "bortskräm": "bortskrämma",
    "bortskrämmande": "bortskrämma",
    "bortskrämmanden": "bortskrämmande",
    "bortskrämmandena": "bortskrämmande",
    "bortskrämmandenas": "bortskrämmande",
    "bortskrämmandens": "bortskrämmande",
    "bortskrämmandes": "bortskrämmande",
    "bortskrämmandet": "bortskrämmande",
    "bortskrämmandets": "bortskrämmande",
    "bortskrämmas": "bortskrämma",
    "bortskrämme": "bortskrämma",
    "bortskrämmer": "bortskrämma",
    "bortskrämmes": "bortskrämma",
    "bortskräms": "bortskrämma",
    "bortskrämt": "bortskrämma",
    "bortskrämts": "bortskrämma",
    "bortslump": "bortslumpa",
    "bortslumpade": "bortslumpa",
    "bortslumpades": "bortslumpa",
    "bortslumpande": "bortslumpa",
    "bortslumpanden": "bortslumpande",
    "bortslumpandena": "bortslumpande",
    "bortslumpandenas": "bortslumpande",
    "bortslumpandens": "bortslumpande",
    "bortslumpandes": "bortslumpande",
    "bortslumpandet": "bortslumpande",
    "bortslumpandets": "bortslumpande",
    "bortslumpar": "bortslumpa",
    "bortslumpas": "bortslumpa",
    "bortslumpat": "bortslumpa",
    "bortslumpats": "bortslumpa",
    "bortslut": "bortsluta",
    "bortslutande": "bortsluta",
    "bortslutanden": "bortslutande",
    "bortslutandena": "bortslutande",
    "bortslutandenas": "bortslutande",
    "bortslutandens": "bortslutande",
    "bortslutandes": "bortslutande",
    "bortslutandet": "bortslutande",
    "bortslutandets": "bortslutande",
    "bortslutas": "bortsluta",
    "bortslute": "bortsluta",
    "bortsluten": "bortsluta",
    "bortslutens": "bortsluta",
    "bortsluter": "bortsluta",
    "bortslutes": "bortsluta",
    "bortslutet": "bortsluta",
    "bortslutets": "bortsluta",
    "bortslutit": "bortsluta",
    "bortslutits": "bortsluta",
    "bortslutna": "bortsluta",
    "bortslutnas": "bortsluta",
    "bortslutne": "bortsluta",
    "bortslutnes": "bortsluta",
    "bortsluts": "bortsluta",
    "bortslöt": "bortsluta",
    "bortslöte": "bortsluta",
    "bortslötes": "bortsluta",
    "bortslöts": "bortsluta",
    "bortstötningar": "bortstötning",
    "bortstötningarna": "bortstötning",
    "bortstötningarnas": "bortstötning",
    "bortstötningars": "bortstötning",
    "bortstötningen": "bortstötning",
    "bortstötningens": "bortstötning",
    "bortstötnings": "bortstötning",
    "bortsättningar": "bortsättning",
    "bortsättningarna": "bortsättning",
    "bortsättningarnas": "bortsättning",
    "bortsättningars": "bortsättning",
    "bortsättningen": "bortsättning",
    "bortsättningens": "bortsättning",
    "bortsättnings": "bortsättning",
    "bortsåg": "bortse",
    "bortsåge": "bortse",
    "bortsåges": "bortse",
    "bortsågs": "bortse",
    "borttag": "bortta",
    "borttaga": "bortta",
    "borttagande": "bortta",
    "borttaganden": "borttagande",
    "borttagandena": "borttagande",
    "borttagandenas": "borttagande",
    "borttagandens": "borttagande",
    "borttagandes": "borttagande",
    "borttagandet": "borttagande",
    "borttagandets": "borttagande",
    "borttagas": "bortta",
    "borttage": "bortta",
    "borttagen": "bortta",
    "borttagens": "bortta",
    "borttager": "bortta",
    "borttages": "bortta",
    "borttaget": "bortta",
    "borttagets": "bortta",
    "borttagit": "bortta",
    "borttagits": "bortta",
    "borttagna": "bortta",
    "borttagnas": "bortta",
    "borttagne": "bortta",
    "borttagnes": "bortta",
    "borttags": "bortta",
    "borttapp": "borttappa",
    "borttappade": "borttappad",
    "borttappades": "borttappad",
    "borttappads": "borttappad",
    "borttappande": "borttappa",
    "borttappanden": "borttappande",
    "borttappandena": "borttappande",
    "borttappandenas": "borttappande",
    "borttappandens": "borttappande",
    "borttappandes": "borttappande",
    "borttappandet": "borttappande",
    "borttappandets": "borttappande",
    "borttappar": "borttappa",
    "borttappas": "borttappa",
    "borttappat": "borttappad",
    "borttappats": "borttappad",
    "borttar": "bortta",
    "borttas": "bortta",
    "borttog": "bortta",
    "borttoge": "bortta",
    "borttoges": "bortta",
    "borttogs": "bortta",
    "borttork": "borttorka",
    "borttorkade": "borttorka",
    "borttorkades": "borttorka",
    "borttorkande": "borttorka",
    "borttorkanden": "borttorkande",
    "borttorkandena": "borttorkande",
    "borttorkandenas": "borttorkande",
    "borttorkandens": "borttorkande",
    "borttorkandes": "borttorkande",
    "borttorkandet": "borttorkande",
    "borttorkandets": "borttorkande",
    "borttorkar": "borttorka",
    "borttorkas": "borttorka",
    "borttorkat": "borttorka",
    "borttorkats": "borttorka",
    "bortträngningar": "bortträngning",
    "bortträngningarna": "bortträngning",
    "bortträngningarnas": "bortträngning",
    "bortträngningars": "bortträngning",
    "bortträngningen": "bortträngning",
    "bortträngningens": "bortträngning",
    "bortträngnings": "bortträngning",
    "borttvagningar": "borttvagning",
    "borttvagningarna": "borttvagning",
    "borttvagningarnas": "borttvagning",
    "borttvagningars": "borttvagning",
    "borttvagningen": "borttvagning",
    "borttvagningens": "borttvagning",
    "borttvagnings": "borttvagning",
    "bortvikten": "bortvikt",
    "bortviktens": "bortvikt",
    "bortvikts": "bortvikt",
    "bortvräk": "bortvräka",
    "bortvräkande": "bortvräka",
    "bortvräkanden": "bortvräkande",
    "bortvräkandena": "bortvräkande",
    "bortvräkandenas": "bortvräkande",
    "bortvräkandens": "bortvräkande",
    "bortvräkandes": "bortvräkande",
    "bortvräkandet": "bortvräkande",
    "bortvräkandets": "bortvräkande",
    "bortvräkas": "bortvräka",
    "bortvräker": "bortvräka",
    "bortvräkes": "bortvräka",
    "bortvräks": "bortvräka",
    "bortvräkt": "bortvräka",
    "bortvräkte": "bortvräka",
    "bortvräktes": "bortvräka",
    "bortvräkts": "bortvräka",
    "bortänd": "bortända",
    "bortändan": "bortända",
    "bortändans": "bortända",
    "bortändas": "bortända",
    "bortände": "bortända",
    "bortänden": "bortände",
    "bortändens": "bortände",
    "bortändes": "bortände",
    "bortändor": "bortända",
    "bortändorna": "bortända",
    "bortändornas": "bortända",
    "bortändors": "bortända",
    "bortänds": "bortända",
    "bos": "bo",
    "bosatta": "bosatt",
    "bosattare": "bosatt",
    "bosattares": "bosatt",
    "bosattas": "bosatt",
    "bosattast": "bosatt",
    "bosattaste": "bosatt",
    "bosattastes": "bosatt",
    "bosattasts": "bosatt",
    "bosatte": "bosatt",
    "bosattes": "bosatt",
    "bosatts": "bosatt",
    "boschet": "bosch",
    "boschets": "bosch",
    "boschs": "bosch",
    "boskapen": "boskap",
    "boskapens": "boskap",
    "boskaps": "boskap",
    "boskapsdriften": "boskapsdrift",
    "boskapsdriftens": "boskapsdrift",
    "boskapsdrifts": "boskapsdrift",
    "boskapshjordar": "boskapshjord",
    "boskapshjordarna": "boskapshjord",
    "boskapshjordarnas": "boskapshjord",
    "boskapshjordars": "boskapshjord",
    "boskapshjorden": "boskapshjord",
    "boskapshjordens": "boskapshjord",
    "boskapshjords": "boskapshjord",
    "boskapspesten": "boskapspest",
    "boskapspestens": "boskapspest",
    "boskapspests": "boskapspest",
    "boskapsskötar": "boskapsskötare",
    "boskapsskötaren": "boskapsskötare",
    "boskapsskötarens": "boskapsskötare",
    "boskapsskötares": "boskapsskötare",
    "boskapsskötarna": "boskapsskötare",
    "boskapsskötarnas": "boskapsskötare",
    "boskapsskötseln": "boskapsskötsel",
    "boskapsskötselns": "boskapsskötsel",
    "boskapsskötsels": "boskapsskötsel",
    "boskapsstockar": "boskapsstock",
    "boskapsstockarna": "boskapsstock",
    "boskapsstockarnas": "boskapsstock",
    "boskapsstockars": "boskapsstock",
    "boskapsstocken": "boskapsstock",
    "boskapsstockens": "boskapsstock",
    "boskapsstocks": "boskapsstock",
    "boskapsstängsels": "boskapsstängsel",
    "boskapsstängslen": "boskapsstängsel",
    "boskapsstängslens": "boskapsstängsel",
    "boskapsstängslet": "boskapsstängsel",
    "boskapsstängslets": "boskapsstängsel",
    "boskapsuppfödningar": "boskapsuppfödning",
    "boskapsuppfödningarna": "boskapsuppfödning",
    "boskapsuppfödningarnas": "boskapsuppfödning",
    "boskapsuppfödningars": "boskapsuppfödning",
    "boskapsuppfödningen": "boskapsuppfödning",
    "boskapsuppfödningens": "boskapsuppfödning",
    "boskapsuppfödnings": "boskapsuppfödning",
    "boskiften": "boskifte",
    "boskiftena": "boskifte",
    "boskiftenas": "boskifte",
    "boskiftens": "boskifte",
    "boskiftes": "boskifte",
    "boskiftet": "boskifte",
    "boskiftets": "boskifte",
    "boskillnaden": "boskillnad",
    "boskillnadens": "boskillnad",
    "boskillnader": "boskillnad",
    "boskillnaderna": "boskillnad",
    "boskillnadernas": "boskillnad",
    "boskillnaders": "boskillnad",
    "boskillnads": "boskillnad",
    "bosniern": "bosnier",
    "bosnierna": "bosnier",
    "bosniernas": "bosnier",
    "bosnierns": "bosnier",
    "bosniers": "bosnier",
    "bosniska": "bosnisk",
    "bosniskan": "bosniska",
    "bosniskans": "bosniska",
    "bosniskare": "bosnisk",
    "bosniskares": "bosnisk",
    "bosniskas": "bosniska",
    "bosniskast": "bosnisk",
    "bosniskaste": "bosnisk",
    "bosniskastes": "bosnisk",
    "bosniskasts": "bosnisk",
    "bosniske": "bosniska",
    "bosniskes": "bosnisk",
    "bosniskor": "bosniska",
    "bosniskorna": "bosniska",
    "bosniskornas": "bosniska",
    "bosniskors": "bosniska",
    "bosnisks": "bosnisk",
    "bosniskt": "bosnisk",
    "bosniskts": "bosnisk",
    "bosonen": "boson",
    "bosonens": "boson",
    "bosoner": "boson",
    "bosonerna": "boson",
    "bosonernas": "boson",
    "bosoners": "boson",
    "bosons": "boson",
    "bossar": "boss",
    "bossarna": "boss",
    "bossarnas": "boss",
    "bossars": "boss",
    "bossen": "boss",
    "bossens": "boss",
    "bosset": "boss",
    "bossets": "boss",
    "bossiga": "bossig",
    "bossigare": "bossig",
    "bossigares": "bossig",
    "bossigas": "bossig",
    "bossigast": "bossig",
    "bossigaste": "bossig",
    "bossigastes": "bossig",
    "bossigasts": "bossig",
    "bossige": "bossig",
    "bossiges": "bossig",
    "bossigheten": "bossighet",
    "bossighetens": "bossighet",
    "bossighets": "bossighet",
    "bossigs": "bossig",
    "bossigt": "bossig",
    "bossigts": "bossig",
    "bossvälden": "bossvälde",
    "bossväldena": "bossvälde",
    "bossväldenas": "bossvälde",
    "bossväldens": "bossvälde",
    "bossväldes": "bossvälde",
    "bossväldet": "bossvälde",
    "bossväldets": "bossvälde",
    "bostaden": "bostad",
    "bostadens": "bostad",
    "bostads": "bostad",
    "bostadsadressen": "bostadsadress",
    "bostadsadressens": "bostadsadress",
    "bostadsadresser": "bostadsadress",
    "bostadsadresserna": "bostadsadress",
    "bostadsadressernas": "bostadsadress",
    "bostadsadressers": "bostadsadress",
    "bostadsbanden": "bostadsband",
    "bostadsbandens": "bostadsband",
    "bostadsbandet": "bostadsband",
    "bostadsbandets": "bostadsband",
    "bostadsbands": "bostadsband",
    "bostadsbeståndet": "bostadsbestånd",
    "bostadsbeståndets": "bostadsbestånd",
    "bostadsbestånds": "bostadsbestånd",
    "bostadsbidragen": "bostadsbidrag",
    "bostadsbidragens": "bostadsbidrag",
    "bostadsbidraget": "bostadsbidrag",
    "bostadsbidragets": "bostadsbidrag",
    "bostadsbidrags": "bostadsbidrag",
    "bostadsbolagen": "bostadsbolag",
    "bostadsbolagens": "bostadsbolag",
    "bostadsbolaget": "bostadsbolag",
    "bostadsbolagets": "bostadsbolag",
    "bostadsbolags": "bostadsbolag",
    "bostadsbristen": "bostadsbrist",
    "bostadsbristens": "bostadsbrist",
    "bostadsbrists": "bostadsbrist",
    "bostadsbubbel": "bostadsbubbla",
    "bostadsbubblan": "bostadsbubbla",
    "bostadsbubblans": "bostadsbubbla",
    "bostadsbubblas": "bostadsbubbla",
    "bostadsbubble": "bostadsbubbla",
    "bostadsbubblor": "bostadsbubbla",
    "bostadsbubblorna": "bostadsbubbla",
    "bostadsbubblornas": "bostadsbubbla",
    "bostadsbubblors": "bostadsbubbla",
    "bostadsbygganden": "bostadsbyggande",
    "bostadsbyggandena": "bostadsbyggande",
    "bostadsbyggandenas": "bostadsbyggande",
    "bostadsbyggandens": "bostadsbyggande",
    "bostadsbyggandes": "bostadsbyggande",
    "bostadsbyggandet": "bostadsbyggande",
    "bostadsbyggandets": "bostadsbyggande",
    "bostadsexperten": "bostadsexpert",
    "bostadsexpertens": "bostadsexpert",
    "bostadsexperter": "bostadsexpert",
    "bostadsexperterna": "bostadsexpert",
    "bostadsexperternas": "bostadsexpert",
    "bostadsexperters": "bostadsexpert",
    "bostadsexperts": "bostadsexpert",
    "bostadsförbättringslånen": "bostadsförbättringslån",
    "bostadsförbättringslånens": "bostadsförbättringslån",
    "bostadsförbättringslånet": "bostadsförbättringslån",
    "bostadsförbättringslånets": "bostadsförbättringslån",
    "bostadsförbättringslåns": "bostadsförbättringslån",
    "bostadsföretagen": "bostadsföretag",
    "bostadsföretagens": "bostadsföretag",
    "bostadsföretaget": "bostadsföretag",
    "bostadsföretagets": "bostadsföretag",
    "bostadsföretags": "bostadsföretag",
    "bostadsförmedlingar": "bostadsförmedling",
    "bostadsförmedlingarna": "bostadsförmedling",
    "bostadsförmedlingarnas": "bostadsförmedling",
    "bostadsförmedlingars": "bostadsförmedling",
    "bostadsförmedlingen": "bostadsförmedling",
    "bostadsförmedlingens": "bostadsförmedling",
    "bostadsförmedlings": "bostadsförmedling",
    "bostadshusen": "bostadshus",
    "bostadshusens": "bostadshus",
    "bostadshuset": "bostadshus",
    "bostadshusets": "bostadshus",
    "bostadsinspektionen": "bostadsinspektion",
    "bostadsinspektionens": "bostadsinspektion",
    "bostadsinspektioner": "bostadsinspektion",
    "bostadsinspektionerna": "bostadsinspektion",
    "bostadsinspektionernas": "bostadsinspektion",
    "bostadsinspektioners": "bostadsinspektion",
    "bostadsinspektions": "bostadsinspektion",
    "bostadskooperationen": "bostadskooperation",
    "bostadskooperationens": "bostadskooperation",
    "bostadskooperationer": "bostadskooperation",
    "bostadskooperationerna": "bostadskooperation",
    "bostadskooperationernas": "bostadskooperation",
    "bostadskooperationers": "bostadskooperation",
    "bostadskooperations": "bostadskooperation",
    "bostadskrediten": "bostadskredit",
    "bostadskreditens": "bostadskredit",
    "bostadskrediter": "bostadskredit",
    "bostadskrediterna": "bostadskredit",
    "bostadskrediternas": "bostadskredit",
    "bostadskrediters": "bostadskredit",
    "bostadskredits": "bostadskredit",
    "bostadskvarteren": "bostadskvarter",
    "bostadskvarterens": "bostadskvarter",
    "bostadskvarteret": "bostadskvarter",
    "bostadskvarterets": "bostadskvarter",
    "bostadskvarters": "bostadskvarter",
    "bostadsköer": "bostadskö",
    "bostadsköerna": "bostadskö",
    "bostadsköernas": "bostadskö",
    "bostadsköers": "bostadskö",
    "bostadskön": "bostadskö",
    "bostadsköns": "bostadskö",
    "bostadskös": "bostadskö",
    "bostadslägenheten": "bostadslägenhet",
    "bostadslägenhetens": "bostadslägenhet",
    "bostadslägenheter": "bostadslägenhet",
    "bostadslägenheterna": "bostadslägenhet",
    "bostadslägenheternas": "bostadslägenhet",
    "bostadslägenheters": "bostadslägenhet",
    "bostadslägenhets": "bostadslägenhet",
    "bostadslånen": "bostadslån",
    "bostadslånens": "bostadslån",
    "bostadslånet": "bostadslån",
    "bostadslånets": "bostadslån",
    "bostadslåns": "bostadslån",
    "bostadslösa": "bostadslös",
    "bostadslösare": "bostadslös",
    "bostadslösares": "bostadslös",
    "bostadslösas": "bostadslös",
    "bostadslösast": "bostadslös",
    "bostadslösaste": "bostadslös",
    "bostadslösastes": "bostadslös",
    "bostadslösasts": "bostadslös",
    "bostadslöse": "bostadslös",
    "bostadslöses": "bostadslös",
    "bostadslösheten": "bostadslöshet",
    "bostadslöshetens": "bostadslöshet",
    "bostadslöshets": "bostadslöshet",
    "bostadslöst": "bostadslös",
    "bostadslösts": "bostadslös",
    "bostadsmarknaden": "bostadsmarknad",
    "bostadsmarknadens": "bostadsmarknad",
    "bostadsmarknader": "bostadsmarknad",
    "bostadsmarknaderna": "bostadsmarknad",
    "bostadsmarknadernas": "bostadsmarknad",
    "bostadsmarknaders": "bostadsmarknad",
    "bostadsmarknads": "bostadsmarknad",
    "bostadsmiljöer": "bostadsmiljö",
    "bostadsmiljöerna": "bostadsmiljö",
    "bostadsmiljöernas": "bostadsmiljö",
    "bostadsmiljöers": "bostadsmiljö",
    "bostadsmiljön": "bostadsmiljö",
    "bostadsmiljöns": "bostadsmiljö",
    "bostadsmiljös": "bostadsmiljö",
    "bostadsmässiga": "bostadsmässig",
    "bostadsmässigare": "bostadsmässig",
    "bostadsmässigares": "bostadsmässig",
    "bostadsmässigas": "bostadsmässig",
    "bostadsmässigast": "bostadsmässig",
    "bostadsmässigaste": "bostadsmässig",
    "bostadsmässigastes": "bostadsmässig",
    "bostadsmässigasts": "bostadsmässig",
    "bostadsmässige": "bostadsmässig",
    "bostadsmässiges": "bostadsmässig",
    "bostadsmässigs": "bostadsmässig",
    "bostadsmässigt": "bostadsmässig",
    "bostadsmässigts": "bostadsmässig",
    "bostadsnämnden": "bostadsnämnd",
    "bostadsnämndens": "bostadsnämnd",
    "bostadsnämnder": "bostadsnämnd",
    "bostadsnämnderna": "bostadsnämnd",
    "bostadsnämndernas": "bostadsnämnd",
    "bostadsnämnders": "bostadsnämnd",
    "bostadsnämnds": "bostadsnämnd",
    "bostadsområden": "bostadsområde",
    "bostadsområdena": "bostadsområde",
    "bostadsområdenas": "bostadsområde",
    "bostadsområdens": "bostadsområde",
    "bostadsområdes": "bostadsområde",
    "bostadsområdet": "bostadsområde",
    "bostadsområdets": "bostadsområde",
    "bostadspolitiken": "bostadspolitik",
    "bostadspolitikens": "bostadspolitik",
    "bostadspolitiks": "bostadspolitik",
    "bostadspolitiska": "bostadspolitisk",
    "bostadspolitiskare": "bostadspolitisk",
    "bostadspolitiskares": "bostadspolitisk",
    "bostadspolitiskas": "bostadspolitisk",
    "bostadspolitiskast": "bostadspolitisk",
    "bostadspolitiskaste": "bostadspolitisk",
    "bostadspolitiskastes": "bostadspolitisk",
    "bostadspolitiskasts": "bostadspolitisk",
    "bostadspolitiske": "bostadspolitisk",
    "bostadspolitiskes": "bostadspolitisk",
    "bostadspolitisks": "bostadspolitisk",
    "bostadspolitiskt": "bostadspolitisk",
    "bostadspolitiskts": "bostadspolitisk",
    "bostadsprisen": "bostadspris",
    "bostadsprisens": "bostadspris",
    "bostadspriser": "bostadspris",
    "bostadspriserna": "bostadspris",
    "bostadsprisernas": "bostadspris",
    "bostadsprisers": "bostadspris",
    "bostadspriset": "bostadspris",
    "bostadsprisets": "bostadspris",
    "bostadsproduktionen": "bostadsproduktion",
    "bostadsproduktionens": "bostadsproduktion",
    "bostadsproduktioner": "bostadsproduktion",
    "bostadsproduktionerna": "bostadsproduktion",
    "bostadsproduktionernas": "bostadsproduktion",
    "bostadsproduktioners": "bostadsproduktion",
    "bostadsproduktions": "bostadsproduktion",
    "bostadsrätten": "bostadsrätt",
    "bostadsrättens": "bostadsrätt",
    "bostadsrätter": "bostadsrätt",
    "bostadsrätterna": "bostadsrätt",
    "bostadsrätternas": "bostadsrätt",
    "bostadsrätters": "bostadsrätt",
    "bostadsrätts": "bostadsrätt",
    "bostadsrättsföreningar": "bostadsrättsförening",
    "bostadsrättsföreningarna": "bostadsrättsförening",
    "bostadsrättsföreningarnas": "bostadsrättsförening",
    "bostadsrättsföreningars": "bostadsrättsförening",
    "bostadsrättsföreningen": "bostadsrättsförening",
    "bostadsrättsföreningens": "bostadsrättsförening",
    "bostadsrättsförenings": "bostadsrättsförening",
    "bostadsrättsinnehavar": "bostadsrättsinnehavare",
    "bostadsrättsinnehavaren": "bostadsrättsinnehavare",
    "bostadsrättsinnehavarens": "bostadsrättsinnehavare",
    "bostadsrättsinnehavares": "bostadsrättsinnehavare",
    "bostadsrättsinnehavarna": "bostadsrättsinnehavare",
    "bostadsrättsinnehavarnas": "bostadsrättsinnehavare",
    "bostadssparandes": "bostadssparande",
    "bostadssparandet": "bostadssparande",
    "bostadssparandets": "bostadssparande",
    "bostadsstyrelsen": "bostadsstyrelse",
    "bostadsstyrelsens": "bostadsstyrelse",
    "bostadsstyrelser": "bostadsstyrelse",
    "bostadsstyrelserna": "bostadsstyrelse",
    "bostadsstyrelsernas": "bostadsstyrelse",
    "bostadsstyrelsers": "bostadsstyrelse",
    "bostadsstyrelses": "bostadsstyrelse",
    "bostadssökanden": "bostadssökande",
    "bostadssökandena": "bostadssökande",
    "bostadssökandenas": "bostadssökande",
    "bostadssökandens": "bostadssökande",
    "bostadssökandes": "bostadssökande",
    "bostadstilläggen": "bostadstillägg",
    "bostadstilläggens": "bostadstillägg",
    "bostadstillägget": "bostadstillägg",
    "bostadstilläggets": "bostadstillägg",
    "bostadstilläggs": "bostadstillägg",
    "bostan": "bostad",
    "bostans": "bostad",
    "bostongurk": "bostongurka",
    "bostongurkan": "bostongurka",
    "bostongurkans": "bostongurka",
    "bostongurkas": "bostongurka",
    "bostongurke": "bostongurka",
    "bostongurkor": "bostongurka",
    "bostongurkorna": "bostongurka",
    "bostongurkornas": "bostongurka",
    "bostongurkors": "bostongurka",
    "bostongurks": "bostongurka",
    "bostonvalsen": "bostonvals",
    "bostonvalsens": "bostonvals",
    "bostonvalser": "bostonvals",
    "bostonvalserna": "bostonvals",
    "bostonvalsernas": "bostonvals",
    "bostonvalsers": "bostonvals",
    "bostäder": "bostad",
    "bostäderna": "bostad",
    "bostädernas": "bostad",
    "bostäders": "bostad",
    "boställen": "boställe",
    "boställena": "boställe",
    "boställenas": "boställe",
    "boställens": "boställe",
    "boställes": "boställe",
    "bostället": "boställe",
    "boställets": "boställe",
    "bosättar": "bosättare",
    "bosättaren": "bosättare",
    "bosättarens": "bosättare",
    "bosättares": "bosättare",
    "bosättarna": "bosättare",
    "bosättarnas": "bosättare",
    "bosättningar": "bosättning",
    "bosättningarna": "bosättning",
    "bosättningarnas": "bosättning",
    "bosättningars": "bosättning",
    "bosättningen": "bosättning",
    "bosättningens": "bosättning",
    "bosättnings": "bosättning",
    "bosättningsaffären": "bosättningsaffär",
    "bosättningsaffärens": "bosättningsaffär",
    "bosättningsaffärer": "bosättningsaffär",
    "bosättningsaffärerna": "bosättningsaffär",
    "bosättningsaffärernas": "bosättningsaffär",
    "bosättningsaffärers": "bosättningsaffär",
    "bosättningsaffärs": "bosättningsaffär",
    "bosättningslånen": "bosättningslån",
    "bosättningslånens": "bosättningslån",
    "bosättningslånet": "bosättningslån",
    "bosättningslånets": "bosättningslån",
    "bosättningslåns": "bosättningslån",
    "bosättningsorten": "bosättningsort",
    "bosättningsortens": "bosättningsort",
    "bosättningsorter": "bosättningsort",
    "bosättningsorterna": "bosättningsort",
    "bosättningsorternas": "bosättningsort",
    "bosättningsorters": "bosättningsort",
    "bosättningsorts": "bosättningsort",
    "bosättningsstoppen": "bosättningsstopp",
    "bosättningsstoppens": "bosättningsstopp",
    "bosättningsstoppet": "bosättningsstopp",
    "bosättningsstoppets": "bosättningsstopp",
    "bosättningsstopps": "bosättningsstopp",
    "bot": "bo",
    "botad": "bota",
    "botade": "bota",
    "botades": "bota",
    "botads": "bota",
    "botande": "bota",
    "botanden": "botande",
    "botandena": "botande",
    "botandenas": "botande",
    "botandens": "botande",
    "botandes": "botande",
    "botandet": "botande",
    "botandets": "botande",
    "botaniken": "botanik",
    "botanikens": "botanik",
    "botanikern": "botaniker",
    "botanikerna": "botaniker",
    "botanikernas": "botaniker",
    "botanikerns": "botaniker",
    "botanikers": "botaniker",
    "botaniks": "botanik",
    "botanikspad": "botanikspade",
    "botanikspadar": "botanikspade",
    "botanikspadarna": "botanikspade",
    "botanikspadarnas": "botanikspade",
    "botanikspadars": "botanikspade",
    "botanikspaden": "botanikspade",
    "botanikspadens": "botanikspade",
    "botanikspades": "botanikspade",
    "botanikspads": "botanikspade",
    "botaniserade": "botanisera",
    "botaniserades": "botanisera",
    "botaniserande": "botanisera",
    "botaniseranden": "botaniserande",
    "botaniserandena": "botaniserande",
    "botaniserandenas": "botaniserande",
    "botaniserandens": "botaniserande",
    "botaniserandes": "botaniserande",
    "botaniserandet": "botaniserande",
    "botaniserandets": "botaniserande",
    "botaniserar": "botanisera",
    "botaniseras": "botanisera",
    "botaniserat": "botanisera",
    "botaniserats": "botanisera",
    "botaniseringar": "botanisering",
    "botaniseringarna": "botanisering",
    "botaniseringarnas": "botanisering",
    "botaniseringars": "botanisering",
    "botaniseringen": "botanisering",
    "botaniseringens": "botanisering",
    "botaniserings": "botanisering",
    "botaniska": "botanisk",
    "botaniskare": "botanisk",
    "botaniskares": "botanisk",
    "botaniskas": "botanisk",
    "botaniskast": "botanisk",
    "botaniskaste": "botanisk",
    "botaniskastes": "botanisk",
    "botaniskasts": "botanisk",
    "botaniske": "botanisk",
    "botaniskes": "botanisk",
    "botanisks": "botanisk",
    "botaniskt": "botanisk",
    "botaniskts": "botanisk",
    "botanisten": "botanist",
    "botanistens": "botanist",
    "botanister": "botanist",
    "botanisterna": "botanist",
    "botanisternas": "botanist",
    "botanisters": "botanist",
    "botanists": "botanist",
    "botanistspad": "botanistspade",
    "botanistspadar": "botanistspade",
    "botanistspadarna": "botanistspade",
    "botanistspadarnas": "botanistspade",
    "botanistspadars": "botanistspade",
    "botanistspaden": "botanistspade",
    "botanistspadens": "botanistspade",
    "botanistspades": "botanistspade",
    "botanistspads": "botanistspade",
    "botar": "bota",
    "botarna": "bot",
    "botarnas": "bot",
    "botars": "bot",
    "botas": "bota",
    "botat": "bota",
    "botats": "bota",
    "botdagar": "botdag",
    "botdagarna": "botdag",
    "botdagarnas": "botdag",
    "botdagars": "botdag",
    "botdagen": "botdag",
    "botdagens": "botdag",
    "botdags": "botdag",
    "bote": "bota",
    "botemedels": "botemedel",
    "botemedlen": "botemedel",
    "botemedlens": "botemedel",
    "botemedlet": "botemedel",
    "botemedlets": "botemedel",
    "boten": "bot",
    "botens": "bot",
    "botfärdiga": "botfärdig",
    "botfärdigare": "botfärdig",
    "botfärdigares": "botfärdig",
    "botfärdigas": "botfärdig",
    "botfärdigast": "botfärdig",
    "botfärdigaste": "botfärdig",
    "botfärdigastes": "botfärdig",
    "botfärdigasts": "botfärdig",
    "botfärdige": "botfärdig",
    "botfärdiges": "botfärdig",
    "botfärdigheten": "botfärdighet",
    "botfärdighetens": "botfärdighet",
    "botfärdighets": "botfärdighet",
    "botfärdigs": "botfärdig",
    "botfärdigt": "botfärdig",
    "botfärdigts": "botfärdig",
    "botgörar": "botgörare",
    "botgöraren": "botgörare",
    "botgörarens": "botgörare",
    "botgörares": "botgörare",
    "botgörarna": "botgörare",
    "botgörarnas": "botgörare",
    "botgörelsen": "botgörelse",
    "botgörelsens": "botgörelse",
    "botgörelser": "botgörelse",
    "botgörelserna": "botgörelse",
    "botgörelsernas": "botgörelse",
    "botgörelsers": "botgörelse",
    "botgörelses": "botgörelse",
    "botgöringar": "botgöring",
    "botgöringarna": "botgöring",
    "botgöringarnas": "botgöring",
    "botgöringars": "botgöring",
    "botgöringen": "botgöring",
    "botgöringens": "botgöring",
    "botgörings": "botgöring",
    "botliga": "botlig",
    "botligare": "botlig",
    "botligares": "botlig",
    "botligas": "botlig",
    "botligast": "botlig",
    "botligaste": "botlig",
    "botligastes": "botlig",
    "botligasts": "botlig",
    "botlige": "botlig",
    "botliges": "botlig",
    "botligheten": "botlighet",
    "botlighetens": "botlighet",
    "botlighets": "botlighet",
    "botligs": "botlig",
    "botligt": "botlig",
    "botligts": "botlig",
    "botoxen": "botox",
    "botoxens": "botox",
    "botoxet": "botox",
    "botoxets": "botox",
    "botoxförlamningar": "botoxförlamning",
    "botoxförlamningarna": "botoxförlamning",
    "botoxförlamningarnas": "botoxförlamning",
    "botoxförlamningars": "botoxförlamning",
    "botoxförlamningen": "botoxförlamning",
    "botoxförlamningens": "botoxförlamning",
    "botoxförlamnings": "botoxförlamning",
    "bots": "bot",
    "botswaniern": "botswanier",
    "botswanierna": "botswanier",
    "botswaniernas": "botswanier",
    "botswanierns": "botswanier",
    "botswaniers": "botswanier",
    "botswanska": "botswansk",
    "botswanskan": "botswanska",
    "botswanskans": "botswanska",
    "botswanskare": "botswansk",
    "botswanskares": "botswansk",
    "botswanskas": "botswanska",
    "botswanskast": "botswansk",
    "botswanskaste": "botswansk",
    "botswanskastes": "botswansk",
    "botswanskasts": "botswansk",
    "botswanske": "botswanska",
    "botswanskes": "botswansk",
    "botswanskor": "botswanska",
    "botswanskorna": "botswanska",
    "botswanskornas": "botswanska",
    "botswanskors": "botswanska",
    "botswansks": "botswansk",
    "botswanskt": "botswansk",
    "botswanskts": "botswansk",
    "bott": "bo",
    "bottenavlagringar": "bottenavlagring",
    "bottenavlagringarna": "bottenavlagring",
    "bottenavlagringarnas": "bottenavlagring",
    "bottenavlagringars": "bottenavlagring",
    "bottenavlagringen": "bottenavlagring",
    "bottenavlagringens": "bottenavlagring",
    "bottenavlagrings": "bottenavlagring",
    "bottenbjälk": "bottenbjälke",
    "bottenbjälkar": "bottenbjälke",
    "bottenbjälkarna": "bottenbjälke",
    "bottenbjälkarnas": "bottenbjälke",
    "bottenbjälkars": "bottenbjälke",
    "bottenbjälken": "bottenbjälke",
    "bottenbjälkens": "bottenbjälke",
    "bottenbjälkes": "bottenbjälke",
    "bottenbjälks": "bottenbjälke",
    "bottendjuren": "bottendjur",
    "bottendjurens": "bottendjur",
    "bottendjuret": "bottendjur",
    "bottendjurets": "bottendjur",
    "bottendjurs": "bottendjur",
    "bottendåliga": "bottendålig",
    "bottendåligare": "bottendålig",
    "bottendåligares": "bottendålig",
    "bottendåligas": "bottendålig",
    "bottendåligast": "bottendålig",
    "bottendåligaste": "bottendålig",
    "bottendåligastes": "bottendålig",
    "bottendåligasts": "bottendålig",
    "bottendålige": "bottendålig",
    "bottendåliges": "bottendålig",
    "bottendåligheten": "bottendålighet",
    "bottendålighetens": "bottendålighet",
    "bottendålighets": "bottendålighet",
    "bottendåligs": "bottendålig",
    "bottendåligt": "bottendålig",
    "bottendåligts": "bottendålig",
    "bottenfasta": "bottenfast",
    "bottenfastare": "bottenfast",
    "bottenfastares": "bottenfast",
    "bottenfastas": "bottenfast",
    "bottenfastast": "bottenfast",
    "bottenfastaste": "bottenfast",
    "bottenfastastes": "bottenfast",
    "bottenfastasts": "bottenfast",
    "bottenfaste": "bottenfast",
    "bottenfastes": "bottenfast",
    "bottenfasts": "bottenfast",
    "bottenfruse": "bottenfrysa",
    "bottenfrusen": "bottenfrysa",
    "bottenfrusens": "bottenfrysa",
    "bottenfruset": "bottenfrysa",
    "bottenfrusets": "bottenfrysa",
    "bottenfrusit": "bottenfrysa",
    "bottenfrusna": "bottenfrysa",
    "bottenfrusnas": "bottenfrysa",
    "bottenfrusne": "bottenfrysa",
    "bottenfrusnes": "bottenfrysa",
    "bottenfrys": "bottenfrysa",
    "bottenfrysande": "bottenfrysa",
    "bottenfrysanden": "bottenfrysande",
    "bottenfrysandena": "bottenfrysande",
    "bottenfrysandenas": "bottenfrysande",
    "bottenfrysandens": "bottenfrysande",
    "bottenfrysandes": "bottenfrysande",
    "bottenfrysandet": "bottenfrysande",
    "bottenfrysandets": "bottenfrysande",
    "bottenfryse": "bottenfrysa",
    "bottenfryser": "bottenfrysa",
    "bottenfryst": "bottenfrysa",
    "bottenfrysta": "bottenfrysa",
    "bottenfrystas": "bottenfrysa",
    "bottenfryste": "bottenfrysa",
    "bottenfrystes": "bottenfrysa",
    "bottenfrysts": "bottenfrysa",
    "bottenfrös": "bottenfrysa",
    "bottenfällningar": "bottenfällning",
    "bottenfällningarna": "bottenfällning",
    "bottenfällningarnas": "bottenfällning",
    "bottenfällningars": "bottenfällning",
    "bottenfällningen": "bottenfällning",
    "bottenfällningens": "bottenfällning",
    "bottenfällnings": "bottenfällning",
    "bottenfärgen": "bottenfärg",
    "bottenfärgens": "bottenfärg",
    "bottenfärger": "bottenfärg",
    "bottenfärgerna": "bottenfärg",
    "bottenfärgernas": "bottenfärg",
    "bottenfärgers": "bottenfärg",
    "bottenfärgs": "bottenfärg",
    "bottengarnen": "bottengarn",
    "bottengarnens": "bottengarn",
    "bottengarnet": "bottengarn",
    "bottengarnets": "bottengarn",
    "bottengarns": "bottengarn",
    "bottenhederliga": "bottenhederlig",
    "bottenhederligare": "bottenhederlig",
    "bottenhederligares": "bottenhederlig",
    "bottenhederligas": "bottenhederlig",
    "bottenhederligast": "bottenhederlig",
    "bottenhederligaste": "bottenhederlig",
    "bottenhederligastes": "bottenhederlig",
    "bottenhederligasts": "bottenhederlig",
    "bottenhederlige": "bottenhederlig",
    "bottenhederliges": "bottenhederlig",
    "bottenhederligheten": "bottenhederlighet",
    "bottenhederlighetens": "bottenhederlighet",
    "bottenhederlighets": "bottenhederlighet",
    "bottenhederligs": "bottenhederlig",
    "bottenhederligt": "bottenhederlig",
    "bottenhederligts": "bottenhederlig",
    "bottenisen": "bottenis",
    "bottenisens": "bottenis",
    "bottenkranar": "bottenkran",
    "bottenkranarna": "bottenkran",
    "bottenkranarnas": "bottenkran",
    "bottenkranars": "bottenkran",
    "bottenkranen": "bottenkran",
    "bottenkranens": "bottenkran",
    "bottenkrans": "bottenkran",
    "bottenkursen": "bottenkurs",
    "bottenkursens": "bottenkurs",
    "bottenkurser": "bottenkurs",
    "bottenkurserna": "bottenkurs",
    "bottenkursernas": "bottenkurs",
    "bottenkursers": "bottenkurs",
    "bottenkänningar": "bottenkänning",
    "bottenkänningarna": "bottenkänning",
    "bottenkänningarnas": "bottenkänning",
    "bottenkänningars": "bottenkänning",
    "bottenkänningen": "bottenkänning",
    "bottenkänningens": "bottenkänning",
    "bottenkännings": "bottenkänning",
    "bottenlagen": "bottenlag",
    "bottenlagens": "bottenlag",
    "bottenlaget": "bottenlag",
    "bottenlagets": "bottenlag",
    "bottenlags": "bottenlag",
    "bottenlägen": "bottenläge",
    "bottenlägena": "bottenläge",
    "bottenlägenas": "bottenläge",
    "bottenlägens": "bottenläge",
    "bottenläges": "bottenläge",
    "bottenläget": "bottenläge",
    "bottenlägets": "bottenläge",
    "bottenlånen": "bottenlån",
    "bottenlånens": "bottenlån",
    "bottenlånet": "bottenlån",
    "bottenlånets": "bottenlån",
    "bottenlåns": "bottenlån",
    "bottenlösa": "bottenlös",
    "bottenlösare": "bottenlös",
    "bottenlösares": "bottenlös",
    "bottenlösas": "bottenlös",
    "bottenlösast": "bottenlös",
    "bottenlösaste": "bottenlös",
    "bottenlösastes": "bottenlös",
    "bottenlösasts": "bottenlös",
    "bottenlöse": "bottenlös",
    "bottenlöses": "bottenlös",
    "bottenlösheten": "bottenlöshet",
    "bottenlöshetens": "bottenlöshet",
    "bottenlösheter": "bottenlöshet",
    "bottenlösheterna": "bottenlöshet",
    "bottenlösheternas": "bottenlöshet",
    "bottenlösheters": "bottenlöshet",
    "bottenlöshets": "bottenlöshet",
    "bottenlöst": "bottenlös",
    "bottenlösts": "bottenlös",
    "bottenmagneten": "bottenmagnet",
    "bottenmagnetens": "bottenmagnet",
    "bottenmagneter": "bottenmagnet",
    "bottenmagneterna": "bottenmagnet",
    "bottenmagneternas": "bottenmagnet",
    "bottenmagneters": "bottenmagnet",
    "bottenmagnets": "bottenmagnet",
    "bottenmoränen": "bottenmorän",
    "bottenmoränens": "bottenmorän",
    "bottenmoräns": "bottenmorän",
    "bottennappen": "bottennapp",
    "bottennappens": "bottennapp",
    "bottennappet": "bottennapp",
    "bottennappets": "bottennapp",
    "bottennapps": "bottennapp",
    "bottenplanen": "bottenplan",
    "bottenplanens": "bottenplan",
    "bottenplanet": "bottenplan",
    "bottenplanets": "bottenplan",
    "bottenplans": "bottenplan",
    "bottenplatt": "bottenplatta",
    "bottenplattan": "bottenplatta",
    "bottenplattans": "bottenplatta",
    "bottenplattas": "bottenplatta",
    "bottenplatte": "bottenplatta",
    "bottenplattor": "bottenplatta",
    "bottenplattorna": "bottenplatta",
    "bottenplattornas": "bottenplatta",
    "bottenplattors": "bottenplatta",
    "bottenplatts": "bottenplatta",
    "bottenrekorden": "bottenrekord",
    "bottenrekordens": "bottenrekord",
    "bottenrekordet": "bottenrekord",
    "bottenrekordets": "bottenrekord",
    "bottenrekords": "bottenrekord",
    "bottenrev": "bottenreva",
    "bottenrevad": "bottenreva",
    "bottenrevade": "bottenreva",
    "bottenrevades": "bottenreva",
    "bottenrevads": "bottenreva",
    "bottenrevande": "bottenreva",
    "bottenrevanden": "bottenrevande",
    "bottenrevandena": "bottenrevande",
    "bottenrevandenas": "bottenrevande",
    "bottenrevandens": "bottenrevande",
    "bottenrevandes": "bottenrevande",
    "bottenrevandet": "bottenrevande",
    "bottenrevandets": "bottenrevande",
    "bottenrevar": "bottenreva",
    "bottenrevas": "bottenreva",
    "bottenrevat": "bottenreva",
    "bottenrevats": "bottenreva",
    "bottenreven": "bottenrev",
    "bottenrevens": "bottenrev",
    "bottenrevet": "bottenrev",
    "bottenrevets": "bottenrev",
    "bottenrevs": "bottenrev",
    "bottens": "botten",
    "bottensatsen": "bottensats",
    "bottensatsens": "bottensats",
    "bottensatser": "bottensats",
    "bottensatserna": "bottensats",
    "bottensatsernas": "bottensats",
    "bottensatsers": "bottensats",
    "bottensedimenten": "bottensediment",
    "bottensedimentens": "bottensediment",
    "bottensedimentet": "bottensediment",
    "bottensedimentets": "bottensediment",
    "bottensediments": "bottensediment",
    "bottenskikten": "bottenskikt",
    "bottenskiktens": "bottenskikt",
    "bottenskiktet": "bottenskikt",
    "bottenskiktets": "bottenskikt",
    "bottenskikts": "bottenskikt",
    "bottenskolan": "bottenskola",
    "bottenskolans": "bottenskola",
    "bottenskolas": "bottenskola",
    "bottenskole": "bottenskola",
    "bottenskolor": "bottenskola",
    "bottenskolorna": "bottenskola",
    "bottenskolornas": "bottenskola",
    "bottenskolors": "bottenskola",
    "bottenskrap": "bottenskrapa",
    "bottenskrapad": "bottenskrapa",
    "bottenskrapade": "bottenskrapa",
    "bottenskrapades": "bottenskrapa",
    "bottenskrapads": "bottenskrapa",
    "bottenskrapan": "bottenskrapa",
    "bottenskrapande": "bottenskrapa",
    "bottenskrapanden": "bottenskrapande",
    "bottenskrapandena": "bottenskrapande",
    "bottenskrapandenas": "bottenskrapande",
    "bottenskrapandens": "bottenskrapande",
    "bottenskrapandes": "bottenskrapande",
    "bottenskrapandet": "bottenskrapande",
    "bottenskrapandets": "bottenskrapande",
    "bottenskrapans": "bottenskrapa",
    "bottenskrapar": "bottenskrapa",
    "bottenskrapas": "bottenskrapa",
    "bottenskrapat": "bottenskrapa",
    "bottenskrapats": "bottenskrapa",
    "bottenskrape": "bottenskrapa",
    "bottenskrapet": "bottenskrap",
    "bottenskrapets": "bottenskrap",
    "bottenskrapor": "bottenskrapa",
    "bottenskraporna": "bottenskrapa",
    "bottenskrapornas": "bottenskrapa",
    "bottenskrapors": "bottenskrapa",
    "bottenskraps": "bottenskrapa",
    "bottenskvättar": "bottenskvätt",
    "bottenskvättarna": "bottenskvätt",
    "bottenskvättarnas": "bottenskvätt",
    "bottenskvättars": "bottenskvätt",
    "bottenskvätten": "bottenskvätt",
    "bottenskvättens": "bottenskvätt",
    "bottenskvätts": "bottenskvätt",
    "bottenskyl": "bottenskyla",
    "bottenskylan": "bottenskyla",
    "bottenskylans": "bottenskyla",
    "bottenskylas": "bottenskyla",
    "bottenskyle": "bottenskyla",
    "bottenskylor": "bottenskyla",
    "bottenskylorna": "bottenskyla",
    "bottenskylornas": "bottenskyla",
    "bottenskylors": "bottenskyla",
    "bottenskyls": "bottenskyla",
    "bottenslammet": "bottenslam",
    "bottenslammets": "bottenslam",
    "bottenslams": "bottenslam",
    "bottenstockar": "bottenstock",
    "bottenstockarna": "bottenstock",
    "bottenstockarnas": "bottenstock",
    "bottenstockars": "bottenstock",
    "bottenstocken": "bottenstock",
    "bottenstockens": "bottenstock",
    "bottenstocks": "bottenstock",
    "bottentrycket": "bottentryck",
    "bottentryckets": "bottentryck",
    "bottentrycks": "bottentryck",
    "bottenvattens": "bottenvatten",
    "bottenvattnen": "bottenvatten",
    "bottenvattnens": "bottenvatten",
    "bottenvattnet": "bottenvatten",
    "bottenvattnets": "bottenvatten",
    "bottenventilen": "bottenventil",
    "bottenventilens": "bottenventil",
    "bottenventiler": "bottenventil",
    "bottenventilerna": "bottenventil",
    "bottenventilernas": "bottenventil",
    "bottenventilers": "bottenventil",
    "bottenventils": "bottenventil",
    "bottenvåningar": "bottenvåning",
    "bottenvåningarna": "bottenvåning",
    "bottenvåningarnas": "bottenvåning",
    "bottenvåningars": "bottenvåning",
    "bottenvåningen": "bottenvåning",
    "bottenvåningens": "bottenvåning",
    "bottenvånings": "bottenvåning",
    "bottenytan": "bottenyta",
    "bottenytans": "bottenyta",
    "bottenytas": "bottenyta",
    "bottenyte": "bottenyta",
    "bottenytor": "bottenyta",
    "bottenytorna": "bottenyta",
    "bottenytornas": "bottenyta",
    "bottenytors": "bottenyta",
    "bottinen": "bottin",
    "bottinens": "bottin",
    "bottiner": "bottin",
    "bottinerna": "bottin",
    "bottinernas": "bottin",
    "bottiners": "bottin",
    "bottins": "bottin",
    "bottn": "bottna",
    "bottnade": "bottna",
    "bottnades": "bottna",
    "bottnande": "bottna",
    "bottnanden": "bottnande",
    "bottnandena": "bottnande",
    "bottnandenas": "bottnande",
    "bottnandens": "bottnande",
    "bottnandes": "bottnande",
    "bottnandet": "bottnande",
    "bottnandets": "bottnande",
    "bottnar": "bottna",
    "bottnarna": "botten",
    "bottnarnas": "botten",
    "bottnars": "botten",
    "bottnas": "bottna",
    "bottnat": "bottna",
    "bottnats": "bottna",
    "bottnen": "botten",
    "bottnens": "botten",
    "bottniska": "bottnisk",
    "bottniskare": "bottnisk",
    "bottniskares": "bottnisk",
    "bottniskas": "bottnisk",
    "bottniskast": "bottnisk",
    "bottniskaste": "bottnisk",
    "bottniskastes": "bottnisk",
    "bottniskasts": "bottnisk",
    "bottniske": "bottnisk",
    "bottniskes": "bottnisk",
    "bottnisks": "bottnisk",
    "bottniskt": "bottnisk",
    "bottniskts": "bottnisk",
    "botts": "bo",
    "botulinet": "botulin",
    "botulinets": "botulin",
    "botulins": "botulin",
    "botulismen": "botulism",
    "botulismens": "botulism",
    "botulismer": "botulism",
    "botulismerna": "botulism",
    "botulismernas": "botulism",
    "botulismers": "botulism",
    "botulisms": "botulism",
    "boudoiren": "boudoir",
    "boudoirens": "boudoir",
    "boudoirer": "boudoir",
    "boudoirerna": "boudoir",
    "boudoirernas": "boudoir",
    "boudoirers": "boudoir",
    "boudoirs": "boudoir",
    "bouillabaissen": "bouillabaisse",
    "bouillabaissens": "bouillabaisse",
    "bouillabaisses": "bouillabaisse",
    "boulen": "boule",
    "boulens": "boule",
    "boules": "boule",
    "boulevarden": "boulevard",
    "boulevardens": "boulevard",
    "boulevarder": "boulevard",
    "boulevarderna": "boulevard",
    "boulevardernas": "boulevard",
    "boulevarders": "boulevard",
    "boulevardpressen": "boulevardpress",
    "boulevardpressens": "boulevardpress",
    "boulevards": "boulevard",
    "bouppteckningar": "bouppteckning",
    "bouppteckningarna": "bouppteckning",
    "bouppteckningarnas": "bouppteckning",
    "bouppteckningars": "bouppteckning",
    "bouppteckningen": "bouppteckning",
    "bouppteckningens": "bouppteckning",
    "boupptecknings": "bouppteckning",
    "bouqueten": "bouquet",
    "bouquetens": "bouquet",
    "bouqueter": "bouquet",
    "bouqueterna": "bouquet",
    "bouqueternas": "bouquet",
    "bouqueters": "bouquet",
    "bouquets": "bouquet",
    "bourbonen": "bourbon",
    "bourbonens": "bourbon",
    "bourbons": "bourbon",
    "bourgeoisien": "bourgeoisie",
    "bourgeoisiens": "bourgeoisie",
    "bourgeoisies": "bourgeoisie",
    "bourgognen": "bourgogne",
    "bourgognens": "bourgogne",
    "bourgogner": "bourgogne",
    "bourgognerna": "bourgogne",
    "bourgognernas": "bourgogne",
    "bourgogners": "bourgogne",
    "bourgognes": "bourgogne",
    "boutiquen": "boutique",
    "boutiquens": "boutique",
    "boutiquer": "boutique",
    "boutiquerna": "boutique",
    "boutiquernas": "boutique",
    "boutiquers": "boutique",
    "boutiques": "boutique",
    "boutredningar": "boutredning",
    "boutredningarna": "boutredning",
    "boutredningarnas": "boutredning",
    "boutredningars": "boutredning",
    "boutredningen": "boutredning",
    "boutredningens": "boutredning",
    "boutrednings": "boutredning",
    "bouzoukin": "bouzouki",
    "bouzoukina": "bouzouki",
    "bouzoukinas": "bouzouki",
    "bouzoukins": "bouzouki",
    "bouzoukis": "bouzouki",
    "bouzoukisarna": "bouzouki",
    "bouzoukisarnas": "bouzouki",
    "bouzoukisen": "bouzouki",
    "bouzoukisens": "bouzouki",
    "bovaktiga": "bovaktig",
    "bovaktigare": "bovaktig",
    "bovaktigares": "bovaktig",
    "bovaktigas": "bovaktig",
    "bovaktigast": "bovaktig",
    "bovaktigaste": "bovaktig",
    "bovaktigastes": "bovaktig",
    "bovaktigasts": "bovaktig",
    "bovaktige": "bovaktig",
    "bovaktiges": "bovaktig",
    "bovaktigheten": "bovaktighet",
    "bovaktighetens": "bovaktighet",
    "bovaktighets": "bovaktighet",
    "bovaktigs": "bovaktig",
    "bovaktigt": "bovaktig",
    "bovaktigts": "bovaktig",
    "bovar": "bov",
    "bovarna": "bov",
    "bovarnas": "bov",
    "bovars": "bov",
    "boven": "bov",
    "bovens": "bov",
    "boveteplättar": "boveteplätt",
    "boveteplättarna": "boveteplätt",
    "boveteplättarnas": "boveteplätt",
    "boveteplättars": "boveteplätt",
    "boveteplätten": "boveteplätt",
    "boveteplättens": "boveteplätt",
    "boveteplätts": "boveteplätt",
    "bovetes": "bovete",
    "bovetet": "bovete",
    "bovetets": "bovete",
    "bovfysionomien": "bovfysionomi",
    "bovfysionomiens": "bovfysionomi",
    "bovfysionomier": "bovfysionomi",
    "bovfysionomierna": "bovfysionomi",
    "bovfysionomiernas": "bovfysionomi",
    "bovfysionomiers": "bovfysionomi",
    "bovfysionomin": "bovfysionomi",
    "bovfysionomins": "bovfysionomi",
    "bovfysionomis": "bovfysionomi",
    "bovs": "bov",
    "bovstrecken": "bovstreck",
    "bovstreckens": "bovstreck",
    "bovstrecket": "bovstreck",
    "bovstreckets": "bovstreck",
    "bovstrecks": "bovstreck",
    "bowlade": "bowla",
    "bowlades": "bowla",
    "bowlande": "bowla",
    "bowlanden": "bowlande",
    "bowlandena": "bowlande",
    "bowlandenas": "bowlande",
    "bowlandens": "bowlande",
    "bowlandes": "bowlande",
    "bowlandet": "bowlande",
    "bowlandets": "bowlande",
    "bowlar": "bowlare",
    "bowlaren": "bowlare",
    "bowlarens": "bowlare",
    "bowlares": "bowlare",
    "bowlarna": "bowlare",
    "bowlarnas": "bowlare",
    "bowlas": "bowla",
    "bowlat": "bowla",
    "bowlats": "bowla",
    "bowlingbanan": "bowlingbana",
    "bowlingbanans": "bowlingbana",
    "bowlingbanas": "bowlingbana",
    "bowlingbane": "bowlingbana",
    "bowlingbanor": "bowlingbana",
    "bowlingbanorna": "bowlingbana",
    "bowlingbanornas": "bowlingbana",
    "bowlingbanors": "bowlingbana",
    "bowlingen": "bowling",
    "bowlingens": "bowling",
    "bowlinghallar": "bowlinghall",
    "bowlinghallarna": "bowlinghall",
    "bowlinghallarnas": "bowlinghall",
    "bowlinghallars": "bowlinghall",
    "bowlinghallen": "bowlinghall",
    "bowlinghallens": "bowlinghall",
    "bowlinghalls": "bowlinghall",
    "bowlingkloten": "bowlingklot",
    "bowlingklotens": "bowlingklot",
    "bowlingklotet": "bowlingklot",
    "bowlingklotets": "bowlingklot",
    "bowlingklots": "bowlingklot",
    "bowlings": "bowling",
    "box": "boxa",
    "boxad": "boxa",
    "boxade": "boxa",
    "boxades": "boxas",
    "boxads": "boxa",
    "boxande": "boxa",
    "boxanden": "boxande",
    "boxandena": "boxande",
    "boxandenas": "boxande",
    "boxandens": "boxande",
    "boxandes": "boxande",
    "boxandet": "boxande",
    "boxandets": "boxande",
    "boxar": "boxare",
    "boxaren": "boxare",
    "boxarens": "boxare",
    "boxares": "boxare",
    "boxarna": "boxare",
    "boxarnas": "boxare",
    "boxars": "box",
    "boxas": "boxa",
    "boxat": "boxa",
    "boxats": "boxas",
    "boxbollar": "boxboll",
    "boxbollarna": "boxboll",
    "boxbollarnas": "boxboll",
    "boxbollars": "boxboll",
    "boxbollen": "boxboll",
    "boxbollens": "boxboll",
    "boxbolls": "boxboll",
    "boxen": "box",
    "boxens": "box",
    "boxern": "boxer",
    "boxerns": "boxer",
    "boxers": "boxer",
    "boxershortsen": "boxershorts",
    "boxershortsens": "boxershorts",
    "boxervalpar": "boxervalp",
    "boxervalparna": "boxervalp",
    "boxervalparnas": "boxervalp",
    "boxervalpars": "boxervalp",
    "boxervalpen": "boxervalp",
    "boxervalpens": "boxervalp",
    "boxervalps": "boxervalp",
    "boxet": "box",
    "boxets": "box",
    "boxhandsk": "boxhandske",
    "boxhandskar": "boxhandske",
    "boxhandskarna": "boxhandske",
    "boxhandskarnas": "boxhandske",
    "boxhandskars": "boxhandske",
    "boxhandsken": "boxhandske",
    "boxhandskens": "boxhandske",
    "boxhandskes": "boxhandske",
    "boxkalven": "boxkalv",
    "boxkalvens": "boxkalv",
    "boxkalvs": "boxkalv",
    "boxningar": "boxning",
    "boxningarna": "boxning",
    "boxningarnas": "boxning",
    "boxningars": "boxning",
    "boxningen": "boxning",
    "boxningens": "boxning",
    "boxnings": "boxning",
    "boxningslokalen": "boxningslokal",
    "boxningslokalens": "boxningslokal",
    "boxningslokaler": "boxningslokal",
    "boxningslokalerna": "boxningslokal",
    "boxningslokalernas": "boxningslokal",
    "boxningslokalers": "boxningslokal",
    "boxningslokals": "boxningslokal",
    "boxningsmatchen": "boxningsmatch",
    "boxningsmatchens": "boxningsmatch",
    "boxningsmatcher": "boxningsmatch",
    "boxningsmatcherna": "boxningsmatch",
    "boxningsmatchernas": "boxningsmatch",
    "boxningsmatchers": "boxningsmatch",
    "boxningsmatchs": "boxningsmatch",
    "boxningsringar": "boxningsring",
    "boxningsringarna": "boxningsring",
    "boxningsringarnas": "boxningsring",
    "boxningsringars": "boxningsring",
    "boxningsringen": "boxningsring",
    "boxningsringens": "boxningsring",
    "boxningsrings": "boxningsring",
    "boxningstränade": "boxningstränad",
    "boxningstränades": "boxningstränad",
    "boxningstränads": "boxningstränad",
    "boxningstränat": "boxningstränad",
    "boxningstränats": "boxningstränad",
    "boxningsträningar": "boxningsträning",
    "boxningsträningarna": "boxningsträning",
    "boxningsträningarnas": "boxningsträning",
    "boxningsträningars": "boxningsträning",
    "boxningsträningen": "boxningsträning",
    "boxningsträningens": "boxningsträning",
    "boxningstränings": "boxningsträning",
    "boxrar": "boxer",
    "boxrarna": "boxer",
    "boxrarnas": "boxer",
    "boxrars": "boxer",
    "boyscouten": "boyscout",
    "boyscoutens": "boyscout",
    "boyscouter": "boyscout",
    "boyscouterna": "boyscout",
    "boyscouternas": "boyscout",
    "boyscouters": "boyscout",
    "boyscouts": "boyscout",
    "boäggen": "boägg",
    "boäggens": "boägg",
    "boägget": "boägg",
    "boäggets": "boägg",
    "boäggs": "boägg",
    "brack": "bracka",
    "brackan": "bracka",
    "brackans": "bracka",
    "brackas": "bracka",
    "bracke": "bracka",
    "brackiga": "brackig",
    "brackigare": "brackig",
    "brackigares": "brackig",
    "brackigas": "brackig",
    "brackigast": "brackig",
    "brackigaste": "brackig",
    "brackigastes": "brackig",
    "brackigasts": "brackig",
    "brackige": "brackig",
    "brackiges": "brackig",
    "brackigheten": "brackighet",
    "brackighetens": "brackighet",
    "brackighets": "brackighet",
    "brackigs": "brackig",
    "brackigt": "brackig",
    "brackigts": "brackig",
    "brackor": "bracka",
    "brackorna": "bracka",
    "brackornas": "bracka",
    "brackors": "bracka",
    "bracks": "bracka",
    "brackvattens": "brackvatten",
    "brackvattnet": "brackvatten",
    "brackvattnets": "brackvatten",
    "bragden": "bragd",
    "bragdens": "bragd",
    "bragder": "bragd",
    "bragderna": "bragd",
    "bragdernas": "bragd",
    "bragders": "bragd",
    "bragdgulden": "bragdguld",
    "bragdguldens": "bragdguld",
    "bragdguldet": "bragdguld",
    "bragdguldets": "bragdguld",
    "bragdgulds": "bragdguld",
    "bragdloppen": "bragdlopp",
    "bragdloppens": "bragdlopp",
    "bragdloppet": "bragdlopp",
    "bragdloppets": "bragdlopp",
    "bragdlopps": "bragdlopp",
    "bragdmässiga": "bragdmässig",
    "bragdmässigare": "bragdmässig",
    "bragdmässigares": "bragdmässig",
    "bragdmässigas": "bragdmässig",
    "bragdmässigast": "bragdmässig",
    "bragdmässigaste": "bragdmässig",
    "bragdmässigastes": "bragdmässig",
    "bragdmässigasts": "bragdmässig",
    "bragdmässige": "bragdmässig",
    "bragdmässiges": "bragdmässig",
    "bragdmässigs": "bragdmässig",
    "bragdmässigt": "bragdmässig",
    "bragdmässigts": "bragdmässig",
    "bragds": "bragd",
    "bragelöften": "bragelöfte",
    "bragelöftena": "bragelöfte",
    "bragelöftenas": "bragelöfte",
    "bragelöftens": "bragelöfte",
    "bragelöftes": "bragelöfte",
    "bragelöftet": "bragelöfte",
    "bragelöftets": "bragelöfte",
    "bragt": "bringa",
    "bragte": "bringa",
    "bragtes": "bringa",
    "bragts": "bringa",
    "brailleskriften": "brailleskrift",
    "brailleskriftens": "brailleskrift",
    "brailleskrifts": "brailleskrift",
    "brainstormingar": "brainstorming",
    "brainstormingarna": "brainstorming",
    "brainstormingarnas": "brainstorming",
    "brainstormingars": "brainstorming",
    "brainstormingen": "brainstorming",
    "brainstormingens": "brainstorming",
    "brainstormings": "brainstorming",
    "brakade": "braka",
    "brakades": "braka",
    "brakande": "braka",
    "brakanden": "brakande",
    "brakandena": "brakande",
    "brakandenas": "brakande",
    "brakandens": "brakande",
    "brakandes": "brakande",
    "brakandet": "brakande",
    "brakandets": "brakande",
    "brakar": "braka",
    "brakas": "braka",
    "brakat": "braka",
    "brakats": "braka",
    "braket": "brak",
    "brakets": "brak",
    "brakfesten": "brakfest",
    "brakfestens": "brakfest",
    "brakfester": "brakfest",
    "brakfesterna": "brakfest",
    "brakfesternas": "brakfest",
    "brakfesters": "brakfest",
    "brakfests": "brakfest",
    "brakfiaskon": "brakfiasko",
    "brakfiaskona": "brakfiasko",
    "brakfiaskonas": "brakfiasko",
    "brakfiaskons": "brakfiasko",
    "brakfiaskos": "brakfiasko",
    "brakfiaskot": "brakfiasko",
    "brakfiaskots": "brakfiasko",
    "brakmiddagar": "brakmiddag",
    "brakmiddagarna": "brakmiddag",
    "brakmiddagarnas": "brakmiddag",
    "brakmiddagars": "brakmiddag",
    "brakmiddagen": "brakmiddag",
    "brakmiddagens": "brakmiddag",
    "brakmiddags": "brakmiddag",
    "braks": "brak",
    "brakskitar": "brakskit",
    "brakskitarna": "brakskit",
    "brakskitarnas": "brakskit",
    "brakskitars": "brakskit",
    "brakskiten": "brakskit",
    "brakskitens": "brakskit",
    "brakskits": "brakskit",
    "brakskivan": "brakskiva",
    "brakskivans": "brakskiva",
    "brakskivas": "brakskiva",
    "brakskive": "brakskiva",
    "brakskivor": "brakskiva",
    "brakskivorna": "brakskiva",
    "brakskivornas": "brakskiva",
    "brakskivors": "brakskiva",
    "braksuccéer": "braksuccé",
    "braksuccéerna": "braksuccé",
    "braksuccéernas": "braksuccé",
    "braksuccéers": "braksuccé",
    "braksuccén": "braksuccé",
    "braksuccéns": "braksuccé",
    "braksuccés": "braksuccé",
    "brakteaten": "brakteat",
    "brakteatens": "brakteat",
    "brakteater": "brakteat",
    "brakteaterna": "brakteat",
    "brakteaternas": "brakteat",
    "brakteaters": "brakteat",
    "brakteats": "brakteat",
    "brakveden": "brakved",
    "brakvedens": "brakved",
    "brakveds": "brakved",
    "brakycefala": "brakycefal",
    "brakycefalare": "brakycefal",
    "brakycefalares": "brakycefal",
    "brakycefalas": "brakycefal",
    "brakycefalast": "brakycefal",
    "brakycefalaste": "brakycefal",
    "brakycefalastes": "brakycefal",
    "brakycefalasts": "brakycefal",
    "brakycefale": "brakycefal",
    "brakycefales": "brakycefal",
    "brakycefalien": "brakycefali",
    "brakycefaliens": "brakycefali",
    "brakycefalin": "brakycefali",
    "brakycefalins": "brakycefali",
    "brakycefalis": "brakycefali",
    "brakycefals": "brakycefal",
    "brakycefalt": "brakycefal",
    "brakycefalts": "brakycefal",
    "brall": "bralla",
    "brallan": "bralla",
    "brallans": "bralla",
    "brallas": "bralla",
    "bralle": "bralla",
    "brallisar": "brallis",
    "brallisarna": "brallis",
    "brallisarnas": "brallis",
    "brallisars": "brallis",
    "brallisen": "brallis",
    "brallisens": "brallis",
    "brallor": "bralla",
    "brallorna": "bralla",
    "brallornas": "bralla",
    "brallors": "bralla",
    "bralls": "bralla",
    "bramanen": "braman",
    "bramanens": "braman",
    "bramaner": "braman",
    "bramanerna": "braman",
    "bramanernas": "braman",
    "bramaners": "braman",
    "bramanismen": "bramanism",
    "bramanismens": "bramanism",
    "bramanismer": "bramanism",
    "bramanismerna": "bramanism",
    "bramanismernas": "bramanism",
    "bramanismers": "bramanism",
    "bramanisms": "bramanism",
    "bramans": "braman",
    "bramanska": "bramansk",
    "bramanskare": "bramansk",
    "bramanskares": "bramansk",
    "bramanskas": "bramansk",
    "bramanskast": "bramansk",
    "bramanskaste": "bramansk",
    "bramanskastes": "bramansk",
    "bramanskasts": "bramansk",
    "bramanske": "bramansk",
    "bramanskes": "bramansk",
    "bramansks": "bramansk",
    "bramanskt": "bramansk",
    "bramanskts": "bramansk",
    "braminen": "bramin",
    "braminens": "bramin",
    "braminer": "bramin",
    "braminerna": "bramin",
    "braminernas": "bramin",
    "braminers": "bramin",
    "bramins": "bramin",
    "bramsegels": "bramsegel",
    "bramseglen": "bramsegel",
    "bramseglens": "bramsegel",
    "bramseglet": "bramsegel",
    "bramseglets": "bramsegel",
    "bramstänger": "bramstång",
    "bramstängerna": "bramstång",
    "bramstängernas": "bramstång",
    "bramstängers": "bramstång",
    "bramstången": "bramstång",
    "bramstångens": "bramstång",
    "bramstångs": "bramstång",
    "brandalarmen": "brandalarm",
    "brandalarmens": "brandalarm",
    "brandalarmet": "brandalarm",
    "brandalarmets": "brandalarm",
    "brandalarms": "brandalarm",
    "brandartikeln": "brandartikel",
    "brandartikelns": "brandartikel",
    "brandartikels": "brandartikel",
    "brandartiklar": "brandartikel",
    "brandartiklarna": "brandartikel",
    "brandartiklarnas": "brandartikel",
    "brandartiklars": "brandartikel",
    "brandattentaten": "brandattentat",
    "brandattentatens": "brandattentat",
    "brandattentatet": "brandattentat",
    "brandattentatets": "brandattentat",
    "brandattentats": "brandattentat",
    "brandbefälen": "brandbefäl",
    "brandbefälens": "brandbefäl",
    "brandbefälet": "brandbefäl",
    "brandbefälets": "brandbefäl",
    "brandbefäls": "brandbefäl",
    "brandbilar": "brandbil",
    "brandbilarna": "brandbil",
    "brandbilarnas": "brandbil",
    "brandbilars": "brandbil",
    "brandbilen": "brandbil",
    "brandbilens": "brandbil",
    "brandbils": "brandbil",
    "brandbomben": "brandbomb",
    "brandbombens": "brandbomb",
    "brandbomber": "brandbomb",
    "brandbomberna": "brandbomb",
    "brandbombernas": "brandbomb",
    "brandbombers": "brandbomb",
    "brandbombs": "brandbomb",
    "brandbottens": "brandbotten",
    "brandbottnar": "brandbotten",
    "brandbottnarna": "brandbotten",
    "brandbottnarnas": "brandbotten",
    "brandbottnars": "brandbotten",
    "brandbottnen": "brandbotten",
    "brandbottnens": "brandbotten",
    "brandchefen": "brandchef",
    "brandchefens": "brandchef",
    "brandchefer": "brandchef",
    "brandcheferna": "brandchef",
    "brandchefernas": "brandchef",
    "brandchefers": "brandchef",
    "brandchefs": "brandchef",
    "branddiken": "branddike",
    "branddikena": "branddike",
    "branddikenas": "branddike",
    "branddikens": "branddike",
    "branddikes": "branddike",
    "branddiket": "branddike",
    "branddikets": "branddike",
    "branddörrar": "branddörr",
    "branddörrarna": "branddörr",
    "branddörrarnas": "branddörr",
    "branddörrars": "branddörr",
    "branddörren": "branddörr",
    "branddörrens": "branddörr",
    "branddörrs": "branddörr",
    "branden": "brand",
    "brandens": "brand",
    "brandfackel": "brandfackla",
    "brandfacklan": "brandfackla",
    "brandfacklans": "brandfackla",
    "brandfacklas": "brandfackla",
    "brandfackle": "brandfackla",
    "brandfacklor": "brandfackla",
    "brandfacklorna": "brandfackla",
    "brandfacklornas": "brandfackla",
    "brandfacklors": "brandfackla",
    "brandfaran": "brandfara",
    "brandfarans": "brandfara",
    "brandfaras": "brandfara",
    "brandfare": "brandfara",
    "brandfarliga": "brandfarlig",
    "brandfarligare": "brandfarlig",
    "brandfarligares": "brandfarlig",
    "brandfarligas": "brandfarlig",
    "brandfarligast": "brandfarlig",
    "brandfarligaste": "brandfarlig",
    "brandfarligastes": "brandfarlig",
    "brandfarligasts": "brandfarlig",
    "brandfarlige": "brandfarlig",
    "brandfarliges": "brandfarlig",
    "brandfarligheten": "brandfarlighet",
    "brandfarlighetens": "brandfarlighet",
    "brandfarlighets": "brandfarlighet",
    "brandfarligs": "brandfarlig",
    "brandfarligt": "brandfarlig",
    "brandfarligts": "brandfarlig",
    "brandfaro": "brandfara",
    "brandförsvaret": "brandförsvar",
    "brandförsvarets": "brandförsvar",
    "brandförsvars": "brandförsvar",
    "brandförsäkringsbolagen": "brandförsäkringsbolag",
    "brandförsäkringsbolagens": "brandförsäkringsbolag",
    "brandförsäkringsbolaget": "brandförsäkringsbolag",
    "brandförsäkringsbolagets": "brandförsäkringsbolag",
    "brandförsäkringsbolags": "brandförsäkringsbolag",
    "brandgat": "brandgata",
    "brandgatan": "brandgata",
    "brandgatans": "brandgata",
    "brandgatas": "brandgata",
    "brandgate": "brandgata",
    "brandgator": "brandgata",
    "brandgatorna": "brandgata",
    "brandgatornas": "brandgata",
    "brandgators": "brandgata",
    "brandgats": "brandgata",
    "brandgaveln": "brandgavel",
    "brandgavelns": "brandgavel",
    "brandgavels": "brandgavel",
    "brandgavlar": "brandgavel",
    "brandgavlarna": "brandgavel",
    "brandgavlarnas": "brandgavel",
    "brandgavlars": "brandgavel",
    "brandgravar": "brandgrav",
    "brandgravarna": "brandgrav",
    "brandgravarnas": "brandgrav",
    "brandgravars": "brandgrav",
    "brandgraven": "brandgrav",
    "brandgravens": "brandgrav",
    "brandgravs": "brandgrav",
    "brandgula": "brandgul",
    "brandgulare": "brandgul",
    "brandgulares": "brandgul",
    "brandgulas": "brandgul",
    "brandgulast": "brandgul",
    "brandgulaste": "brandgul",
    "brandgulastes": "brandgul",
    "brandgulasts": "brandgul",
    "brandgule": "brandgul",
    "brandgules": "brandgul",
    "brandguls": "brandgul",
    "brandgult": "brandgul",
    "brandgults": "brandgul",
    "brandhärdar": "brandhärd",
    "brandhärdarna": "brandhärd",
    "brandhärdarnas": "brandhärd",
    "brandhärdars": "brandhärd",
    "brandhärden": "brandhärd",
    "brandhärdens": "brandhärd",
    "brandhärdiga": "brandhärdig",
    "brandhärdigare": "brandhärdig",
    "brandhärdigares": "brandhärdig",
    "brandhärdigas": "brandhärdig",
    "brandhärdigast": "brandhärdig",
    "brandhärdigaste": "brandhärdig",
    "brandhärdigastes": "brandhärdig",
    "brandhärdigasts": "brandhärdig",
    "brandhärdige": "brandhärdig",
    "brandhärdiges": "brandhärdig",
    "brandhärdigheten": "brandhärdighet",
    "brandhärdighetens": "brandhärdighet",
    "brandhärdighets": "brandhärdighet",
    "brandhärdigs": "brandhärdig",
    "brandhärdigt": "brandhärdig",
    "brandhärdigts": "brandhärdig",
    "brandhärds": "brandhärd",
    "brandhärj": "brandhärja",
    "brandhärjad": "brandhärja",
    "brandhärjade": "brandhärja",
    "brandhärjades": "brandhärja",
    "brandhärjads": "brandhärja",
    "brandhärjande": "brandhärja",
    "brandhärjanden": "brandhärjande",
    "brandhärjandena": "brandhärjande",
    "brandhärjandenas": "brandhärjande",
    "brandhärjandens": "brandhärjande",
    "brandhärjandes": "brandhärjande",
    "brandhärjandet": "brandhärjande",
    "brandhärjandets": "brandhärjande",
    "brandhärjar": "brandhärja",
    "brandhärjas": "brandhärja",
    "brandhärjat": "brandhärja",
    "brandhärjats": "brandhärja",
    "brandingenjören": "brandingenjör",
    "brandingenjörens": "brandingenjör",
    "brandingenjörer": "brandingenjör",
    "brandingenjörerna": "brandingenjör",
    "brandingenjörernas": "brandingenjör",
    "brandingenjörers": "brandingenjör",
    "brandingenjörn": "brandingenjör",
    "brandingenjörns": "brandingenjör",
    "brandingenjörs": "brandingenjör",
    "brandinspektionen": "brandinspektion",
    "brandinspektionens": "brandinspektion",
    "brandinspektioner": "brandinspektion",
    "brandinspektionerna": "brandinspektion",
    "brandinspektionernas": "brandinspektion",
    "brandinspektioners": "brandinspektion",
    "brandinspektions": "brandinspektion",
    "brandinspektören": "brandinspektör",
    "brandinspektörens": "brandinspektör",
    "brandinspektörer": "brandinspektör",
    "brandinspektörerna": "brandinspektör",
    "brandinspektörernas": "brandinspektör",
    "brandinspektörers": "brandinspektör",
    "brandinspektörn": "brandinspektör",
    "brandinspektörns": "brandinspektör",
    "brandinspektörs": "brandinspektör",
    "brandkaptenen": "brandkapten",
    "brandkaptenens": "brandkapten",
    "brandkaptener": "brandkapten",
    "brandkaptenerna": "brandkapten",
    "brandkaptenernas": "brandkapten",
    "brandkapteners": "brandkapten",
    "brandkaptens": "brandkapten",
    "brandkåren": "brandkår",
    "brandkårens": "brandkår",
    "brandkårer": "brandkår",
    "brandkårerna": "brandkår",
    "brandkårernas": "brandkår",
    "brandkårers": "brandkår",
    "brandkårs": "brandkår",
    "brandkårsutryckningar": "brandkårsutryckning",
    "brandkårsutryckningarna": "brandkårsutryckning",
    "brandkårsutryckningarnas": "brandkårsutryckning",
    "brandkårsutryckningars": "brandkårsutryckning",
    "brandkårsutryckningen": "brandkårsutryckning",
    "brandkårsutryckningens": "brandkårsutryckning",
    "brandkårsutrycknings": "brandkårsutryckning",
    "brandlagerna": "brandlager",
    "brandlagernas": "brandlager",
    "brandlagers": "brandlager",
    "brandlagren": "brandlager",
    "brandlagrens": "brandlager",
    "brandlagret": "brandlager",
    "brandlagrets": "brandlager",
    "brandlarmen": "brandlarm",
    "brandlarmens": "brandlarm",
    "brandlarmet": "brandlarm",
    "brandlarmets": "brandlarm",
    "brandlarms": "brandlarm",
    "brandmannen": "brandman",
    "brandmannens": "brandman",
    "brandmans": "brandman",
    "brandmansgreppet": "brandmansgrepp",
    "brandmansgreppets": "brandmansgrepp",
    "brandmansgrepps": "brandmansgrepp",
    "brandmurar": "brandmur",
    "brandmurarna": "brandmur",
    "brandmurarnas": "brandmur",
    "brandmurars": "brandmur",
    "brandmuren": "brandmur",
    "brandmurens": "brandmur",
    "brandmurs": "brandmur",
    "brandmän": "brandman",
    "brandmännen": "brandman",
    "brandmännens": "brandman",
    "brandmäns": "brandman",
    "brandorsaken": "brandorsak",
    "brandorsakens": "brandorsak",
    "brandorsaker": "brandorsak",
    "brandorsakerna": "brandorsak",
    "brandorsakernas": "brandorsak",
    "brandorsakers": "brandorsak",
    "brandorsaks": "brandorsak",
    "brandposten": "brandpost",
    "brandpostens": "brandpost",
    "brandposter": "brandpost",
    "brandposterna": "brandpost",
    "brandposternas": "brandpost",
    "brandposters": "brandpost",
    "brandposts": "brandpost",
    "brandredskapen": "brandredskap",
    "brandredskapens": "brandredskap",
    "brandredskapet": "brandredskap",
    "brandredskapets": "brandredskap",
    "brandredskaps": "brandredskap",
    "brandresten": "brandrest",
    "brandrestens": "brandrest",
    "brandrester": "brandrest",
    "brandresterna": "brandrest",
    "brandresternas": "brandrest",
    "brandresters": "brandrest",
    "brandrests": "brandrest",
    "brandrören": "brandrör",
    "brandrörens": "brandrör",
    "brandröret": "brandrör",
    "brandrörets": "brandrör",
    "brandrörs": "brandrör",
    "brands": "brand",
    "brandsegels": "brandsegel",
    "brandseglen": "brandsegel",
    "brandseglens": "brandsegel",
    "brandseglet": "brandsegel",
    "brandseglets": "brandsegel",
    "brandskadade": "brandskadad",
    "brandskadades": "brandskadad",
    "brandskadads": "brandskadad",
    "brandskadan": "brandskada",
    "brandskadans": "brandskada",
    "brandskadas": "brandskada",
    "brandskadat": "brandskadad",
    "brandskadats": "brandskadad",
    "brandskade": "brandskada",
    "brandskador": "brandskada",
    "brandskadorna": "brandskada",
    "brandskadornas": "brandskada",
    "brandskadors": "brandskada",
    "brandskatt": "brandskatta",
    "brandskattad": "brandskatta",
    "brandskattade": "brandskatta",
    "brandskattades": "brandskatta",
    "brandskattads": "brandskatta",
    "brandskattande": "brandskatta",
    "brandskattanden": "brandskattande",
    "brandskattandena": "brandskattande",
    "brandskattandenas": "brandskattande",
    "brandskattandens": "brandskattande",
    "brandskattandes": "brandskattande",
    "brandskattandet": "brandskattande",
    "brandskattandets": "brandskattande",
    "brandskattar": "brandskatta",
    "brandskattas": "brandskatta",
    "brandskattat": "brandskatta",
    "brandskattats": "brandskatta",
    "brandskatten": "brandskatt",
    "brandskattens": "brandskatt",
    "brandskatter": "brandskatt",
    "brandskatterna": "brandskatt",
    "brandskatternas": "brandskatt",
    "brandskatters": "brandskatt",
    "brandskatts": "brandskatt",
    "brandskyddet": "brandskydd",
    "brandskyddets": "brandskydd",
    "brandskydds": "brandskydd",
    "brandskyddslagstiftningar": "brandskyddslagstiftning",
    "brandskyddslagstiftningarna": "brandskyddslagstiftning",
    "brandskyddslagstiftningarnas": "brandskyddslagstiftning",
    "brandskyddslagstiftningars": "brandskyddslagstiftning",
    "brandskyddslagstiftningen": "brandskyddslagstiftning",
    "brandskyddslagstiftningens": "brandskyddslagstiftning",
    "brandskyddslagstiftnings": "brandskyddslagstiftning",
    "brandskåpen": "brandskåp",
    "brandskåpens": "brandskåp",
    "brandskåpet": "brandskåp",
    "brandskåpets": "brandskåp",
    "brandskåps": "brandskåp",
    "brandslangar": "brandslang",
    "brandslangarna": "brandslang",
    "brandslangarnas": "brandslang",
    "brandslangars": "brandslang",
    "brandslangen": "brandslang",
    "brandslangens": "brandslang",
    "brandslangs": "brandslang",
    "brandsläckar": "brandsläckare",
    "brandsläckarattrappen": "brandsläckarattrapp",
    "brandsläckarattrappens": "brandsläckarattrapp",
    "brandsläckarattrapper": "brandsläckarattrapp",
    "brandsläckarattrapperna": "brandsläckarattrapp",
    "brandsläckarattrappernas": "brandsläckarattrapp",
    "brandsläckarattrappers": "brandsläckarattrapp",
    "brandsläckarattrapps": "brandsläckarattrapp",
    "brandsläckaren": "brandsläckare",
    "brandsläckarens": "brandsläckare",
    "brandsläckares": "brandsläckare",
    "brandsläckarna": "brandsläckare",
    "brandsläckarnas": "brandsläckare",
    "brandsoldaten": "brandsoldat",
    "brandsoldatens": "brandsoldat",
    "brandsoldater": "brandsoldat",
    "brandsoldaterna": "brandsoldat",
    "brandsoldaternas": "brandsoldat",
    "brandsoldaters": "brandsoldat",
    "brandsoldats": "brandsoldat",
    "brandsprut": "brandspruta",
    "brandsprutan": "brandspruta",
    "brandsprutans": "brandspruta",
    "brandsprutas": "brandspruta",
    "brandsprute": "brandspruta",
    "brandsprutor": "brandspruta",
    "brandsprutorna": "brandspruta",
    "brandsprutornas": "brandspruta",
    "brandsprutors": "brandspruta",
    "brandspruts": "brandspruta",
    "brandstationen": "brandstation",
    "brandstationens": "brandstation",
    "brandstationer": "brandstation",
    "brandstationerna": "brandstation",
    "brandstationernas": "brandstation",
    "brandstationers": "brandstation",
    "brandstations": "brandstation",
    "brandsteg": "brandstege",
    "brandstegar": "brandstege",
    "brandstegarna": "brandstege",
    "brandstegarnas": "brandstege",
    "brandstegars": "brandstege",
    "brandstegen": "brandstege",
    "brandstegens": "brandstege",
    "brandsteges": "brandstege",
    "brandstegs": "brandstege",
    "brandstoden": "brandstod",
    "brandstodens": "brandstod",
    "brandstods": "brandstod",
    "brandstodsbolagen": "brandstodsbolag",
    "brandstodsbolagens": "brandstodsbolag",
    "brandstodsbolaget": "brandstodsbolag",
    "brandstodsbolagets": "brandstodsbolag",
    "brandstodsbolags": "brandstodsbolag",
    "brandstyrkan": "brandstyrka",
    "brandstyrkans": "brandstyrka",
    "brandstyrkas": "brandstyrka",
    "brandstyrke": "brandstyrka",
    "brandstyrkor": "brandstyrka",
    "brandstyrkorna": "brandstyrka",
    "brandstyrkornas": "brandstyrka",
    "brandstyrkors": "brandstyrka",
    "brandsvampar": "brandsvamp",
    "brandsvamparna": "brandsvamp",
    "brandsvamparnas": "brandsvamp",
    "brandsvampars": "brandsvamp",
    "brandsvampen": "brandsvamp",
    "brandsvampens": "brandsvamp",
    "brandsvamps": "brandsvamp",
    "brandsynen": "brandsyn",
    "brandsynens": "brandsyn",
    "brandsyner": "brandsyn",
    "brandsynerna": "brandsyn",
    "brandsynernas": "brandsyn",
    "brandsyners": "brandsyn",
    "brandsyns": "brandsyn",
    "brandsäkerheten": "brandsäkerhet",
    "brandsäkerhetens": "brandsäkerhet",
    "brandsäkerhets": "brandsäkerhet",
    "brandsäkers": "brandsäker",
    "brandsäkert": "brandsäker",
    "brandsäkerts": "brandsäker",
    "brandsäkra": "brandsäker",
    "brandsäkrare": "brandsäker",
    "brandsäkrares": "brandsäker",
    "brandsäkras": "brandsäker",
    "brandsäkrast": "brandsäker",
    "brandsäkraste": "brandsäker",
    "brandsäkrastes": "brandsäker",
    "brandsäkrasts": "brandsäker",
    "brandsäkre": "brandsäker",
    "brandsäkres": "brandsäker",
    "brandtalen": "brandtal",
    "brandtalens": "brandtal",
    "brandtalet": "brandtal",
    "brandtalets": "brandtal",
    "brandtals": "brandtal",
    "brandtornen": "brandtorn",
    "brandtornens": "brandtorn",
    "brandtornet": "brandtorn",
    "brandtornets": "brandtorn",
    "brandtorns": "brandtorn",
    "brandvakten": "brandvakt",
    "brandvaktens": "brandvakt",
    "brandvakter": "brandvakt",
    "brandvakterna": "brandvakt",
    "brandvakternas": "brandvakt",
    "brandvakters": "brandvakt",
    "brandvakts": "brandvakt",
    "brandvarnar": "brandvarnare",
    "brandvarnaren": "brandvarnare",
    "brandvarnarens": "brandvarnare",
    "brandvarnares": "brandvarnare",
    "brandvarnarna": "brandvarnare",
    "brandvarnarnas": "brandvarnare",
    "brandväsendet": "brandväsen",
    "brandväsendets": "brandväsen",
    "brandväsenet": "brandväsen",
    "brandväsenets": "brandväsen",
    "brandväsens": "brandväsen",
    "brandyn": "brandy",
    "brandyns": "brandy",
    "brandys": "brandy",
    "brandövningar": "brandövning",
    "brandövningarna": "brandövning",
    "brandövningarnas": "brandövning",
    "brandövningars": "brandövning",
    "brandövningen": "brandövning",
    "brandövningens": "brandövning",
    "brandövnings": "brandövning",
    "brann": "brinna",
    "branns": "brinna",
    "branschen": "bransch",
    "branschens": "bransch",
    "branscher": "bransch",
    "branscherna": "bransch",
    "branschernas": "bransch",
    "branschers": "bransch",
    "branschföreningar": "branschförening",
    "branschföreningarna": "branschförening",
    "branschföreningarnas": "branschförening",
    "branschföreningars": "branschförening",
    "branschföreningen": "branschförening",
    "branschföreningens": "branschförening",
    "branschförenings": "branschförening",
    "branschmässiga": "branschmässig",
    "branschmässigare": "branschmässig",
    "branschmässigares": "branschmässig",
    "branschmässigas": "branschmässig",
    "branschmässigast": "branschmässig",
    "branschmässigaste": "branschmässig",
    "branschmässigastes": "branschmässig",
    "branschmässigasts": "branschmässig",
    "branschmässige": "branschmässig",
    "branschmässiges": "branschmässig",
    "branschmässigs": "branschmässig",
    "branschmässigt": "branschmässig",
    "branschmässigts": "branschmässig",
    "branschråden": "branschråd",
    "branschrådens": "branschråd",
    "branschrådet": "branschråd",
    "branschrådets": "branschråd",
    "branschråds": "branschråd",
    "branschs": "bransch",
    "branschtidningar": "branschtidning",
    "branschtidningarna": "branschtidning",
    "branschtidningarnas": "branschtidning",
    "branschtidningars": "branschtidning",
    "branschtidningen": "branschtidning",
    "branschtidningens": "branschtidning",
    "branschtidnings": "branschtidning",
    "branschvanan": "branschvana",
    "branschvanans": "branschvana",
    "branschvanas": "branschvana",
    "branschvane": "branschvana",
    "branta": "brant",
    "brantare": "brant",
    "brantares": "brant",
    "brantas": "brant",
    "brantast": "brant",
    "brantaste": "brant",
    "brantastes": "brant",
    "brantasts": "brant",
    "brante": "brant",
    "branten": "brant",
    "brantens": "brant",
    "branter": "brant",
    "branterna": "brant",
    "branternas": "brant",
    "branters": "brant",
    "brantes": "brant",
    "brantheten": "branthet",
    "branthetens": "branthet",
    "branthets": "branthet",
    "brants": "brant",
    "bras": "brasa",
    "brasan": "brasa",
    "brasans": "brasa",
    "brasas": "brasa",
    "brase": "brasa",
    "brasilianar": "brasilianare",
    "brasilianaren": "brasilianare",
    "brasilianarens": "brasilianare",
    "brasilianares": "brasilianare",
    "brasilianarna": "brasilianare",
    "brasilianarnas": "brasilianare",
    "brasilianen": "brasilian",
    "brasilianens": "brasilian",
    "brasilianer": "brasilian",
    "brasilianerna": "brasilian",
    "brasilianernas": "brasilian",
    "brasilianers": "brasilian",
    "brasilians": "brasilian",
    "brasilianska": "brasiliansk",
    "brasilianskan": "brasilianska",
    "brasilianskans": "brasilianska",
    "brasilianskare": "brasiliansk",
    "brasilianskares": "brasiliansk",
    "brasilianskas": "brasilianska",
    "brasilianskast": "brasiliansk",
    "brasilianskaste": "brasiliansk",
    "brasilianskastes": "brasiliansk",
    "brasilianskasts": "brasiliansk",
    "brasilianske": "brasilianska",
    "brasilianskes": "brasiliansk",
    "brasilianskor": "brasilianska",
    "brasilianskorna": "brasilianska",
    "brasilianskornas": "brasilianska",
    "brasilianskors": "brasilianska",
    "brasiliansks": "brasiliansk",
    "brasilianskt": "brasiliansk",
    "brasilianskts": "brasiliansk",
    "brasiliern": "brasilier",
    "brasilierna": "brasilier",
    "brasiliernas": "brasilier",
    "brasilierns": "brasilier",
    "brasiliers": "brasilier",
    "brask": "braska",
    "braskade": "braska",
    "braskades": "braska",
    "braskande": "braska",
    "braskanden": "braskande",
    "braskandena": "braskande",
    "braskandenas": "braskande",
    "braskandens": "braskande",
    "braskandes": "braskande",
    "braskandet": "braskande",
    "braskandets": "braskande",
    "braskar": "braska",
    "braskas": "braska",
    "braskat": "braska",
    "braskats": "braska",
    "brasklappar": "brasklapp",
    "brasklapparna": "brasklapp",
    "brasklapparnas": "brasklapp",
    "brasklappars": "brasklapp",
    "brasklappen": "brasklapp",
    "brasklappens": "brasklapp",
    "brasklapps": "brasklapp",
    "brasor": "brasa",
    "brasorna": "brasa",
    "brasornas": "brasa",
    "brasors": "brasa",
    "brass": "brassa",
    "brassad": "brassa",
    "brassade": "brassa",
    "brassades": "brassa",
    "brassads": "brassa",
    "brassande": "brassa",
    "brassanden": "brassande",
    "brassandena": "brassande",
    "brassandenas": "brassande",
    "brassandens": "brassande",
    "brassandes": "brassande",
    "brassandet": "brassande",
    "brassandets": "brassande",
    "brassar": "brassa",
    "brassas": "brassa",
    "brassat": "brassa",
    "brassats": "brassa",
    "brasset": "brass",
    "brassets": "brass",
    "brast": "brista",
    "brasts": "brista",
    "braständar": "braständare",
    "braständaren": "braständare",
    "braständarens": "braständare",
    "braständares": "braständare",
    "braständarna": "braständare",
    "braständarnas": "braständare",
    "brasveden": "brasved",
    "brasvedens": "brasved",
    "brasveds": "brasved",
    "bravaden": "bravad",
    "bravadens": "bravad",
    "bravader": "bravad",
    "bravaderna": "bravad",
    "bravadernas": "bravad",
    "bravaders": "bravad",
    "bravads": "bravad",
    "braverade": "bravera",
    "braverades": "bravera",
    "braverande": "bravera",
    "braveranden": "braverande",
    "braverandena": "braverande",
    "braverandenas": "braverande",
    "braverandens": "braverande",
    "braverandes": "braverande",
    "braverandet": "braverande",
    "braverandets": "braverande",
    "braverar": "bravera",
    "braveras": "bravera",
    "braverat": "bravera",
    "braverats": "bravera",
    "bravurari": "bravuraria",
    "bravurarian": "bravuraria",
    "bravurarians": "bravuraria",
    "bravurarias": "bravuraria",
    "bravurarie": "bravuraria",
    "bravurarior": "bravuraria",
    "bravurariorna": "bravuraria",
    "bravurariornas": "bravuraria",
    "bravurariors": "bravuraria",
    "bravuraris": "bravuraria",
    "bravuren": "bravur",
    "bravurens": "bravur",
    "bravurnummerna": "bravurnummer",
    "bravurnummernas": "bravurnummer",
    "bravurnummers": "bravurnummer",
    "bravurnumren": "bravurnummer",
    "bravurnumrens": "bravurnummer",
    "bravurnumret": "bravurnummer",
    "bravurnumrets": "bravurnummer",
    "bravurrollen": "bravurroll",
    "bravurrollens": "bravurroll",
    "bravurroller": "bravurroll",
    "bravurrollerna": "bravurroll",
    "bravurrollernas": "bravurroll",
    "bravurrollers": "bravurroll",
    "bravurrolls": "bravurroll",
    "bravurs": "bravur",
    "braxengräset": "braxengräs",
    "braxengräsets": "braxengräs",
    "braxenmygg": "braxenmygga",
    "braxenmyggan": "braxenmygga",
    "braxenmyggans": "braxenmygga",
    "braxenmyggas": "braxenmygga",
    "braxenmygge": "braxenmygga",
    "braxenmyggor": "braxenmygga",
    "braxenmyggorna": "braxenmygga",
    "braxenmyggornas": "braxenmygga",
    "braxenmyggors": "braxenmygga",
    "braxenmyggs": "braxenmygga",
    "braxenpank": "braxenpanka",
    "braxenpankan": "braxenpanka",
    "braxenpankans": "braxenpanka",
    "braxenpankas": "braxenpanka",
    "braxenpanke": "braxenpanka",
    "braxenpankor": "braxenpanka",
    "braxenpankorna": "braxenpanka",
    "braxenpankornas": "braxenpanka",
    "braxenpankors": "braxenpanka",
    "braxenpanks": "braxenpanka",
    "braxens": "braxen",
    "braxnar": "braxen",
    "braxnarna": "braxen",
    "braxnarnas": "braxen",
    "braxnars": "braxen",
    "braxnen": "braxen",
    "braxnens": "braxen",
    "breakdancen": "breakdance",
    "breakdancens": "breakdance",
    "breakdances": "breakdance",
    "breaken": "break",
    "breakens": "break",
    "breaket": "break",
    "breakets": "break",
    "breaks": "break",
    "brecci": "breccia",
    "breccian": "breccia",
    "breccians": "breccia",
    "breccias": "breccia",
    "breccie": "breccia",
    "breccior": "breccia",
    "brecciorna": "breccia",
    "brecciornas": "breccia",
    "brecciors": "breccia",
    "breccis": "breccia",
    "bred": "bre",
    "breda": "bred",
    "bredande": "bre",
    "bredanden": "bredande",
    "bredandena": "bredande",
    "bredandenas": "bredande",
    "bredandens": "bredande",
    "bredandes": "bredande",
    "bredandet": "bredande",
    "bredandets": "bredande",
    "bredare": "bred",
    "bredares": "bred",
    "bredas": "bred",
    "bredast": "bred",
    "bredaste": "bred",
    "bredastes": "bred",
    "bredasts": "bred",
    "bredaxlade": "bredaxlad",
    "bredaxlades": "bredaxlad",
    "bredaxlads": "bredaxlad",
    "bredaxlat": "bredaxlad",
    "bredaxlats": "bredaxlad",
    "bredbanden": "bredband",
    "bredbandens": "bredband",
    "bredbandet": "bredband",
    "bredbandets": "bredband",
    "bredbands": "bredband",
    "bredbandsföretagen": "bredbandsföretag",
    "bredbandsföretagens": "bredbandsföretag",
    "bredbandsföretaget": "bredbandsföretag",
    "bredbandsföretagets": "bredbandsföretag",
    "bredbandsföretags": "bredbandsföretag",
    "bredbara": "bredbar",
    "bredbarare": "bredbar",
    "bredbarares": "bredbar",
    "bredbaras": "bredbar",
    "bredbarast": "bredbar",
    "bredbaraste": "bredbar",
    "bredbarastes": "bredbar",
    "bredbarasts": "bredbar",
    "bredbare": "bredbar",
    "bredbares": "bredbar",
    "bredbarheten": "bredbarhet",
    "bredbarhetens": "bredbarhet",
    "bredbarhets": "bredbarhet",
    "bredbars": "bredbar",
    "bredbart": "bredbar",
    "bredbarts": "bredbar",
    "bredbenta": "bredbent",
    "bredbentare": "bredbent",
    "bredbentares": "bredbent",
    "bredbentas": "bredbent",
    "bredbentast": "bredbent",
    "bredbentaste": "bredbent",
    "bredbentastes": "bredbent",
    "bredbentasts": "bredbent",
    "bredbente": "bredbent",
    "bredbentes": "bredbent",
    "bredbentheten": "bredbenthet",
    "bredbenthetens": "bredbenthet",
    "bredbenthets": "bredbenthet",
    "bredbents": "bredbent",
    "bredbladiga": "bredbladig",
    "bredbladigare": "bredbladig",
    "bredbladigares": "bredbladig",
    "bredbladigas": "bredbladig",
    "bredbladigast": "bredbladig",
    "bredbladigaste": "bredbladig",
    "bredbladigastes": "bredbladig",
    "bredbladigasts": "bredbladig",
    "bredbladige": "bredbladig",
    "bredbladiges": "bredbladig",
    "bredbladigheten": "bredbladighet",
    "bredbladighetens": "bredbladighet",
    "bredbladighets": "bredbladighet",
    "bredbladigs": "bredbladig",
    "bredbladigt": "bredbladig",
    "bredbladigts": "bredbladig",
    "bredbrättade": "bredbrättad",
    "bredbrättades": "bredbrättad",
    "bredbrättads": "bredbrättad",
    "bredbrättat": "bredbrättad",
    "bredbrättats": "bredbrättad",
    "bredbrättiga": "bredbrättig",
    "bredbrättigare": "bredbrättig",
    "bredbrättigares": "bredbrättig",
    "bredbrättigas": "bredbrättig",
    "bredbrättigast": "bredbrättig",
    "bredbrättigaste": "bredbrättig",
    "bredbrättigastes": "bredbrättig",
    "bredbrättigasts": "bredbrättig",
    "bredbrättige": "bredbrättig",
    "bredbrättiges": "bredbrättig",
    "bredbrättigheten": "bredbrättighet",
    "bredbrättighetens": "bredbrättighet",
    "bredbrättighets": "bredbrättighet",
    "bredbrättigs": "bredbrättig",
    "bredbrättigt": "bredbrättig",
    "bredbrättigts": "bredbrättig",
    "bredd": "bredda",
    "bredda": "bre",
    "breddad": "bredda",
    "breddade": "bredda",
    "breddades": "bredda",
    "breddads": "bredda",
    "breddande": "bredda",
    "breddanden": "breddande",
    "breddandena": "breddande",
    "breddandenas": "breddande",
    "breddandens": "breddande",
    "breddandes": "breddande",
    "breddandet": "breddande",
    "breddandets": "breddande",
    "breddar": "bredda",
    "breddas": "bredda",
    "breddat": "bredda",
    "breddats": "bredda",
    "bredde": "bre",
    "bredden": "bredd",
    "breddens": "bredd",
    "bredder": "bredd",
    "bredderna": "bredd",
    "breddernas": "bredd",
    "bredders": "bredd",
    "breddes": "bre",
    "breddgraden": "breddgrad",
    "breddgradens": "breddgrad",
    "breddgrader": "breddgrad",
    "breddgraderna": "breddgrad",
    "breddgradernas": "breddgrad",
    "breddgraders": "breddgrad",
    "breddgrads": "breddgrad",
    "breddidrotten": "breddidrott",
    "breddidrottens": "breddidrott",
    "breddidrotter": "breddidrott",
    "breddidrotterna": "breddidrott",
    "breddidrotternas": "breddidrott",
    "breddidrotters": "breddidrott",
    "breddidrotts": "breddidrott",
    "breddmässiga": "breddmässig",
    "breddmässigare": "breddmässig",
    "breddmässigares": "breddmässig",
    "breddmässigas": "breddmässig",
    "breddmässigast": "breddmässig",
    "breddmässigaste": "breddmässig",
    "breddmässigastes": "breddmässig",
    "breddmässigasts": "breddmässig",
    "breddmässige": "breddmässig",
    "breddmässiges": "breddmässig",
    "breddmässigs": "breddmässig",
    "breddmässigt": "breddmässig",
    "breddmässigts": "breddmässig",
    "breddningar": "breddning",
    "breddningarna": "breddning",
    "breddningarnas": "breddning",
    "breddningars": "breddning",
    "breddningen": "breddning",
    "breddningens": "breddning",
    "breddnings": "breddning",
    "bredds": "bredd",
    "brede": "bred",
    "breder": "bre",
    "bredes": "bred",
    "bredheten": "bredhet",
    "bredhetens": "bredhet",
    "bredhets": "bredhet",
    "bredkäftade": "bredkäftad",
    "bredkäftades": "bredkäftad",
    "bredkäftads": "bredkäftad",
    "bredkäftat": "bredkäftad",
    "bredkäftats": "bredkäftad",
    "bredmunnar": "bredmun",
    "bredmunnarna": "bredmun",
    "bredmunnarnas": "bredmun",
    "bredmunnars": "bredmun",
    "bredmunnen": "bredmun",
    "bredmunnens": "bredmun",
    "bredmuns": "bredmun",
    "bredmynta": "bredmynt",
    "bredmyntare": "bredmynt",
    "bredmyntares": "bredmynt",
    "bredmyntas": "bredmynt",
    "bredmyntast": "bredmynt",
    "bredmyntaste": "bredmynt",
    "bredmyntastes": "bredmynt",
    "bredmyntasts": "bredmynt",
    "bredmynte": "bredmynt",
    "bredmyntes": "bredmynt",
    "bredmyntheten": "bredmynthet",
    "bredmynthetens": "bredmynthet",
    "bredmynthets": "bredmynthet",
    "bredmynts": "bredmynt",
    "bredrandiga": "bredrandig",
    "bredrandigare": "bredrandig",
    "bredrandigares": "bredrandig",
    "bredrandigas": "bredrandig",
    "bredrandigast": "bredrandig",
    "bredrandigaste": "bredrandig",
    "bredrandigastes": "bredrandig",
    "bredrandigasts": "bredrandig",
    "bredrandige": "bredrandig",
    "bredrandiges": "bredrandig",
    "bredrandigheten": "bredrandighet",
    "bredrandighetens": "bredrandighet",
    "bredrandighets": "bredrandighet",
    "bredrandigs": "bredrandig",
    "bredrandigt": "bredrandig",
    "bredrandigts": "bredrandig",
    "breds": "bred",
    "bredsidan": "bredsida",
    "bredsidans": "bredsida",
    "bredsidas": "bredsida",
    "bredside": "bredsida",
    "bredsides": "bredsida",
    "bredsidor": "bredsida",
    "bredsidorna": "bredsida",
    "bredsidornas": "bredsida",
    "bredsidors": "bredsida",
    "bredskyggiga": "bredskyggig",
    "bredskyggigare": "bredskyggig",
    "bredskyggigares": "bredskyggig",
    "bredskyggigas": "bredskyggig",
    "bredskyggigast": "bredskyggig",
    "bredskyggigaste": "bredskyggig",
    "bredskyggigastes": "bredskyggig",
    "bredskyggigasts": "bredskyggig",
    "bredskyggige": "bredskyggig",
    "bredskyggiges": "bredskyggig",
    "bredskyggigheten": "bredskyggighet",
    "bredskyggighetens": "bredskyggighet",
    "bredskyggighets": "bredskyggighet",
    "bredskyggigs": "bredskyggig",
    "bredskyggigt": "bredskyggig",
    "bredskyggigts": "bredskyggig",
    "bredspackeln": "bredspackel",
    "bredspackelns": "bredspackel",
    "bredspackels": "bredspackel",
    "bredspacklar": "bredspackel",
    "bredspacklarna": "bredspackel",
    "bredspacklarnas": "bredspackel",
    "bredspacklars": "bredspackel",
    "bredspåriga": "bredspårig",
    "bredspårigare": "bredspårig",
    "bredspårigares": "bredspårig",
    "bredspårigas": "bredspårig",
    "bredspårigast": "bredspårig",
    "bredspårigaste": "bredspårig",
    "bredspårigastes": "bredspårig",
    "bredspårigasts": "bredspårig",
    "bredspårige": "bredspårig",
    "bredspåriges": "bredspårig",
    "bredspårigheten": "bredspårighet",
    "bredspårighetens": "bredspårighet",
    "bredspårighets": "bredspårighet",
    "bredspårigs": "bredspårig",
    "bredspårigt": "bredspårig",
    "bredspårigts": "bredspårig",
    "bredsådd": "bredså",
    "bredsådda": "bredså",
    "bredsåddas": "bredså",
    "bredsådde": "bredså",
    "bredsådden": "bredsådd",
    "bredsåddens": "bredsådd",
    "bredsåddes": "bredså",
    "bredsådds": "bredsådd",
    "bredsående": "bredså",
    "bredsåenden": "bredsående",
    "bredsåendena": "bredsående",
    "bredsåendenas": "bredsående",
    "bredsåendens": "bredsående",
    "bredsåendes": "bredsående",
    "bredsåendet": "bredsående",
    "bredsåendets": "bredsående",
    "bredsår": "bredså",
    "bredsås": "bredså",
    "bredsått": "bredså",
    "bredsåtts": "bredså",
    "bredvidläsningar": "bredvidläsning",
    "bredvidläsningarna": "bredvidläsning",
    "bredvidläsningarnas": "bredvidläsning",
    "bredvidläsningars": "bredvidläsning",
    "bredvidläsningen": "bredvidläsning",
    "bredvidläsningens": "bredvidläsning",
    "bredvidläsnings": "bredvidläsning",
    "breende": "bre",
    "breenden": "breende",
    "breendena": "breende",
    "breendenas": "breende",
    "breendens": "breende",
    "breendes": "breende",
    "breendet": "breende",
    "breendets": "breende",
    "brer": "bre",
    "bres": "bre",
    "bresiljan": "bresilja",
    "bresiljans": "bresilja",
    "bresiljas": "bresilja",
    "bretagnar": "bretagnare",
    "bretagnaren": "bretagnare",
    "bretagnarens": "bretagnare",
    "bretagnares": "bretagnare",
    "bretagnarna": "bretagnare",
    "bretagnarnas": "bretagnare",
    "bretagnisk": "bretagniska",
    "bretagniska": "bretagnisk",
    "bretagniskan": "bretagniska",
    "bretagniskans": "bretagniska",
    "bretagniskare": "bretagnisk",
    "bretagniskares": "bretagnisk",
    "bretagniskas": "bretagniska",
    "bretagniskast": "bretagnisk",
    "bretagniskaste": "bretagnisk",
    "bretagniskastes": "bretagnisk",
    "bretagniskasts": "bretagnisk",
    "bretagniske": "bretagniska",
    "bretagniskes": "bretagnisk",
    "bretagniskor": "bretagniska",
    "bretagniskorna": "bretagniska",
    "bretagniskornas": "bretagniska",
    "bretagniskors": "bretagniska",
    "bretagnisks": "bretagnisk",
    "bretagniskt": "bretagnisk",
    "bretagniskts": "bretagnisk",
    "bretonen": "breton",
    "bretonens": "breton",
    "bretoner": "breton",
    "bretonerna": "breton",
    "bretonernas": "breton",
    "bretoners": "breton",
    "bretons": "breton",
    "bretonsk": "bretonska",
    "bretonska": "bretonsk",
    "bretonskan": "bretonska",
    "bretonskans": "bretonska",
    "bretonskare": "bretonsk",
    "bretonskares": "bretonsk",
    "bretonskas": "bretonska",
    "bretonskast": "bretonsk",
    "bretonskaste": "bretonsk",
    "bretonskastes": "bretonsk",
    "bretonskasts": "bretonsk",
    "bretonske": "bretonska",
    "bretonskes": "bretonsk",
    "bretonskor": "bretonska",
    "bretonskorna": "bretonska",
    "bretonskornas": "bretonska",
    "bretonskors": "bretonska",
    "bretonsks": "bretonsk",
    "bretonskt": "bretonsk",
    "bretonskts": "bretonsk",
    "brett": "bred",
    "bretts": "bred",
    "brevbomben": "brevbomb",
    "brevbombens": "brevbomb",
    "brevbomber": "brevbomb",
    "brevbomberna": "brevbomb",
    "brevbombernas": "brevbomb",
    "brevbombers": "brevbomb",
    "brevbombs": "brevbomb",
    "brevbärar": "brevbärare",
    "brevbäraren": "brevbärare",
    "brevbärarens": "brevbärare",
    "brevbärares": "brevbärare",
    "brevbärarna": "brevbärare",
    "brevbärarnas": "brevbärare",
    "brevbäringar": "brevbäring",
    "brevbäringarna": "brevbäring",
    "brevbäringarnas": "brevbäring",
    "brevbäringars": "brevbäring",
    "brevbäringen": "brevbäring",
    "brevbäringens": "brevbäring",
    "brevbärings": "brevbäring",
    "brevcensuren": "brevcensur",
    "brevcensurens": "brevcensur",
    "brevcensurs": "brevcensur",
    "brevduv": "brevduva",
    "brevduvan": "brevduva",
    "brevduvans": "brevduva",
    "brevduvas": "brevduva",
    "brevduve": "brevduva",
    "brevduvor": "brevduva",
    "brevduvorna": "brevduva",
    "brevduvornas": "brevduva",
    "brevduvors": "brevduva",
    "brevduvs": "brevduva",
    "breven": "brev",
    "brevens": "brev",
    "brevet": "brev",
    "brevets": "brev",
    "brevfacken": "brevfack",
    "brevfackens": "brevfack",
    "brevfacket": "brevfack",
    "brevfackets": "brevfack",
    "brevfacks": "brevfack",
    "brevfrågan": "brevfråga",
    "brevfrågans": "brevfråga",
    "brevfrågas": "brevfråga",
    "brevfråge": "brevfråga",
    "brevfrågor": "brevfråga",
    "brevfrågorna": "brevfråga",
    "brevfrågornas": "brevfråga",
    "brevfrågors": "brevfråga",
    "brevförsändelsen": "brevförsändelse",
    "brevförsändelsens": "brevförsändelse",
    "brevförsändelser": "brevförsändelse",
    "brevförsändelserna": "brevförsändelse",
    "brevförsändelsernas": "brevförsändelse",
    "brevförsändelsers": "brevförsändelse",
    "brevförsändelses": "brevförsändelse",
    "brevhemligheten": "brevhemlighet",
    "brevhemlighetens": "brevhemlighet",
    "brevhemligheter": "brevhemlighet",
    "brevhemligheterna": "brevhemlighet",
    "brevhemligheternas": "brevhemlighet",
    "brevhemligheters": "brevhemlighet",
    "brevhemlighets": "brevhemlighet",
    "brevhuvuden": "brevhuvud",
    "brevhuvudena": "brevhuvud",
    "brevhuvudenas": "brevhuvud",
    "brevhuvudens": "brevhuvud",
    "brevhuvudet": "brevhuvud",
    "brevhuvudets": "brevhuvud",
    "brevhuvuds": "brevhuvud",
    "breviarie": "breviarium",
    "breviarier": "breviarium",
    "breviarierna": "breviarium",
    "breviariernas": "breviarium",
    "breviariers": "breviarium",
    "breviariet": "breviarium",
    "breviariets": "breviarium",
    "breviariums": "breviarium",
    "brevinkasten": "brevinkast",
    "brevinkastens": "brevinkast",
    "brevinkastet": "brevinkast",
    "brevinkastets": "brevinkast",
    "brevinkasts": "brevinkast",
    "brevkorten": "brevkort",
    "brevkortens": "brevkort",
    "brevkortet": "brevkort",
    "brevkortets": "brevkort",
    "brevkorts": "brevkort",
    "brevlåd": "brevlåda",
    "brevlådan": "brevlåda",
    "brevlådans": "brevlåda",
    "brevlådas": "brevlåda",
    "brevlåde": "brevlåda",
    "brevlådeföretagen": "brevlådeföretag",
    "brevlådeföretagens": "brevlådeföretag",
    "brevlådeföretaget": "brevlådeföretag",
    "brevlådeföretagets": "brevlådeföretag",
    "brevlådeföretags": "brevlådeföretag",
    "brevlådor": "brevlåda",
    "brevlådorna": "brevlåda",
    "brevlådornas": "brevlåda",
    "brevlådors": "brevlåda",
    "brevlåds": "brevlåda",
    "brevpapperen": "brevpapper",
    "brevpapperens": "brevpapper",
    "brevpapperet": "brevpapper",
    "brevpapperets": "brevpapper",
    "brevpapperna": "brevpapper",
    "brevpappernas": "brevpapper",
    "brevpappers": "brevpapper",
    "brevpappren": "brevpapper",
    "brevpapprens": "brevpapper",
    "brevpappret": "brevpapper",
    "brevpapprets": "brevpapper",
    "brevporton": "brevporto",
    "brevportona": "brevporto",
    "brevportonas": "brevporto",
    "brevportons": "brevporto",
    "brevportos": "brevporto",
    "brevportot": "brevporto",
    "brevportots": "brevporto",
    "brevpressar": "brevpress",
    "brevpressarna": "brevpress",
    "brevpressarnas": "brevpress",
    "brevpressars": "brevpress",
    "brevpressen": "brevpress",
    "brevpressens": "brevpress",
    "brevromanen": "brevroman",
    "brevromanens": "brevroman",
    "brevromaner": "brevroman",
    "brevromanerna": "brevroman",
    "brevromanernas": "brevroman",
    "brevromaners": "brevroman",
    "brevromans": "brevroman",
    "brevs": "brev",
    "brevskolan": "brevskola",
    "brevskolans": "brevskola",
    "brevskolas": "brevskola",
    "brevskole": "brevskola",
    "brevskolor": "brevskola",
    "brevskolorna": "brevskola",
    "brevskolornas": "brevskola",
    "brevskolors": "brevskola",
    "brevskrivar": "brevskrivare",
    "brevskrivaren": "brevskrivare",
    "brevskrivarens": "brevskrivare",
    "brevskrivares": "brevskrivare",
    "brevskrivarna": "brevskrivare",
    "brevskrivarnas": "brevskrivare",
    "brevskördar": "brevskörd",
    "brevskördarna": "brevskörd",
    "brevskördarnas": "brevskörd",
    "brevskördars": "brevskörd",
    "brevskörden": "brevskörd",
    "brevskördens": "brevskörd",
    "brevskörds": "brevskörd",
    "brevställar": "brevställare",
    "brevställaren": "brevställare",
    "brevställarens": "brevställare",
    "brevställares": "brevställare",
    "brevställarna": "brevställare",
    "brevställarnas": "brevställare",
    "brevställen": "brevställ",
    "brevställens": "brevställ",
    "brevstället": "brevställ",
    "brevställets": "brevställ",
    "brevställs": "brevställ",
    "brevsvaren": "brevsvar",
    "brevsvarens": "brevsvar",
    "brevsvaret": "brevsvar",
    "brevsvarets": "brevsvar",
    "brevsvars": "brevsvar",
    "brevtelegrammen": "brevtelegram",
    "brevtelegrammens": "brevtelegram",
    "brevtelegrammet": "brevtelegram",
    "brevtelegrammets": "brevtelegram",
    "brevtelegrams": "brevtelegram",
    "brevvännen": "brevvän",
    "brevvännens": "brevvän",
    "brevvänner": "brevvän",
    "brevvännerna": "brevvän",
    "brevvännernas": "brevvän",
    "brevvänners": "brevvän",
    "brevväns": "brevvän",
    "brevväxlad": "brevväxla",
    "brevväxlade": "brevväxla",
    "brevväxlades": "brevväxla",
    "brevväxlads": "brevväxla",
    "brevväxlande": "brevväxla",
    "brevväxlanden": "brevväxlande",
    "brevväxlandena": "brevväxlande",
    "brevväxlandenas": "brevväxlande",
    "brevväxlandens": "brevväxlande",
    "brevväxlandes": "brevväxlande",
    "brevväxlandet": "brevväxlande",
    "brevväxlandets": "brevväxlande",
    "brevväxlar": "brevväxla",
    "brevväxlas": "brevväxla",
    "brevväxlat": "brevväxla",
    "brevväxlats": "brevväxla",
    "brevväxlingar": "brevväxling",
    "brevväxlingarna": "brevväxling",
    "brevväxlingarnas": "brevväxling",
    "brevväxlingars": "brevväxling",
    "brevväxlingen": "brevväxling",
    "brevväxlingens": "brevväxling",
    "brevväxlings": "brevväxling",
    "brevvågar": "brevvåg",
    "brevvågarna": "brevvåg",
    "brevvågarnas": "brevvåg",
    "brevvågars": "brevvåg",
    "brevvågen": "brevvåg",
    "brevvågens": "brevvåg",
    "brevvågs": "brevvåg",
    "brevöppnar": "brevöppnare",
    "brevöppnaren": "brevöppnare",
    "brevöppnarens": "brevöppnare",
    "brevöppnares": "brevöppnare",
    "brevöppnarna": "brevöppnare",
    "brevöppnarnas": "brevöppnare",
    "brick": "bricka",
    "brickan": "bricka",
    "brickans": "bricka",
    "brickas": "bricka",
    "brickbanden": "brickband",
    "brickbandens": "brickband",
    "brickbandet": "brickband",
    "brickbandets": "brickband",
    "brickbands": "brickband",
    "brickborden": "brickbord",
    "brickbordens": "brickbord",
    "brickbordet": "brickbord",
    "brickbordets": "brickbord",
    "brickbords": "brickbord",
    "brickdukar": "brickduk",
    "brickdukarna": "brickduk",
    "brickdukarnas": "brickduk",
    "brickdukars": "brickduk",
    "brickduken": "brickduk",
    "brickdukens": "brickduk",
    "brickduks": "brickduk",
    "bricke": "bricka",
    "bricklunchen": "bricklunch",
    "bricklunchens": "bricklunch",
    "brickluncher": "bricklunch",
    "brickluncherna": "bricklunch",
    "bricklunchernas": "bricklunch",
    "bricklunchers": "bricklunch",
    "bricklunchs": "bricklunch",
    "brickor": "bricka",
    "brickorna": "bricka",
    "brickornas": "bricka",
    "brickors": "bricka",
    "brickplockar": "brickplockare",
    "brickplockaren": "brickplockare",
    "brickplockarens": "brickplockare",
    "brickplockares": "brickplockare",
    "brickplockarna": "brickplockare",
    "brickplockarnas": "brickplockare",
    "bricks": "bricka",
    "brickunderläggen": "brickunderlägg",
    "brickunderläggens": "brickunderlägg",
    "brickunderlägget": "brickunderlägg",
    "brickunderläggets": "brickunderlägg",
    "brickunderläggs": "brickunderlägg",
    "brickvävda": "brickvävd",
    "brickvävdare": "brickvävd",
    "brickvävdares": "brickvävd",
    "brickvävdas": "brickvävd",
    "brickvävdast": "brickvävd",
    "brickvävdaste": "brickvävd",
    "brickvävdastes": "brickvävd",
    "brickvävdasts": "brickvävd",
    "brickvävde": "brickvävd",
    "brickvävdes": "brickvävd",
    "brickvävds": "brickvävd",
    "brickvävningar": "brickvävning",
    "brickvävningarna": "brickvävning",
    "brickvävningarnas": "brickvävning",
    "brickvävningars": "brickvävning",
    "brickvävningen": "brickvävning",
    "brickvävningens": "brickvävning",
    "brickvävnings": "brickvävning",
    "brickvävt": "brickvävd",
    "brickvävts": "brickvävd",
    "bridgeborden": "bridgebord",
    "bridgebordens": "bridgebord",
    "bridgebordet": "bridgebord",
    "bridgebordets": "bridgebord",
    "bridgebords": "bridgebord",
    "bridgen": "bridge",
    "bridgens": "bridge",
    "bridges": "bridge",
    "bridongen": "bridong",
    "bridongens": "bridong",
    "bridonger": "bridong",
    "bridongerna": "bridong",
    "bridongernas": "bridong",
    "bridongers": "bridong",
    "bridongs": "bridong",
    "bridreaktorer": "bridreaktor",
    "bridreaktorerna": "bridreaktor",
    "bridreaktorernas": "bridreaktor",
    "bridreaktorers": "bridreaktor",
    "bridreaktorn": "bridreaktor",
    "bridreaktorns": "bridreaktor",
    "bridreaktors": "bridreaktor",
    "brief": "briefa",
    "briefad": "briefa",
    "briefade": "briefa",
    "briefades": "briefa",
    "briefads": "briefa",
    "briefande": "briefa",
    "briefanden": "briefande",
    "briefandena": "briefande",
    "briefandenas": "briefande",
    "briefandens": "briefande",
    "briefandes": "briefande",
    "briefandet": "briefande",
    "briefandets": "briefande",
    "briefar": "briefa",
    "briefas": "briefa",
    "briefat": "briefa",
    "briefats": "briefa",
    "brigaden": "brigad",
    "brigadens": "brigad",
    "brigader": "brigad",
    "brigaderna": "brigad",
    "brigadernas": "brigad",
    "brigaders": "brigad",
    "brigadgeneralen": "brigadgeneral",
    "brigadgeneralens": "brigadgeneral",
    "brigadgeneraler": "brigadgeneral",
    "brigadgeneralerna": "brigadgeneral",
    "brigadgeneralernas": "brigadgeneral",
    "brigadgeneralers": "brigadgeneral",
    "brigadgenerals": "brigadgeneral",
    "brigads": "brigad",
    "brigadören": "brigadör",
    "brigadörens": "brigadör",
    "brigadörer": "brigadör",
    "brigadörerna": "brigadör",
    "brigadörernas": "brigadör",
    "brigadörers": "brigadör",
    "brigadörn": "brigadör",
    "brigadörns": "brigadör",
    "brigadörs": "brigadör",
    "brigantinen": "brigantin",
    "brigantinens": "brigantin",
    "brigantiner": "brigantin",
    "brigantinerna": "brigantin",
    "brigantinernas": "brigantin",
    "brigantiners": "brigantin",
    "brigantins": "brigantin",
    "briggar": "brigg",
    "briggarna": "brigg",
    "briggarnas": "brigg",
    "briggars": "brigg",
    "briggen": "brigg",
    "briggens": "brigg",
    "briggs": "brigg",
    "briggsegels": "briggsegel",
    "briggseglen": "briggsegel",
    "briggseglens": "briggsegel",
    "briggseglet": "briggsegel",
    "briggseglets": "briggsegel",
    "briketten": "brikett",
    "brikettens": "brikett",
    "briketter": "brikett",
    "briketterad": "brikettera",
    "briketterade": "brikettera",
    "briketterades": "brikettera",
    "briketterads": "brikettera",
    "briketterande": "brikettera",
    "briketteranden": "briketterande",
    "briketterandena": "briketterande",
    "briketterandenas": "briketterande",
    "briketterandens": "briketterande",
    "briketterandes": "briketterande",
    "briketterandet": "briketterande",
    "briketterandets": "briketterande",
    "briketterar": "brikettera",
    "briketteras": "brikettera",
    "briketterat": "brikettera",
    "briketterats": "brikettera",
    "briketterbara": "briketterbar",
    "briketterbarare": "briketterbar",
    "briketterbarares": "briketterbar",
    "briketterbaras": "briketterbar",
    "briketterbarast": "briketterbar",
    "briketterbaraste": "briketterbar",
    "briketterbarastes": "briketterbar",
    "briketterbarasts": "briketterbar",
    "briketterbare": "briketterbar",
    "briketterbares": "briketterbar",
    "briketterbarheten": "briketterbarhet",
    "briketterbarhetens": "briketterbarhet",
    "briketterbarhets": "briketterbarhet",
    "briketterbars": "briketterbar",
    "briketterbart": "briketterbar",
    "briketterbarts": "briketterbar",
    "briketteringar": "brikettering",
    "briketteringarna": "brikettering",
    "briketteringarnas": "brikettering",
    "briketteringars": "brikettering",
    "briketteringen": "brikettering",
    "briketteringens": "brikettering",
    "briketterings": "brikettering",
    "briketterna": "brikett",
    "briketternas": "brikett",
    "briketters": "brikett",
    "brikettpressar": "brikettpress",
    "brikettpressarna": "brikettpress",
    "brikettpressarnas": "brikettpress",
    "brikettpressars": "brikettpress",
    "brikettpressen": "brikettpress",
    "brikettpressens": "brikettpress",
    "briketts": "brikett",
    "brikollstötar": "brikollstöt",
    "brikollstötarna": "brikollstöt",
    "brikollstötarnas": "brikollstöt",
    "brikollstötars": "brikollstöt",
    "brikollstöten": "brikollstöt",
    "brikollstötens": "brikollstöt",
    "brikollstöts": "brikollstöt",
    "briljansen": "briljans",
    "briljansens": "briljans",
    "briljanta": "briljant",
    "briljantare": "briljant",
    "briljantares": "briljant",
    "briljantas": "briljant",
    "briljantast": "briljant",
    "briljantaste": "briljant",
    "briljantastes": "briljant",
    "briljantasts": "briljant",
    "briljante": "briljant",
    "briljanten": "briljant",
    "briljantens": "briljant",
    "briljanter": "briljant",
    "briljanterade": "briljanterad",
    "briljanterades": "briljanterad",
    "briljanterads": "briljanterad",
    "briljanterat": "briljanterad",
    "briljanterats": "briljanterad",
    "briljanterna": "briljant",
    "briljanternas": "briljant",
    "briljanters": "briljant",
    "briljantes": "briljant",
    "briljantglaset": "briljantglas",
    "briljantglasets": "briljantglas",
    "briljantinen": "briljantin",
    "briljantinens": "briljantin",
    "briljantinet": "briljantin",
    "briljantinets": "briljantin",
    "briljantins": "briljantin",
    "briljants": "briljant",
    "briljerade": "briljera",
    "briljerades": "briljera",
    "briljerande": "briljera",
    "briljeranden": "briljerande",
    "briljerandena": "briljerande",
    "briljerandenas": "briljerande",
    "briljerandens": "briljerande",
    "briljerandes": "briljerande",
    "briljerandet": "briljerande",
    "briljerandets": "briljerande",
    "briljerar": "briljera",
    "briljeras": "briljera",
    "briljerat": "briljera",
    "briljerats": "briljera",
    "briljeringar": "briljering",
    "briljeringarna": "briljering",
    "briljeringarnas": "briljering",
    "briljeringars": "briljering",
    "briljeringen": "briljering",
    "briljeringens": "briljering",
    "briljerings": "briljering",
    "brill": "brillor",
    "brilliants": "brilliant",
    "brillorna": "brillor",
    "brillornas": "brillor",
    "brillors": "brillor",
    "brills": "brillor",
    "bring": "bringa",
    "bringad": "bringa",
    "bringade": "bringa",
    "bringades": "bringa",
    "bringads": "bringa",
    "bringan": "bringa",
    "bringande": "bringa",
    "bringanden": "bringande",
    "bringandena": "bringande",
    "bringandenas": "bringande",
    "bringandens": "bringande",
    "bringandes": "bringande",
    "bringandet": "bringande",
    "bringandets": "bringande",
    "bringans": "bringa",
    "bringar": "bringa",
    "bringas": "bringa",
    "bringat": "bringa",
    "bringats": "bringa",
    "bringe": "bringa",
    "bringor": "bringa",
    "bringorna": "bringa",
    "bringornas": "bringa",
    "bringors": "bringa",
    "brings": "bringa",
    "brinkar": "brink",
    "brinkarna": "brink",
    "brinkarnas": "brink",
    "brinkars": "brink",
    "brinken": "brink",
    "brinkens": "brink",
    "brinks": "brink",
    "brinn": "brinna",
    "brinnande": "brinna",
    "brinnanden": "brinnande",
    "brinnandena": "brinnande",
    "brinnandenas": "brinnande",
    "brinnandens": "brinnande",
    "brinnandes": "brinnande",
    "brinnandet": "brinnande",
    "brinnandets": "brinnande",
    "brinnas": "brinna",
    "brinne": "brinna",
    "brinner": "brinna",
    "brinnes": "brinna",
    "brinns": "brinna",
    "brinnsträck": "brinnsträcka",
    "brinnsträckan": "brinnsträcka",
    "brinnsträckans": "brinnsträcka",
    "brinnsträckas": "brinnsträcka",
    "brinnsträcke": "brinnsträcka",
    "brinnsträckor": "brinnsträcka",
    "brinnsträckorna": "brinnsträcka",
    "brinnsträckornas": "brinnsträcka",
    "brinnsträckors": "brinnsträcka",
    "brinnsträcks": "brinnsträcka",
    "brion": "brio",
    "brions": "brio",
    "brios": "brio",
    "brisaden": "brisad",
    "brisadens": "brisad",
    "brisader": "brisad",
    "brisaderna": "brisad",
    "brisadernas": "brisad",
    "brisaders": "brisad",
    "brisads": "brisad",
    "brisansen": "brisans",
    "brisansens": "brisans",
    "brisanser": "brisans",
    "brisanserna": "brisans",
    "brisansernas": "brisans",
    "brisansers": "brisans",
    "brisansgranaten": "brisansgranat",
    "brisansgranatens": "brisansgranat",
    "brisansgranater": "brisansgranat",
    "brisansgranaterna": "brisansgranat",
    "brisansgranaternas": "brisansgranat",
    "brisansgranaters": "brisansgranat",
    "brisansgranats": "brisansgranat",
    "brisanta": "brisant",
    "brisantare": "brisant",
    "brisantares": "brisant",
    "brisantas": "brisant",
    "brisantast": "brisant",
    "brisantaste": "brisant",
    "brisantastes": "brisant",
    "brisantasts": "brisant",
    "brisante": "brisant",
    "brisanten": "brisant",
    "brisantens": "brisant",
    "brisanter": "brisant",
    "brisanterna": "brisant",
    "brisanternas": "brisant",
    "brisanters": "brisant",
    "brisantes": "brisant",
    "brisants": "brisant",
    "brisar": "bris",
    "brisarna": "bris",
    "brisarnas": "bris",
    "brisars": "bris",
    "brisen": "bris",
    "brisens": "bris",
    "briser": "bris",
    "briserad": "brisera",
    "briserade": "brisera",
    "briserades": "brisera",
    "briserads": "brisera",
    "briserande": "brisera",
    "briseranden": "briserande",
    "briserandena": "briserande",
    "briserandenas": "briserande",
    "briserandens": "briserande",
    "briserandes": "briserande",
    "briserandet": "briserande",
    "briserandets": "briserande",
    "briserar": "brisera",
    "briseras": "brisera",
    "briserat": "brisera",
    "briserats": "brisera",
    "briserbara": "briserbar",
    "briserbarare": "briserbar",
    "briserbarares": "briserbar",
    "briserbaras": "briserbar",
    "briserbarast": "briserbar",
    "briserbaraste": "briserbar",
    "briserbarastes": "briserbar",
    "briserbarasts": "briserbar",
    "briserbare": "briserbar",
    "briserbares": "briserbar",
    "briserbarheten": "briserbarhet",
    "briserbarhetens": "briserbarhet",
    "briserbarhets": "briserbarhet",
    "briserbars": "briserbar",
    "briserbart": "briserbar",
    "briserbarts": "briserbar",
    "briseringar": "brisering",
    "briseringarna": "brisering",
    "briseringarnas": "brisering",
    "briseringars": "brisering",
    "briseringen": "brisering",
    "briseringens": "brisering",
    "briserings": "brisering",
    "briserna": "bris",
    "brisernas": "bris",
    "brisers": "bris",
    "briskenheten": "briskenhet",
    "briskenhetens": "briskenhet",
    "briskenhets": "briskenhet",
    "briskens": "brisken",
    "brisket": "brisken",
    "briskets": "brisken",
    "briskna": "brisken",
    "brisknare": "brisken",
    "brisknares": "brisken",
    "brisknas": "brisken",
    "brisknast": "brisken",
    "brisknaste": "brisken",
    "brisknastes": "brisken",
    "brisknasts": "brisken",
    "briskne": "brisken",
    "brisknes": "brisken",
    "brisslingar": "brissling",
    "brisslingarna": "brissling",
    "brisslingarnas": "brissling",
    "brisslingars": "brissling",
    "brisslingen": "brissling",
    "brisslingens": "brissling",
    "brisslings": "brissling",
    "brist": "brista",
    "bristande": "brista",
    "bristanden": "bristande",
    "bristandena": "bristande",
    "bristandenas": "bristande",
    "bristandens": "bristande",
    "bristandes": "bristande",
    "bristandet": "bristande",
    "bristandets": "bristande",
    "bristas": "brista",
    "briste": "brista",
    "bristen": "brist",
    "bristens": "brist",
    "brister": "brista",
    "bristerna": "brist",
    "bristernas": "brist",
    "bristers": "brist",
    "bristes": "brista",
    "bristfälliga": "bristfällig",
    "bristfälligare": "bristfällig",
    "bristfälligares": "bristfällig",
    "bristfälligas": "bristfällig",
    "bristfälligast": "bristfällig",
    "bristfälligaste": "bristfällig",
    "bristfälligastes": "bristfällig",
    "bristfälligasts": "bristfällig",
    "bristfällige": "bristfällig",
    "bristfälliges": "bristfällig",
    "bristfälligheten": "bristfällighet",
    "bristfällighetens": "bristfällighet",
    "bristfälligheter": "bristfällighet",
    "bristfälligheterna": "bristfällighet",
    "bristfälligheternas": "bristfällighet",
    "bristfälligheters": "bristfällighet",
    "bristfällighets": "bristfällighet",
    "bristfälligs": "bristfällig",
    "bristfälligt": "bristfällig",
    "bristfälligts": "bristfällig",
    "bristlägen": "bristläge",
    "bristlägena": "bristläge",
    "bristlägenas": "bristläge",
    "bristlägens": "bristläge",
    "bristläges": "bristläge",
    "bristläget": "bristläge",
    "bristlägets": "bristläge",
    "bristningar": "bristning",
    "bristningarna": "bristning",
    "bristningarnas": "bristning",
    "bristningars": "bristning",
    "bristningen": "bristning",
    "bristningens": "bristning",
    "bristnings": "bristning",
    "bristningsgränsen": "bristningsgräns",
    "bristningsgränsens": "bristningsgräns",
    "brists": "brista",
    "bristsituationen": "bristsituation",
    "bristsituationens": "bristsituation",
    "bristsituationer": "bristsituation",
    "bristsituationerna": "bristsituation",
    "bristsituationernas": "bristsituation",
    "bristsituationers": "bristsituation",
    "bristsituations": "bristsituation",
    "bristsjukdomar": "bristsjukdom",
    "bristsjukdomarna": "bristsjukdom",
    "bristsjukdomarnas": "bristsjukdom",
    "bristsjukdomars": "bristsjukdom",
    "bristsjukdomen": "bristsjukdom",
    "bristsjukdomens": "bristsjukdom",
    "bristsjukdoms": "bristsjukdom",
    "bristvar": "bristvara",
    "bristvaran": "bristvara",
    "bristvarans": "bristvara",
    "bristvaras": "bristvara",
    "bristvare": "bristvara",
    "bristvaror": "bristvara",
    "bristvarorna": "bristvara",
    "bristvarornas": "bristvara",
    "bristvarors": "bristvara",
    "bristvars": "bristvara",
    "bristyrken": "bristyrke",
    "bristyrkena": "bristyrke",
    "bristyrkenas": "bristyrke",
    "bristyrkens": "bristyrke",
    "bristyrkes": "bristyrke",
    "bristyrket": "bristyrke",
    "bristyrkets": "bristyrke",
    "britanniametallen": "britanniametall",
    "britanniametallens": "britanniametall",
    "britanniametalls": "britanniametall",
    "britanniska": "britannisk",
    "britanniskare": "britannisk",
    "britanniskares": "britannisk",
    "britanniskas": "britannisk",
    "britanniskast": "britannisk",
    "britanniskaste": "britannisk",
    "britanniskastes": "britannisk",
    "britanniskasts": "britannisk",
    "britanniske": "britannisk",
    "britanniskes": "britannisk",
    "britannisks": "britannisk",
    "britanniskt": "britannisk",
    "britanniskts": "britannisk",
    "britsar": "brits",
    "britsarna": "brits",
    "britsarnas": "brits",
    "britsars": "brits",
    "britsen": "brits",
    "britsens": "brits",
    "britten": "britt",
    "brittens": "britt",
    "britter": "britt",
    "britterna": "britt",
    "britternas": "britt",
    "britters": "britt",
    "brittiska": "brittisk",
    "brittiskan": "brittiska",
    "brittiskans": "brittiska",
    "brittiskare": "brittisk",
    "brittiskares": "brittisk",
    "brittiskas": "brittiska",
    "brittiskast": "brittisk",
    "brittiskaste": "brittisk",
    "brittiskastes": "brittisk",
    "brittiskasts": "brittisk",
    "brittiske": "brittiska",
    "brittiskes": "brittisk",
    "brittiskor": "brittiska",
    "brittiskorna": "brittiska",
    "brittiskornas": "brittiska",
    "brittiskors": "brittiska",
    "brittisks": "brittisk",
    "brittiskt": "brittisk",
    "brittiskts": "brittisk",
    "brittmäss": "brittmässa",
    "brittmässan": "brittmässa",
    "brittmässans": "brittmässa",
    "brittmässas": "brittmässa",
    "brittmässe": "brittmässa",
    "brittmässor": "brittmässa",
    "brittmässorna": "brittmässa",
    "brittmässornas": "brittmässa",
    "brittmässors": "brittmässa",
    "britts": "britt",
    "brittsommaren": "brittsommar",
    "brittsommarens": "brittsommar",
    "brittsommarn": "brittsommar",
    "brittsommarns": "brittsommar",
    "brittsommars": "brittsommar",
    "brittsommarväderna": "brittsommarväder",
    "brittsommarvädernas": "brittsommarväder",
    "brittsommarväders": "brittsommarväder",
    "brittsommarvädren": "brittsommarväder",
    "brittsommarvädrens": "brittsommarväder",
    "brittsommarvädret": "brittsommarväder",
    "brittsommarvädrets": "brittsommarväder",
    "brittsomrar": "brittsommar",
    "brittsomrarna": "brittsommar",
    "brittsomrarnas": "brittsommar",
    "brittsomrars": "brittsommar",
    "bro": "broa",
    "broad": "broa",
    "broade": "broa",
    "broades": "broa",
    "broads": "broa",
    "broande": "broa",
    "broanden": "broande",
    "broandena": "broande",
    "broandenas": "broande",
    "broandens": "broande",
    "broandes": "broande",
    "broandet": "broande",
    "broandets": "broande",
    "broar": "broa",
    "broarna": "bro",
    "broarnas": "bro",
    "broars": "bro",
    "broas": "broa",
    "broat": "broa",
    "broats": "broa",
    "broavgiften": "broavgift",
    "broavgiftens": "broavgift",
    "broavgifter": "broavgift",
    "broavgifterna": "broavgift",
    "broavgifternas": "broavgift",
    "broavgifters": "broavgift",
    "broavgifts": "broavgift",
    "brobanan": "brobana",
    "brobanans": "brobana",
    "brobanas": "brobana",
    "brobane": "brobana",
    "brobanor": "brobana",
    "brobanorna": "brobana",
    "brobanornas": "brobana",
    "brobanors": "brobana",
    "brobelastningar": "brobelastning",
    "brobelastningarna": "brobelastning",
    "brobelastningarnas": "brobelastning",
    "brobelastningars": "brobelastning",
    "brobelastningen": "brobelastning",
    "brobelastningens": "brobelastning",
    "brobelastnings": "brobelastning",
    "brobänkar": "brobänk",
    "brobänkarna": "brobänk",
    "brobänkarnas": "brobänk",
    "brobänkars": "brobänk",
    "brobänken": "brobänk",
    "brobänkens": "brobänk",
    "brobänks": "brobänk",
    "broccolin": "broccoli",
    "broccolins": "broccoli",
    "broccolis": "broccoli",
    "brockar": "brock",
    "brockarna": "brock",
    "brockarnas": "brock",
    "brockars": "brock",
    "brockbanden": "brockband",
    "brockbandens": "brockband",
    "brockbandet": "brockband",
    "brockbandets": "brockband",
    "brockbands": "brockband",
    "brocken": "brock",
    "brockens": "brock",
    "brocket": "brock",
    "brockets": "brock",
    "brockfågeln": "brockfågel",
    "brockfågelns": "brockfågel",
    "brockfågels": "brockfågel",
    "brockfåglar": "brockfågel",
    "brockfåglarna": "brockfågel",
    "brockfåglarnas": "brockfågel",
    "brockfåglars": "brockfågel",
    "brocks": "brock",
    "brodd": "brodda",
    "broddad": "brodda",
    "broddade": "brodda",
    "broddades": "brodda",
    "broddads": "brodda",
    "broddande": "brodda",
    "broddanden": "broddande",
    "broddandena": "broddande",
    "broddandenas": "broddande",
    "broddandens": "broddande",
    "broddandes": "broddande",
    "broddandet": "broddande",
    "broddandets": "broddande",
    "broddar": "brodda",
    "broddarna": "brodd",
    "broddarnas": "brodd",
    "broddars": "brodd",
    "broddas": "brodda",
    "broddat": "brodda",
    "broddats": "brodda",
    "brodden": "brodd",
    "broddens": "brodd",
    "brodds": "brodd",
    "broderad": "brodera",
    "broderade": "brodera",
    "broderades": "brodera",
    "broderads": "brodera",
    "broderande": "brodera",
    "broderanden": "broderande",
    "broderandena": "broderande",
    "broderandenas": "broderande",
    "broderandens": "broderande",
    "broderandes": "broderande",
    "broderandet": "broderande",
    "broderandets": "broderande",
    "broderar": "brodera",
    "broderas": "brodera",
    "broderat": "brodera",
    "broderats": "brodera",
    "broderbara": "broderbar",
    "broderbarare": "broderbar",
    "broderbarares": "broderbar",
    "broderbaras": "broderbar",
    "broderbarast": "broderbar",
    "broderbaraste": "broderbar",
    "broderbarastes": "broderbar",
    "broderbarasts": "broderbar",
    "broderbare": "broderbar",
    "broderbares": "broderbar",
    "broderbarheten": "broderbarhet",
    "broderbarhetens": "broderbarhet",
    "broderbarhets": "broderbarhet",
    "broderbars": "broderbar",
    "broderbart": "broderbar",
    "broderbarts": "broderbar",
    "broderboken": "broderbok",
    "broderbokens": "broderbok",
    "broderboks": "broderbok",
    "broderbåg": "broderbåge",
    "broderbågar": "broderbåge",
    "broderbågarna": "broderbåge",
    "broderbågarnas": "broderbåge",
    "broderbågars": "broderbåge",
    "broderbågen": "broderbåge",
    "broderbågens": "broderbåge",
    "broderbåges": "broderbåge",
    "broderbågs": "broderbåge",
    "broderböcker": "broderbok",
    "broderböckerna": "broderbok",
    "broderböckernas": "broderbok",
    "broderböckers": "broderbok",
    "broderfolken": "broderfolk",
    "broderfolkens": "broderfolk",
    "broderfolket": "broderfolk",
    "broderfolkets": "broderfolk",
    "broderfolks": "broderfolk",
    "brodergarnet": "brodergarn",
    "brodergarnets": "brodergarn",
    "brodergarns": "brodergarn",
    "broderier": "broderi",
    "broderierna": "broderi",
    "broderiernas": "broderi",
    "broderiers": "broderi",
    "broderiet": "broderi",
    "broderiets": "broderi",
    "broderingar": "brodering",
    "broderingarna": "brodering",
    "broderingarnas": "brodering",
    "broderingars": "brodering",
    "broderingen": "brodering",
    "broderingens": "brodering",
    "broderings": "brodering",
    "broderis": "broderi",
    "broderit": "broderi",
    "broderits": "broderi",
    "broderlandet": "broderland",
    "broderlandets": "broderland",
    "broderlands": "broderland",
    "broderliga": "broderlig",
    "broderligare": "broderlig",
    "broderligares": "broderlig",
    "broderligas": "broderlig",
    "broderligast": "broderlig",
    "broderligaste": "broderlig",
    "broderligastes": "broderlig",
    "broderligasts": "broderlig",
    "broderlige": "broderlig",
    "broderliges": "broderlig",
    "broderligheten": "broderlighet",
    "broderlighetens": "broderlighet",
    "broderlighets": "broderlighet",
    "broderligs": "broderlig",
    "broderligt": "broderlig",
    "broderligts": "broderlig",
    "broderländer": "broderland",
    "broderländerna": "broderland",
    "broderländernas": "broderland",
    "broderländers": "broderland",
    "brodern": "bror",
    "broderns": "bror",
    "brodernålar": "brodernål",
    "brodernålarna": "brodernål",
    "brodernålarnas": "brodernål",
    "brodernålars": "brodernål",
    "brodernålen": "brodernål",
    "brodernålens": "brodernål",
    "brodernåls": "brodernål",
    "broders": "broder",
    "brodersaxar": "brodersax",
    "brodersaxarna": "brodersax",
    "brodersaxarnas": "brodersax",
    "brodersaxars": "brodersax",
    "brodersaxen": "brodersax",
    "brodersaxens": "brodersax",
    "brodersilkes": "brodersilke",
    "brodersilket": "brodersilke",
    "brodersilkets": "brodersilke",
    "broderskapen": "broderskap",
    "broderskapens": "broderskap",
    "broderskapet": "broderskap",
    "broderskapets": "broderskap",
    "broderskaps": "broderskap",
    "broderskärlekar": "broderskärlek",
    "broderskärlekarna": "broderskärlek",
    "broderskärlekarnas": "broderskärlek",
    "broderskärlekars": "broderskärlek",
    "broderskärleken": "broderskärlek",
    "broderskärlekens": "broderskärlek",
    "broderskärleks": "broderskärlek",
    "brodersömmar": "brodersöm",
    "brodersömmarna": "brodersöm",
    "brodersömmarnas": "brodersöm",
    "brodersömmars": "brodersöm",
    "brodersömmen": "brodersöm",
    "brodersömmens": "brodersöm",
    "brodersöms": "brodersöm",
    "brodyren": "brodyr",
    "brodyrens": "brodyr",
    "brodyrer": "brodyr",
    "brodyrerna": "brodyr",
    "brodyrernas": "brodyr",
    "brodyrers": "brodyr",
    "brodyrs": "brodyr",
    "brofäst": "brofäste",
    "brofästen": "brofäste",
    "brofästena": "brofäste",
    "brofästenas": "brofäste",
    "brofästens": "brofäste",
    "brofästes": "brofäste",
    "brofästet": "brofäste",
    "brofästets": "brofäste",
    "brohusen": "brohus",
    "brohusens": "brohus",
    "brohuset": "brohus",
    "brohusets": "brohus",
    "brohuvuden": "brohuvud",
    "brohuvudena": "brohuvud",
    "brohuvudenas": "brohuvud",
    "brohuvudens": "brohuvud",
    "brohuvudet": "brohuvud",
    "brohuvudets": "brohuvud",
    "brohuvuds": "brohuvud",
    "broilern": "broiler",
    "broilerns": "broiler",
    "broilers": "broiler",
    "broilersarna": "broiler",
    "broilersarnas": "broiler",
    "broilersen": "broiler",
    "broilersens": "broiler",
    "broilrar": "broiler",
    "broilrarna": "broiler",
    "broilrarnas": "broiler",
    "broilrars": "broiler",
    "brokaden": "brokad",
    "brokadens": "brokad",
    "brokader": "brokad",
    "brokaderna": "brokad",
    "brokadernas": "brokad",
    "brokaders": "brokad",
    "brokads": "brokad",
    "brokanalen": "brokanal",
    "brokanalens": "brokanal",
    "brokanaler": "brokanal",
    "brokanalerna": "brokanal",
    "brokanalernas": "brokanal",
    "brokanalers": "brokanal",
    "brokanals": "brokanal",
    "brokar": "brok",
    "brokaren": "brokar",
    "brokarens": "brokar",
    "brokaret": "brokar",
    "brokarets": "brokar",
    "brokarna": "brok",
    "brokarnas": "brok",
    "brokars": "brokar",
    "brokbladiga": "brokbladig",
    "brokbladigare": "brokbladig",
    "brokbladigares": "brokbladig",
    "brokbladigas": "brokbladig",
    "brokbladigast": "brokbladig",
    "brokbladigaste": "brokbladig",
    "brokbladigastes": "brokbladig",
    "brokbladigasts": "brokbladig",
    "brokbladige": "brokbladig",
    "brokbladiges": "brokbladig",
    "brokbladigheten": "brokbladighet",
    "brokbladighetens": "brokbladighet",
    "brokbladighets": "brokbladighet",
    "brokbladigs": "brokbladig",
    "brokbladigt": "brokbladig",
    "brokbladigts": "brokbladig",
    "brokblommiga": "brokblommig",
    "brokblommigare": "brokblommig",
    "brokblommigares": "brokblommig",
    "brokblommigas": "brokblommig",
    "brokblommigast": "brokblommig",
    "brokblommigaste": "brokblommig",
    "brokblommigastes": "brokblommig",
    "brokblommigasts": "brokblommig",
    "brokblommige": "brokblommig",
    "brokblommiges": "brokblommig",
    "brokblommigheten": "brokblommighet",
    "brokblommighetens": "brokblommighet",
    "brokblommighets": "brokblommighet",
    "brokblommigs": "brokblommig",
    "brokblommigt": "brokblommig",
    "brokblommigts": "brokblommig",
    "broken": "brok",
    "brokens": "brok",
    "brokiga": "brokig",
    "brokigare": "brokig",
    "brokigares": "brokig",
    "brokigas": "brokig",
    "brokigast": "brokig",
    "brokigaste": "brokig",
    "brokigastes": "brokig",
    "brokigasts": "brokig",
    "brokige": "brokig",
    "brokiges": "brokig",
    "brokigheten": "brokighet",
    "brokighetens": "brokighet",
    "brokigheter": "brokighet",
    "brokigheterna": "brokighet",
    "brokigheternas": "brokighet",
    "brokigheters": "brokighet",
    "brokighets": "brokighet",
    "brokigs": "brokig",
    "brokigt": "brokig",
    "brokigts": "brokig",
    "brokist": "brokista",
    "brokistan": "brokista",
    "brokistans": "brokista",
    "brokistas": "brokista",
    "brokiste": "brokista",
    "brokistor": "brokista",
    "brokistorna": "brokista",
    "brokistornas": "brokista",
    "brokistors": "brokista",
    "broks": "brok",
    "brokspettar": "brokspett",
    "brokspettarna": "brokspett",
    "brokspettarnas": "brokspett",
    "brokspettars": "brokspett",
    "brokspetten": "brokspett",
    "brokspettens": "brokspett",
    "brokspetts": "brokspett",
    "brola": "brolägga",
    "brolade": "brolägga",
    "brolades": "brolägga",
    "brolagd": "brolägga",
    "brolagda": "brolägga",
    "brolagdas": "brolägga",
    "brolagde": "brolägga",
    "brolagdes": "brolägga",
    "brolagds": "brolägga",
    "brolagt": "brolägga",
    "brolagts": "brolägga",
    "brolas": "brolägga",
    "brollan": "brolla",
    "brollans": "brolla",
    "brollas": "brolla",
    "brollor": "brolla",
    "brollorna": "brolla",
    "brollornas": "brolla",
    "brollors": "brolla",
    "broloppen": "brolopp",
    "broloppens": "brolopp",
    "broloppet": "brolopp",
    "broloppets": "brolopp",
    "brolopps": "brolopp",
    "brolägg": "brolägga",
    "broläggande": "brolägga",
    "brolägganden": "broläggande",
    "broläggandena": "broläggande",
    "broläggandenas": "broläggande",
    "broläggandens": "broläggande",
    "broläggandes": "broläggande",
    "broläggandet": "broläggande",
    "broläggandets": "broläggande",
    "broläggas": "brolägga",
    "brolägger": "brolägga",
    "brolägges": "brolägga",
    "broläggs": "brolägga",
    "bromelian": "bromelia",
    "bromelias": "bromelia",
    "bromeliorna": "bromelia",
    "bromeliors": "bromelia",
    "bromen": "brom",
    "bromens": "brom",
    "bromerad": "bromera",
    "bromerade": "bromera",
    "bromerades": "bromera",
    "bromerads": "bromera",
    "bromerande": "bromera",
    "bromeranden": "bromerande",
    "bromerandena": "bromerande",
    "bromerandenas": "bromerande",
    "bromerandens": "bromerande",
    "bromerandes": "bromerande",
    "bromerandet": "bromerande",
    "bromerandets": "bromerande",
    "bromerar": "bromera",
    "bromeras": "bromera",
    "bromerat": "bromera",
    "bromerats": "bromera",
    "bromerbara": "bromerbar",
    "bromerbarare": "bromerbar",
    "bromerbarares": "bromerbar",
    "bromerbaras": "bromerbar",
    "bromerbarast": "bromerbar",
    "bromerbaraste": "bromerbar",
    "bromerbarastes": "bromerbar",
    "bromerbarasts": "bromerbar",
    "bromerbare": "bromerbar",
    "bromerbares": "bromerbar",
    "bromerbarheten": "bromerbarhet",
    "bromerbarhetens": "bromerbarhet",
    "bromerbarhets": "bromerbarhet",
    "bromerbars": "bromerbar",
    "bromerbart": "bromerbar",
    "bromerbarts": "bromerbar",
    "bromeringar": "bromering",
    "bromeringarna": "bromering",
    "bromeringarnas": "bromering",
    "bromeringars": "bromering",
    "bromeringen": "bromering",
    "bromeringens": "bromering",
    "bromerings": "bromering",
    "bromförgiftningar": "bromförgiftning",
    "bromförgiftningarna": "bromförgiftning",
    "bromförgiftningarnas": "bromförgiftning",
    "bromförgiftningars": "bromförgiftning",
    "bromförgiftningen": "bromförgiftning",
    "bromförgiftningens": "bromförgiftning",
    "bromförgiftnings": "bromförgiftning",
    "bromiden": "bromid",
    "bromidens": "bromid",
    "bromider": "bromid",
    "bromiderna": "bromid",
    "bromidernas": "bromid",
    "bromiders": "bromid",
    "bromids": "bromid",
    "bromismen": "bromism",
    "bromismens": "bromism",
    "bromismer": "bromism",
    "bromismerna": "bromism",
    "bromismernas": "bromism",
    "bromismers": "bromism",
    "bromisms": "bromism",
    "broms": "bromsa",
    "bromsad": "bromsa",
    "bromsade": "bromsa",
    "bromsades": "bromsa",
    "bromsads": "bromsa",
    "bromsande": "bromsa",
    "bromsanden": "bromsande",
    "bromsandena": "bromsande",
    "bromsandenas": "bromsande",
    "bromsandens": "bromsande",
    "bromsandes": "bromsande",
    "bromsandet": "bromsande",
    "bromsandets": "bromsande",
    "bromsar": "bromsare",
    "bromsaren": "bromsare",
    "bromsarens": "bromsare",
    "bromsares": "bromsare",
    "bromsarna": "bromsare",
    "bromsarnas": "bromsare",
    "bromsars": "broms",
    "bromsas": "bromsa",
    "bromsat": "bromsa",
    "bromsats": "bromsa",
    "bromsbackar": "bromsback",
    "bromsbackarna": "bromsback",
    "bromsbackarnas": "bromsback",
    "bromsbackars": "bromsback",
    "bromsbacken": "bromsback",
    "bromsbackens": "bromsback",
    "bromsbacks": "bromsback",
    "bromsbanden": "bromsband",
    "bromsbandens": "bromsband",
    "bromsbandet": "bromsband",
    "bromsbandets": "bromsband",
    "bromsbands": "bromsband",
    "bromsbeläggen": "bromsbelägg",
    "bromsbeläggens": "bromsbelägg",
    "bromsbelägget": "bromsbelägg",
    "bromsbeläggets": "bromsbelägg",
    "bromsbeläggs": "bromsbelägg",
    "bromsblocken": "bromsblock",
    "bromsblockens": "bromsblock",
    "bromsblocket": "bromsblock",
    "bromsblockets": "bromsblock",
    "bromsblocks": "bromsblock",
    "bromscylindern": "bromscylinder",
    "bromscylinderns": "bromscylinder",
    "bromscylinders": "bromscylinder",
    "bromscylindrar": "bromscylinder",
    "bromscylindrarna": "bromscylinder",
    "bromscylindrarnas": "bromscylinder",
    "bromscylindrars": "bromscylinder",
    "bromsen": "broms",
    "bromsens": "broms",
    "bromsfadingar": "bromsfading",
    "bromsfadingarna": "bromsfading",
    "bromsfadingarnas": "bromsfading",
    "bromsfadingars": "bromsfading",
    "bromsfadingen": "bromsfading",
    "bromsfadingens": "bromsfading",
    "bromsfadings": "bromsfading",
    "bromsfelen": "bromsfel",
    "bromsfelens": "bromsfel",
    "bromsfelet": "bromsfel",
    "bromsfelets": "bromsfel",
    "bromsfels": "bromsfel",
    "bromsgallerna": "bromsgaller",
    "bromsgallernas": "bromsgaller",
    "bromsgallers": "bromsgaller",
    "bromsgallren": "bromsgaller",
    "bromsgallrens": "bromsgaller",
    "bromsgallret": "bromsgaller",
    "bromsgallrets": "bromsgaller",
    "bromshandtagen": "bromshandtag",
    "bromshandtagens": "bromshandtag",
    "bromshandtaget": "bromshandtag",
    "bromshandtagets": "bromshandtag",
    "bromshandtags": "bromshandtag",
    "bromsilverpapperen": "bromsilverpapper",
    "bromsilverpapperens": "bromsilverpapper",
    "bromsilverpapperet": "bromsilverpapper",
    "bromsilverpapperets": "bromsilverpapper",
    "bromsilverpapperna": "bromsilverpapper",
    "bromsilverpappernas": "bromsilverpapper",
    "bromsilverpappers": "bromsilverpapper",
    "bromsilverpappren": "bromsilverpapper",
    "bromsilverpapprens": "bromsilverpapper",
    "bromsilverpappret": "bromsilverpapper",
    "bromsilverpapprets": "bromsilverpapper",
    "bromsklaffar": "bromsklaff",
    "bromsklaffarna": "bromsklaff",
    "bromsklaffarnas": "bromsklaff",
    "bromsklaffars": "bromsklaff",
    "bromsklaffen": "bromsklaff",
    "bromsklaffens": "bromsklaff",
    "bromsklaffs": "bromsklaff",
    "bromsklossar": "bromskloss",
    "bromsklossarna": "bromskloss",
    "bromsklossarnas": "bromskloss",
    "bromsklossars": "bromskloss",
    "bromsklossen": "bromskloss",
    "bromsklossens": "bromskloss",
    "bromskraften": "bromskraft",
    "bromskraftens": "bromskraft",
    "bromskrafts": "bromskraft",
    "bromsljusen": "bromsljus",
    "bromsljusens": "bromsljus",
    "bromsljuset": "bromsljus",
    "bromsljusets": "bromsljus",
    "bromsmedicinen": "bromsmedicin",
    "bromsmedicinens": "bromsmedicin",
    "bromsmediciner": "bromsmedicin",
    "bromsmedicinerna": "bromsmedicin",
    "bromsmedicinernas": "bromsmedicin",
    "bromsmediciners": "bromsmedicin",
    "bromsmedicins": "bromsmedicin",
    "bromsningar": "bromsning",
    "bromsningarna": "bromsning",
    "bromsningarnas": "bromsning",
    "bromsningars": "bromsning",
    "bromsningen": "bromsning",
    "bromsningens": "bromsning",
    "bromsnings": "bromsning",
    "bromsoljan": "bromsolja",
    "bromsoljans": "bromsolja",
    "bromsoljas": "bromsolja",
    "bromsolje": "bromsolja",
    "bromsoljor": "bromsolja",
    "bromsoljorna": "bromsolja",
    "bromsoljornas": "bromsolja",
    "bromsoljors": "bromsolja",
    "bromspedalen": "bromspedal",
    "bromspedalens": "bromspedal",
    "bromspedaler": "bromspedal",
    "bromspedalerna": "bromspedal",
    "bromspedalernas": "bromspedal",
    "bromspedalers": "bromspedal",
    "bromspedals": "bromspedal",
    "bromsraketen": "bromsraket",
    "bromsraketens": "bromsraket",
    "bromsraketer": "bromsraket",
    "bromsraketerna": "bromsraket",
    "bromsraketernas": "bromsraket",
    "bromsraketers": "bromsraket",
    "bromsrakets": "bromsraket",
    "bromsservon": "bromsservo",
    "bromsservons": "bromsservo",
    "bromsservos": "bromsservo",
    "bromsskivan": "bromsskiva",
    "bromsskivans": "bromsskiva",
    "bromsskivas": "bromsskiva",
    "bromsskive": "bromsskiva",
    "bromsskivor": "bromsskiva",
    "bromsskivorna": "bromsskiva",
    "bromsskivornas": "bromsskiva",
    "bromsskivors": "bromsskiva",
    "bromsskon": "bromssko",
    "bromsskons": "bromssko",
    "bromsskor": "bromssko",
    "bromsskorna": "bromssko",
    "bromsskornas": "bromssko",
    "bromsskors": "bromssko",
    "bromsskos": "bromssko",
    "bromsskärmar": "bromsskärm",
    "bromsskärmarna": "bromsskärm",
    "bromsskärmarnas": "bromsskärm",
    "bromsskärmars": "bromsskärm",
    "bromsskärmen": "bromsskärm",
    "bromsskärmens": "bromsskärm",
    "bromsskärms": "bromsskärm",
    "bromsspåren": "bromsspår",
    "bromsspårens": "bromsspår",
    "bromsspåret": "bromsspår",
    "bromsspårets": "bromsspår",
    "bromsspårs": "bromsspår",
    "bromssträck": "bromssträcka",
    "bromssträckan": "bromssträcka",
    "bromssträckans": "bromssträcka",
    "bromssträckas": "bromssträcka",
    "bromssträcke": "bromssträcka",
    "bromssträckor": "bromssträcka",
    "bromssträckorna": "bromssträcka",
    "bromssträckornas": "bromssträcka",
    "bromssträckors": "bromssträcka",
    "bromssträcks": "bromssträcka",
    "bromsstrålningar": "bromsstrålning",
    "bromsstrålningarna": "bromsstrålning",
    "bromsstrålningarnas": "bromsstrålning",
    "bromsstrålningars": "bromsstrålning",
    "bromsstrålningen": "bromsstrålning",
    "bromsstrålningens": "bromsstrålning",
    "bromsstrålnings": "bromsstrålning",
    "bromssystemen": "bromssystem",
    "bromssystemens": "bromssystem",
    "bromssystemet": "bromssystem",
    "bromssystemets": "bromssystem",
    "bromssystems": "bromssystem",
    "bromstrum": "bromstrumma",
    "bromstrumman": "bromstrumma",
    "bromstrummans": "bromstrumma",
    "bromstrummas": "bromstrumma",
    "bromstrumme": "bromstrumma",
    "bromstrummor": "bromstrumma",
    "bromstrummorna": "bromstrumma",
    "bromstrummornas": "bromstrumma",
    "bromstrummors": "bromstrumma",
    "bromstrums": "bromstrumma",
    "bromsvagnar": "bromsvagn",
    "bromsvagnarna": "bromsvagn",
    "bromsvagnarnas": "bromsvagn",
    "bromsvagnars": "bromsvagn",
    "bromsvagnen": "bromsvagn",
    "bromsvagnens": "bromsvagn",
    "bromsvagns": "bromsvagn",
    "bromsverkans": "bromsverkan",
    "bromsvätskan": "bromsvätska",
    "bromsvätskans": "bromsvätska",
    "bromsvätskas": "bromsvätska",
    "bromsvätske": "bromsvätska",
    "bromsvätskor": "bromsvätska",
    "bromsvätskorna": "bromsvätska",
    "bromsvätskornas": "bromsvätska",
    "bromsvätskors": "bromsvätska",
    "bromtymolblåtts": "bromtymolblått",
    "bromuralet": "bromural",
    "bromuralets": "bromural",
    "bromurals": "bromural",
    "bromvätes": "bromväte",
    "bromvätesyran": "bromvätesyra",
    "bromvätesyrans": "bromvätesyra",
    "bromvätesyras": "bromvätesyra",
    "bromvätesyre": "bromvätesyra",
    "bromvätesyror": "bromvätesyra",
    "bromvätesyrorna": "bromvätesyra",
    "bromvätesyrornas": "bromvätesyra",
    "bromvätesyrors": "bromvätesyra",
    "bromvätet": "bromväte",
    "bromvätets": "bromväte",
    "bromylen": "bromyl",
    "bromylens": "bromyl",
    "bromyls": "bromyl",
    "bron": "bro",
    "bronk": "bronker",
    "bronkerna": "bronker",
    "bronkernas": "bronker",
    "bronkers": "bronker",
    "bronkialastman": "bronkialastma",
    "bronkialastmans": "bronkialastma",
    "bronkialastmas": "bronkialastma",
    "bronkiten": "bronkit",
    "bronkitens": "bronkit",
    "bronkiter": "bronkit",
    "bronkiterna": "bronkit",
    "bronkiternas": "bronkit",
    "bronkiters": "bronkit",
    "bronkits": "bronkit",
    "bronkografien": "bronkografi",
    "bronkografiens": "bronkografi",
    "bronkografier": "bronkografi",
    "bronkografierna": "bronkografi",
    "bronkografiernas": "bronkografi",
    "bronkografiers": "bronkografi",
    "bronkografin": "bronkografi",
    "bronkografins": "bronkografi",
    "bronkografis": "bronkografi",
    "bronkoskopen": "bronkoskop",
    "bronkoskopens": "bronkoskop",
    "bronkoskopet": "bronkoskop",
    "bronkoskopets": "bronkoskop",
    "bronkoskopien": "bronkoskopi",
    "bronkoskopiens": "bronkoskopi",
    "bronkoskopier": "bronkoskopi",
    "bronkoskopierna": "bronkoskopi",
    "bronkoskopiernas": "bronkoskopi",
    "bronkoskopiers": "bronkoskopi",
    "bronkoskopin": "bronkoskopi",
    "bronkoskopins": "bronkoskopi",
    "bronkoskopis": "bronkoskopi",
    "bronkoskops": "bronkoskop",
    "bronks": "bronker",
    "brons": "bro",
    "bronsborst": "bronsborste",
    "bronsborstar": "bronsborste",
    "bronsborstarna": "bronsborste",
    "bronsborstarnas": "bronsborste",
    "bronsborstars": "bronsborste",
    "bronsborsten": "bronsborste",
    "bronsborstens": "bronsborste",
    "bronsborstes": "bronsborste",
    "bronsen": "brons",
    "bronsens": "brons",
    "bronser": "brons",
    "bronserad": "bronsera",
    "bronserade": "bronsera",
    "bronserades": "bronsera",
    "bronserads": "bronsera",
    "bronserande": "bronsera",
    "bronseranden": "bronserande",
    "bronserandena": "bronserande",
    "bronserandenas": "bronserande",
    "bronserandens": "bronserande",
    "bronserandes": "bronserande",
    "bronserandet": "bronserande",
    "bronserandets": "bronserande",
    "bronserar": "bronsera",
    "bronseras": "bronsera",
    "bronserat": "bronsera",
    "bronserats": "bronsera",
    "bronserbara": "bronserbar",
    "bronserbarare": "bronserbar",
    "bronserbarares": "bronserbar",
    "bronserbaras": "bronserbar",
    "bronserbarast": "bronserbar",
    "bronserbaraste": "bronserbar",
    "bronserbarastes": "bronserbar",
    "bronserbarasts": "bronserbar",
    "bronserbare": "bronserbar",
    "bronserbares": "bronserbar",
    "bronserbarheten": "bronserbarhet",
    "bronserbarhetens": "bronserbarhet",
    "bronserbarhets": "bronserbarhet",
    "bronserbars": "bronserbar",
    "bronserbart": "bronserbar",
    "bronserbarts": "bronserbar",
    "bronseringar": "bronsering",
    "bronseringarna": "bronsering",
    "bronseringarnas": "bronsering",
    "bronseringars": "bronsering",
    "bronseringen": "bronsering",
    "bronseringens": "bronsering",
    "bronserings": "bronsering",
    "bronserna": "brons",
    "bronsernas": "brons",
    "bronsers": "brons",
    "bronset": "brons",
    "bronsets": "brons",
    "bronsfärgade": "bronsfärgad",
    "bronsfärgades": "bronsfärgad",
    "bronsfärgads": "bronsfärgad",
    "bronsfärgat": "bronsfärgad",
    "bronsfärgats": "bronsfärgad",
    "bronsfärgen": "bronsfärg",
    "bronsfärgens": "bronsfärg",
    "bronsfärgs": "bronsfärg",
    "bronsförgyll": "bronsförgylla",
    "bronsförgyllande": "bronsförgylla",
    "bronsförgyllanden": "bronsförgyllande",
    "bronsförgyllandena": "bronsförgyllande",
    "bronsförgyllandenas": "bronsförgyllande",
    "bronsförgyllandens": "bronsförgyllande",
    "bronsförgyllandes": "bronsförgyllande",
    "bronsförgyllandet": "bronsförgyllande",
    "bronsförgyllandets": "bronsförgyllande",
    "bronsförgyllas": "bronsförgylla",
    "bronsförgylld": "bronsförgylla",
    "bronsförgyllda": "bronsförgylla",
    "bronsförgylldas": "bronsförgylla",
    "bronsförgyllde": "bronsförgylla",
    "bronsförgylldes": "bronsförgylla",
    "bronsförgyllds": "bronsförgylla",
    "bronsförgyller": "bronsförgylla",
    "bronsförgylles": "bronsförgylla",
    "bronsförgylls": "bronsförgylla",
    "bronsförgyllt": "bronsförgylla",
    "bronsförgyllts": "bronsförgylla",
    "bronsinfattade": "bronsinfattad",
    "bronsinfattades": "bronsinfattad",
    "bronsinfattads": "bronsinfattad",
    "bronsinfattat": "bronsinfattad",
    "bronsinfattats": "bronsinfattad",
    "bronskannan": "bronskanna",
    "bronskannans": "bronskanna",
    "bronskannas": "bronskanna",
    "bronskanne": "bronskanna",
    "bronskannor": "bronskanna",
    "bronskannorna": "bronskanna",
    "bronskannornas": "bronskanna",
    "bronskannors": "bronskanna",
    "bronsknappar": "bronsknapp",
    "bronsknapparna": "bronsknapp",
    "bronsknapparnas": "bronsknapp",
    "bronsknappars": "bronsknapp",
    "bronsknappen": "bronsknapp",
    "bronsknappens": "bronsknapp",
    "bronsknapps": "bronsknapp",
    "bronsmedaljen": "bronsmedalj",
    "bronsmedaljens": "bronsmedalj",
    "bronsmedaljer": "bronsmedalj",
    "bronsmedaljerna": "bronsmedalj",
    "bronsmedaljernas": "bronsmedalj",
    "bronsmedaljers": "bronsmedalj",
    "bronsmedaljs": "bronsmedalj",
    "bronsmärken": "bronsmärke",
    "bronsmärkena": "bronsmärke",
    "bronsmärkenas": "bronsmärke",
    "bronsmärkens": "bronsmärke",
    "bronsmärkes": "bronsmärke",
    "bronsmärket": "bronsmärke",
    "bronsmärkets": "bronsmärke",
    "bronsspännen": "bronsspänne",
    "bronsspännena": "bronsspänne",
    "bronsspännenas": "bronsspänne",
    "bronsspännens": "bronsspänne",
    "bronsspännes": "bronsspänne",
    "bronsspännet": "bronsspänne",
    "bronsspännets": "bronsspänne",
    "bronsspänns": "bronsspänne",
    "bronstavel": "bronstavla",
    "bronstavlan": "bronstavla",
    "bronstavlans": "bronstavla",
    "bronstavlas": "bronstavla",
    "bronstavle": "bronstavla",
    "bronstavlor": "bronstavla",
    "bronstavlorna": "bronstavla",
    "bronstavlornas": "bronstavla",
    "bronstavlors": "bronstavla",
    "bronsåldern": "bronsålder",
    "bronsålderns": "bronsålder",
    "bronsålders": "bronsålder",
    "bronsåldersfynden": "bronsåldersfynd",
    "bronsåldersfyndens": "bronsåldersfynd",
    "bronsåldersfyndet": "bronsåldersfynd",
    "bronsåldersfyndets": "bronsåldersfynd",
    "bronsåldersfynds": "bronsåldersfynd",
    "bronsåldersgravar": "bronsåldersgrav",
    "bronsåldersgravarna": "bronsåldersgrav",
    "bronsåldersgravarnas": "bronsåldersgrav",
    "bronsåldersgravars": "bronsåldersgrav",
    "bronsåldersgraven": "bronsåldersgrav",
    "bronsåldersgravens": "bronsåldersgrav",
    "bronsåldersgravs": "bronsåldersgrav",
    "broolyck": "broolycka",
    "broolyckan": "broolycka",
    "broolyckans": "broolycka",
    "broolyckas": "broolycka",
    "broolycke": "broolycka",
    "broolyckor": "broolycka",
    "broolyckorna": "broolycka",
    "broolyckornas": "broolycka",
    "broolyckors": "broolycka",
    "broolycks": "broolycka",
    "bropelar": "bropelare",
    "bropelaren": "bropelare",
    "bropelarens": "bropelare",
    "bropelares": "bropelare",
    "bropelarna": "bropelare",
    "bropelarnas": "bropelare",
    "bropengar": "bropeng",
    "bropengarna": "bropeng",
    "bropengarnas": "bropeng",
    "bropengars": "bropeng",
    "bropengen": "bropeng",
    "bropengens": "bropeng",
    "bropengs": "bropeng",
    "bropenningar": "bropenning",
    "bropenningarna": "bropenning",
    "bropenningarnas": "bropenning",
    "bropenningars": "bropenning",
    "bropenningen": "bropenning",
    "bropenningens": "bropenning",
    "bropennings": "bropenning",
    "broplank": "broplanka",
    "broplankan": "broplanka",
    "broplankans": "broplanka",
    "broplankas": "broplanka",
    "broplanke": "broplanka",
    "broplankor": "broplanka",
    "broplankorna": "broplanka",
    "broplankornas": "broplanka",
    "broplankors": "broplanka",
    "broplanks": "broplanka",
    "brorn": "bror",
    "brorns": "bror",
    "brors": "brorsa",
    "brorsan": "brorsa",
    "brorsans": "brorsa",
    "brorsarven": "brorsarv",
    "brorsarvens": "brorsarv",
    "brorsarvet": "brorsarv",
    "brorsarvets": "brorsarv",
    "brorsarvs": "brorsarv",
    "brorsas": "brorsa",
    "brorsbarnen": "brorsbarn",
    "brorsbarnens": "brorsbarn",
    "brorsbarnet": "brorsbarn",
    "brorsbarnets": "brorsbarn",
    "brorsbarns": "brorsbarn",
    "brorsdottern": "brorsdotter",
    "brorsdotterns": "brorsdotter",
    "brorsdotters": "brorsdotter",
    "brorsdöttrar": "brorsdotter",
    "brorsdöttrarna": "brorsdotter",
    "brorsdöttrarnas": "brorsdotter",
    "brorsdöttrars": "brorsdotter",
    "brorse": "brorsa",
    "brorskålar": "brorskål",
    "brorskålarna": "brorskål",
    "brorskålarnas": "brorskål",
    "brorskålars": "brorskål",
    "brorskålen": "brorskål",
    "brorskålens": "brorskål",
    "brorskåls": "brorskål",
    "brorslotten": "brorslott",
    "brorslottens": "brorslott",
    "brorslotter": "brorslott",
    "brorslotterna": "brorslott",
    "brorslotternas": "brorslott",
    "brorslotters": "brorslott",
    "brorslotts": "brorslott",
    "brorsonen": "brorson",
    "brorsonens": "brorson",
    "brorsons": "brorson",
    "brorsor": "brorsa",
    "brorsorna": "brorsa",
    "brorsornas": "brorsa",
    "brorsors": "brorsa",
    "brorsskålar": "brorsskål",
    "brorsskålarna": "brorsskål",
    "brorsskålarnas": "brorsskål",
    "brorsskålars": "brorsskål",
    "brorsskålen": "brorsskål",
    "brorsskålens": "brorsskål",
    "brorsskåls": "brorsskål",
    "brorsöner": "brorson",
    "brorsönerna": "brorson",
    "brorsönernas": "brorson",
    "brorsöners": "brorson",
    "bros": "bro",
    "broschen": "brosch",
    "broschens": "brosch",
    "broscher": "brosch",
    "broscherad": "broschera",
    "broscherade": "broscherad",
    "broscherades": "broscherad",
    "broscherads": "broscherad",
    "broscherande": "broschera",
    "broscheranden": "broscherande",
    "broscherandena": "broscherande",
    "broscherandenas": "broscherande",
    "broscherandens": "broscherande",
    "broscherandes": "broscherande",
    "broscherandet": "broscherande",
    "broscherandets": "broscherande",
    "broscherar": "broschera",
    "broscheras": "broschera",
    "broscherat": "broscherad",
    "broscherats": "broscherad",
    "broscherbara": "broscherbar",
    "broscherbarare": "broscherbar",
    "broscherbarares": "broscherbar",
    "broscherbaras": "broscherbar",
    "broscherbarast": "broscherbar",
    "broscherbaraste": "broscherbar",
    "broscherbarastes": "broscherbar",
    "broscherbarasts": "broscherbar",
    "broscherbare": "broscherbar",
    "broscherbares": "broscherbar",
    "broscherbarheten": "broscherbarhet",
    "broscherbarhetens": "broscherbarhet",
    "broscherbarhets": "broscherbarhet",
    "broscherbars": "broscherbar",
    "broscherbart": "broscherbar",
    "broscherbarts": "broscherbar",
    "broscheringar": "broschering",
    "broscheringarna": "broschering",
    "broscheringarnas": "broschering",
    "broscheringars": "broschering",
    "broscheringen": "broschering",
    "broscheringens": "broschering",
    "broscherings": "broschering",
    "broscherna": "brosch",
    "broschernas": "brosch",
    "broschers": "brosch",
    "broschs": "brosch",
    "broschyren": "broschyr",
    "broschyrens": "broschyr",
    "broschyrer": "broschyr",
    "broschyrerna": "broschyr",
    "broschyrernas": "broschyr",
    "broschyrers": "broschyr",
    "broschyrs": "broschyr",
    "brosken": "brosk",
    "broskens": "brosk",
    "brosket": "brosk",
    "broskets": "brosk",
    "broskfiskar": "broskfisk",
    "broskfiskarna": "broskfisk",
    "broskfiskarnas": "broskfisk",
    "broskfiskars": "broskfisk",
    "broskfisken": "broskfisk",
    "broskfiskens": "broskfisk",
    "broskfisks": "broskfisk",
    "broskhinnan": "broskhinna",
    "broskhinnans": "broskhinna",
    "broskhinnas": "broskhinna",
    "broskhinne": "broskhinna",
    "broskhinnor": "broskhinna",
    "broskhinnorna": "broskhinna",
    "broskhinnornas": "broskhinna",
    "broskhinnors": "broskhinna",
    "brosks": "brosk",
    "broskskivan": "broskskiva",
    "broskskivans": "broskskiva",
    "broskskivas": "broskskiva",
    "broskskive": "broskskiva",
    "broskskivlingar": "broskskivling",
    "broskskivlingarna": "broskskivling",
    "broskskivlingarnas": "broskskivling",
    "broskskivlingars": "broskskivling",
    "broskskivlingen": "broskskivling",
    "broskskivlingens": "broskskivling",
    "broskskivlings": "broskskivling",
    "broskskivor": "broskskiva",
    "broskskivorna": "broskskiva",
    "broskskivornas": "broskskiva",
    "broskskivors": "broskskiva",
    "brosksvampar": "brosksvamp",
    "brosksvamparna": "brosksvamp",
    "brosksvamparnas": "brosksvamp",
    "brosksvampars": "brosksvamp",
    "brosksvampen": "brosksvamp",
    "brosksvampens": "brosksvamp",
    "brosksvamps": "brosksvamp",
    "broskverken": "broskverk",
    "broskverkens": "broskverk",
    "broskverket": "broskverk",
    "broskverkets": "broskverk",
    "broskverks": "broskverk",
    "broskvävnaden": "broskvävnad",
    "broskvävnadens": "broskvävnad",
    "broskvävnader": "broskvävnad",
    "broskvävnaderna": "broskvävnad",
    "broskvävnadernas": "broskvävnad",
    "broskvävnaders": "broskvävnad",
    "broskvävnads": "broskvävnad",
    "broslagningar": "broslagning",
    "broslagningarna": "broslagning",
    "broslagningarnas": "broslagning",
    "broslagningars": "broslagning",
    "broslagningen": "broslagning",
    "broslagningens": "broslagning",
    "broslagnings": "broslagning",
    "brosmar": "brosme",
    "brosmarna": "brosme",
    "brosmarnas": "brosme",
    "brosmars": "brosme",
    "brosmen": "brosme",
    "brosmens": "brosme",
    "brosmes": "brosme",
    "brospannen": "brospann",
    "brospannens": "brospann",
    "brospannet": "brospann",
    "brospannets": "brospann",
    "brospanns": "brospann",
    "brossel": "brossla",
    "brosslad": "brossla",
    "brosslade": "brossla",
    "brosslades": "brossla",
    "brosslads": "brossla",
    "brosslande": "brossla",
    "brosslanden": "brosslande",
    "brosslandena": "brosslande",
    "brosslandenas": "brosslande",
    "brosslandens": "brosslande",
    "brosslandes": "brosslande",
    "brosslandet": "brosslande",
    "brosslandets": "brosslande",
    "brosslar": "brossla",
    "brosslas": "brossla",
    "brosslat": "brossla",
    "brosslats": "brossla",
    "brotsch": "brotscha",
    "brotschad": "brotscha",
    "brotschade": "brotscha",
    "brotschades": "brotscha",
    "brotschads": "brotscha",
    "brotschande": "brotscha",
    "brotschanden": "brotschande",
    "brotschandena": "brotschande",
    "brotschandenas": "brotschande",
    "brotschandens": "brotschande",
    "brotschandes": "brotschande",
    "brotschandet": "brotschande",
    "brotschandets": "brotschande",
    "brotschar": "brotscha",
    "brotscharna": "brotsch",
    "brotscharnas": "brotsch",
    "brotschars": "brotsch",
    "brotschas": "brotscha",
    "brotschat": "brotscha",
    "brotschats": "brotscha",
    "brotschen": "brotsch",
    "brotschens": "brotsch",
    "brotschs": "brotsch",
    "brottades": "brottas",
    "brottar": "brottare",
    "brottaren": "brottare",
    "brottarens": "brottare",
    "brottares": "brottare",
    "brottarna": "brottare",
    "brottarnas": "brottare",
    "brottats": "brottas",
    "brotten": "brott",
    "brottens": "brott",
    "brottet": "brott",
    "brottets": "brott",
    "brottmålen": "brottmål",
    "brottmålens": "brottmål",
    "brottmålet": "brottmål",
    "brottmålets": "brottmål",
    "brottmåls": "brottmål",
    "brottningar": "brottning",
    "brottningarna": "brottning",
    "brottningarnas": "brottning",
    "brottningars": "brottning",
    "brottningen": "brottning",
    "brottningens": "brottning",
    "brottnings": "brottning",
    "brottningsgreppen": "brottningsgrepp",
    "brottningsgreppens": "brottningsgrepp",
    "brottningsgreppet": "brottningsgrepp",
    "brottningsgreppets": "brottningsgrepp",
    "brottningsgrepps": "brottningsgrepp",
    "brottningsmatchen": "brottningsmatch",
    "brottningsmatchens": "brottningsmatch",
    "brottningsmatcher": "brottningsmatch",
    "brottningsmatcherna": "brottningsmatch",
    "brottningsmatchernas": "brottningsmatch",
    "brottningsmatchers": "brottningsmatch",
    "brottningsmatchs": "brottningsmatch",
    "brottningsringar": "brottningsring",
    "brottningsringarna": "brottningsring",
    "brottningsringarnas": "brottningsring",
    "brottningsringars": "brottningsring",
    "brottningsringen": "brottningsring",
    "brottningsringens": "brottningsring",
    "brottningsrings": "brottningsring",
    "brotts": "brott",
    "brottsbalken": "brottsbalk",
    "brottsbalkens": "brottsbalk",
    "brottsbalks": "brottsbalk",
    "brottsbekämpningen": "brottsbekämpning",
    "brottsbekämpningens": "brottsbekämpning",
    "brottsbekämpnings": "brottsbekämpning",
    "brottsbevakningar": "brottsbevakning",
    "brottsbevakningarna": "brottsbevakning",
    "brottsbevakningarnas": "brottsbevakning",
    "brottsbevakningars": "brottsbevakning",
    "brottsbevakningen": "brottsbevakning",
    "brottsbevakningens": "brottsbevakning",
    "brottsbevaknings": "brottsbevakning",
    "brottsjöar": "brottsjö",
    "brottsjöarna": "brottsjö",
    "brottsjöarnas": "brottsjö",
    "brottsjöars": "brottsjö",
    "brottsjön": "brottsjö",
    "brottsjöns": "brottsjö",
    "brottsjös": "brottsjö",
    "brottskonkurrensen": "brottskonkurrens",
    "brottskonkurrensens": "brottskonkurrens",
    "brottsliga": "brottslig",
    "brottsligare": "brottslig",
    "brottsligares": "brottslig",
    "brottsligas": "brottslig",
    "brottsligast": "brottslig",
    "brottsligaste": "brottslig",
    "brottsligastes": "brottslig",
    "brottsligasts": "brottslig",
    "brottslige": "brottslig",
    "brottsliges": "brottslig",
    "brottsligheten": "brottslighet",
    "brottslighetens": "brottslighet",
    "brottsligheter": "brottslighet",
    "brottsligheterna": "brottslighet",
    "brottsligheternas": "brottslighet",
    "brottsligheters": "brottslighet",
    "brottslighets": "brottslighet",
    "brottsligs": "brottslig",
    "brottsligt": "brottslig",
    "brottsligts": "brottslig",
    "brottslingar": "brottsling",
    "brottslingarna": "brottsling",
    "brottslingarnas": "brottsling",
    "brottslingars": "brottsling",
    "brottslingen": "brottsling",
    "brottslingens": "brottsling",
    "brottslings": "brottsling",
    "brottsmisstankar": "brottsmisstanke",
    "brottsmisstankarna": "brottsmisstanke",
    "brottsmisstankarnas": "brottsmisstanke",
    "brottsmisstankars": "brottsmisstanke",
    "brottsmisstanken": "brottsmisstanke",
    "brottsmisstankens": "brottsmisstanke",
    "brottsmisstankes": "brottsmisstanke",
    "brottsoffers": "brottsoffer",
    "brottsoffren": "brottsoffer",
    "brottsoffrens": "brottsoffer",
    "brottsoffret": "brottsoffer",
    "brottsoffrets": "brottsoffer",
    "brottsplatsen": "brottsplats",
    "brottsplatsens": "brottsplats",
    "brottsplatser": "brottsplats",
    "brottsplatserna": "brottsplats",
    "brottsplatsernas": "brottsplats",
    "brottsplatsers": "brottsplats",
    "brottsplatsteknikern": "brottsplatstekniker",
    "brottsplatsteknikerna": "brottsplatstekniker",
    "brottsplatsteknikernas": "brottsplatstekniker",
    "brottsplatsteknikerns": "brottsplatstekniker",
    "brottsplatsteknikers": "brottsplatstekniker",
    "brottsplatsundersökningar": "brottsplatsundersökning",
    "brottsplatsundersökningarna": "brottsplatsundersökning",
    "brottsplatsundersökningarnas": "brottsplatsundersökning",
    "brottsplatsundersökningars": "brottsplatsundersökning",
    "brottsplatsundersökningen": "brottsplatsundersökning",
    "brottsplatsundersökningens": "brottsplatsundersökning",
    "brottsplatsundersöknings": "brottsplatsundersökning",
    "brottsprovokationen": "brottsprovokation",
    "brottsprovokationens": "brottsprovokation",
    "brottsprovokationer": "brottsprovokation",
    "brottsprovokationerna": "brottsprovokation",
    "brottsprovokationernas": "brottsprovokation",
    "brottsprovokationers": "brottsprovokation",
    "brottsprovokations": "brottsprovokation",
    "brottsregisterna": "brottsregister",
    "brottsregisternas": "brottsregister",
    "brottsregisters": "brottsregister",
    "brottsregistren": "brottsregister",
    "brottsregistrens": "brottsregister",
    "brottsregistret": "brottsregister",
    "brottsregistrets": "brottsregister",
    "brottsrekvisiten": "brottsrekvisit",
    "brottsrekvisitens": "brottsrekvisit",
    "brottsrekvisitet": "brottsrekvisit",
    "brottsrekvisitets": "brottsrekvisit",
    "brottsrekvisits": "brottsrekvisit",
    "brottsrubriceringar": "brottsrubricering",
    "brottsrubriceringarna": "brottsrubricering",
    "brottsrubriceringarnas": "brottsrubricering",
    "brottsrubriceringars": "brottsrubricering",
    "brottsrubriceringen": "brottsrubricering",
    "brottsrubriceringens": "brottsrubricering",
    "brottsrubricerings": "brottsrubricering",
    "brottstillfällen": "brottstillfälle",
    "brottstillfällena": "brottstillfälle",
    "brottstillfällenas": "brottstillfälle",
    "brottstillfällens": "brottstillfälle",
    "brottstillfälles": "brottstillfälle",
    "brottstillfället": "brottstillfälle",
    "brottstillfällets": "brottstillfälle",
    "brottstycken": "brottstycke",
    "brottstyckena": "brottstycke",
    "brottstyckenas": "brottstycke",
    "brottstyckens": "brottstycke",
    "brottstyckes": "brottstycke",
    "brottstycket": "brottstycke",
    "brottstyckets": "brottstycke",
    "brottstycks": "brottstycke",
    "brottställen": "brottställe",
    "brottställena": "brottställe",
    "brottställenas": "brottställe",
    "brottställens": "brottställe",
    "brottställes": "brottställe",
    "brottstället": "brottställe",
    "brottställets": "brottställe",
    "brottsutredningar": "brottsutredning",
    "brottsutredningarna": "brottsutredning",
    "brottsutredningarnas": "brottsutredning",
    "brottsutredningars": "brottsutredning",
    "brottsutredningen": "brottsutredning",
    "brottsutredningens": "brottsutredning",
    "brottsutrednings": "brottsutredning",
    "brottytan": "brottyta",
    "brottytans": "brottyta",
    "brottytas": "brottyta",
    "brottyte": "brottyta",
    "brottytor": "brottyta",
    "brottytorna": "brottyta",
    "brottytornas": "brottyta",
    "brottytors": "brottyta",
    "brovalven": "brovalv",
    "brovalvens": "brovalv",
    "brovalvet": "brovalv",
    "brovalvets": "brovalv",
    "brovalvs": "brovalv",
    "browningar": "browning",
    "browningarna": "browning",
    "browningarnas": "browning",
    "browningars": "browning",
    "browningen": "browning",
    "browningens": "browning",
    "brownings": "browning",
    "broöppningar": "broöppning",
    "broöppningarna": "broöppning",
    "broöppningarnas": "broöppning",
    "broöppningars": "broöppning",
    "broöppningen": "broöppning",
    "broöppningens": "broöppning",
    "broöppnings": "broöppning",
    "bruckel": "bruckla",
    "bruckels": "bruckel",
    "brucklad": "bruckla",
    "brucklade": "bruckla",
    "brucklades": "bruckla",
    "brucklads": "bruckla",
    "brucklande": "bruckla",
    "brucklanden": "brucklande",
    "brucklandena": "brucklande",
    "brucklandenas": "brucklande",
    "brucklandens": "brucklande",
    "brucklandes": "brucklande",
    "brucklandet": "brucklande",
    "brucklandets": "brucklande",
    "brucklar": "bruckla",
    "brucklas": "bruckla",
    "brucklat": "bruckla",
    "brucklats": "bruckla",
    "brucklen": "bruckel",
    "brucklens": "bruckel",
    "brucklet": "bruckel",
    "brucklets": "bruckel",
    "brudanden": "brudand",
    "brudandens": "brudand",
    "brudands": "brudand",
    "brudar": "brud",
    "brudarna": "brud",
    "brudarnas": "brud",
    "brudars": "brud",
    "brudborst": "brudborste",
    "brudborsta": "brudborste",
    "brudborsten": "brudborste",
    "brudborstens": "brudborste",
    "brudborstes": "brudborste",
    "brudbrödet": "brudbröd",
    "brudbrödets": "brudbröd",
    "brudbröds": "brudbröd",
    "brudbuketten": "brudbukett",
    "brudbukettens": "brudbukett",
    "brudbuketter": "brudbukett",
    "brudbuketterna": "brudbukett",
    "brudbuketternas": "brudbukett",
    "brudbuketters": "brudbukett",
    "brudbuketts": "brudbukett",
    "bruden": "brud",
    "brudens": "brud",
    "brudfoton": "brudfoto",
    "brudfotona": "brudfoto",
    "brudfotonas": "brudfoto",
    "brudfotons": "brudfoto",
    "brudfotos": "brudfoto",
    "brudfotot": "brudfoto",
    "brudfotots": "brudfoto",
    "brudfräm": "brudfrämma",
    "brudfrämman": "brudfrämma",
    "brudfrämmans": "brudfrämma",
    "brudfrämmas": "brudfrämma",
    "brudfrämme": "brudfrämma",
    "brudfrämmor": "brudfrämma",
    "brudfrämmorna": "brudfrämma",
    "brudfrämmornas": "brudfrämma",
    "brudfrämmors": "brudfrämma",
    "brudfräms": "brudfrämma",
    "brudföljen": "brudfölje",
    "brudföljena": "brudfölje",
    "brudföljenas": "brudfölje",
    "brudföljens": "brudfölje",
    "brudföljes": "brudfölje",
    "brudföljet": "brudfölje",
    "brudföljets": "brudfölje",
    "brudföljs": "brudfölje",
    "brudgummar": "brudgum",
    "brudgummarna": "brudgum",
    "brudgummarnas": "brudgum",
    "brudgummars": "brudgum",
    "brudgummen": "brudgum",
    "brudgummens": "brudgum",
    "brudgums": "brudgum",
    "brudgåvan": "brudgåva",
    "brudgåvans": "brudgåva",
    "brudgåvas": "brudgåva",
    "brudgåve": "brudgåva",
    "brudgåvo": "brudgåva",
    "brudgåvor": "brudgåva",
    "brudgåvorna": "brudgåva",
    "brudgåvornas": "brudgåva",
    "brudgåvors": "brudgåva",
    "brudklänningar": "brudklänning",
    "brudklänningarna": "brudklänning",
    "brudklänningarnas": "brudklänning",
    "brudklänningars": "brudklänning",
    "brudklänningen": "brudklänning",
    "brudklänningens": "brudklänning",
    "brudklännings": "brudklänning",
    "brudkron": "brudkrona",
    "brudkronan": "brudkrona",
    "brudkronans": "brudkrona",
    "brudkronas": "brudkrona",
    "brudkrone": "brudkrona",
    "brudkronor": "brudkrona",
    "brudkronorna": "brudkrona",
    "brudkronornas": "brudkrona",
    "brudkronors": "brudkrona",
    "brudkrons": "brudkrona",
    "brudköpen": "brudköp",
    "brudköpens": "brudköp",
    "brudköpet": "brudköp",
    "brudköpets": "brudköp",
    "brudköps": "brudköp",
    "brudmystiken": "brudmystik",
    "brudmystikens": "brudmystik",
    "brudmystiks": "brudmystik",
    "brudnäbbar": "brudnäbb",
    "brudnäbbarna": "brudnäbb",
    "brudnäbbarnas": "brudnäbb",
    "brudnäbbars": "brudnäbb",
    "brudnäbben": "brudnäbb",
    "brudnäbbens": "brudnäbb",
    "brudnäbbs": "brudnäbb",
    "brudpallar": "brudpall",
    "brudpallarna": "brudpall",
    "brudpallarnas": "brudpall",
    "brudpallars": "brudpall",
    "brudpallen": "brudpall",
    "brudpallens": "brudpall",
    "brudpalls": "brudpall",
    "brudparen": "brudpar",
    "brudparens": "brudpar",
    "brudparet": "brudpar",
    "brudparets": "brudpar",
    "brudpars": "brudpar",
    "brudpällar": "brudpäll",
    "brudpällarna": "brudpäll",
    "brudpällarnas": "brudpäll",
    "brudpällars": "brudpäll",
    "brudpällen": "brudpäll",
    "brudpällens": "brudpäll",
    "brudpälls": "brudpäll",
    "brudroven": "brudrov",
    "brudrovens": "brudrov",
    "brudrovet": "brudrov",
    "brudrovets": "brudrov",
    "brudrovs": "brudrov",
    "bruds": "brud",
    "brudslöjan": "brudslöja",
    "brudslöjans": "brudslöja",
    "brudslöjas": "brudslöja",
    "brudslöje": "brudslöja",
    "brudslöjor": "brudslöja",
    "brudslöjorna": "brudslöja",
    "brudslöjornas": "brudslöja",
    "brudslöjors": "brudslöja",
    "brudsporr": "brudsporre",
    "brudsporrar": "brudsporre",
    "brudsporrarna": "brudsporre",
    "brudsporrarnas": "brudsporre",
    "brudsporrars": "brudsporre",
    "brudsporren": "brudsporre",
    "brudsporrens": "brudsporre",
    "brudsporres": "brudsporre",
    "brudsporrs": "brudsporre",
    "brudstolar": "brudstol",
    "brudstolarna": "brudstol",
    "brudstolarnas": "brudstol",
    "brudstolars": "brudstol",
    "brudstolen": "brudstol",
    "brudstolens": "brudstol",
    "brudstols": "brudstol",
    "brudsängar": "brudsäng",
    "brudsängarna": "brudsäng",
    "brudsängarnas": "brudsäng",
    "brudsängars": "brudsäng",
    "brudsängen": "brudsäng",
    "brudsängens": "brudsäng",
    "brudsängs": "brudsäng",
    "brudtärn": "brudtärna",
    "brudtärnan": "brudtärna",
    "brudtärnans": "brudtärna",
    "brudtärnas": "brudtärna",
    "brudtärne": "brudtärna",
    "brudtärnor": "brudtärna",
    "brudtärnorna": "brudtärna",
    "brudtärnornas": "brudtärna",
    "brudtärnors": "brudtärna",
    "brudtärns": "brudtärna",
    "brudänder": "brudand",
    "brudänderna": "brudand",
    "brudändernas": "brudand",
    "brudänders": "brudand",
    "brugden": "brugd",
    "brugdens": "brugd",
    "brugder": "brugd",
    "brugderna": "brugd",
    "brugdernas": "brugd",
    "brugders": "brugd",
    "brugds": "brugd",
    "bruk": "bruka",
    "brukad": "bruka",
    "brukade": "bruka",
    "brukades": "bruka",
    "brukads": "bruka",
    "brukande": "bruka",
    "brukanden": "brukande",
    "brukandena": "brukande",
    "brukandenas": "brukande",
    "brukandens": "brukande",
    "brukandes": "brukande",
    "brukandet": "brukande",
    "brukandets": "brukande",
    "brukar": "brukare",
    "brukaren": "brukare",
    "brukarens": "brukare",
    "brukares": "brukare",
    "brukarna": "brukare",
    "brukarnas": "brukare",
    "brukas": "bruka",
    "brukat": "bruka",
    "brukats": "bruka",
    "brukbara": "brukbar",
    "brukbarare": "brukbar",
    "brukbarares": "brukbar",
    "brukbaras": "brukbar",
    "brukbarast": "brukbar",
    "brukbaraste": "brukbar",
    "brukbarastes": "brukbar",
    "brukbarasts": "brukbar",
    "brukbare": "brukbar",
    "brukbares": "brukbar",
    "brukbarheten": "brukbarhet",
    "brukbarhetens": "brukbarhet",
    "brukbarhets": "brukbarhet",
    "brukbars": "brukbar",
    "brukbart": "brukbar",
    "brukbarts": "brukbar",
    "bruken": "bruk",
    "brukens": "bruk",
    "bruket": "bruk",
    "brukets": "bruk",
    "brukliga": "bruklig",
    "brukligare": "bruklig",
    "brukligares": "bruklig",
    "brukligas": "bruklig",
    "brukligast": "bruklig",
    "brukligaste": "bruklig",
    "brukligastes": "bruklig",
    "brukligasts": "bruklig",
    "bruklige": "bruklig",
    "brukliges": "bruklig",
    "brukligheten": "bruklighet",
    "bruklighetens": "bruklighet",
    "brukligheter": "bruklighet",
    "brukligheterna": "bruklighet",
    "brukligheternas": "bruklighet",
    "brukligheters": "bruklighet",
    "bruklighets": "bruklighet",
    "brukligs": "bruklig",
    "brukligt": "bruklig",
    "brukligts": "bruklig",
    "brukningar": "brukning",
    "brukningarna": "brukning",
    "brukningarnas": "brukning",
    "brukningars": "brukning",
    "brukningen": "brukning",
    "brukningens": "brukning",
    "bruknings": "brukning",
    "brukningsenheten": "brukningsenhet",
    "brukningsenhetens": "brukningsenhet",
    "brukningsenheter": "brukningsenhet",
    "brukningsenheterna": "brukningsenhet",
    "brukningsenheternas": "brukningsenhet",
    "brukningsenheters": "brukningsenhet",
    "brukningsenhets": "brukningsenhet",
    "bruks": "bruk",
    "bruksanvisningar": "bruksanvisning",
    "bruksanvisningarna": "bruksanvisning",
    "bruksanvisningarnas": "bruksanvisning",
    "bruksanvisningars": "bruksanvisning",
    "bruksanvisningen": "bruksanvisning",
    "bruksanvisningens": "bruksanvisning",
    "bruksanvisnings": "bruksanvisning",
    "bruksartikeln": "bruksartikel",
    "bruksartikelns": "bruksartikel",
    "bruksartikels": "bruksartikel",
    "bruksartiklar": "bruksartikel",
    "bruksartiklarna": "bruksartikel",
    "bruksartiklarnas": "bruksartikel",
    "bruksartiklars": "bruksartikel",
    "bruksdisponenten": "bruksdisponent",
    "bruksdisponentens": "bruksdisponent",
    "bruksdisponenter": "bruksdisponent",
    "bruksdisponenterna": "bruksdisponent",
    "bruksdisponenternas": "bruksdisponent",
    "bruksdisponenters": "bruksdisponent",
    "bruksdisponents": "bruksdisponent",
    "bruksdjuren": "bruksdjur",
    "bruksdjurens": "bruksdjur",
    "bruksdjuret": "bruksdjur",
    "bruksdjurets": "bruksdjur",
    "bruksdjurs": "bruksdjur",
    "bruksföremålen": "bruksföremål",
    "bruksföremålens": "bruksföremål",
    "bruksföremålet": "bruksföremål",
    "bruksföremålets": "bruksföremål",
    "bruksföremåls": "bruksföremål",
    "brukshundar": "brukshund",
    "brukshundarna": "brukshund",
    "brukshundarnas": "brukshund",
    "brukshundars": "brukshund",
    "brukshunden": "brukshund",
    "brukshundens": "brukshund",
    "brukshunds": "brukshund",
    "brukskonsten": "brukskonst",
    "brukskonstens": "brukskonst",
    "brukskonsts": "brukskonst",
    "brukslagar": "brukslagare",
    "brukslagaren": "brukslagare",
    "brukslagarens": "brukslagare",
    "brukslagares": "brukslagare",
    "brukslagarna": "brukslagare",
    "brukslagarnas": "brukslagare",
    "brukslagen": "brukslå",
    "brukslagens": "brukslå",
    "brukslaget": "brukslå",
    "brukslagets": "brukslå",
    "brukslagit": "brukslå",
    "brukslagits": "brukslå",
    "brukslagna": "brukslå",
    "brukslagnas": "brukslå",
    "brukslagne": "brukslå",
    "brukslagnes": "brukslå",
    "brukslevar": "brukslev",
    "brukslevarna": "brukslev",
    "brukslevarnas": "brukslev",
    "brukslevars": "brukslev",
    "bruksleven": "brukslev",
    "brukslevens": "brukslev",
    "brukslevs": "brukslev",
    "brukslog": "brukslå",
    "bruksloge": "brukslå",
    "bruksloges": "brukslå",
    "brukslogs": "brukslå",
    "brukslående": "brukslå",
    "brukslåenden": "brukslående",
    "brukslåendena": "brukslående",
    "brukslåendenas": "brukslående",
    "brukslåendens": "brukslående",
    "brukslåendes": "brukslående",
    "brukslåendet": "brukslående",
    "brukslåendets": "brukslående",
    "brukslår": "brukslå",
    "brukslås": "brukslå",
    "brukspatronen": "brukspatron",
    "brukspatronens": "brukspatron",
    "brukspatroner": "brukspatron",
    "brukspatronerna": "brukspatron",
    "brukspatronernas": "brukspatron",
    "brukspatroners": "brukspatron",
    "brukspatrons": "brukspatron",
    "brukssamhällen": "brukssamhälle",
    "brukssamhällena": "brukssamhälle",
    "brukssamhällenas": "brukssamhälle",
    "brukssamhällens": "brukssamhälle",
    "brukssamhälles": "brukssamhälle",
    "brukssamhället": "brukssamhälle",
    "brukssamhällets": "brukssamhälle",
    "brukssamhälls": "brukssamhälle",
    "bruksvärden": "bruksvärde",
    "bruksvärdena": "bruksvärde",
    "bruksvärdenas": "bruksvärde",
    "bruksvärdens": "bruksvärde",
    "bruksvärdes": "bruksvärde",
    "bruksvärdeshyr": "bruksvärdeshyra",
    "bruksvärdeshyran": "bruksvärdeshyra",
    "bruksvärdeshyrans": "bruksvärdeshyra",
    "bruksvärdeshyras": "bruksvärdeshyra",
    "bruksvärdeshyre": "bruksvärdeshyra",
    "bruksvärdeshyror": "bruksvärdeshyra",
    "bruksvärdeshyrorna": "bruksvärdeshyra",
    "bruksvärdeshyrornas": "bruksvärdeshyra",
    "bruksvärdeshyrors": "bruksvärdeshyra",
    "bruksvärdeshyrs": "bruksvärdeshyra",
    "bruksvärdet": "bruksvärde",
    "bruksvärdets": "bruksvärde",
    "brulépuddingar": "brulépudding",
    "brulépuddingarna": "brulépudding",
    "brulépuddingarnas": "brulépudding",
    "brulépuddingars": "brulépudding",
    "brulépuddingen": "brulépudding",
    "brulépuddingens": "brulépudding",
    "brulépuddings": "brulépudding",
    "brum": "brumma",
    "brumbasar": "brumbas",
    "brumbasarna": "brumbas",
    "brumbasarnas": "brumbas",
    "brumbasars": "brumbas",
    "brumbasen": "brumbas",
    "brumbasens": "brumbas",
    "brumbjörnar": "brumbjörn",
    "brumbjörnarna": "brumbjörn",
    "brumbjörnarnas": "brumbjörn",
    "brumbjörnars": "brumbjörn",
    "brumbjörnen": "brumbjörn",
    "brumbjörnens": "brumbjörn",
    "brumbjörns": "brumbjörn",
    "brumkören": "brumkör",
    "brumkörens": "brumkör",
    "brumkörer": "brumkör",
    "brumkörerna": "brumkör",
    "brumkörernas": "brumkör",
    "brumkörers": "brumkör",
    "brumkörs": "brumkör",
    "brummade": "brumma",
    "brummades": "brumma",
    "brummande": "brumma",
    "brummanden": "brummande",
    "brummandena": "brummande",
    "brummandenas": "brummande",
    "brummandens": "brummande",
    "brummandes": "brummande",
    "brummandet": "brummande",
    "brummandets": "brummande",
    "brummar": "brummare",
    "brummaren": "brummare",
    "brummarens": "brummare",
    "brummares": "brummare",
    "brummarna": "brummare",
    "brummarnas": "brummare",
    "brummas": "brumma",
    "brummat": "brumma",
    "brummats": "brumma",
    "brummet": "brum",
    "brummets": "brum",
    "brums": "brum",
    "bruna": "brun",
    "brunaktiga": "brunaktig",
    "brunaktigare": "brunaktig",
    "brunaktigares": "brunaktig",
    "brunaktigas": "brunaktig",
    "brunaktigast": "brunaktig",
    "brunaktigaste": "brunaktig",
    "brunaktigastes": "brunaktig",
    "brunaktigasts": "brunaktig",
    "brunaktige": "brunaktig",
    "brunaktiges": "brunaktig",
    "brunaktigheten": "brunaktighet",
    "brunaktighetens": "brunaktighet",
    "brunaktighets": "brunaktighet",
    "brunaktigs": "brunaktig",
    "brunaktigt": "brunaktig",
    "brunaktigts": "brunaktig",
    "brunalgen": "brunalg",
    "brunalgens": "brunalg",
    "brunalger": "brunalg",
    "brunalgerna": "brunalg",
    "brunalgernas": "brunalg",
    "brunalgers": "brunalg",
    "brunalgs": "brunalg",
    "brunare": "brun",
    "brunares": "brun",
    "brunas": "brun",
    "brunast": "brun",
    "brunaste": "brun",
    "brunastes": "brun",
    "brunasts": "brun",
    "brunbrända": "brunbränd",
    "brunbrändare": "brunbränd",
    "brunbrändares": "brunbränd",
    "brunbrändas": "brunbränd",
    "brunbrändast": "brunbränd",
    "brunbrändaste": "brunbränd",
    "brunbrändastes": "brunbränd",
    "brunbrändasts": "brunbränd",
    "brunbrände": "brunbränd",
    "brunbrändes": "brunbränd",
    "brunbränds": "brunbränd",
    "brunbränt": "brunbränd",
    "brunbränts": "brunbränd",
    "brunbären": "brunbär",
    "brunbärens": "brunbär",
    "brunbäret": "brunbär",
    "brunbärets": "brunbär",
    "brunbärs": "brunbär",
    "brunchen": "brunch",
    "brunchens": "brunch",
    "bruncher": "brunch",
    "bruncherna": "brunch",
    "brunchernas": "brunch",
    "brunchers": "brunch",
    "brunchs": "brunch",
    "brunchtesten": "brunchtest",
    "brunchtestens": "brunchtest",
    "brunchtester": "brunchtest",
    "brunchtesterna": "brunchtest",
    "brunchtesternas": "brunchtest",
    "brunchtesters": "brunchtest",
    "brunchtestet": "brunchtest",
    "brunchtestets": "brunchtest",
    "brunchtests": "brunchtest",
    "brune": "brun",
    "bruneiern": "bruneier",
    "bruneierna": "bruneier",
    "bruneiernas": "bruneier",
    "bruneierns": "bruneier",
    "bruneiers": "bruneier",
    "bruneiska": "bruneisk",
    "bruneiskan": "bruneiska",
    "bruneiskans": "bruneiska",
    "bruneiskare": "bruneisk",
    "bruneiskares": "bruneisk",
    "bruneiskas": "bruneiska",
    "bruneiskast": "bruneisk",
    "bruneiskaste": "bruneisk",
    "bruneiskastes": "bruneisk",
    "bruneiskasts": "bruneisk",
    "bruneiske": "bruneiska",
    "bruneiskes": "bruneisk",
    "bruneiskor": "bruneiska",
    "bruneiskorna": "bruneiska",
    "bruneiskornas": "bruneiska",
    "bruneiskors": "bruneiska",
    "bruneisks": "bruneisk",
    "bruneiskt": "bruneisk",
    "bruneiskts": "bruneisk",
    "brunerad": "brunera",
    "brunerade": "brunera",
    "brunerades": "brunera",
    "brunerads": "brunera",
    "brunerande": "brunera",
    "bruneranden": "brunerande",
    "brunerandena": "brunerande",
    "brunerandenas": "brunerande",
    "brunerandens": "brunerande",
    "brunerandes": "brunerande",
    "brunerandet": "brunerande",
    "brunerandets": "brunerande",
    "brunerar": "brunera",
    "bruneras": "brunera",
    "brunerat": "brunera",
    "brunerats": "brunera",
    "brunerbara": "brunerbar",
    "brunerbarare": "brunerbar",
    "brunerbarares": "brunerbar",
    "brunerbaras": "brunerbar",
    "brunerbarast": "brunerbar",
    "brunerbaraste": "brunerbar",
    "brunerbarastes": "brunerbar",
    "brunerbarasts": "brunerbar",
    "brunerbare": "brunerbar",
    "brunerbares": "brunerbar",
    "brunerbarheten": "brunerbarhet",
    "brunerbarhetens": "brunerbarhet",
    "brunerbarhets": "brunerbarhet",
    "brunerbars": "brunerbar",
    "brunerbart": "brunerbar",
    "brunerbarts": "brunerbar",
    "bruneringar": "brunering",
    "bruneringarna": "brunering",
    "bruneringarnas": "brunering",
    "bruneringars": "brunering",
    "bruneringen": "brunering",
    "bruneringens": "brunering",
    "brunerings": "brunering",
    "brunes": "brun",
    "brunetta": "brunett",
    "brunettare": "brunett",
    "brunettares": "brunett",
    "brunettas": "brunett",
    "brunettast": "brunett",
    "brunettaste": "brunett",
    "brunettastes": "brunett",
    "brunettasts": "brunett",
    "brunette": "brunett",
    "brunettes": "brunett",
    "brunetts": "brunett",
    "brunfärg": "brunfärga",
    "brunfärgad": "brunfärga",
    "brunfärgade": "brunfärgad",
    "brunfärgades": "brunfärgad",
    "brunfärgads": "brunfärgad",
    "brunfärgande": "brunfärga",
    "brunfärganden": "brunfärgande",
    "brunfärgandena": "brunfärgande",
    "brunfärgandenas": "brunfärgande",
    "brunfärgandens": "brunfärgande",
    "brunfärgandes": "brunfärgande",
    "brunfärgandet": "brunfärgande",
    "brunfärgandets": "brunfärgande",
    "brunfärgar": "brunfärga",
    "brunfärgas": "brunfärga",
    "brunfärgat": "brunfärgad",
    "brunfärgats": "brunfärgad",
    "brunheten": "brunhet",
    "brunhetens": "brunhet",
    "brunhets": "brunhet",
    "brunhåriga": "brunhårig",
    "brunhårigare": "brunhårig",
    "brunhårigares": "brunhårig",
    "brunhårigas": "brunhårig",
    "brunhårigast": "brunhårig",
    "brunhårigaste": "brunhårig",
    "brunhårigastes": "brunhårig",
    "brunhårigasts": "brunhårig",
    "brunhårige": "brunhårig",
    "brunhåriges": "brunhårig",
    "brunhårigheten": "brunhårighet",
    "brunhårighetens": "brunhårighet",
    "brunhårighets": "brunhårighet",
    "brunhårigs": "brunhårig",
    "brunhårigt": "brunhårig",
    "brunhårigts": "brunhårig",
    "brunjorden": "brunjord",
    "brunjordens": "brunjord",
    "brunjords": "brunjord",
    "brunkolen": "brunkol",
    "brunkolens": "brunkol",
    "brunkolet": "brunkol",
    "brunkolets": "brunkol",
    "brunkols": "brunkol",
    "brunkull": "brunkulla",
    "brunkullan": "brunkulla",
    "brunkullans": "brunkulla",
    "brunkullas": "brunkulla",
    "brunkulle": "brunkulla",
    "brunkullor": "brunkulla",
    "brunkullorna": "brunkulla",
    "brunkullornas": "brunkulla",
    "brunkullors": "brunkulla",
    "brunkulls": "brunkulla",
    "brunkålen": "brunkål",
    "brunkålens": "brunkål",
    "brunkåls": "brunkål",
    "brunlackerade": "brunlackerad",
    "brunlackerades": "brunlackerad",
    "brunlackerads": "brunlackerad",
    "brunlackerat": "brunlackerad",
    "brunlackerats": "brunlackerad",
    "brunmålade": "brunmålad",
    "brunmålades": "brunmålad",
    "brunmålads": "brunmålad",
    "brunmålat": "brunmålad",
    "brunmålats": "brunmålad",
    "brunna": "brinna",
    "brunnar": "brunn",
    "brunnarna": "brunn",
    "brunnarnas": "brunn",
    "brunnars": "brunn",
    "brunnas": "brinna",
    "brunne": "brinna",
    "brunnen": "brunn",
    "brunnens": "brunn",
    "brunnes": "brinna",
    "brunnet": "brinna",
    "brunnets": "brinna",
    "brunnit": "brinna",
    "brunnits": "brinna",
    "brunns": "brunn",
    "brunnsdrickningar": "brunnsdrickning",
    "brunnsdrickningarna": "brunnsdrickning",
    "brunnsdrickningarnas": "brunnsdrickning",
    "brunnsdrickningars": "brunnsdrickning",
    "brunnsdrickningen": "brunnsdrickning",
    "brunnsdrickningens": "brunnsdrickning",
    "brunnsdricknings": "brunnsdrickning",
    "brunnshusen": "brunnshus",
    "brunnshusens": "brunnshus",
    "brunnshuset": "brunnshus",
    "brunnshusets": "brunnshus",
    "brunnskalla": "brunnskall",
    "brunnskallare": "brunnskall",
    "brunnskallares": "brunnskall",
    "brunnskallas": "brunnskall",
    "brunnskallast": "brunnskall",
    "brunnskallaste": "brunnskall",
    "brunnskallastes": "brunnskall",
    "brunnskallasts": "brunnskall",
    "brunnskalle": "brunnskall",
    "brunnskalles": "brunnskall",
    "brunnskalls": "brunnskall",
    "brunnskallt": "brunnskall",
    "brunnskallts": "brunnskall",
    "brunnskaren": "brunnskar",
    "brunnskarens": "brunnskar",
    "brunnskaret": "brunnskar",
    "brunnskarets": "brunnskar",
    "brunnskars": "brunnskar",
    "brunnskuren": "brunnskur",
    "brunnskurens": "brunnskur",
    "brunnskurer": "brunnskur",
    "brunnskurerna": "brunnskur",
    "brunnskurernas": "brunnskur",
    "brunnskurers": "brunnskur",
    "brunnskurs": "brunnskur",
    "brunnsorten": "brunnsort",
    "brunnsortens": "brunnsort",
    "brunnsorter": "brunnsort",
    "brunnsorterna": "brunnsort",
    "brunnsorternas": "brunnsort",
    "brunnsorters": "brunnsort",
    "brunnsorts": "brunnsort",
    "brunnssvängeln": "brunnssvängel",
    "brunnssvängelns": "brunnssvängel",
    "brunnssvängels": "brunnssvängel",
    "brunnssvänglar": "brunnssvängel",
    "brunnssvänglarna": "brunnssvängel",
    "brunnssvänglarnas": "brunnssvängel",
    "brunnssvänglars": "brunnssvängel",
    "brunnsvattens": "brunnsvatten",
    "brunnsvattnen": "brunnsvatten",
    "brunnsvattnens": "brunnsvatten",
    "brunnsvattnet": "brunnsvatten",
    "brunnsvattnets": "brunnsvatten",
    "brunockran": "brunockra",
    "brunockrans": "brunockra",
    "brunockras": "brunockra",
    "brunrosten": "brunrost",
    "brunrostens": "brunrost",
    "brunrosts": "brunrost",
    "brunrutiga": "brunrutig",
    "brunrutigare": "brunrutig",
    "brunrutigares": "brunrutig",
    "brunrutigas": "brunrutig",
    "brunrutigast": "brunrutig",
    "brunrutigaste": "brunrutig",
    "brunrutigastes": "brunrutig",
    "brunrutigasts": "brunrutig",
    "brunrutige": "brunrutig",
    "brunrutiges": "brunrutig",
    "brunrutigheten": "brunrutighet",
    "brunrutighetens": "brunrutighet",
    "brunrutighets": "brunrutighet",
    "brunrutigs": "brunrutig",
    "brunrutigt": "brunrutig",
    "brunrutigts": "brunrutig",
    "brunröda": "brunröd",
    "brunrödare": "brunröd",
    "brunrödares": "brunröd",
    "brunrödas": "brunröd",
    "brunrödast": "brunröd",
    "brunrödaste": "brunröd",
    "brunrödastes": "brunröd",
    "brunrödasts": "brunröd",
    "brunröde": "brunröd",
    "brunrödes": "brunröd",
    "brunröds": "brunröd",
    "brunrötan": "brunröta",
    "brunrötans": "brunröta",
    "brunrötas": "brunröta",
    "brunröte": "brunröta",
    "brunrött": "brunröd",
    "brunrötts": "brunröd",
    "bruns": "brun",
    "brunskjort": "brunskjorta",
    "brunskjortan": "brunskjorta",
    "brunskjortans": "brunskjorta",
    "brunskjortas": "brunskjorta",
    "brunskjorte": "brunskjorta",
    "brunskjortor": "brunskjorta",
    "brunskjortorna": "brunskjorta",
    "brunskjortornas": "brunskjorta",
    "brunskjortors": "brunskjorta",
    "brunskjorts": "brunskjorta",
    "brunskär": "brunskära",
    "brunskäran": "brunskära",
    "brunskärans": "brunskära",
    "brunskäras": "brunskära",
    "brunskäre": "brunskära",
    "brunskäror": "brunskära",
    "brunskärorna": "brunskära",
    "brunskärornas": "brunskära",
    "brunskärors": "brunskära",
    "brunskärs": "brunskära",
    "brunsten": "brunst",
    "brunstenen": "brunsten",
    "brunstenens": "brunsten",
    "brunstens": "brunsten",
    "brunstiga": "brunstig",
    "brunstigare": "brunstig",
    "brunstigares": "brunstig",
    "brunstigas": "brunstig",
    "brunstigast": "brunstig",
    "brunstigaste": "brunstig",
    "brunstigastes": "brunstig",
    "brunstigasts": "brunstig",
    "brunstige": "brunstig",
    "brunstiges": "brunstig",
    "brunstigheten": "brunstighet",
    "brunstighetens": "brunstighet",
    "brunstighets": "brunstighet",
    "brunstigs": "brunstig",
    "brunstigt": "brunstig",
    "brunstigts": "brunstig",
    "brunsts": "brunst",
    "brunsvarta": "brunsvart",
    "brunsvartare": "brunsvart",
    "brunsvartares": "brunsvart",
    "brunsvartas": "brunsvart",
    "brunsvartast": "brunsvart",
    "brunsvartaste": "brunsvart",
    "brunsvartastes": "brunsvart",
    "brunsvartasts": "brunsvart",
    "brunsvarte": "brunsvart",
    "brunsvartes": "brunsvart",
    "brunsvarts": "brunsvart",
    "brunt": "brun",
    "bruntar": "brunte",
    "bruntarna": "brunte",
    "bruntarnas": "brunte",
    "bruntars": "brunte",
    "brunten": "brunte",
    "bruntens": "brunte",
    "bruntes": "brunte",
    "brunts": "brun",
    "brunögda": "brunögd",
    "brunögdare": "brunögd",
    "brunögdares": "brunögd",
    "brunögdas": "brunögd",
    "brunögdast": "brunögd",
    "brunögdaste": "brunögd",
    "brunögdastes": "brunögd",
    "brunögdasts": "brunögd",
    "brunögde": "brunögd",
    "brunögdes": "brunögd",
    "brunögdheten": "brunögdhet",
    "brunögdhetens": "brunögdhet",
    "brunögdhets": "brunögdhet",
    "brunögds": "brunögd",
    "brunögt": "brunögd",
    "brunögts": "brunögd",
    "brunörten": "brunört",
    "brunörtens": "brunört",
    "brunörter": "brunört",
    "brunörterna": "brunört",
    "brunörternas": "brunört",
    "brunörters": "brunört",
    "brunörts": "brunört",
    "brus": "brusa",
    "brusade": "brusa",
    "brusades": "brusa",
    "brusande": "brusa",
    "brusanden": "brusande",
    "brusandena": "brusande",
    "brusandenas": "brusande",
    "brusandens": "brusande",
    "brusandes": "brusande",
    "brusandet": "brusande",
    "brusandets": "brusande",
    "brusar": "brusa",
    "brusas": "brusa",
    "brusat": "brusa",
    "brusats": "brusa",
    "bruset": "brus",
    "brusets": "brus",
    "brushan": "brushane",
    "brushanar": "brushane",
    "brushanarna": "brushane",
    "brushanarnas": "brushane",
    "brushanars": "brushane",
    "brushanen": "brushane",
    "brushanens": "brushane",
    "brushanes": "brushane",
    "brushans": "brushane",
    "brushuvuden": "brushuvud",
    "brushuvudena": "brushuvud",
    "brushuvudenas": "brushuvud",
    "brushuvudens": "brushuvud",
    "brushuvudet": "brushuvud",
    "brushuvudets": "brushuvud",
    "brushuvuds": "brushuvud",
    "brustabletten": "brustablett",
    "brustablettens": "brustablett",
    "brustabletter": "brustablett",
    "brustabletterna": "brustablett",
    "brustabletternas": "brustablett",
    "brustabletters": "brustablett",
    "brustabletts": "brustablett",
    "bruste": "brista",
    "brusten": "brista",
    "brustenheten": "brustenhet",
    "brustenhetens": "brustenhet",
    "brustenhets": "brustenhet",
    "brustens": "brusten",
    "brustes": "brista",
    "brustet": "brusten",
    "brustets": "brusten",
    "brustit": "brista",
    "brustits": "brista",
    "brustna": "brusten",
    "brustnare": "brusten",
    "brustnares": "brusten",
    "brustnas": "brusten",
    "brustnast": "brusten",
    "brustnaste": "brusten",
    "brustnastes": "brusten",
    "brustnasts": "brusten",
    "brustne": "brusten",
    "brustnes": "brusten",
    "brutala": "brutal",
    "brutalare": "brutal",
    "brutalares": "brutal",
    "brutalas": "brutal",
    "brutalast": "brutal",
    "brutalaste": "brutal",
    "brutalastes": "brutal",
    "brutalasts": "brutal",
    "brutale": "brutal",
    "brutales": "brutal",
    "brutaliserad": "brutalisera",
    "brutaliserade": "brutalisera",
    "brutaliserades": "brutalisera",
    "brutaliserads": "brutalisera",
    "brutaliserande": "brutalisera",
    "brutaliseranden": "brutaliserande",
    "brutaliserandena": "brutaliserande",
    "brutaliserandenas": "brutaliserande",
    "brutaliserandens": "brutaliserande",
    "brutaliserandes": "brutaliserande",
    "brutaliserandet": "brutaliserande",
    "brutaliserandets": "brutaliserande",
    "brutaliserar": "brutalisera",
    "brutaliseras": "brutalisera",
    "brutaliserat": "brutalisera",
    "brutaliserats": "brutalisera",
    "brutaliserbara": "brutaliserbar",
    "brutaliserbarare": "brutaliserbar",
    "brutaliserbarares": "brutaliserbar",
    "brutaliserbaras": "brutaliserbar",
    "brutaliserbarast": "brutaliserbar",
    "brutaliserbaraste": "brutaliserbar",
    "brutaliserbarastes": "brutaliserbar",
    "brutaliserbarasts": "brutaliserbar",
    "brutaliserbare": "brutaliserbar",
    "brutaliserbares": "brutaliserbar",
    "brutaliserbarheten": "brutaliserbarhet",
    "brutaliserbarhetens": "brutaliserbarhet",
    "brutaliserbarhets": "brutaliserbarhet",
    "brutaliserbars": "brutaliserbar",
    "brutaliserbart": "brutaliserbar",
    "brutaliserbarts": "brutaliserbar",
    "brutaliseringar": "brutalisering",
    "brutaliseringarna": "brutalisering",
    "brutaliseringarnas": "brutalisering",
    "brutaliseringars": "brutalisering",
    "brutaliseringen": "brutalisering",
    "brutaliseringens": "brutalisering",
    "brutaliserings": "brutalisering",
    "brutaliteten": "brutalitet",
    "brutalitetens": "brutalitet",
    "brutaliteter": "brutalitet",
    "brutaliteterna": "brutalitet",
    "brutaliteternas": "brutalitet",
    "brutaliteters": "brutalitet",
    "brutalitets": "brutalitet",
    "brutals": "brutal",
    "brutalt": "brutal",
    "brutalts": "brutal",
    "bruten": "bryta",
    "brutens": "bryta",
    "brutet": "bryta",
    "brutets": "bryta",
    "brutit": "bryta",
    "brutits": "bryta",
    "brutna": "bryta",
    "brutnas": "bryta",
    "brutne": "bryta",
    "brutnes": "bryta",
    "brutt": "brutta",
    "bruttan": "brutta",
    "bruttans": "brutta",
    "bruttas": "brutta",
    "brutte": "brutta",
    "bruttobehållningar": "bruttobehållning",
    "bruttobehållningarna": "bruttobehållning",
    "bruttobehållningarnas": "bruttobehållning",
    "bruttobehållningars": "bruttobehållning",
    "bruttobehållningen": "bruttobehållning",
    "bruttobehållningens": "bruttobehållning",
    "bruttobehållnings": "bruttobehållning",
    "bruttodräktigheten": "bruttodräktighet",
    "bruttodräktighetens": "bruttodräktighet",
    "bruttodräktigheter": "bruttodräktighet",
    "bruttodräktigheterna": "bruttodräktighet",
    "bruttodräktigheternas": "bruttodräktighet",
    "bruttodräktigheters": "bruttodräktighet",
    "bruttodräktighets": "bruttodräktighet",
    "bruttoformeln": "bruttoformel",
    "bruttoformelns": "bruttoformel",
    "bruttoformels": "bruttoformel",
    "bruttoformler": "bruttoformel",
    "bruttoformlerna": "bruttoformel",
    "bruttoformlernas": "bruttoformel",
    "bruttoformlers": "bruttoformel",
    "bruttoinkomsten": "bruttoinkomst",
    "bruttoinkomstens": "bruttoinkomst",
    "bruttoinkomster": "bruttoinkomst",
    "bruttoinkomsterna": "bruttoinkomst",
    "bruttoinkomsternas": "bruttoinkomst",
    "bruttoinkomsters": "bruttoinkomst",
    "bruttoinkomsts": "bruttoinkomst",
    "bruttolönen": "bruttolön",
    "bruttolönens": "bruttolön",
    "bruttolöner": "bruttolön",
    "bruttolönerna": "bruttolön",
    "bruttolönernas": "bruttolön",
    "bruttolöners": "bruttolön",
    "bruttolöns": "bruttolön",
    "brutton": "brutto",
    "bruttona": "brutto",
    "bruttonas": "brutto",
    "bruttonationalprodukten": "bruttonationalprodukt",
    "bruttonationalproduktens": "bruttonationalprodukt",
    "bruttonationalprodukter": "bruttonationalprodukt",
    "bruttonationalprodukterna": "bruttonationalprodukt",
    "bruttonationalprodukternas": "bruttonationalprodukt",
    "bruttonationalprodukters": "bruttonationalprodukt",
    "bruttonationalprodukts": "bruttonationalprodukt",
    "bruttons": "brutto",
    "bruttoprisen": "bruttopris",
    "bruttoprisens": "bruttopris",
    "bruttopriser": "bruttopris",
    "bruttopriserna": "bruttopris",
    "bruttoprisernas": "bruttopris",
    "bruttoprisers": "bruttopris",
    "bruttopriset": "bruttopris",
    "bruttoprisets": "bruttopris",
    "bruttor": "brutta",
    "bruttoregistertonnen": "bruttoregisterton",
    "bruttoregistertonnens": "bruttoregisterton",
    "bruttoregistertonnet": "bruttoregisterton",
    "bruttoregistertonnets": "bruttoregisterton",
    "bruttoregistertons": "bruttoregisterton",
    "bruttorna": "brutta",
    "bruttornas": "brutta",
    "bruttors": "brutta",
    "bruttos": "brutto",
    "bruttot": "brutto",
    "bruttots": "brutto",
    "bruttovikten": "bruttovikt",
    "bruttoviktens": "bruttovikt",
    "bruttovikts": "bruttovikt",
    "brutts": "brutta",
    "brydd": "bry",
    "brydda": "brydd",
    "bryddare": "brydd",
    "bryddares": "brydd",
    "bryddas": "brydd",
    "bryddast": "brydd",
    "bryddaste": "brydd",
    "bryddastes": "brydd",
    "bryddasts": "brydd",
    "brydde": "brydd",
    "bryddes": "brydd",
    "bryddheten": "bryddhet",
    "bryddhetens": "bryddhet",
    "bryddhets": "bryddhet",
    "brydds": "brydd",
    "bryderier": "bryderi",
    "bryderierna": "bryderi",
    "bryderiernas": "bryderi",
    "bryderiers": "bryderi",
    "bryderiet": "bryderi",
    "bryderiets": "bryderi",
    "bryderis": "bryderi",
    "bryderit": "bryderi",
    "bryderits": "bryderi",
    "brydsamheten": "brydsamhet",
    "brydsamhetens": "brydsamhet",
    "brydsamhets": "brydsamhet",
    "brydsamma": "brydsam",
    "brydsammare": "brydsam",
    "brydsammares": "brydsam",
    "brydsammas": "brydsam",
    "brydsammast": "brydsam",
    "brydsammaste": "brydsam",
    "brydsammastes": "brydsam",
    "brydsammasts": "brydsam",
    "brydsamme": "brydsam",
    "brydsammes": "brydsam",
    "brydsams": "brydsam",
    "brydsamt": "brydsam",
    "brydsamts": "brydsam",
    "bryende": "bry",
    "bryenden": "bryende",
    "bryendena": "bryende",
    "bryendenas": "bryende",
    "bryendens": "bryende",
    "bryendes": "bryende",
    "bryendet": "bryende",
    "bryendets": "bryende",
    "brygden": "brygd",
    "brygdens": "brygd",
    "brygder": "brygd",
    "brygderna": "brygd",
    "brygdernas": "brygd",
    "brygders": "brygd",
    "brygds": "brygd",
    "brygg": "brygga",
    "bryggan": "brygga",
    "bryggande": "brygga",
    "brygganden": "bryggande",
    "bryggandena": "bryggande",
    "bryggandenas": "bryggande",
    "bryggandens": "bryggande",
    "bryggandes": "bryggande",
    "bryggandet": "bryggande",
    "bryggandets": "bryggande",
    "bryggans": "brygga",
    "bryggar": "bryggare",
    "bryggaren": "bryggare",
    "bryggarens": "bryggare",
    "bryggares": "bryggare",
    "bryggarna": "bryggare",
    "bryggarnas": "bryggare",
    "bryggas": "brygga",
    "bryggd": "brygga",
    "bryggda": "brygga",
    "bryggdas": "brygga",
    "bryggde": "brygga",
    "bryggdes": "brygga",
    "bryggds": "brygga",
    "brygge": "brygga",
    "brygger": "brygga",
    "bryggerier": "bryggeri",
    "bryggerierna": "bryggeri",
    "bryggeriernas": "bryggeri",
    "bryggeriers": "bryggeri",
    "bryggeriet": "bryggeri",
    "bryggeriets": "bryggeri",
    "bryggerijästen": "bryggerijäst",
    "bryggerijästens": "bryggerijäst",
    "bryggerijästs": "bryggerijäst",
    "bryggerijättar": "bryggerijätte",
    "bryggerijättarna": "bryggerijätte",
    "bryggerijättarnas": "bryggerijätte",
    "bryggerijättars": "bryggerijätte",
    "bryggerijätten": "bryggerijätte",
    "bryggerijättens": "bryggerijätte",
    "bryggerijättes": "bryggerijätte",
    "bryggeris": "bryggeri",
    "bryggerit": "bryggeri",
    "bryggerits": "bryggeri",
    "brygges": "brygga",
    "brygghusen": "brygghus",
    "brygghusens": "brygghus",
    "brygghuset": "brygghus",
    "brygghusets": "brygghus",
    "bryggjästen": "bryggjäst",
    "bryggjästens": "bryggjäst",
    "bryggjästs": "bryggjäst",
    "bryggkaffen": "bryggkaffe",
    "bryggkaffena": "bryggkaffe",
    "bryggkaffenas": "bryggkaffe",
    "bryggkaffens": "bryggkaffe",
    "bryggkaffes": "bryggkaffe",
    "bryggkaffet": "bryggkaffe",
    "bryggkaffets": "bryggkaffe",
    "bryggkanten": "bryggkant",
    "bryggkantens": "bryggkant",
    "bryggkanter": "bryggkant",
    "bryggkanterna": "bryggkant",
    "bryggkanternas": "bryggkant",
    "bryggkanters": "bryggkant",
    "bryggkants": "bryggkant",
    "bryggmalda": "bryggmald",
    "bryggmaldare": "bryggmald",
    "bryggmaldares": "bryggmald",
    "bryggmaldas": "bryggmald",
    "bryggmaldast": "bryggmald",
    "bryggmaldaste": "bryggmald",
    "bryggmaldastes": "bryggmald",
    "bryggmaldasts": "bryggmald",
    "bryggmalde": "bryggmald",
    "bryggmaldes": "bryggmald",
    "bryggmalds": "bryggmald",
    "bryggmalens": "bryggmalen",
    "bryggmalet": "bryggmalen",
    "bryggmalets": "bryggmalen",
    "bryggmalna": "bryggmalen",
    "bryggmalnare": "bryggmalen",
    "bryggmalnares": "bryggmalen",
    "bryggmalnas": "bryggmalen",
    "bryggmalnast": "bryggmalen",
    "bryggmalnaste": "bryggmalen",
    "bryggmalnastes": "bryggmalen",
    "bryggmalnasts": "bryggmalen",
    "bryggmalne": "bryggmalen",
    "bryggmalnes": "bryggmalen",
    "bryggmalt": "bryggmald",
    "bryggmalts": "bryggmald",
    "bryggor": "brygga",
    "bryggorna": "brygga",
    "bryggornas": "brygga",
    "bryggors": "brygga",
    "bryggs": "brygga",
    "bryggt": "brygga",
    "bryggts": "brygga",
    "bryggvågar": "bryggvåg",
    "bryggvågarna": "bryggvåg",
    "bryggvågarnas": "bryggvåg",
    "bryggvågars": "bryggvåg",
    "bryggvågen": "bryggvåg",
    "bryggvågens": "bryggvåg",
    "bryggvågs": "bryggvåg",
    "bryllingar": "brylling",
    "bryllingarna": "brylling",
    "bryllingarnas": "brylling",
    "bryllingars": "brylling",
    "bryllingen": "brylling",
    "bryllingens": "brylling",
    "bryllings": "brylling",
    "brylåer": "brylå",
    "brylåerna": "brylå",
    "brylåernas": "brylå",
    "brylåers": "brylå",
    "brylån": "brylå",
    "brylåns": "brylå",
    "brylås": "brylå",
    "brylépuddingar": "brylépudding",
    "brylépuddingarna": "brylépudding",
    "brylépuddingarnas": "brylépudding",
    "brylépuddingars": "brylépudding",
    "brylépuddingen": "brylépudding",
    "brylépuddingens": "brylépudding",
    "brylépuddings": "brylépudding",
    "bryn": "bryna",
    "brynande": "bryna",
    "brynanden": "brynande",
    "brynandena": "brynande",
    "brynandenas": "brynande",
    "brynandens": "brynande",
    "brynandes": "brynande",
    "brynandet": "brynande",
    "brynandets": "brynande",
    "brynas": "bryna",
    "brynen": "bryne",
    "brynena": "bryne",
    "brynenas": "bryne",
    "brynens": "bryne",
    "bryner": "bryna",
    "brynes": "bryne",
    "brynet": "bryne",
    "brynets": "bryne",
    "brynjan": "brynja",
    "brynjans": "brynja",
    "brynjas": "brynja",
    "brynje": "brynja",
    "brynjor": "brynja",
    "brynjorna": "brynja",
    "brynjornas": "brynja",
    "brynjors": "brynja",
    "bryns": "bryne",
    "brynseten": "brynset",
    "brynsetens": "brynset",
    "brynsetet": "brynset",
    "brynsetets": "brynset",
    "brynsets": "brynset",
    "brynstenar": "brynsten",
    "brynstenarna": "brynsten",
    "brynstenarnas": "brynsten",
    "brynstenars": "brynsten",
    "brynstenen": "brynsten",
    "brynstenens": "brynsten",
    "brynstens": "brynsten",
    "brynstålen": "brynstål",
    "brynstålens": "brynstål",
    "brynstålet": "brynstål",
    "brynstålets": "brynstål",
    "brynståls": "brynstål",
    "brynt": "bryna",
    "brynta": "bryna",
    "bryntas": "bryna",
    "brynte": "bryna",
    "bryntes": "bryna",
    "brynts": "bryna",
    "bryologen": "bryolog",
    "bryologens": "bryolog",
    "bryologer": "bryolog",
    "bryologerna": "bryolog",
    "bryologernas": "bryolog",
    "bryologers": "bryolog",
    "bryologien": "bryologi",
    "bryologiens": "bryologi",
    "bryologin": "bryologi",
    "bryologins": "bryologi",
    "bryologis": "bryologi",
    "bryologs": "bryolog",
    "bryr": "bry",
    "brys": "bry",
    "bryska": "brysk",
    "bryskare": "brysk",
    "bryskares": "brysk",
    "bryskas": "brysk",
    "bryskast": "brysk",
    "bryskaste": "brysk",
    "bryskastes": "brysk",
    "bryskasts": "brysk",
    "bryske": "brysk",
    "bryskes": "brysk",
    "bryskheten": "bryskhet",
    "bryskhetens": "bryskhet",
    "bryskhets": "bryskhet",
    "brysks": "brysk",
    "bryskt": "brysk",
    "bryskts": "brysk",
    "brysselkålen": "brysselkål",
    "brysselkålens": "brysselkål",
    "brysselkåls": "brysselkål",
    "brysselmatt": "brysselmatta",
    "brysselmattan": "brysselmatta",
    "brysselmattans": "brysselmatta",
    "brysselmattas": "brysselmatta",
    "brysselmatte": "brysselmatta",
    "brysselmattor": "brysselmatta",
    "brysselmattorna": "brysselmatta",
    "brysselmattornas": "brysselmatta",
    "brysselmattors": "brysselmatta",
    "brysselmatts": "brysselmatta",
    "brysselspetsar": "brysselspets",
    "brysselspetsarna": "brysselspets",
    "brysselspetsarnas": "brysselspets",
    "brysselspetsars": "brysselspets",
    "brysselspetsen": "brysselspets",
    "brysselspetsens": "brysselspets",
    "bryt": "bryte",
    "brytande": "bryta",
    "brytanden": "brytande",
    "brytandena": "brytande",
    "brytandenas": "brytande",
    "brytandens": "brytande",
    "brytandes": "brytande",
    "brytandet": "brytande",
    "brytandets": "brytande",
    "brytar": "bryte",
    "brytaren": "brytare",
    "brytarens": "brytare",
    "brytares": "brytare",
    "brytarfelen": "brytarfel",
    "brytarfelens": "brytarfel",
    "brytarfelet": "brytarfel",
    "brytarfelets": "brytarfel",
    "brytarfels": "brytarfel",
    "brytarna": "bryte",
    "brytarnas": "bryte",
    "brytars": "bryte",
    "brytas": "bryta",
    "brytbladen": "brytblad",
    "brytbladens": "brytblad",
    "brytbladet": "brytblad",
    "brytbladets": "brytblad",
    "brytblads": "brytblad",
    "brytbladsknivar": "brytbladskniv",
    "brytbladsknivarna": "brytbladskniv",
    "brytbladsknivarnas": "brytbladskniv",
    "brytbladsknivars": "brytbladskniv",
    "brytbladskniven": "brytbladskniv",
    "brytbladsknivens": "brytbladskniv",
    "brytbladsknivs": "brytbladskniv",
    "brytbön": "brytböna",
    "brytbönan": "brytböna",
    "brytbönans": "brytböna",
    "brytbönas": "brytböna",
    "brytböne": "brytböna",
    "brytbönor": "brytböna",
    "brytbönorna": "brytböna",
    "brytbönornas": "brytböna",
    "brytbönors": "brytböna",
    "brytböns": "brytböna",
    "bryte": "bryta",
    "bryten": "bryte",
    "brytens": "bryte",
    "bryter": "bryta",
    "brytes": "bryte",
    "brytningar": "brytning",
    "brytningarna": "brytning",
    "brytningarnas": "brytning",
    "brytningars": "brytning",
    "brytningen": "brytning",
    "brytningens": "brytning",
    "brytnings": "brytning",
    "brytningsexponenten": "brytningsexponent",
    "brytningsexponentens": "brytningsexponent",
    "brytningsexponenter": "brytningsexponent",
    "brytningsexponenterna": "brytningsexponent",
    "brytningsexponenternas": "brytningsexponent",
    "brytningsexponenters": "brytningsexponent",
    "brytningsexponents": "brytningsexponent",
    "brytningsfelen": "brytningsfel",
    "brytningsfelens": "brytningsfel",
    "brytningsfelet": "brytningsfel",
    "brytningsfelets": "brytningsfel",
    "brytningsfels": "brytningsfel",
    "brytningsförmågan": "brytningsförmåga",
    "brytningsförmågans": "brytningsförmåga",
    "brytningsförmågas": "brytningsförmåga",
    "brytningsförmåge": "brytningsförmåga",
    "brytningsförmågor": "brytningsförmåga",
    "brytningsförmågorna": "brytningsförmåga",
    "brytningsförmågornas": "brytningsförmåga",
    "brytningsförmågors": "brytningsförmåga",
    "brytningsgränsen": "brytningsgräns",
    "brytningsgränsens": "brytningsgräns",
    "brytningsindexen": "brytningsindex",
    "brytningsindexens": "brytningsindex",
    "brytningsindexet": "brytningsindex",
    "brytningsindexets": "brytningsindex",
    "brytningspunkten": "brytningspunkt",
    "brytningspunktens": "brytningspunkt",
    "brytningspunkter": "brytningspunkt",
    "brytningspunkterna": "brytningspunkt",
    "brytningspunkternas": "brytningspunkt",
    "brytningspunkters": "brytningspunkt",
    "brytningspunkts": "brytningspunkt",
    "brytningstiden": "brytningstid",
    "brytningstidens": "brytningstid",
    "brytningstider": "brytningstid",
    "brytningstiderna": "brytningstid",
    "brytningstidernas": "brytningstid",
    "brytningstiders": "brytningstid",
    "brytningstids": "brytningstid",
    "brytningsvinkeln": "brytningsvinkel",
    "brytningsvinkelns": "brytningsvinkel",
    "brytningsvinkels": "brytningsvinkel",
    "brytningsvinklar": "brytningsvinkel",
    "brytningsvinklarna": "brytningsvinkel",
    "brytningsvinklarnas": "brytningsvinkel",
    "brytningsvinklars": "brytningsvinkel",
    "brytningsåren": "brytningsår",
    "brytningsårens": "brytningsår",
    "brytningsåret": "brytningsår",
    "brytningsårets": "brytningsår",
    "brytningsårs": "brytningsår",
    "brytpunkten": "brytpunkt",
    "brytpunktens": "brytpunkt",
    "brytpunkter": "brytpunkt",
    "brytpunkterna": "brytpunkt",
    "brytpunkternas": "brytpunkt",
    "brytpunkters": "brytpunkt",
    "brytpunkts": "brytpunkt",
    "bryts": "bryte",
    "brytt": "brydd",
    "brytts": "brydd",
    "brytvapens": "brytvapen",
    "brytvapnen": "brytvapen",
    "brytvapnens": "brytvapen",
    "brytvapnet": "brytvapen",
    "brytvapnets": "brytvapen",
    "bräck": "bräcka",
    "bräckages": "bräckage",
    "bräckaget": "bräckage",
    "bräckagets": "bräckage",
    "bräckande": "bräcka",
    "bräckanden": "bräckande",
    "bräckandena": "bräckande",
    "bräckandenas": "bräckande",
    "bräckandens": "bräckande",
    "bräckandes": "bräckande",
    "bräckandet": "bräckande",
    "bräckandets": "bräckande",
    "bräckas": "bräcka",
    "bräcker": "bräcka",
    "bräckes": "bräcka",
    "bräcket": "bräck",
    "bräckets": "bräck",
    "bräckhammar": "bräckhammare",
    "bräckhammaren": "bräckhammare",
    "bräckhammarens": "bräckhammare",
    "bräckhammares": "bräckhammare",
    "bräckhamrar": "bräckhammare",
    "bräckhamrarna": "bräckhammare",
    "bräckhamrarnas": "bräckhammare",
    "bräckhamrars": "bräckhammare",
    "bräckjärnen": "bräckjärn",
    "bräckjärnens": "bräckjärn",
    "bräckjärnet": "bräckjärn",
    "bräckjärnets": "bräckjärn",
    "bräckjärns": "bräckjärn",
    "bräckkorvar": "bräckkorv",
    "bräckkorvarna": "bräckkorv",
    "bräckkorvarnas": "bräckkorv",
    "bräckkorvars": "bräckkorv",
    "bräckkorven": "bräckkorv",
    "bräckkorvens": "bräckkorv",
    "bräckkorvs": "bräckkorv",
    "bräckliga": "bräcklig",
    "bräckligare": "bräcklig",
    "bräckligares": "bräcklig",
    "bräckligas": "bräcklig",
    "bräckligast": "bräcklig",
    "bräckligaste": "bräcklig",
    "bräckligastes": "bräcklig",
    "bräckligasts": "bräcklig",
    "bräcklige": "bräcklig",
    "bräckliges": "bräcklig",
    "bräckligheten": "bräcklighet",
    "bräcklighetens": "bräcklighet",
    "bräcklighets": "bräcklighet",
    "bräckligs": "bräcklig",
    "bräckligt": "bräcklig",
    "bräckligts": "bräcklig",
    "bräcks": "bräcka",
    "bräckt": "bräcka",
    "bräckta": "bräckt",
    "bräcktare": "bräckt",
    "bräcktares": "bräckt",
    "bräcktas": "bräckt",
    "bräcktast": "bräckt",
    "bräcktaste": "bräckt",
    "bräcktastes": "bräckt",
    "bräcktasts": "bräckt",
    "bräckte": "bräckt",
    "bräcktes": "bräckt",
    "bräcktheten": "bräckthet",
    "bräckthetens": "bräckthet",
    "bräckthets": "bräckthet",
    "bräckts": "bräckt",
    "bräckvattens": "bräckvatten",
    "bräckvattnen": "bräckvatten",
    "bräckvattnens": "bräckvatten",
    "bräckvattnet": "bräckvatten",
    "bräckvattnets": "bräckvatten",
    "brädad": "bräda",
    "brädade": "bräda",
    "brädades": "bräda",
    "brädads": "bräda",
    "brädan": "bräda",
    "brädande": "bräda",
    "brädanden": "brädande",
    "brädandena": "brädande",
    "brädandenas": "brädande",
    "brädandens": "brädande",
    "brädandes": "brädande",
    "brädandet": "brädande",
    "brädandets": "brädande",
    "brädans": "bräda",
    "brädar": "bräda",
    "brädas": "bräda",
    "brädat": "bräda",
    "brädats": "bräda",
    "brädbekläd": "brädbeklä",
    "brädbekläda": "brädbeklä",
    "brädbeklädande": "brädbeklä",
    "brädbeklädanden": "brädbeklädande",
    "brädbeklädandena": "brädbeklädande",
    "brädbeklädandenas": "brädbeklädande",
    "brädbeklädandens": "brädbeklädande",
    "brädbeklädandes": "brädbeklädande",
    "brädbeklädandet": "brädbeklädande",
    "brädbeklädandets": "brädbeklädande",
    "brädbeklädas": "brädbeklä",
    "brädbeklädd": "brädbeklä",
    "brädbeklädda": "brädbeklä",
    "brädbekläddas": "brädbeklä",
    "brädbeklädde": "brädbeklä",
    "brädbekläddes": "brädbeklä",
    "brädbeklädds": "brädbeklä",
    "brädbekläder": "brädbeklä",
    "brädbekläds": "brädbeklä",
    "brädbekläende": "brädbeklä",
    "brädbekläendes": "brädbeklä",
    "brädbeklär": "brädbeklä",
    "brädbekläs": "brädbeklä",
    "brädbeklätt": "brädbeklä",
    "brädbeklätts": "brädbeklä",
    "brädbeslagen": "brädbeslå",
    "brädbeslagens": "brädbeslå",
    "brädbeslaget": "brädbeslå",
    "brädbeslagets": "brädbeslå",
    "brädbeslagit": "brädbeslå",
    "brädbeslagits": "brädbeslå",
    "brädbeslagna": "brädbeslå",
    "brädbeslagnas": "brädbeslå",
    "brädbeslagne": "brädbeslå",
    "brädbeslagnes": "brädbeslå",
    "brädbeslog": "brädbeslå",
    "brädbesloge": "brädbeslå",
    "brädbesloges": "brädbeslå",
    "brädbeslogs": "brädbeslå",
    "brädbeslående": "brädbeslå",
    "brädbeslåenden": "brädbeslående",
    "brädbeslåendena": "brädbeslående",
    "brädbeslåendenas": "brädbeslående",
    "brädbeslåendens": "brädbeslående",
    "brädbeslåendes": "brädbeslående",
    "brädbeslåendet": "brädbeslående",
    "brädbeslåendets": "brädbeslående",
    "brädbeslår": "brädbeslå",
    "brädbeslås": "brädbeslå",
    "brädd": "brädda",
    "bräddad": "brädda",
    "bräddade": "brädda",
    "bräddades": "brädda",
    "bräddads": "brädda",
    "bräddande": "brädda",
    "bräddanden": "bräddande",
    "bräddandena": "bräddande",
    "bräddandenas": "bräddande",
    "bräddandens": "bräddande",
    "bräddandes": "bräddande",
    "bräddandet": "bräddande",
    "bräddandets": "bräddande",
    "bräddar": "brädda",
    "bräddarna": "brädd",
    "bräddarnas": "brädd",
    "bräddars": "brädd",
    "bräddas": "brädda",
    "bräddat": "brädda",
    "bräddats": "brädda",
    "bräddavloppen": "bräddavlopp",
    "bräddavloppens": "bräddavlopp",
    "bräddavloppet": "bräddavlopp",
    "bräddavloppets": "bräddavlopp",
    "bräddavlopps": "bräddavlopp",
    "brädden": "brädd",
    "bräddens": "brädd",
    "bräddfulla": "bräddfull",
    "bräddfullare": "bräddfull",
    "bräddfullares": "bräddfull",
    "bräddfullas": "bräddfull",
    "bräddfullast": "bräddfull",
    "bräddfullaste": "bräddfull",
    "bräddfullastes": "bräddfull",
    "bräddfullasts": "bräddfull",
    "bräddfulle": "bräddfull",
    "bräddfulles": "bräddfull",
    "bräddfullheten": "bräddfullhet",
    "bräddfullhetens": "bräddfullhet",
    "bräddfullhets": "bräddfullhet",
    "bräddfulls": "bräddfull",
    "bräddfullt": "bräddfull",
    "bräddfullts": "bräddfull",
    "bräddfyllda": "bräddfylld",
    "bräddfylldare": "bräddfylld",
    "bräddfylldares": "bräddfylld",
    "bräddfylldas": "bräddfylld",
    "bräddfylldast": "bräddfylld",
    "bräddfylldaste": "bräddfylld",
    "bräddfylldastes": "bräddfylld",
    "bräddfylldasts": "bräddfylld",
    "bräddfyllde": "bräddfylld",
    "bräddfylldes": "bräddfylld",
    "bräddfylldheten": "bräddfylldhet",
    "bräddfylldhetens": "bräddfylldhet",
    "bräddfylldhets": "bräddfylldhet",
    "bräddfyllds": "bräddfylld",
    "bräddfyllt": "bräddfylld",
    "bräddfyllts": "bräddfylld",
    "brädds": "brädd",
    "bräden": "bräde",
    "brädena": "bräde",
    "brädenas": "bräde",
    "brädens": "bräde",
    "bräder": "bräda",
    "bräderna": "bräda",
    "brädernas": "bräda",
    "bräders": "bräda",
    "brädes": "bräde",
    "brädet": "bräde",
    "brädets": "bräde",
    "brädfodrad": "brädfodra",
    "brädfodrade": "brädfodra",
    "brädfodrades": "brädfodra",
    "brädfodrads": "brädfodra",
    "brädfodrande": "brädfodra",
    "brädfodranden": "brädfodrande",
    "brädfodrandena": "brädfodrande",
    "brädfodrandenas": "brädfodrande",
    "brädfodrandens": "brädfodrande",
    "brädfodrandes": "brädfodrande",
    "brädfodrandet": "brädfodrande",
    "brädfodrandets": "brädfodrande",
    "brädfodrar": "brädfodra",
    "brädfodras": "brädfodra",
    "brädfodrat": "brädfodra",
    "brädfodrats": "brädfodra",
    "brädgångar": "brädgång",
    "brädgångarna": "brädgång",
    "brädgångarnas": "brädgång",
    "brädgångars": "brädgång",
    "brädgången": "brädgång",
    "brädgångens": "brädgång",
    "brädgångs": "brädgång",
    "brädgårdar": "brädgård",
    "brädgårdarna": "brädgård",
    "brädgårdarnas": "brädgård",
    "brädgårdars": "brädgård",
    "brädgården": "brädgård",
    "brädgårdens": "brädgård",
    "brädgårds": "brädgård",
    "brädor": "bräda",
    "brädorna": "bräda",
    "brädornas": "bräda",
    "brädors": "bräda",
    "brädplanken": "brädplank",
    "brädplankens": "brädplank",
    "brädplanket": "brädplank",
    "brädplankets": "brädplank",
    "brädplanks": "brädplank",
    "bräds": "bräde",
    "brädseglad": "brädsegla",
    "brädseglade": "brädsegla",
    "brädseglades": "brädsegla",
    "brädseglads": "brädsegla",
    "brädseglande": "brädsegla",
    "brädseglanden": "brädseglande",
    "brädseglandena": "brädseglande",
    "brädseglandenas": "brädseglande",
    "brädseglandens": "brädseglande",
    "brädseglandes": "brädseglande",
    "brädseglandet": "brädseglande",
    "brädseglandets": "brädseglande",
    "brädseglar": "brädsegla",
    "brädseglas": "brädsegla",
    "brädseglat": "brädsegla",
    "brädseglats": "brädsegla",
    "brädslagen": "brädslå",
    "brädslagens": "brädslå",
    "brädslaget": "brädslå",
    "brädslagets": "brädslå",
    "brädslagit": "brädslå",
    "brädslagits": "brädslå",
    "brädslagna": "brädslå",
    "brädslagnas": "brädslå",
    "brädslagne": "brädslå",
    "brädslagnes": "brädslå",
    "brädslog": "brädslå",
    "brädsloge": "brädslå",
    "brädsloges": "brädslå",
    "brädslogs": "brädslå",
    "brädslående": "brädslå",
    "brädslåenden": "brädslående",
    "brädslåendena": "brädslående",
    "brädslåendenas": "brädslående",
    "brädslåendens": "brädslående",
    "brädslåendes": "brädslående",
    "brädslåendet": "brädslående",
    "brädslåendets": "brädslående",
    "brädslår": "brädslå",
    "brädslås": "brädslå",
    "brädspelen": "brädspel",
    "brädspelens": "brädspel",
    "brädspelet": "brädspel",
    "brädspelets": "brädspel",
    "brädspels": "brädspel",
    "brädväggar": "brädvägg",
    "brädväggarna": "brädvägg",
    "brädväggarnas": "brädvägg",
    "brädväggars": "brädvägg",
    "brädväggen": "brädvägg",
    "brädväggens": "brädvägg",
    "brädväggs": "brädvägg",
    "bräk": "bräka",
    "bräkande": "bräka",
    "bräkanden": "bräkande",
    "bräkandena": "bräkande",
    "bräkandenas": "bräkande",
    "bräkandens": "bräkande",
    "bräkandes": "bräkande",
    "bräkandet": "bräkande",
    "bräkandets": "bräkande",
    "bräkas": "bräka",
    "bräkens": "bräken",
    "bräker": "bräka",
    "bräkes": "bräka",
    "bräknar": "bräken",
    "bräknarna": "bräken",
    "bräknarnas": "bräken",
    "bräknars": "bräken",
    "bräknen": "bräken",
    "bräknens": "bräken",
    "bräks": "bräka",
    "bräkt": "bräka",
    "bräkte": "bräka",
    "bräktes": "bräka",
    "bräkts": "bräka",
    "bräm": "bräma",
    "brämad": "bräma",
    "brämade": "bräma",
    "brämades": "bräma",
    "brämads": "bräma",
    "brämande": "bräma",
    "brämanden": "brämande",
    "brämandena": "brämande",
    "brämandenas": "brämande",
    "brämandens": "brämande",
    "brämandes": "brämande",
    "brämandet": "brämande",
    "brämandets": "brämande",
    "brämar": "bräma",
    "brämas": "bräma",
    "brämat": "bräma",
    "brämats": "bräma",
    "brämen": "bräm",
    "brämens": "bräm",
    "brämet": "bräm",
    "brämets": "bräm",
    "bräms": "bräm",
    "bränd": "bränna",
    "brända": "bränna",
    "brändas": "bränna",
    "brände": "bränna",
    "bränder": "brand",
    "bränderna": "brand",
    "brändernas": "brand",
    "bränders": "brand",
    "brändes": "brännas",
    "bränds": "bränna",
    "bränn": "bränna",
    "brännande": "bränna",
    "brännanden": "brännande",
    "brännandena": "brännande",
    "brännandenas": "brännande",
    "brännandens": "brännande",
    "brännandes": "brännande",
    "brännandet": "brännande",
    "brännandets": "brännande",
    "brännar": "brännare",
    "brännaren": "brännare",
    "brännarens": "brännare",
    "brännares": "brännare",
    "brännarna": "brännare",
    "brännarnas": "brännare",
    "brännas": "bränna",
    "brännbara": "brännbar",
    "brännbarare": "brännbar",
    "brännbarares": "brännbar",
    "brännbaras": "brännbar",
    "brännbarast": "brännbar",
    "brännbaraste": "brännbar",
    "brännbarastes": "brännbar",
    "brännbarasts": "brännbar",
    "brännbare": "brännbar",
    "brännbares": "brännbar",
    "brännbarheten": "brännbarhet",
    "brännbarhetens": "brännbarhet",
    "brännbarhets": "brännbarhet",
    "brännbars": "brännbar",
    "brännbart": "brännbar",
    "brännbarts": "brännbar",
    "brännblås": "brännblåsa",
    "brännblåsan": "brännblåsa",
    "brännblåsans": "brännblåsa",
    "brännblåsas": "brännblåsa",
    "brännblåse": "brännblåsa",
    "brännblåsor": "brännblåsa",
    "brännblåsorna": "brännblåsa",
    "brännblåsornas": "brännblåsa",
    "brännblåsors": "brännblåsa",
    "brännbollar": "brännboll",
    "brännbollarna": "brännboll",
    "brännbollarnas": "brännboll",
    "brännbollars": "brännboll",
    "brännbollen": "brännboll",
    "brännbollens": "brännboll",
    "brännbolls": "brännboll",
    "brännbollsträet": "brännbollsträ",
    "brännbollsträets": "brännbollsträ",
    "brännbollsträn": "brännbollsträ",
    "brännbollsträna": "brännbollsträ",
    "brännbollstränas": "brännbollsträ",
    "brännbollsträns": "brännbollsträ",
    "brännbollsträs": "brännbollsträ",
    "brännbollsträt": "brännbollsträ",
    "brännbollsträts": "brännbollsträ",
    "bränner": "bränna",
    "brännerier": "bränneri",
    "brännerierna": "bränneri",
    "bränneriernas": "bränneri",
    "bränneriers": "bränneri",
    "bränneriet": "bränneri",
    "bränneriets": "bränneri",
    "bränneris": "bränneri",
    "brännerit": "bränneri",
    "brännerits": "bränneri",
    "brännes": "bränne",
    "brännet": "bränne",
    "brännets": "bränne",
    "brännglasen": "brännglas",
    "brännglasens": "brännglas",
    "brännglaset": "brännglas",
    "brännglasets": "brännglas",
    "brännheta": "brännhet",
    "brännhetare": "brännhet",
    "brännhetares": "brännhet",
    "brännhetas": "brännhet",
    "brännhetast": "brännhet",
    "brännhetaste": "brännhet",
    "brännhetastes": "brännhet",
    "brännhetasts": "brännhet",
    "brännhete": "brännhet",
    "brännhetes": "brännhet",
    "brännhets": "brännhet",
    "brännhett": "brännhet",
    "brännhetts": "brännhet",
    "brännhåren": "brännhår",
    "brännhårens": "brännhår",
    "brännhåret": "brännhår",
    "brännhårets": "brännhår",
    "brännhårs": "brännhår",
    "bränningar": "bränning",
    "bränningarna": "bränning",
    "bränningarnas": "bränning",
    "bränningars": "bränning",
    "bränningen": "bränning",
    "bränningens": "bränning",
    "brännings": "bränning",
    "brännjärnen": "brännjärn",
    "brännjärnens": "brännjärn",
    "brännjärnet": "brännjärn",
    "brännjärnets": "brännjärn",
    "brännjärns": "brännjärn",
    "brännkammar": "brännkammare",
    "brännkammaren": "brännkammare",
    "brännkammarens": "brännkammare",
    "brännkammares": "brännkammare",
    "brännkammarna": "brännkammare",
    "brännkammarnas": "brännkammare",
    "brännlacken": "brännlack",
    "brännlackens": "brännlack",
    "brännlackerad": "brännlackera",
    "brännlackerade": "brännlackera",
    "brännlackerades": "brännlackera",
    "brännlackerads": "brännlackera",
    "brännlackerande": "brännlackera",
    "brännlackeranden": "brännlackerande",
    "brännlackerandena": "brännlackerande",
    "brännlackerandenas": "brännlackerande",
    "brännlackerandens": "brännlackerande",
    "brännlackerandes": "brännlackerande",
    "brännlackerandet": "brännlackerande",
    "brännlackerandets": "brännlackerande",
    "brännlackerar": "brännlackera",
    "brännlackeras": "brännlackera",
    "brännlackerat": "brännlackera",
    "brännlackerats": "brännlackera",
    "brännlackerbara": "brännlackerbar",
    "brännlackerbarare": "brännlackerbar",
    "brännlackerbarares": "brännlackerbar",
    "brännlackerbaras": "brännlackerbar",
    "brännlackerbarast": "brännlackerbar",
    "brännlackerbaraste": "brännlackerbar",
    "brännlackerbarastes": "brännlackerbar",
    "brännlackerbarasts": "brännlackerbar",
    "brännlackerbare": "brännlackerbar",
    "brännlackerbares": "brännlackerbar",
    "brännlackerbarheten": "brännlackerbarhet",
    "brännlackerbarhetens": "brännlackerbarhet",
    "brännlackerbarhets": "brännlackerbarhet",
    "brännlackerbars": "brännlackerbar",
    "brännlackerbart": "brännlackerbar",
    "brännlackerbarts": "brännlackerbar",
    "brännlackeringar": "brännlackering",
    "brännlackeringarna": "brännlackering",
    "brännlackeringarnas": "brännlackering",
    "brännlackeringars": "brännlackering",
    "brännlackeringen": "brännlackering",
    "brännlackeringens": "brännlackering",
    "brännlackerings": "brännlackering",
    "brännlacket": "brännlack",
    "brännlackets": "brännlack",
    "brännlacks": "brännlack",
    "brännmaneten": "brännmanet",
    "brännmanetens": "brännmanet",
    "brännmaneter": "brännmanet",
    "brännmaneterna": "brännmanet",
    "brännmaneternas": "brännmanet",
    "brännmaneters": "brännmanet",
    "brännmanets": "brännmanet",
    "brännmärk": "brännmärka",
    "brännmärkande": "brännmärka",
    "brännmärkanden": "brännmärkande",
    "brännmärkandena": "brännmärkande",
    "brännmärkandenas": "brännmärkande",
    "brännmärkandens": "brännmärkande",
    "brännmärkandes": "brännmärkande",
    "brännmärkandet": "brännmärkande",
    "brännmärkandets": "brännmärkande",
    "brännmärkas": "brännmärka",
    "brännmärken": "brännmärke",
    "brännmärkena": "brännmärke",
    "brännmärkenas": "brännmärke",
    "brännmärkens": "brännmärke",
    "brännmärker": "brännmärka",
    "brännmärkes": "brännmärke",
    "brännmärket": "brännmärke",
    "brännmärkets": "brännmärke",
    "brännmärks": "brännmärka",
    "brännmärkt": "brännmärka",
    "brännmärkta": "brännmärka",
    "brännmärktas": "brännmärka",
    "brännmärkte": "brännmärka",
    "brännmärktes": "brännmärka",
    "brännmärkts": "brännmärka",
    "brännoffers": "brännoffer",
    "brännoffren": "brännoffer",
    "brännoffrens": "brännoffer",
    "brännoffret": "brännoffer",
    "brännoffrets": "brännoffer",
    "brännoljan": "brännolja",
    "brännoljans": "brännolja",
    "brännoljas": "brännolja",
    "brännolje": "brännolja",
    "brännpunkten": "brännpunkt",
    "brännpunktens": "brännpunkt",
    "brännpunkter": "brännpunkt",
    "brännpunkterna": "brännpunkt",
    "brännpunkternas": "brännpunkt",
    "brännpunkters": "brännpunkt",
    "brännpunkts": "brännpunkt",
    "bränns": "brännas",
    "brännskad": "brännskada",
    "brännskadad": "brännskada",
    "brännskadade": "brännskadad",
    "brännskadades": "brännskadad",
    "brännskadads": "brännskadad",
    "brännskadan": "brännskada",
    "brännskadande": "brännskada",
    "brännskadanden": "brännskadande",
    "brännskadandena": "brännskadande",
    "brännskadandenas": "brännskadande",
    "brännskadandens": "brännskadande",
    "brännskadandes": "brännskadande",
    "brännskadandet": "brännskadande",
    "brännskadandets": "brännskadande",
    "brännskadans": "brännskada",
    "brännskadar": "brännskada",
    "brännskadas": "brännskada",
    "brännskadat": "brännskadad",
    "brännskadats": "brännskadad",
    "brännskade": "brännskada",
    "brännskador": "brännskada",
    "brännskadorna": "brännskada",
    "brännskadornas": "brännskada",
    "brännskadors": "brännskada",
    "brännstålet": "brännstål",
    "brännstålets": "brännstål",
    "brännståls": "brännstål",
    "brännsåren": "brännsår",
    "brännsårens": "brännsår",
    "brännsåret": "brännsår",
    "brännsårets": "brännsår",
    "brännsårs": "brännsår",
    "brännvidden": "brännvidd",
    "brännviddens": "brännvidd",
    "brännvidder": "brännvidd",
    "brännvidderna": "brännvidd",
    "brännviddernas": "brännvidd",
    "brännvidders": "brännvidd",
    "brännvidds": "brännvidd",
    "brännviner": "brännvin",
    "brännvinerna": "brännvin",
    "brännvinernas": "brännvin",
    "brännviners": "brännvin",
    "brännvinet": "brännvin",
    "brännvinets": "brännvin",
    "brännvins": "brännvin",
    "brännvinsadvokaten": "brännvinsadvokat",
    "brännvinsadvokatens": "brännvinsadvokat",
    "brännvinsadvokater": "brännvinsadvokat",
    "brännvinsadvokaterna": "brännvinsadvokat",
    "brännvinsadvokaternas": "brännvinsadvokat",
    "brännvinsadvokaters": "brännvinsadvokat",
    "brännvinsadvokats": "brännvinsadvokat",
    "brännvinsbasar": "brännvinsbas",
    "brännvinsbasarna": "brännvinsbas",
    "brännvinsbasarnas": "brännvinsbas",
    "brännvinsbasars": "brännvinsbas",
    "brännvinsbasen": "brännvinsbas",
    "brännvinsbasens": "brännvinsbas",
    "brännvinsbrännerier": "brännvinsbränneri",
    "brännvinsbrännerierna": "brännvinsbränneri",
    "brännvinsbränneriernas": "brännvinsbränneri",
    "brännvinsbränneriers": "brännvinsbränneri",
    "brännvinsbränneriet": "brännvinsbränneri",
    "brännvinsbränneriets": "brännvinsbränneri",
    "brännvinsbränneris": "brännvinsbränneri",
    "brännvinsbrännerit": "brännvinsbränneri",
    "brännvinsbrännerits": "brännvinsbränneri",
    "brännvinsglasen": "brännvinsglas",
    "brännvinsglasens": "brännvinsglas",
    "brännvinsglaset": "brännvinsglas",
    "brännvinsglasets": "brännvinsglas",
    "brännvinsnäs": "brännvinsnäsa",
    "brännvinsnäsan": "brännvinsnäsa",
    "brännvinsnäsans": "brännvinsnäsa",
    "brännvinsnäsas": "brännvinsnäsa",
    "brännvinsnäse": "brännvinsnäsa",
    "brännvinsnäsor": "brännvinsnäsa",
    "brännvinsnäsorna": "brännvinsnäsa",
    "brännvinsnäsornas": "brännvinsnäsa",
    "brännvinsnäsors": "brännvinsnäsa",
    "brännvinsprovar": "brännvinsprovare",
    "brännvinsprovaren": "brännvinsprovare",
    "brännvinsprovarens": "brännvinsprovare",
    "brännvinsprovares": "brännvinsprovare",
    "brännvinsprovarna": "brännvinsprovare",
    "brännvinsprovarnas": "brännvinsprovare",
    "brännytan": "brännyta",
    "brännytans": "brännyta",
    "brännytas": "brännyta",
    "brännyte": "brännyta",
    "brännytor": "brännyta",
    "brännytorna": "brännyta",
    "brännytornas": "brännyta",
    "brännytors": "brännyta",
    "brännässel": "brännässla",
    "brännässlan": "brännässla",
    "brännässlans": "brännässla",
    "brännässlas": "brännässla",
    "brännässle": "brännässla",
    "brännässlor": "brännässla",
    "brännässlorna": "brännässla",
    "brännässlornas": "brännässla",
    "brännässlors": "brännässla",
    "bränslebristen": "bränslebrist",
    "bränslebristens": "bränslebrist",
    "bränslebrists": "bränslebrist",
    "bränslecellen": "bränslecell",
    "bränslecellens": "bränslecell",
    "bränsleceller": "bränslecell",
    "bränslecellerna": "bränslecell",
    "bränslecellernas": "bränslecell",
    "bränslecellers": "bränslecell",
    "bränslecells": "bränslecell",
    "bränslecellsdrivens": "bränslecellsdriven",
    "bränslecellsdrivet": "bränslecellsdriven",
    "bränslecellsdrivets": "bränslecellsdriven",
    "bränslecellsdrivna": "bränslecellsdriven",
    "bränslecellsdrivnare": "bränslecellsdriven",
    "bränslecellsdrivnares": "bränslecellsdriven",
    "bränslecellsdrivnas": "bränslecellsdriven",
    "bränslecellsdrivnast": "bränslecellsdriven",
    "bränslecellsdrivnaste": "bränslecellsdriven",
    "bränslecellsdrivnastes": "bränslecellsdriven",
    "bränslecellsdrivnasts": "bränslecellsdriven",
    "bränslecellsdrivne": "bränslecellsdriven",
    "bränslecellsdrivnes": "bränslecellsdriven",
    "bränslecellskonstruktionen": "bränslecellskonstruktion",
    "bränslecellskonstruktionens": "bränslecellskonstruktion",
    "bränslecellskonstruktioner": "bränslecellskonstruktion",
    "bränslecellskonstruktionerna": "bränslecellskonstruktion",
    "bränslecellskonstruktionernas": "bränslecellskonstruktion",
    "bränslecellskonstruktioners": "bränslecellskonstruktion",
    "bränslecellskonstruktions": "bränslecellskonstruktion",
    "bränslecellskraftverken": "bränslecellskraftverk",
    "bränslecellskraftverkens": "bränslecellskraftverk",
    "bränslecellskraftverket": "bränslecellskraftverk",
    "bränslecellskraftverkets": "bränslecellskraftverk",
    "bränslecellskraftverks": "bränslecellskraftverk",
    "bränslecellstypen": "bränslecellstyp",
    "bränslecellstypens": "bränslecellstyp",
    "bränslecellstyper": "bränslecellstyp",
    "bränslecellstyperna": "bränslecellstyp",
    "bränslecellstypernas": "bränslecellstyp",
    "bränslecellstypers": "bränslecellstyp",
    "bränslecellstyps": "bränslecellstyp",
    "bränsleelementen": "bränsleelement",
    "bränsleelementens": "bränsleelement",
    "bränsleelementet": "bränsleelement",
    "bränsleelementets": "bränsleelement",
    "bränsleelements": "bränsleelement",
    "bränslefilterna": "bränslefilter",
    "bränslefilternas": "bränslefilter",
    "bränslefilters": "bränslefilter",
    "bränslefiltren": "bränslefilter",
    "bränslefiltrens": "bränslefilter",
    "bränslefiltret": "bränslefilter",
    "bränslefiltrets": "bränslefilter",
    "bränslefälten": "bränslefält",
    "bränslefältens": "bränslefält",
    "bränslefältet": "bränslefält",
    "bränslefältets": "bränslefält",
    "bränslefälts": "bränslefält",
    "bränsleförbrukningen": "bränsleförbrukning",
    "bränsleförbrukningens": "bränsleförbrukning",
    "bränsleförbruknings": "bränsleförbrukning",
    "bränsleförråden": "bränsleförråd",
    "bränsleförrådens": "bränsleförråd",
    "bränsleförrådet": "bränsleförråd",
    "bränsleförrådets": "bränsleförråd",
    "bränsleförråds": "bränsleförråd",
    "bränslegasen": "bränslegas",
    "bränslegasens": "bränslegas",
    "bränslegaser": "bränslegas",
    "bränslegaserna": "bränslegas",
    "bränslegasernas": "bränslegas",
    "bränslegasers": "bränslegas",
    "bränslekanalen": "bränslekanal",
    "bränslekanalens": "bränslekanal",
    "bränslekanaler": "bränslekanal",
    "bränslekanalerna": "bränslekanal",
    "bränslekanalernas": "bränslekanal",
    "bränslekanalers": "bränslekanal",
    "bränslekanals": "bränslekanal",
    "bränslekrisen": "bränslekris",
    "bränslekrisens": "bränslekris",
    "bränslekriser": "bränslekris",
    "bränslekriserna": "bränslekris",
    "bränslekrisernas": "bränslekris",
    "bränslekrisers": "bränslekris",
    "bränslemätar": "bränslemätare",
    "bränslemätaren": "bränslemätare",
    "bränslemätarens": "bränslemätare",
    "bränslemätares": "bränslemätare",
    "bränslemätarna": "bränslemätare",
    "bränslemätarnas": "bränslemätare",
    "bränslen": "bränsle",
    "bränslena": "bränsle",
    "bränslenas": "bränsle",
    "bränslens": "bränsle",
    "bränsleomvandlar": "bränsleomvandlare",
    "bränsleomvandlaren": "bränsleomvandlare",
    "bränsleomvandlarens": "bränsleomvandlare",
    "bränsleomvandlares": "bränsleomvandlare",
    "bränsleomvandlarna": "bränsleomvandlare",
    "bränsleomvandlarnas": "bränsleomvandlare",
    "bränsles": "bränsle",
    "bränslesnåla": "bränslesnål",
    "bränslesnålare": "bränslesnål",
    "bränslesnålares": "bränslesnål",
    "bränslesnålas": "bränslesnål",
    "bränslesnålast": "bränslesnål",
    "bränslesnålaste": "bränslesnål",
    "bränslesnålastes": "bränslesnål",
    "bränslesnålasts": "bränslesnål",
    "bränslesnåle": "bränslesnål",
    "bränslesnåles": "bränslesnål",
    "bränslesnålheten": "bränslesnålhet",
    "bränslesnålhetens": "bränslesnålhet",
    "bränslesnålhets": "bränslesnålhet",
    "bränslesnåls": "bränslesnål",
    "bränslesnålt": "bränslesnål",
    "bränslesnålts": "bränslesnål",
    "bränslestavar": "bränslestav",
    "bränslestavarna": "bränslestav",
    "bränslestavarnas": "bränslestav",
    "bränslestavars": "bränslestav",
    "bränslestaven": "bränslestav",
    "bränslestavens": "bränslestav",
    "bränslestavs": "bränslestav",
    "bränslet": "bränsle",
    "bränsletankar": "bränsletank",
    "bränsletankarna": "bränsletank",
    "bränsletankarnas": "bränsletank",
    "bränsletankars": "bränsletank",
    "bränsletanken": "bränsletank",
    "bränsletankens": "bränsletank",
    "bränsletanks": "bränsletank",
    "bränsletilläggen": "bränsletillägg",
    "bränsletilläggens": "bränsletillägg",
    "bränsletillägget": "bränsletillägg",
    "bränsletilläggets": "bränsletillägg",
    "bränsletilläggs": "bränsletillägg",
    "bränslets": "bränsle",
    "bränsletypen": "bränsletyp",
    "bränsletypens": "bränsletyp",
    "bränsletyper": "bränsletyp",
    "bränsletyperna": "bränsletyp",
    "bränsletypernas": "bränsletyp",
    "bränsletypers": "bränsletyp",
    "bränsletyps": "bränsletyp",
    "bränt": "bränna",
    "bränts": "brännas",
    "bräschen": "bräsch",
    "bräschens": "bräsch",
    "bräscher": "bräsch",
    "bräscherna": "bräsch",
    "bräschernas": "bräsch",
    "bräschers": "bräsch",
    "bräschs": "bräsch",
    "bräserad": "bräsera",
    "bräserade": "bräsera",
    "bräserades": "bräsera",
    "bräserads": "bräsera",
    "bräserande": "bräsera",
    "bräseranden": "bräserande",
    "bräserandena": "bräserande",
    "bräserandenas": "bräserande",
    "bräserandens": "bräserande",
    "bräserandes": "bräserande",
    "bräserandet": "bräserande",
    "bräserandets": "bräserande",
    "bräserar": "bräsera",
    "bräseras": "bräsera",
    "bräserat": "bräsera",
    "bräserats": "bräsera",
    "bräserbara": "bräserbar",
    "bräserbarare": "bräserbar",
    "bräserbarares": "bräserbar",
    "bräserbaras": "bräserbar",
    "bräserbarast": "bräserbar",
    "bräserbaraste": "bräserbar",
    "bräserbarastes": "bräserbar",
    "bräserbarasts": "bräserbar",
    "bräserbare": "bräserbar",
    "bräserbares": "bräserbar",
    "bräserbarheten": "bräserbarhet",
    "bräserbarhetens": "bräserbarhet",
    "bräserbarhets": "bräserbarhet",
    "bräserbars": "bräserbar",
    "bräserbart": "bräserbar",
    "bräserbarts": "bräserbar",
    "bräseringar": "bräsering",
    "bräseringarna": "bräsering",
    "bräseringarnas": "bräsering",
    "bräseringars": "bräsering",
    "bräseringen": "bräsering",
    "bräseringens": "bräsering",
    "bräserings": "bräsering",
    "bräsm": "bräsma",
    "bräsman": "bräsma",
    "bräsmans": "bräsma",
    "bräsmas": "bräsma",
    "bräsme": "bräsma",
    "bräsmor": "bräsma",
    "bräsmorna": "bräsma",
    "bräsmornas": "bräsma",
    "bräsmors": "bräsma",
    "brässen": "bräss",
    "brässens": "bräss",
    "brässet": "bräss",
    "brässets": "bräss",
    "brätten": "brätte",
    "brättena": "brätte",
    "brättenas": "brätte",
    "brättens": "brätte",
    "brättes": "brätte",
    "brättet": "brätte",
    "brättets": "brätte",
    "brätts": "brätte",
    "bråckbanden": "bråckband",
    "bråckbandens": "bråckband",
    "bråckbandet": "bråckband",
    "bråckbandets": "bråckband",
    "bråckbands": "bråckband",
    "bråcken": "bråck",
    "bråckens": "bråck",
    "bråcket": "bråck",
    "bråckets": "bråck",
    "bråcks": "bråck",
    "bråda": "bråd",
    "brådare": "bråd",
    "brådares": "bråd",
    "brådas": "bråd",
    "brådast": "bråd",
    "brådaste": "bråd",
    "brådastes": "bråd",
    "brådasts": "bråd",
    "bråddes": "brås",
    "bråddjupa": "bråddjup",
    "bråddjupare": "bråddjup",
    "bråddjupares": "bråddjup",
    "bråddjupas": "bråddjup",
    "bråddjupast": "bråddjup",
    "bråddjupaste": "bråddjup",
    "bråddjupastes": "bråddjup",
    "bråddjupasts": "bråddjup",
    "bråddjupe": "bråddjup",
    "bråddjupen": "bråddjup",
    "bråddjupens": "bråddjup",
    "bråddjupes": "bråddjup",
    "bråddjupet": "bråddjup",
    "bråddjupets": "bråddjup",
    "bråddjupheten": "bråddjuphet",
    "bråddjuphetens": "bråddjuphet",
    "bråddjuphets": "bråddjuphet",
    "bråddjups": "bråddjup",
    "bråddjupt": "bråddjup",
    "bråddjupts": "bråddjup",
    "bråde": "bråd",
    "brådes": "bråd",
    "brådheten": "brådhet",
    "brådhetens": "brådhet",
    "brådhets": "brådhet",
    "brådmogenheten": "brådmogenhet",
    "brådmogenhetens": "brådmogenhet",
    "brådmogenhets": "brådmogenhet",
    "brådmogens": "brådmogen",
    "brådmoget": "brådmogen",
    "brådmogets": "brådmogen",
    "brådmogna": "brådmogen",
    "brådmognare": "brådmogen",
    "brådmognares": "brådmogen",
    "brådmognas": "brådmogen",
    "brådmognast": "brådmogen",
    "brådmognaste": "brådmogen",
    "brådmognastes": "brådmogen",
    "brådmognasts": "brådmogen",
    "brådmogne": "brådmogen",
    "brådmognes": "brådmogen",
    "bråds": "bråd",
    "brådskade": "brådska",
    "brådskades": "brådska",
    "brådskan": "brådska",
    "brådskande": "brådska",
    "brådskanden": "brådskande",
    "brådskandena": "brådskande",
    "brådskandenas": "brådskande",
    "brådskandens": "brådskande",
    "brådskandes": "brådskande",
    "brådskandet": "brådskande",
    "brådskandets": "brådskande",
    "brådskans": "brådska",
    "brådskar": "brådska",
    "brådskas": "brådska",
    "brådskat": "brådska",
    "brådskats": "brådska",
    "brådstörtade": "brådstörtad",
    "brådstörtades": "brådstörtad",
    "brådstörtads": "brådstörtad",
    "brådstörtat": "brådstörtad",
    "brådstörtats": "brådstörtad",
    "bråk": "bråka",
    "bråkad": "bråka",
    "bråkade": "bråka",
    "bråkades": "bråka",
    "bråkads": "bråka",
    "bråkan": "bråka",
    "bråkande": "bråka",
    "bråkanden": "bråkande",
    "bråkandena": "bråkande",
    "bråkandenas": "bråkande",
    "bråkandens": "bråkande",
    "bråkandes": "bråkande",
    "bråkandet": "bråkande",
    "bråkandets": "bråkande",
    "bråkans": "bråka",
    "bråkar": "bråka",
    "bråkas": "bråka",
    "bråkat": "bråka",
    "bråkats": "bråka",
    "bråkdelar": "bråkdel",
    "bråkdelarna": "bråkdel",
    "bråkdelarnas": "bråkdel",
    "bråkdelars": "bråkdel",
    "bråkdelen": "bråkdel",
    "bråkdelens": "bråkdel",
    "bråkdels": "bråkdel",
    "bråke": "bråka",
    "bråken": "bråk",
    "bråkens": "bråk",
    "bråket": "bråk",
    "bråkets": "bråk",
    "bråkiga": "bråkig",
    "bråkigare": "bråkig",
    "bråkigares": "bråkig",
    "bråkigas": "bråkig",
    "bråkigast": "bråkig",
    "bråkigaste": "bråkig",
    "bråkigastes": "bråkig",
    "bråkigasts": "bråkig",
    "bråkige": "bråkig",
    "bråkiges": "bråkig",
    "bråkigs": "bråkig",
    "bråkigt": "bråkig",
    "bråkigts": "bråkig",
    "bråkmakar": "bråkmakare",
    "bråkmakaren": "bråkmakare",
    "bråkmakarens": "bråkmakare",
    "bråkmakares": "bråkmakare",
    "bråkmakarna": "bråkmakare",
    "bråkmakarnas": "bråkmakare",
    "bråkor": "bråka",
    "bråkorna": "bråka",
    "bråkornas": "bråka",
    "bråkors": "bråka",
    "bråks": "bråka",
    "bråkstak": "bråkstake",
    "bråkstakar": "bråkstake",
    "bråkstakarna": "bråkstake",
    "bråkstakarnas": "bråkstake",
    "bråkstakars": "bråkstake",
    "bråkstaken": "bråkstake",
    "bråkstakens": "bråkstake",
    "bråkstakes": "bråkstake",
    "bråkstaks": "bråkstake",
    "bråkstrecken": "bråkstreck",
    "bråkstreckens": "bråkstreck",
    "bråkstrecket": "bråkstreck",
    "bråkstreckets": "bråkstreck",
    "bråkstrecks": "bråkstreck",
    "bråktalen": "bråktal",
    "bråktalens": "bråktal",
    "bråktalet": "bråktal",
    "bråktalets": "bråktal",
    "bråktals": "bråktal",
    "brånaden": "brånad",
    "brånadens": "brånad",
    "brånader": "brånad",
    "brånaderna": "brånad",
    "brånadernas": "brånad",
    "brånaders": "brånad",
    "brånads": "brånad",
    "bråten": "bråte",
    "bråtens": "bråte",
    "bråtes": "bråte",
    "bråtet": "bråte",
    "bråtets": "bråte",
    "brått": "bråd",
    "bråtts": "brås",
    "brö": "bröa",
    "bröad": "bröa",
    "bröade": "bröa",
    "bröades": "bröa",
    "bröads": "bröa",
    "bröande": "bröa",
    "bröanden": "bröande",
    "bröandena": "bröande",
    "bröandenas": "bröande",
    "bröandens": "bröande",
    "bröandes": "bröande",
    "bröandet": "bröande",
    "bröandets": "bröande",
    "bröar": "bröa",
    "bröas": "bröa",
    "bröat": "bröa",
    "bröats": "bröa",
    "bröd": "bröda",
    "brödad": "bröda",
    "brödade": "bröda",
    "brödades": "bröda",
    "brödads": "bröda",
    "brödande": "bröda",
    "brödanden": "brödande",
    "brödandena": "brödande",
    "brödandenas": "brödande",
    "brödandens": "brödande",
    "brödandes": "brödande",
    "brödandet": "brödande",
    "brödandets": "brödande",
    "brödar": "bröda",
    "brödas": "bröda",
    "brödat": "bröda",
    "brödats": "bröda",
    "brödbagg": "brödbagge",
    "brödbaggar": "brödbagge",
    "brödbaggarna": "brödbagge",
    "brödbaggarnas": "brödbagge",
    "brödbaggars": "brödbagge",
    "brödbaggen": "brödbagge",
    "brödbaggens": "brödbagge",
    "brödbagges": "brödbagge",
    "brödbaggs": "brödbagge",
    "brödbaken": "brödbak",
    "brödbakens": "brödbak",
    "brödbaket": "brödbak",
    "brödbakets": "brödbak",
    "brödbaks": "brödbak",
    "brödbitar": "brödbit",
    "brödbitarna": "brödbit",
    "brödbitarnas": "brödbit",
    "brödbitars": "brödbit",
    "brödbiten": "brödbit",
    "brödbitens": "brödbit",
    "brödbits": "brödbit",
    "brödburkar": "brödburk",
    "brödburkarna": "brödburk",
    "brödburkarnas": "brödburk",
    "brödburkars": "brödburk",
    "brödburken": "brödburk",
    "brödburkens": "brödburk",
    "brödburks": "brödburk",
    "bröden": "bröd",
    "brödens": "bröd",
    "bröder": "bror",
    "bröderna": "bror",
    "brödernas": "bror",
    "bröders": "bror",
    "brödet": "bröd",
    "brödets": "bröd",
    "brödfaten": "brödfat",
    "brödfatens": "brödfat",
    "brödfatet": "brödfat",
    "brödfatets": "brödfat",
    "brödfats": "brödfat",
    "brödfrukten": "brödfrukt",
    "brödfruktens": "brödfrukt",
    "brödfrukter": "brödfrukt",
    "brödfrukterna": "brödfrukt",
    "brödfrukternas": "brödfrukt",
    "brödfrukters": "brödfrukt",
    "brödfrukts": "brödfrukt",
    "brödfödan": "brödföda",
    "brödfödans": "brödföda",
    "brödfödas": "brödföda",
    "brödingar": "bröding",
    "brödingarna": "bröding",
    "brödingarnas": "bröding",
    "brödingars": "bröding",
    "brödingen": "bröding",
    "brödingens": "bröding",
    "brödings": "bröding",
    "brödkak": "brödkaka",
    "brödkakan": "brödkaka",
    "brödkakans": "brödkaka",
    "brödkakas": "brödkaka",
    "brödkake": "brödkaka",
    "brödkakor": "brödkaka",
    "brödkakorna": "brödkaka",
    "brödkakornas": "brödkaka",
    "brödkakors": "brödkaka",
    "brödkaks": "brödkaka",
    "brödkanten": "brödkant",
    "brödkantens": "brödkant",
    "brödkanter": "brödkant",
    "brödkanterna": "brödkant",
    "brödkanternas": "brödkant",
    "brödkanters": "brödkant",
    "brödkants": "brödkant",
    "brödkaveln": "brödkavel",
    "brödkavelns": "brödkavel",
    "brödkavels": "brödkavel",
    "brödkavl": "brödkavle",
    "brödkavlar": "brödkavle",
    "brödkavlarna": "brödkavle",
    "brödkavlarnas": "brödkavle",
    "brödkavlars": "brödkavle",
    "brödkavlen": "brödkavle",
    "brödkavlens": "brödkavle",
    "brödkavles": "brödkavle",
    "brödkavls": "brödkavle",
    "brödknivar": "brödkniv",
    "brödknivarna": "brödkniv",
    "brödknivarnas": "brödkniv",
    "brödknivars": "brödkniv",
    "brödkniven": "brödkniv",
    "brödknivens": "brödkniv",
    "brödknivs": "brödkniv",
    "brödkorgar": "brödkorg",
    "brödkorgarna": "brödkorg",
    "brödkorgarnas": "brödkorg",
    "brödkorgars": "brödkorg",
    "brödkorgen": "brödkorg",
    "brödkorgens": "brödkorg",
    "brödkorgs": "brödkorg",
    "brödköer": "brödkö",
    "brödköerna": "brödkö",
    "brödköernas": "brödkö",
    "brödköers": "brödkö",
    "brödkön": "brödkö",
    "brödköns": "brödkö",
    "brödkös": "brödkö",
    "brödlösa": "brödlös",
    "brödlösare": "brödlös",
    "brödlösares": "brödlös",
    "brödlösas": "brödlös",
    "brödlösast": "brödlös",
    "brödlösaste": "brödlös",
    "brödlösastes": "brödlös",
    "brödlösasts": "brödlös",
    "brödlöse": "brödlös",
    "brödlöses": "brödlös",
    "brödlösheten": "brödlöshet",
    "brödlöshetens": "brödlöshet",
    "brödlöshets": "brödlöshet",
    "brödlöst": "brödlös",
    "brödlösts": "brödlös",
    "brödnaggar": "brödnagg",
    "brödnaggarna": "brödnagg",
    "brödnaggarnas": "brödnagg",
    "brödnaggars": "brödnagg",
    "brödnaggen": "brödnagg",
    "brödnaggens": "brödnagg",
    "brödnaggs": "brödnagg",
    "brödpuddingar": "brödpudding",
    "brödpuddingarna": "brödpudding",
    "brödpuddingarnas": "brödpudding",
    "brödpuddingars": "brödpudding",
    "brödpuddingen": "brödpudding",
    "brödpuddingens": "brödpudding",
    "brödpuddings": "brödpudding",
    "brödrafolken": "brödrafolk",
    "brödrafolkens": "brödrafolk",
    "brödrafolket": "brödrafolk",
    "brödrafolkets": "brödrafolk",
    "brödrafolks": "brödrafolk",
    "brödraparen": "brödrapar",
    "brödraparens": "brödrapar",
    "brödraparet": "brödrapar",
    "brödraparets": "brödrapar",
    "brödrapars": "brödrapar",
    "brödraskapen": "brödraskap",
    "brödraskapens": "brödraskap",
    "brödraskapet": "brödraskap",
    "brödraskapets": "brödraskap",
    "brödraskaps": "brödraskap",
    "brödrostar": "brödrost",
    "brödrostarna": "brödrost",
    "brödrostarnas": "brödrost",
    "brödrostars": "brödrost",
    "brödrosten": "brödrost",
    "brödrostens": "brödrost",
    "brödrosts": "brödrost",
    "bröds": "bröd",
    "brödsbrytelsen": "brödsbrytelse",
    "brödsbrytelsens": "brödsbrytelse",
    "brödsbrytelser": "brödsbrytelse",
    "brödsbrytelserna": "brödsbrytelse",
    "brödsbrytelsernas": "brödsbrytelse",
    "brödsbrytelsers": "brödsbrytelse",
    "brödsbrytelses": "brödsbrytelse",
    "brödskivan": "brödskiva",
    "brödskivans": "brödskiva",
    "brödskivas": "brödskiva",
    "brödskive": "brödskiva",
    "brödskivor": "brödskiva",
    "brödskivorna": "brödskiva",
    "brödskivornas": "brödskiva",
    "brödskivors": "brödskiva",
    "brödskriverier": "brödskriveri",
    "brödskriverierna": "brödskriveri",
    "brödskriveriernas": "brödskriveri",
    "brödskriveriers": "brödskriveri",
    "brödskriveriet": "brödskriveri",
    "brödskriveriets": "brödskriveri",
    "brödskriveris": "brödskriveri",
    "brödskriverit": "brödskriveri",
    "brödskriverits": "brödskriveri",
    "brödsmul": "brödsmula",
    "brödsmulan": "brödsmula",
    "brödsmulans": "brödsmula",
    "brödsmulas": "brödsmula",
    "brödsmule": "brödsmula",
    "brödsmulor": "brödsmula",
    "brödsmulorna": "brödsmula",
    "brödsmulornas": "brödsmula",
    "brödsmulors": "brödsmula",
    "brödsmuls": "brödsmula",
    "brödspad": "brödspade",
    "brödspadar": "brödspade",
    "brödspadarna": "brödspade",
    "brödspadarnas": "brödspade",
    "brödspadars": "brödspade",
    "brödspaden": "brödspade",
    "brödspadens": "brödspade",
    "brödspades": "brödspade",
    "brödspads": "brödspade",
    "brödstilen": "brödstil",
    "brödstilens": "brödstil",
    "brödstils": "brödstil",
    "brödsäden": "brödsäd",
    "brödsädens": "brödsäd",
    "brödsädes": "brödsäd",
    "brödsäds": "brödsäd",
    "brödtexten": "brödtext",
    "brödtextens": "brödtext",
    "brödtexts": "brödtext",
    "bröl": "bröla",
    "brölade": "bröla",
    "brölades": "bröla",
    "brölande": "bröla",
    "brölanden": "brölande",
    "brölandena": "brölande",
    "brölandenas": "brölande",
    "brölandens": "brölande",
    "brölandes": "brölande",
    "brölandet": "brölande",
    "brölandets": "brölande",
    "brölar": "bröla",
    "brölas": "bröla",
    "brölat": "bröla",
    "brölats": "bröla",
    "brölen": "bröl",
    "brölens": "bröl",
    "brölet": "bröl",
    "brölets": "bröl",
    "bröllopen": "bröllop",
    "bröllopens": "bröllop",
    "bröllopet": "bröllop",
    "bröllopets": "bröllop",
    "bröllops": "bröllop",
    "bröllopsbussar": "bröllopsbuss",
    "bröllopsbussarna": "bröllopsbuss",
    "bröllopsbussarnas": "bröllopsbuss",
    "bröllopsbussars": "bröllopsbuss",
    "bröllopsbussen": "bröllopsbuss",
    "bröllopsbussens": "bröllopsbuss",
    "bröllopsdagar": "bröllopsdag",
    "bröllopsdagarna": "bröllopsdag",
    "bröllopsdagarnas": "bröllopsdag",
    "bröllopsdagars": "bröllopsdag",
    "bröllopsdagen": "bröllopsdag",
    "bröllopsdagens": "bröllopsdag",
    "bröllopsdags": "bröllopsdag",
    "bröllopsdikten": "bröllopsdikt",
    "bröllopsdiktens": "bröllopsdikt",
    "bröllopsdikter": "bröllopsdikt",
    "bröllopsdikterna": "bröllopsdikt",
    "bröllopsdikternas": "bröllopsdikt",
    "bröllopsdikters": "bröllopsdikt",
    "bröllopsdikts": "bröllopsdikt",
    "bröllopsfoton": "bröllopsfoto",
    "bröllopsfotona": "bröllopsfoto",
    "bröllopsfotonas": "bröllopsfoto",
    "bröllopsfotons": "bröllopsfoto",
    "bröllopsfotos": "bröllopsfoto",
    "bröllopsfotot": "bröllopsfoto",
    "bröllopsfotots": "bröllopsfoto",
    "bröllopsgästen": "bröllopsgäst",
    "bröllopsgästens": "bröllopsgäst",
    "bröllopsgäster": "bröllopsgäst",
    "bröllopsgästerna": "bröllopsgäst",
    "bröllopsgästernas": "bröllopsgäst",
    "bröllopsgästers": "bröllopsgäst",
    "bröllopsgästs": "bröllopsgäst",
    "bröllopsgåvan": "bröllopsgåva",
    "bröllopsgåvans": "bröllopsgåva",
    "bröllopsgåvas": "bröllopsgåva",
    "bröllopsgåve": "bröllopsgåva",
    "bröllopsgåvo": "bröllopsgåva",
    "bröllopsgåvor": "bröllopsgåva",
    "bröllopsgåvorna": "bröllopsgåva",
    "bröllopsgåvornas": "bröllopsgåva",
    "bröllopsgåvors": "bröllopsgåva",
    "bröllopsklänningar": "bröllopsklänning",
    "bröllopsklänningarna": "bröllopsklänning",
    "bröllopsklänningarnas": "bröllopsklänning",
    "bröllopsklänningars": "bröllopsklänning",
    "bröllopsklänningen": "bröllopsklänning",
    "bröllopsklänningens": "bröllopsklänning",
    "bröllopsklännings": "bröllopsklänning",
    "bröllopsmarschen": "bröllopsmarsch",
    "bröllopsmarschens": "bröllopsmarsch",
    "bröllopsmarscher": "bröllopsmarsch",
    "bröllopsmarscherna": "bröllopsmarsch",
    "bröllopsmarschernas": "bröllopsmarsch",
    "bröllopsmarschers": "bröllopsmarsch",
    "bröllopsmarschs": "bröllopsmarsch",
    "bröllopsnatn": "bröllopsnatt",
    "bröllopsnatns": "bröllopsnatt",
    "bröllopsnatten": "bröllopsnatt",
    "bröllopsnattens": "bröllopsnatt",
    "bröllopsnatts": "bröllopsnatt",
    "bröllopsnätter": "bröllopsnatt",
    "bröllopsnätterna": "bröllopsnatt",
    "bröllopsnätternas": "bröllopsnatt",
    "bröllopsnätters": "bröllopsnatt",
    "bröllopsparen": "bröllopspar",
    "bröllopsparens": "bröllopspar",
    "bröllopsparet": "bröllopspar",
    "bröllopsparets": "bröllopspar",
    "bröllopspars": "bröllopspar",
    "bröllopsresan": "bröllopsresa",
    "bröllopsresans": "bröllopsresa",
    "bröllopsresas": "bröllopsresa",
    "bröllopsrese": "bröllopsresa",
    "bröllopsresmålen": "bröllopsresmål",
    "bröllopsresmålens": "bröllopsresmål",
    "bröllopsresmålet": "bröllopsresmål",
    "bröllopsresmålets": "bröllopsresmål",
    "bröllopsresmåls": "bröllopsresmål",
    "bröllopsresor": "bröllopsresa",
    "bröllopsresorna": "bröllopsresa",
    "bröllopsresornas": "bröllopsresa",
    "bröllopsresors": "bröllopsresa",
    "bröllopsseden": "bröllopssed",
    "bröllopssedens": "bröllopssed",
    "bröllopsseder": "bröllopssed",
    "bröllopssederna": "bröllopssed",
    "bröllopssedernas": "bröllopssed",
    "bröllopsseders": "bröllopssed",
    "bröllopsseds": "bröllopssed",
    "bröllopstårt": "bröllopstårta",
    "bröllopstårtan": "bröllopstårta",
    "bröllopstårtans": "bröllopstårta",
    "bröllopstårtas": "bröllopstårta",
    "bröllopstårte": "bröllopstårta",
    "bröllopstårtor": "bröllopstårta",
    "bröllopstårtorna": "bröllopstårta",
    "bröllopstårtornas": "bröllopstårta",
    "bröllopstårtors": "bröllopstårta",
    "bröllopstårts": "bröllopstårta",
    "bröllopsvittnen": "bröllopsvittne",
    "bröllopsvittnena": "bröllopsvittne",
    "bröllopsvittnenas": "bröllopsvittne",
    "bröllopsvittnens": "bröllopsvittne",
    "bröllopsvittnes": "bröllopsvittne",
    "bröllopsvittnet": "bröllopsvittne",
    "bröllopsvittnets": "bröllopsvittne",
    "bröllopsyran": "bröllopsyra",
    "bröllopsyrans": "bröllopsyra",
    "bröllopsyras": "bröllopsyra",
    "bröllopsyre": "bröllopsyra",
    "bröllopsyror": "bröllopsyra",
    "bröllopsyrorna": "bröllopsyra",
    "bröllopsyrornas": "bröllopsyra",
    "bröllopsyrors": "bröllopsyra",
    "bröls": "bröl",
    "bröst": "brösta",
    "bröstan": "brösta",
    "bröstans": "brösta",
    "bröstarven": "bröstarv",
    "bröstarvens": "bröstarv",
    "bröstarvet": "bröstarv",
    "bröstarvets": "bröstarv",
    "bröstarvingar": "bröstarvinge",
    "bröstarvingarna": "bröstarvinge",
    "bröstarvingarnas": "bröstarvinge",
    "bröstarvingars": "bröstarvinge",
    "bröstarvingen": "bröstarvinge",
    "bröstarvingens": "bröstarvinge",
    "bröstarvinges": "bröstarvinge",
    "bröstarvs": "bröstarv",
    "bröstas": "brösta",
    "bröstbarnen": "bröstbarn",
    "bröstbarnens": "bröstbarn",
    "bröstbarnet": "bröstbarn",
    "bröstbarnets": "bröstbarn",
    "bröstbarns": "bröstbarn",
    "bröstbenen": "bröstben",
    "bröstbenens": "bröstben",
    "bröstbenet": "bröstben",
    "bröstbenets": "bröstben",
    "bröstbens": "bröstben",
    "bröstbilden": "bröstbild",
    "bröstbildens": "bröstbild",
    "bröstbilder": "bröstbild",
    "bröstbilderna": "bröstbild",
    "bröstbildernas": "bröstbild",
    "bröstbilders": "bröstbild",
    "bröstbilds": "bröstbild",
    "bröstbölden": "bröstböld",
    "bröstböldens": "bröstböld",
    "bröstbölder": "bröstböld",
    "bröstbölderna": "bröstböld",
    "bröstböldernas": "bröstböld",
    "bröstbölders": "bröstböld",
    "bröstbölds": "bröstböld",
    "bröstcancerdiagnosen": "bröstcancerdiagnos",
    "bröstcancerdiagnosens": "bröstcancerdiagnos",
    "bröstcancerdiagnoser": "bröstcancerdiagnos",
    "bröstcancerdiagnoserna": "bröstcancerdiagnos",
    "bröstcancerdiagnosernas": "bröstcancerdiagnos",
    "bröstcancerdiagnosers": "bröstcancerdiagnos",
    "bröstcancern": "bröstcancer",
    "bröstcancerns": "bröstcancer",
    "bröstcancers": "bröstcancer",
    "bröstcancrar": "bröstcancer",
    "bröstcancrarna": "bröstcancer",
    "bröstcancrarnas": "bröstcancer",
    "bröstcancrars": "bröstcancer",
    "bröstdropparna": "bröstdroppar",
    "bröstdropparnas": "bröstdroppar",
    "bröstdroppars": "bröstdroppar",
    "bröstdropps": "bröstdroppar",
    "bröste": "brösta",
    "brösten": "bröst",
    "bröstens": "bröst",
    "bröstet": "bröst",
    "bröstets": "bröst",
    "bröstfen": "bröstfena",
    "bröstfenan": "bröstfena",
    "bröstfenans": "bröstfena",
    "bröstfenas": "bröstfena",
    "bröstfene": "bröstfena",
    "bröstfenor": "bröstfena",
    "bröstfenorna": "bröstfena",
    "bröstfenornas": "bröstfena",
    "bröstfenors": "bröstfena",
    "bröstfens": "bröstfena",
    "bröstfick": "bröstficka",
    "bröstfickan": "bröstficka",
    "bröstfickans": "bröstficka",
    "bröstfickas": "bröstficka",
    "bröstficke": "bröstficka",
    "bröstfickor": "bröstficka",
    "bröstfickorna": "bröstficka",
    "bröstfickornas": "bröstficka",
    "bröstfickors": "bröstficka",
    "bröstficks": "bröstficka",
    "bröstgångar": "bröstgång",
    "bröstgångarna": "bröstgång",
    "bröstgångarnas": "bröstgång",
    "bröstgångars": "bröstgång",
    "bröstgången": "bröstgång",
    "bröstgångens": "bröstgång",
    "bröstgångs": "bröstgång",
    "brösthål": "brösthåla",
    "brösthålan": "brösthåla",
    "brösthålans": "brösthåla",
    "brösthålas": "brösthåla",
    "brösthåle": "brösthåla",
    "brösthålor": "brösthåla",
    "brösthålorna": "brösthåla",
    "brösthålornas": "brösthåla",
    "brösthålors": "brösthåla",
    "brösthåls": "brösthåla",
    "brösthöjds": "brösthöjd",
    "bröstimplantaten": "bröstimplantat",
    "bröstimplantatens": "bröstimplantat",
    "bröstimplantatet": "bröstimplantat",
    "bröstimplantatets": "bröstimplantat",
    "bröstimplantats": "bröstimplantat",
    "bröstkaramellen": "bröstkaramell",
    "bröstkaramellens": "bröstkaramell",
    "bröstkarameller": "bröstkaramell",
    "bröstkaramellerna": "bröstkaramell",
    "bröstkaramellernas": "bröstkaramell",
    "bröstkaramellers": "bröstkaramell",
    "bröstkaramells": "bröstkaramell",
    "bröstkatarren": "bröstkatarr",
    "bröstkatarrens": "bröstkatarr",
    "bröstkatarrer": "bröstkatarr",
    "bröstkatarrerna": "bröstkatarr",
    "bröstkatarrernas": "bröstkatarr",
    "bröstkatarrers": "bröstkatarr",
    "bröstkatarrs": "bröstkatarr",
    "bröstklangen": "bröstklang",
    "bröstklangens": "bröstklang",
    "bröstklangs": "bröstklang",
    "bröstkorgar": "bröstkorg",
    "bröstkorgarna": "bröstkorg",
    "bröstkorgarnas": "bröstkorg",
    "bröstkorgars": "bröstkorg",
    "bröstkorgen": "bröstkorg",
    "bröstkorgens": "bröstkorg",
    "bröstkorgs": "bröstkorg",
    "bröstkot": "bröstkota",
    "bröstkotan": "bröstkota",
    "bröstkotans": "bröstkota",
    "bröstkotas": "bröstkota",
    "bröstkote": "bröstkota",
    "bröstkotor": "bröstkota",
    "bröstkotorna": "bröstkota",
    "bröstkotornas": "bröstkota",
    "bröstkotors": "bröstkota",
    "bröstkots": "bröstkota",
    "bröstkörteln": "bröstkörtel",
    "bröstkörtelns": "bröstkörtel",
    "bröstkörtels": "bröstkörtel",
    "bröstkörtlar": "bröstkörtel",
    "bröstkörtlarna": "bröstkörtel",
    "bröstkörtlarnas": "bröstkörtel",
    "bröstkörtlars": "bröstkörtel",
    "bröstlappar": "bröstlapp",
    "bröstlapparna": "bröstlapp",
    "bröstlapparnas": "bröstlapp",
    "bröstlappars": "bröstlapp",
    "bröstlappen": "bröstlapp",
    "bröstlappens": "bröstlapp",
    "bröstlapps": "bröstlapp",
    "bröstlidandes": "bröstlidande",
    "bröstlidandet": "bröstlidande",
    "bröstlidandets": "bröstlidande",
    "bröstmjölken": "bröstmjölk",
    "bröstmjölkens": "bröstmjölk",
    "bröstmjölks": "bröstmjölk",
    "bröstmurar": "bröstmur",
    "bröstmurarna": "bröstmur",
    "bröstmurarnas": "bröstmur",
    "bröstmurars": "bröstmur",
    "bröstmuren": "bröstmur",
    "bröstmurens": "bröstmur",
    "bröstmurs": "bröstmur",
    "bröstmuskeln": "bröstmuskel",
    "bröstmuskelns": "bröstmuskel",
    "bröstmuskels": "bröstmuskel",
    "bröstmuskler": "bröstmuskel",
    "bröstmusklerna": "bröstmuskel",
    "bröstmusklernas": "bröstmuskel",
    "bröstmusklers": "bröstmuskel",
    "bröstmåtten": "bröstmått",
    "bröstmåttens": "bröstmått",
    "bröstmåttet": "bröstmått",
    "bröstmåttets": "bröstmått",
    "bröstmåtts": "bröstmått",
    "bröstningar": "bröstning",
    "bröstningarna": "bröstning",
    "bröstningarnas": "bröstning",
    "bröstningars": "bröstning",
    "bröstningen": "bröstning",
    "bröstningens": "bröstning",
    "bröstnings": "bröstning",
    "bröstoperationen": "bröstoperation",
    "bröstoperationens": "bröstoperation",
    "bröstoperationer": "bröstoperation",
    "bröstoperationerna": "bröstoperation",
    "bröstoperationernas": "bröstoperation",
    "bröstoperationers": "bröstoperation",
    "bröstoperations": "bröstoperation",
    "bröstor": "brösta",
    "bröstorna": "brösta",
    "bröstornas": "brösta",
    "bröstors": "brösta",
    "bröstpartier": "bröstparti",
    "bröstpartierna": "bröstparti",
    "bröstpartiernas": "bröstparti",
    "bröstpartiers": "bröstparti",
    "bröstpartiet": "bröstparti",
    "bröstpartiets": "bröstparti",
    "bröstpartis": "bröstparti",
    "bröstpartit": "bröstparti",
    "bröstpartits": "bröstparti",
    "bröstpumpar": "bröstpump",
    "bröstpumparna": "bröstpump",
    "bröstpumparnas": "bröstpump",
    "bröstpumpars": "bröstpump",
    "bröstpumpen": "bröstpump",
    "bröstpumpens": "bröstpump",
    "bröstpumps": "bröstpump",
    "bröstregisterna": "bröstregister",
    "bröstregisternas": "bröstregister",
    "bröstregisters": "bröstregister",
    "bröstregistren": "bröstregister",
    "bröstregistrens": "bröstregister",
    "bröstregistret": "bröstregister",
    "bröstregistrets": "bröstregister",
    "brösts": "bröst",
    "bröstsimmar": "bröstsimmare",
    "bröstsimmaren": "bröstsimmare",
    "bröstsimmarens": "bröstsimmare",
    "bröstsimmares": "bröstsimmare",
    "bröstsimmarna": "bröstsimmare",
    "bröstsimmarnas": "bröstsimmare",
    "bröstsimmet": "bröstsim",
    "bröstsimmets": "bröstsim",
    "bröstsims": "bröstsim",
    "bröstskydden": "bröstskydd",
    "bröstskyddens": "bröstskydd",
    "bröstskyddet": "bröstskydd",
    "bröstskyddets": "bröstskydd",
    "bröstskydds": "bröstskydd",
    "bröstsockers": "bröstsocker",
    "bröstsockret": "bröstsocker",
    "bröstsockrets": "bröstsocker",
    "brösttonen": "bröstton",
    "brösttonens": "bröstton",
    "brösttoner": "bröstton",
    "brösttonerna": "bröstton",
    "brösttonernas": "bröstton",
    "brösttoners": "bröstton",
    "brösttons": "bröstton",
    "bröstvidden": "bröstvidd",
    "bröstviddens": "bröstvidd",
    "bröstvidder": "bröstvidd",
    "bröstvidderna": "bröstvidd",
    "bröstviddernas": "bröstvidd",
    "bröstvidders": "bröstvidd",
    "bröstvidds": "bröstvidd",
    "bröstvärnen": "bröstvärn",
    "bröstvärnens": "bröstvärn",
    "bröstvärnet": "bröstvärn",
    "bröstvärnets": "bröstvärn",
    "bröstvärns": "bröstvärn",
    "bröstvårt": "bröstvårta",
    "bröstvårtan": "bröstvårta",
    "bröstvårtans": "bröstvårta",
    "bröstvårtas": "bröstvårta",
    "bröstvårte": "bröstvårta",
    "bröstvårtor": "bröstvårta",
    "bröstvårtorna": "bröstvårta",
    "bröstvårtornas": "bröstvårta",
    "bröstvårtors": "bröstvårta",
    "bröstvårts": "bröstvårta",
    "bröt": "bryta",
    "brötar": "bröt",
    "brötarna": "bröt",
    "brötarnas": "bröt",
    "brötars": "bröt",
    "bröte": "bryta",
    "bröten": "bröt",
    "brötens": "bröt",
    "brötes": "bryta",
    "bröthakar": "bröthake",
    "bröthakarna": "bröthake",
    "bröthakarnas": "bröthake",
    "bröthakars": "bröthake",
    "bröthaken": "bröthake",
    "bröthakens": "bröthake",
    "bröthakes": "bröthake",
    "brötlingar": "brötling",
    "brötlingarna": "brötling",
    "brötlingarnas": "brötling",
    "brötlingars": "brötling",
    "brötlingen": "brötling",
    "brötlingens": "brötling",
    "brötlings": "brötling",
    "bröts": "bryta",
    "buade": "bua",
    "buades": "bua",
    "buande": "bua",
    "buanden": "buande",
    "buandena": "buande",
    "buandenas": "buande",
    "buandens": "buande",
    "buandes": "buande",
    "buandet": "buande",
    "buandets": "buande",
    "buar": "bua",
    "buas": "bua",
    "buat": "bua",
    "buats": "bua",
    "bubb": "bubba",
    "bubbad": "bubba",
    "bubbade": "bubba",
    "bubbades": "bubba",
    "bubbads": "bubba",
    "bubbande": "bubba",
    "bubbanden": "bubbande",
    "bubbandena": "bubbande",
    "bubbandenas": "bubbande",
    "bubbandens": "bubbande",
    "bubbandes": "bubbande",
    "bubbandet": "bubbande",
    "bubbandets": "bubbande",
    "bubbar": "bubba",
    "bubbas": "bubba",
    "bubbat": "bubba",
    "bubbats": "bubba",
    "bubbel": "bubbla",
    "bubbelbaden": "bubbelbad",
    "bubbelbadens": "bubbelbad",
    "bubbelbadet": "bubbelbad",
    "bubbelbadets": "bubbelbad",
    "bubbelbadkaren": "bubbelbadkar",
    "bubbelbadkarens": "bubbelbadkar",
    "bubbelbadkaret": "bubbelbadkar",
    "bubbelbadkarets": "bubbelbadkar",
    "bubbelbadkars": "bubbelbadkar",
    "bubbelbads": "bubbelbad",
    "bubbelgummen": "bubbelgum",
    "bubbelgummens": "bubbelgum",
    "bubbelgummet": "bubbelgum",
    "bubbelgummets": "bubbelgum",
    "bubbelgums": "bubbelgum",
    "bubbelkammar": "bubbelkammare",
    "bubbelkammaren": "bubbelkammare",
    "bubbelkammarens": "bubbelkammare",
    "bubbelkammares": "bubbelkammare",
    "bubbelkamrar": "bubbelkammare",
    "bubbelkamrarna": "bubbelkammare",
    "bubbelkamrarnas": "bubbelkammare",
    "bubbelkamrars": "bubbelkammare",
    "bubbelpoolen": "bubbelpool",
    "bubbelpoolens": "bubbelpool",
    "bubbelpooler": "bubbelpool",
    "bubbelpoolerna": "bubbelpool",
    "bubbelpoolernas": "bubbelpool",
    "bubbelpoolers": "bubbelpool",
    "bubbelpools": "bubbelpool",
    "bubbels": "bubbel",
    "bubblade": "bubbla",
    "bubblades": "bubbla",
    "bubblan": "bubbla",
    "bubblande": "bubbla",
    "bubblanden": "bubblande",
    "bubblandena": "bubblande",
    "bubblandenas": "bubblande",
    "bubblandens": "bubblande",
    "bubblandes": "bubblande",
    "bubblandet": "bubblande",
    "bubblandets": "bubblande",
    "bubblans": "bubbla",
    "bubblar": "bubblare",
    "bubblaren": "bubblare",
    "bubblarens": "bubblare",
    "bubblares": "bubblare",
    "bubblarna": "bubblare",
    "bubblarnas": "bubblare",
    "bubblas": "bubbla",
    "bubblat": "bubbla",
    "bubblats": "bubbla",
    "bubble": "bubbla",
    "bubblet": "bubbel",
    "bubblets": "bubbel",
    "bubbliga": "bubblig",
    "bubbligare": "bubblig",
    "bubbligares": "bubblig",
    "bubbligas": "bubblig",
    "bubbligast": "bubblig",
    "bubbligaste": "bubblig",
    "bubbligastes": "bubblig",
    "bubbligasts": "bubblig",
    "bubblige": "bubblig",
    "bubbliges": "bubblig",
    "bubbligheten": "bubblighet",
    "bubblighetens": "bubblighet",
    "bubblighets": "bubblighet",
    "bubbligs": "bubblig",
    "bubbligt": "bubblig",
    "bubbligts": "bubblig",
    "bubblor": "bubbla",
    "bubblorna": "bubbla",
    "bubblornas": "bubbla",
    "bubblors": "bubbla",
    "bubonen": "bubon",
    "bubonens": "bubon",
    "buboner": "bubon",
    "bubonerna": "bubon",
    "bubonernas": "bubon",
    "buboners": "bubon",
    "bubons": "bubon",
    "buckel": "buckla",
    "bucklan": "buckla",
    "bucklans": "buckla",
    "bucklas": "buckla",
    "buckle": "buckla",
    "buckliga": "bucklig",
    "buckligare": "bucklig",
    "buckligares": "bucklig",
    "buckligas": "bucklig",
    "buckligast": "bucklig",
    "buckligaste": "bucklig",
    "buckligastes": "bucklig",
    "buckligasts": "bucklig",
    "bucklige": "bucklig",
    "buckliges": "bucklig",
    "buckligheten": "bucklighet",
    "bucklighetens": "bucklighet",
    "bucklighets": "bucklighet",
    "buckligs": "bucklig",
    "buckligt": "bucklig",
    "buckligts": "bucklig",
    "bucklor": "buckla",
    "bucklorna": "buckla",
    "bucklornas": "buckla",
    "bucklors": "buckla",
    "buckramen": "buckram",
    "buckramens": "buckram",
    "buckrams": "buckram",
    "bud": "buda",
    "budad": "buda",
    "budade": "buda",
    "budades": "buda",
    "budads": "buda",
    "budande": "buda",
    "budanden": "budande",
    "budandena": "budande",
    "budandenas": "budande",
    "budandens": "budande",
    "budandes": "budande",
    "budandet": "budande",
    "budandets": "budande",
    "budar": "buda",
    "budas": "buda",
    "budat": "buda",
    "budats": "buda",
    "budbyråer": "budbyrå",
    "budbyråerna": "budbyrå",
    "budbyråernas": "budbyrå",
    "budbyråers": "budbyrå",
    "budbyrån": "budbyrå",
    "budbyråns": "budbyrå",
    "budbyrås": "budbyrå",
    "budbärar": "budbärare",
    "budbäraren": "budbärare",
    "budbärarens": "budbärare",
    "budbärares": "budbärare",
    "budbärarna": "budbärare",
    "budbärarnas": "budbärare",
    "buddh": "buddha",
    "buddhan": "buddha",
    "buddhans": "buddha",
    "buddhas": "buddha",
    "buddhe": "buddha",
    "buddhismen": "buddhism",
    "buddhismens": "buddhism",
    "buddhismer": "buddhism",
    "buddhismerna": "buddhism",
    "buddhismernas": "buddhism",
    "buddhismers": "buddhism",
    "buddhisms": "buddhism",
    "buddhisten": "buddhist",
    "buddhistens": "buddhist",
    "buddhister": "buddhist",
    "buddhisterna": "buddhist",
    "buddhisternas": "buddhist",
    "buddhisters": "buddhist",
    "buddhistiska": "buddhistisk",
    "buddhistiskare": "buddhistisk",
    "buddhistiskares": "buddhistisk",
    "buddhistiskas": "buddhistisk",
    "buddhistiskast": "buddhistisk",
    "buddhistiskaste": "buddhistisk",
    "buddhistiskastes": "buddhistisk",
    "buddhistiskasts": "buddhistisk",
    "buddhistiske": "buddhistisk",
    "buddhistiskes": "buddhistisk",
    "buddhistisks": "buddhistisk",
    "buddhistiskt": "buddhistisk",
    "buddhistiskts": "buddhistisk",
    "buddhists": "buddhist",
    "buddhor": "buddha",
    "buddhorna": "buddha",
    "buddhornas": "buddha",
    "buddhors": "buddha",
    "buddhs": "buddha",
    "buddismen": "buddism",
    "buddismens": "buddism",
    "buddismer": "buddism",
    "buddismerna": "buddism",
    "buddismernas": "buddism",
    "buddismers": "buddism",
    "buddisms": "buddism",
    "buddisten": "buddist",
    "buddistens": "buddist",
    "buddister": "buddist",
    "buddisterna": "buddist",
    "buddisternas": "buddist",
    "buddisters": "buddist",
    "buddistiska": "buddistisk",
    "buddistiskare": "buddistisk",
    "buddistiskares": "buddistisk",
    "buddistiskas": "buddistisk",
    "buddistiskast": "buddistisk",
    "buddistiskaste": "buddistisk",
    "buddistiskastes": "buddistisk",
    "buddistiskasts": "buddistisk",
    "buddistiske": "buddistisk",
    "buddistiskes": "buddistisk",
    "buddistisks": "buddistisk",
    "buddistiskt": "buddistisk",
    "buddistiskts": "buddistisk",
    "buddists": "buddist",
    "buden": "bud",
    "budens": "bud",
    "budet": "bud",
    "budets": "bud",
    "budgetalternativen": "budgetalternativ",
    "budgetalternativens": "budgetalternativ",
    "budgetalternativet": "budgetalternativ",
    "budgetalternativets": "budgetalternativ",
    "budgetalternativs": "budgetalternativ",
    "budgetar": "budget",
    "budgetarna": "budget",
    "budgetarnas": "budget",
    "budgetars": "budget",
    "budgetdisciplinen": "budgetdisciplin",
    "budgetdisciplinens": "budgetdisciplin",
    "budgetdisciplins": "budgetdisciplin",
    "budgeten": "budget",
    "budgetens": "budget",
    "budgeter": "budget",
    "budgeterad": "budgetera",
    "budgeterade": "budgetera",
    "budgeterades": "budgetera",
    "budgeterads": "budgetera",
    "budgeterande": "budgetera",
    "budgeteranden": "budgeterande",
    "budgeterandena": "budgeterande",
    "budgeterandenas": "budgeterande",
    "budgeterandens": "budgeterande",
    "budgeterandes": "budgeterande",
    "budgeterandet": "budgeterande",
    "budgeterandets": "budgeterande",
    "budgeterar": "budgetera",
    "budgeteras": "budgetera",
    "budgeterat": "budgetera",
    "budgeterats": "budgetera",
    "budgeterbara": "budgeterbar",
    "budgeterbarare": "budgeterbar",
    "budgeterbarares": "budgeterbar",
    "budgeterbaras": "budgeterbar",
    "budgeterbarast": "budgeterbar",
    "budgeterbaraste": "budgeterbar",
    "budgeterbarastes": "budgeterbar",
    "budgeterbarasts": "budgeterbar",
    "budgeterbare": "budgeterbar",
    "budgeterbares": "budgeterbar",
    "budgeterbarheten": "budgeterbarhet",
    "budgeterbarhetens": "budgeterbarhet",
    "budgeterbarhets": "budgeterbarhet",
    "budgeterbars": "budgeterbar",
    "budgeterbart": "budgeterbar",
    "budgeterbarts": "budgeterbar",
    "budgeteringar": "budgetering",
    "budgeteringarna": "budgetering",
    "budgeteringarnas": "budgetering",
    "budgeteringars": "budgetering",
    "budgeteringen": "budgetering",
    "budgeteringens": "budgetering",
    "budgeterings": "budgetering",
    "budgeterna": "budget",
    "budgeternas": "budget",
    "budgeters": "budget",
    "budgetflygen": "budgetflyg",
    "budgetflygens": "budgetflyg",
    "budgetflyget": "budgetflyg",
    "budgetflygets": "budgetflyg",
    "budgetflygs": "budgetflyg",
    "budgetmässiga": "budgetmässig",
    "budgetmässigare": "budgetmässig",
    "budgetmässigares": "budgetmässig",
    "budgetmässigas": "budgetmässig",
    "budgetmässigast": "budgetmässig",
    "budgetmässigaste": "budgetmässig",
    "budgetmässigastes": "budgetmässig",
    "budgetmässigasts": "budgetmässig",
    "budgetmässige": "budgetmässig",
    "budgetmässiges": "budgetmässig",
    "budgetmässigs": "budgetmässig",
    "budgetmässigt": "budgetmässig",
    "budgetmässigts": "budgetmässig",
    "budgetpolitiken": "budgetpolitik",
    "budgetpolitikens": "budgetpolitik",
    "budgetpolitiks": "budgetpolitik",
    "budgetpolitiska": "budgetpolitisk",
    "budgetpolitiskare": "budgetpolitisk",
    "budgetpolitiskares": "budgetpolitisk",
    "budgetpolitiskas": "budgetpolitisk",
    "budgetpolitiskast": "budgetpolitisk",
    "budgetpolitiskaste": "budgetpolitisk",
    "budgetpolitiskastes": "budgetpolitisk",
    "budgetpolitiskasts": "budgetpolitisk",
    "budgetpolitiske": "budgetpolitisk",
    "budgetpolitiskes": "budgetpolitisk",
    "budgetpolitisks": "budgetpolitisk",
    "budgetpolitiskt": "budgetpolitisk",
    "budgetpolitiskts": "budgetpolitisk",
    "budgetpropositionen": "budgetproposition",
    "budgetpropositionens": "budgetproposition",
    "budgetpropositioner": "budgetproposition",
    "budgetpropositionerna": "budgetproposition",
    "budgetpropositionernas": "budgetproposition",
    "budgetpropositioners": "budgetproposition",
    "budgetpropositions": "budgetproposition",
    "budgetresan": "budgetresa",
    "budgetresans": "budgetresa",
    "budgetresas": "budgetresa",
    "budgetrese": "budgetresa",
    "budgetresor": "budgetresa",
    "budgetresorna": "budgetresa",
    "budgetresornas": "budgetresa",
    "budgetresors": "budgetresa",
    "budgets": "budget",
    "budgetspan": "budgetspa",
    "budgetspana": "budgetspa",
    "budgetspanas": "budgetspa",
    "budgetspans": "budgetspa",
    "budgetspas": "budgetspa",
    "budgetspat": "budgetspa",
    "budgetspats": "budgetspa",
    "budgetunderskotten": "budgetunderskott",
    "budgetunderskottens": "budgetunderskott",
    "budgetunderskottet": "budgetunderskott",
    "budgetunderskottets": "budgetunderskott",
    "budgetunderskotts": "budgetunderskott",
    "budgetvarianten": "budgetvariant",
    "budgetvariantens": "budgetvariant",
    "budgetvarianter": "budgetvariant",
    "budgetvarianterna": "budgetvariant",
    "budgetvarianternas": "budgetvariant",
    "budgetvarianters": "budgetvariant",
    "budgetvariants": "budgetvariant",
    "budgetära": "budgetär",
    "budgetärare": "budgetär",
    "budgetärares": "budgetär",
    "budgetäras": "budgetär",
    "budgetärast": "budgetär",
    "budgetäraste": "budgetär",
    "budgetärastes": "budgetär",
    "budgetärasts": "budgetär",
    "budgetäre": "budgetär",
    "budgetäres": "budgetär",
    "budgetärs": "budgetär",
    "budgetärt": "budgetär",
    "budgetärts": "budgetär",
    "budgetåren": "budgetår",
    "budgetårens": "budgetår",
    "budgetåret": "budgetår",
    "budgetårets": "budgetår",
    "budgetårs": "budgetår",
    "budgetöverskotten": "budgetöverskott",
    "budgetöverskottens": "budgetöverskott",
    "budgetöverskottet": "budgetöverskott",
    "budgetöverskottets": "budgetöverskott",
    "budgetöverskotts": "budgetöverskott",
    "budgivningar": "budgivning",
    "budgivningarna": "budgivning",
    "budgivningarnas": "budgivning",
    "budgivningars": "budgivning",
    "budgivningen": "budgivning",
    "budgivningens": "budgivning",
    "budgivnings": "budgivning",
    "budkaveln": "budkavel",
    "budkavelns": "budkavel",
    "budkavels": "budkavel",
    "budkavl": "budkavle",
    "budkavlar": "budkavle",
    "budkavlarna": "budkavle",
    "budkavlarnas": "budkavle",
    "budkavlars": "budkavle",
    "budkavlelöpningar": "budkavlelöpning",
    "budkavlelöpningarna": "budkavlelöpning",
    "budkavlelöpningarnas": "budkavlelöpning",
    "budkavlelöpningars": "budkavlelöpning",
    "budkavlelöpningen": "budkavlelöpning",
    "budkavlelöpningens": "budkavlelöpning",
    "budkavlelöpnings": "budkavlelöpning",
    "budkavlen": "budkavle",
    "budkavlens": "budkavle",
    "budkavles": "budkavle",
    "budkavls": "budkavle",
    "budoaren": "budoar",
    "budoarens": "budoar",
    "budoarer": "budoar",
    "budoarerna": "budoar",
    "budoarernas": "budoar",
    "budoarers": "budoar",
    "budoarmässiga": "budoarmässig",
    "budoarmässigare": "budoarmässig",
    "budoarmässigares": "budoarmässig",
    "budoarmässigas": "budoarmässig",
    "budoarmässigast": "budoarmässig",
    "budoarmässigaste": "budoarmässig",
    "budoarmässigastes": "budoarmässig",
    "budoarmässigasts": "budoarmässig",
    "budoarmässige": "budoarmässig",
    "budoarmässiges": "budoarmässig",
    "budoarmässigs": "budoarmässig",
    "budoarmässigt": "budoarmässig",
    "budoarmässigts": "budoarmässig",
    "budoars": "budoar",
    "budon": "budo",
    "budons": "budo",
    "budorden": "budord",
    "budordens": "budord",
    "budordet": "budord",
    "budordets": "budord",
    "budords": "budord",
    "budos": "budo",
    "buds": "bud",
    "budskapen": "budskap",
    "budskapens": "budskap",
    "budskapet": "budskap",
    "budskapets": "budskap",
    "budskaps": "budskap",
    "buff": "buffa",
    "buffad": "buffa",
    "buffade": "buffa",
    "buffades": "buffa",
    "buffads": "buffa",
    "buffan": "buffa",
    "buffande": "buffa",
    "buffanden": "buffande",
    "buffandena": "buffande",
    "buffandenas": "buffande",
    "buffandens": "buffande",
    "buffandes": "buffande",
    "buffandet": "buffande",
    "buffandets": "buffande",
    "buffans": "buffa",
    "buffaoperan": "buffaopera",
    "buffaoperans": "buffaopera",
    "buffaoperas": "buffaopera",
    "buffaoperor": "buffaopera",
    "buffaoperorna": "buffaopera",
    "buffaoperornas": "buffaopera",
    "buffaoperors": "buffaopera",
    "buffar": "buffa",
    "buffarna": "buff",
    "buffarnas": "buff",
    "buffars": "buff",
    "buffas": "buffa",
    "buffat": "buffa",
    "buffats": "buffa",
    "buffe": "buffa",
    "buffelaktiga": "buffelaktig",
    "buffelaktigare": "buffelaktig",
    "buffelaktigares": "buffelaktig",
    "buffelaktigas": "buffelaktig",
    "buffelaktigast": "buffelaktig",
    "buffelaktigaste": "buffelaktig",
    "buffelaktigastes": "buffelaktig",
    "buffelaktigasts": "buffelaktig",
    "buffelaktige": "buffelaktig",
    "buffelaktiges": "buffelaktig",
    "buffelaktigheten": "buffelaktighet",
    "buffelaktighetens": "buffelaktighet",
    "buffelaktighets": "buffelaktighet",
    "buffelaktigs": "buffelaktig",
    "buffelaktigt": "buffelaktig",
    "buffelaktigts": "buffelaktig",
    "buffelhjordar": "buffelhjord",
    "buffelhjordarna": "buffelhjord",
    "buffelhjordarnas": "buffelhjord",
    "buffelhjordars": "buffelhjord",
    "buffelhjorden": "buffelhjord",
    "buffelhjordens": "buffelhjord",
    "buffelhjords": "buffelhjord",
    "buffeln": "buffel",
    "buffelns": "buffel",
    "buffels": "buffel",
    "buffen": "buff",
    "buffens": "buff",
    "buffer": "buffra",
    "buffertar": "buffert",
    "buffertarna": "buffert",
    "buffertarnas": "buffert",
    "buffertars": "buffert",
    "bufferten": "buffert",
    "buffertens": "buffert",
    "buffertkapaciteten": "buffertkapacitet",
    "buffertkapacitetens": "buffertkapacitet",
    "buffertkapaciteter": "buffertkapacitet",
    "buffertkapaciteterna": "buffertkapacitet",
    "buffertkapaciteternas": "buffertkapacitet",
    "buffertkapaciteters": "buffertkapacitet",
    "buffertkapacitets": "buffertkapacitet",
    "buffertlagerna": "buffertlager",
    "buffertlagernas": "buffertlager",
    "buffertlagers": "buffertlager",
    "buffertlagren": "buffertlager",
    "buffertlagrens": "buffertlager",
    "buffertlagret": "buffertlager",
    "buffertlagrets": "buffertlager",
    "buffertlösningar": "buffertlösning",
    "buffertlösningarna": "buffertlösning",
    "buffertlösningarnas": "buffertlösning",
    "buffertlösningars": "buffertlösning",
    "buffertlösningen": "buffertlösning",
    "buffertlösningens": "buffertlösning",
    "buffertlösnings": "buffertlösning",
    "bufferts": "buffert",
    "buffertstaten": "buffertstat",
    "buffertstatens": "buffertstat",
    "buffertstater": "buffertstat",
    "buffertstaterna": "buffertstat",
    "buffertstaternas": "buffertstat",
    "buffertstaters": "buffertstat",
    "buffertstats": "buffertstat",
    "bufflar": "buffel",
    "bufflarna": "buffel",
    "bufflarnas": "buffel",
    "bufflars": "buffel",
    "buffliga": "bufflig",
    "buffligare": "bufflig",
    "buffligares": "bufflig",
    "buffligas": "bufflig",
    "buffligast": "bufflig",
    "buffligaste": "bufflig",
    "buffligastes": "bufflig",
    "buffligasts": "bufflig",
    "bufflige": "bufflig",
    "buffliges": "bufflig",
    "buffligheten": "bufflighet",
    "bufflighetens": "bufflighet",
    "buffligheter": "bufflighet",
    "buffligheterna": "bufflighet",
    "buffligheternas": "bufflighet",
    "buffligheters": "bufflighet",
    "bufflighets": "bufflighet",
    "buffligs": "bufflig",
    "buffligt": "bufflig",
    "buffligts": "bufflig",
    "buffor": "buffa",
    "bufforna": "buffa",
    "buffornas": "buffa",
    "buffors": "buffa",
    "buffrad": "buffra",
    "buffrade": "buffra",
    "buffrades": "buffra",
    "buffrads": "buffra",
    "buffrande": "buffra",
    "buffranden": "buffrande",
    "buffrandena": "buffrande",
    "buffrandenas": "buffrande",
    "buffrandens": "buffrande",
    "buffrandes": "buffrande",
    "buffrandet": "buffrande",
    "buffrandets": "buffrande",
    "buffrar": "buffra",
    "buffras": "buffra",
    "buffrat": "buffra",
    "buffrats": "buffra",
    "buffringsförmågan": "buffringsförmåga",
    "buffringsförmågans": "buffringsförmåga",
    "buffringsförmågas": "buffringsförmåga",
    "buffringsförmåge": "buffringsförmåga",
    "buffs": "buffa",
    "bufféer": "buffé",
    "bufféerna": "buffé",
    "bufféernas": "buffé",
    "bufféers": "buffé",
    "buffén": "buffé",
    "bufféns": "buffé",
    "buffés": "buffé",
    "bugade": "buga",
    "bugades": "buga",
    "bugande": "buga",
    "buganden": "bugande",
    "bugandena": "bugande",
    "bugandenas": "bugande",
    "bugandens": "bugande",
    "bugandes": "bugande",
    "bugandet": "bugande",
    "bugandets": "bugande",
    "bugar": "buga",
    "bugarna": "bug",
    "bugarnas": "bug",
    "bugars": "bug",
    "bugas": "buga",
    "bugat": "buga",
    "bugats": "buga",
    "bugen": "bug",
    "bugens": "bug",
    "buggade": "bugga",
    "buggades": "bugga",
    "buggande": "bugga",
    "bugganden": "buggande",
    "buggandena": "buggande",
    "buggandenas": "buggande",
    "buggandens": "buggande",
    "buggandes": "buggande",
    "buggandet": "buggande",
    "buggandets": "buggande",
    "buggar": "bugga",
    "buggarna": "bugg",
    "buggarnas": "bugg",
    "buggars": "bugg",
    "buggas": "bugga",
    "buggat": "bugga",
    "buggats": "bugga",
    "buggen": "bugg",
    "buggens": "bugg",
    "buggfixar": "buggfix",
    "buggfixarna": "buggfix",
    "buggfixarnas": "buggfix",
    "buggfixars": "buggfix",
    "buggfixen": "buggfix",
    "buggfixens": "buggfix",
    "buggningar": "buggning",
    "buggningarna": "buggning",
    "buggningarnas": "buggning",
    "buggningars": "buggning",
    "buggningen": "buggning",
    "buggningens": "buggning",
    "buggnings": "buggning",
    "buggs": "bugg",
    "bugningar": "bugning",
    "bugningarna": "bugning",
    "bugningarnas": "bugning",
    "bugningars": "bugning",
    "bugningen": "bugning",
    "bugningens": "bugning",
    "bugnings": "bugning",
    "bugs": "bug",
    "bukar": "buk",
    "bukarna": "buk",
    "bukarnas": "buk",
    "bukars": "buk",
    "buken": "buk",
    "bukens": "buk",
    "buketten": "bukett",
    "bukettens": "bukett",
    "buketter": "bukett",
    "buketterna": "bukett",
    "buketternas": "bukett",
    "buketters": "bukett",
    "bukettgrönts": "bukettgrönt",
    "buketts": "bukett",
    "bukfettet": "bukfett",
    "bukfettets": "bukfett",
    "bukfetts": "bukfett",
    "bukfettslagerna": "bukfettslager",
    "bukfettslagernas": "bukfettslager",
    "bukfettslagers": "bukfettslager",
    "bukfettslagren": "bukfettslager",
    "bukfettslagrens": "bukfettslager",
    "bukfettslagret": "bukfettslager",
    "bukfettslagrets": "bukfettslager",
    "bukformiga": "bukformig",
    "bukformigare": "bukformig",
    "bukformigares": "bukformig",
    "bukformigas": "bukformig",
    "bukformigast": "bukformig",
    "bukformigaste": "bukformig",
    "bukformigastes": "bukformig",
    "bukformigasts": "bukformig",
    "bukformige": "bukformig",
    "bukformiges": "bukformig",
    "bukformigs": "bukformig",
    "bukformigt": "bukformig",
    "bukformigts": "bukformig",
    "bukfyllan": "bukfylla",
    "bukfyllans": "bukfylla",
    "bukfyllas": "bukfylla",
    "bukgjordar": "bukgjord",
    "bukgjordarna": "bukgjord",
    "bukgjordarnas": "bukgjord",
    "bukgjordars": "bukgjord",
    "bukgjorden": "bukgjord",
    "bukgjordens": "bukgjord",
    "bukgjords": "bukgjord",
    "bukhinnan": "bukhinna",
    "bukhinnans": "bukhinna",
    "bukhinnas": "bukhinna",
    "bukhinne": "bukhinna",
    "bukhinneinflammationen": "bukhinneinflammation",
    "bukhinneinflammationens": "bukhinneinflammation",
    "bukhinneinflammationer": "bukhinneinflammation",
    "bukhinneinflammationerna": "bukhinneinflammation",
    "bukhinneinflammationernas": "bukhinneinflammation",
    "bukhinneinflammationers": "bukhinneinflammation",
    "bukhinneinflammations": "bukhinneinflammation",
    "bukhinnor": "bukhinna",
    "bukhinnorna": "bukhinna",
    "bukhinnornas": "bukhinna",
    "bukhinnors": "bukhinna",
    "bukhål": "bukhåla",
    "bukhålan": "bukhåla",
    "bukhålans": "bukhåla",
    "bukhålas": "bukhåla",
    "bukhåle": "bukhåla",
    "bukhålor": "bukhåla",
    "bukhålorna": "bukhåla",
    "bukhålornas": "bukhåla",
    "bukhålors": "bukhåla",
    "bukhåls": "bukhåla",
    "bukiga": "bukig",
    "bukigare": "bukig",
    "bukigares": "bukig",
    "bukigas": "bukig",
    "bukigast": "bukig",
    "bukigaste": "bukig",
    "bukigastes": "bukig",
    "bukigasts": "bukig",
    "bukige": "bukig",
    "bukiges": "bukig",
    "bukigs": "bukig",
    "bukigt": "bukig",
    "bukigts": "bukig",
    "buklandad": "buklanda",
    "buklandade": "buklanda",
    "buklandades": "buklanda",
    "buklandads": "buklanda",
    "buklandande": "buklanda",
    "buklandanden": "buklandande",
    "buklandandena": "buklandande",
    "buklandandenas": "buklandande",
    "buklandandens": "buklandande",
    "buklandandes": "buklandande",
    "buklandandet": "buklandande",
    "buklandandets": "buklandande",
    "buklandar": "buklanda",
    "buklandas": "buklanda",
    "buklandat": "buklanda",
    "buklandats": "buklanda",
    "bukmuskeln": "bukmuskel",
    "bukmuskelns": "bukmuskel",
    "bukmuskels": "bukmuskel",
    "bukmuskler": "bukmuskel",
    "bukmusklerna": "bukmuskel",
    "bukmusklernas": "bukmuskel",
    "bukmusklers": "bukmuskel",
    "bukoliska": "bukolisk",
    "bukoliskare": "bukolisk",
    "bukoliskares": "bukolisk",
    "bukoliskas": "bukolisk",
    "bukoliskast": "bukolisk",
    "bukoliskaste": "bukolisk",
    "bukoliskastes": "bukolisk",
    "bukoliskasts": "bukolisk",
    "bukoliske": "bukolisk",
    "bukoliskes": "bukolisk",
    "bukolisks": "bukolisk",
    "bukoliskt": "bukolisk",
    "bukoliskts": "bukolisk",
    "buks": "buk",
    "bukspotten": "bukspott",
    "bukspottens": "bukspott",
    "bukspottet": "bukspott",
    "bukspottets": "bukspott",
    "bukspottkörteln": "bukspottkörtel",
    "bukspottkörtelns": "bukspottkörtel",
    "bukspottkörtels": "bukspottkörtel",
    "bukspottkörtlar": "bukspottkörtel",
    "bukspottkörtlarna": "bukspottkörtel",
    "bukspottkörtlarnas": "bukspottkörtel",
    "bukspottkörtlars": "bukspottkörtel",
    "bukspotts": "bukspott",
    "bukstinna": "bukstinn",
    "bukstinnare": "bukstinn",
    "bukstinnares": "bukstinn",
    "bukstinnas": "bukstinn",
    "bukstinnast": "bukstinn",
    "bukstinnaste": "bukstinn",
    "bukstinnastes": "bukstinn",
    "bukstinnasts": "bukstinn",
    "bukstinne": "bukstinn",
    "bukstinnes": "bukstinn",
    "bukstinnheten": "bukstinnhet",
    "bukstinnhetens": "bukstinnhet",
    "bukstinnhets": "bukstinnhet",
    "bukstinns": "bukstinn",
    "bukstint": "bukstinn",
    "bukstints": "bukstinn",
    "buksvågern": "buksvåger",
    "buksvågerns": "buksvåger",
    "buksvågers": "buksvåger",
    "buksvågrar": "buksvåger",
    "buksvågrarna": "buksvåger",
    "buksvågrarnas": "buksvåger",
    "buksvågrars": "buksvåger",
    "buktade": "bukta",
    "buktades": "bukta",
    "buktalade": "buktala",
    "buktalades": "buktala",
    "buktalande": "buktala",
    "buktalanden": "buktalande",
    "buktalandena": "buktalande",
    "buktalandenas": "buktalande",
    "buktalandens": "buktalande",
    "buktalandes": "buktalande",
    "buktalandet": "buktalande",
    "buktalandets": "buktalande",
    "buktalar": "buktalare",
    "buktalaren": "buktalare",
    "buktalarens": "buktalare",
    "buktalares": "buktalare",
    "buktalarna": "buktalare",
    "buktalarnas": "buktalare",
    "buktalas": "buktala",
    "buktalat": "buktala",
    "buktalats": "buktala",
    "buktande": "bukta",
    "buktanden": "buktande",
    "buktandena": "buktande",
    "buktandenas": "buktande",
    "buktandens": "buktande",
    "buktandes": "buktande",
    "buktandet": "buktande",
    "buktandets": "buktande",
    "buktar": "bukta",
    "buktas": "bukta",
    "buktat": "bukta",
    "buktats": "bukta",
    "bukten": "bukt",
    "buktens": "bukt",
    "bukter": "bukt",
    "bukterna": "bukt",
    "bukternas": "bukt",
    "bukters": "bukt",
    "buktiga": "buktig",
    "buktigare": "buktig",
    "buktigares": "buktig",
    "buktigas": "buktig",
    "buktigast": "buktig",
    "buktigaste": "buktig",
    "buktigastes": "buktig",
    "buktigasts": "buktig",
    "buktige": "buktig",
    "buktiges": "buktig",
    "buktigheten": "buktighet",
    "buktighetens": "buktighet",
    "buktighets": "buktighet",
    "buktigs": "buktig",
    "buktigt": "buktig",
    "buktigts": "buktig",
    "bukts": "bukt",
    "bukväggar": "bukvägg",
    "bukväggarna": "bukvägg",
    "bukväggarnas": "bukvägg",
    "bukväggars": "bukvägg",
    "bukväggen": "bukvägg",
    "bukväggens": "bukvägg",
    "bukväggs": "bukvägg",
    "bul": "bula",
    "bulan": "bula",
    "bulans": "bula",
    "bulas": "bula",
    "bulben": "bulb",
    "bulbens": "bulb",
    "bulber": "bulb",
    "bulberna": "bulb",
    "bulbernas": "bulb",
    "bulbers": "bulb",
    "bulbjärnen": "bulbjärn",
    "bulbjärnens": "bulbjärn",
    "bulbjärnet": "bulbjärn",
    "bulbjärnets": "bulbjärn",
    "bulbjärns": "bulbjärn",
    "bulbs": "bulb",
    "buldanen": "buldan",
    "buldanens": "buldan",
    "buldanet": "buldan",
    "buldanets": "buldan",
    "buldans": "buldan",
    "bule": "bula",
    "bulevarden": "bulevard",
    "bulevardens": "bulevard",
    "bulevarder": "bulevard",
    "bulevarderna": "bulevard",
    "bulevardernas": "bulevard",
    "bulevarders": "bulevard",
    "bulevards": "bulevard",
    "bulgaren": "bulgar",
    "bulgarens": "bulgar",
    "bulgarer": "bulgar",
    "bulgarerna": "bulgar",
    "bulgarernas": "bulgar",
    "bulgarers": "bulgar",
    "bulgarisk": "bulgariska",
    "bulgariska": "bulgarisk",
    "bulgariskan": "bulgariska",
    "bulgariskans": "bulgariska",
    "bulgariskare": "bulgarisk",
    "bulgariskares": "bulgarisk",
    "bulgariskas": "bulgariska",
    "bulgariskast": "bulgarisk",
    "bulgariskaste": "bulgarisk",
    "bulgariskastes": "bulgarisk",
    "bulgariskasts": "bulgarisk",
    "bulgariske": "bulgariska",
    "bulgariskes": "bulgarisk",
    "bulgariskor": "bulgariska",
    "bulgariskorna": "bulgariska",
    "bulgariskornas": "bulgariska",
    "bulgariskors": "bulgariska",
    "bulgarisks": "bulgarisk",
    "bulgariskt": "bulgarisk",
    "bulgariskts": "bulgarisk",
    "bulgars": "bulgar",
    "bulguren": "bulgur",
    "bulgurens": "bulgur",
    "bulguret": "bulgur",
    "bulgurets": "bulgur",
    "bulgurns": "bulgurn",
    "bulgurs": "bulgur",
    "bulimien": "bulimi",
    "bulimiens": "bulimi",
    "bulimier": "bulimi",
    "bulimierna": "bulimi",
    "bulimiernas": "bulimi",
    "bulimiers": "bulimi",
    "bulimin": "bulimi",
    "bulimins": "bulimi",
    "bulimis": "bulimi",
    "buljongbenen": "buljongben",
    "buljongbenens": "buljongben",
    "buljongbenet": "buljongben",
    "buljongbenets": "buljongben",
    "buljongbens": "buljongben",
    "buljongen": "buljong",
    "buljongens": "buljong",
    "buljonger": "buljong",
    "buljongerna": "buljong",
    "buljongernas": "buljong",
    "buljongers": "buljong",
    "buljongköttet": "buljongkött",
    "buljongköttets": "buljongkött",
    "buljongkötts": "buljongkött",
    "buljongs": "buljong",
    "buljongtärningar": "buljongtärning",
    "buljongtärningarna": "buljongtärning",
    "buljongtärningarnas": "buljongtärning",
    "buljongtärningars": "buljongtärning",
    "buljongtärningen": "buljongtärning",
    "buljongtärningens": "buljongtärning",
    "buljongtärnings": "buljongtärning",
    "bulken": "bulk",
    "bulkens": "bulk",
    "bulkfartygen": "bulkfartyg",
    "bulkfartygens": "bulkfartyg",
    "bulkfartyget": "bulkfartyg",
    "bulkfartygets": "bulkfartyg",
    "bulkfartygs": "bulkfartyg",
    "bulklastar": "bulklastare",
    "bulklastaren": "bulklastare",
    "bulklastarens": "bulklastare",
    "bulklastares": "bulklastare",
    "bulklastarna": "bulklastare",
    "bulklastarnas": "bulklastare",
    "bulklasten": "bulklast",
    "bulklastens": "bulklast",
    "bulklaster": "bulklast",
    "bulklasterna": "bulklast",
    "bulklasternas": "bulklast",
    "bulklasters": "bulklast",
    "bulklasts": "bulklast",
    "bulkmedels": "bulkmedel",
    "bulkmedlen": "bulkmedel",
    "bulkmedlens": "bulkmedel",
    "bulkmedlet": "bulkmedel",
    "bulkmedlets": "bulkmedel",
    "bulks": "bulk",
    "bull": "bulle",
    "bullan": "bulla",
    "bullans": "bulla",
    "bullar": "bulle",
    "bullarna": "bulle",
    "bullarnas": "bulle",
    "bullars": "bulle",
    "bullas": "bulla",
    "bulldoggar": "bulldogg",
    "bulldoggarna": "bulldogg",
    "bulldoggarnas": "bulldogg",
    "bulldoggars": "bulldogg",
    "bulldoggen": "bulldogg",
    "bulldoggens": "bulldogg",
    "bulldoggs": "bulldogg",
    "bulldozern": "bulldozer",
    "bulldozerns": "bulldozer",
    "bulldozers": "bulldozer",
    "bulldozersarna": "bulldozer",
    "bulldozersarnas": "bulldozer",
    "bulldozersen": "bulldozer",
    "bulldozersens": "bulldozer",
    "bulldozrar": "bulldozer",
    "bulldozrarna": "bulldozer",
    "bulldozrarnas": "bulldozer",
    "bulldozrars": "bulldozer",
    "bulle": "bulla",
    "bullen": "bulle",
    "bullens": "bulle",
    "buller": "bullra",
    "bullerbasar": "bullerbas",
    "bullerbasarna": "bullerbas",
    "bullerbasarnas": "bullerbas",
    "bullerbasars": "bullerbas",
    "bullerbasen": "bullerbas",
    "bullerbasens": "bullerbas",
    "bullerblomsterna": "bullerblomster",
    "bullerblomsternas": "bullerblomster",
    "bullerblomsters": "bullerblomster",
    "bullerblomstren": "bullerblomster",
    "bullerblomstrens": "bullerblomster",
    "bullerblomstret": "bullerblomster",
    "bullerblomstrets": "bullerblomster",
    "bullerdämpningen": "bullerdämpning",
    "bullerdämpningens": "bullerdämpning",
    "bullerdämpnings": "bullerdämpning",
    "bullerkraven": "bullerkrav",
    "bullerkravens": "bullerkrav",
    "bullerkravet": "bullerkrav",
    "bullerkravets": "bullerkrav",
    "bullerkravs": "bullerkrav",
    "bullermatt": "bullermatta",
    "bullermattan": "bullermatta",
    "bullermattans": "bullermatta",
    "bullermattas": "bullermatta",
    "bullermatte": "bullermatta",
    "bullermattor": "bullermatta",
    "bullermattorna": "bullermatta",
    "bullermattornas": "bullermatta",
    "bullermattors": "bullermatta",
    "bullermatts": "bullermatta",
    "bullerna": "buller",
    "bullernas": "buller",
    "bullers": "buller",
    "bullersamheten": "bullersamhet",
    "bullersamhetens": "bullersamhet",
    "bullersamhets": "bullersamhet",
    "bullersamma": "bullersam",
    "bullersammare": "bullersam",
    "bullersammares": "bullersam",
    "bullersammas": "bullersam",
    "bullersammast": "bullersam",
    "bullersammaste": "bullersam",
    "bullersammastes": "bullersam",
    "bullersammasts": "bullersam",
    "bullersamme": "bullersam",
    "bullersammes": "bullersam",
    "bullersams": "bullersam",
    "bullersamt": "bullersam",
    "bullersamts": "bullersam",
    "bullerskadan": "bullerskada",
    "bullerskadans": "bullerskada",
    "bullerskadas": "bullerskada",
    "bullerskade": "bullerskada",
    "bullerskador": "bullerskada",
    "bullerskadorna": "bullerskada",
    "bullerskadornas": "bullerskada",
    "bullerskadors": "bullerskada",
    "bullerstenar": "bullersten",
    "bullerstenarna": "bullersten",
    "bullerstenarnas": "bullersten",
    "bullerstenars": "bullersten",
    "bullerstenen": "bullersten",
    "bullerstenens": "bullersten",
    "bullerstens": "bullersten",
    "bulles": "bulle",
    "bulletinen": "bulletin",
    "bulletinens": "bulletin",
    "bulletiner": "bulletin",
    "bulletinerna": "bulletin",
    "bulletinernas": "bulletin",
    "bulletiners": "bulletin",
    "bulletins": "bulletin",
    "bulliga": "bullig",
    "bulligare": "bullig",
    "bulligares": "bullig",
    "bulligas": "bullig",
    "bulligast": "bullig",
    "bulligaste": "bullig",
    "bulligastes": "bullig",
    "bulligasts": "bullig",
    "bullige": "bullig",
    "bulliges": "bullig",
    "bulligheten": "bullighet",
    "bullighetens": "bullighet",
    "bullighets": "bullighet",
    "bulligs": "bullig",
    "bulligt": "bullig",
    "bulligts": "bullig",
    "bullor": "bulla",
    "bullorna": "bulla",
    "bullornas": "bulla",
    "bullors": "bulla",
    "bullrade": "bullra",
    "bullrades": "bullra",
    "bullrande": "bullra",
    "bullranden": "bullrande",
    "bullrandena": "bullrande",
    "bullrandenas": "bullrande",
    "bullrandens": "bullrande",
    "bullrandes": "bullrande",
    "bullrandet": "bullrande",
    "bullrandets": "bullrande",
    "bullrar": "bullra",
    "bullras": "bullra",
    "bullrat": "bullra",
    "bullrats": "bullra",
    "bullren": "buller",
    "bullrens": "buller",
    "bullret": "buller",
    "bullrets": "buller",
    "bullriga": "bullrig",
    "bullrigare": "bullrig",
    "bullrigares": "bullrig",
    "bullrigas": "bullrig",
    "bullrigast": "bullrig",
    "bullrigaste": "bullrig",
    "bullrigastes": "bullrig",
    "bullrigasts": "bullrig",
    "bullrige": "bullrig",
    "bullriges": "bullrig",
    "bullrigheten": "bullrighet",
    "bullrighetens": "bullrighet",
    "bullrighets": "bullrighet",
    "bullrigs": "bullrig",
    "bullrigt": "bullrig",
    "bullrigts": "bullrig",
    "bulls": "bulle",
    "bullshiten": "bullshit",
    "bullshitens": "bullshit",
    "bullshitet": "bullshit",
    "bullshitets": "bullshit",
    "bullshits": "bullshit",
    "bulnade": "bulna",
    "bulnaden": "bulnad",
    "bulnadens": "bulnad",
    "bulnader": "bulnad",
    "bulnaderna": "bulnad",
    "bulnadernas": "bulnad",
    "bulnaders": "bulnad",
    "bulnades": "bulna",
    "bulnads": "bulnad",
    "bulnande": "bulna",
    "bulnanden": "bulnande",
    "bulnandena": "bulnande",
    "bulnandenas": "bulnande",
    "bulnandens": "bulnande",
    "bulnandes": "bulnande",
    "bulnandet": "bulnande",
    "bulnandets": "bulnande",
    "bulnar": "bulna",
    "bulnas": "bulna",
    "bulnat": "bulna",
    "bulnats": "bulna",
    "bulor": "bula",
    "bulorna": "bula",
    "bulornas": "bula",
    "bulors": "bula",
    "buls": "bula",
    "bulsiga": "bulsig",
    "bulsigare": "bulsig",
    "bulsigares": "bulsig",
    "bulsigas": "bulsig",
    "bulsigast": "bulsig",
    "bulsigaste": "bulsig",
    "bulsigastes": "bulsig",
    "bulsigasts": "bulsig",
    "bulsige": "bulsig",
    "bulsiges": "bulsig",
    "bulsigheten": "bulsighet",
    "bulsighetens": "bulsighet",
    "bulsighets": "bulsighet",
    "bulsigs": "bulsig",
    "bulsigt": "bulsig",
    "bulsigts": "bulsig",
    "bult": "bulta",
    "bultad": "bulta",
    "bultade": "bulta",
    "bultades": "bulta",
    "bultads": "bulta",
    "bultande": "bulta",
    "bultanden": "bultande",
    "bultandena": "bultande",
    "bultandenas": "bultande",
    "bultandens": "bultande",
    "bultandes": "bultande",
    "bultandet": "bultande",
    "bultandets": "bultande",
    "bultar": "bulta",
    "bultarna": "bult",
    "bultarnas": "bult",
    "bultars": "bult",
    "bultas": "bulta",
    "bultat": "bulta",
    "bultats": "bulta",
    "bulten": "bult",
    "bultens": "bult",
    "bulthuvuden": "bulthuvud",
    "bulthuvudena": "bulthuvud",
    "bulthuvudenas": "bulthuvud",
    "bulthuvudens": "bulthuvud",
    "bulthuvudet": "bulthuvud",
    "bulthuvudets": "bulthuvud",
    "bulthuvuds": "bulthuvud",
    "bultpistolen": "bultpistol",
    "bultpistolens": "bultpistol",
    "bultpistoler": "bultpistol",
    "bultpistolerna": "bultpistol",
    "bultpistolernas": "bultpistol",
    "bultpistolers": "bultpistol",
    "bultpistols": "bultpistol",
    "bults": "bult",
    "bultsaxar": "bultsax",
    "bultsaxarna": "bultsax",
    "bultsaxarnas": "bultsax",
    "bultsaxars": "bultsax",
    "bultsaxen": "bultsax",
    "bultsaxens": "bultsax",
    "bultskall": "bultskalle",
    "bultskallar": "bultskalle",
    "bultskallarna": "bultskalle",
    "bultskallarnas": "bultskalle",
    "bultskallars": "bultskalle",
    "bultskallen": "bultskalle",
    "bultskallens": "bultskalle",
    "bultskalles": "bultskalle",
    "bultskalls": "bultskalle",
    "bulvanen": "bulvan",
    "bulvanens": "bulvan",
    "bulvaner": "bulvan",
    "bulvanerna": "bulvan",
    "bulvanernas": "bulvan",
    "bulvaners": "bulvan",
    "bulvans": "bulvan",
    "bulvanverksamheten": "bulvanverksamhet",
    "bulvanverksamhetens": "bulvanverksamhet",
    "bulvanverksamheter": "bulvanverksamhet",
    "bulvanverksamheterna": "bulvanverksamhet",
    "bulvanverksamheternas": "bulvanverksamhet",
    "bulvanverksamheters": "bulvanverksamhet",
    "bulvanverksamhets": "bulvanverksamhet",
    "bumerangen": "bumerang",
    "bumerangens": "bumerang",
    "bumeranger": "bumerang",
    "bumerangerna": "bumerang",
    "bumerangernas": "bumerang",
    "bumerangers": "bumerang",
    "bumerangs": "bumerang",
    "bumlingar": "bumling",
    "bumlingarna": "bumling",
    "bumlingarnas": "bumling",
    "bumlingars": "bumling",
    "bumlingen": "bumling",
    "bumlingens": "bumling",
    "bumlings": "bumling",
    "bunde": "binda",
    "bunden": "binda",
    "bundenheten": "bundenhet",
    "bundenhetens": "bundenhet",
    "bundenhets": "bundenhet",
    "bundens": "bunden",
    "bundes": "binda",
    "bundet": "bunden",
    "bundets": "bunden",
    "bundit": "binda",
    "bundits": "binda",
    "bundna": "bunden",
    "bundnare": "bunden",
    "bundnares": "bunden",
    "bundnas": "bunden",
    "bundnast": "bunden",
    "bundnaste": "bunden",
    "bundnastes": "bunden",
    "bundnasts": "bunden",
    "bundne": "bunden",
    "bundnes": "bunden",
    "bundsförvanten": "bundsförvant",
    "bundsförvantens": "bundsförvant",
    "bundsförvanter": "bundsförvant",
    "bundsförvanterna": "bundsförvant",
    "bundsförvanternas": "bundsförvant",
    "bundsförvanters": "bundsförvant",
    "bundsförvants": "bundsförvant",
    "bungalowen": "bungalow",
    "bungalowens": "bungalow",
    "bungalower": "bungalow",
    "bungalowerna": "bungalow",
    "bungalowernas": "bungalow",
    "bungalowers": "bungalow",
    "bungalows": "bungalow",
    "bunk": "bunke",
    "bunkar": "bunke",
    "bunkarna": "bunke",
    "bunkarnas": "bunke",
    "bunkars": "bunke",
    "bunken": "bunke",
    "bunkens": "bunke",
    "bunker": "bunkra",
    "bunkern": "bunker",
    "bunkerns": "bunker",
    "bunkers": "bunker",
    "bunkersarna": "bunker",
    "bunkersarnas": "bunker",
    "bunkersen": "bunker",
    "bunkersens": "bunker",
    "bunkes": "bunke",
    "bunkrad": "bunkra",
    "bunkrade": "bunkra",
    "bunkrades": "bunkra",
    "bunkrads": "bunkra",
    "bunkrande": "bunkra",
    "bunkranden": "bunkrande",
    "bunkrandena": "bunkrande",
    "bunkrandenas": "bunkrande",
    "bunkrandens": "bunkrande",
    "bunkrandes": "bunkrande",
    "bunkrandet": "bunkrande",
    "bunkrandets": "bunkrande",
    "bunkrar": "bunkra",
    "bunkrarna": "bunker",
    "bunkrarnas": "bunker",
    "bunkrars": "bunker",
    "bunkras": "bunkra",
    "bunkrat": "bunkra",
    "bunkrats": "bunkra",
    "bunkringsoljan": "bunkringsolja",
    "bunkringsoljans": "bunkringsolja",
    "bunkringsoljas": "bunkringsolja",
    "bunkringsolje": "bunkringsolja",
    "bunks": "bunke",
    "bunkstålet": "bunkstål",
    "bunkstålets": "bunkstål",
    "bunkståls": "bunkstål",
    "bunsenbrännar": "bunsenbrännare",
    "bunsenbrännaren": "bunsenbrännare",
    "bunsenbrännarens": "bunsenbrännare",
    "bunsenbrännares": "bunsenbrännare",
    "bunsenbrännarna": "bunsenbrännare",
    "bunsenbrännarnas": "bunsenbrännare",
    "bunt": "bunta",
    "buntad": "bunta",
    "buntade": "bunta",
    "buntades": "bunta",
    "buntads": "bunta",
    "buntande": "bunta",
    "buntanden": "buntande",
    "buntandena": "buntande",
    "buntandenas": "buntande",
    "buntandens": "buntande",
    "buntandes": "buntande",
    "buntandet": "buntande",
    "buntandets": "buntande",
    "buntar": "bunta",
    "buntarna": "bunt",
    "buntarnas": "bunt",
    "buntars": "bunt",
    "buntas": "bunta",
    "buntat": "bunta",
    "buntats": "bunta",
    "bunten": "bunt",
    "buntens": "bunt",
    "buntmakar": "buntmakare",
    "buntmakaren": "buntmakare",
    "buntmakarens": "buntmakare",
    "buntmakares": "buntmakare",
    "buntmakarna": "buntmakare",
    "buntmakarnas": "buntmakare",
    "bunts": "bunt",
    "burar": "bur",
    "burarna": "bur",
    "burarnas": "bur",
    "burars": "bur",
    "burbreven": "burbrev",
    "burbrevens": "burbrev",
    "burbrevet": "burbrev",
    "burbrevets": "burbrev",
    "burbrevs": "burbrev",
    "burdusa": "burdus",
    "burdusare": "burdus",
    "burdusares": "burdus",
    "burdusas": "burdus",
    "burdusast": "burdus",
    "burdusaste": "burdus",
    "burdusastes": "burdus",
    "burdusasts": "burdus",
    "burduse": "burdus",
    "burduses": "burdus",
    "burdust": "burdus",
    "burdusts": "burdus",
    "bure": "bära",
    "buren": "bur",
    "burens": "buren",
    "bures": "bära",
    "buret": "buren",
    "burets": "buren",
    "burfågeln": "burfågel",
    "burfågelns": "burfågel",
    "burfågels": "burfågel",
    "burfåglar": "burfågel",
    "burfåglarna": "burfågel",
    "burfåglarnas": "burfågel",
    "burfåglars": "burfågel",
    "burgar": "burgare",
    "burgarbaren": "burgarbar",
    "burgarbarens": "burgarbar",
    "burgarbarer": "burgarbar",
    "burgarbarerna": "burgarbar",
    "burgarbarernas": "burgarbar",
    "burgarbarers": "burgarbar",
    "burgarbars": "burgarbar",
    "burgaren": "burgare",
    "burgarens": "burgare",
    "burgares": "burgare",
    "burgarna": "burgare",
    "burgarnas": "burgare",
    "burgarrestaurangen": "burgarrestaurang",
    "burgarrestaurangens": "burgarrestaurang",
    "burgarrestauranger": "burgarrestaurang",
    "burgarrestaurangerna": "burgarrestaurang",
    "burgarrestaurangernas": "burgarrestaurang",
    "burgarrestaurangers": "burgarrestaurang",
    "burgarrestaurangs": "burgarrestaurang",
    "burgarställen": "burgarställe",
    "burgarställena": "burgarställe",
    "burgarställenas": "burgarställe",
    "burgarställens": "burgarställe",
    "burgarställes": "burgarställe",
    "burgarstället": "burgarställe",
    "burgarställets": "burgarställe",
    "burgenheten": "burgenhet",
    "burgenhetens": "burgenhet",
    "burgenhets": "burgenhet",
    "burgens": "burgen",
    "burgerbaren": "burgerbar",
    "burgerbarens": "burgerbar",
    "burgerbarer": "burgerbar",
    "burgerbarerna": "burgerbar",
    "burgerbarernas": "burgerbar",
    "burgerbarers": "burgerbar",
    "burgerbars": "burgerbar",
    "burgerrestaurangen": "burgerrestaurang",
    "burgerrestaurangens": "burgerrestaurang",
    "burgerrestauranger": "burgerrestaurang",
    "burgerrestaurangerna": "burgerrestaurang",
    "burgerrestaurangernas": "burgerrestaurang",
    "burgerrestaurangers": "burgerrestaurang",
    "burgerrestaurangs": "burgerrestaurang",
    "burgerställen": "burgerställe",
    "burgerställena": "burgerställe",
    "burgerställenas": "burgerställe",
    "burgerställens": "burgerställe",
    "burgerställes": "burgerställe",
    "burgerstället": "burgerställe",
    "burgerställets": "burgerställe",
    "burget": "burgen",
    "burgets": "burgen",
    "burgna": "burgen",
    "burgnare": "burgen",
    "burgnares": "burgen",
    "burgnas": "burgen",
    "burgnast": "burgen",
    "burgnaste": "burgen",
    "burgnastes": "burgen",
    "burgnasts": "burgen",
    "burgne": "burgen",
    "burgnes": "burgen",
    "burgundern": "burgunder",
    "burgunderna": "burgunder",
    "burgundernas": "burgunder",
    "burgunderns": "burgunder",
    "burgunders": "burgunder",
    "burit": "bära",
    "burits": "bära",
    "burk": "burka",
    "burkad": "burka",
    "burkade": "burka",
    "burkades": "burka",
    "burkads": "burka",
    "burkan": "burka",
    "burkande": "burka",
    "burkanden": "burkande",
    "burkandena": "burkande",
    "burkandenas": "burkande",
    "burkandens": "burkande",
    "burkandes": "burkande",
    "burkandet": "burkande",
    "burkandets": "burkande",
    "burkans": "burka",
    "burkar": "burka",
    "burkarna": "burk",
    "burkarnas": "burk",
    "burkars": "burk",
    "burkas": "burka",
    "burkat": "burka",
    "burkats": "burka",
    "burken": "burk",
    "burkens": "burk",
    "burkhållar": "burkhållare",
    "burkhållaren": "burkhållare",
    "burkhållarens": "burkhållare",
    "burkhållares": "burkhållare",
    "burkhållarna": "burkhållare",
    "burkhållarnas": "burkhållare",
    "burkiniern": "burkinier",
    "burkinierna": "burkinier",
    "burkiniernas": "burkinier",
    "burkinierns": "burkinier",
    "burkiniers": "burkinier",
    "burkinska": "burkinsk",
    "burkinskan": "burkinska",
    "burkinskans": "burkinska",
    "burkinskare": "burkinsk",
    "burkinskares": "burkinsk",
    "burkinskas": "burkinska",
    "burkinskast": "burkinsk",
    "burkinskaste": "burkinsk",
    "burkinskastes": "burkinsk",
    "burkinskasts": "burkinsk",
    "burkinske": "burkinska",
    "burkinskes": "burkinsk",
    "burkinskor": "burkinska",
    "burkinskorna": "burkinska",
    "burkinskornas": "burkinska",
    "burkinskors": "burkinska",
    "burkinsks": "burkinsk",
    "burkinskt": "burkinsk",
    "burkinskts": "burkinsk",
    "burkmaten": "burkmat",
    "burkmatens": "burkmat",
    "burkmats": "burkmat",
    "burkor": "burka",
    "burkorna": "burka",
    "burkornas": "burka",
    "burkors": "burka",
    "burks": "burk",
    "burkslavar": "burkslav",
    "burkslavarna": "burkslav",
    "burkslavarnas": "burkslav",
    "burkslavars": "burkslav",
    "burkslaven": "burkslav",
    "burkslavens": "burkslav",
    "burkslavs": "burkslav",
    "burkölen": "burköl",
    "burkölens": "burköl",
    "burkölet": "burköl",
    "burkölets": "burköl",
    "burköls": "burköl",
    "burköppnar": "burköppnare",
    "burköppnaren": "burköppnare",
    "burköppnarens": "burköppnare",
    "burköppnares": "burköppnare",
    "burköppnarna": "burköppnare",
    "burköppnarnas": "burköppnare",
    "burleska": "burlesk",
    "burleskare": "burlesk",
    "burleskares": "burlesk",
    "burleskas": "burlesk",
    "burleskast": "burlesk",
    "burleskaste": "burlesk",
    "burleskastes": "burlesk",
    "burleskasts": "burlesk",
    "burleske": "burlesk",
    "burlesken": "burlesk",
    "burleskens": "burlesk",
    "burlesker": "burlesk",
    "burleskerier": "burleskeri",
    "burleskerierna": "burleskeri",
    "burleskeriernas": "burleskeri",
    "burleskeriers": "burleskeri",
    "burleskeriet": "burleskeri",
    "burleskeriets": "burleskeri",
    "burleskeris": "burleskeri",
    "burleskerit": "burleskeri",
    "burleskerits": "burleskeri",
    "burleskerna": "burlesk",
    "burleskernas": "burlesk",
    "burleskers": "burlesk",
    "burleskes": "burlesk",
    "burlesks": "burlesk",
    "burleskt": "burlesk",
    "burleskts": "burlesk",
    "burmanen": "burman",
    "burmanens": "burman",
    "burmaner": "burman",
    "burmanerna": "burman",
    "burmanernas": "burman",
    "burmaners": "burman",
    "burmans": "burman",
    "burmansk": "burmanska",
    "burmanska": "burmansk",
    "burmanskan": "burmanska",
    "burmanskans": "burmanska",
    "burmanskare": "burmansk",
    "burmanskares": "burmansk",
    "burmanskas": "burmanska",
    "burmanskast": "burmansk",
    "burmanskaste": "burmansk",
    "burmanskastes": "burmansk",
    "burmanskasts": "burmansk",
    "burmanske": "burmanska",
    "burmanskes": "burmansk",
    "burmanskor": "burmanska",
    "burmanskorna": "burmanska",
    "burmanskornas": "burmanska",
    "burmanskors": "burmanska",
    "burmansks": "burmansk",
    "burmanskt": "burmansk",
    "burmanskts": "burmansk",
    "burmesen": "burmes",
    "burmesens": "burmes",
    "burmeser": "burmes",
    "burmeserna": "burmes",
    "burmesernas": "burmes",
    "burmesers": "burmes",
    "burmesisk": "burmesiska",
    "burmesiska": "burmesisk",
    "burmesiskan": "burmesiska",
    "burmesiskans": "burmesiska",
    "burmesiskare": "burmesisk",
    "burmesiskares": "burmesisk",
    "burmesiskas": "burmesiska",
    "burmesiskast": "burmesisk",
    "burmesiskaste": "burmesisk",
    "burmesiskastes": "burmesisk",
    "burmesiskasts": "burmesisk",
    "burmesiske": "burmesiska",
    "burmesiskes": "burmesisk",
    "burmesiskor": "burmesiska",
    "burmesiskorna": "burmesiska",
    "burmesiskornas": "burmesiska",
    "burmesiskors": "burmesiska",
    "burmesisks": "burmesisk",
    "burmesiskt": "burmesisk",
    "burmesiskts": "burmesisk",
    "burna": "buren",
    "burnas": "buren",
    "burne": "buren",
    "burnes": "buren",
    "burnusar": "burnus",
    "burnusarna": "burnus",
    "burnusarnas": "burnus",
    "burnusars": "burnus",
    "burnusen": "burnus",
    "burnusens": "burnus",
    "burnuser": "burnus",
    "burnuserna": "burnus",
    "burnusernas": "burnus",
    "burnusers": "burnus",
    "burren": "burr",
    "burrens": "burr",
    "burret": "burr",
    "burrets": "burr",
    "burriga": "burrig",
    "burrigare": "burrig",
    "burrigares": "burrig",
    "burrigas": "burrig",
    "burrigast": "burrig",
    "burrigaste": "burrig",
    "burrigastes": "burrig",
    "burrigasts": "burrig",
    "burrige": "burrig",
    "burriges": "burrig",
    "burrigheten": "burrighet",
    "burrighetens": "burrighet",
    "burrighets": "burrighet",
    "burrigs": "burrig",
    "burrigt": "burrig",
    "burrigts": "burrig",
    "burrs": "burr",
    "burs": "bur",
    "burschikosa": "burschikos",
    "burschikosare": "burschikos",
    "burschikosares": "burschikos",
    "burschikosas": "burschikos",
    "burschikosast": "burschikos",
    "burschikosaste": "burschikos",
    "burschikosastes": "burschikos",
    "burschikosasts": "burschikos",
    "burschikose": "burschikos",
    "burschikoses": "burschikos",
    "burschikost": "burschikos",
    "burschikosts": "burschikos",
    "burskapet": "burskap",
    "burskapets": "burskap",
    "burskaps": "burskap",
    "burspråken": "burspråk",
    "burspråkens": "burspråk",
    "burspråket": "burspråk",
    "burspråkets": "burspråk",
    "burspråks": "burspråk",
    "burundiern": "burundier",
    "burundierna": "burundier",
    "burundiernas": "burundier",
    "burundierns": "burundier",
    "burundiers": "burundier",
    "burundiska": "burundisk",
    "burundiskan": "burundiska",
    "burundiskans": "burundiska",
    "burundiskare": "burundisk",
    "burundiskares": "burundisk",
    "burundiskas": "burundiska",
    "burundiskast": "burundisk",
    "burundiskaste": "burundisk",
    "burundiskastes": "burundisk",
    "burundiskasts": "burundisk",
    "burundiske": "burundiska",
    "burundiskes": "burundisk",
    "burundiskor": "burundiska",
    "burundiskorna": "burundiska",
    "burundiskornas": "burundiska",
    "burundiskors": "burundiska",
    "burundisks": "burundisk",
    "burundiskt": "burundisk",
    "burundiskts": "burundisk",
    "bus": "buse",
    "busade": "busa",
    "busades": "busa",
    "busande": "busa",
    "busanden": "busande",
    "busandena": "busande",
    "busandenas": "busande",
    "busandens": "busande",
    "busandes": "busande",
    "busandet": "busande",
    "busandets": "busande",
    "busar": "buse",
    "busarna": "buse",
    "busarnas": "buse",
    "busars": "buse",
    "busas": "busa",
    "busat": "busa",
    "busats": "busa",
    "busen": "buse",
    "busens": "buse",
    "buses": "buse",
    "buset": "bus",
    "busets": "bus",
    "busfasonen": "busfason",
    "busfasonens": "busfason",
    "busfasoner": "busfason",
    "busfasonerna": "busfason",
    "busfasonernas": "busfason",
    "busfasoners": "busfason",
    "busfasons": "busfason",
    "busfröen": "busfrö",
    "busfröens": "busfrö",
    "busfröet": "busfrö",
    "busfröets": "busfrö",
    "busfrön": "busfrö",
    "busfröna": "busfrö",
    "busfrönas": "busfrö",
    "busfröns": "busfrö",
    "busfrös": "busfrö",
    "busfröt": "busfrö",
    "busfröts": "busfrö",
    "bushen": "bush",
    "bushens": "bush",
    "bushmannen": "bushman",
    "bushmannens": "bushman",
    "bushmans": "bushman",
    "bushmän": "bushman",
    "bushmännen": "bushman",
    "bushmännens": "bushman",
    "bushmäns": "bushman",
    "busiga": "busig",
    "busigare": "busig",
    "busigares": "busig",
    "busigas": "busig",
    "busigast": "busig",
    "busigaste": "busig",
    "busigastes": "busig",
    "busigasts": "busig",
    "busige": "busig",
    "busiges": "busig",
    "busigs": "busig",
    "busigt": "busig",
    "busigts": "busig",
    "businessar": "business",
    "businessarna": "business",
    "businessarnas": "business",
    "businessars": "business",
    "businessen": "business",
    "businessens": "business",
    "busk": "buske",
    "buskablyga": "buskablyg",
    "buskablygare": "buskablyg",
    "buskablygares": "buskablyg",
    "buskablygas": "buskablyg",
    "buskablygast": "buskablyg",
    "buskablygaste": "buskablyg",
    "buskablygastes": "buskablyg",
    "buskablygasts": "buskablyg",
    "buskablyge": "buskablyg",
    "buskablyges": "buskablyg",
    "buskablygheten": "buskablyghet",
    "buskablyghetens": "buskablyghet",
    "buskablyghets": "buskablyghet",
    "buskablygs": "buskablyg",
    "buskablygt": "buskablyg",
    "buskablygts": "buskablyg",
    "buskad": "buska",
    "buskade": "buska",
    "buskades": "buska",
    "buskads": "buska",
    "buskagen": "buskage",
    "buskagens": "buskage",
    "buskages": "buskage",
    "buskaget": "buskage",
    "buskagets": "buskage",
    "buskagitationen": "buskagitation",
    "buskagitationens": "buskagitation",
    "buskagitationer": "buskagitation",
    "buskagitationerna": "buskagitation",
    "buskagitationernas": "buskagitation",
    "buskagitationers": "buskagitation",
    "buskagitations": "buskagitation",
    "buskande": "buska",
    "buskanden": "buskande",
    "buskandena": "buskande",
    "buskandenas": "buskande",
    "buskandens": "buskande",
    "buskandes": "buskande",
    "buskandet": "buskande",
    "buskandets": "buskande",
    "buskar": "buske",
    "buskarna": "buske",
    "buskarnas": "buske",
    "buskars": "buske",
    "buskartade": "buskartad",
    "buskartades": "buskartad",
    "buskartads": "buskartad",
    "buskartat": "buskartad",
    "buskartats": "buskartad",
    "buskas": "buska",
    "buskat": "buska",
    "buskats": "buska",
    "busken": "buske",
    "buskens": "buske",
    "buskes": "buske",
    "buskiga": "buskig",
    "buskigare": "buskig",
    "buskigares": "buskig",
    "buskigas": "buskig",
    "buskigast": "buskig",
    "buskigaste": "buskig",
    "buskigastes": "buskig",
    "buskigasts": "buskig",
    "buskige": "buskig",
    "buskiges": "buskig",
    "buskigheten": "buskighet",
    "buskighetens": "buskighet",
    "buskighets": "buskighet",
    "buskigs": "buskig",
    "buskigt": "buskig",
    "buskigts": "buskig",
    "buskisen": "buskis",
    "buskisens": "buskis",
    "buskskvätt": "buskskvätta",
    "buskskvättan": "buskskvätta",
    "buskskvättans": "buskskvätta",
    "buskskvättas": "buskskvätta",
    "buskskvätte": "buskskvätta",
    "buskskvättor": "buskskvätta",
    "buskskvättorna": "buskskvätta",
    "buskskvättornas": "buskskvätta",
    "buskskvättors": "buskskvätta",
    "buskskvätts": "buskskvätta",
    "buskslyet": "busksly",
    "buskslyets": "busksly",
    "buskslyn": "busksly",
    "buskslyna": "busksly",
    "buskslynas": "busksly",
    "buskslyns": "busksly",
    "buskslys": "busksly",
    "buskslyt": "busksly",
    "buskslyts": "busksly",
    "buskteatern": "buskteater",
    "buskteaterns": "buskteater",
    "buskteaters": "buskteater",
    "buskörar": "buskörare",
    "busköraren": "buskörare",
    "buskörarens": "buskörare",
    "buskörares": "buskörare",
    "buskörarna": "buskörare",
    "buskörarnas": "buskörare",
    "buskörningar": "buskörning",
    "buskörningarna": "buskörning",
    "buskörningarnas": "buskörning",
    "buskörningars": "buskörning",
    "buskörningen": "buskörning",
    "buskörningens": "buskörning",
    "buskörnings": "buskörning",
    "buslivet": "busliv",
    "buslivets": "busliv",
    "buslivs": "busliv",
    "buss": "bussa",
    "bussad": "bussa",
    "bussade": "bussa",
    "bussades": "bussa",
    "bussads": "bussa",
    "bussande": "bussa",
    "bussanden": "bussande",
    "bussandena": "bussande",
    "bussandenas": "bussande",
    "bussandens": "bussande",
    "bussandes": "bussande",
    "bussandet": "bussande",
    "bussandets": "bussande",
    "bussankomsten": "bussankomst",
    "bussankomstens": "bussankomst",
    "bussankomster": "bussankomst",
    "bussankomsterna": "bussankomst",
    "bussankomsternas": "bussankomst",
    "bussankomsters": "bussankomst",
    "bussankomsts": "bussankomst",
    "bussar": "bussa",
    "bussarna": "buss",
    "bussarnas": "buss",
    "bussarongen": "bussarong",
    "bussarongens": "bussarong",
    "bussaronger": "bussarong",
    "bussarongerna": "bussarong",
    "bussarongernas": "bussarong",
    "bussarongers": "bussarong",
    "bussarongs": "bussarong",
    "bussars": "buss",
    "bussas": "bussa",
    "bussat": "bussa",
    "bussats": "bussa",
    "bussavgångar": "bussavgång",
    "bussavgångarna": "bussavgång",
    "bussavgångarnas": "bussavgång",
    "bussavgångars": "bussavgång",
    "bussavgången": "bussavgång",
    "bussavgångens": "bussavgång",
    "bussavgångs": "bussavgång",
    "busschauffören": "busschaufför",
    "busschaufförens": "busschaufför",
    "busschaufförer": "busschaufför",
    "busschaufförerna": "busschaufför",
    "busschaufförernas": "busschaufför",
    "busschaufförers": "busschaufför",
    "busschaufförn": "busschaufför",
    "busschaufförns": "busschaufför",
    "busschaufförs": "busschaufför",
    "bussen": "buss",
    "bussens": "buss",
    "bussförbindelsen": "bussförbindelse",
    "bussförbindelsens": "bussförbindelse",
    "bussförbindelser": "bussförbindelse",
    "bussförbindelserna": "bussförbindelse",
    "bussförbindelsernas": "bussförbindelse",
    "bussförbindelsers": "bussförbindelse",
    "bussförbindelses": "bussförbindelse",
    "busshållplatsen": "busshållplats",
    "busshållplatsens": "busshållplats",
    "busshållplatser": "busshållplats",
    "busshållplatserna": "busshållplats",
    "busshållplatsernas": "busshållplats",
    "busshållplatsers": "busshållplats",
    "bussiga": "bussig",
    "bussigare": "bussig",
    "bussigares": "bussig",
    "bussigas": "bussig",
    "bussigast": "bussig",
    "bussigaste": "bussig",
    "bussigastes": "bussig",
    "bussigasts": "bussig",
    "bussige": "bussig",
    "bussiges": "bussig",
    "bussigheten": "bussighet",
    "bussighetens": "bussighet",
    "bussighets": "bussighet",
    "bussigs": "bussig",
    "bussigt": "bussig",
    "bussigts": "bussig",
    "busskorten": "busskort",
    "busskortens": "busskort",
    "busskortet": "busskort",
    "busskortets": "busskort",
    "busskorts": "busskort",
    "busskrockar": "busskrock",
    "busskrockarna": "busskrock",
    "busskrockarnas": "busskrock",
    "busskrockars": "busskrock",
    "busskrocken": "busskrock",
    "busskrockens": "busskrock",
    "busskrocks": "busskrock",
    "busslasten": "busslast",
    "busslastens": "busslast",
    "busslaster": "busslast",
    "busslasterna": "busslast",
    "busslasternas": "busslast",
    "busslasters": "busslast",
    "busslasts": "busslast",
    "busslinjen": "busslinje",
    "busslinjens": "busslinje",
    "busslinjer": "busslinje",
    "busslinjerna": "busslinje",
    "busslinjernas": "busslinje",
    "busslinjers": "busslinje",
    "busslinjes": "busslinje",
    "bussningar": "bussning",
    "bussningarna": "bussning",
    "bussningarnas": "bussning",
    "bussningars": "bussning",
    "bussningen": "bussning",
    "bussningens": "bussning",
    "bussnings": "bussning",
    "busspassagerar": "busspassagerare",
    "busspassageraren": "busspassagerare",
    "busspassagerarens": "busspassagerare",
    "busspassagerares": "busspassagerare",
    "busspassagerarna": "busspassagerare",
    "busspassagerarnas": "busspassagerare",
    "bussresan": "bussresa",
    "bussresans": "bussresa",
    "bussresas": "bussresa",
    "bussrese": "bussresa",
    "bussresor": "bussresa",
    "bussresorna": "bussresa",
    "bussresornas": "bussresa",
    "bussresors": "bussresa",
    "busstationen": "busstation",
    "busstationens": "busstation",
    "busstationer": "busstation",
    "busstationerna": "busstation",
    "busstationernas": "busstation",
    "busstationers": "busstation",
    "busstations": "busstation",
    "bussterminalen": "bussterminal",
    "bussterminalens": "bussterminal",
    "bussterminaler": "bussterminal",
    "bussterminalerna": "bussterminal",
    "bussterminalernas": "bussterminal",
    "bussterminalers": "bussterminal",
    "bussterminals": "bussterminal",
    "busstidtabellen": "busstidtabell",
    "busstidtabellens": "busstidtabell",
    "busstidtabeller": "busstidtabell",
    "busstidtabellerna": "busstidtabell",
    "busstidtabellernas": "busstidtabell",
    "busstidtabellers": "busstidtabell",
    "busstidtabells": "busstidtabell",
    "busstrafiken": "busstrafik",
    "busstrafikens": "busstrafik",
    "busstrafiks": "busstrafik",
    "busstransporten": "busstransport",
    "busstransportens": "busstransport",
    "busstransporter": "busstransport",
    "busstransporterna": "busstransport",
    "busstransporternas": "busstransport",
    "busstransporters": "busstransport",
    "busstransports": "busstransport",
    "bussturen": "busstur",
    "bussturens": "busstur",
    "bussturer": "busstur",
    "bussturerna": "busstur",
    "bussturernas": "busstur",
    "bussturers": "busstur",
    "bussturs": "busstur",
    "busungar": "busunge",
    "busungarna": "busunge",
    "busungarnas": "busunge",
    "busungars": "busunge",
    "busungen": "busunge",
    "busungens": "busunge",
    "busunges": "busunge",
    "busvissel": "busvissla",
    "busvisslad": "busvissla",
    "busvisslade": "busvissla",
    "busvisslades": "busvissla",
    "busvisslads": "busvissla",
    "busvisslande": "busvissla",
    "busvisslanden": "busvisslande",
    "busvisslandena": "busvisslande",
    "busvisslandenas": "busvisslande",
    "busvisslandens": "busvisslande",
    "busvisslandes": "busvisslande",
    "busvisslandet": "busvisslande",
    "busvisslandets": "busvisslande",
    "busvisslar": "busvissla",
    "busvisslas": "busvissla",
    "busvisslat": "busvissla",
    "busvisslats": "busvissla",
    "busvisslingar": "busvissling",
    "busvisslingarna": "busvissling",
    "busvisslingarnas": "busvissling",
    "busvisslingars": "busvissling",
    "busvisslingen": "busvissling",
    "busvisslingens": "busvissling",
    "busvisslings": "busvissling",
    "busväderna": "busväder",
    "busvädernas": "busväder",
    "busväders": "busväder",
    "busvädren": "busväder",
    "busvädrens": "busväder",
    "busvädret": "busväder",
    "busvädrets": "busväder",
    "butadienet": "butadien",
    "butadienets": "butadien",
    "butadiens": "butadien",
    "butanen": "butan",
    "butanens": "butan",
    "butaner": "butan",
    "butanerna": "butan",
    "butanernas": "butan",
    "butaners": "butan",
    "butanet": "butan",
    "butanets": "butan",
    "butanolen": "butanol",
    "butanolens": "butanol",
    "butanols": "butanol",
    "butans": "butan",
    "buteljborst": "buteljborste",
    "buteljborstar": "buteljborste",
    "buteljborstarna": "buteljborste",
    "buteljborstarnas": "buteljborste",
    "buteljborstars": "buteljborste",
    "buteljborsten": "buteljborste",
    "buteljborstens": "buteljborste",
    "buteljborstes": "buteljborste",
    "buteljbottens": "buteljbotten",
    "buteljbottnar": "buteljbotten",
    "buteljbottnarna": "buteljbotten",
    "buteljbottnarnas": "buteljbotten",
    "buteljbottnars": "buteljbotten",
    "buteljbottnen": "buteljbotten",
    "buteljbottnens": "buteljbotten",
    "buteljen": "butelj",
    "buteljens": "butelj",
    "buteljer": "butelj",
    "buteljerad": "buteljera",
    "buteljerade": "buteljera",
    "buteljerades": "buteljera",
    "buteljerads": "buteljera",
    "buteljerande": "buteljera",
    "buteljeranden": "buteljerande",
    "buteljerandena": "buteljerande",
    "buteljerandenas": "buteljerande",
    "buteljerandens": "buteljerande",
    "buteljerandes": "buteljerande",
    "buteljerandet": "buteljerande",
    "buteljerandets": "buteljerande",
    "buteljerar": "buteljera",
    "buteljeras": "buteljera",
    "buteljerat": "buteljera",
    "buteljerats": "buteljera",
    "buteljerbara": "buteljerbar",
    "buteljerbarare": "buteljerbar",
    "buteljerbarares": "buteljerbar",
    "buteljerbaras": "buteljerbar",
    "buteljerbarast": "buteljerbar",
    "buteljerbaraste": "buteljerbar",
    "buteljerbarastes": "buteljerbar",
    "buteljerbarasts": "buteljerbar",
    "buteljerbare": "buteljerbar",
    "buteljerbares": "buteljerbar",
    "buteljerbarheten": "buteljerbarhet",
    "buteljerbarhetens": "buteljerbarhet",
    "buteljerbarhets": "buteljerbarhet",
    "buteljerbars": "buteljerbar",
    "buteljerbart": "buteljerbar",
    "buteljerbarts": "buteljerbar",
    "buteljeringar": "buteljering",
    "buteljeringarna": "buteljering",
    "buteljeringarnas": "buteljering",
    "buteljeringars": "buteljering",
    "buteljeringen": "buteljering",
    "buteljeringens": "buteljering",
    "buteljerings": "buteljering",
    "buteljerna": "butelj",
    "buteljernas": "butelj",
    "buteljers": "butelj",
    "buteljglaset": "buteljglas",
    "buteljglasets": "buteljglas",
    "buteljgröna": "buteljgrön",
    "buteljgrönare": "buteljgrön",
    "buteljgrönares": "buteljgrön",
    "buteljgrönas": "buteljgrön",
    "buteljgrönast": "buteljgrön",
    "buteljgrönaste": "buteljgrön",
    "buteljgrönastes": "buteljgrön",
    "buteljgrönasts": "buteljgrön",
    "buteljgröne": "buteljgrön",
    "buteljgrönes": "buteljgrön",
    "buteljgröns": "buteljgrön",
    "buteljgrönt": "buteljgrön",
    "buteljgrönts": "buteljgrön",
    "buteljlacket": "buteljlack",
    "buteljlackets": "buteljlack",
    "buteljlacks": "buteljlack",
    "buteljs": "butelj",
    "butiken": "butik",
    "butikens": "butik",
    "butiker": "butik",
    "butikerna": "butik",
    "butikernas": "butik",
    "butikers": "butik",
    "butiks": "butik",
    "butiksanställde": "butiksanställd",
    "butiksanställdes": "butiksanställd",
    "butiksanställds": "butiksanställd",
    "butiksanställt": "butiksanställd",
    "butiksanställts": "butiksanställd",
    "butiksbiträden": "butiksbiträde",
    "butiksbiträdena": "butiksbiträde",
    "butiksbiträdenas": "butiksbiträde",
    "butiksbiträdens": "butiksbiträde",
    "butiksbiträdes": "butiksbiträde",
    "butiksbiträdet": "butiksbiträde",
    "butiksbiträdets": "butiksbiträde",
    "butiksdörrar": "butiksdörr",
    "butiksdörrarna": "butiksdörr",
    "butiksdörrarnas": "butiksdörr",
    "butiksdörrars": "butiksdörr",
    "butiksdörren": "butiksdörr",
    "butiksdörrens": "butiksdörr",
    "butiksdörrs": "butiksdörr",
    "butiksinnehavar": "butiksinnehavare",
    "butiksinnehavaren": "butiksinnehavare",
    "butiksinnehavarens": "butiksinnehavare",
    "butiksinnehavares": "butiksinnehavare",
    "butiksinnehavarna": "butiksinnehavare",
    "butiksinnehavarnas": "butiksinnehavare",
    "butikskedjan": "butikskedja",
    "butikskedjans": "butikskedja",
    "butikskedjas": "butikskedja",
    "butikskedje": "butikskedja",
    "butikskedjor": "butikskedja",
    "butikskedjorna": "butikskedja",
    "butikskedjornas": "butikskedja",
    "butikskedjors": "butikskedja",
    "butiksrånen": "butiksrån",
    "butiksrånens": "butiksrån",
    "butiksrånet": "butiksrån",
    "butiksrånets": "butiksrån",
    "butiksråns": "butiksrån",
    "butiksstängningslagar": "butiksstängningslag",
    "butiksstängningslagarna": "butiksstängningslag",
    "butiksstängningslagarnas": "butiksstängningslag",
    "butiksstängningslagars": "butiksstängningslag",
    "butiksstängningslagen": "butiksstängningslag",
    "butiksstängningslagens": "butiksstängningslag",
    "butiksstängningslags": "butiksstängningslag",
    "butikstjuvar": "butikstjuv",
    "butikstjuvarna": "butikstjuv",
    "butikstjuvarnas": "butikstjuv",
    "butikstjuvars": "butikstjuv",
    "butikstjuven": "butikstjuv",
    "butikstjuvens": "butikstjuv",
    "butikstjuvs": "butikstjuv",
    "butlern": "butler",
    "butlerns": "butler",
    "butlers": "butler",
    "butlersarna": "butler",
    "butlersarnas": "butler",
    "butlersen": "butler",
    "butlersens": "butler",
    "butterheten": "butterhet",
    "butterhetens": "butterhet",
    "butterhets": "butterhet",
    "butterkak": "butterkaka",
    "butterkakan": "butterkaka",
    "butterkakans": "butterkaka",
    "butterkakas": "butterkaka",
    "butterkake": "butterkaka",
    "butterkakor": "butterkaka",
    "butterkakorna": "butterkaka",
    "butterkakornas": "butterkaka",
    "butterkakors": "butterkaka",
    "butterkaks": "butterkaka",
    "butters": "butter",
    "buttert": "butter",
    "butterts": "butter",
    "buttra": "butter",
    "buttrare": "butter",
    "buttrares": "butter",
    "buttras": "butter",
    "buttrast": "butter",
    "buttraste": "butter",
    "buttrastes": "butter",
    "buttrasts": "butter",
    "buttre": "butter",
    "buttres": "butter",
    "butylalkoholen": "butylalkohol",
    "butylalkoholens": "butylalkohol",
    "butylalkohols": "butylalkohol",
    "butylen": "butyl",
    "butylens": "butyl",
    "butyler": "butyl",
    "butylerna": "butyl",
    "butylernas": "butyl",
    "butylers": "butyl",
    "butylet": "butyl",
    "butylets": "butyl",
    "butyls": "butyl",
    "buxbomar": "buxbom",
    "buxbomarna": "buxbom",
    "buxbomarnas": "buxbom",
    "buxbomars": "buxbom",
    "buxbomen": "buxbom",
    "buxbomens": "buxbom",
    "buxboms": "buxbom",
    "byalagen": "byalag",
    "byalagens": "byalag",
    "byalaget": "byalag",
    "byalagets": "byalag",
    "byalags": "byalag",
    "byamålen": "byamål",
    "byamålens": "byamål",
    "byamålet": "byamål",
    "byamålets": "byamål",
    "byamåls": "byamål",
    "byar": "by",
    "byarna": "by",
    "byarnas": "by",
    "byars": "by",
    "byfféer": "byffé",
    "byfféerna": "byffé",
    "byfféernas": "byffé",
    "byfféers": "byffé",
    "byffén": "byffé",
    "byfféns": "byffé",
    "byffés": "byffé",
    "byfogd": "byfogde",
    "byfogdar": "byfogde",
    "byfogdarna": "byfogde",
    "byfogdarnas": "byfogde",
    "byfogdars": "byfogde",
    "byfogden": "byfogde",
    "byfogdens": "byfogde",
    "byfogdes": "byfogde",
    "byfogds": "byfogde",
    "byfånar": "byfåne",
    "byfånarna": "byfåne",
    "byfånarnas": "byfåne",
    "byfånars": "byfåne",
    "byfånen": "byfåne",
    "byfånens": "byfåne",
    "byfånes": "byfåne",
    "bygat": "bygata",
    "bygatan": "bygata",
    "bygatans": "bygata",
    "bygatas": "bygata",
    "bygate": "bygata",
    "bygator": "bygata",
    "bygatorna": "bygata",
    "bygatornas": "bygata",
    "bygators": "bygata",
    "bygats": "bygata",
    "bygde": "bygd",
    "bygdeborgar": "bygdeborg",
    "bygdeborgarna": "bygdeborg",
    "bygdeborgarnas": "bygdeborg",
    "bygdeborgars": "bygdeborg",
    "bygdeborgen": "bygdeborg",
    "bygdeborgens": "bygdeborg",
    "bygdeborgs": "bygdeborg",
    "bygdegårdar": "bygdegård",
    "bygdegårdarna": "bygdegård",
    "bygdegårdarnas": "bygdegård",
    "bygdegårdars": "bygdegård",
    "bygdegården": "bygdegård",
    "bygdegårdens": "bygdegård",
    "bygdegårds": "bygdegård",
    "bygdemålen": "bygdemål",
    "bygdemålens": "bygdemål",
    "bygdemålet": "bygdemål",
    "bygdemålets": "bygdemål",
    "bygdemåls": "bygdemål",
    "bygden": "bygd",
    "bygdens": "bygd",
    "bygder": "bygd",
    "bygderna": "bygd",
    "bygdernas": "bygd",
    "bygders": "bygd",
    "bygds": "bygd",
    "bygelhornen": "bygelhorn",
    "bygelhornens": "bygelhorn",
    "bygelhornet": "bygelhorn",
    "bygelhornets": "bygelhorn",
    "bygelhorns": "bygelhorn",
    "bygelhästar": "bygelhäst",
    "bygelhästarna": "bygelhäst",
    "bygelhästarnas": "bygelhäst",
    "bygelhästars": "bygelhäst",
    "bygelhästen": "bygelhäst",
    "bygelhästens": "bygelhäst",
    "bygelhästs": "bygelhäst",
    "bygellåsen": "bygellås",
    "bygellåsens": "bygellås",
    "bygellåset": "bygellås",
    "bygellåsets": "bygellås",
    "bygeln": "bygel",
    "bygelns": "bygel",
    "bygels": "bygel",
    "bygg": "bygga",
    "byggande": "bygga",
    "byggandes": "byggande",
    "byggandet": "byggande",
    "byggandets": "byggande",
    "byggar": "byggare",
    "byggarbetar": "byggarbetare",
    "byggarbetaren": "byggarbetare",
    "byggarbetarens": "byggarbetare",
    "byggarbetares": "byggarbetare",
    "byggarbetarna": "byggarbetare",
    "byggarbetarnas": "byggarbetare",
    "byggarbetskranar": "byggarbetskran",
    "byggarbetskranarna": "byggarbetskran",
    "byggarbetskranarnas": "byggarbetskran",
    "byggarbetskranars": "byggarbetskran",
    "byggarbetskranen": "byggarbetskran",
    "byggarbetskranens": "byggarbetskran",
    "byggarbetskrans": "byggarbetskran",
    "byggarbetsplatsen": "byggarbetsplats",
    "byggarbetsplatsens": "byggarbetsplats",
    "byggarbetsplatser": "byggarbetsplats",
    "byggarbetsplatserna": "byggarbetsplats",
    "byggarbetsplatsernas": "byggarbetsplats",
    "byggarbetsplatsers": "byggarbetsplats",
    "byggaren": "byggare",
    "byggarens": "byggare",
    "byggares": "byggare",
    "byggarna": "byggare",
    "byggarnas": "byggare",
    "byggas": "bygga",
    "byggbeslagen": "byggbeslag",
    "byggbeslagens": "byggbeslag",
    "byggbeslaget": "byggbeslag",
    "byggbeslagets": "byggbeslag",
    "byggbeslags": "byggbeslag",
    "byggd": "bygga",
    "byggda": "bygga",
    "byggdammet": "byggdamm",
    "byggdammets": "byggdamm",
    "byggdamms": "byggdamm",
    "byggdas": "bygga",
    "byggde": "bygga",
    "byggdes": "bygga",
    "byggds": "bygga",
    "byggelementen": "byggelement",
    "byggelementens": "byggelement",
    "byggelementet": "byggelement",
    "byggelementets": "byggelement",
    "byggelements": "byggelement",
    "byggen": "bygge",
    "byggena": "bygge",
    "byggenas": "bygge",
    "byggens": "bygge",
    "byggenskapen": "byggenskap",
    "byggenskapens": "byggenskap",
    "byggenskaps": "byggenskap",
    "bygger": "bygga",
    "bygges": "bygge",
    "bygget": "bygge",
    "byggets": "bygge",
    "byggföretagen": "byggföretag",
    "byggföretagens": "byggföretag",
    "byggföretaget": "byggföretag",
    "byggföretagets": "byggföretag",
    "byggföretags": "byggföretag",
    "byggherrar": "byggherre",
    "byggherrarna": "byggherre",
    "byggherrarnas": "byggherre",
    "byggherrars": "byggherre",
    "byggherren": "byggherre",
    "byggherrens": "byggherre",
    "byggherres": "byggherre",
    "byggklossar": "byggkloss",
    "byggklossarna": "byggkloss",
    "byggklossarnas": "byggkloss",
    "byggklossars": "byggkloss",
    "byggklossen": "byggkloss",
    "byggklossens": "byggkloss",
    "byggkostnaden": "byggkostnad",
    "byggkostnadens": "byggkostnad",
    "byggkostnader": "byggkostnad",
    "byggkostnaderna": "byggkostnad",
    "byggkostnadernas": "byggkostnad",
    "byggkostnaders": "byggkostnad",
    "byggkostnads": "byggkostnad",
    "bygglagar": "bygglag",
    "bygglagarna": "bygglag",
    "bygglagarnas": "bygglag",
    "bygglagars": "bygglag",
    "bygglagen": "bygglag",
    "bygglagens": "bygglag",
    "bygglags": "bygglag",
    "bygglekplatsen": "bygglekplats",
    "bygglekplatsens": "bygglekplats",
    "bygglekplatser": "bygglekplats",
    "bygglekplatserna": "bygglekplats",
    "bygglekplatsernas": "bygglekplats",
    "bygglekplatsers": "bygglekplats",
    "byggloven": "bygglov",
    "bygglovens": "bygglov",
    "bygglovet": "bygglov",
    "bygglovets": "bygglov",
    "bygglovs": "bygglov",
    "bygglåd": "bygglåda",
    "bygglådan": "bygglåda",
    "bygglådans": "bygglåda",
    "bygglådas": "bygglåda",
    "bygglåde": "bygglåda",
    "bygglådor": "bygglåda",
    "bygglådorna": "bygglåda",
    "bygglådornas": "bygglåda",
    "bygglådors": "bygglåda",
    "bygglåds": "bygglåda",
    "byggmaterialen": "byggmaterial",
    "byggmaterialens": "byggmaterial",
    "byggmaterialet": "byggmaterial",
    "byggmaterialets": "byggmaterial",
    "byggmaterials": "byggmaterial",
    "byggmästar": "byggmästare",
    "byggmästardottern": "byggmästardotter",
    "byggmästardotterns": "byggmästardotter",
    "byggmästardotters": "byggmästardotter",
    "byggmästardöttrar": "byggmästardotter",
    "byggmästardöttrarna": "byggmästardotter",
    "byggmästardöttrarnas": "byggmästardotter",
    "byggmästardöttrars": "byggmästardotter",
    "byggmästaren": "byggmästare",
    "byggmästarens": "byggmästare",
    "byggmästares": "byggmästare",
    "byggmästarna": "byggmästare",
    "byggmästarnas": "byggmästare",
    "byggnaden": "byggnad",
    "byggnadens": "byggnad",
    "byggnader": "byggnad",
    "byggnaderna": "byggnad",
    "byggnadernas": "byggnad",
    "byggnaders": "byggnad",
    "byggnads": "byggnad",
    "byggnadsarbetar": "byggnadsarbetare",
    "byggnadsarbetaren": "byggnadsarbetare",
    "byggnadsarbetarens": "byggnadsarbetare",
    "byggnadsarbetares": "byggnadsarbetare",
    "byggnadsarbetarna": "byggnadsarbetare",
    "byggnadsarbetarnas": "byggnadsarbetare",
    "byggnadsindustrien": "byggnadsindustri",
    "byggnadsindustriens": "byggnadsindustri",
    "byggnadsindustrier": "byggnadsindustri",
    "byggnadsindustrierna": "byggnadsindustri",
    "byggnadsindustriernas": "byggnadsindustri",
    "byggnadsindustriers": "byggnadsindustri",
    "byggnadsindustrin": "byggnadsindustri",
    "byggnadsindustrins": "byggnadsindustri",
    "byggnadsindustris": "byggnadsindustri",
    "byggnadskonsten": "byggnadskonst",
    "byggnadskonstens": "byggnadskonst",
    "byggnadskonstruktionen": "byggnadskonstruktion",
    "byggnadskonstruktionens": "byggnadskonstruktion",
    "byggnadskonstruktioner": "byggnadskonstruktion",
    "byggnadskonstruktionerna": "byggnadskonstruktion",
    "byggnadskonstruktionernas": "byggnadskonstruktion",
    "byggnadskonstruktioners": "byggnadskonstruktion",
    "byggnadskonstruktions": "byggnadskonstruktion",
    "byggnadskonsts": "byggnadskonst",
    "byggnadskontoren": "byggnadskontor",
    "byggnadskontorens": "byggnadskontor",
    "byggnadskontoret": "byggnadskontor",
    "byggnadskontorets": "byggnadskontor",
    "byggnadskontors": "byggnadskontor",
    "byggnadskrediten": "byggnadskredit",
    "byggnadskreditens": "byggnadskredit",
    "byggnadskrediter": "byggnadskredit",
    "byggnadskrediterna": "byggnadskredit",
    "byggnadskrediternas": "byggnadskredit",
    "byggnadskrediters": "byggnadskredit",
    "byggnadskreditiven": "byggnadskreditiv",
    "byggnadskreditivens": "byggnadskreditiv",
    "byggnadskreditivet": "byggnadskreditiv",
    "byggnadskreditivets": "byggnadskreditiv",
    "byggnadskreditivs": "byggnadskreditiv",
    "byggnadskredits": "byggnadskredit",
    "byggnadsloven": "byggnadslov",
    "byggnadslovens": "byggnadslov",
    "byggnadslovet": "byggnadslov",
    "byggnadslovets": "byggnadslov",
    "byggnadslovs": "byggnadslov",
    "byggnadslånen": "byggnadslån",
    "byggnadslånens": "byggnadslån",
    "byggnadslånet": "byggnadslån",
    "byggnadslånets": "byggnadslån",
    "byggnadslåns": "byggnadslån",
    "byggnadsmaterialen": "byggnadsmaterial",
    "byggnadsmaterialens": "byggnadsmaterial",
    "byggnadsmaterialet": "byggnadsmaterial",
    "byggnadsmaterialets": "byggnadsmaterial",
    "byggnadsmaterials": "byggnadsmaterial",
    "byggnadsminnen": "byggnadsminne",
    "byggnadsminnena": "byggnadsminne",
    "byggnadsminnenas": "byggnadsminne",
    "byggnadsminnens": "byggnadsminne",
    "byggnadsminnes": "byggnadsminne",
    "byggnadsminnet": "byggnadsminne",
    "byggnadsminnets": "byggnadsminne",
    "byggnadsmässiga": "byggnadsmässig",
    "byggnadsmässigare": "byggnadsmässig",
    "byggnadsmässigares": "byggnadsmässig",
    "byggnadsmässigas": "byggnadsmässig",
    "byggnadsmässigast": "byggnadsmässig",
    "byggnadsmässigaste": "byggnadsmässig",
    "byggnadsmässigastes": "byggnadsmässig",
    "byggnadsmässigasts": "byggnadsmässig",
    "byggnadsmässige": "byggnadsmässig",
    "byggnadsmässiges": "byggnadsmässig",
    "byggnadsmässigs": "byggnadsmässig",
    "byggnadsmässigt": "byggnadsmässig",
    "byggnadsmässigts": "byggnadsmässig",
    "byggnadsnämnden": "byggnadsnämnd",
    "byggnadsnämndens": "byggnadsnämnd",
    "byggnadsnämnder": "byggnadsnämnd",
    "byggnadsnämnderna": "byggnadsnämnd",
    "byggnadsnämndernas": "byggnadsnämnd",
    "byggnadsnämnders": "byggnadsnämnd",
    "byggnadsnämnds": "byggnadsnämnd",
    "byggnadsplane": "byggnadsplan",
    "byggnadsplanen": "byggnadsplan",
    "byggnadsplanens": "byggnadsplan",
    "byggnadsplaner": "byggnadsplan",
    "byggnadsplanerna": "byggnadsplan",
    "byggnadsplanernas": "byggnadsplan",
    "byggnadsplaners": "byggnadsplan",
    "byggnadsplans": "byggnadsplan",
    "byggnadssnickar": "byggnadssnickare",
    "byggnadssnickaren": "byggnadssnickare",
    "byggnadssnickarens": "byggnadssnickare",
    "byggnadssnickares": "byggnadssnickare",
    "byggnadssnickarna": "byggnadssnickare",
    "byggnadssnickarnas": "byggnadssnickare",
    "byggnadsstenar": "byggnadssten",
    "byggnadsstenarna": "byggnadssten",
    "byggnadsstenarnas": "byggnadssten",
    "byggnadsstenars": "byggnadssten",
    "byggnadsstenen": "byggnadssten",
    "byggnadsstenens": "byggnadssten",
    "byggnadsstens": "byggnadssten",
    "byggnadsstilar": "byggnadsstil",
    "byggnadsstilarna": "byggnadsstil",
    "byggnadsstilarnas": "byggnadsstil",
    "byggnadsstilars": "byggnadsstil",
    "byggnadsstilen": "byggnadsstil",
    "byggnadsstilens": "byggnadsstil",
    "byggnadsstils": "byggnadsstil",
    "byggnadsstommar": "byggnadsstomme",
    "byggnadsstommarna": "byggnadsstomme",
    "byggnadsstommarnas": "byggnadsstomme",
    "byggnadsstommars": "byggnadsstomme",
    "byggnadsstommen": "byggnadsstomme",
    "byggnadsstommens": "byggnadsstomme",
    "byggnadsstommes": "byggnadsstomme",
    "byggnadsstyrelsen": "byggnadsstyrelse",
    "byggnadsstyrelsens": "byggnadsstyrelse",
    "byggnadsstyrelser": "byggnadsstyrelse",
    "byggnadsstyrelserna": "byggnadsstyrelse",
    "byggnadsstyrelsernas": "byggnadsstyrelse",
    "byggnadsstyrelsers": "byggnadsstyrelse",
    "byggnadsstyrelses": "byggnadsstyrelse",
    "byggnadsställningar": "byggnadsställning",
    "byggnadsställningarna": "byggnadsställning",
    "byggnadsställningarnas": "byggnadsställning",
    "byggnadsställningars": "byggnadsställning",
    "byggnadsställningen": "byggnadsställning",
    "byggnadsställningens": "byggnadsställning",
    "byggnadsställnings": "byggnadsställning",
    "byggnadstillstånden": "byggnadstillstånd",
    "byggnadstillståndens": "byggnadstillstånd",
    "byggnadstillståndet": "byggnadstillstånd",
    "byggnadstillståndets": "byggnadstillstånd",
    "byggnadstillstånds": "byggnadstillstånd",
    "byggnadsverken": "byggnadsverk",
    "byggnadsverkens": "byggnadsverk",
    "byggnadsverket": "byggnadsverk",
    "byggnadsverkets": "byggnadsverk",
    "byggnadsverks": "byggnadsverk",
    "byggnationen": "byggnation",
    "byggnationens": "byggnation",
    "byggnationer": "byggnation",
    "byggnationerna": "byggnation",
    "byggnationernas": "byggnation",
    "byggnationers": "byggnation",
    "byggnations": "byggnation",
    "byggningar": "byggning",
    "byggningarna": "byggning",
    "byggningarnas": "byggning",
    "byggningars": "byggning",
    "byggningen": "byggning",
    "byggningens": "byggning",
    "byggnings": "byggning",
    "byggnormen": "byggnorm",
    "byggnormens": "byggnorm",
    "byggnormer": "byggnorm",
    "byggnormerna": "byggnorm",
    "byggnormernas": "byggnorm",
    "byggnormers": "byggnorm",
    "byggnorms": "byggnorm",
    "byggpassen": "byggpass",
    "byggpassens": "byggpass",
    "byggpasset": "byggpass",
    "byggpassets": "byggpass",
    "byggs": "bygga",
    "byggsatsen": "byggsats",
    "byggsatsens": "byggsats",
    "byggsatser": "byggsats",
    "byggsatserna": "byggsats",
    "byggsatsernas": "byggsats",
    "byggsatsers": "byggsats",
    "byggstarten": "byggstart",
    "byggstartens": "byggstart",
    "byggstarter": "byggstart",
    "byggstarterna": "byggstart",
    "byggstarternas": "byggstart",
    "byggstarters": "byggstart",
    "byggstarts": "byggstart",
    "byggstenar": "byggsten",
    "byggstenarna": "byggsten",
    "byggstenarnas": "byggsten",
    "byggstenars": "byggsten",
    "byggstenen": "byggsten",
    "byggstenens": "byggsten",
    "byggstens": "byggsten",
    "byggstoppen": "byggstopp",
    "byggstoppens": "byggstopp",
    "byggstoppet": "byggstopp",
    "byggstoppets": "byggstopp",
    "byggstopps": "byggstopp",
    "byggställningar": "byggställning",
    "byggställningarna": "byggställning",
    "byggställningarnas": "byggställning",
    "byggställningars": "byggställning",
    "byggställningen": "byggställning",
    "byggställningens": "byggställning",
    "byggställnings": "byggställning",
    "byggt": "bygga",
    "byggtorkar": "byggtork",
    "byggtorkarna": "byggtork",
    "byggtorkarnas": "byggtork",
    "byggtorkars": "byggtork",
    "byggtorken": "byggtork",
    "byggtorkens": "byggtork",
    "byggtorks": "byggtork",
    "byggts": "bygga",
    "byglar": "bygel",
    "byglarna": "bygel",
    "byglarnas": "bygel",
    "byglars": "bygel",
    "byhusen": "byhus",
    "byhusens": "byhus",
    "byhuset": "byhus",
    "byhusets": "byhus",
    "byiga": "byig",
    "byigare": "byig",
    "byigares": "byig",
    "byigas": "byig",
    "byigast": "byig",
    "byigaste": "byig",
    "byigastes": "byig",
    "byigasts": "byig",
    "byige": "byig",
    "byiges": "byig",
    "byigs": "byig",
    "byigt": "byig",
    "byigts": "byig",
    "byk": "byka",
    "bykande": "byka",
    "bykanden": "bykande",
    "bykandena": "bykande",
    "bykandenas": "bykande",
    "bykandens": "bykande",
    "bykandes": "bykande",
    "bykandet": "bykande",
    "bykandets": "bykande",
    "bykar": "byk",
    "bykarna": "byk",
    "bykarnas": "byk",
    "bykars": "byk",
    "bykas": "byka",
    "byken": "byk",
    "bykens": "byk",
    "byker": "byka",
    "bykes": "byke",
    "byket": "byke",
    "bykets": "byke",
    "bykgryt": "bykgryta",
    "bykgrytan": "bykgryta",
    "bykgrytans": "bykgryta",
    "bykgrytas": "bykgryta",
    "bykgryte": "bykgryta",
    "bykgrytor": "bykgryta",
    "bykgrytorna": "bykgryta",
    "bykgrytornas": "bykgryta",
    "bykgrytors": "bykgryta",
    "bykgryts": "bykgryta",
    "byks": "byka",
    "bykt": "byka",
    "bykte": "byka",
    "byktes": "byka",
    "bykts": "byka",
    "bylingar": "byling",
    "bylingarna": "byling",
    "bylingarnas": "byling",
    "bylingars": "byling",
    "bylingen": "byling",
    "bylingens": "byling",
    "bylings": "byling",
    "bylsiga": "bylsig",
    "bylsigare": "bylsig",
    "bylsigares": "bylsig",
    "bylsigas": "bylsig",
    "bylsigast": "bylsig",
    "bylsigaste": "bylsig",
    "bylsigastes": "bylsig",
    "bylsigasts": "bylsig",
    "bylsige": "bylsig",
    "bylsiges": "bylsig",
    "bylsigheten": "bylsighet",
    "bylsighetens": "bylsighet",
    "bylsighets": "bylsighet",
    "bylsigs": "bylsig",
    "bylsigt": "bylsig",
    "bylsigts": "bylsig",
    "bylten": "bylte",
    "byltena": "bylte",
    "byltenas": "bylte",
    "byltens": "bylte",
    "byltes": "bylte",
    "byltet": "bylte",
    "byltets": "bylte",
    "bylts": "bylte",
    "bymolnen": "bymoln",
    "bymolnens": "bymoln",
    "bymolnet": "bymoln",
    "bymolnets": "bymoln",
    "bymolns": "bymoln",
    "bymoskéer": "bymoské",
    "bymoskéerna": "bymoské",
    "bymoskéernas": "bymoské",
    "bymoskéers": "bymoské",
    "bymoskén": "bymoské",
    "bymoskéns": "bymoské",
    "bymoskés": "bymoské",
    "byn": "by",
    "byns": "by",
    "byområden": "byområde",
    "byområdena": "byområde",
    "byområdenas": "byområde",
    "byområdens": "byområde",
    "byområdes": "byområde",
    "byområdet": "byområde",
    "byområdets": "byområde",
    "byordningar": "byordning",
    "byordningarna": "byordning",
    "byordningarnas": "byordning",
    "byordningars": "byordning",
    "byordningen": "byordning",
    "byordningens": "byordning",
    "byordnings": "byordning",
    "byrack": "byracka",
    "byrackan": "byracka",
    "byrackans": "byracka",
    "byrackas": "byracka",
    "byracke": "byracka",
    "byrackor": "byracka",
    "byrackorna": "byracka",
    "byrackornas": "byracka",
    "byrackors": "byracka",
    "byracks": "byracka",
    "byretten": "byrett",
    "byrettens": "byrett",
    "byretter": "byrett",
    "byretterna": "byrett",
    "byretternas": "byrett",
    "byretters": "byrett",
    "byretts": "byrett",
    "byråar": "byrå",
    "byråarna": "byrå",
    "byråarnas": "byrå",
    "byråars": "byrå",
    "byråassistenten": "byråassistent",
    "byråassistentens": "byråassistent",
    "byråassistenter": "byråassistent",
    "byråassistenterna": "byråassistent",
    "byråassistenternas": "byråassistent",
    "byråassistenters": "byråassistent",
    "byråassistents": "byråassistent",
    "byråchefen": "byråchef",
    "byråchefens": "byråchef",
    "byråchefer": "byråchef",
    "byråcheferna": "byråchef",
    "byråchefernas": "byråchef",
    "byråchefers": "byråchef",
    "byråchefs": "byråchef",
    "byrådirektören": "byrådirektör",
    "byrådirektörens": "byrådirektör",
    "byrådirektörer": "byrådirektör",
    "byrådirektörerna": "byrådirektör",
    "byrådirektörernas": "byrådirektör",
    "byrådirektörers": "byrådirektör",
    "byrådirektörn": "byrådirektör",
    "byrådirektörns": "byrådirektör",
    "byrådirektörs": "byrådirektör",
    "byråer": "byrå",
    "byråerna": "byrå",
    "byråernas": "byrå",
    "byråers": "byrå",
    "byråkraten": "byråkrat",
    "byråkratens": "byråkrat",
    "byråkrater": "byråkrat",
    "byråkraterna": "byråkrat",
    "byråkraternas": "byråkrat",
    "byråkraters": "byråkrat",
    "byråkratien": "byråkrati",
    "byråkratiens": "byråkrati",
    "byråkratier": "byråkrati",
    "byråkratierna": "byråkrati",
    "byråkratiernas": "byråkrati",
    "byråkratiers": "byråkrati",
    "byråkratin": "byråkrati",
    "byråkratins": "byråkrati",
    "byråkratis": "byråkrati",
    "byråkratiserad": "byråkratisera",
    "byråkratiserade": "byråkratisera",
    "byråkratiserades": "byråkratisera",
    "byråkratiserads": "byråkratisera",
    "byråkratiserande": "byråkratisera",
    "byråkratiseranden": "byråkratiserande",
    "byråkratiserandena": "byråkratiserande",
    "byråkratiserandenas": "byråkratiserande",
    "byråkratiserandens": "byråkratiserande",
    "byråkratiserandes": "byråkratiserande",
    "byråkratiserandet": "byråkratiserande",
    "byråkratiserandets": "byråkratiserande",
    "byråkratiserar": "byråkratisera",
    "byråkratiseras": "byråkratisera",
    "byråkratiserat": "byråkratisera",
    "byråkratiserats": "byråkratisera",
    "byråkratiserbara": "byråkratiserbar",
    "byråkratiserbarare": "byråkratiserbar",
    "byråkratiserbarares": "byråkratiserbar",
    "byråkratiserbaras": "byråkratiserbar",
    "byråkratiserbarast": "byråkratiserbar",
    "byråkratiserbaraste": "byråkratiserbar",
    "byråkratiserbarastes": "byråkratiserbar",
    "byråkratiserbarasts": "byråkratiserbar",
    "byråkratiserbare": "byråkratiserbar",
    "byråkratiserbares": "byråkratiserbar",
    "byråkratiserbarheten": "byråkratiserbarhet",
    "byråkratiserbarhetens": "byråkratiserbarhet",
    "byråkratiserbarhets": "byråkratiserbarhet",
    "byråkratiserbars": "byråkratiserbar",
    "byråkratiserbart": "byråkratiserbar",
    "byråkratiserbarts": "byråkratiserbar",
    "byråkratiseringar": "byråkratisering",
    "byråkratiseringarna": "byråkratisering",
    "byråkratiseringarnas": "byråkratisering",
    "byråkratiseringars": "byråkratisering",
    "byråkratiseringen": "byråkratisering",
    "byråkratiseringens": "byråkratisering",
    "byråkratiserings": "byråkratisering",
    "byråkratiska": "byråkratisk",
    "byråkratiskare": "byråkratisk",
    "byråkratiskares": "byråkratisk",
    "byråkratiskas": "byråkratisk",
    "byråkratiskast": "byråkratisk",
    "byråkratiskaste": "byråkratisk",
    "byråkratiskastes": "byråkratisk",
    "byråkratiskasts": "byråkratisk",
    "byråkratiske": "byråkratisk",
    "byråkratiskes": "byråkratisk",
    "byråkratisks": "byråkratisk",
    "byråkratiskt": "byråkratisk",
    "byråkratiskts": "byråkratisk",
    "byråkratismen": "byråkratism",
    "byråkratismens": "byråkratism",
    "byråkratismer": "byråkratism",
    "byråkratismerna": "byråkratism",
    "byråkratismernas": "byråkratism",
    "byråkratismers": "byråkratism",
    "byråkratisms": "byråkratism",
    "byråkrats": "byråkrat",
    "byrån": "byrå",
    "byråns": "byrå",
    "byrås": "byrå",
    "byråsekreterar": "byråsekreterare",
    "byråsekreteraren": "byråsekreterare",
    "byråsekreterarens": "byråsekreterare",
    "byråsekreterares": "byråsekreterare",
    "byråsekreterarna": "byråsekreterare",
    "byråsekreterarnas": "byråsekreterare",
    "bys": "by",
    "bysamfälligheten": "bysamfällighet",
    "bysamfällighetens": "bysamfällighet",
    "bysamfälligheter": "bysamfällighet",
    "bysamfälligheterna": "bysamfällighet",
    "bysamfälligheternas": "bysamfällighet",
    "bysamfälligheters": "bysamfällighet",
    "bysamfällighets": "bysamfällighet",
    "bysantinen": "bysantin",
    "bysantinens": "bysantin",
    "bysantiner": "bysantin",
    "bysantinerna": "bysantin",
    "bysantinernas": "bysantin",
    "bysantiners": "bysantin",
    "bysantinismen": "bysantinism",
    "bysantinismens": "bysantinism",
    "bysantinismer": "bysantinism",
    "bysantinismerna": "bysantinism",
    "bysantinismernas": "bysantinism",
    "bysantinismers": "bysantinism",
    "bysantinisms": "bysantinism",
    "bysantins": "bysantin",
    "bysantinska": "bysantinsk",
    "bysantinskare": "bysantinsk",
    "bysantinskares": "bysantinsk",
    "bysantinskas": "bysantinsk",
    "bysantinskast": "bysantinsk",
    "bysantinskaste": "bysantinsk",
    "bysantinskastes": "bysantinsk",
    "bysantinskasts": "bysantinsk",
    "bysantinske": "bysantinsk",
    "bysantinskes": "bysantinsk",
    "bysantinsks": "bysantinsk",
    "bysantinskt": "bysantinsk",
    "bysantinskts": "bysantinsk",
    "bysatt": "bysätta",
    "bysatta": "bysätta",
    "bysattas": "bysätta",
    "bysatte": "bysätta",
    "bysattes": "bysätta",
    "bysatts": "bysätta",
    "bysnillen": "bysnille",
    "bysnillena": "bysnille",
    "bysnillenas": "bysnille",
    "bysnillens": "bysnille",
    "bysnilles": "bysnille",
    "bysnillet": "bysnille",
    "bysnillets": "bysnille",
    "bysnills": "bysnille",
    "byssjan": "byssja",
    "byssjans": "byssja",
    "byssjas": "byssja",
    "byssje": "byssja",
    "byssjor": "byssja",
    "byssjorna": "byssja",
    "byssjornas": "byssja",
    "byssjors": "byssja",
    "bystans": "bystan",
    "bystdrottningar": "bystdrottning",
    "bystdrottningarna": "bystdrottning",
    "bystdrottningarnas": "bystdrottning",
    "bystdrottningars": "bystdrottning",
    "bystdrottningen": "bystdrottning",
    "bystdrottningens": "bystdrottning",
    "bystdrottnings": "bystdrottning",
    "bysten": "byst",
    "bystens": "byst",
    "byster": "byst",
    "bysterna": "byst",
    "bysternas": "byst",
    "bysters": "byst",
    "bysthållar": "bysthållare",
    "bysthållaren": "bysthållare",
    "bysthållarens": "bysthållare",
    "bysthållares": "bysthållare",
    "bysthållarna": "bysthållare",
    "bysthållarnas": "bysthållare",
    "bystmåtten": "bystmått",
    "bystmåttens": "bystmått",
    "bystmåttet": "bystmått",
    "bystmåttets": "bystmått",
    "bystmåtts": "bystmått",
    "bysts": "byst",
    "bystämman": "bystämma",
    "bystämmans": "bystämma",
    "bystämmas": "bystämma",
    "bystämme": "bystämma",
    "bystämmo": "bystämma",
    "bystämmor": "bystämma",
    "bystämmorna": "bystämma",
    "bystämmornas": "bystämma",
    "bystämmors": "bystämma",
    "bysätt": "bysätta",
    "bysättande": "bysätta",
    "bysättanden": "bysättande",
    "bysättandena": "bysättande",
    "bysättandenas": "bysättande",
    "bysättandens": "bysättande",
    "bysättandes": "bysättande",
    "bysättandet": "bysättande",
    "bysättandets": "bysättande",
    "bysättas": "bysätta",
    "bysätter": "bysätta",
    "bysättes": "bysätta",
    "bysätts": "bysätta",
    "byt": "byta",
    "bytande": "byta",
    "bytanden": "bytande",
    "bytandena": "bytande",
    "bytandenas": "bytande",
    "bytandens": "bytande",
    "bytandes": "bytande",
    "bytandet": "bytande",
    "bytandets": "bytande",
    "bytas": "byta",
    "byten": "byte",
    "bytena": "byte",
    "bytenas": "byte",
    "bytens": "byte",
    "byter": "byta",
    "bytes": "byte",
    "bytesaffären": "bytesaffär",
    "bytesaffärens": "bytesaffär",
    "bytesaffärer": "bytesaffär",
    "bytesaffärerna": "bytesaffär",
    "bytesaffärernas": "bytesaffär",
    "bytesaffärers": "bytesaffär",
    "bytesaffärs": "bytesaffär",
    "bytesbalansen": "bytesbalans",
    "bytesbalansens": "bytesbalans",
    "bytesbalansunderskotten": "bytesbalansunderskott",
    "bytesbalansunderskottens": "bytesbalansunderskott",
    "bytesbalansunderskottet": "bytesbalansunderskott",
    "bytesbalansunderskottets": "bytesbalansunderskott",
    "bytesbalansunderskotts": "bytesbalansunderskott",
    "bytesbalansöverskotten": "bytesbalansöverskott",
    "bytesbalansöverskottens": "bytesbalansöverskott",
    "bytesbalansöverskottet": "bytesbalansöverskott",
    "bytesbalansöverskottets": "bytesbalansöverskott",
    "bytesbalansöverskotts": "bytesbalansöverskott",
    "bytesdjuren": "bytesdjur",
    "bytesdjurens": "bytesdjur",
    "bytesdjuret": "bytesdjur",
    "bytesdjurets": "bytesdjur",
    "bytesdjurs": "bytesdjur",
    "byteshandeln": "byteshandel",
    "byteshandelns": "byteshandel",
    "byteshandels": "byteshandel",
    "byteshushållningar": "byteshushållning",
    "byteshushållningarna": "byteshushållning",
    "byteshushållningarnas": "byteshushållning",
    "byteshushållningars": "byteshushållning",
    "byteshushållningen": "byteshushållning",
    "byteshushållningens": "byteshushållning",
    "byteshushållnings": "byteshushållning",
    "byteslägenheten": "byteslägenhet",
    "byteslägenhetens": "byteslägenhet",
    "byteslägenheter": "byteslägenhet",
    "byteslägenheterna": "byteslägenhet",
    "byteslägenheternas": "byteslägenhet",
    "byteslägenheters": "byteslägenhet",
    "byteslägenhets": "byteslägenhet",
    "bytesmedels": "bytesmedel",
    "bytesmedlen": "bytesmedel",
    "bytesmedlens": "bytesmedel",
    "bytesmedlet": "bytesmedel",
    "bytesmedlets": "bytesmedel",
    "bytesobjekten": "bytesobjekt",
    "bytesobjektens": "bytesobjekt",
    "bytesobjektet": "bytesobjekt",
    "bytesobjektets": "bytesobjekt",
    "bytesobjekts": "bytesobjekt",
    "bytesvärden": "bytesvärde",
    "bytesvärdena": "bytesvärde",
    "bytesvärdenas": "bytesvärde",
    "bytesvärdens": "bytesvärde",
    "bytesvärdes": "bytesvärde",
    "bytesvärdet": "bytesvärde",
    "bytesvärdets": "bytesvärde",
    "bytet": "byte",
    "bytets": "byte",
    "bytingar": "byting",
    "bytingarna": "byting",
    "bytingarnas": "byting",
    "bytingars": "byting",
    "bytingen": "byting",
    "bytingens": "byting",
    "bytings": "byting",
    "byts": "byta",
    "bytt": "bytta",
    "bytta": "byta",
    "byttan": "bytta",
    "byttans": "bytta",
    "byttas": "bytta",
    "bytte": "bytta",
    "byttes": "byta",
    "byttor": "bytta",
    "byttorna": "bytta",
    "byttornas": "bytta",
    "byttors": "bytta",
    "bytts": "bytta",
    "byvägar": "byväg",
    "byvägarna": "byväg",
    "byvägarnas": "byväg",
    "byvägars": "byväg",
    "byvägen": "byväg",
    "byvägens": "byväg",
    "byvägs": "byväg",
    "byx": "byxa",
    "byxan": "byxa",
    "byxans": "byxa",
    "byxar": "byx",
    "byxarna": "byx",
    "byxarnas": "byx",
    "byxars": "byx",
    "byxas": "byxa",
    "byxbakar": "byxbak",
    "byxbakarna": "byxbak",
    "byxbakarnas": "byxbak",
    "byxbakars": "byxbak",
    "byxbaken": "byxbak",
    "byxbakens": "byxbak",
    "byxbaks": "byxbak",
    "byxbenen": "byxben",
    "byxbenens": "byxben",
    "byxbenet": "byxben",
    "byxbenets": "byxben",
    "byxbens": "byxben",
    "byxdressar": "byxdress",
    "byxdressarna": "byxdress",
    "byxdressarnas": "byxdress",
    "byxdressars": "byxdress",
    "byxdressen": "byxdress",
    "byxdressens": "byxdress",
    "byxdresser": "byxdress",
    "byxdresserna": "byxdress",
    "byxdressernas": "byxdress",
    "byxdressers": "byxdress",
    "byxdräkten": "byxdräkt",
    "byxdräktens": "byxdräkt",
    "byxdräkter": "byxdräkt",
    "byxdräkterna": "byxdräkt",
    "byxdräkternas": "byxdräkt",
    "byxdräkters": "byxdräkt",
    "byxdräkts": "byxdräkt",
    "byxe": "byxa",
    "byxen": "byx",
    "byxens": "byx",
    "byxfick": "byxficka",
    "byxfickan": "byxficka",
    "byxfickans": "byxficka",
    "byxfickas": "byxficka",
    "byxficke": "byxficka",
    "byxfickor": "byxficka",
    "byxfickorna": "byxficka",
    "byxfickornas": "byxficka",
    "byxfickors": "byxficka",
    "byxficks": "byxficka",
    "byxholkar": "byxholk",
    "byxholkarna": "byxholk",
    "byxholkarnas": "byxholk",
    "byxholkars": "byxholk",
    "byxholken": "byxholk",
    "byxholkens": "byxholk",
    "byxholks": "byxholk",
    "byxhäll": "byxhälla",
    "byxhällan": "byxhälla",
    "byxhällans": "byxhälla",
    "byxhällas": "byxhälla",
    "byxhälle": "byxhälla",
    "byxhällor": "byxhälla",
    "byxhällorna": "byxhälla",
    "byxhällornas": "byxhälla",
    "byxhällors": "byxhälla",
    "byxhälls": "byxhälla",
    "byxkjolar": "byxkjol",
    "byxkjolarna": "byxkjol",
    "byxkjolarnas": "byxkjol",
    "byxkjolars": "byxkjol",
    "byxkjolen": "byxkjol",
    "byxkjolens": "byxkjol",
    "byxkjols": "byxkjol",
    "byxklämman": "byxklämma",
    "byxklämmans": "byxklämma",
    "byxklämmas": "byxklämma",
    "byxklämme": "byxklämma",
    "byxklämmor": "byxklämma",
    "byxklämmorna": "byxklämma",
    "byxklämmornas": "byxklämma",
    "byxklämmors": "byxklämma",
    "byxlösa": "byxlös",
    "byxlösare": "byxlös",
    "byxlösares": "byxlös",
    "byxlösas": "byxlös",
    "byxlösast": "byxlös",
    "byxlösaste": "byxlös",
    "byxlösastes": "byxlös",
    "byxlösasts": "byxlös",
    "byxlöse": "byxlös",
    "byxlöses": "byxlös",
    "byxlösheten": "byxlöshet",
    "byxlöshetens": "byxlöshet",
    "byxlöshets": "byxlöshet",
    "byxlöst": "byxlös",
    "byxlösts": "byxlös",
    "byxor": "byxa",
    "byxorna": "byxa",
    "byxornas": "byxa",
    "byxors": "byxa",
    "byxångesten": "byxångest",
    "byxångestens": "byxångest",
    "byxångests": "byxångest",
    "byäldstar": "byäldste",
    "byäldstarna": "byäldste",
    "byäldstarnas": "byäldste",
    "byäldstars": "byäldste",
    "byäldsten": "byäldste",
    "byäldstens": "byäldste",
    "byäldstes": "byäldste",
    "bäbisar": "bäbis",
    "bäbisarna": "bäbis",
    "bäbisarnas": "bäbis",
    "bäbisars": "bäbis",
    "bäbisen": "bäbis",
    "bäbisens": "bäbis",
    "bäckahästar": "bäckahäst",
    "bäckahästarna": "bäckahäst",
    "bäckahästarnas": "bäckahäst",
    "bäckahästars": "bäckahäst",
    "bäckahästen": "bäckahäst",
    "bäckahästens": "bäckahäst",
    "bäckahästs": "bäckahäst",
    "bäckar": "bäck",
    "bäckarna": "bäck",
    "bäckarnas": "bäck",
    "bäckars": "bäck",
    "bäcken": "bäck",
    "bäckenbenen": "bäckenben",
    "bäckenbenens": "bäckenben",
    "bäckenbenet": "bäckenben",
    "bäckenbenets": "bäckenben",
    "bäckenbens": "bäckenben",
    "bäckenen": "bäcken",
    "bäckenens": "bäcken",
    "bäckenet": "bäcken",
    "bäckenets": "bäcken",
    "bäckenförträngningar": "bäckenförträngning",
    "bäckenförträngningarna": "bäckenförträngning",
    "bäckenförträngningarnas": "bäckenförträngning",
    "bäckenförträngningars": "bäckenförträngning",
    "bäckenförträngningen": "bäckenförträngning",
    "bäckenförträngningens": "bäckenförträngning",
    "bäckenförträngnings": "bäckenförträngning",
    "bäckens": "bäcken",
    "bäckforellen": "bäckforell",
    "bäckforellens": "bäckforell",
    "bäckforeller": "bäckforell",
    "bäckforellerna": "bäckforell",
    "bäckforellernas": "bäckforell",
    "bäckforellers": "bäckforell",
    "bäckforells": "bäckforell",
    "bäckmynningar": "bäckmynning",
    "bäckmynningarna": "bäckmynning",
    "bäckmynningarnas": "bäckmynning",
    "bäckmynningars": "bäckmynning",
    "bäckmynningen": "bäckmynning",
    "bäckmynningens": "bäckmynning",
    "bäckmynnings": "bäckmynning",
    "bäckravinen": "bäckravin",
    "bäckravinens": "bäckravin",
    "bäckraviner": "bäckravin",
    "bäckravinerna": "bäckravin",
    "bäckravinernas": "bäckravin",
    "bäckraviners": "bäckravin",
    "bäckravins": "bäckravin",
    "bäckrödingar": "bäckröding",
    "bäckrödingarna": "bäckröding",
    "bäckrödingarnas": "bäckröding",
    "bäckrödingars": "bäckröding",
    "bäckrödingen": "bäckröding",
    "bäckrödingens": "bäckröding",
    "bäckrödings": "bäckröding",
    "bäcks": "bäck",
    "bäcköringar": "bäcköring",
    "bäcköringarna": "bäcköring",
    "bäcköringarnas": "bäcköring",
    "bäcköringars": "bäcköring",
    "bäcköringen": "bäcköring",
    "bäcköringens": "bäcköring",
    "bäckörings": "bäcköring",
    "bädd": "bädda",
    "bäddad": "bädda",
    "bäddade": "bädda",
    "bäddades": "bädda",
    "bäddads": "bädda",
    "bäddande": "bädda",
    "bäddanden": "bäddande",
    "bäddandena": "bäddande",
    "bäddandenas": "bäddande",
    "bäddandens": "bäddande",
    "bäddandes": "bäddande",
    "bäddandet": "bäddande",
    "bäddandets": "bäddande",
    "bäddar": "bädda",
    "bäddarna": "bädd",
    "bäddarnas": "bädd",
    "bäddars": "bädd",
    "bäddas": "bädda",
    "bäddat": "bädda",
    "bäddats": "bädda",
    "bädden": "bädd",
    "bäddens": "bädd",
    "bäddjack": "bäddjacka",
    "bäddjackan": "bäddjacka",
    "bäddjackans": "bäddjacka",
    "bäddjackas": "bäddjacka",
    "bäddjacke": "bäddjacka",
    "bäddjackor": "bäddjacka",
    "bäddjackorna": "bäddjacka",
    "bäddjackornas": "bäddjacka",
    "bäddjackors": "bäddjacka",
    "bäddjacks": "bäddjacka",
    "bädds": "bädd",
    "bäddsoff": "bäddsoffa",
    "bäddsoffan": "bäddsoffa",
    "bäddsoffans": "bäddsoffa",
    "bäddsoffas": "bäddsoffa",
    "bäddsoffe": "bäddsoffa",
    "bäddsoffor": "bäddsoffa",
    "bäddsofforna": "bäddsoffa",
    "bäddsoffornas": "bäddsoffa",
    "bäddsoffors": "bäddsoffa",
    "bäddsoffs": "bäddsoffa",
    "bäddutrustningar": "bäddutrustning",
    "bäddutrustningarna": "bäddutrustning",
    "bäddutrustningarnas": "bäddutrustning",
    "bäddutrustningars": "bäddutrustning",
    "bäddutrustningen": "bäddutrustning",
    "bäddutrustningens": "bäddutrustning",
    "bäddutrustnings": "bäddutrustning",
    "bägar": "bägare",
    "bägaren": "bägare",
    "bägarens": "bägare",
    "bägares": "bägare",
    "bägarkorallen": "bägarkorall",
    "bägarkorallens": "bägarkorall",
    "bägarkoraller": "bägarkorall",
    "bägarkorallerna": "bägarkorall",
    "bägarkorallernas": "bägarkorall",
    "bägarkorallers": "bägarkorall",
    "bägarkoralls": "bägarkorall",
    "bägarmaneten": "bägarmanet",
    "bägarmanetens": "bägarmanet",
    "bägarmaneter": "bägarmanet",
    "bägarmaneterna": "bägarmanet",
    "bägarmaneternas": "bägarmanet",
    "bägarmaneters": "bägarmanet",
    "bägarmanets": "bägarmanet",
    "bägarna": "bägare",
    "bägarnas": "bägare",
    "bägarsvampar": "bägarsvamp",
    "bägarsvamparna": "bägarsvamp",
    "bägarsvamparnas": "bägarsvamp",
    "bägarsvampars": "bägarsvamp",
    "bägarsvampen": "bägarsvamp",
    "bägarsvampens": "bägarsvamp",
    "bägarsvamps": "bägarsvamp",
    "bäggederas": "bäggedera",
    "bägges": "bägge",
    "bälgad": "bälga",
    "bälgade": "bälga",
    "bälgades": "bälga",
    "bälgads": "bälga",
    "bälgande": "bälga",
    "bälganden": "bälgande",
    "bälgandena": "bälgande",
    "bälgandenas": "bälgande",
    "bälgandens": "bälgande",
    "bälgandes": "bälgande",
    "bälgandet": "bälgande",
    "bälgandets": "bälgande",
    "bälgar": "bälga",
    "bälgarna": "bälg",
    "bälgarnas": "bälg",
    "bälgars": "bälg",
    "bälgas": "bälga",
    "bälgat": "bälga",
    "bälgats": "bälga",
    "bälgen": "bälg",
    "bälgens": "bälg",
    "bälgformade": "bälgformad",
    "bälgformades": "bälgformad",
    "bälgformads": "bälgformad",
    "bälgformat": "bälgformad",
    "bälgformats": "bälgformad",
    "bälgkameran": "bälgkamera",
    "bälgkamerans": "bälgkamera",
    "bälgkameras": "bälgkamera",
    "bälgkameror": "bälgkamera",
    "bälgkamerorna": "bälgkamera",
    "bälgkamerornas": "bälgkamera",
    "bälgkamerors": "bälgkamera",
    "bälgs": "bälg",
    "bälgvant": "bälgvante",
    "bälgvantar": "bälgvante",
    "bälgvantarna": "bälgvante",
    "bälgvantarnas": "bälgvante",
    "bälgvantars": "bälgvante",
    "bälgvanten": "bälgvante",
    "bälgvantens": "bälgvante",
    "bälgvantes": "bälgvante",
    "bälgvants": "bälgvante",
    "bält": "bälta",
    "bältan": "bälta",
    "bältans": "bälta",
    "bältas": "bälta",
    "bältdjuren": "bältdjur",
    "bältdjurens": "bältdjur",
    "bältdjuret": "bältdjur",
    "bältdjurets": "bältdjur",
    "bältdjurs": "bältdjur",
    "bälte": "bälta",
    "bälten": "bälte",
    "bältena": "bälte",
    "bältenas": "bälte",
    "bältens": "bälte",
    "bältes": "bälte",
    "bältesläggningar": "bältesläggning",
    "bältesläggningarna": "bältesläggning",
    "bältesläggningarnas": "bältesläggning",
    "bältesläggningars": "bältesläggning",
    "bältesläggningen": "bältesläggning",
    "bältesläggningens": "bältesläggning",
    "bältesläggnings": "bältesläggning",
    "bältespännar": "bältespännare",
    "bältespännaren": "bältespännare",
    "bältespännarens": "bältespännare",
    "bältespännares": "bältespännare",
    "bältespännarna": "bältespännare",
    "bältespännarnas": "bältespännare",
    "bältestvången": "bältestvång",
    "bältestvångens": "bältestvång",
    "bältestvånget": "bältestvång",
    "bältestvångets": "bältestvång",
    "bältestvångs": "bältestvång",
    "bältet": "bälte",
    "bältets": "bälte",
    "bältor": "bälta",
    "bältorna": "bälta",
    "bältornas": "bälta",
    "bältors": "bälta",
    "bältrosen": "bältros",
    "bältrosens": "bältros",
    "bälts": "bälta",
    "bänd": "bända",
    "bändande": "bända",
    "bändanden": "bändande",
    "bändandena": "bändande",
    "bändandenas": "bändande",
    "bändandens": "bändande",
    "bändandes": "bändande",
    "bändandet": "bändande",
    "bändandets": "bändande",
    "bändas": "bända",
    "bände": "bända",
    "bändelbanden": "bändelband",
    "bändelbandens": "bändelband",
    "bändelbandet": "bändelband",
    "bändelbandets": "bändelband",
    "bändelbands": "bändelband",
    "bänder": "bända",
    "bändes": "bända",
    "bändjärnen": "bändjärn",
    "bändjärnens": "bändjärn",
    "bändjärnet": "bändjärn",
    "bändjärnets": "bändjärn",
    "bändjärns": "bändjärn",
    "bänds": "bända",
    "bändsel": "bändsla",
    "bändseln": "bändsel",
    "bändselns": "bändsel",
    "bändsels": "bändsel",
    "bändslad": "bändsla",
    "bändslade": "bändsla",
    "bändslades": "bändsla",
    "bändslads": "bändsla",
    "bändslande": "bändsla",
    "bändslanden": "bändslande",
    "bändslandena": "bändslande",
    "bändslandenas": "bändslande",
    "bändslandens": "bändslande",
    "bändslandes": "bändslande",
    "bändslandet": "bändslande",
    "bändslandets": "bändslande",
    "bändslar": "bändsla",
    "bändslarna": "bändsel",
    "bändslarnas": "bändsel",
    "bändslars": "bändsel",
    "bändslas": "bändsla",
    "bändslat": "bändsla",
    "bändslats": "bändsla",
    "bänga": "bäng",
    "bängare": "bäng",
    "bängares": "bäng",
    "bängas": "bäng",
    "bängast": "bäng",
    "bängaste": "bäng",
    "bängastes": "bäng",
    "bängasts": "bäng",
    "bänge": "bäng",
    "bängeln": "bängel",
    "bängelns": "bängel",
    "bängels": "bängel",
    "bänges": "bäng",
    "bängheten": "bänghet",
    "bänghetens": "bänghet",
    "bänghets": "bänghet",
    "bänglar": "bängel",
    "bänglarna": "bängel",
    "bänglarnas": "bängel",
    "bänglars": "bängel",
    "bängs": "bäng",
    "bängt": "bäng",
    "bängts": "bäng",
    "bänkar": "bänk",
    "bänkarna": "bänk",
    "bänkarnas": "bänk",
    "bänkars": "bänk",
    "bänken": "bänk",
    "bänkens": "bänk",
    "bänkgrann": "bänkgranne",
    "bänkgrannar": "bänkgranne",
    "bänkgrannarna": "bänkgranne",
    "bänkgrannarnas": "bänkgranne",
    "bänkgrannars": "bänkgranne",
    "bänkgrannen": "bänkgranne",
    "bänkgrannens": "bänkgranne",
    "bänkgrannes": "bänkgranne",
    "bänkgranns": "bänkgranne",
    "bänkkamraten": "bänkkamrat",
    "bänkkamratens": "bänkkamrat",
    "bänkkamrater": "bänkkamrat",
    "bänkkamraterna": "bänkkamrat",
    "bänkkamraternas": "bänkkamrat",
    "bänkkamraters": "bänkkamrat",
    "bänkkamrats": "bänkkamrat",
    "bänknummerna": "bänknummer",
    "bänknummernas": "bänknummer",
    "bänknummers": "bänknummer",
    "bänknumren": "bänknummer",
    "bänknumrens": "bänknummer",
    "bänknumret": "bänknummer",
    "bänknumrets": "bänknummer",
    "bänkpressen": "bänkpress",
    "bänkpressens": "bänkpress",
    "bänkraden": "bänkrad",
    "bänkradens": "bänkrad",
    "bänkrader": "bänkrad",
    "bänkraderna": "bänkrad",
    "bänkradernas": "bänkrad",
    "bänkraders": "bänkrad",
    "bänkrads": "bänkrad",
    "bänks": "bänk",
    "bänkskåpen": "bänkskåp",
    "bänkskåpens": "bänkskåp",
    "bänkskåpet": "bänkskåp",
    "bänkskåpets": "bänkskåp",
    "bänkskåps": "bänkskåp",
    "bänkslipmaskinen": "bänkslipmaskin",
    "bänkslipmaskinens": "bänkslipmaskin",
    "bänkslipmaskiner": "bänkslipmaskin",
    "bänkslipmaskinerna": "bänkslipmaskin",
    "bänkslipmaskinernas": "bänkslipmaskin",
    "bänkslipmaskiners": "bänkslipmaskin",
    "bänkslipmaskins": "bänkslipmaskin",
    "bänkspisar": "bänkspis",
    "bänkspisarna": "bänkspis",
    "bänkspisarnas": "bänkspis",
    "bänkspisars": "bänkspis",
    "bänkspisen": "bänkspis",
    "bänkspisens": "bänkspis",
    "bänsel": "bänsla",
    "bänseln": "bänsel",
    "bänselns": "bänsel",
    "bänsels": "bänsel",
    "bänslad": "bänsla",
    "bänslade": "bänsla",
    "bänslades": "bänsla",
    "bänslads": "bänsla",
    "bänslande": "bänsla",
    "bänslanden": "bänslande",
    "bänslandena": "bänslande",
    "bänslandenas": "bänslande",
    "bänslandens": "bänslande",
    "bänslandes": "bänslande",
    "bänslandet": "bänslande",
    "bänslandets": "bänslande",
    "bänslar": "bänsla",
    "bänslarna": "bänsel",
    "bänslarnas": "bänsel",
    "bänslars": "bänsel",
    "bänslas": "bänsla",
    "bänslat": "bänsla",
    "bänslats": "bänsla",
    "bänt": "bända",
    "bänts": "bända",
    "bär": "bära",
    "bärande": "bära",
    "bäranden": "bärande",
    "bärandena": "bärande",
    "bärandenas": "bärande",
    "bärandens": "bärande",
    "bärandes": "bärande",
    "bärandet": "bärande",
    "bärandets": "bärande",
    "bärar": "bärare",
    "bäraren": "bärare",
    "bärarens": "bärare",
    "bärares": "bärare",
    "bärarna": "bärare",
    "bärarnas": "bärare",
    "bäras": "bära",
    "bärbara": "bärbar",
    "bärbarare": "bärbar",
    "bärbarares": "bärbar",
    "bärbaras": "bärbar",
    "bärbarast": "bärbar",
    "bärbaraste": "bärbar",
    "bärbarastes": "bärbar",
    "bärbarasts": "bärbar",
    "bärbare": "bärbar",
    "bärbares": "bärbar",
    "bärbarheten": "bärbarhet",
    "bärbarhetens": "bärbarhet",
    "bärbarhets": "bärbarhet",
    "bärbars": "bärbar",
    "bärbart": "bärbar",
    "bärbarts": "bärbar",
    "bärbjälk": "bärbjälke",
    "bärbjälkar": "bärbjälke",
    "bärbjälkarna": "bärbjälke",
    "bärbjälkarnas": "bärbjälke",
    "bärbjälkars": "bärbjälke",
    "bärbjälken": "bärbjälke",
    "bärbjälkens": "bärbjälke",
    "bärbjälkes": "bärbjälke",
    "bärbjälks": "bärbjälke",
    "bärbusk": "bärbuske",
    "bärbuskar": "bärbuske",
    "bärbuskarna": "bärbuske",
    "bärbuskarnas": "bärbuske",
    "bärbuskars": "bärbuske",
    "bärbusken": "bärbuske",
    "bärbuskens": "bärbuske",
    "bärbuskes": "bärbuske",
    "bäre": "bära",
    "bären": "bär",
    "bärens": "bär",
    "bäres": "bära",
    "bäret": "bär",
    "bärets": "bär",
    "bärfisar": "bärfis",
    "bärfisarna": "bärfis",
    "bärfisarnas": "bärfis",
    "bärfisars": "bärfis",
    "bärfisen": "bärfis",
    "bärfisens": "bärfis",
    "bärfrekvensen": "bärfrekvens",
    "bärfrekvensens": "bärfrekvens",
    "bärfrekvenser": "bärfrekvens",
    "bärfrekvenserna": "bärfrekvens",
    "bärfrekvensernas": "bärfrekvens",
    "bärfrekvensers": "bärfrekvens",
    "bärg": "bärga",
    "bärgad": "bärga",
    "bärgade": "bärga",
    "bärgades": "bärga",
    "bärgads": "bärga",
    "bärgande": "bärga",
    "bärganden": "bärgande",
    "bärgandena": "bärgande",
    "bärgandenas": "bärgande",
    "bärgandens": "bärgande",
    "bärgandes": "bärgande",
    "bärgandet": "bärgande",
    "bärgandets": "bärgande",
    "bärgar": "bärga",
    "bärgas": "bärga",
    "bärgat": "bärga",
    "bärgats": "bärga",
    "bärgningar": "bärgning",
    "bärgningarna": "bärgning",
    "bärgningarnas": "bärgning",
    "bärgningars": "bärgning",
    "bärgningen": "bärgning",
    "bärgningens": "bärgning",
    "bärgnings": "bärgning",
    "bärgningsbilar": "bärgningsbil",
    "bärgningsbilarna": "bärgningsbil",
    "bärgningsbilarnas": "bärgningsbil",
    "bärgningsbilars": "bärgningsbil",
    "bärgningsbilen": "bärgningsbil",
    "bärgningsbilens": "bärgningsbil",
    "bärgningsbils": "bärgningsbil",
    "bärgningsföretagen": "bärgningsföretag",
    "bärgningsföretagens": "bärgningsföretag",
    "bärgningsföretaget": "bärgningsföretag",
    "bärgningsföretagets": "bärgningsföretag",
    "bärgningsföretags": "bärgningsföretag",
    "bärhandtagen": "bärhandtag",
    "bärhandtagens": "bärhandtag",
    "bärhandtaget": "bärhandtag",
    "bärhandtagets": "bärhandtag",
    "bärhandtags": "bärhandtag",
    "bäriga": "bärig",
    "bärigare": "bärig",
    "bärigares": "bärig",
    "bärigas": "bärig",
    "bärigast": "bärig",
    "bärigaste": "bärig",
    "bärigastes": "bärig",
    "bärigasts": "bärig",
    "bärige": "bärig",
    "bäriges": "bärig",
    "bärigs": "bärig",
    "bärigt": "bärig",
    "bärigts": "bärig",
    "bäringar": "bäring",
    "bäringarna": "bäring",
    "bäringarnas": "bäring",
    "bäringars": "bäring",
    "bäringen": "bäring",
    "bäringens": "bäring",
    "bärings": "bäring",
    "bärkass": "bärkasse",
    "bärkassar": "bärkasse",
    "bärkassarna": "bärkasse",
    "bärkassarnas": "bärkasse",
    "bärkassars": "bärkasse",
    "bärkassen": "bärkasse",
    "bärkassens": "bärkasse",
    "bärkasses": "bärkasse",
    "bärkott": "bärkotte",
    "bärkottar": "bärkotte",
    "bärkottarna": "bärkotte",
    "bärkottarnas": "bärkotte",
    "bärkottars": "bärkotte",
    "bärkotten": "bärkotte",
    "bärkottens": "bärkotte",
    "bärkottes": "bärkotte",
    "bärkotts": "bärkotte",
    "bärkraften": "bärkraft",
    "bärkraftens": "bärkraft",
    "bärkraftiga": "bärkraftig",
    "bärkraftigare": "bärkraftig",
    "bärkraftigares": "bärkraftig",
    "bärkraftigas": "bärkraftig",
    "bärkraftigast": "bärkraftig",
    "bärkraftigaste": "bärkraftig",
    "bärkraftigastes": "bärkraftig",
    "bärkraftigasts": "bärkraftig",
    "bärkraftige": "bärkraftig",
    "bärkraftiges": "bärkraftig",
    "bärkraftigheten": "bärkraftighet",
    "bärkraftighetens": "bärkraftighet",
    "bärkraftighets": "bärkraftighet",
    "bärkraftigs": "bärkraftig",
    "bärkraftigt": "bärkraftig",
    "bärkraftigts": "bärkraftig",
    "bärkrafts": "bärkraft",
    "bärlagerna": "bärlager",
    "bärlagernas": "bärlager",
    "bärlagers": "bärlager",
    "bärlagren": "bärlager",
    "bärlagrens": "bärlager",
    "bärlagret": "bärlager",
    "bärlagrets": "bärlager",
    "bärmarken": "bärmark",
    "bärmarkens": "bärmark",
    "bärmarker": "bärmark",
    "bärmarkerna": "bärmark",
    "bärmarkernas": "bärmark",
    "bärmarkers": "bärmark",
    "bärmarks": "bärmark",
    "bärmen": "bärm",
    "bärmens": "bärm",
    "bärmer": "bärm",
    "bärmerna": "bärm",
    "bärmernas": "bärm",
    "bärmers": "bärm",
    "bärms": "bärm",
    "bärnstenen": "bärnsten",
    "bärnstenens": "bärnsten",
    "bärnstens": "bärnsten",
    "bärnstenssyran": "bärnstenssyra",
    "bärnstenssyrans": "bärnstenssyra",
    "bärnstenssyras": "bärnstenssyra",
    "bärnstenssyre": "bärnstenssyra",
    "bärnäsen": "bärnäs",
    "bärnäsens": "bärnäs",
    "bärnäser": "bärnäs",
    "bärnäserna": "bärnäs",
    "bärnäsernas": "bärnäs",
    "bärnäsers": "bärnäs",
    "bärnässåsen": "bärnässås",
    "bärnässåsens": "bärnässås",
    "bärnässåser": "bärnässås",
    "bärnässåserna": "bärnässås",
    "bärnässåsernas": "bärnässås",
    "bärnässåsers": "bärnässås",
    "bärpelar": "bärpelare",
    "bärpelaren": "bärpelare",
    "bärpelarens": "bärpelare",
    "bärpelares": "bärpelare",
    "bärpelarna": "bärpelare",
    "bärpelarnas": "bärpelare",
    "bärplanen": "bärplan",
    "bärplanens": "bärplan",
    "bärplanet": "bärplan",
    "bärplanets": "bärplan",
    "bärplans": "bärplan",
    "bärplansbåtar": "bärplansbåt",
    "bärplansbåtarna": "bärplansbåt",
    "bärplansbåtarnas": "bärplansbåt",
    "bärplansbåtars": "bärplansbåt",
    "bärplansbåten": "bärplansbåt",
    "bärplansbåtens": "bärplansbåt",
    "bärplansbåts": "bärplansbåt",
    "bärplockar": "bärplockare",
    "bärplockaren": "bärplockare",
    "bärplockarens": "bärplockare",
    "bärplockares": "bärplockare",
    "bärplockarna": "bärplockare",
    "bärplockarnas": "bärplockare",
    "bärpås": "bärpåse",
    "bärpåsar": "bärpåse",
    "bärpåsarna": "bärpåse",
    "bärpåsarnas": "bärpåse",
    "bärpåsars": "bärpåse",
    "bärpåsen": "bärpåse",
    "bärpåsens": "bärpåse",
    "bärpåses": "bärpåse",
    "bärraketen": "bärraket",
    "bärraketens": "bärraket",
    "bärraketer": "bärraket",
    "bärraketerna": "bärraket",
    "bärraketernas": "bärraket",
    "bärraketers": "bärraket",
    "bärrakets": "bärraket",
    "bärs": "bära",
    "bärsade": "bärsa",
    "bärsades": "bärsa",
    "bärsan": "bärsa",
    "bärsande": "bärsa",
    "bärsanden": "bärsande",
    "bärsandena": "bärsande",
    "bärsandenas": "bärsande",
    "bärsandens": "bärsande",
    "bärsandes": "bärsande",
    "bärsandet": "bärsande",
    "bärsandets": "bärsande",
    "bärsans": "bärsa",
    "bärsar": "bärsa",
    "bärsarna": "bärs",
    "bärsarnas": "bärs",
    "bärsars": "bärs",
    "bärsas": "bärsa",
    "bärsat": "bärsa",
    "bärsats": "bärsa",
    "bärsen": "bärs",
    "bärsens": "bärs",
    "bärset": "bärs",
    "bärsets": "bärs",
    "bärsor": "bärsa",
    "bärsorna": "bärsa",
    "bärsornas": "bärsa",
    "bärsors": "bärsa",
    "bärstolar": "bärstol",
    "bärstolarna": "bärstol",
    "bärstolarnas": "bärstol",
    "bärstolars": "bärstol",
    "bärstolen": "bärstol",
    "bärstolens": "bärstol",
    "bärstols": "bärstol",
    "bärsärkagången": "bärsärkagång",
    "bärsärkagångens": "bärsärkagång",
    "bärsärkagångs": "bärsärkagång",
    "bärsärkar": "bärsärk",
    "bärsärkaraseriet": "bärsärkaraseri",
    "bärsärkaraseriets": "bärsärkaraseri",
    "bärsärkaraseris": "bärsärkaraseri",
    "bärsärkaraserit": "bärsärkaraseri",
    "bärsärkaraserits": "bärsärkaraseri",
    "bärsärkarna": "bärsärk",
    "bärsärkarnas": "bärsärk",
    "bärsärkars": "bärsärk",
    "bärsärken": "bärsärk",
    "bärsärkens": "bärsärk",
    "bärsärks": "bärsärk",
    "bärvidden": "bärvidd",
    "bärviddens": "bärvidd",
    "bärvidder": "bärvidd",
    "bärvidderna": "bärvidd",
    "bärviddernas": "bärvidd",
    "bärvidders": "bärvidd",
    "bärvidds": "bärvidd",
    "bärvågen": "bärvåg",
    "bärvågens": "bärvåg",
    "bärvågor": "bärvåg",
    "bärvågorna": "bärvåg",
    "bärvågornas": "bärvåg",
    "bärvågors": "bärvåg",
    "bärvågs": "bärvåg",
    "bäst": "god",
    "bäst-före-dagar": "bäst-före-dag",
    "bäst-före-dagarna": "bäst-före-dag",
    "bäst-före-dagarnas": "bäst-före-dag",
    "bäst-före-dagars": "bäst-före-dag",
    "bäst-före-dagen": "bäst-före-dag",
    "bäst-före-dagens": "bäst-före-dag",
    "bäst-före-dags": "bäst-före-dag",
    "bäst-före-dan": "bäst-före-dag",
    "bäst-före-dans": "bäst-före-dag",
    "bäst-före-dar": "bäst-före-dag",
    "bäst-före-darna": "bäst-före-dag",
    "bäst-före-darnas": "bäst-före-dag",
    "bäst-före-dars": "bäst-före-dag",
    "bäst-före-datumar": "bäst-före-datum",
    "bäst-före-datumarna": "bäst-före-datum",
    "bäst-före-datumarnas": "bäst-före-datum",
    "bäst-före-datumars": "bäst-före-datum",
    "bäst-före-datumen": "bäst-före-datum",
    "bäst-före-datumens": "bäst-före-datum",
    "bäst-före-datumer": "bäst-före-datum",
    "bäst-före-datumerna": "bäst-före-datum",
    "bäst-före-datumernas": "bäst-före-datum",
    "bäst-före-datumers": "bäst-före-datum",
    "bäst-före-datumet": "bäst-före-datum",
    "bäst-före-datumets": "bäst-före-datum",
    "bäst-före-datums": "bäst-före-datum",
    "bästa": "god",
    "bästas": "god",
    "bäste": "god",
    "bästemannen": "bästeman",
    "bästemannens": "bästeman",
    "bästemans": "bästeman",
    "bästemän": "bästeman",
    "bästemännen": "bästeman",
    "bästemännens": "bästeman",
    "bästemäns": "bästeman",
    "bästes": "god",
    "bästföre-dagar": "bästföre-dag",
    "bästföre-dagarna": "bästföre-dag",
    "bästföre-dagarnas": "bästföre-dag",
    "bästföre-dagars": "bästföre-dag",
    "bästföre-dagen": "bästföre-dag",
    "bästföre-dagens": "bästföre-dag",
    "bästföre-dags": "bästföre-dag",
    "bästföre-dan": "bästföre-dag",
    "bästföre-dans": "bästföre-dag",
    "bästföre-dar": "bästföre-dag",
    "bästföre-darna": "bästföre-dag",
    "bästföre-darnas": "bästföre-dag",
    "bästföre-dars": "bästföre-dag",
    "bästföre-datumar": "bästföre-datum",
    "bästföre-datumarna": "bästföre-datum",
    "bästföre-datumarnas": "bästföre-datum",
    "bästföre-datumars": "bästföre-datum",
    "bästföre-datumen": "bästföre-datum",
    "bästföre-datumens": "bästföre-datum",
    "bästföre-datumer": "bästföre-datum",
    "bästföre-datumerna": "bästföre-datum",
    "bästföre-datumernas": "bästföre-datum",
    "bästföre-datumers": "bästföre-datum",
    "bästföre-datumet": "bästföre-datum",
    "bästföre-datumets": "bästföre-datum",
    "bästföre-datums": "bästföre-datum",
    "bästföredagar": "bästföredag",
    "bästföredagarna": "bästföredag",
    "bästföredagarnas": "bästföredag",
    "bästföredagars": "bästföredag",
    "bästföredagen": "bästföredag",
    "bästföredagens": "bästföredag",
    "bästföredags": "bästföredag",
    "bästföredan": "bästföredag",
    "bästföredans": "bästföredag",
    "bästföredar": "bästföredag",
    "bästföredarna": "bästföredag",
    "bästföredarnas": "bästföredag",
    "bästföredars": "bästföredag",
    "bästföredatumar": "bästföredatum",
    "bästföredatumarna": "bästföredatum",
    "bästföredatumarnas": "bästföredatum",
    "bästföredatumars": "bästföredatum",
    "bästföredatumen": "bästföredatum",
    "bästföredatumens": "bästföredatum",
    "bästföredatumer": "bästföredatum",
    "bästföredatumerna": "bästföredatum",
    "bästföredatumernas": "bästföredatum",
    "bästföredatumers": "bästföredatum",
    "bästföredatumet": "bästföredatum",
    "bästföredatumets": "bästföredatum",
    "bästföredatums": "bästföredatum",
    "bästisar": "bästis",
    "bästisarna": "bästis",
    "bästisarnas": "bästis",
    "bästisars": "bästis",
    "bästisen": "bästis",
    "bästisens": "bästis",
    "bästs": "god",
    "bästsäljar": "bästsäljare",
    "bästsäljaren": "bästsäljare",
    "bästsäljarens": "bästsäljare",
    "bästsäljares": "bästsäljare",
    "bästsäljarna": "bästsäljare",
    "bästsäljarnas": "bästsäljare",
    "bättrad": "bättra",
    "bättrade": "bättra",
    "bättrades": "bättra",
    "bättrads": "bättra",
    "bättrande": "bättra",
    "bättranden": "bättrande",
    "bättrandena": "bättrande",
    "bättrandenas": "bättrande",
    "bättrandens": "bättrande",
    "bättrandes": "bättrande",
    "bättrandet": "bättrande",
    "bättrandets": "bättrande",
    "bättrar": "bättra",
    "bättras": "bättra",
    "bättrat": "bättra",
    "bättrats": "bättra",
    "bättre": "god",
    "bättres": "god",
    "bättringar": "bättring",
    "bättringarna": "bättring",
    "bättringarnas": "bättring",
    "bättringars": "bättring",
    "bättringen": "bättring",
    "bättringens": "bättring",
    "bättrings": "bättring",
    "bävade": "bäva",
    "bävades": "bäva",
    "bävande": "bäva",
    "bävanden": "bävande",
    "bävandena": "bävande",
    "bävandenas": "bävande",
    "bävandens": "bävande",
    "bävandes": "bävande",
    "bävandet": "bävande",
    "bävandets": "bävande",
    "bävans": "bävan",
    "bävar": "bäva",
    "bävas": "bäva",
    "bävat": "bäva",
    "bävats": "bäva",
    "bävergällen": "bävergäll",
    "bävergällens": "bävergäll",
    "bävergället": "bävergäll",
    "bävergällets": "bävergäll",
    "bävergälls": "bävergäll",
    "bävern": "bäver",
    "bäverns": "bäver",
    "bävernylonen": "bävernylon",
    "bävernylonens": "bävernylon",
    "bävernylonet": "bävernylon",
    "bävernylonets": "bävernylon",
    "bävernylonoverallen": "bävernylonoverall",
    "bävernylonoverallens": "bävernylonoverall",
    "bävernylonoveraller": "bävernylonoverall",
    "bävernylonoverallerna": "bävernylonoverall",
    "bävernylonoverallernas": "bävernylonoverall",
    "bävernylonoverallers": "bävernylonoverall",
    "bävernylonoveralls": "bävernylonoverall",
    "bävernylons": "bävernylon",
    "bäverrått": "bäverråtta",
    "bäverråttan": "bäverråtta",
    "bäverråttans": "bäverråtta",
    "bäverråttas": "bäverråtta",
    "bäverråtte": "bäverråtta",
    "bäverråttor": "bäverråtta",
    "bäverråttorna": "bäverråtta",
    "bäverråttornas": "bäverråtta",
    "bäverråttors": "bäverråtta",
    "bäverråtts": "bäverråtta",
    "bävers": "bäver",
    "bävningar": "bävning",
    "bävningarna": "bävning",
    "bävningarnas": "bävning",
    "bävningars": "bävning",
    "bävningen": "bävning",
    "bävningens": "bävning",
    "bävnings": "bävning",
    "bävrar": "bäver",
    "bävrarna": "bäver",
    "bävrarnas": "bäver",
    "bävrars": "bäver",
    "båd": "både",
    "bådade": "båda",
    "bådaderas": "bådadera",
    "bådades": "båda",
    "bådan": "båda",
    "bådande": "båda",
    "bådanden": "bådande",
    "bådandena": "bådande",
    "bådandenas": "bådande",
    "bådandens": "bådande",
    "bådandes": "bådande",
    "bådandet": "bådande",
    "bådandets": "bådande",
    "bådans": "båda",
    "bådar": "både",
    "bådarna": "både",
    "bådarnas": "både",
    "bådars": "både",
    "bådas": "båda",
    "bådat": "båda",
    "bådats": "båda",
    "både": "båda",
    "båden": "både",
    "bådens": "både",
    "bådes": "både",
    "bådor": "båda",
    "bådorna": "båda",
    "bådornas": "båda",
    "bådors": "båda",
    "båds": "både",
    "båg": "båge",
    "bågade": "båga",
    "bågades": "båga",
    "bågande": "båga",
    "båganden": "bågande",
    "bågandena": "bågande",
    "bågandenas": "bågande",
    "bågandens": "bågande",
    "bågandes": "bågande",
    "bågandet": "bågande",
    "bågandets": "bågande",
    "bågar": "båge",
    "bågarna": "båge",
    "bågarnas": "båge",
    "bågars": "båge",
    "bågas": "båga",
    "bågat": "båga",
    "bågats": "båga",
    "bågbroar": "bågbro",
    "bågbroarna": "bågbro",
    "bågbroarnas": "bågbro",
    "bågbroars": "bågbro",
    "bågbron": "bågbro",
    "bågbrons": "bågbro",
    "bågbros": "bågbro",
    "bågen": "båge",
    "bågens": "båge",
    "båges": "båge",
    "båget": "båg",
    "bågets": "båg",
    "bågfilar": "bågfil",
    "bågfilarna": "bågfil",
    "bågfilarnas": "bågfil",
    "bågfilars": "bågfil",
    "bågfilen": "bågfil",
    "bågfilens": "bågfil",
    "bågfils": "bågfil",
    "bågformade": "bågformad",
    "bågformades": "bågformad",
    "bågformads": "bågformad",
    "bågformat": "bågformad",
    "bågformats": "bågformad",
    "bågformiga": "bågformig",
    "bågformigare": "bågformig",
    "bågformigares": "bågformig",
    "bågformigas": "bågformig",
    "bågformigast": "bågformig",
    "bågformigaste": "bågformig",
    "bågformigastes": "bågformig",
    "bågformigasts": "bågformig",
    "bågformige": "bågformig",
    "bågformiges": "bågformig",
    "bågformigheten": "bågformighet",
    "bågformighetens": "bågformighet",
    "bågformighets": "bågformighet",
    "bågformigs": "bågformig",
    "bågformigt": "bågformig",
    "bågformigts": "bågformig",
    "bågfrisen": "bågfris",
    "bågfrisens": "bågfris",
    "bågfriser": "bågfris",
    "bågfriserna": "bågfris",
    "bågfrisernas": "bågfris",
    "bågfrisers": "bågfris",
    "bågfälten": "bågfält",
    "bågfältens": "bågfält",
    "bågfältet": "bågfält",
    "bågfältets": "bågfält",
    "bågfälts": "bågfält",
    "bågfönsterna": "bågfönster",
    "bågfönsternas": "bågfönster",
    "bågfönsters": "bågfönster",
    "bågfönstren": "bågfönster",
    "bågfönstrens": "bågfönster",
    "bågfönstret": "bågfönster",
    "bågfönstrets": "bågfönster",
    "båggångar": "båggång",
    "båggångarna": "båggång",
    "båggångarnas": "båggång",
    "båggångars": "båggång",
    "båggången": "båggång",
    "båggångens": "båggång",
    "båggångs": "båggång",
    "bågiga": "bågig",
    "bågigare": "bågig",
    "bågigares": "bågig",
    "bågigas": "bågig",
    "bågigast": "bågig",
    "bågigaste": "bågig",
    "bågigastes": "bågig",
    "bågigasts": "bågig",
    "bågige": "bågig",
    "bågiges": "bågig",
    "bågigs": "bågig",
    "bågigt": "bågig",
    "bågigts": "bågig",
    "båglamp": "båglampa",
    "båglampan": "båglampa",
    "båglampans": "båglampa",
    "båglampas": "båglampa",
    "båglampe": "båglampa",
    "båglampor": "båglampa",
    "båglamporna": "båglampa",
    "båglampornas": "båglampa",
    "båglampors": "båglampa",
    "båglamps": "båglampa",
    "bågljuset": "bågljus",
    "bågljusets": "bågljus",
    "bågminuten": "bågminut",
    "bågminutens": "bågminut",
    "bågminuter": "bågminut",
    "bågminuterna": "bågminut",
    "bågminuternas": "bågminut",
    "bågminuters": "bågminut",
    "bågminuts": "bågminut",
    "bågn": "bågna",
    "bågnad": "bågna",
    "bågnade": "bågna",
    "bågnades": "bågna",
    "bågnads": "bågna",
    "bågnande": "bågna",
    "bågnanden": "bågnande",
    "bågnandena": "bågnande",
    "bågnandenas": "bågnande",
    "bågnandens": "bågnande",
    "bågnandes": "bågnande",
    "bågnandet": "bågnande",
    "bågnandets": "bågnande",
    "bågnar": "bågna",
    "bågnas": "bågna",
    "bågnat": "bågna",
    "bågnats": "bågna",
    "bågs": "båge",
    "bågsekunden": "bågsekund",
    "bågsekundens": "bågsekund",
    "bågsekunder": "bågsekund",
    "bågsekunderna": "bågsekund",
    "bågsekundernas": "bågsekund",
    "bågsekunders": "bågsekund",
    "bågsekunds": "bågsekund",
    "bågskyttar": "bågskytt",
    "bågskyttarna": "bågskytt",
    "bågskyttarnas": "bågskytt",
    "bågskyttars": "bågskytt",
    "bågskyttefälten": "bågskyttefält",
    "bågskyttefältens": "bågskyttefält",
    "bågskyttefältet": "bågskyttefält",
    "bågskyttefältets": "bågskyttefält",
    "bågskyttefälts": "bågskyttefält",
    "bågskytten": "bågskytt",
    "bågskyttens": "bågskytt",
    "bågskyttes": "bågskytte",
    "bågskyttet": "bågskytte",
    "bågskyttets": "bågskytte",
    "bågskytts": "bågskytt",
    "bågsvetsningar": "bågsvetsning",
    "bågsvetsningarna": "bågsvetsning",
    "bågsvetsningarnas": "bågsvetsning",
    "bågsvetsningars": "bågsvetsning",
    "bågsvetsningen": "bågsvetsning",
    "bågsvetsningens": "bågsvetsning",
    "bågsvetsnings": "bågsvetsning",
    "bågsågar": "bågsåg",
    "bågsågarna": "bågsåg",
    "bågsågarnas": "bågsåg",
    "bågsågars": "bågsåg",
    "bågsågen": "bågsåg",
    "bågsågens": "bågsåg",
    "bågsågs": "bågsåg",
    "båkar": "båk",
    "båkarna": "båk",
    "båkarnas": "båk",
    "båkars": "båk",
    "båken": "båk",
    "båkens": "båk",
    "båks": "båk",
    "bålar": "bål",
    "bålarna": "bål",
    "bålarnas": "bål",
    "bålars": "bål",
    "bålda": "båld",
    "båldare": "båld",
    "båldares": "båld",
    "båldas": "båld",
    "båldast": "båld",
    "båldaste": "båld",
    "båldastes": "båld",
    "båldasts": "båld",
    "bålde": "båld",
    "båldes": "båld",
    "båldheten": "båldhet",
    "båldhetens": "båldhet",
    "båldhets": "båldhet",
    "bålds": "båld",
    "bålen": "bål",
    "bålens": "bål",
    "bålet": "bål",
    "bålets": "bål",
    "bålgetingar": "bålgeting",
    "bålgetingarna": "bålgeting",
    "bålgetingarnas": "bålgeting",
    "bålgetingars": "bålgeting",
    "bålgetingen": "bålgeting",
    "bålgetingens": "bålgeting",
    "bålgetings": "bålgeting",
    "bålrullningar": "bålrullning",
    "bålrullningarna": "bålrullning",
    "bålrullningarnas": "bålrullning",
    "bålrullningars": "bålrullning",
    "bålrullningen": "bålrullning",
    "bålrullningens": "bålrullning",
    "bålrullnings": "bålrullning",
    "båls": "bål",
    "bålt": "båld",
    "bålts": "båld",
    "bålverken": "bålverk",
    "bålverkens": "bålverk",
    "bålverket": "bålverk",
    "bålverkets": "bålverk",
    "bålverks": "bålverk",
    "bålväxten": "bålväxt",
    "bålväxtens": "bålväxt",
    "bålväxter": "bålväxt",
    "bålväxterna": "bålväxt",
    "bålväxternas": "bålväxt",
    "bålväxters": "bålväxt",
    "bålväxts": "bålväxt",
    "bångstyriga": "bångstyrig",
    "bångstyrigare": "bångstyrig",
    "bångstyrigares": "bångstyrig",
    "bångstyrigas": "bångstyrig",
    "bångstyrigast": "bångstyrig",
    "bångstyrigaste": "bångstyrig",
    "bångstyrigastes": "bångstyrig",
    "bångstyrigasts": "bångstyrig",
    "bångstyrige": "bångstyrig",
    "bångstyriges": "bångstyrig",
    "bångstyrigheten": "bångstyrighet",
    "bångstyrighetens": "bångstyrighet",
    "bångstyrighets": "bångstyrighet",
    "bångstyrigs": "bångstyrig",
    "bångstyrigt": "bångstyrig",
    "bångstyrigts": "bångstyrig",
    "bårar": "bår",
    "bårarna": "bår",
    "bårarnas": "bår",
    "bårars": "bår",
    "bårbärar": "bårbärare",
    "bårbäraren": "bårbärare",
    "bårbärarens": "bårbärare",
    "bårbärares": "bårbärare",
    "bårbärarna": "bårbärare",
    "bårbärarnas": "bårbärare",
    "bården": "bård",
    "bårdens": "bård",
    "bårder": "bård",
    "bårderna": "bård",
    "bårdernas": "bård",
    "bårders": "bård",
    "bårds": "bård",
    "båren": "bår",
    "bårens": "bår",
    "bårhusen": "bårhus",
    "bårhusens": "bårhus",
    "bårhuset": "bårhus",
    "bårhusets": "bårhus",
    "bårs": "bår",
    "båsen": "bås",
    "båsens": "bås",
    "båset": "bås",
    "båsets": "bås",
    "båtade": "båta",
    "båtades": "båta",
    "båtande": "båta",
    "båtanden": "båtande",
    "båtandena": "båtande",
    "båtandenas": "båtande",
    "båtandens": "båtande",
    "båtandes": "båtande",
    "båtandet": "båtande",
    "båtandets": "båtande",
    "båtankomsten": "båtankomst",
    "båtankomstens": "båtankomst",
    "båtankomster": "båtankomst",
    "båtankomsterna": "båtankomst",
    "båtankomsternas": "båtankomst",
    "båtankomsters": "båtankomst",
    "båtankomsts": "båtankomst",
    "båtar": "båta",
    "båtarna": "båt",
    "båtarnas": "båt",
    "båtars": "båt",
    "båtas": "båta",
    "båtat": "båta",
    "båtats": "båta",
    "båtavgångar": "båtavgång",
    "båtavgångarna": "båtavgång",
    "båtavgångarnas": "båtavgång",
    "båtavgångars": "båtavgång",
    "båtavgången": "båtavgång",
    "båtavgångens": "båtavgång",
    "båtavgångs": "båtavgång",
    "båtbenen": "båtben",
    "båtbenens": "båtben",
    "båtbenet": "båtben",
    "båtbenets": "båtben",
    "båtbens": "båtben",
    "båtbottens": "båtbotten",
    "båtbottnar": "båtbotten",
    "båtbottnarna": "båtbotten",
    "båtbottnarnas": "båtbotten",
    "båtbottnars": "båtbotten",
    "båtbottnen": "båtbotten",
    "båtbottnens": "båtbotten",
    "båtbrygg": "båtbrygga",
    "båtbryggan": "båtbrygga",
    "båtbryggans": "båtbrygga",
    "båtbryggas": "båtbrygga",
    "båtbrygge": "båtbrygga",
    "båtbryggor": "båtbrygga",
    "båtbryggorna": "båtbrygga",
    "båtbryggornas": "båtbrygga",
    "båtbryggors": "båtbrygga",
    "båtbryggs": "båtbrygga",
    "båtbyggar": "båtbyggare",
    "båtbyggaren": "båtbyggare",
    "båtbyggarens": "båtbyggare",
    "båtbyggares": "båtbyggare",
    "båtbyggarna": "båtbyggare",
    "båtbyggarnas": "båtbyggare",
    "båtbyggerier": "båtbyggeri",
    "båtbyggerierna": "båtbyggeri",
    "båtbyggeriernas": "båtbyggeri",
    "båtbyggeriers": "båtbyggeri",
    "båtbyggeriet": "båtbyggeri",
    "båtbyggeriets": "båtbyggeri",
    "båtbyggeris": "båtbyggeri",
    "båtbyggerit": "båtbyggeri",
    "båtbyggerits": "båtbyggeri",
    "båtdäcken": "båtdäck",
    "båtdäckens": "båtdäck",
    "båtdäcket": "båtdäck",
    "båtdäckets": "båtdäck",
    "båtdäcks": "båtdäck",
    "båten": "båt",
    "båtens": "båt",
    "båtformiga": "båtformig",
    "båtformigare": "båtformig",
    "båtformigares": "båtformig",
    "båtformigas": "båtformig",
    "båtformigast": "båtformig",
    "båtformigaste": "båtformig",
    "båtformigastes": "båtformig",
    "båtformigasts": "båtformig",
    "båtformige": "båtformig",
    "båtformiges": "båtformig",
    "båtformigs": "båtformig",
    "båtformigt": "båtformig",
    "båtformigts": "båtformig",
    "båtgravar": "båtgrav",
    "båtgravarna": "båtgrav",
    "båtgravarnas": "båtgrav",
    "båtgravars": "båtgrav",
    "båtgraven": "båtgrav",
    "båtgravens": "båtgrav",
    "båtgravs": "båtgrav",
    "båthusen": "båthus",
    "båthusens": "båthus",
    "båthuset": "båthus",
    "båthusets": "båthus",
    "båtklubbar": "båtklubb",
    "båtklubbarna": "båtklubb",
    "båtklubbarnas": "båtklubb",
    "båtklubbars": "båtklubb",
    "båtklubben": "båtklubb",
    "båtklubbens": "båtklubb",
    "båtklubbs": "båtklubb",
    "båtlägenheten": "båtlägenhet",
    "båtlägenhetens": "båtlägenhet",
    "båtlägenheter": "båtlägenhet",
    "båtlägenheterna": "båtlägenhet",
    "båtlägenheternas": "båtlägenhet",
    "båtlägenheters": "båtlägenhet",
    "båtlägenhets": "båtlägenhet",
    "båtmotorer": "båtmotor",
    "båtmotorerna": "båtmotor",
    "båtmotorernas": "båtmotor",
    "båtmotorers": "båtmotor",
    "båtmotorn": "båtmotor",
    "båtmotorns": "båtmotor",
    "båtmotors": "båtmotor",
    "båtmäss": "båtmässa",
    "båtmässan": "båtmässa",
    "båtmässans": "båtmässa",
    "båtmässas": "båtmässa",
    "båtmässe": "båtmässa",
    "båtmässor": "båtmässa",
    "båtmässorna": "båtmässa",
    "båtmässornas": "båtmässa",
    "båtmässors": "båtmässa",
    "båtmöss": "båtmössa",
    "båtmössan": "båtmössa",
    "båtmössans": "båtmössa",
    "båtmössas": "båtmössa",
    "båtmösse": "båtmössa",
    "båtmössor": "båtmössa",
    "båtmössorna": "båtmössa",
    "båtmössornas": "båtmössa",
    "båtmössors": "båtmössa",
    "båtnaden": "båtnad",
    "båtnadens": "båtnad",
    "båtnader": "båtnad",
    "båtnaderna": "båtnad",
    "båtnadernas": "båtnad",
    "båtnaders": "båtnad",
    "båtnads": "båtnad",
    "båtplatsen": "båtplats",
    "båtplatsens": "båtplats",
    "båtplatser": "båtplats",
    "båtplatserna": "båtplats",
    "båtplatsernas": "båtplats",
    "båtplatsers": "båtplats",
    "båtresan": "båtresa",
    "båtresans": "båtresa",
    "båtresas": "båtresa",
    "båtrese": "båtresa",
    "båtresor": "båtresa",
    "båtresorna": "båtresa",
    "båtresornas": "båtresa",
    "båtresors": "båtresa",
    "båts": "båt",
    "båtshakar": "båtshake",
    "båtshakarna": "båtshake",
    "båtshakarnas": "båtshake",
    "båtshakars": "båtshake",
    "båtshaken": "båtshake",
    "båtshakens": "båtshake",
    "båtshakes": "båtshake",
    "båtskjulen": "båtskjul",
    "båtskjulens": "båtskjul",
    "båtskjulet": "båtskjul",
    "båtskjulets": "båtskjul",
    "båtskjuls": "båtskjul",
    "båtskråen": "båtskrå",
    "båtskråens": "båtskrå",
    "båtskrået": "båtskrå",
    "båtskråets": "båtskrå",
    "båtskrån": "båtskrå",
    "båtskråna": "båtskrå",
    "båtskrånas": "båtskrå",
    "båtskråns": "båtskrå",
    "båtskrås": "båtskrå",
    "båtskråt": "båtskrå",
    "båtskråts": "båtskrå",
    "båtsmannen": "båtsman",
    "båtsmannens": "båtsman",
    "båtsmans": "båtsman",
    "båtsmansstolar": "båtsmansstol",
    "båtsmansstolarna": "båtsmansstol",
    "båtsmansstolarnas": "båtsmansstol",
    "båtsmansstolars": "båtsmansstol",
    "båtsmansstolen": "båtsmansstol",
    "båtsmansstolens": "båtsmansstol",
    "båtsmansstols": "båtsmansstol",
    "båtsmän": "båtsman",
    "båtsmännen": "båtsman",
    "båtsmännens": "båtsman",
    "båtsmäns": "båtsman",
    "båtterminalen": "båtterminal",
    "båtterminalens": "båtterminal",
    "båtterminaler": "båtterminal",
    "båtterminalerna": "båtterminal",
    "båtterminalernas": "båtterminal",
    "båtterminalers": "båtterminal",
    "båtterminals": "båtterminal",
    "båttidtabellen": "båttidtabell",
    "båttidtabellens": "båttidtabell",
    "båttidtabeller": "båttidtabell",
    "båttidtabellerna": "båttidtabell",
    "båttidtabellernas": "båttidtabell",
    "båttidtabellers": "båttidtabell",
    "båttidtabells": "båttidtabell",
    "båttrafiken": "båttrafik",
    "båttrafikens": "båttrafik",
    "båttrafiks": "båttrafik",
    "båttransporten": "båttransport",
    "båttransportens": "båttransport",
    "båttransporter": "båttransport",
    "båttransporterna": "båttransport",
    "båttransporternas": "båttransport",
    "båttransporters": "båttransport",
    "båttransports": "båttransport",
    "båtturen": "båttur",
    "båtturens": "båttur",
    "båtturer": "båttur",
    "båtturerna": "båttur",
    "båtturernas": "båttur",
    "båtturers": "båttur",
    "båtturs": "båttur",
    "båttävlingar": "båttävling",
    "båttävlingarna": "båttävling",
    "båttävlingarnas": "båttävling",
    "båttävlingars": "båttävling",
    "båttävlingen": "båttävling",
    "båttävlingens": "båttävling",
    "båttävlings": "båttävling",
    "båtvården": "båtvård",
    "båtvårdens": "båtvård",
    "båtvårds": "båtvård",
    "båtvårdsmedels": "båtvårdsmedel",
    "båtvårdsmedlen": "båtvårdsmedel",
    "båtvårdsmedlens": "båtvårdsmedel",
    "båtvårdsmedlet": "båtvårdsmedel",
    "båtvårdsmedlets": "båtvårdsmedel",
    "båtyx": "båtyxa",
    "båtyxan": "båtyxa",
    "båtyxans": "båtyxa",
    "båtyxas": "båtyxa",
    "båtyxe": "båtyxa",
    "båtyxor": "båtyxa",
    "båtyxorna": "båtyxa",
    "båtyxornas": "båtyxa",
    "båtyxors": "båtyxa",
    "béarnaisen": "béarnaise",
    "béarnaisens": "béarnaise",
    "béarnaiser": "béarnaise",
    "béarnaiserna": "béarnaise",
    "béarnaisernas": "béarnaise",
    "béarnaisers": "béarnaise",
    "béarnaises": "béarnaise",
    "béarnaisesåsen": "béarnaisesås",
    "béarnaisesåsens": "béarnaisesås",
    "béarnaisesåser": "béarnaisesås",
    "béarnaisesåserna": "béarnaisesås",
    "béarnaisesåsernas": "béarnaisesås",
    "béarnaisesåsers": "béarnaisesås",
    "böcker": "bok",
    "böckerna": "bok",
    "böckernas": "bok",
    "böckers": "bok",
    "böcklingar": "böckling",
    "böcklingarna": "böckling",
    "böcklingarnas": "böckling",
    "böcklingars": "böckling",
    "böcklingen": "böckling",
    "böcklingens": "böckling",
    "böcklings": "böckling",
    "bödeln": "bödel",
    "bödelns": "bödel",
    "bödels": "bödel",
    "bödelsdrängar": "bödelsdräng",
    "bödelsdrängarna": "bödelsdräng",
    "bödelsdrängarnas": "bödelsdräng",
    "bödelsdrängars": "bödelsdräng",
    "bödelsdrängen": "bödelsdräng",
    "bödelsdrängens": "bödelsdräng",
    "bödelsdrängs": "bödelsdräng",
    "bödlar": "bödel",
    "bödlarna": "bödel",
    "bödlarnas": "bödel",
    "bödlars": "bödel",
    "bögar": "bög",
    "bögarna": "bög",
    "bögarnas": "bög",
    "bögars": "bög",
    "bögdöden": "bögdöd",
    "bögdödens": "bögdöd",
    "bögdöds": "bögdöd",
    "bögen": "bög",
    "bögens": "bög",
    "bögs": "bög",
    "böhmar": "böhmare",
    "böhmaren": "böhmare",
    "böhmarens": "böhmare",
    "böhmares": "böhmare",
    "böhmarna": "böhmare",
    "böhmarnas": "böhmare",
    "böhmiska": "böhmisk",
    "böhmiskare": "böhmisk",
    "böhmiskares": "böhmisk",
    "böhmiskas": "böhmisk",
    "böhmiskast": "böhmisk",
    "böhmiskaste": "böhmisk",
    "böhmiskastes": "böhmisk",
    "böhmiskasts": "böhmisk",
    "böhmiske": "böhmisk",
    "böhmiskes": "böhmisk",
    "böhmisks": "böhmisk",
    "böhmiskt": "böhmisk",
    "böhmiskts": "böhmisk",
    "böj": "böja",
    "böjande": "böja",
    "böjanden": "böjande",
    "böjandena": "böjande",
    "böjandenas": "böjande",
    "böjandens": "böjande",
    "böjandes": "böjande",
    "böjandet": "böjande",
    "böjandets": "böjande",
    "böjar": "böjare",
    "böjaren": "böjare",
    "böjarens": "böjare",
    "böjares": "böjare",
    "böjarmuskeln": "böjarmuskel",
    "böjarmuskelns": "böjarmuskel",
    "böjarmuskels": "böjarmuskel",
    "böjarmuskler": "böjarmuskel",
    "böjarmusklerna": "böjarmuskel",
    "böjarmusklernas": "böjarmuskel",
    "böjarmusklers": "böjarmuskel",
    "böjarna": "böjare",
    "böjarnas": "böjare",
    "böjars": "böj",
    "böjas": "böja",
    "böjbara": "böjbar",
    "böjbarare": "böjbar",
    "böjbarares": "böjbar",
    "böjbaras": "böjbar",
    "böjbarast": "böjbar",
    "böjbaraste": "böjbar",
    "böjbarastes": "böjbar",
    "böjbarasts": "böjbar",
    "böjbare": "böjbar",
    "böjbares": "böjbar",
    "böjbarheten": "böjbarhet",
    "böjbarhetens": "böjbarhet",
    "böjbarhets": "böjbarhet",
    "böjbars": "böjbar",
    "böjbart": "böjbar",
    "böjbarts": "böjbar",
    "böjd": "böja",
    "böjda": "böjd",
    "böjdare": "böjd",
    "böjdares": "böjd",
    "böjdas": "böjd",
    "böjdast": "böjd",
    "böjdaste": "böjd",
    "böjdastes": "böjd",
    "böjdasts": "böjd",
    "böjde": "böjd",
    "böjdes": "böjd",
    "böjdheten": "böjdhet",
    "böjdhetens": "böjdhet",
    "böjdhets": "böjdhet",
    "böjds": "böjd",
    "böjelsen": "böjelse",
    "böjelsens": "böjelse",
    "böjelser": "böjelse",
    "böjelserna": "böjelse",
    "böjelsernas": "böjelse",
    "böjelsers": "böjelse",
    "böjelses": "böjelse",
    "böjen": "böj",
    "böjens": "böj",
    "böjer": "böja",
    "böjes": "böja",
    "böjhållfastheten": "böjhållfasthet",
    "böjhållfasthetens": "böjhållfasthet",
    "böjhållfastheter": "böjhållfasthet",
    "böjhållfastheterna": "böjhållfasthet",
    "böjhållfastheternas": "böjhållfasthet",
    "böjhållfastheters": "böjhållfasthet",
    "böjhållfasthets": "böjhållfasthet",
    "böjliga": "böjlig",
    "böjligare": "böjlig",
    "böjligares": "böjlig",
    "böjligas": "böjlig",
    "böjligast": "böjlig",
    "böjligaste": "böjlig",
    "böjligastes": "böjlig",
    "böjligasts": "böjlig",
    "böjlige": "böjlig",
    "böjliges": "böjlig",
    "böjligheten": "böjlighet",
    "böjlighetens": "böjlighet",
    "böjlighets": "böjlighet",
    "böjligs": "böjlig",
    "böjligt": "böjlig",
    "böjligts": "böjlig",
    "böjmuskeln": "böjmuskel",
    "böjmuskelns": "böjmuskel",
    "böjmuskels": "böjmuskel",
    "böjmuskler": "böjmuskel",
    "böjmusklerna": "böjmuskel",
    "böjmusklernas": "böjmuskel",
    "böjmusklers": "böjmuskel",
    "böjningar": "böjning",
    "böjningarna": "böjning",
    "böjningarnas": "böjning",
    "böjningars": "böjning",
    "böjningen": "böjning",
    "böjningens": "böjning",
    "böjnings": "böjning",
    "böjningsformen": "böjningsform",
    "böjningsformens": "böjningsform",
    "böjningsformer": "böjningsform",
    "böjningsformerna": "böjningsform",
    "böjningsformernas": "böjningsform",
    "böjningsformers": "böjningsform",
    "böjningsforms": "böjningsform",
    "böjningsmönsterna": "böjningsmönster",
    "böjningsmönsternas": "böjningsmönster",
    "böjningsmönsters": "böjningsmönster",
    "böjningsmönstren": "böjningsmönster",
    "böjningsmönstrens": "böjningsmönster",
    "böjningsmönstret": "böjningsmönster",
    "böjningsmönstrets": "böjningsmönster",
    "böjningsändelsen": "böjningsändelse",
    "böjningsändelsens": "böjningsändelse",
    "böjningsändelser": "böjningsändelse",
    "böjningsändelserna": "böjningsändelse",
    "böjningsändelsernas": "böjningsändelse",
    "böjningsändelsers": "böjningsändelse",
    "böjningsändelses": "böjningsändelse",
    "böjproven": "böjprov",
    "böjprovens": "böjprov",
    "böjprovet": "böjprov",
    "böjprovets": "böjprov",
    "böjprovs": "böjprov",
    "böjs": "böja",
    "böjt": "böjd",
    "böjträet": "böjträ",
    "böjträets": "böjträ",
    "böjträs": "böjträ",
    "böjträt": "böjträ",
    "böjträts": "böjträ",
    "böjts": "böjd",
    "bök": "böka",
    "bökade": "böka",
    "bökades": "böka",
    "bökande": "böka",
    "bökanden": "bökande",
    "bökandena": "bökande",
    "bökandenas": "bökande",
    "bökandens": "bökande",
    "bökandes": "bökande",
    "bökandet": "bökande",
    "bökandets": "bökande",
    "bökar": "böka",
    "bökas": "böka",
    "bökat": "böka",
    "bökats": "böka",
    "böket": "bök",
    "bökets": "bök",
    "bökiga": "bökig",
    "bökigare": "bökig",
    "bökigares": "bökig",
    "bökigas": "bökig",
    "bökigast": "bökig",
    "bökigaste": "bökig",
    "bökigastes": "bökig",
    "bökigasts": "bökig",
    "bökige": "bökig",
    "bökiges": "bökig",
    "bökigs": "bökig",
    "bökigt": "bökig",
    "bökigts": "bökig",
    "böks": "bök",
    "böl": "böla",
    "bölade": "böla",
    "bölades": "böla",
    "bölande": "böla",
    "bölanden": "bölande",
    "bölandena": "bölande",
    "bölandenas": "bölande",
    "bölandens": "bölande",
    "bölandes": "bölande",
    "bölandet": "bölande",
    "bölandets": "bölande",
    "bölar": "böla",
    "bölas": "böla",
    "bölat": "böla",
    "bölats": "böla",
    "bölden": "böld",
    "böldens": "böld",
    "bölder": "böld",
    "bölderna": "böld",
    "böldernas": "böld",
    "bölders": "böld",
    "böldpesten": "böldpest",
    "böldpestens": "böldpest",
    "böldpests": "böldpest",
    "bölds": "böld",
    "bölet": "böl",
    "bölets": "böl",
    "bölj": "bölja",
    "böljade": "bölja",
    "böljades": "bölja",
    "böljan": "bölja",
    "böljande": "bölja",
    "böljanden": "böljande",
    "böljandena": "böljande",
    "böljandenas": "böljande",
    "böljandens": "böljande",
    "böljandes": "böljande",
    "böljandet": "böljande",
    "böljandets": "böljande",
    "böljans": "bölja",
    "böljar": "bölja",
    "böljas": "bölja",
    "böljat": "bölja",
    "böljats": "bölja",
    "bölje": "bölja",
    "böljegångar": "böljegång",
    "böljegångarna": "böljegång",
    "böljegångarnas": "böljegång",
    "böljegångars": "böljegång",
    "böljegången": "böljegång",
    "böljegångens": "böljegång",
    "böljegångs": "böljegång",
    "böljeslagen": "böljeslag",
    "böljeslagens": "böljeslag",
    "böljeslaget": "böljeslag",
    "böljeslagets": "böljeslag",
    "böljeslags": "böljeslag",
    "böljeslagsmärken": "böljeslagsmärke",
    "böljeslagsmärkena": "böljeslagsmärke",
    "böljeslagsmärkenas": "böljeslagsmärke",
    "böljeslagsmärkens": "böljeslagsmärke",
    "böljeslagsmärkes": "böljeslagsmärke",
    "böljeslagsmärket": "böljeslagsmärke",
    "böljeslagsmärkets": "böljeslagsmärke",
    "böljor": "bölja",
    "böljorna": "bölja",
    "böljornas": "bölja",
    "böljors": "bölja",
    "böls": "böl",
    "bön": "böna",
    "bönade": "böna",
    "bönades": "böna",
    "bönan": "böna",
    "bönande": "böna",
    "bönanden": "bönande",
    "bönandena": "bönande",
    "bönandenas": "bönande",
    "bönandens": "bönande",
    "bönandes": "bönande",
    "bönandet": "bönande",
    "bönandets": "bönande",
    "bönans": "böna",
    "bönar": "böna",
    "bönas": "böna",
    "bönat": "böna",
    "bönats": "böna",
    "bönboken": "bönbok",
    "bönbokens": "bönbok",
    "bönboks": "bönbok",
    "bönböcker": "bönbok",
    "bönböckerna": "bönbok",
    "bönböckernas": "bönbok",
    "bönböckers": "bönbok",
    "böndagar": "böndag",
    "böndagarna": "böndag",
    "böndagarnas": "böndag",
    "böndagars": "böndag",
    "böndagen": "böndag",
    "böndagens": "böndag",
    "böndags": "böndag",
    "bönder": "bonde",
    "bönderna": "bonde",
    "böndernas": "bonde",
    "bönders": "bonde",
    "böne": "böna",
    "böneanropen": "böneanrop",
    "böneanropens": "böneanrop",
    "böneanropet": "böneanrop",
    "böneanropets": "böneanrop",
    "böneanrops": "böneanrop",
    "bönegudstjänsten": "bönegudstjänst",
    "bönegudstjänstens": "bönegudstjänst",
    "bönegudstjänster": "bönegudstjänst",
    "bönegudstjänsterna": "bönegudstjänst",
    "bönegudstjänsternas": "bönegudstjänst",
    "bönegudstjänsters": "bönegudstjänst",
    "bönegudstjänsts": "bönegudstjänst",
    "bönehusen": "bönehus",
    "bönehusens": "bönehus",
    "bönehuset": "bönehus",
    "bönehusets": "bönehus",
    "bönemannen": "böneman",
    "bönemannens": "böneman",
    "bönemans": "böneman",
    "bönematt": "bönematta",
    "bönemattan": "bönematta",
    "bönemattans": "bönematta",
    "bönemattas": "bönematta",
    "bönematte": "bönematta",
    "bönemattor": "bönematta",
    "bönemattorna": "bönematta",
    "bönemattornas": "bönematta",
    "bönemattors": "bönematta",
    "bönematts": "bönematta",
    "bönemän": "böneman",
    "bönemännen": "böneman",
    "bönemännens": "böneman",
    "bönemäns": "böneman",
    "bönemöten": "bönemöte",
    "bönemötena": "bönemöte",
    "bönemötenas": "bönemöte",
    "bönemötens": "bönemöte",
    "bönemötes": "bönemöte",
    "bönemötet": "bönemöte",
    "bönemötets": "bönemöte",
    "bönen": "bön",
    "bönens": "bön",
    "böner": "bön",
    "bönerna": "bön",
    "bönernas": "bön",
    "böners": "bön",
    "bönesalar": "bönesal",
    "bönesalarna": "bönesal",
    "bönesalarnas": "bönesal",
    "bönesalars": "bönesal",
    "bönesalen": "bönesal",
    "bönesalens": "bönesal",
    "bönesals": "bönesal",
    "böneskriften": "böneskrift",
    "böneskriftens": "böneskrift",
    "böneskrifter": "böneskrift",
    "böneskrifterna": "böneskrift",
    "böneskrifternas": "böneskrift",
    "böneskrifters": "böneskrift",
    "böneskrifts": "böneskrift",
    "böneutropar": "böneutropare",
    "böneutroparen": "böneutropare",
    "böneutroparens": "böneutropare",
    "böneutropares": "böneutropare",
    "böneutroparna": "böneutropare",
    "böneutroparnas": "böneutropare",
    "bönfall": "bönfalla",
    "bönfallande": "bönfalla",
    "bönfallanden": "bönfallande",
    "bönfallandena": "bönfallande",
    "bönfallandenas": "bönfallande",
    "bönfallandens": "bönfallande",
    "bönfallandes": "bönfallande",
    "bönfallandet": "bönfallande",
    "bönfallandets": "bönfallande",
    "bönfallas": "bönfalla",
    "bönfalle": "bönfalla",
    "bönfallen": "bönfalla",
    "bönfallens": "bönfalla",
    "bönfaller": "bönfalla",
    "bönfalles": "bönfalla",
    "bönfallet": "bönfalla",
    "bönfallets": "bönfalla",
    "bönfallit": "bönfalla",
    "bönfallits": "bönfalla",
    "bönfallna": "bönfalla",
    "bönfallnas": "bönfalla",
    "bönfallne": "bönfalla",
    "bönfallnes": "bönfalla",
    "bönfalls": "bönfalla",
    "bönformiga": "bönformig",
    "bönformigare": "bönformig",
    "bönformigares": "bönformig",
    "bönformigas": "bönformig",
    "bönformigast": "bönformig",
    "bönformigaste": "bönformig",
    "bönformigastes": "bönformig",
    "bönformigasts": "bönformig",
    "bönformige": "bönformig",
    "bönformiges": "bönformig",
    "bönformigs": "bönformig",
    "bönformigt": "bönformig",
    "bönformigts": "bönformig",
    "bönföll": "bönfalla",
    "bönfölle": "bönfalla",
    "bönfölles": "bönfalla",
    "bönfölls": "bönfalla",
    "bönhasar": "bönhas",
    "bönhasarna": "bönhas",
    "bönhasarnas": "bönhas",
    "bönhasars": "bönhas",
    "bönhasen": "bönhas",
    "bönhasens": "bönhas",
    "bönhör": "bönhöra",
    "bönhörande": "bönhöra",
    "bönhöranden": "bönhörande",
    "bönhörandena": "bönhörande",
    "bönhörandenas": "bönhörande",
    "bönhörandens": "bönhörande",
    "bönhörandes": "bönhörande",
    "bönhörandet": "bönhörande",
    "bönhörandets": "bönhörande",
    "bönhöras": "bönhöra",
    "bönhörd": "bönhöra",
    "bönhörda": "bönhöra",
    "bönhördas": "bönhöra",
    "bönhörde": "bönhöra",
    "bönhördes": "bönhöra",
    "bönhörds": "bönhöra",
    "bönhörelsen": "bönhörelse",
    "bönhörelsens": "bönhörelse",
    "bönhörelser": "bönhörelse",
    "bönhörelserna": "bönhörelse",
    "bönhörelsernas": "bönhörelse",
    "bönhörelsers": "bönhörelse",
    "bönhörelses": "bönhörelse",
    "bönhöres": "bönhöra",
    "bönhörs": "bönhöra",
    "bönhört": "bönhöra",
    "bönhörts": "bönhöra",
    "bönkaffes": "bönkaffe",
    "bönkaffet": "bönkaffe",
    "bönkaffets": "bönkaffe",
    "bönor": "böna",
    "bönorna": "böna",
    "bönornas": "böna",
    "bönors": "böna",
    "bönpallar": "bönpall",
    "bönpallarna": "bönpall",
    "bönpallarnas": "bönpall",
    "bönpallars": "bönpall",
    "bönpallen": "bönpall",
    "bönpallens": "bönpall",
    "bönpalls": "bönpall",
    "böns": "böna",
    "bönskid": "bönskida",
    "bönskidan": "bönskida",
    "bönskidans": "bönskida",
    "bönskidas": "bönskida",
    "bönskide": "bönskida",
    "bönskidor": "bönskida",
    "bönskidorna": "bönskida",
    "bönskidornas": "bönskida",
    "bönskidors": "bönskida",
    "bönskids": "bönskida",
    "bönväxten": "bönväxt",
    "bönväxtens": "bönväxt",
    "bönväxter": "bönväxt",
    "bönväxterna": "bönväxt",
    "bönväxternas": "bönväxt",
    "bönväxters": "bönväxt",
    "bönväxts": "bönväxt",
    "bör": "böra",
    "börande": "böra",
    "böranden": "börande",
    "börandena": "börande",
    "börandenas": "börande",
    "börandens": "börande",
    "börandes": "börande",
    "börandet": "börande",
    "börandets": "börande",
    "böras": "böra",
    "bördan": "börda",
    "bördans": "börda",
    "bördas": "börda",
    "börde": "börda",
    "börden": "börd",
    "bördens": "börd",
    "bördiga": "bördig",
    "bördigare": "bördig",
    "bördigares": "bördig",
    "bördigas": "bördig",
    "bördigast": "bördig",
    "bördigaste": "bördig",
    "bördigastes": "bördig",
    "bördigasts": "bördig",
    "bördige": "bördig",
    "bördiges": "bördig",
    "bördigheten": "bördighet",
    "bördighetens": "bördighet",
    "bördighets": "bördighet",
    "bördigs": "bördig",
    "bördigt": "bördig",
    "bördigts": "bördig",
    "bördor": "börda",
    "bördorna": "börda",
    "bördornas": "börda",
    "bördors": "börda",
    "börds": "börd",
    "bördsadeln": "bördsadel",
    "bördsadelns": "bördsadel",
    "bördsadels": "bördsadel",
    "bördshögfärden": "bördshögfärd",
    "bördshögfärdens": "bördshögfärd",
    "bördshögfärds": "bördshögfärd",
    "bördsrätten": "bördsrätt",
    "bördsrättens": "bördsrätt",
    "bördsrätts": "bördsrätt",
    "bördsstolta": "bördsstolt",
    "bördsstoltare": "bördsstolt",
    "bördsstoltares": "bördsstolt",
    "bördsstoltas": "bördsstolt",
    "bördsstoltast": "bördsstolt",
    "bördsstoltaste": "bördsstolt",
    "bördsstoltastes": "bördsstolt",
    "bördsstoltasts": "bördsstolt",
    "bördsstolte": "bördsstolt",
    "bördsstoltes": "bördsstolt",
    "bördsstoltheten": "bördsstolthet",
    "bördsstolthetens": "bördsstolthet",
    "bördsstolthets": "bördsstolthet",
    "bördsstolts": "bördsstolt",
    "böres": "böra",
    "börj": "börja",
    "börjad": "börja",
    "började": "börja",
    "börjades": "börja",
    "börjads": "börja",
    "börjande": "börja",
    "börjanden": "börjande",
    "börjandena": "börjande",
    "börjandenas": "börjande",
    "börjandens": "börjande",
    "börjandes": "börjande",
    "börjandet": "börjande",
    "börjandets": "börjande",
    "börjans": "början",
    "börjar": "börja",
    "börjas": "börja",
    "börjat": "börja",
    "börjats": "börja",
    "börs": "böra",
    "börsanalysen": "börsanalys",
    "börsanalysens": "börsanalys",
    "börsanalyser": "börsanalys",
    "börsanalyserna": "börsanalys",
    "börsanalysernas": "börsanalys",
    "börsanalysers": "börsanalys",
    "börsanalytikern": "börsanalytiker",
    "börsanalytikerna": "börsanalytiker",
    "börsanalytikernas": "börsanalytiker",
    "börsanalytikerns": "börsanalytiker",
    "börsanalytikers": "börsanalytiker",
    "börsar": "börs",
    "börsarna": "börs",
    "börsarnas": "börs",
    "börsars": "börs",
    "börsbolagen": "börsbolag",
    "börsbolagens": "börsbolag",
    "börsbolaget": "börsbolag",
    "börsbolagets": "börsbolag",
    "börsbolags": "börsbolag",
    "börsen": "börs",
    "börsens": "börs",
    "börser": "börs",
    "börserna": "börs",
    "börsernas": "börs",
    "börsers": "börs",
    "börsjobbar": "börsjobbare",
    "börsjobbaren": "börsjobbare",
    "börsjobbarens": "börsjobbare",
    "börsjobbares": "börsjobbare",
    "börsjobbarna": "börsjobbare",
    "börsjobbarnas": "börsjobbare",
    "börskaosen": "börskaos",
    "börskaosens": "börskaos",
    "börskaoset": "börskaos",
    "börskaosets": "börskaos",
    "börskraschen": "börskrasch",
    "börskraschens": "börskrasch",
    "börskrascher": "börskrasch",
    "börskrascherna": "börskrasch",
    "börskraschernas": "börskrasch",
    "börskraschers": "börskrasch",
    "börskraschs": "börskrasch",
    "börskursen": "börskurs",
    "börskursens": "börskurs",
    "börskurser": "börskurs",
    "börskurserna": "börskurs",
    "börskursernas": "börskurs",
    "börskursers": "börskurs",
    "börsmäklar": "börsmäklare",
    "börsmäklaren": "börsmäklare",
    "börsmäklarens": "börsmäklare",
    "börsmäklares": "börsmäklare",
    "börsmäklarna": "börsmäklare",
    "börsmäklarnas": "börsmäklare",
    "börsmässiga": "börsmässig",
    "börsmässigare": "börsmässig",
    "börsmässigares": "börsmässig",
    "börsmässigas": "börsmässig",
    "börsmässigast": "börsmässig",
    "börsmässigaste": "börsmässig",
    "börsmässigastes": "börsmässig",
    "börsmässigasts": "börsmässig",
    "börsmässige": "börsmässig",
    "börsmässiges": "börsmässig",
    "börsmässigs": "börsmässig",
    "börsmässigt": "börsmässig",
    "börsmässigts": "börsmässig",
    "börsnoterad": "börsnotera",
    "börsnoterade": "börsnotera",
    "börsnoterades": "börsnotera",
    "börsnoterads": "börsnotera",
    "börsnoterande": "börsnotera",
    "börsnoteranden": "börsnoterande",
    "börsnoterandena": "börsnoterande",
    "börsnoterandenas": "börsnoterande",
    "börsnoterandens": "börsnoterande",
    "börsnoterandes": "börsnoterande",
    "börsnoterandet": "börsnoterande",
    "börsnoterandets": "börsnoterande",
    "börsnoterar": "börsnotera",
    "börsnoteras": "börsnotera",
    "börsnoterat": "börsnotera",
    "börsnoterats": "börsnotera",
    "börsnoterbara": "börsnoterbar",
    "börsnoterbarare": "börsnoterbar",
    "börsnoterbarares": "börsnoterbar",
    "börsnoterbaras": "börsnoterbar",
    "börsnoterbarast": "börsnoterbar",
    "börsnoterbaraste": "börsnoterbar",
    "börsnoterbarastes": "börsnoterbar",
    "börsnoterbarasts": "börsnoterbar",
    "börsnoterbare": "börsnoterbar",
    "börsnoterbares": "börsnoterbar",
    "börsnoterbarheten": "börsnoterbarhet",
    "börsnoterbarhetens": "börsnoterbarhet",
    "börsnoterbarhets": "börsnoterbarhet",
    "börsnoterbars": "börsnoterbar",
    "börsnoterbart": "börsnoterbar",
    "börsnoterbarts": "börsnoterbar",
    "börsnoteringar": "börsnotering",
    "börsnoteringarna": "börsnotering",
    "börsnoteringarnas": "börsnotering",
    "börsnoteringars": "börsnotering",
    "börsnoteringen": "börsnotering",
    "börsnoteringens": "börsnotering",
    "börsnoterings": "börsnotering",
    "börsrasen": "börsras",
    "börsrasens": "börsras",
    "börsraset": "börsras",
    "börsrasets": "börsras",
    "börsspekulanten": "börsspekulant",
    "börsspekulantens": "börsspekulant",
    "börsspekulanter": "börsspekulant",
    "börsspekulanterna": "börsspekulant",
    "börsspekulanternas": "börsspekulant",
    "börsspekulanters": "börsspekulant",
    "börsspekulants": "börsspekulant",
    "börsspekulationen": "börsspekulation",
    "börsspekulationens": "börsspekulation",
    "börsspekulationer": "börsspekulation",
    "börsspekulationerna": "börsspekulation",
    "börsspekulationernas": "börsspekulation",
    "börsspekulationers": "börsspekulation",
    "börsspekulations": "börsspekulation",
    "börstelegrafen": "börstelegraf",
    "börstelegrafens": "börstelegraf",
    "börstelegrafer": "börstelegraf",
    "börstelegraferna": "börstelegraf",
    "börstelegrafernas": "börstelegraf",
    "börstelegrafers": "börstelegraf",
    "börstelegrafs": "börstelegraf",
    "börsuppgångar": "börsuppgång",
    "börsuppgångarna": "börsuppgång",
    "börsuppgångarnas": "börsuppgång",
    "börsuppgångars": "börsuppgång",
    "börsuppgången": "börsuppgång",
    "börsuppgångens": "börsuppgång",
    "börsuppgångs": "börsuppgång",
    "börsutvecklingen": "börsutveckling",
    "börsutvecklingens": "börsutveckling",
    "börsutvecklings": "börsutveckling",
    "börsyran": "börsyra",
    "börsyrans": "börsyra",
    "börsyras": "börsyra",
    "börsyre": "börsyra",
    "börsyror": "börsyra",
    "börsyrorna": "börsyra",
    "börsyrornas": "börsyra",
    "börsyrors": "börsyra",
    "börtingar": "börting",
    "börtingarna": "börting",
    "börtingarnas": "börting",
    "börtingars": "börting",
    "börtingen": "börting",
    "börtingens": "börting",
    "börtings": "börting",
    "böss": "bössa",
    "bössan": "bössa",
    "bössans": "bössa",
    "bössas": "bössa",
    "bösse": "bössa",
    "bösshållen": "bösshåll",
    "bösshållens": "bösshåll",
    "bösshållet": "bösshåll",
    "bösshållets": "bösshåll",
    "bösshålls": "bösshåll",
    "bössinsamlingar": "bössinsamling",
    "bössinsamlingarna": "bössinsamling",
    "bössinsamlingarnas": "bössinsamling",
    "bössinsamlingars": "bössinsamling",
    "bössinsamlingen": "bössinsamling",
    "bössinsamlingens": "bössinsamling",
    "bössinsamlings": "bössinsamling",
    "bössor": "bössa",
    "bössorna": "bössa",
    "bössornas": "bössa",
    "bössors": "bössa",
    "böst": "bösta",
    "böstade": "bösta",
    "böstades": "bösta",
    "böstande": "bösta",
    "böstanden": "böstande",
    "böstandena": "böstande",
    "böstandenas": "böstande",
    "böstandens": "böstande",
    "böstandes": "böstande",
    "böstandet": "böstande",
    "böstandets": "böstande",
    "böstar": "bösta",
    "böstas": "bösta",
    "böstat": "bösta",
    "böstats": "bösta",
    "böt": "böter",
    "bötad": "böta",
    "bötade": "böta",
    "bötades": "böta",
    "bötads": "böta",
    "bötande": "böta",
    "bötanden": "bötande",
    "bötandena": "bötande",
    "bötandenas": "bötande",
    "bötandens": "bötande",
    "bötandes": "bötande",
    "bötandet": "bötande",
    "bötandets": "bötande",
    "bötar": "böta",
    "bötas": "böta",
    "bötat": "böta",
    "bötats": "böta",
    "böterna": "böter",
    "böternas": "böter",
    "böters": "böter",
    "bötes": "böter",
    "bötessumman": "bötessumma",
    "bötessummans": "bötessumma",
    "bötessummas": "bötessumma",
    "bötessumme": "bötessumma",
    "bötessummor": "bötessumma",
    "bötessummorna": "bötessumma",
    "bötessummornas": "bötessumma",
    "bötessummors": "bötessumma",
    "bötfäll": "bötfälla",
    "bötfällande": "bötfälla",
    "bötfällanden": "bötfällande",
    "bötfällandena": "bötfällande",
    "bötfällandenas": "bötfällande",
    "bötfällandens": "bötfällande",
    "bötfällandes": "bötfällande",
    "bötfällandet": "bötfällande",
    "bötfällandets": "bötfällande",
    "bötfällas": "bötfälla",
    "bötfälld": "bötfälla",
    "bötfällda": "bötfälla",
    "bötfälldas": "bötfälla",
    "bötfällde": "bötfälla",
    "bötfälldes": "bötfälla",
    "bötfällds": "bötfälla",
    "bötfäller": "bötfälla",
    "bötfälles": "bötfälla",
    "bötfälls": "bötfälla",
    "bötfällt": "bötfälla",
    "bötfällts": "bötfälla",
    "böts": "böter",
    "bövelen": "bövel",
    "bövelens": "bövel",
    "böveln": "bövel",
    "bövelns": "bövel",
    "bövels": "bövel",
    "bövlar": "bövel",
    "bövlarna": "bövel",
    "bövlarnas": "bövel",
    "bövlars": "bövel",
    "c-et": "c",
    "c-ets": "c",
    "c-n": "c",
    "c-na": "c",
    "c-nas": "c",
    "c-ns": "c",
    "c-s": "c",
    "c-t": "c",
    "c-ts": "c",
    "c:et": "c",
    "c:ets": "c",
    "c:n": "c",
    "c:na": "c",
    "c:nas": "c",
    "c:ns": "c",
    "c:s": "c",
    "c:t": "c",
    "c:ts": "c",
    "cabar": "cab",
    "cabarna": "cab",
    "cabarnas": "cab",
    "cabars": "cab",
    "cabbar": "cabb",
    "cabbarna": "cabb",
    "cabbarnas": "cabb",
    "cabbars": "cabb",
    "cabben": "cabb",
    "cabbens": "cabb",
    "cabbs": "cabb",
    "caben": "cab",
    "cabens": "cab",
    "cabotages": "cabotage",
    "cabotaget": "cabotage",
    "cabotagets": "cabotage",
    "cabrioleten": "cabriolet",
    "cabrioletens": "cabriolet",
    "cabrioleter": "cabriolet",
    "cabrioleterna": "cabriolet",
    "cabrioleternas": "cabriolet",
    "cabrioleters": "cabriolet",
    "cabriolets": "cabriolet",
    "cabs": "cab",
    "caddien": "caddie",
    "caddiens": "caddie",
    "caddier": "caddie",
    "caddierna": "caddie",
    "caddiernas": "caddie",
    "caddiers": "caddie",
    "caddies": "caddie",
    "caddiesen": "caddie",
    "caddiesens": "caddie",
    "cafeer": "cafe",
    "cafeerna": "cafe",
    "cafeernas": "cafe",
    "cafeers": "cafe",
    "cafeet": "cafe",
    "cafeets": "cafe",
    "cafes": "cafe",
    "cafet": "cafe",
    "cafeteri": "cafeteria",
    "cafeterian": "cafeteria",
    "cafeterians": "cafeteria",
    "cafeterias": "cafeteria",
    "cafeterie": "cafeteria",
    "cafeterior": "cafeteria",
    "cafeteriorna": "cafeteria",
    "cafeteriornas": "cafeteria",
    "cafeteriors": "cafeteria",
    "cafeteris": "cafeteria",
    "cafets": "cafe",
    "caféborden": "cafébord",
    "cafébordens": "cafébord",
    "cafébordet": "cafébord",
    "cafébordets": "cafébord",
    "cafébords": "cafébord",
    "caféer": "café",
    "caféerna": "café",
    "caféernas": "café",
    "caféers": "café",
    "caféet": "café",
    "caféets": "café",
    "cafés": "café",
    "cafét": "café",
    "caféts": "café",
    "californiet": "californium",
    "californiets": "californium",
    "californiumet": "californium",
    "californiumets": "californium",
    "californiums": "californium",
    "callgirlen": "callgirl",
    "callgirlens": "callgirl",
    "callgirls": "callgirl",
    "callgirlsarna": "callgirl",
    "callgirlsarnas": "callgirl",
    "callgirlsen": "callgirl",
    "callgirlsens": "callgirl",
    "calmettevaccineringar": "calmettevaccinering",
    "calmettevaccineringarna": "calmettevaccinering",
    "calmettevaccineringarnas": "calmettevaccinering",
    "calmettevaccineringars": "calmettevaccinering",
    "calmettevaccineringen": "calmettevaccinering",
    "calmettevaccineringens": "calmettevaccinering",
    "calmettevaccinerings": "calmettevaccinering",
    "calypson": "calypso",
    "calypsons": "calypso",
    "calypsos": "calypso",
    "camemberten": "camembert",
    "camembertens": "camembert",
    "camemberts": "camembert",
    "camorran": "camorra",
    "camorrans": "camorra",
    "camorras": "camorra",
    "camorror": "camorra",
    "camorrorna": "camorra",
    "camorrornas": "camorra",
    "camorrors": "camorra",
    "camouflagen": "camouflage",
    "camouflagens": "camouflage",
    "camouflages": "camouflage",
    "camouflaget": "camouflage",
    "camouflagets": "camouflage",
    "camouflerad": "camouflera",
    "camouflerade": "camouflera",
    "camouflerades": "camouflera",
    "camouflerads": "camouflera",
    "camouflerande": "camouflera",
    "camoufleranden": "camouflerande",
    "camouflerandena": "camouflerande",
    "camouflerandenas": "camouflerande",
    "camouflerandens": "camouflerande",
    "camouflerandes": "camouflerande",
    "camouflerandet": "camouflerande",
    "camouflerandets": "camouflerande",
    "camouflerar": "camouflera",
    "camoufleras": "camouflera",
    "camouflerat": "camouflera",
    "camouflerats": "camouflera",
    "camouflerbara": "camouflerbar",
    "camouflerbarare": "camouflerbar",
    "camouflerbarares": "camouflerbar",
    "camouflerbaras": "camouflerbar",
    "camouflerbarast": "camouflerbar",
    "camouflerbaraste": "camouflerbar",
    "camouflerbarastes": "camouflerbar",
    "camouflerbarasts": "camouflerbar",
    "camouflerbare": "camouflerbar",
    "camouflerbares": "camouflerbar",
    "camouflerbarheten": "camouflerbarhet",
    "camouflerbarhetens": "camouflerbarhet",
    "camouflerbarhets": "camouflerbarhet",
    "camouflerbars": "camouflerbar",
    "camouflerbart": "camouflerbar",
    "camouflerbarts": "camouflerbar",
    "camoufleringar": "camouflering",
    "camoufleringarna": "camouflering",
    "camoufleringarnas": "camouflering",
    "camoufleringars": "camouflering",
    "camoufleringen": "camouflering",
    "camoufleringens": "camouflering",
    "camouflerings": "camouflering",
    "campa": "camp",
    "campade": "campa",
    "campades": "campa",
    "campande": "campa",
    "campanden": "campande",
    "campandena": "campande",
    "campandenas": "campande",
    "campandens": "campande",
    "campandes": "campande",
    "campandet": "campande",
    "campandets": "campande",
    "campar": "campare",
    "campare": "camp",
    "camparen": "campare",
    "camparens": "campare",
    "campares": "campare",
    "camparna": "campare",
    "camparnas": "campare",
    "campas": "campa",
    "campast": "camp",
    "campaste": "camp",
    "campastes": "camp",
    "campasts": "camp",
    "campat": "campa",
    "campats": "campa",
    "campe": "camp",
    "campes": "camp",
    "campheten": "camphet",
    "camphetens": "camphet",
    "camphets": "camphet",
    "campingar": "camping",
    "campingarna": "camping",
    "campingarnas": "camping",
    "campingars": "camping",
    "campingen": "camping",
    "campingens": "camping",
    "campinglamp": "campinglampa",
    "campinglampan": "campinglampa",
    "campinglampans": "campinglampa",
    "campinglampas": "campinglampa",
    "campinglampe": "campinglampa",
    "campinglampor": "campinglampa",
    "campinglamporna": "campinglampa",
    "campinglampornas": "campinglampa",
    "campinglampors": "campinglampa",
    "campinglamps": "campinglampa",
    "campingplatsen": "campingplats",
    "campingplatsens": "campingplats",
    "campingplatser": "campingplats",
    "campingplatserna": "campingplats",
    "campingplatsernas": "campingplats",
    "campingplatsers": "campingplats",
    "campings": "camping",
    "campingstugan": "campingstuga",
    "campingstugans": "campingstuga",
    "campingstugas": "campingstuga",
    "campingstuge": "campingstuga",
    "campingstugor": "campingstuga",
    "campingstugorna": "campingstuga",
    "campingstugornas": "campingstuga",
    "campingstugors": "campingstuga",
    "campingstugu": "campingstuga",
    "camps": "camp",
    "campusen": "campus",
    "campusens": "campus",
    "campuset": "campus",
    "campusets": "campus",
    "canastan": "canasta",
    "canastans": "canasta",
    "canastas": "canasta",
    "cancanen": "cancan",
    "cancanens": "cancan",
    "cancans": "cancan",
    "cancerbehandlingar": "cancerbehandling",
    "cancerbehandlingarna": "cancerbehandling",
    "cancerbehandlingarnas": "cancerbehandling",
    "cancerbehandlingars": "cancerbehandling",
    "cancerbehandlingen": "cancerbehandling",
    "cancerbehandlingens": "cancerbehandling",
    "cancerbehandlings": "cancerbehandling",
    "cancerfallen": "cancerfall",
    "cancerfallens": "cancerfall",
    "cancerfallet": "cancerfall",
    "cancerfallets": "cancerfall",
    "cancerfalls": "cancerfall",
    "cancerfar": "cancerfara",
    "cancerfaran": "cancerfara",
    "cancerfarans": "cancerfara",
    "cancerfaras": "cancerfara",
    "cancerfare": "cancerfara",
    "cancerfaro": "cancerfara",
    "cancerfaror": "cancerfara",
    "cancerfarorna": "cancerfara",
    "cancerfarornas": "cancerfara",
    "cancerfarors": "cancerfara",
    "cancerfars": "cancerfara",
    "cancerformen": "cancerform",
    "cancerformens": "cancerform",
    "cancerformer": "cancerform",
    "cancerformerna": "cancerform",
    "cancerformernas": "cancerform",
    "cancerformers": "cancerform",
    "cancerforms": "cancerform",
    "cancerforskar": "cancerforskare",
    "cancerforskaren": "cancerforskare",
    "cancerforskarens": "cancerforskare",
    "cancerforskares": "cancerforskare",
    "cancerforskarna": "cancerforskare",
    "cancerforskarnas": "cancerforskare",
    "cancerforskningar": "cancerforskning",
    "cancerforskningarna": "cancerforskning",
    "cancerforskningarnas": "cancerforskning",
    "cancerforskningars": "cancerforskning",
    "cancerforskningen": "cancerforskning",
    "cancerforskningens": "cancerforskning",
    "cancerforsknings": "cancerforskning",
    "cancern": "cancer",
    "cancerns": "cancer",
    "cancerogena": "cancerogen",
    "cancerogenare": "cancerogen",
    "cancerogenares": "cancerogen",
    "cancerogenas": "cancerogen",
    "cancerogenast": "cancerogen",
    "cancerogenaste": "cancerogen",
    "cancerogenastes": "cancerogen",
    "cancerogenasts": "cancerogen",
    "cancerogene": "cancerogen",
    "cancerogenes": "cancerogen",
    "cancerogens": "cancerogen",
    "cancerogent": "cancerogen",
    "cancerogents": "cancerogen",
    "cancerrisken": "cancerrisk",
    "cancerriskens": "cancerrisk",
    "cancerrisker": "cancerrisk",
    "cancerriskerna": "cancerrisk",
    "cancerriskernas": "cancerrisk",
    "cancerriskers": "cancerrisk",
    "cancerrisks": "cancerrisk",
    "cancers": "cancer",
    "cancersvulsten": "cancersvulst",
    "cancersvulstens": "cancersvulst",
    "cancersvulster": "cancersvulst",
    "cancersvulsterna": "cancersvulst",
    "cancersvulsternas": "cancersvulst",
    "cancersvulsters": "cancersvulst",
    "cancersvulsts": "cancersvulst",
    "cancertumören": "cancertumör",
    "cancertumörens": "cancertumör",
    "cancertumörer": "cancertumör",
    "cancertumörerna": "cancertumör",
    "cancertumörernas": "cancertumör",
    "cancertumörers": "cancertumör",
    "cancertumörs": "cancertumör",
    "canceruppföljningar": "canceruppföljning",
    "canceruppföljningarna": "canceruppföljning",
    "canceruppföljningarnas": "canceruppföljning",
    "canceruppföljningars": "canceruppföljning",
    "canceruppföljningen": "canceruppföljning",
    "canceruppföljningens": "canceruppföljning",
    "canceruppföljnings": "canceruppföljning",
    "cancrar": "cancer",
    "cancrarna": "cancer",
    "cancrarnas": "cancer",
    "cancrars": "cancer",
    "candelan": "candela",
    "candelana": "candela",
    "candelanas": "candela",
    "candelans": "candela",
    "candelas": "candela",
    "cannabisen": "cannabis",
    "cannabisens": "cannabis",
    "cannabisodlingar": "cannabisodling",
    "cannabisodlingarna": "cannabisodling",
    "cannabisodlingarnas": "cannabisodling",
    "cannabisodlingars": "cannabisodling",
    "cannabisodlingen": "cannabisodling",
    "cannabisodlingens": "cannabisodling",
    "cannabisodlings": "cannabisodling",
    "canossavandringar": "canossavandring",
    "canossavandringarna": "canossavandring",
    "canossavandringarnas": "canossavandring",
    "canossavandringars": "canossavandring",
    "canossavandringen": "canossavandring",
    "canossavandringens": "canossavandring",
    "canossavandrings": "canossavandring",
    "cantilen": "cantilena",
    "cantilenan": "cantilena",
    "cantilenans": "cantilena",
    "cantilenas": "cantilena",
    "cantilene": "cantilena",
    "cantilenor": "cantilena",
    "cantilenorna": "cantilena",
    "cantilenornas": "cantilena",
    "cantilenors": "cantilena",
    "cantilens": "cantilena",
    "capen": "cape",
    "capens": "cape",
    "caper": "cape",
    "caperna": "cape",
    "capernas": "cape",
    "capers": "cape",
    "capes": "cape",
    "cappuccinokoppar": "cappuccinokopp",
    "cappuccinokopparna": "cappuccinokopp",
    "cappuccinokopparnas": "cappuccinokopp",
    "cappuccinokoppars": "cappuccinokopp",
    "cappuccinokoppen": "cappuccinokopp",
    "cappuccinokoppens": "cappuccinokopp",
    "cappuccinokopps": "cappuccinokopp",
    "cappuccinon": "cappuccino",
    "cappuccinona": "cappuccino",
    "cappuccinonas": "cappuccino",
    "cappuccinons": "cappuccino",
    "cappuccinos": "cappuccino",
    "carambolen": "carambole",
    "carambolens": "carambole",
    "caramboles": "carambole",
    "carcinogenen": "carcinogen",
    "carcinogenens": "carcinogen",
    "carcinogener": "carcinogen",
    "carcinogenerna": "carcinogen",
    "carcinogenernas": "carcinogen",
    "carcinogeners": "carcinogen",
    "carcinogens": "carcinogen",
    "cardiganen": "cardigan",
    "cardiganens": "cardigan",
    "cardigans": "cardigan",
    "cardigansarna": "cardigan",
    "cardigansarnas": "cardigan",
    "cardigansen": "cardigan",
    "cardigansens": "cardigan",
    "casanov": "casanova",
    "casanovan": "casanova",
    "casanovans": "casanova",
    "casanovas": "casanova",
    "casanove": "casanova",
    "casanovor": "casanova",
    "casanovorna": "casanova",
    "casanovornas": "casanova",
    "casanovors": "casanova",
    "casanovs": "casanova",
    "cashen": "cash",
    "cashens": "cash",
    "cashet": "cash",
    "cashets": "cash",
    "cashewen": "cashew",
    "cashewens": "cashew",
    "cashewn": "cashew",
    "cashewns": "cashew",
    "cashewnöten": "cashewnöt",
    "cashewnötens": "cashewnöt",
    "cashewnöts": "cashewnöt",
    "cashewnötter": "cashewnöt",
    "cashewnötterna": "cashewnöt",
    "cashewnötternas": "cashewnöt",
    "cashewnötters": "cashewnöt",
    "cashews": "cashew",
    "cashewsen": "cashew",
    "cashewsens": "cashew",
    "cashs": "cash",
    "castingen": "casting",
    "castingens": "casting",
    "castings": "casting",
    "catch-as-catch-cans": "catch-as-catch-can",
    "caterad": "catera",
    "caterade": "catera",
    "caterades": "catera",
    "caterads": "catera",
    "caterande": "catera",
    "cateranden": "caterande",
    "caterandena": "caterande",
    "caterandenas": "caterande",
    "caterandens": "caterande",
    "caterandes": "caterande",
    "caterandet": "caterande",
    "caterandets": "caterande",
    "caterar": "catera",
    "cateras": "catera",
    "caterat": "catera",
    "caterats": "catera",
    "cateringen": "catering",
    "cateringens": "catering",
    "caterings": "catering",
    "caterpillarn": "caterpillar",
    "caterpillarns": "caterpillar",
    "caterpillars": "caterpillar",
    "caterpillarsarna": "caterpillar",
    "caterpillarsarnas": "caterpillar",
    "caterpillarsen": "caterpillar",
    "caterpillarsens": "caterpillar",
    "caterpillrar": "caterpillar",
    "caterpillrarna": "caterpillar",
    "caterpillrarnas": "caterpillar",
    "caterpillrars": "caterpillar",
    "catguten": "catgut",
    "catgutens": "catgut",
    "catguts": "catgut",
    "cavatin": "cavatina",
    "cavatinan": "cavatina",
    "cavatinans": "cavatina",
    "cavatinas": "cavatina",
    "cavatine": "cavatina",
    "cavatinor": "cavatina",
    "cavatinorna": "cavatina",
    "cavatinornas": "cavatina",
    "cavatinors": "cavatina",
    "cavatins": "cavatina",
    "cayennepepparn": "cayennepeppar",
    "cayennepepparns": "cayennepeppar",
    "cayennepeppars": "cayennepeppar",
    "cd-rommen": "cd-rom",
    "cd-rommens": "cd-rom",
    "cd-rommet": "cd-rom",
    "cd-rommets": "cd-rom",
    "cd-spelarens": "cd-spelare",
    "cd-spelarna": "cd-spelare",
    "cd:arnas": "cd",
    "cd:ars": "cd",
    "cd:erna": "cd",
    "cd:ers": "cd",
    "cd:ns": "cd",
    "cdar": "cd",
    "cdarnas": "cd",
    "cdars": "cd",
    "cderna": "cd",
    "cders": "cd",
    "cdns": "cd",
    "cds": "cd",
    "cederad": "cedera",
    "cederade": "cedera",
    "cederades": "cedera",
    "cederads": "cedera",
    "cederande": "cedera",
    "cederanden": "cederande",
    "cederandena": "cederande",
    "cederandenas": "cederande",
    "cederandens": "cederande",
    "cederandes": "cederande",
    "cederandet": "cederande",
    "cederandets": "cederande",
    "cederar": "cedera",
    "cederas": "cedera",
    "cederat": "cedera",
    "cederats": "cedera",
    "cederbara": "cederbar",
    "cederbarare": "cederbar",
    "cederbarares": "cederbar",
    "cederbaras": "cederbar",
    "cederbarast": "cederbar",
    "cederbaraste": "cederbar",
    "cederbarastes": "cederbar",
    "cederbarasts": "cederbar",
    "cederbare": "cederbar",
    "cederbares": "cederbar",
    "cederbarheten": "cederbarhet",
    "cederbarhetens": "cederbarhet",
    "cederbarhets": "cederbarhet",
    "cederbars": "cederbar",
    "cederbart": "cederbar",
    "cederbarts": "cederbar",
    "cederingar": "cedering",
    "cederingarna": "cedering",
    "cederingarnas": "cedering",
    "cederingars": "cedering",
    "cederingen": "cedering",
    "cederingens": "cedering",
    "cederings": "cedering",
    "cedern": "ceder",
    "cederns": "ceder",
    "ceders": "ceder",
    "cederskogar": "cederskog",
    "cederskogarna": "cederskog",
    "cederskogarnas": "cederskog",
    "cederskogars": "cederskog",
    "cederskogen": "cederskog",
    "cederskogens": "cederskog",
    "cederskogs": "cederskog",
    "cediljen": "cedilj",
    "cediljens": "cedilj",
    "cediljer": "cedilj",
    "cediljerna": "cedilj",
    "cediljernas": "cedilj",
    "cediljers": "cedilj",
    "cediljs": "cedilj",
    "cedrar": "ceder",
    "cedrarna": "ceder",
    "cedrarnas": "ceder",
    "cedrars": "ceder",
    "cedratet": "cedrat",
    "cedratets": "cedrat",
    "cedrats": "cedrat",
    "cedrooljan": "cedroolja",
    "cedrooljans": "cedroolja",
    "cedrooljas": "cedroolja",
    "cedroolje": "cedroolja",
    "celebers": "celeber",
    "celebert": "celeber",
    "celeberts": "celeber",
    "celebra": "celeber",
    "celebrare": "celeber",
    "celebrares": "celeber",
    "celebras": "celeber",
    "celebrast": "celeber",
    "celebraste": "celeber",
    "celebrastes": "celeber",
    "celebrasts": "celeber",
    "celebre": "celeber",
    "celebrerad": "celebrera",
    "celebrerade": "celebrera",
    "celebrerades": "celebrera",
    "celebrerads": "celebrera",
    "celebrerande": "celebrera",
    "celebreranden": "celebrerande",
    "celebrerandena": "celebrerande",
    "celebrerandenas": "celebrerande",
    "celebrerandens": "celebrerande",
    "celebrerandes": "celebrerande",
    "celebrerandet": "celebrerande",
    "celebrerandets": "celebrerande",
    "celebrerar": "celebrera",
    "celebreras": "celebrera",
    "celebrerat": "celebrera",
    "celebrerats": "celebrera",
    "celebrerbara": "celebrerbar",
    "celebrerbarare": "celebrerbar",
    "celebrerbarares": "celebrerbar",
    "celebrerbaras": "celebrerbar",
    "celebrerbarast": "celebrerbar",
    "celebrerbaraste": "celebrerbar",
    "celebrerbarastes": "celebrerbar",
    "celebrerbarasts": "celebrerbar",
    "celebrerbare": "celebrerbar",
    "celebrerbares": "celebrerbar",
    "celebrerbarheten": "celebrerbarhet",
    "celebrerbarhetens": "celebrerbarhet",
    "celebrerbarhets": "celebrerbarhet",
    "celebrerbars": "celebrerbar",
    "celebrerbart": "celebrerbar",
    "celebrerbarts": "celebrerbar",
    "celebreringar": "celebrering",
    "celebreringarna": "celebrering",
    "celebreringarnas": "celebrering",
    "celebreringars": "celebrering",
    "celebreringen": "celebrering",
    "celebreringens": "celebrering",
    "celebrerings": "celebrering",
    "celebres": "celeber",
    "celebriteten": "celebritet",
    "celebritetens": "celebritet",
    "celebriteter": "celebritet",
    "celebriteterna": "celebritet",
    "celebriteternas": "celebritet",
    "celebriteters": "celebritet",
    "celebritets": "celebritet",
    "celest": "celesta",
    "celesta": "celest",
    "celestan": "celesta",
    "celestans": "celesta",
    "celestare": "celest",
    "celestares": "celest",
    "celestas": "celesta",
    "celestast": "celest",
    "celestaste": "celest",
    "celestastes": "celest",
    "celestasts": "celest",
    "celeste": "celesta",
    "celestes": "celest",
    "celestor": "celesta",
    "celestorna": "celesta",
    "celestornas": "celesta",
    "celestors": "celesta",
    "celests": "celest",
    "celibaten": "celibat",
    "celibatens": "celibat",
    "celibater": "celibat",
    "celibaterna": "celibat",
    "celibaternas": "celibat",
    "celibaters": "celibat",
    "celibatet": "celibat",
    "celibatets": "celibat",
    "celibatlöften": "celibatlöfte",
    "celibatlöftena": "celibatlöfte",
    "celibatlöftenas": "celibatlöfte",
    "celibatlöftens": "celibatlöfte",
    "celibatlöftes": "celibatlöfte",
    "celibatlöftet": "celibatlöfte",
    "celibatlöftets": "celibatlöfte",
    "celibats": "celibat",
    "cell": "cella",
    "cellan": "cella",
    "cellandningar": "cellandning",
    "cellandningarna": "cellandning",
    "cellandningarnas": "cellandning",
    "cellandningars": "cellandning",
    "cellandningen": "cellandning",
    "cellandningens": "cellandning",
    "cellandnings": "cellandning",
    "cellans": "cella",
    "cellas": "cella",
    "cellbiologien": "cellbiologi",
    "cellbiologiens": "cellbiologi",
    "cellbiologin": "cellbiologi",
    "cellbiologins": "cellbiologi",
    "cellbiologis": "cellbiologi",
    "celldelningar": "celldelning",
    "celldelningarna": "celldelning",
    "celldelningarnas": "celldelning",
    "celldelningars": "celldelning",
    "celldelningen": "celldelning",
    "celldelningens": "celldelning",
    "celldelnings": "celldelning",
    "celle": "cella",
    "cellen": "cell",
    "cellens": "cell",
    "celler": "cell",
    "cellerna": "cell",
    "cellernas": "cell",
    "cellers": "cell",
    "cellfängelser": "cellfängelse",
    "cellfängelserna": "cellfängelse",
    "cellfängelsernas": "cellfängelse",
    "cellfängelsers": "cellfängelse",
    "cellfängelses": "cellfängelse",
    "cellfängelset": "cellfängelse",
    "cellfängelsets": "cellfängelse",
    "cellgifter": "cellgift",
    "cellgifterna": "cellgift",
    "cellgifternas": "cellgift",
    "cellgifters": "cellgift",
    "cellgiftet": "cellgift",
    "cellgiftets": "cellgift",
    "cellgifts": "cellgift",
    "cellgiftsbehandlingar": "cellgiftsbehandling",
    "cellgiftsbehandlingarna": "cellgiftsbehandling",
    "cellgiftsbehandlingarnas": "cellgiftsbehandling",
    "cellgiftsbehandlingars": "cellgiftsbehandling",
    "cellgiftsbehandlingen": "cellgiftsbehandling",
    "cellgiftsbehandlingens": "cellgiftsbehandling",
    "cellgiftsbehandlings": "cellgiftsbehandling",
    "cellgrann": "cellgranne",
    "cellgrannar": "cellgranne",
    "cellgrannarna": "cellgranne",
    "cellgrannarnas": "cellgranne",
    "cellgrannars": "cellgranne",
    "cellgrannen": "cellgranne",
    "cellgrannens": "cellgranne",
    "cellgrannes": "cellgranne",
    "cellgranns": "cellgranne",
    "celli": "cello",
    "cellinis": "cellini",
    "cellis": "cello",
    "cellisten": "cellist",
    "cellistens": "cellist",
    "cellister": "cellist",
    "cellisterna": "cellist",
    "cellisternas": "cellist",
    "cellisters": "cellist",
    "cellists": "cellist",
    "cellkamraten": "cellkamrat",
    "cellkamratens": "cellkamrat",
    "cellkamrater": "cellkamrat",
    "cellkamraterna": "cellkamrat",
    "cellkamraternas": "cellkamrat",
    "cellkamraters": "cellkamrat",
    "cellkamrats": "cellkamrat",
    "cellkärn": "cellkärna",
    "cellkärnan": "cellkärna",
    "cellkärnans": "cellkärna",
    "cellkärnas": "cellkärna",
    "cellkärne": "cellkärna",
    "cellkärnor": "cellkärna",
    "cellkärnorna": "cellkärna",
    "cellkärnornas": "cellkärna",
    "cellkärnors": "cellkärna",
    "cellkärns": "cellkärna",
    "cellmembranen": "cellmembran",
    "cellmembranens": "cellmembran",
    "cellmembraner": "cellmembran",
    "cellmembranerna": "cellmembran",
    "cellmembranernas": "cellmembran",
    "cellmembraners": "cellmembran",
    "cellmembranet": "cellmembran",
    "cellmembranets": "cellmembran",
    "cellmembrans": "cellmembran",
    "cellofanen": "cellofan",
    "cellofanens": "cellofan",
    "cellofanet": "cellofan",
    "cellofanets": "cellofan",
    "cellofans": "cellofan",
    "cellon": "cello",
    "cellons": "cello",
    "cellor": "cello",
    "cellorna": "cello",
    "cellornas": "cello",
    "cellors": "cello",
    "cellos": "cello",
    "cellplasman": "cellplasma",
    "cellplasmans": "cellplasma",
    "cellplasmas": "cellplasma",
    "cellplasmat": "cellplasma",
    "cellplasmats": "cellplasma",
    "cellplasmer": "cellplasma",
    "cellplasmerna": "cellplasma",
    "cellplasmernas": "cellplasma",
    "cellplasmers": "cellplasma",
    "cellproven": "cellprov",
    "cellprovens": "cellprov",
    "cellprover": "cellprov",
    "cellproverna": "cellprov",
    "cellprovernas": "cellprov",
    "cellprovers": "cellprov",
    "cellprovet": "cellprov",
    "cellprovets": "cellprov",
    "cellprovs": "cellprov",
    "cells": "cella",
    "cellsjoken": "cellsjok",
    "cellsjokens": "cellsjok",
    "cellsjoket": "cellsjok",
    "cellsjokets": "cellsjok",
    "cellsjoks": "cellsjok",
    "cellskikten": "cellskikt",
    "cellskiktens": "cellskikt",
    "cellskiktet": "cellskikt",
    "cellskiktets": "cellskikt",
    "cellskikts": "cellskikt",
    "cellskräcken": "cellskräck",
    "cellskräckens": "cellskräck",
    "cellskräcks": "cellskräck",
    "cellspänningar": "cellspänning",
    "cellspänningarna": "cellspänning",
    "cellspänningarnas": "cellspänning",
    "cellspänningars": "cellspänning",
    "cellspänningen": "cellspänning",
    "cellspänningens": "cellspänning",
    "cellspännings": "cellspänning",
    "cellstoffen": "cellstoff",
    "cellstoffens": "cellstoff",
    "cellstoffet": "cellstoff",
    "cellstoffets": "cellstoff",
    "cellstoffs": "cellstoff",
    "cellstraffen": "cellstraff",
    "cellstraffens": "cellstraff",
    "cellstraffet": "cellstraff",
    "cellstraffets": "cellstraff",
    "cellstraffs": "cellstraff",
    "cellstrukturen": "cellstruktur",
    "cellstrukturens": "cellstruktur",
    "cellstrukturer": "cellstruktur",
    "cellstrukturerna": "cellstruktur",
    "cellstrukturernas": "cellstruktur",
    "cellstrukturers": "cellstruktur",
    "cellstrukturs": "cellstruktur",
    "celltrådar": "celltråd",
    "celltrådarna": "celltråd",
    "celltrådarnas": "celltråd",
    "celltrådars": "celltråd",
    "celltråden": "celltråd",
    "celltrådens": "celltråd",
    "celltråds": "celltråd",
    "celltypen": "celltyp",
    "celltypens": "celltyp",
    "celltyper": "celltyp",
    "celltyperna": "celltyp",
    "celltypernas": "celltyp",
    "celltypers": "celltyp",
    "celltyps": "celltyp",
    "cellulasen": "cellulas",
    "cellulasens": "cellulas",
    "celluloiden": "celluloid",
    "celluloidens": "celluloid",
    "celluloids": "celluloid",
    "cellulosaetanolen": "cellulosaetanol",
    "cellulosaetanolens": "cellulosaetanol",
    "cellulosaetanoler": "cellulosaetanol",
    "cellulosaetanolerna": "cellulosaetanol",
    "cellulosaetanolernas": "cellulosaetanol",
    "cellulosaetanolers": "cellulosaetanol",
    "cellulosaetanols": "cellulosaetanol",
    "cellulosaförtunningar": "cellulosaförtunning",
    "cellulosaförtunningarna": "cellulosaförtunning",
    "cellulosaförtunningarnas": "cellulosaförtunning",
    "cellulosaförtunningars": "cellulosaförtunning",
    "cellulosaförtunningen": "cellulosaförtunning",
    "cellulosaförtunningens": "cellulosaförtunning",
    "cellulosaförtunnings": "cellulosaförtunning",
    "cellulosaindustrien": "cellulosaindustri",
    "cellulosaindustriens": "cellulosaindustri",
    "cellulosaindustrier": "cellulosaindustri",
    "cellulosaindustrierna": "cellulosaindustri",
    "cellulosaindustriernas": "cellulosaindustri",
    "cellulosaindustriers": "cellulosaindustri",
    "cellulosaindustrin": "cellulosaindustri",
    "cellulosaindustrins": "cellulosaindustri",
    "cellulosaindustris": "cellulosaindustri",
    "cellulosalacken": "cellulosalack",
    "cellulosalackens": "cellulosalack",
    "cellulosalacker": "cellulosalack",
    "cellulosalackerna": "cellulosalack",
    "cellulosalackernas": "cellulosalack",
    "cellulosalackers": "cellulosalack",
    "cellulosalacket": "cellulosalack",
    "cellulosalackets": "cellulosalack",
    "cellulosalacks": "cellulosalack",
    "cellulosamolekylen": "cellulosamolekyl",
    "cellulosamolekylens": "cellulosamolekyl",
    "cellulosamolekyler": "cellulosamolekyl",
    "cellulosamolekylerna": "cellulosamolekyl",
    "cellulosamolekylernas": "cellulosamolekyl",
    "cellulosamolekylers": "cellulosamolekyl",
    "cellulosamolekyls": "cellulosamolekyl",
    "cellulosan": "cellulosa",
    "cellulosanitraten": "cellulosanitrat",
    "cellulosanitratens": "cellulosanitrat",
    "cellulosanitrater": "cellulosanitrat",
    "cellulosanitraterna": "cellulosanitrat",
    "cellulosanitraternas": "cellulosanitrat",
    "cellulosanitraters": "cellulosanitrat",
    "cellulosanitratet": "cellulosanitrat",
    "cellulosanitratets": "cellulosanitrat",
    "cellulosanitrats": "cellulosanitrat",
    "cellulosans": "cellulosa",
    "cellulosaplasten": "cellulosaplast",
    "cellulosaplastens": "cellulosaplast",
    "cellulosaplaster": "cellulosaplast",
    "cellulosaplasterna": "cellulosaplast",
    "cellulosaplasternas": "cellulosaplast",
    "cellulosaplasters": "cellulosaplast",
    "cellulosaplasts": "cellulosaplast",
    "cellulosas": "cellulosa",
    "cellulosavadden": "cellulosavadd",
    "cellulosavaddens": "cellulosavadd",
    "cellulosavadds": "cellulosavadd",
    "cellulära": "cellulär",
    "cellulärare": "cellulär",
    "cellulärares": "cellulär",
    "celluläras": "cellulär",
    "cellulärast": "cellulär",
    "celluläraste": "cellulär",
    "cellulärastes": "cellulär",
    "cellulärasts": "cellulär",
    "celluläre": "cellulär",
    "celluläres": "cellulär",
    "cellulärs": "cellulär",
    "cellulärt": "cellulär",
    "cellulärts": "cellulär",
    "cellväggar": "cellvägg",
    "cellväggarna": "cellvägg",
    "cellväggarnas": "cellvägg",
    "cellväggars": "cellvägg",
    "cellväggen": "cellvägg",
    "cellväggens": "cellvägg",
    "cellväggs": "cellvägg",
    "celsiusgraden": "celsiusgrad",
    "celsiusgradens": "celsiusgrad",
    "celsiusgrader": "celsiusgrad",
    "celsiusgraderna": "celsiusgrad",
    "celsiusgradernas": "celsiusgrad",
    "celsiusgraders": "celsiusgrad",
    "celsiusgrads": "celsiusgrad",
    "celsiusskalan": "celsiusskala",
    "celsiusskalans": "celsiusskala",
    "celsiusskalas": "celsiusskala",
    "celsiustermometern": "celsiustermometer",
    "celsiustermometerns": "celsiustermometer",
    "celsiustermometers": "celsiustermometer",
    "celsiustermometrar": "celsiustermometer",
    "celsiustermometrarna": "celsiustermometer",
    "celsiustermometrarnas": "celsiustermometer",
    "celsiustermometrars": "celsiustermometer",
    "celten": "celt",
    "celtens": "celt",
    "celter": "celt",
    "celterna": "celt",
    "celternas": "celt",
    "celters": "celt",
    "celts": "celt",
    "cembali": "cembalo",
    "cembalis": "cembalo",
    "cembalisten": "cembalist",
    "cembalistens": "cembalist",
    "cembalister": "cembalist",
    "cembalisterna": "cembalist",
    "cembalisternas": "cembalist",
    "cembalisters": "cembalist",
    "cembalists": "cembalist",
    "cembalon": "cembalo",
    "cembalons": "cembalo",
    "cembalor": "cembalo",
    "cembalorna": "cembalo",
    "cembalornas": "cembalo",
    "cembalors": "cembalo",
    "cembalos": "cembalo",
    "cembalotillverkningar": "cembalotillverkning",
    "cembalotillverkningarna": "cembalotillverkning",
    "cembalotillverkningarnas": "cembalotillverkning",
    "cembalotillverkningars": "cembalotillverkning",
    "cembalotillverkningen": "cembalotillverkning",
    "cembalotillverkningens": "cembalotillverkning",
    "cembalotillverknings": "cembalotillverkning",
    "cement": "cementa",
    "cementad": "cementa",
    "cementade": "cementa",
    "cementades": "cementa",
    "cementads": "cementa",
    "cementande": "cementa",
    "cementanden": "cementande",
    "cementandena": "cementande",
    "cementandenas": "cementande",
    "cementandens": "cementande",
    "cementandes": "cementande",
    "cementandet": "cementande",
    "cementandets": "cementande",
    "cementar": "cementa",
    "cementas": "cementa",
    "cementat": "cementa",
    "cementats": "cementa",
    "cementblandar": "cementblandare",
    "cementblandaren": "cementblandare",
    "cementblandarens": "cementblandare",
    "cementblandares": "cementblandare",
    "cementblandarna": "cementblandare",
    "cementblandarnas": "cementblandare",
    "cementen": "cement",
    "cementens": "cement",
    "cementerad": "cementera",
    "cementerade": "cementera",
    "cementerades": "cementera",
    "cementerads": "cementera",
    "cementerande": "cementera",
    "cementeranden": "cementerande",
    "cementerandena": "cementerande",
    "cementerandenas": "cementerande",
    "cementerandens": "cementerande",
    "cementerandes": "cementerande",
    "cementerandet": "cementerande",
    "cementerandets": "cementerande",
    "cementerar": "cementera",
    "cementeras": "cementera",
    "cementerat": "cementera",
    "cementerats": "cementera",
    "cementerbara": "cementerbar",
    "cementerbarare": "cementerbar",
    "cementerbarares": "cementerbar",
    "cementerbaras": "cementerbar",
    "cementerbarast": "cementerbar",
    "cementerbaraste": "cementerbar",
    "cementerbarastes": "cementerbar",
    "cementerbarasts": "cementerbar",
    "cementerbare": "cementerbar",
    "cementerbares": "cementerbar",
    "cementerbarheten": "cementerbarhet",
    "cementerbarhetens": "cementerbarhet",
    "cementerbarhets": "cementerbarhet",
    "cementerbars": "cementerbar",
    "cementerbart": "cementerbar",
    "cementerbarts": "cementerbar",
    "cementeringar": "cementering",
    "cementeringarna": "cementering",
    "cementeringarnas": "cementering",
    "cementeringars": "cementering",
    "cementeringen": "cementering",
    "cementeringens": "cementering",
    "cementerings": "cementering",
    "cementet": "cement",
    "cementets": "cement",
    "cementrören": "cementrör",
    "cementrörens": "cementrör",
    "cementröret": "cementrör",
    "cementrörets": "cementrör",
    "cementrörs": "cementrör",
    "cements": "cement",
    "cenakels": "cenakel",
    "cenaklen": "cenakel",
    "cenaklens": "cenakel",
    "cenakler": "cenakel",
    "cenaklerna": "cenakel",
    "cenaklernas": "cenakel",
    "cenaklers": "cenakel",
    "cenaklet": "cenakel",
    "cenaklets": "cenakel",
    "censorer": "censor",
    "censorerna": "censor",
    "censorernas": "censor",
    "censorers": "censor",
    "censorn": "censor",
    "censorns": "censor",
    "censors": "censor",
    "censuren": "censur",
    "censurens": "censur",
    "censurerad": "censurera",
    "censurerade": "censurera",
    "censurerades": "censurera",
    "censurerads": "censurera",
    "censurerande": "censurera",
    "censureranden": "censurerande",
    "censurerandena": "censurerande",
    "censurerandenas": "censurerande",
    "censurerandens": "censurerande",
    "censurerandes": "censurerande",
    "censurerandet": "censurerande",
    "censurerandets": "censurerande",
    "censurerar": "censurera",
    "censureras": "censurera",
    "censurerat": "censurera",
    "censurerats": "censurera",
    "censurerbara": "censurerbar",
    "censurerbarare": "censurerbar",
    "censurerbarares": "censurerbar",
    "censurerbaras": "censurerbar",
    "censurerbarast": "censurerbar",
    "censurerbaraste": "censurerbar",
    "censurerbarastes": "censurerbar",
    "censurerbarasts": "censurerbar",
    "censurerbare": "censurerbar",
    "censurerbares": "censurerbar",
    "censurerbarheten": "censurerbarhet",
    "censurerbarhetens": "censurerbarhet",
    "censurerbarhets": "censurerbarhet",
    "censurerbars": "censurerbar",
    "censurerbart": "censurerbar",
    "censurerbarts": "censurerbar",
    "censureringar": "censurering",
    "censureringarna": "censurering",
    "censureringarnas": "censurering",
    "censureringars": "censurering",
    "censureringen": "censurering",
    "censureringens": "censurering",
    "censurerings": "censurering",
    "censurs": "censur",
    "censusar": "census",
    "censusarna": "census",
    "censusarnas": "census",
    "censusars": "census",
    "censusen": "census",
    "censusens": "census",
    "centauren": "centaur",
    "centaurens": "centaur",
    "centaurer": "centaur",
    "centaurerna": "centaur",
    "centaurernas": "centaur",
    "centaurers": "centaur",
    "centaurs": "centaur",
    "centen": "cent",
    "centens": "cent",
    "centerbackar": "centerback",
    "centerbackarna": "centerback",
    "centerbackarnas": "centerback",
    "centerbackars": "centerback",
    "centerbacken": "centerback",
    "centerbackens": "centerback",
    "centerbacks": "centerback",
    "centerborden": "centerbord",
    "centerbordens": "centerbord",
    "centerbordet": "centerbord",
    "centerbordets": "centerbord",
    "centerbords": "centerbord",
    "centercourten": "centercourt",
    "centercourtens": "centercourt",
    "centercourts": "centercourt",
    "centerforwardar": "centerforward",
    "centerforwardarna": "centerforward",
    "centerforwardarnas": "centerforward",
    "centerforwardars": "centerforward",
    "centerforwarden": "centerforward",
    "centerforwardens": "centerforward",
    "centerforwards": "centerforward",
    "centerforwardsarna": "centerforward",
    "centerforwardsarnas": "centerforward",
    "centerforwardsen": "centerforward",
    "centerforwardsens": "centerforward",
    "centerhalvar": "centerhalv",
    "centerhalvarna": "centerhalv",
    "centerhalvarnas": "centerhalv",
    "centerhalvars": "centerhalv",
    "centerhalven": "centerhalv",
    "centerhalvens": "centerhalv",
    "centerhalvor": "centerhalv",
    "centerhalvorna": "centerhalv",
    "centerhalvornas": "centerhalv",
    "centerhalvors": "centerhalv",
    "centerhalvs": "centerhalv",
    "centerismen": "centerism",
    "centerismens": "centerism",
    "centerismer": "centerism",
    "centerismerna": "centerism",
    "centerismernas": "centerism",
    "centerismers": "centerism",
    "centerisms": "centerism",
    "centern": "center",
    "centerns": "center",
    "centerpartier": "centerparti",
    "centerpartierna": "centerparti",
    "centerpartiernas": "centerparti",
    "centerpartiers": "centerparti",
    "centerpartiet": "centerparti",
    "centerpartiets": "centerparti",
    "centerpartis": "centerparti",
    "centerpartisten": "centerpartist",
    "centerpartistens": "centerpartist",
    "centerpartister": "centerpartist",
    "centerpartisterna": "centerpartist",
    "centerpartisternas": "centerpartist",
    "centerpartisters": "centerpartist",
    "centerpartists": "centerpartist",
    "centerpartit": "centerparti",
    "centerpartits": "centerparti",
    "centers": "center",
    "centilitern": "centiliter",
    "centiliterna": "centiliter",
    "centiliternas": "centiliter",
    "centiliterns": "centiliter",
    "centiliters": "centiliter",
    "centilongen": "centilong",
    "centilongens": "centilong",
    "centilongs": "centilong",
    "centimetern": "centimeter",
    "centimeterna": "centimeter",
    "centimeternas": "centimeter",
    "centimeterns": "centimeter",
    "centimeters": "centimeter",
    "centimeterskalan": "centimeterskala",
    "centimeterskalans": "centimeterskala",
    "centimeterskalas": "centimeterskala",
    "centimeterskale": "centimeterskala",
    "centimeterskalor": "centimeterskala",
    "centimeterskalorna": "centimeterskala",
    "centimeterskalornas": "centimeterskala",
    "centimeterskalors": "centimeterskala",
    "centimetertjocka": "centimetertjock",
    "centimetertjockare": "centimetertjock",
    "centimetertjockares": "centimetertjock",
    "centimetertjockas": "centimetertjock",
    "centimetertjockast": "centimetertjock",
    "centimetertjockaste": "centimetertjock",
    "centimetertjockastes": "centimetertjock",
    "centimetertjockasts": "centimetertjock",
    "centimetertjocke": "centimetertjock",
    "centimetertjockes": "centimetertjock",
    "centimetertjocks": "centimetertjock",
    "centimetertjockt": "centimetertjock",
    "centimetertjockts": "centimetertjock",
    "centimetrar": "centimeter",
    "centimetrarna": "centimeter",
    "centimetrarnas": "centimeter",
    "centimetrars": "centimeter",
    "centnern": "centner",
    "centnerna": "centner",
    "centnernas": "centner",
    "centnerns": "centner",
    "centners": "centner",
    "centra": "centrum",
    "centrad": "centra",
    "centrade": "centra",
    "centrades": "centra",
    "centrads": "centra",
    "centrala": "central",
    "centralafrikanen": "centralafrikan",
    "centralafrikanens": "centralafrikan",
    "centralafrikaner": "centralafrikan",
    "centralafrikanerna": "centralafrikan",
    "centralafrikanernas": "centralafrikan",
    "centralafrikaners": "centralafrikan",
    "centralafrikans": "centralafrikan",
    "centralafrikanska": "centralafrikansk",
    "centralafrikanskan": "centralafrikanska",
    "centralafrikanskans": "centralafrikanska",
    "centralafrikanskare": "centralafrikansk",
    "centralafrikanskares": "centralafrikansk",
    "centralafrikanskas": "centralafrikanska",
    "centralafrikanskast": "centralafrikansk",
    "centralafrikanskaste": "centralafrikansk",
    "centralafrikanskastes": "centralafrikansk",
    "centralafrikanskasts": "centralafrikansk",
    "centralafrikanske": "centralafrikanska",
    "centralafrikanskes": "centralafrikansk",
    "centralafrikanskor": "centralafrikanska",
    "centralafrikanskorna": "centralafrikanska",
    "centralafrikanskornas": "centralafrikanska",
    "centralafrikanskors": "centralafrikanska",
    "centralafrikansks": "centralafrikansk",
    "centralafrikanskt": "centralafrikansk",
    "centralafrikanskts": "centralafrikansk",
    "centralamerikanska": "centralamerikansk",
    "centralamerikanskare": "centralamerikansk",
    "centralamerikanskares": "centralamerikansk",
    "centralamerikanskas": "centralamerikansk",
    "centralamerikanskast": "centralamerikansk",
    "centralamerikanskaste": "centralamerikansk",
    "centralamerikanskastes": "centralamerikansk",
    "centralamerikanskasts": "centralamerikansk",
    "centralamerikanske": "centralamerikansk",
    "centralamerikanskes": "centralamerikansk",
    "centralamerikansks": "centralamerikansk",
    "centralamerikanskt": "centralamerikansk",
    "centralamerikanskts": "centralamerikansk",
    "centralanstalten": "centralanstalt",
    "centralanstaltens": "centralanstalt",
    "centralanstalter": "centralanstalt",
    "centralanstalterna": "centralanstalt",
    "centralanstalternas": "centralanstalt",
    "centralanstalters": "centralanstalt",
    "centralanstalts": "centralanstalt",
    "centralantennen": "centralantenn",
    "centralantennens": "centralantenn",
    "centralantenner": "centralantenn",
    "centralantennerna": "centralantenn",
    "centralantennernas": "centralantenn",
    "centralantenners": "centralantenn",
    "centralantenns": "centralantenn",
    "centralare": "central",
    "centralares": "central",
    "centralas": "central",
    "centralast": "central",
    "centralaste": "central",
    "centralastes": "central",
    "centralasts": "central",
    "centralbanken": "centralbank",
    "centralbankens": "centralbank",
    "centralbanker": "centralbank",
    "centralbankerna": "centralbank",
    "centralbankernas": "centralbank",
    "centralbankers": "centralbank",
    "centralbanks": "centralbank",
    "centralbankschefen": "centralbankschef",
    "centralbankschefens": "centralbankschef",
    "centralbankschefer": "centralbankschef",
    "centralbankscheferna": "centralbankschef",
    "centralbankschefernas": "centralbankschef",
    "centralbankschefers": "centralbankschef",
    "centralbankschefs": "centralbankschef",
    "centralbyggnaden": "centralbyggnad",
    "centralbyggnadens": "centralbyggnad",
    "centralbyggnader": "centralbyggnad",
    "centralbyggnaderna": "centralbyggnad",
    "centralbyggnadernas": "centralbyggnad",
    "centralbyggnaders": "centralbyggnad",
    "centralbyggnads": "centralbyggnad",
    "centralbyråer": "centralbyrå",
    "centralbyråerna": "centralbyrå",
    "centralbyråernas": "centralbyrå",
    "centralbyråers": "centralbyrå",
    "centralbyrån": "centralbyrå",
    "centralbyråns": "centralbyrå",
    "centralbyrås": "centralbyrå",
    "centraldirigerade": "centraldirigerad",
    "centraldirigerades": "centraldirigerad",
    "centraldirigerads": "centraldirigerad",
    "centraldirigerat": "centraldirigerad",
    "centraldirigerats": "centraldirigerad",
    "centrale": "central",
    "centralen": "central",
    "centralenheten": "centralenhet",
    "centralenhetens": "centralenhet",
    "centralenheter": "centralenhet",
    "centralenheterna": "centralenhet",
    "centralenheternas": "centralenhet",
    "centralenheters": "centralenhet",
    "centralenhets": "centralenhet",
    "centralens": "central",
    "centraler": "central",
    "centralerna": "central",
    "centralernas": "central",
    "centralers": "central",
    "centrales": "central",
    "centraleuropeiska": "centraleuropeisk",
    "centraleuropeiskare": "centraleuropeisk",
    "centraleuropeiskares": "centraleuropeisk",
    "centraleuropeiskas": "centraleuropeisk",
    "centraleuropeiskast": "centraleuropeisk",
    "centraleuropeiskaste": "centraleuropeisk",
    "centraleuropeiskastes": "centraleuropeisk",
    "centraleuropeiskasts": "centraleuropeisk",
    "centraleuropeiske": "centraleuropeisk",
    "centraleuropeiskes": "centraleuropeisk",
    "centraleuropeisks": "centraleuropeisk",
    "centraleuropeiskt": "centraleuropeisk",
    "centraleuropeiskts": "centraleuropeisk",
    "centralfiguren": "centralfigur",
    "centralfigurens": "centralfigur",
    "centralfigurer": "centralfigur",
    "centralfigurerna": "centralfigur",
    "centralfigurernas": "centralfigur",
    "centralfigurers": "centralfigur",
    "centralfigurs": "centralfigur",
    "centralförbunden": "centralförbund",
    "centralförbundens": "centralförbund",
    "centralförbundet": "centralförbund",
    "centralförbundets": "centralförbund",
    "centralförbunds": "centralförbund",
    "centralförsvaret": "centralförsvar",
    "centralförsvarets": "centralförsvar",
    "centralförsvars": "centralförsvar",
    "centralförvaltningar": "centralförvaltning",
    "centralförvaltningarna": "centralförvaltning",
    "centralförvaltningarnas": "centralförvaltning",
    "centralförvaltningars": "centralförvaltning",
    "centralförvaltningen": "centralförvaltning",
    "centralförvaltningens": "centralförvaltning",
    "centralförvaltnings": "centralförvaltning",
    "centralgestalten": "centralgestalt",
    "centralgestaltens": "centralgestalt",
    "centralgestalter": "centralgestalt",
    "centralgestalterna": "centralgestalt",
    "centralgestalternas": "centralgestalt",
    "centralgestalters": "centralgestalt",
    "centralgestalts": "centralgestalt",
    "centraliserad": "centralisera",
    "centraliserade": "centralisera",
    "centraliserades": "centralisera",
    "centraliserads": "centralisera",
    "centraliserande": "centralisera",
    "centraliseranden": "centraliserande",
    "centraliserandena": "centraliserande",
    "centraliserandenas": "centraliserande",
    "centraliserandens": "centraliserande",
    "centraliserandes": "centraliserande",
    "centraliserandet": "centraliserande",
    "centraliserandets": "centraliserande",
    "centraliserar": "centralisera",
    "centraliseras": "centralisera",
    "centraliserat": "centralisera",
    "centraliserats": "centralisera",
    "centraliserbara": "centraliserbar",
    "centraliserbarare": "centraliserbar",
    "centraliserbarares": "centraliserbar",
    "centraliserbaras": "centraliserbar",
    "centraliserbarast": "centraliserbar",
    "centraliserbaraste": "centraliserbar",
    "centraliserbarastes": "centraliserbar",
    "centraliserbarasts": "centraliserbar",
    "centraliserbare": "centraliserbar",
    "centraliserbares": "centraliserbar",
    "centraliserbarheten": "centraliserbarhet",
    "centraliserbarhetens": "centraliserbarhet",
    "centraliserbarhets": "centraliserbarhet",
    "centraliserbars": "centraliserbar",
    "centraliserbart": "centraliserbar",
    "centraliserbarts": "centraliserbar",
    "centraliseringar": "centralisering",
    "centraliseringarna": "centralisering",
    "centraliseringarnas": "centralisering",
    "centraliseringars": "centralisering",
    "centraliseringen": "centralisering",
    "centraliseringens": "centralisering",
    "centraliserings": "centralisering",
    "centralismen": "centralism",
    "centralismens": "centralism",
    "centralismer": "centralism",
    "centralismerna": "centralism",
    "centralismernas": "centralism",
    "centralismers": "centralism",
    "centralisms": "centralism",
    "centralistiska": "centralistisk",
    "centralistiskare": "centralistisk",
    "centralistiskares": "centralistisk",
    "centralistiskas": "centralistisk",
    "centralistiskast": "centralistisk",
    "centralistiskaste": "centralistisk",
    "centralistiskastes": "centralistisk",
    "centralistiskasts": "centralistisk",
    "centralistiske": "centralistisk",
    "centralistiskes": "centralistisk",
    "centralistisks": "centralistisk",
    "centralistiskt": "centralistisk",
    "centralistiskts": "centralistisk",
    "centralkommittéer": "centralkommitté",
    "centralkommittéerna": "centralkommitté",
    "centralkommittéernas": "centralkommitté",
    "centralkommittéers": "centralkommitté",
    "centralkommittén": "centralkommitté",
    "centralkommitténs": "centralkommitté",
    "centralkommittés": "centralkommitté",
    "centralkontoren": "centralkontor",
    "centralkontorens": "centralkontor",
    "centralkontoret": "centralkontor",
    "centralkontorets": "centralkontor",
    "centralkontors": "centralkontor",
    "centralkyrk": "centralkyrka",
    "centralkyrkan": "centralkyrka",
    "centralkyrkans": "centralkyrka",
    "centralkyrkas": "centralkyrka",
    "centralkyrke": "centralkyrka",
    "centralkyrko": "centralkyrka",
    "centralkyrkor": "centralkyrka",
    "centralkyrkorna": "centralkyrka",
    "centralkyrkornas": "centralkyrka",
    "centralkyrkors": "centralkyrka",
    "centralkyrks": "centralkyrka",
    "centrallasaretten": "centrallasarett",
    "centrallasarettens": "centrallasarett",
    "centrallasarettet": "centrallasarett",
    "centrallasarettets": "centrallasarett",
    "centrallasaretts": "centrallasarett",
    "centrallyriken": "centrallyrik",
    "centrallyrikens": "centrallyrik",
    "centrallyriks": "centrallyrik",
    "centrallyriska": "centrallyrisk",
    "centrallyriskare": "centrallyrisk",
    "centrallyriskares": "centrallyrisk",
    "centrallyriskas": "centrallyrisk",
    "centrallyriskast": "centrallyrisk",
    "centrallyriskaste": "centrallyrisk",
    "centrallyriskastes": "centrallyrisk",
    "centrallyriskasts": "centrallyrisk",
    "centrallyriske": "centrallyrisk",
    "centrallyriskes": "centrallyrisk",
    "centrallyrisks": "centrallyrisk",
    "centrallyriskt": "centrallyrisk",
    "centrallyriskts": "centrallyrisk",
    "centralmakten": "centralmakt",
    "centralmaktens": "centralmakt",
    "centralmakter": "centralmakt",
    "centralmakterna": "centralmakt",
    "centralmakternas": "centralmakt",
    "centralmakters": "centralmakt",
    "centralmakts": "centralmakt",
    "centralnämnden": "centralnämnd",
    "centralnämndens": "centralnämnd",
    "centralnämnder": "centralnämnd",
    "centralnämnderna": "centralnämnd",
    "centralnämndernas": "centralnämnd",
    "centralnämnders": "centralnämnd",
    "centralnämnds": "centralnämnd",
    "centralorganisationen": "centralorganisation",
    "centralorganisationens": "centralorganisation",
    "centralorganisationer": "centralorganisation",
    "centralorganisationerna": "centralorganisation",
    "centralorganisationernas": "centralorganisation",
    "centralorganisationers": "centralorganisation",
    "centralorganisations": "centralorganisation",
    "centralorten": "centralort",
    "centralortens": "centralort",
    "centralorter": "centralort",
    "centralorterna": "centralort",
    "centralorternas": "centralort",
    "centralorters": "centralort",
    "centralorts": "centralort",
    "centralradion": "centralradio",
    "centralradions": "centralradio",
    "centralradios": "centralradio",
    "centralregeringar": "centralregering",
    "centralregeringarna": "centralregering",
    "centralregeringarnas": "centralregering",
    "centralregeringars": "centralregering",
    "centralregeringen": "centralregering",
    "centralregeringens": "centralregering",
    "centralregerings": "centralregering",
    "centralrörelsen": "centralrörelse",
    "centralrörelsens": "centralrörelse",
    "centralrörelser": "centralrörelse",
    "centralrörelserna": "centralrörelse",
    "centralrörelsernas": "centralrörelse",
    "centralrörelsers": "centralrörelse",
    "centralrörelses": "centralrörelse",
    "centrals": "central",
    "centralskolan": "centralskola",
    "centralskolans": "centralskola",
    "centralskolas": "centralskola",
    "centralskole": "centralskola",
    "centralskolor": "centralskola",
    "centralskolorna": "centralskola",
    "centralskolornas": "centralskola",
    "centralskolors": "centralskola",
    "centralstationen": "centralstation",
    "centralstationens": "centralstation",
    "centralstationer": "centralstation",
    "centralstationerna": "centralstation",
    "centralstationernas": "centralstation",
    "centralstationers": "centralstation",
    "centralstations": "centralstation",
    "centralstimulantian": "centralstimulantia",
    "centralstimulantiana": "centralstimulantia",
    "centralstimulantianas": "centralstimulantia",
    "centralstimulantians": "centralstimulantia",
    "centralstimulantias": "centralstimulantia",
    "centralstyrda": "centralstyrd",
    "centralstyrdare": "centralstyrd",
    "centralstyrdares": "centralstyrd",
    "centralstyrdas": "centralstyrd",
    "centralstyrdast": "centralstyrd",
    "centralstyrdaste": "centralstyrd",
    "centralstyrdastes": "centralstyrd",
    "centralstyrdasts": "centralstyrd",
    "centralstyrde": "centralstyrd",
    "centralstyrdes": "centralstyrd",
    "centralstyrds": "centralstyrd",
    "centralstyrelsen": "centralstyrelse",
    "centralstyrelsens": "centralstyrelse",
    "centralstyrelser": "centralstyrelse",
    "centralstyrelserna": "centralstyrelse",
    "centralstyrelsernas": "centralstyrelse",
    "centralstyrelsers": "centralstyrelse",
    "centralstyrelses": "centralstyrelse",
    "centralstyrt": "centralstyrd",
    "centralstyrts": "centralstyrd",
    "centralt": "central",
    "centralts": "central",
    "centralvärmen": "centralvärme",
    "centralvärmens": "centralvärme",
    "centralvärmes": "centralvärme",
    "centrana": "centrum",
    "centranas": "centrum",
    "centrande": "centra",
    "centranden": "centrande",
    "centrandena": "centrande",
    "centrandenas": "centrande",
    "centrandens": "centrande",
    "centrandes": "centrande",
    "centrandet": "centrande",
    "centrandets": "centrande",
    "centrar": "centra",
    "centrarna": "center",
    "centrarnas": "center",
    "centrars": "center",
    "centras": "centrum",
    "centrat": "centra",
    "centrats": "centra",
    "centrecourten": "centrecourt",
    "centrecourtens": "centrecourt",
    "centrecourts": "centrecourt",
    "centrer": "centrum",
    "centrerad": "centrera",
    "centrerade": "centrera",
    "centrerades": "centrera",
    "centrerads": "centrera",
    "centrerande": "centrera",
    "centreranden": "centrerande",
    "centrerandena": "centrerande",
    "centrerandenas": "centrerande",
    "centrerandens": "centrerande",
    "centrerandes": "centrerande",
    "centrerandet": "centrerande",
    "centrerandets": "centrerande",
    "centrerar": "centrera",
    "centreras": "centrera",
    "centrerat": "centrera",
    "centrerats": "centrera",
    "centrerbara": "centrerbar",
    "centrerbarare": "centrerbar",
    "centrerbarares": "centrerbar",
    "centrerbaras": "centrerbar",
    "centrerbarast": "centrerbar",
    "centrerbaraste": "centrerbar",
    "centrerbarastes": "centrerbar",
    "centrerbarasts": "centrerbar",
    "centrerbare": "centrerbar",
    "centrerbares": "centrerbar",
    "centrerbarheten": "centrerbarhet",
    "centrerbarhetens": "centrerbarhet",
    "centrerbarhets": "centrerbarhet",
    "centrerbars": "centrerbar",
    "centrerbart": "centrerbar",
    "centrerbarts": "centrerbar",
    "centreringar": "centrering",
    "centreringarna": "centrering",
    "centreringarnas": "centrering",
    "centreringars": "centrering",
    "centreringen": "centrering",
    "centreringens": "centrering",
    "centrerings": "centrering",
    "centrerna": "centrum",
    "centrernas": "centrum",
    "centrers": "centrum",
    "centret": "centrum",
    "centrets": "centrum",
    "centrifugala": "centrifugal",
    "centrifugalare": "centrifugal",
    "centrifugalares": "centrifugal",
    "centrifugalas": "centrifugal",
    "centrifugalast": "centrifugal",
    "centrifugalaste": "centrifugal",
    "centrifugalastes": "centrifugal",
    "centrifugalasts": "centrifugal",
    "centrifugale": "centrifugal",
    "centrifugales": "centrifugal",
    "centrifugalkraften": "centrifugalkraft",
    "centrifugalkraftens": "centrifugalkraft",
    "centrifugalkrafts": "centrifugalkraft",
    "centrifugalpumpar": "centrifugalpump",
    "centrifugalpumparna": "centrifugalpump",
    "centrifugalpumparnas": "centrifugalpump",
    "centrifugalpumpars": "centrifugalpump",
    "centrifugalpumpen": "centrifugalpump",
    "centrifugalpumpens": "centrifugalpump",
    "centrifugalpumps": "centrifugalpump",
    "centrifugals": "centrifugal",
    "centrifugalt": "centrifugal",
    "centrifugalts": "centrifugal",
    "centrifugen": "centrifug",
    "centrifugens": "centrifug",
    "centrifuger": "centrifug",
    "centrifugerad": "centrifugera",
    "centrifugerade": "centrifugera",
    "centrifugerades": "centrifugera",
    "centrifugerads": "centrifugera",
    "centrifugerande": "centrifugera",
    "centrifugeranden": "centrifugerande",
    "centrifugerandena": "centrifugerande",
    "centrifugerandenas": "centrifugerande",
    "centrifugerandens": "centrifugerande",
    "centrifugerandes": "centrifugerande",
    "centrifugerandet": "centrifugerande",
    "centrifugerandets": "centrifugerande",
    "centrifugerar": "centrifugera",
    "centrifugeras": "centrifugera",
    "centrifugerat": "centrifugera",
    "centrifugerats": "centrifugera",
    "centrifugerbara": "centrifugerbar",
    "centrifugerbarare": "centrifugerbar",
    "centrifugerbarares": "centrifugerbar",
    "centrifugerbaras": "centrifugerbar",
    "centrifugerbarast": "centrifugerbar",
    "centrifugerbaraste": "centrifugerbar",
    "centrifugerbarastes": "centrifugerbar",
    "centrifugerbarasts": "centrifugerbar",
    "centrifugerbare": "centrifugerbar",
    "centrifugerbares": "centrifugerbar",
    "centrifugerbarheten": "centrifugerbarhet",
    "centrifugerbarhetens": "centrifugerbarhet",
    "centrifugerbarhets": "centrifugerbarhet",
    "centrifugerbars": "centrifugerbar",
    "centrifugerbart": "centrifugerbar",
    "centrifugerbarts": "centrifugerbar",
    "centrifugeringar": "centrifugering",
    "centrifugeringarna": "centrifugering",
    "centrifugeringarnas": "centrifugering",
    "centrifugeringars": "centrifugering",
    "centrifugeringen": "centrifugering",
    "centrifugeringens": "centrifugering",
    "centrifugerings": "centrifugering",
    "centrifugerna": "centrifug",
    "centrifugernas": "centrifug",
    "centrifugers": "centrifug",
    "centrifugs": "centrifug",
    "centripetala": "centripetal",
    "centripetalare": "centripetal",
    "centripetalares": "centripetal",
    "centripetalas": "centripetal",
    "centripetalast": "centripetal",
    "centripetalaste": "centripetal",
    "centripetalastes": "centripetal",
    "centripetalasts": "centripetal",
    "centripetale": "centripetal",
    "centripetales": "centripetal",
    "centripetalkraften": "centripetalkraft",
    "centripetalkraftens": "centripetalkraft",
    "centripetalkrafts": "centripetalkraft",
    "centripetals": "centripetal",
    "centripetalt": "centripetal",
    "centripetalts": "centripetal",
    "centriska": "centrisk",
    "centriskare": "centrisk",
    "centriskares": "centrisk",
    "centriskas": "centrisk",
    "centriskast": "centrisk",
    "centriskaste": "centrisk",
    "centriskastes": "centrisk",
    "centriskasts": "centrisk",
    "centriske": "centrisk",
    "centriskes": "centrisk",
    "centrisks": "centrisk",
    "centriskt": "centrisk",
    "centriskts": "centrisk",
    "centrumen": "centrum",
    "centrumens": "centrum",
    "centrumet": "centrum",
    "centrumets": "centrum",
    "centrums": "centrum",
    "cents": "cent",
    "centumspråken": "centumspråk",
    "centumspråkens": "centumspråk",
    "centumspråket": "centumspråk",
    "centumspråkets": "centumspråk",
    "centumspråks": "centumspråk",
    "ceraten": "cerat",
    "ceratens": "cerat",
    "cerater": "cerat",
    "ceraterna": "cerat",
    "ceraternas": "cerat",
    "ceraters": "cerat",
    "ceratet": "cerat",
    "ceratets": "cerat",
    "cerats": "cerat",
    "cerealie": "cerealier",
    "cerealierna": "cerealier",
    "cerealiernas": "cerealier",
    "cerealiers": "cerealier",
    "cerebrala": "cerebral",
    "cerebralare": "cerebral",
    "cerebralares": "cerebral",
    "cerebralas": "cerebral",
    "cerebralast": "cerebral",
    "cerebralaste": "cerebral",
    "cerebralastes": "cerebral",
    "cerebralasts": "cerebral",
    "cerebrale": "cerebral",
    "cerebrales": "cerebral",
    "cerebrals": "cerebral",
    "cerebralt": "cerebral",
    "cerebralts": "cerebral",
    "cerebrospinala": "cerebrospinal",
    "cerebrospinalare": "cerebrospinal",
    "cerebrospinalares": "cerebrospinal",
    "cerebrospinalas": "cerebrospinal",
    "cerebrospinalast": "cerebrospinal",
    "cerebrospinalaste": "cerebrospinal",
    "cerebrospinalastes": "cerebrospinal",
    "cerebrospinalasts": "cerebrospinal",
    "cerebrospinale": "cerebrospinal",
    "cerebrospinales": "cerebrospinal",
    "cerebrospinals": "cerebrospinal",
    "cerebrospinalt": "cerebrospinal",
    "cerebrospinalts": "cerebrospinal",
    "cerebrospinalvätskan": "cerebrospinalvätska",
    "cerebrospinalvätskans": "cerebrospinalvätska",
    "cerebrospinalvätskas": "cerebrospinalvätska",
    "cerebrospinalvätske": "cerebrospinalvätska",
    "ceremonielen": "ceremoniel",
    "ceremonielens": "ceremoniel",
    "ceremonielet": "ceremoniel",
    "ceremonielets": "ceremoniel",
    "ceremoniella": "ceremoniell",
    "ceremoniellare": "ceremoniell",
    "ceremoniellares": "ceremoniell",
    "ceremoniellas": "ceremoniell",
    "ceremoniellast": "ceremoniell",
    "ceremoniellaste": "ceremoniell",
    "ceremoniellastes": "ceremoniell",
    "ceremoniellasts": "ceremoniell",
    "ceremonielle": "ceremoniell",
    "ceremonielles": "ceremoniell",
    "ceremoniells": "ceremoniell",
    "ceremoniellt": "ceremoniell",
    "ceremoniellts": "ceremoniell",
    "ceremoniels": "ceremoniel",
    "ceremonien": "ceremoni",
    "ceremoniens": "ceremoni",
    "ceremonier": "ceremoni",
    "ceremonierna": "ceremoni",
    "ceremoniernas": "ceremoni",
    "ceremoniers": "ceremoni",
    "ceremonimästar": "ceremonimästare",
    "ceremonimästaren": "ceremonimästare",
    "ceremonimästarens": "ceremonimästare",
    "ceremonimästares": "ceremonimästare",
    "ceremonimästarna": "ceremonimästare",
    "ceremonimästarnas": "ceremonimästare",
    "ceremonin": "ceremoni",
    "ceremonins": "ceremoni",
    "ceremonis": "ceremoni",
    "ceremoniösa": "ceremoniös",
    "ceremoniösare": "ceremoniös",
    "ceremoniösares": "ceremoniös",
    "ceremoniösas": "ceremoniös",
    "ceremoniösast": "ceremoniös",
    "ceremoniösaste": "ceremoniös",
    "ceremoniösastes": "ceremoniös",
    "ceremoniösasts": "ceremoniös",
    "ceremoniöse": "ceremoniös",
    "ceremoniöses": "ceremoniös",
    "ceremoniöst": "ceremoniös",
    "ceremoniösts": "ceremoniös",
    "ceriet": "cerium",
    "ceriets": "cerium",
    "cerisefärgade": "cerisefärgad",
    "cerisefärgades": "cerisefärgad",
    "cerisefärgads": "cerisefärgad",
    "cerisefärgat": "cerisefärgad",
    "cerisefärgats": "cerisefärgad",
    "cerisen": "cerise",
    "cerisens": "cerise",
    "ceriser": "cerise",
    "ceriserna": "cerise",
    "cerisernas": "cerise",
    "cerisers": "cerise",
    "cerises": "cerise",
    "ceriumet": "cerium",
    "ceriumets": "cerium",
    "ceriums": "cerium",
    "cernerad": "cernera",
    "cernerade": "cernera",
    "cernerades": "cernera",
    "cernerads": "cernera",
    "cernerande": "cernera",
    "cerneranden": "cernerande",
    "cernerandena": "cernerande",
    "cernerandenas": "cernerande",
    "cernerandens": "cernerande",
    "cernerandes": "cernerande",
    "cernerandet": "cernerande",
    "cernerandets": "cernerande",
    "cernerar": "cernera",
    "cerneras": "cernera",
    "cernerat": "cernera",
    "cernerats": "cernera",
    "cernerbara": "cernerbar",
    "cernerbarare": "cernerbar",
    "cernerbarares": "cernerbar",
    "cernerbaras": "cernerbar",
    "cernerbarast": "cernerbar",
    "cernerbaraste": "cernerbar",
    "cernerbarastes": "cernerbar",
    "cernerbarasts": "cernerbar",
    "cernerbare": "cernerbar",
    "cernerbares": "cernerbar",
    "cernerbarheten": "cernerbarhet",
    "cernerbarhetens": "cernerbarhet",
    "cernerbarhets": "cernerbarhet",
    "cernerbars": "cernerbar",
    "cernerbart": "cernerbar",
    "cernerbarts": "cernerbar",
    "cerneringar": "cernering",
    "cerneringarna": "cernering",
    "cerneringarnas": "cernering",
    "cerneringars": "cernering",
    "cerneringen": "cernering",
    "cerneringens": "cernering",
    "cernerings": "cernering",
    "certen": "cert",
    "certens": "cert",
    "certepartier": "certeparti",
    "certepartierna": "certeparti",
    "certepartiernas": "certeparti",
    "certepartiers": "certeparti",
    "certepartiet": "certeparti",
    "certepartiets": "certeparti",
    "certepartis": "certeparti",
    "certepartit": "certeparti",
    "certepartits": "certeparti",
    "certer": "cert",
    "certerna": "cert",
    "certernas": "cert",
    "certers": "cert",
    "certifierad": "certifiera",
    "certifierade": "certifiera",
    "certifierades": "certifiera",
    "certifierads": "certifiera",
    "certifierande": "certifiera",
    "certifieranden": "certifierande",
    "certifierandena": "certifierande",
    "certifierandenas": "certifierande",
    "certifierandens": "certifierande",
    "certifierandes": "certifierande",
    "certifierandet": "certifierande",
    "certifierandets": "certifierande",
    "certifierar": "certifiera",
    "certifieras": "certifiera",
    "certifierat": "certifiera",
    "certifierats": "certifiera",
    "certifieringar": "certifiering",
    "certifieringarna": "certifiering",
    "certifieringarnas": "certifiering",
    "certifieringars": "certifiering",
    "certifieringen": "certifiering",
    "certifieringens": "certifiering",
    "certifierings": "certifiering",
    "certifikaten": "certifikat",
    "certifikatens": "certifikat",
    "certifikatet": "certifikat",
    "certifikatets": "certifikat",
    "certifikats": "certifikat",
    "certs": "cert",
    "cervelatkorven": "cervelatkorv",
    "cervelatkorvens": "cervelatkorv",
    "cervelatkorvs": "cervelatkorv",
    "cesariska": "cesarisk",
    "cesariskare": "cesarisk",
    "cesariskares": "cesarisk",
    "cesariskas": "cesarisk",
    "cesariskast": "cesarisk",
    "cesariskaste": "cesarisk",
    "cesariskastes": "cesarisk",
    "cesariskasts": "cesarisk",
    "cesariske": "cesarisk",
    "cesariskes": "cesarisk",
    "cesarisks": "cesarisk",
    "cesariskt": "cesarisk",
    "cesariskts": "cesarisk",
    "cesarismen": "cesarism",
    "cesarismens": "cesarism",
    "cesarismer": "cesarism",
    "cesarismerna": "cesarism",
    "cesarismernas": "cesarism",
    "cesarismers": "cesarism",
    "cesarisms": "cesarism",
    "cesiet": "cesium",
    "cesiets": "cesium",
    "cesium-137-s": "cesium-137",
    "cesium-137:s": "cesium-137",
    "cesiumet": "cesium",
    "cesiumets": "cesium",
    "cesiums": "cesium",
    "cessionen": "cession",
    "cessionens": "cession",
    "cessioner": "cession",
    "cessionerna": "cession",
    "cessionernas": "cession",
    "cessioners": "cession",
    "cessions": "cession",
    "cesuren": "cesur",
    "cesurens": "cesur",
    "cesurer": "cesur",
    "cesurerna": "cesur",
    "cesurernas": "cesur",
    "cesurers": "cesur",
    "cesurs": "cesur",
    "cha-chan": "cha-cha",
    "cha-chans": "cha-cha",
    "cha-chas": "cha-cha",
    "chagrinen": "chagrin",
    "chagrinens": "chagrin",
    "chagrinet": "chagrin",
    "chagrinets": "chagrin",
    "chagrins": "chagrin",
    "chagrängen": "chagräng",
    "chagrängens": "chagräng",
    "chagränget": "chagräng",
    "chagrängets": "chagräng",
    "chagrängs": "chagräng",
    "chamotten": "chamotte",
    "chamottens": "chamotte",
    "chamottes": "chamotte",
    "champagneflask": "champagneflaska",
    "champagneflaskan": "champagneflaska",
    "champagneflaskans": "champagneflaska",
    "champagneflaskas": "champagneflaska",
    "champagneflaske": "champagneflaska",
    "champagneflaskor": "champagneflaska",
    "champagneflaskorna": "champagneflaska",
    "champagneflaskornas": "champagneflaska",
    "champagneflaskors": "champagneflaska",
    "champagneglasen": "champagneglas",
    "champagneglasens": "champagneglas",
    "champagneglaset": "champagneglas",
    "champagneglasets": "champagneglas",
    "champagnekorkar": "champagnekork",
    "champagnekorkarna": "champagnekork",
    "champagnekorkarnas": "champagnekork",
    "champagnekorkars": "champagnekork",
    "champagnekorken": "champagnekork",
    "champagnekorkens": "champagnekork",
    "champagnekorks": "champagnekork",
    "champagnen": "champagne",
    "champagnens": "champagne",
    "champagner": "champagne",
    "champagnerna": "champagne",
    "champagnernas": "champagne",
    "champagners": "champagne",
    "champagnes": "champagne",
    "champagnesabeln": "champagnesabel",
    "champagnesabelns": "champagnesabel",
    "champagnesabels": "champagnesabel",
    "champagnesablar": "champagnesabel",
    "champagnesablarna": "champagnesabel",
    "champagnesablarnas": "champagnesabel",
    "champagnesablars": "champagnesabel",
    "champagnevispar": "champagnevisp",
    "champagnevisparna": "champagnevisp",
    "champagnevisparnas": "champagnevisp",
    "champagnevispars": "champagnevisp",
    "champagnevispen": "champagnevisp",
    "champagnevispens": "champagnevisp",
    "champagnevisps": "champagnevisp",
    "champinjonbäddar": "champinjonbädd",
    "champinjonbäddarna": "champinjonbädd",
    "champinjonbäddarnas": "champinjonbädd",
    "champinjonbäddars": "champinjonbädd",
    "champinjonbädden": "champinjonbädd",
    "champinjonbäddens": "champinjonbädd",
    "champinjonbädds": "champinjonbädd",
    "champinjonen": "champinjon",
    "champinjonens": "champinjon",
    "champinjoner": "champinjon",
    "champinjonerna": "champinjon",
    "champinjonernas": "champinjon",
    "champinjoners": "champinjon",
    "champinjons": "champinjon",
    "championaten": "championat",
    "championatens": "championat",
    "championatet": "championat",
    "championatets": "championat",
    "championats": "championat",
    "championen": "champion",
    "championens": "champion",
    "champions": "champion",
    "championsarna": "champion",
    "championsarnas": "champion",
    "championsen": "champion",
    "championsens": "champion",
    "changemangen": "changemang",
    "changemangens": "changemang",
    "changemanger": "changemang",
    "changemangerna": "changemang",
    "changemangernas": "changemang",
    "changemangers": "changemang",
    "changemanget": "changemang",
    "changemangets": "changemang",
    "changemangs": "changemang",
    "changerade": "changera",
    "changerades": "changera",
    "changerande": "changera",
    "changeranden": "changerande",
    "changerandena": "changerande",
    "changerandenas": "changerande",
    "changerandens": "changerande",
    "changerandes": "changerande",
    "changerandet": "changerande",
    "changerandets": "changerande",
    "changerar": "changera",
    "changeras": "changera",
    "changerat": "changera",
    "changerats": "changera",
    "changeringar": "changering",
    "changeringarna": "changering",
    "changeringarnas": "changering",
    "changeringars": "changering",
    "changeringen": "changering",
    "changeringens": "changering",
    "changerings": "changering",
    "changserade": "changsera",
    "changserades": "changsera",
    "changserande": "changsera",
    "changseranden": "changserande",
    "changserandena": "changserande",
    "changserandenas": "changserande",
    "changserandens": "changserande",
    "changserandes": "changserande",
    "changserandet": "changserande",
    "changserandets": "changserande",
    "changserar": "changsera",
    "changseras": "changsera",
    "changserat": "changsera",
    "changserats": "changsera",
    "changseringar": "changsering",
    "changseringarna": "changsering",
    "changseringarnas": "changsering",
    "changseringars": "changsering",
    "changseringen": "changsering",
    "changseringens": "changsering",
    "changserings": "changsering",
    "chansade": "chansa",
    "chansades": "chansa",
    "chansande": "chansa",
    "chansanden": "chansande",
    "chansandena": "chansande",
    "chansandenas": "chansande",
    "chansandens": "chansande",
    "chansandes": "chansande",
    "chansandet": "chansande",
    "chansandets": "chansande",
    "chansar": "chansa",
    "chansartade": "chansartad",
    "chansartades": "chansartad",
    "chansartads": "chansartad",
    "chansartat": "chansartad",
    "chansartats": "chansartad",
    "chansas": "chansa",
    "chansat": "chansa",
    "chansats": "chansa",
    "chansen": "chans",
    "chansens": "chans",
    "chanser": "chans",
    "chanserade": "chansera",
    "chanserades": "chansera",
    "chanserande": "chansera",
    "chanseranden": "chanserande",
    "chanserandena": "chanserande",
    "chanserandenas": "chanserande",
    "chanserandens": "chanserande",
    "chanserandes": "chanserande",
    "chanserandet": "chanserande",
    "chanserandets": "chanserande",
    "chanserar": "chansera",
    "chanseras": "chansera",
    "chanserat": "chansera",
    "chanserats": "chansera",
    "chanseringar": "chansering",
    "chanseringarna": "chansering",
    "chanseringarnas": "chansering",
    "chanseringars": "chansering",
    "chanseringen": "chansering",
    "chanseringens": "chansering",
    "chanserings": "chansering",
    "chanserna": "chans",
    "chansernas": "chans",
    "chansers": "chans",
    "chanslösa": "chanslös",
    "chanslösare": "chanslös",
    "chanslösares": "chanslös",
    "chanslösas": "chanslös",
    "chanslösast": "chanslös",
    "chanslösaste": "chanslös",
    "chanslösastes": "chanslös",
    "chanslösasts": "chanslös",
    "chanslöse": "chanslös",
    "chanslöses": "chanslös",
    "chanslösheten": "chanslöshet",
    "chanslöshetens": "chanslöshet",
    "chanslöshets": "chanslöshet",
    "chanslöst": "chanslös",
    "chanslösts": "chanslös",
    "chansmässiga": "chansmässig",
    "chansmässigare": "chansmässig",
    "chansmässigares": "chansmässig",
    "chansmässigas": "chansmässig",
    "chansmässigast": "chansmässig",
    "chansmässigaste": "chansmässig",
    "chansmässigastes": "chansmässig",
    "chansmässigasts": "chansmässig",
    "chansmässige": "chansmässig",
    "chansmässiges": "chansmässig",
    "chansmässigs": "chansmässig",
    "chansmässigt": "chansmässig",
    "chansmässigts": "chansmässig",
    "chansningar": "chansning",
    "chansningarna": "chansning",
    "chansningarnas": "chansning",
    "chansningars": "chansning",
    "chansningen": "chansning",
    "chansningens": "chansning",
    "chansnings": "chansning",
    "chansonen": "chanson",
    "chansonens": "chanson",
    "chansoner": "chanson",
    "chansonerna": "chanson",
    "chansonernas": "chanson",
    "chansoners": "chanson",
    "chansonetten": "chansonett",
    "chansonettens": "chansonett",
    "chansonetter": "chansonett",
    "chansonetterna": "chansonett",
    "chansonetternas": "chansonett",
    "chansonetters": "chansonett",
    "chansonetts": "chansonett",
    "chansons": "chanson",
    "chanstagar": "chanstagare",
    "chanstagaren": "chanstagare",
    "chanstagarens": "chanstagare",
    "chanstagares": "chanstagare",
    "chanstagarna": "chanstagare",
    "chanstagarnas": "chanstagare",
    "chanstagningar": "chanstagning",
    "chanstagningarna": "chanstagning",
    "chanstagningarnas": "chanstagning",
    "chanstagningars": "chanstagning",
    "chanstagningen": "chanstagning",
    "chanstagningens": "chanstagning",
    "chanstagnings": "chanstagning",
    "chapeau-claquen": "chapeau-claque",
    "chapeau-claquens": "chapeau-claque",
    "chapeau-claquer": "chapeau-claque",
    "chapeau-claquerna": "chapeau-claque",
    "chapeau-claquernas": "chapeau-claque",
    "chapeau-claquers": "chapeau-claque",
    "chapeau-claques": "chapeau-claque",
    "charabangen": "charabang",
    "charabangens": "charabang",
    "charabanger": "charabang",
    "charabangerna": "charabang",
    "charabangernas": "charabang",
    "charabangers": "charabang",
    "charabangs": "charabang",
    "charaden": "charad",
    "charadens": "charad",
    "charader": "charad",
    "charaderna": "charad",
    "charadernas": "charad",
    "charaders": "charad",
    "charads": "charad",
    "charen": "char",
    "charens": "char",
    "charer": "char",
    "charerna": "char",
    "charernas": "char",
    "charers": "char",
    "chargen": "charge",
    "chargens": "charge",
    "charger": "charge",
    "chargerad": "chargera",
    "chargerade": "chargera",
    "chargerades": "chargera",
    "chargerads": "chargera",
    "chargerande": "chargera",
    "chargeranden": "chargerande",
    "chargerandena": "chargerande",
    "chargerandenas": "chargerande",
    "chargerandens": "chargerande",
    "chargerandes": "chargerande",
    "chargerandet": "chargerande",
    "chargerandets": "chargerande",
    "chargerar": "chargera",
    "chargeras": "chargera",
    "chargerat": "chargera",
    "chargerats": "chargera",
    "chargerbara": "chargerbar",
    "chargerbarare": "chargerbar",
    "chargerbarares": "chargerbar",
    "chargerbaras": "chargerbar",
    "chargerbarast": "chargerbar",
    "chargerbaraste": "chargerbar",
    "chargerbarastes": "chargerbar",
    "chargerbarasts": "chargerbar",
    "chargerbare": "chargerbar",
    "chargerbares": "chargerbar",
    "chargerbarheten": "chargerbarhet",
    "chargerbarhetens": "chargerbarhet",
    "chargerbarhets": "chargerbarhet",
    "chargerbars": "chargerbar",
    "chargerbart": "chargerbar",
    "chargerbarts": "chargerbar",
    "chargeringar": "chargering",
    "chargeringarna": "chargering",
    "chargeringarnas": "chargering",
    "chargeringars": "chargering",
    "chargeringen": "chargering",
    "chargeringens": "chargering",
    "chargerings": "chargering",
    "chargerna": "charge",
    "chargernas": "charge",
    "chargers": "charge",
    "charges": "charge",
    "chargé-d'affairesen": "chargé-d'affaires",
    "chargé-d'affairesens": "chargé-d'affaires",
    "chargé-d'affaireser": "chargé-d'affaires",
    "chargé-d'affaireserna": "chargé-d'affaires",
    "chargé-d'affairesernas": "chargé-d'affaires",
    "chargé-d'affairesers": "chargé-d'affaires",
    "charken": "chark",
    "charkens": "chark",
    "charks": "chark",
    "charkuterier": "charkuteri",
    "charkuterierna": "charkuteri",
    "charkuteriernas": "charkuteri",
    "charkuteriers": "charkuteri",
    "charkuteriet": "charkuteri",
    "charkuteriets": "charkuteri",
    "charkuteris": "charkuteri",
    "charkuteristen": "charkuterist",
    "charkuteristens": "charkuterist",
    "charkuterister": "charkuterist",
    "charkuteristerna": "charkuterist",
    "charkuteristernas": "charkuterist",
    "charkuteristers": "charkuterist",
    "charkuterists": "charkuterist",
    "charkuterit": "charkuteri",
    "charkuterits": "charkuteri",
    "charkuterivar": "charkuterivara",
    "charkuterivaran": "charkuterivara",
    "charkuterivarans": "charkuterivara",
    "charkuterivaras": "charkuterivara",
    "charkuterivare": "charkuterivara",
    "charkuterivaror": "charkuterivara",
    "charkuterivarorna": "charkuterivara",
    "charkuterivarornas": "charkuterivara",
    "charkuterivarors": "charkuterivara",
    "charkuterivars": "charkuterivara",
    "charkvar": "charkvara",
    "charkvaran": "charkvara",
    "charkvarans": "charkvara",
    "charkvaras": "charkvara",
    "charkvare": "charkvara",
    "charkvaror": "charkvara",
    "charkvarorna": "charkvara",
    "charkvarornas": "charkvara",
    "charkvarors": "charkvara",
    "charkvars": "charkvara",
    "charlatanen": "charlatan",
    "charlatanens": "charlatan",
    "charlataner": "charlatan",
    "charlatanerna": "charlatan",
    "charlatanernas": "charlatan",
    "charlataners": "charlatan",
    "charlatanmässiga": "charlatanmässig",
    "charlatanmässigare": "charlatanmässig",
    "charlatanmässigares": "charlatanmässig",
    "charlatanmässigas": "charlatanmässig",
    "charlatanmässigast": "charlatanmässig",
    "charlatanmässigaste": "charlatanmässig",
    "charlatanmässigastes": "charlatanmässig",
    "charlatanmässigasts": "charlatanmässig",
    "charlatanmässige": "charlatanmässig",
    "charlatanmässiges": "charlatanmässig",
    "charlatanmässigs": "charlatanmässig",
    "charlatanmässigt": "charlatanmässig",
    "charlatanmässigts": "charlatanmässig",
    "charlatans": "charlatan",
    "charm": "charma",
    "charmad": "charma",
    "charmade": "charma",
    "charmades": "charma",
    "charmads": "charma",
    "charmande": "charma",
    "charmanden": "charmande",
    "charmandena": "charmande",
    "charmandenas": "charmande",
    "charmandens": "charmande",
    "charmandes": "charmande",
    "charmandet": "charmande",
    "charmandets": "charmande",
    "charmanta": "charmant",
    "charmantare": "charmant",
    "charmantares": "charmant",
    "charmantas": "charmant",
    "charmantast": "charmant",
    "charmantaste": "charmant",
    "charmantastes": "charmant",
    "charmantasts": "charmant",
    "charmante": "charmant",
    "charmantes": "charmant",
    "charmants": "charmant",
    "charmar": "charma",
    "charmas": "charma",
    "charmat": "charma",
    "charmats": "charma",
    "charmen": "charm",
    "charmens": "charm",
    "charmerad": "charmera",
    "charmerade": "charmera",
    "charmerades": "charmera",
    "charmerads": "charmera",
    "charmerande": "charmera",
    "charmeranden": "charmerande",
    "charmerandena": "charmerande",
    "charmerandenas": "charmerande",
    "charmerandens": "charmerande",
    "charmerandes": "charmerande",
    "charmerandet": "charmerande",
    "charmerandets": "charmerande",
    "charmerar": "charmera",
    "charmeras": "charmera",
    "charmerat": "charmera",
    "charmerats": "charmera",
    "charmerbara": "charmerbar",
    "charmerbarare": "charmerbar",
    "charmerbarares": "charmerbar",
    "charmerbaras": "charmerbar",
    "charmerbarast": "charmerbar",
    "charmerbaraste": "charmerbar",
    "charmerbarastes": "charmerbar",
    "charmerbarasts": "charmerbar",
    "charmerbare": "charmerbar",
    "charmerbares": "charmerbar",
    "charmerbarheten": "charmerbarhet",
    "charmerbarhetens": "charmerbarhet",
    "charmerbarhets": "charmerbarhet",
    "charmerbars": "charmerbar",
    "charmerbart": "charmerbar",
    "charmerbarts": "charmerbar",
    "charmeringar": "charmering",
    "charmeringarna": "charmering",
    "charmeringarnas": "charmering",
    "charmeringars": "charmering",
    "charmeringen": "charmering",
    "charmeringens": "charmering",
    "charmerings": "charmering",
    "charmeusen": "charmeuse",
    "charmeusens": "charmeuse",
    "charmeuses": "charmeuse",
    "charmfulla": "charmfull",
    "charmfullare": "charmfull",
    "charmfullares": "charmfull",
    "charmfullas": "charmfull",
    "charmfullast": "charmfull",
    "charmfullaste": "charmfull",
    "charmfullastes": "charmfull",
    "charmfullasts": "charmfull",
    "charmfulle": "charmfull",
    "charmfulles": "charmfull",
    "charmfullheten": "charmfullhet",
    "charmfullhetens": "charmfullhet",
    "charmfullhets": "charmfullhet",
    "charmfulls": "charmfull",
    "charmfullt": "charmfull",
    "charmfullts": "charmfull",
    "charmiga": "charmig",
    "charmigare": "charmig",
    "charmigares": "charmig",
    "charmigas": "charmig",
    "charmigast": "charmig",
    "charmigaste": "charmig",
    "charmigastes": "charmig",
    "charmigasts": "charmig",
    "charmige": "charmig",
    "charmiges": "charmig",
    "charmigheten": "charmighet",
    "charmighetens": "charmighet",
    "charmighets": "charmighet",
    "charmigs": "charmig",
    "charmigt": "charmig",
    "charmigts": "charmig",
    "charmkursen": "charmkurs",
    "charmkursens": "charmkurs",
    "charmkurser": "charmkurs",
    "charmkurserna": "charmkurs",
    "charmkursernas": "charmkurs",
    "charmkursers": "charmkurs",
    "charmlösa": "charmlös",
    "charmlösare": "charmlös",
    "charmlösares": "charmlös",
    "charmlösas": "charmlös",
    "charmlösast": "charmlös",
    "charmlösaste": "charmlös",
    "charmlösastes": "charmlös",
    "charmlösasts": "charmlös",
    "charmlöse": "charmlös",
    "charmlöses": "charmlös",
    "charmlösheten": "charmlöshet",
    "charmlöshetens": "charmlöshet",
    "charmlösheter": "charmlöshet",
    "charmlösheterna": "charmlöshet",
    "charmlösheternas": "charmlöshet",
    "charmlösheters": "charmlöshet",
    "charmlöshets": "charmlöshet",
    "charmlöst": "charmlös",
    "charmlösts": "charmlös",
    "charmoffensiven": "charmoffensiv",
    "charmoffensivens": "charmoffensiv",
    "charmoffensiver": "charmoffensiv",
    "charmoffensiverna": "charmoffensiv",
    "charmoffensivernas": "charmoffensiv",
    "charmoffensivers": "charmoffensiv",
    "charmoffensivs": "charmoffensiv",
    "charms": "charm",
    "charmtrollen": "charmtroll",
    "charmtrollens": "charmtroll",
    "charmtrollet": "charmtroll",
    "charmtrollets": "charmtroll",
    "charmtrolls": "charmtroll",
    "charmören": "charmör",
    "charmörens": "charmör",
    "charmörer": "charmör",
    "charmörerna": "charmör",
    "charmörernas": "charmör",
    "charmörers": "charmör",
    "charmörn": "charmör",
    "charmörns": "charmör",
    "charmörs": "charmör",
    "charneren": "charner",
    "charnerens": "charner",
    "charneret": "charner",
    "charnerets": "charner",
    "charners": "charner",
    "charpiet": "charpi",
    "charpiets": "charpi",
    "charpis": "charpi",
    "charpit": "charpi",
    "charpits": "charpi",
    "chars": "char",
    "chartan": "charta",
    "chartans": "charta",
    "chartas": "charta",
    "chartern": "charter",
    "charterns": "charter",
    "charterresan": "charterresa",
    "charterresans": "charterresa",
    "charterresas": "charterresa",
    "charterrese": "charterresa",
    "charterresor": "charterresa",
    "charterresorna": "charterresa",
    "charterresornas": "charterresa",
    "charterresors": "charterresa",
    "charters": "charter",
    "charterturisten": "charterturist",
    "charterturistens": "charterturist",
    "charterturister": "charterturist",
    "charterturisterna": "charterturist",
    "charterturisternas": "charterturist",
    "charterturisters": "charterturist",
    "charterturists": "charterturist",
    "chartrad": "chartra",
    "chartrade": "chartra",
    "chartrades": "chartra",
    "chartrads": "chartra",
    "chartrande": "chartra",
    "chartranden": "chartrande",
    "chartrandena": "chartrande",
    "chartrandenas": "chartrande",
    "chartrandens": "chartrande",
    "chartrandes": "chartrande",
    "chartrandet": "chartrande",
    "chartrandets": "chartrande",
    "chartrar": "chartra",
    "chartras": "chartra",
    "chartrat": "chartra",
    "chartrats": "chartra",
    "chartreusen": "chartreuse",
    "chartreusens": "chartreuse",
    "chartreuser": "chartreuse",
    "chartreuserna": "chartreuse",
    "chartreusernas": "chartreuse",
    "chartreusers": "chartreuse",
    "chartreuses": "chartreuse",
    "chassidismen": "chassidism",
    "chassidismens": "chassidism",
    "chassidismer": "chassidism",
    "chassidismerna": "chassidism",
    "chassidismernas": "chassidism",
    "chassidismers": "chassidism",
    "chassidisms": "chassidism",
    "chassidistiska": "chassidistisk",
    "chassidistiskas": "chassidistisk",
    "chassidistiske": "chassidistisk",
    "chassidistiskes": "chassidistisk",
    "chassidistisks": "chassidistisk",
    "chassidistiskt": "chassidistisk",
    "chassidistiskts": "chassidistisk",
    "chassier": "chassi",
    "chassierna": "chassi",
    "chassiernas": "chassi",
    "chassiers": "chassi",
    "chassiet": "chassi",
    "chassiets": "chassi",
    "chassis": "chassi",
    "chassit": "chassi",
    "chassits": "chassi",
    "chateaubrianden": "chateaubriand",
    "chateaubriandens": "chateaubriand",
    "chateaubriander": "chateaubriand",
    "chateaubrianderna": "chateaubriand",
    "chateaubriandernas": "chateaubriand",
    "chateaubrianders": "chateaubriand",
    "chateaubriands": "chateaubriand",
    "chattkonversationen": "chattkonversation",
    "chattkonversationens": "chattkonversation",
    "chattkonversationer": "chattkonversation",
    "chattkonversationerna": "chattkonversation",
    "chattkonversationernas": "chattkonversation",
    "chattkonversationers": "chattkonversation",
    "chattkonversations": "chattkonversation",
    "chauffören": "chaufför",
    "chaufförens": "chaufför",
    "chaufförer": "chaufför",
    "chaufförerna": "chaufför",
    "chaufförernas": "chaufför",
    "chaufförers": "chaufför",
    "chaufförn": "chaufför",
    "chaufförns": "chaufför",
    "chaufförs": "chaufför",
    "chausserade": "chausserad",
    "chausserades": "chausserad",
    "chausserads": "chausserad",
    "chausserat": "chausserad",
    "chausserats": "chausserad",
    "chausséer": "chaussé",
    "chausséerna": "chaussé",
    "chausséernas": "chaussé",
    "chausséers": "chaussé",
    "chaussén": "chaussé",
    "chausséns": "chaussé",
    "chaussés": "chaussé",
    "chauvinismen": "chauvinism",
    "chauvinismens": "chauvinism",
    "chauvinismer": "chauvinism",
    "chauvinismerna": "chauvinism",
    "chauvinismernas": "chauvinism",
    "chauvinismers": "chauvinism",
    "chauvinisms": "chauvinism",
    "chauvinisten": "chauvinist",
    "chauvinistens": "chauvinist",
    "chauvinister": "chauvinist",
    "chauvinisterna": "chauvinist",
    "chauvinisternas": "chauvinist",
    "chauvinisters": "chauvinist",
    "chauvinistiska": "chauvinistisk",
    "chauvinistiskare": "chauvinistisk",
    "chauvinistiskares": "chauvinistisk",
    "chauvinistiskas": "chauvinistisk",
    "chauvinistiskast": "chauvinistisk",
    "chauvinistiskaste": "chauvinistisk",
    "chauvinistiskastes": "chauvinistisk",
    "chauvinistiskasts": "chauvinistisk",
    "chauvinistiske": "chauvinistisk",
    "chauvinistiskes": "chauvinistisk",
    "chauvinistisks": "chauvinistisk",
    "chauvinistiskt": "chauvinistisk",
    "chauvinistiskts": "chauvinistisk",
    "chauvinists": "chauvinist",
    "check": "checka",
    "checkad": "checka",
    "checkade": "checka",
    "checkades": "checka",
    "checkads": "checka",
    "checkande": "checka",
    "checkanden": "checkande",
    "checkandena": "checkande",
    "checkandenas": "checkande",
    "checkandens": "checkande",
    "checkandes": "checkande",
    "checkandet": "checkande",
    "checkandets": "checkande",
    "checkar": "checka",
    "checkarna": "check",
    "checkarnas": "check",
    "checkars": "check",
    "checkas": "checka",
    "checkat": "checka",
    "checkats": "checka",
    "checken": "check",
    "checkens": "check",
    "checker": "check",
    "checkerna": "check",
    "checkernas": "check",
    "checkers": "check",
    "checkhäften": "checkhäfte",
    "checkhäftena": "checkhäfte",
    "checkhäftenas": "checkhäfte",
    "checkhäftens": "checkhäfte",
    "checkhäftes": "checkhäfte",
    "checkhäftet": "checkhäfte",
    "checkhäftets": "checkhäfte",
    "checkkonton": "checkkonto",
    "checkkontona": "checkkonto",
    "checkkontonas": "checkkonto",
    "checkkontons": "checkkonto",
    "checkkontos": "checkkonto",
    "checkkontot": "checkkonto",
    "checkkontots": "checkkonto",
    "checkkrediten": "checkkredit",
    "checkkreditens": "checkkredit",
    "checkkrediter": "checkkredit",
    "checkkrediterna": "checkkredit",
    "checkkrediternas": "checkkredit",
    "checkkrediters": "checkkredit",
    "checkkredits": "checkkredit",
    "checklistan": "checklista",
    "checklistans": "checklista",
    "checklistas": "checklista",
    "checkliste": "checklista",
    "checklistor": "checklista",
    "checklistorna": "checklista",
    "checklistornas": "checklista",
    "checklistors": "checklista",
    "checklönen": "checklön",
    "checklönens": "checklön",
    "checklöner": "checklön",
    "checklönerna": "checklön",
    "checklönernas": "checklön",
    "checklöners": "checklön",
    "checklöns": "checklön",
    "checkräkningar": "checkräkning",
    "checkräkningarna": "checkräkning",
    "checkräkningarnas": "checkräkning",
    "checkräkningars": "checkräkning",
    "checkräkningen": "checkräkning",
    "checkräkningens": "checkräkning",
    "checkräknings": "checkräkning",
    "checks": "check",
    "checksumman": "checksumma",
    "checksummans": "checksumma",
    "checksummas": "checksumma",
    "checksumme": "checksumma",
    "checksummor": "checksumma",
    "checksummorna": "checksumma",
    "checksummornas": "checksumma",
    "checksummors": "checksumma",
    "cheddarostar": "cheddarost",
    "cheddarostarna": "cheddarost",
    "cheddarostarnas": "cheddarost",
    "cheddarostars": "cheddarost",
    "cheddarosten": "cheddarost",
    "cheddarostens": "cheddarost",
    "cheddarosts": "cheddarost",
    "chef-d'oeuvres": "chef-d'oeuvre",
    "chefade": "chefa",
    "chefades": "chefa",
    "chefande": "chefa",
    "chefanden": "chefande",
    "chefandena": "chefande",
    "chefandenas": "chefande",
    "chefandens": "chefande",
    "chefandes": "chefande",
    "chefandet": "chefande",
    "chefandets": "chefande",
    "chefar": "chefa",
    "chefas": "chefa",
    "chefat": "chefa",
    "chefats": "chefa",
    "chefen": "chef",
    "chefens": "chef",
    "chefer": "chef",
    "cheferna": "chef",
    "chefernas": "chef",
    "chefers": "chef",
    "chefredaktören": "chefredaktör",
    "chefredaktörens": "chefredaktör",
    "chefredaktörer": "chefredaktör",
    "chefredaktörerna": "chefredaktör",
    "chefredaktörernas": "chefredaktör",
    "chefredaktörers": "chefredaktör",
    "chefredaktörn": "chefredaktör",
    "chefredaktörns": "chefredaktör",
    "chefredaktörs": "chefredaktör",
    "chefs": "chef",
    "chefsekonomen": "chefsekonom",
    "chefsekonomens": "chefsekonom",
    "chefsekonomer": "chefsekonom",
    "chefsekonomerna": "chefsekonom",
    "chefsekonomernas": "chefsekonom",
    "chefsekonomers": "chefsekonom",
    "chefsekonoms": "chefsekonom",
    "chefsideologen": "chefsideolog",
    "chefsideologens": "chefsideolog",
    "chefsideologer": "chefsideolog",
    "chefsideologerna": "chefsideolog",
    "chefsideologernas": "chefsideolog",
    "chefsideologers": "chefsideolog",
    "chefsideologs": "chefsideolog",
    "chefsjobben": "chefsjobb",
    "chefsjobbens": "chefsjobb",
    "chefsjobbet": "chefsjobb",
    "chefsjobbets": "chefsjobb",
    "chefsjobbs": "chefsjobb",
    "chefskapet": "chefskap",
    "chefskapets": "chefskap",
    "chefskaps": "chefskap",
    "chefsskapet": "chefsskap",
    "chefsskapets": "chefsskap",
    "chefsskaps": "chefsskap",
    "chefsställningar": "chefsställning",
    "chefsställningarna": "chefsställning",
    "chefsställningarnas": "chefsställning",
    "chefsställningars": "chefsställning",
    "chefsställningen": "chefsställning",
    "chefsställningens": "chefsställning",
    "chefsställnings": "chefsställning",
    "chefstjänstemannen": "chefstjänsteman",
    "chefstjänstemannens": "chefstjänsteman",
    "chefstjänstemans": "chefstjänsteman",
    "chefstjänstemän": "chefstjänsteman",
    "chefstjänstemännen": "chefstjänsteman",
    "chefstjänstemännens": "chefstjänsteman",
    "chefstjänstemäns": "chefstjänsteman",
    "chemisen": "chemis",
    "chemisens": "chemis",
    "chemiser": "chemis",
    "chemiserna": "chemis",
    "chemisernas": "chemis",
    "chemisers": "chemis",
    "chemisetten": "chemisett",
    "chemisettens": "chemisett",
    "chemisetter": "chemisett",
    "chemisetterna": "chemisett",
    "chemisetternas": "chemisett",
    "chemisetters": "chemisett",
    "chemisetts": "chemisett",
    "cherimoyan": "cherimoya",
    "cherimoyans": "cherimoya",
    "cherimoyas": "cherimoya",
    "chevalereska": "chevaleresk",
    "chevalereskare": "chevaleresk",
    "chevalereskares": "chevaleresk",
    "chevalereskas": "chevaleresk",
    "chevalereskast": "chevaleresk",
    "chevalereskaste": "chevaleresk",
    "chevalereskastes": "chevaleresk",
    "chevalereskasts": "chevaleresk",
    "chevalereske": "chevaleresk",
    "chevalereskes": "chevaleresk",
    "chevaleresks": "chevaleresk",
    "chevalereskt": "chevaleresk",
    "chevalereskts": "chevaleresk",
    "chevelyren": "chevelyr",
    "chevelyrens": "chevelyr",
    "chevelyrer": "chevelyr",
    "chevelyrerna": "chevelyr",
    "chevelyrernas": "chevelyr",
    "chevelyrers": "chevelyr",
    "chevelyrs": "chevelyr",
    "chevioten": "cheviot",
    "cheviotens": "cheviot",
    "chevioter": "cheviot",
    "chevioterna": "cheviot",
    "chevioternas": "cheviot",
    "chevioters": "cheviot",
    "cheviots": "cheviot",
    "chevreaun": "chevreau",
    "chevreauns": "chevreau",
    "chevreaus": "chevreau",
    "chevroterad": "chevrotera",
    "chevroterade": "chevrotera",
    "chevroterades": "chevrotera",
    "chevroterads": "chevrotera",
    "chevroterande": "chevrotera",
    "chevroteranden": "chevroterande",
    "chevroterandena": "chevroterande",
    "chevroterandenas": "chevroterande",
    "chevroterandens": "chevroterande",
    "chevroterandes": "chevroterande",
    "chevroterandet": "chevroterande",
    "chevroterandets": "chevroterande",
    "chevroterar": "chevrotera",
    "chevroteras": "chevrotera",
    "chevroterat": "chevrotera",
    "chevroterats": "chevrotera",
    "chevroterbara": "chevroterbar",
    "chevroterbarare": "chevroterbar",
    "chevroterbarares": "chevroterbar",
    "chevroterbaras": "chevroterbar",
    "chevroterbarast": "chevroterbar",
    "chevroterbaraste": "chevroterbar",
    "chevroterbarastes": "chevroterbar",
    "chevroterbarasts": "chevroterbar",
    "chevroterbare": "chevroterbar",
    "chevroterbares": "chevroterbar",
    "chevroterbarheten": "chevroterbarhet",
    "chevroterbarhetens": "chevroterbarhet",
    "chevroterbarhets": "chevroterbarhet",
    "chevroterbars": "chevroterbar",
    "chevroterbart": "chevroterbar",
    "chevroterbarts": "chevroterbar",
    "chevroteringar": "chevrotering",
    "chevroteringarna": "chevrotering",
    "chevroteringarnas": "chevrotering",
    "chevroteringars": "chevrotering",
    "chevroteringen": "chevrotering",
    "chevroteringens": "chevrotering",
    "chevroterings": "chevrotering",
    "chiantin": "chianti",
    "chiantins": "chianti",
    "chiantis": "chianti",
    "chibbar": "chibbe",
    "chibbarna": "chibbe",
    "chibbarnas": "chibbe",
    "chibbars": "chibbe",
    "chibben": "chibbe",
    "chibbens": "chibbe",
    "chibbes": "chibbe",
    "chica": "chic",
    "chicare": "chic",
    "chicares": "chic",
    "chicas": "chic",
    "chicast": "chic",
    "chicaste": "chic",
    "chicastes": "chic",
    "chicasts": "chic",
    "chice": "chic",
    "chices": "chic",
    "chicheten": "chichet",
    "chichetens": "chichet",
    "chichets": "chichet",
    "chics": "chic",
    "chict": "chic",
    "chicts": "chic",
    "chien": "chi",
    "chiens": "chi",
    "chiet": "chi",
    "chiets": "chi",
    "chiffern": "chiffer",
    "chifferns": "chiffer",
    "chiffernyckeln": "chiffernyckel",
    "chiffernyckelns": "chiffernyckel",
    "chiffernyckels": "chiffernyckel",
    "chiffernycklar": "chiffernyckel",
    "chiffernycklarna": "chiffernyckel",
    "chiffernycklarnas": "chiffernyckel",
    "chiffernycklars": "chiffernyckel",
    "chiffers": "chiffer",
    "chiffongen": "chiffong",
    "chiffongens": "chiffong",
    "chiffonger": "chiffong",
    "chiffongerna": "chiffong",
    "chiffongernas": "chiffong",
    "chiffongers": "chiffong",
    "chiffongklänningar": "chiffongklänning",
    "chiffongklänningarna": "chiffongklänning",
    "chiffongklänningarnas": "chiffongklänning",
    "chiffongklänningars": "chiffongklänning",
    "chiffongklänningen": "chiffongklänning",
    "chiffongklänningens": "chiffongklänning",
    "chiffongklännings": "chiffongklänning",
    "chiffongs": "chiffong",
    "chiffonjéer": "chiffonjé",
    "chiffonjéerna": "chiffonjé",
    "chiffonjéernas": "chiffonjé",
    "chiffonjéers": "chiffonjé",
    "chiffonjén": "chiffonjé",
    "chiffonjéns": "chiffonjé",
    "chiffonjés": "chiffonjé",
    "chiffren": "chiffer",
    "chiffrens": "chiffer",
    "chiffrer": "chiffer",
    "chiffrerad": "chiffrera",
    "chiffrerade": "chiffrera",
    "chiffrerades": "chiffrera",
    "chiffrerads": "chiffrera",
    "chiffrerande": "chiffrera",
    "chiffreranden": "chiffrerande",
    "chiffrerandena": "chiffrerande",
    "chiffrerandenas": "chiffrerande",
    "chiffrerandens": "chiffrerande",
    "chiffrerandes": "chiffrerande",
    "chiffrerandet": "chiffrerande",
    "chiffrerandets": "chiffrerande",
    "chiffrerar": "chiffrera",
    "chiffreras": "chiffrera",
    "chiffrerat": "chiffrera",
    "chiffrerats": "chiffrera",
    "chiffrerbara": "chiffrerbar",
    "chiffrerbarare": "chiffrerbar",
    "chiffrerbarares": "chiffrerbar",
    "chiffrerbaras": "chiffrerbar",
    "chiffrerbarast": "chiffrerbar",
    "chiffrerbaraste": "chiffrerbar",
    "chiffrerbarastes": "chiffrerbar",
    "chiffrerbarasts": "chiffrerbar",
    "chiffrerbare": "chiffrerbar",
    "chiffrerbares": "chiffrerbar",
    "chiffrerbarheten": "chiffrerbarhet",
    "chiffrerbarhetens": "chiffrerbarhet",
    "chiffrerbarhets": "chiffrerbarhet",
    "chiffrerbars": "chiffrerbar",
    "chiffrerbart": "chiffrerbar",
    "chiffrerbarts": "chiffrerbar",
    "chiffreringar": "chiffrering",
    "chiffreringarna": "chiffrering",
    "chiffreringarnas": "chiffrering",
    "chiffreringars": "chiffrering",
    "chiffreringen": "chiffrering",
    "chiffreringens": "chiffrering",
    "chiffrerings": "chiffrering",
    "chiffrerna": "chiffer",
    "chiffrernas": "chiffer",
    "chiffrers": "chiffer",
    "chiffret": "chiffer",
    "chiffrets": "chiffer",
    "chikanen": "chikan",
    "chikanens": "chikan",
    "chikaner": "chikan",
    "chikanerad": "chikanera",
    "chikanerade": "chikanera",
    "chikanerades": "chikanera",
    "chikanerads": "chikanera",
    "chikanerande": "chikanera",
    "chikaneranden": "chikanerande",
    "chikanerandena": "chikanerande",
    "chikanerandenas": "chikanerande",
    "chikanerandens": "chikanerande",
    "chikanerandes": "chikanerande",
    "chikanerandet": "chikanerande",
    "chikanerandets": "chikanerande",
    "chikanerar": "chikanera",
    "chikaneras": "chikanera",
    "chikanerat": "chikanera",
    "chikanerats": "chikanera",
    "chikanerbara": "chikanerbar",
    "chikanerbarare": "chikanerbar",
    "chikanerbarares": "chikanerbar",
    "chikanerbaras": "chikanerbar",
    "chikanerbarast": "chikanerbar",
    "chikanerbaraste": "chikanerbar",
    "chikanerbarastes": "chikanerbar",
    "chikanerbarasts": "chikanerbar",
    "chikanerbare": "chikanerbar",
    "chikanerbares": "chikanerbar",
    "chikanerbarheten": "chikanerbarhet",
    "chikanerbarhetens": "chikanerbarhet",
    "chikanerbarhets": "chikanerbarhet",
    "chikanerbars": "chikanerbar",
    "chikanerbart": "chikanerbar",
    "chikanerbarts": "chikanerbar",
    "chikaneringar": "chikanering",
    "chikaneringarna": "chikanering",
    "chikaneringarnas": "chikanering",
    "chikaneringars": "chikanering",
    "chikaneringen": "chikanering",
    "chikaneringens": "chikanering",
    "chikanerings": "chikanering",
    "chikanerna": "chikan",
    "chikanernas": "chikan",
    "chikaners": "chikan",
    "chikans": "chikan",
    "chilenar": "chilenare",
    "chilenaren": "chilenare",
    "chilenarens": "chilenare",
    "chilenares": "chilenare",
    "chilenarna": "chilenare",
    "chilenarnas": "chilenare",
    "chilenen": "chilen",
    "chilenens": "chilen",
    "chilener": "chilen",
    "chilenerna": "chilen",
    "chilenernas": "chilen",
    "chileners": "chilen",
    "chilens": "chilen",
    "chilenska": "chilensk",
    "chilenskan": "chilenska",
    "chilenskans": "chilenska",
    "chilenskare": "chilensk",
    "chilenskares": "chilensk",
    "chilenskas": "chilenska",
    "chilenskast": "chilensk",
    "chilenskaste": "chilensk",
    "chilenskastes": "chilensk",
    "chilenskasts": "chilensk",
    "chilenske": "chilenska",
    "chilenskes": "chilensk",
    "chilenskor": "chilenska",
    "chilenskorna": "chilenska",
    "chilenskornas": "chilenska",
    "chilenskors": "chilenska",
    "chilensks": "chilensk",
    "chilenskt": "chilensk",
    "chilenskts": "chilensk",
    "chilesalpetern": "chilesalpeter",
    "chilesalpeterns": "chilesalpeter",
    "chilesalpeters": "chilesalpeter",
    "chilin": "chili",
    "chilins": "chili",
    "chilipepparn": "chilipeppar",
    "chilipepparns": "chilipeppar",
    "chilipeppars": "chilipeppar",
    "chilis": "chili",
    "chilisåsen": "chilisås",
    "chilisåsens": "chilisås",
    "chillade": "chilla",
    "chillades": "chilla",
    "chillande": "chilla",
    "chillanden": "chillande",
    "chillandena": "chillande",
    "chillandenas": "chillande",
    "chillandens": "chillande",
    "chillandes": "chillande",
    "chillandet": "chillande",
    "chillandets": "chillande",
    "chillar": "chilla",
    "chillas": "chilla",
    "chillat": "chilla",
    "chillats": "chilla",
    "chimpansen": "chimpans",
    "chimpansens": "chimpans",
    "chimpanser": "chimpans",
    "chimpanserna": "chimpans",
    "chimpansernas": "chimpans",
    "chimpansers": "chimpans",
    "chimären": "chimär",
    "chimärens": "chimär",
    "chimärer": "chimär",
    "chimärerna": "chimär",
    "chimärernas": "chimär",
    "chimärers": "chimär",
    "chimärs": "chimär",
    "chin": "chi",
    "china": "chi",
    "chinas": "chi",
    "chinchill": "chinchilla",
    "chinchillan": "chinchilla",
    "chinchillans": "chinchilla",
    "chinchillas": "chinchilla",
    "chinchille": "chinchilla",
    "chinchillor": "chinchilla",
    "chinchillorna": "chinchilla",
    "chinchillornas": "chinchilla",
    "chinchillors": "chinchilla",
    "chinchills": "chinchilla",
    "chinjongen": "chinjong",
    "chinjongens": "chinjong",
    "chinjonger": "chinjong",
    "chinjongerna": "chinjong",
    "chinjongernas": "chinjong",
    "chinjongers": "chinjong",
    "chinjongs": "chinjong",
    "chins": "chi",
    "chintzen": "chintz",
    "chintzens": "chintz",
    "chipen": "chip",
    "chipens": "chip",
    "chipet": "chip",
    "chipets": "chip",
    "chips": "chip",
    "chipsen": "chips",
    "chipsens": "chips",
    "chipset": "chips",
    "chipsets": "chips",
    "chipssuget": "chipssug",
    "chipssugets": "chipssug",
    "chipssugs": "chipssug",
    "chirrar": "chirre",
    "chirrarna": "chirre",
    "chirrarnas": "chirre",
    "chirrars": "chirre",
    "chirren": "chirre",
    "chirrens": "chirre",
    "chirres": "chirre",
    "chis": "chi",
    "chit": "chi",
    "chits": "chi",
    "chock": "chocka",
    "chockad": "chocka",
    "chockade": "chocka",
    "chockades": "chocka",
    "chockads": "chocka",
    "chockande": "chocka",
    "chockanden": "chockande",
    "chockandena": "chockande",
    "chockandenas": "chockande",
    "chockandens": "chockande",
    "chockandes": "chockande",
    "chockandet": "chockande",
    "chockandets": "chockande",
    "chockar": "chocka",
    "chockartade": "chockartad",
    "chockartades": "chockartad",
    "chockartads": "chockartad",
    "chockartat": "chockartad",
    "chockartats": "chockartad",
    "chockas": "chocka",
    "chockat": "chocka",
    "chockats": "chocka",
    "chockbehandlad": "chockbehandla",
    "chockbehandlade": "chockbehandla",
    "chockbehandlades": "chockbehandla",
    "chockbehandlads": "chockbehandla",
    "chockbehandlande": "chockbehandla",
    "chockbehandlanden": "chockbehandlande",
    "chockbehandlandena": "chockbehandlande",
    "chockbehandlandenas": "chockbehandlande",
    "chockbehandlandens": "chockbehandlande",
    "chockbehandlandes": "chockbehandlande",
    "chockbehandlandet": "chockbehandlande",
    "chockbehandlandets": "chockbehandlande",
    "chockbehandlar": "chockbehandla",
    "chockbehandlas": "chockbehandla",
    "chockbehandlat": "chockbehandla",
    "chockbehandlats": "chockbehandla",
    "chockbehandlingar": "chockbehandling",
    "chockbehandlingarna": "chockbehandling",
    "chockbehandlingarnas": "chockbehandling",
    "chockbehandlingars": "chockbehandling",
    "chockbehandlingen": "chockbehandling",
    "chockbehandlingens": "chockbehandling",
    "chockbehandlings": "chockbehandling",
    "chockbeskeden": "chockbesked",
    "chockbeskedens": "chockbesked",
    "chockbeskedet": "chockbesked",
    "chockbeskedets": "chockbesked",
    "chockbeskeds": "chockbesked",
    "chockbilden": "chockbild",
    "chockbildens": "chockbild",
    "chockbilder": "chockbild",
    "chockbilderna": "chockbild",
    "chockbildernas": "chockbild",
    "chockbilders": "chockbild",
    "chockbilds": "chockbild",
    "chocken": "chock",
    "chockens": "chock",
    "chocker": "chock",
    "chockerad": "chockera",
    "chockerade": "chockera",
    "chockerades": "chockera",
    "chockerads": "chockera",
    "chockerande": "chockera",
    "chockeranden": "chockerande",
    "chockerandena": "chockerande",
    "chockerandenas": "chockerande",
    "chockerandens": "chockerande",
    "chockerandes": "chockerande",
    "chockerandet": "chockerande",
    "chockerandets": "chockerande",
    "chockerar": "chockera",
    "chockeras": "chockera",
    "chockerat": "chockera",
    "chockerats": "chockera",
    "chockerbara": "chockerbar",
    "chockerbarare": "chockerbar",
    "chockerbarares": "chockerbar",
    "chockerbaras": "chockerbar",
    "chockerbarast": "chockerbar",
    "chockerbaraste": "chockerbar",
    "chockerbarastes": "chockerbar",
    "chockerbarasts": "chockerbar",
    "chockerbare": "chockerbar",
    "chockerbares": "chockerbar",
    "chockerbarheten": "chockerbarhet",
    "chockerbarhetens": "chockerbarhet",
    "chockerbarhets": "chockerbarhet",
    "chockerbars": "chockerbar",
    "chockerbart": "chockerbar",
    "chockerbarts": "chockerbar",
    "chockeringar": "chockering",
    "chockeringarna": "chockering",
    "chockeringarnas": "chockering",
    "chockeringars": "chockering",
    "chockeringen": "chockering",
    "chockeringens": "chockering",
    "chockerings": "chockering",
    "chockerna": "chock",
    "chockernas": "chock",
    "chockers": "chock",
    "chockfasen": "chockfas",
    "chockfasens": "chockfas",
    "chockfaser": "chockfas",
    "chockfaserna": "chockfas",
    "chockfasernas": "chockfas",
    "chockfasers": "chockfas",
    "chocks": "chock",
    "chockterapien": "chockterapi",
    "chockterapiens": "chockterapi",
    "chockterapier": "chockterapi",
    "chockterapierna": "chockterapi",
    "chockterapiernas": "chockterapi",
    "chockterapiers": "chockterapi",
    "chockterapin": "chockterapi",
    "chockterapins": "chockterapi",
    "chockterapis": "chockterapi",
    "chocktillstånden": "chocktillstånd",
    "chocktillståndens": "chocktillstånd",
    "chocktillståndet": "chocktillstånd",
    "chocktillståndets": "chocktillstånd",
    "chocktillstånds": "chocktillstånd",
    "chockvågen": "chockvåg",
    "chockvågens": "chockvåg",
    "chockvågor": "chockvåg",
    "chockvågorna": "chockvåg",
    "chockvågornas": "chockvåg",
    "chockvågors": "chockvåg",
    "chockvågs": "chockvåg",
    "chok": "choka",
    "chokad": "choka",
    "chokade": "choka",
    "chokades": "choka",
    "chokads": "choka",
    "chokande": "choka",
    "chokanden": "chokande",
    "chokandena": "chokande",
    "chokandenas": "chokande",
    "chokandens": "chokande",
    "chokandes": "chokande",
    "chokandet": "chokande",
    "chokandets": "chokande",
    "chokar": "choke",
    "chokarna": "choke",
    "chokarnas": "choke",
    "chokars": "choke",
    "chokas": "choka",
    "chokat": "choka",
    "chokats": "choka",
    "choken": "choke",
    "chokens": "choke",
    "chokes": "choke",
    "chokladbitar": "chokladbit",
    "chokladbitarna": "chokladbit",
    "chokladbitarnas": "chokladbit",
    "chokladbitars": "chokladbit",
    "chokladbiten": "chokladbit",
    "chokladbitens": "chokladbit",
    "chokladbits": "chokladbit",
    "chokladbollar": "chokladboll",
    "chokladbollarna": "chokladboll",
    "chokladbollarnas": "chokladboll",
    "chokladbollars": "chokladboll",
    "chokladbollen": "chokladboll",
    "chokladbollens": "chokladboll",
    "chokladbolls": "chokladboll",
    "chokladen": "choklad",
    "chokladens": "choklad",
    "choklader": "choklad",
    "chokladerna": "choklad",
    "chokladernas": "choklad",
    "chokladers": "choklad",
    "chokladet": "choklad",
    "chokladets": "choklad",
    "chokladkak": "chokladkaka",
    "chokladkakan": "chokladkaka",
    "chokladkakans": "chokladkaka",
    "chokladkakas": "chokladkaka",
    "chokladkake": "chokladkaka",
    "chokladkakor": "chokladkaka",
    "chokladkakorna": "chokladkaka",
    "chokladkakornas": "chokladkaka",
    "chokladkakors": "chokladkaka",
    "chokladkaks": "chokladkaka",
    "chokladpuddingar": "chokladpudding",
    "chokladpuddingarna": "chokladpudding",
    "chokladpuddingarnas": "chokladpudding",
    "chokladpuddingars": "chokladpudding",
    "chokladpuddingen": "chokladpudding",
    "chokladpuddingens": "chokladpudding",
    "chokladpuddings": "chokladpudding",
    "choklads": "choklad",
    "chokladtårt": "chokladtårta",
    "chokladtårtan": "chokladtårta",
    "chokladtårtans": "chokladtårta",
    "chokladtårtas": "chokladtårta",
    "chokladtårte": "chokladtårta",
    "chokladtårtor": "chokladtårta",
    "chokladtårtorna": "chokladtårta",
    "chokladtårtornas": "chokladtårta",
    "chokladtårtors": "chokladtårta",
    "chokladtårts": "chokladtårta",
    "chose": "choser",
    "chosefria": "chosefri",
    "chosefriare": "chosefri",
    "chosefriares": "chosefri",
    "chosefrias": "chosefri",
    "chosefriast": "chosefri",
    "chosefriaste": "chosefri",
    "chosefriastes": "chosefri",
    "chosefriasts": "chosefri",
    "chosefrie": "chosefri",
    "chosefries": "chosefri",
    "chosefris": "chosefri",
    "chosefritt": "chosefri",
    "chosefritts": "chosefri",
    "choserna": "choser",
    "chosernas": "choser",
    "chosers": "choser",
    "chosiga": "chosig",
    "chosigare": "chosig",
    "chosigares": "chosig",
    "chosigas": "chosig",
    "chosigast": "chosig",
    "chosigaste": "chosig",
    "chosigastes": "chosig",
    "chosigasts": "chosig",
    "chosige": "chosig",
    "chosiges": "chosig",
    "chosigs": "chosig",
    "chosigt": "chosig",
    "chosigts": "chosig",
    "chuckar": "chuck",
    "chuckarna": "chuck",
    "chuckarnas": "chuck",
    "chuckars": "chuck",
    "chucken": "chuck",
    "chuckens": "chuck",
    "chucks": "chuck",
    "chutneyn": "chutney",
    "chutneyns": "chutney",
    "chutneys": "chutney",
    "ciceron": "cicero",
    "ciceronen": "ciceron",
    "ciceronens": "ciceron",
    "ciceroner": "ciceron",
    "ciceronerna": "ciceron",
    "ciceronernas": "ciceron",
    "ciceroners": "ciceron",
    "cicerons": "ciceron",
    "ciceros": "cicero",
    "cidern": "cider",
    "ciderns": "cider",
    "ciders": "cider",
    "cigar": "cig",
    "cigarettautomaten": "cigarettautomat",
    "cigarettautomatens": "cigarettautomat",
    "cigarettautomater": "cigarettautomat",
    "cigarettautomaterna": "cigarettautomat",
    "cigarettautomaternas": "cigarettautomat",
    "cigarettautomaters": "cigarettautomat",
    "cigarettautomats": "cigarettautomat",
    "cigaretten": "cigarett",
    "cigarettens": "cigarett",
    "cigaretter": "cigarett",
    "cigaretterna": "cigarett",
    "cigaretternas": "cigarett",
    "cigaretters": "cigarett",
    "cigarettfimpar": "cigarettfimp",
    "cigarettfimparna": "cigarettfimp",
    "cigarettfimparnas": "cigarettfimp",
    "cigarettfimpars": "cigarettfimp",
    "cigarettfimpen": "cigarettfimp",
    "cigarettfimpens": "cigarettfimp",
    "cigarettfimps": "cigarettfimp",
    "cigarettförsäljningen": "cigarettförsäljning",
    "cigarettförsäljningens": "cigarettförsäljning",
    "cigarettförsäljnings": "cigarettförsäljning",
    "cigarettlimp": "cigarettlimpa",
    "cigarettlimpan": "cigarettlimpa",
    "cigarettlimpans": "cigarettlimpa",
    "cigarettlimpas": "cigarettlimpa",
    "cigarettlimpe": "cigarettlimpa",
    "cigarettlimpor": "cigarettlimpa",
    "cigarettlimporna": "cigarettlimpa",
    "cigarettlimpornas": "cigarettlimpa",
    "cigarettlimpors": "cigarettlimpa",
    "cigarettlimps": "cigarettlimpa",
    "cigarettpaketen": "cigarettpaket",
    "cigarettpaketens": "cigarettpaket",
    "cigarettpaketet": "cigarettpaket",
    "cigarettpaketets": "cigarettpaket",
    "cigarettpakets": "cigarettpaket",
    "cigarettrökar": "cigarettrök",
    "cigarettrökarna": "cigarettrök",
    "cigarettrökarnas": "cigarettrök",
    "cigarettrökars": "cigarettrök",
    "cigarettröken": "cigarettrök",
    "cigarettrökens": "cigarettrök",
    "cigarettröks": "cigarettrök",
    "cigaretts": "cigarett",
    "cigarettuttagen": "cigarettuttag",
    "cigarettuttagens": "cigarettuttag",
    "cigarettuttaget": "cigarettuttag",
    "cigarettuttagets": "cigarettuttag",
    "cigarettuttags": "cigarettuttag",
    "cigarettändar": "cigarettändare",
    "cigarettändaren": "cigarettändare",
    "cigarettändarens": "cigarettändare",
    "cigarettändares": "cigarettändare",
    "cigarettändarkontakten": "cigarettändarkontakt",
    "cigarettändarkontaktens": "cigarettändarkontakt",
    "cigarettändarkontakter": "cigarettändarkontakt",
    "cigarettändarkontakterna": "cigarettändarkontakt",
    "cigarettändarkontakternas": "cigarettändarkontakt",
    "cigarettändarkontakters": "cigarettändarkontakt",
    "cigarettändarkontakts": "cigarettändarkontakt",
    "cigarettändarna": "cigarettändare",
    "cigarettändarnas": "cigarettändare",
    "cigarettändaruttagen": "cigarettändaruttag",
    "cigarettändaruttagens": "cigarettändaruttag",
    "cigarettändaruttager": "cigarettändaruttag",
    "cigarettändaruttagerna": "cigarettändaruttag",
    "cigarettändaruttagernas": "cigarettändaruttag",
    "cigarettändaruttagers": "cigarettändaruttag",
    "cigarettändaruttags": "cigarettändaruttag",
    "cigarillen": "cigarill",
    "cigarillens": "cigarill",
    "cigariller": "cigarill",
    "cigarillerna": "cigarill",
    "cigarillernas": "cigarill",
    "cigarillers": "cigarill",
    "cigarills": "cigarill",
    "cigarna": "cig",
    "cigarnas": "cig",
    "cigarrcigaretten": "cigarrcigarett",
    "cigarrcigarettens": "cigarrcigarett",
    "cigarrcigaretter": "cigarrcigarett",
    "cigarrcigaretterna": "cigarrcigarett",
    "cigarrcigaretternas": "cigarrcigarett",
    "cigarrcigaretters": "cigarrcigarett",
    "cigarrcigaretts": "cigarrcigarett",
    "cigarrcigarretten": "cigarrcigarrett",
    "cigarrcigarrettens": "cigarrcigarrett",
    "cigarrcigarretter": "cigarrcigarrett",
    "cigarrcigarretterna": "cigarrcigarrett",
    "cigarrcigarretternas": "cigarrcigarrett",
    "cigarrcigarretters": "cigarrcigarrett",
    "cigarrcigarretts": "cigarrcigarrett",
    "cigarren": "cigarr",
    "cigarrens": "cigarr",
    "cigarrer": "cigarr",
    "cigarrerna": "cigarr",
    "cigarrernas": "cigarr",
    "cigarrers": "cigarr",
    "cigarretten": "cigarrett",
    "cigarrettens": "cigarrett",
    "cigarretter": "cigarrett",
    "cigarretterna": "cigarrett",
    "cigarretternas": "cigarrett",
    "cigarretters": "cigarrett",
    "cigarrettfimpar": "cigarrettfimp",
    "cigarrettfimparna": "cigarrettfimp",
    "cigarrettfimparnas": "cigarrettfimp",
    "cigarrettfimpars": "cigarrettfimp",
    "cigarrettfimpen": "cigarrettfimp",
    "cigarrettfimpens": "cigarrettfimp",
    "cigarrettfimps": "cigarrettfimp",
    "cigarrettlimp": "cigarrettlimpa",
    "cigarrettlimpan": "cigarrettlimpa",
    "cigarrettlimpans": "cigarrettlimpa",
    "cigarrettlimpas": "cigarrettlimpa",
    "cigarrettlimpe": "cigarrettlimpa",
    "cigarrettlimpor": "cigarrettlimpa",
    "cigarrettlimporna": "cigarrettlimpa",
    "cigarrettlimpornas": "cigarrettlimpa",
    "cigarrettlimpors": "cigarrettlimpa",
    "cigarrettlimps": "cigarrettlimpa",
    "cigarrettpaketen": "cigarrettpaket",
    "cigarrettpaketens": "cigarrettpaket",
    "cigarrettpaketet": "cigarrettpaket",
    "cigarrettpaketets": "cigarrettpaket",
    "cigarrettpakets": "cigarrettpaket",
    "cigarrettrökar": "cigarrettrök",
    "cigarrettrökarna": "cigarrettrök",
    "cigarrettrökarnas": "cigarrettrök",
    "cigarrettrökars": "cigarrettrök",
    "cigarrettröken": "cigarrettrök",
    "cigarrettrökens": "cigarrettrök",
    "cigarrettröks": "cigarrettrök",
    "cigarretts": "cigarrett",
    "cigarrettuttagen": "cigarrettuttag",
    "cigarrettuttagens": "cigarrettuttag",
    "cigarrettuttaget": "cigarrettuttag",
    "cigarrettuttagets": "cigarrettuttag",
    "cigarrettuttags": "cigarrettuttag",
    "cigarrettändar": "cigarrettändare",
    "cigarrettändaren": "cigarrettändare",
    "cigarrettändarens": "cigarrettändare",
    "cigarrettändares": "cigarrettändare",
    "cigarrettändarkontakten": "cigarrettändarkontakt",
    "cigarrettändarkontaktens": "cigarrettändarkontakt",
    "cigarrettändarkontakter": "cigarrettändarkontakt",
    "cigarrettändarkontakterna": "cigarrettändarkontakt",
    "cigarrettändarkontakternas": "cigarrettändarkontakt",
    "cigarrettändarkontakters": "cigarrettändarkontakt",
    "cigarrettändarkontakts": "cigarrettändarkontakt",
    "cigarrettändarna": "cigarrettändare",
    "cigarrettändarnas": "cigarrettändare",
    "cigarrettändaruttagen": "cigarrettändaruttag",
    "cigarrettändaruttagens": "cigarrettändaruttag",
    "cigarrettändaruttager": "cigarrettändaruttag",
    "cigarrettändaruttagerna": "cigarrettändaruttag",
    "cigarrettändaruttagernas": "cigarrettändaruttag",
    "cigarrettändaruttagers": "cigarrettändaruttag",
    "cigarrettändaruttags": "cigarrettändaruttag",
    "cigarrillen": "cigarrill",
    "cigarrillens": "cigarrill",
    "cigarriller": "cigarrill",
    "cigarrillerna": "cigarrill",
    "cigarrillernas": "cigarrill",
    "cigarrillers": "cigarrill",
    "cigarrills": "cigarrill",
    "cigarrlåd": "cigarrlåda",
    "cigarrlådan": "cigarrlåda",
    "cigarrlådans": "cigarrlåda",
    "cigarrlådas": "cigarrlåda",
    "cigarrlåde": "cigarrlåda",
    "cigarrlådor": "cigarrlåda",
    "cigarrlådorna": "cigarrlåda",
    "cigarrlådornas": "cigarrlåda",
    "cigarrlådors": "cigarrlåda",
    "cigarrlåds": "cigarrlåda",
    "cigarrs": "cigarr",
    "cigars": "cig",
    "cigen": "cig",
    "cigens": "cig",
    "ciggar": "cigg",
    "ciggarna": "cigg",
    "ciggarnas": "cigg",
    "ciggars": "cigg",
    "ciggen": "cigg",
    "ciggens": "cigg",
    "ciggs": "cigg",
    "cigs": "cig",
    "cikad": "cikada",
    "cikadan": "cikada",
    "cikadans": "cikada",
    "cikadas": "cikada",
    "cikade": "cikada",
    "cikador": "cikada",
    "cikadorna": "cikada",
    "cikadornas": "cikada",
    "cikadors": "cikada",
    "cikads": "cikada",
    "ciklidfiskar": "ciklidfisk",
    "ciklidfiskarna": "ciklidfisk",
    "ciklidfiskarnas": "ciklidfisk",
    "ciklidfiskars": "ciklidfisk",
    "ciklidfisken": "ciklidfisk",
    "ciklidfiskens": "ciklidfisk",
    "ciklidfiskfaun": "ciklidfiskfauna",
    "ciklidfiskfaunan": "ciklidfiskfauna",
    "ciklidfiskfaunans": "ciklidfiskfauna",
    "ciklidfiskfaunas": "ciklidfiskfauna",
    "ciklidfiskfaune": "ciklidfiskfauna",
    "ciklidfiskfaunor": "ciklidfiskfauna",
    "ciklidfiskfaunorna": "ciklidfiskfauna",
    "ciklidfiskfaunornas": "ciklidfiskfauna",
    "ciklidfiskfaunors": "ciklidfiskfauna",
    "ciklidfiskfauns": "ciklidfiskfauna",
    "ciklidfisks": "ciklidfisk",
    "cikorian": "cikoria",
    "cikorians": "cikoria",
    "cikorias": "cikoria",
    "ciliarkroppar": "ciliarkropp",
    "ciliarkropparna": "ciliarkropp",
    "ciliarkropparnas": "ciliarkropp",
    "ciliarkroppars": "ciliarkropp",
    "ciliarkroppen": "ciliarkropp",
    "ciliarkroppens": "ciliarkropp",
    "ciliarkropps": "ciliarkropp",
    "ciliarmuskeln": "ciliarmuskel",
    "ciliarmuskelns": "ciliarmuskel",
    "ciliarmuskels": "ciliarmuskel",
    "ciliarmuskler": "ciliarmuskel",
    "ciliarmusklerna": "ciliarmuskel",
    "ciliarmusklernas": "ciliarmuskel",
    "ciliarmusklers": "ciliarmuskel",
    "cilien": "cilie",
    "ciliens": "cilie",
    "cilier": "cilie",
    "cilierna": "cilie",
    "ciliernas": "cilie",
    "ciliers": "cilie",
    "cilies": "cilie",
    "cimbel": "cimbrer",
    "cimbels": "cimbrer",
    "cimbrerna": "cimbrer",
    "cimbrernas": "cimbrer",
    "cimbrers": "cimbrer",
    "cineasten": "cineast",
    "cineastens": "cineast",
    "cineaster": "cineast",
    "cineasterna": "cineast",
    "cineasternas": "cineast",
    "cineasters": "cineast",
    "cineasts": "cineast",
    "cinemateken": "cinematek",
    "cinematekens": "cinematek",
    "cinemateket": "cinematek",
    "cinematekets": "cinematek",
    "cinemateks": "cinematek",
    "cinerari": "cineraria",
    "cinerarian": "cineraria",
    "cinerarians": "cineraria",
    "cinerarias": "cineraria",
    "cinerarie": "cineraria",
    "cinerarior": "cineraria",
    "cinerariorna": "cineraria",
    "cinerariornas": "cineraria",
    "cinerariors": "cineraria",
    "cineraris": "cineraria",
    "cinnobern": "cinnober",
    "cinnoberns": "cinnober",
    "cinnobers": "cinnober",
    "cirkaprisen": "cirkapris",
    "cirkaprisens": "cirkapris",
    "cirkapriser": "cirkapris",
    "cirkapriserna": "cirkapris",
    "cirkaprisernas": "cirkapris",
    "cirkaprisers": "cirkapris",
    "cirkapriset": "cirkapris",
    "cirkaprisets": "cirkapris",
    "cirkelbanan": "cirkelbana",
    "cirkelbanans": "cirkelbana",
    "cirkelbanas": "cirkelbana",
    "cirkelbane": "cirkelbana",
    "cirkelbanor": "cirkelbana",
    "cirkelbanorna": "cirkelbana",
    "cirkelbanornas": "cirkelbana",
    "cirkelbanors": "cirkelbana",
    "cirkelbenen": "cirkelben",
    "cirkelbenens": "cirkelben",
    "cirkelbenet": "cirkelben",
    "cirkelbenets": "cirkelben",
    "cirkelbens": "cirkelben",
    "cirkelbevisen": "cirkelbevis",
    "cirkelbevisens": "cirkelbevis",
    "cirkelbeviset": "cirkelbevis",
    "cirkelbevisets": "cirkelbevis",
    "cirkelbåg": "cirkelbåge",
    "cirkelbågar": "cirkelbåge",
    "cirkelbågarna": "cirkelbåge",
    "cirkelbågarnas": "cirkelbåge",
    "cirkelbågars": "cirkelbåge",
    "cirkelbågen": "cirkelbåge",
    "cirkelbågens": "cirkelbåge",
    "cirkelbåges": "cirkelbåge",
    "cirkelbågs": "cirkelbåge",
    "cirkeldefinitionen": "cirkeldefinition",
    "cirkeldefinitionens": "cirkeldefinition",
    "cirkeldefinitioner": "cirkeldefinition",
    "cirkeldefinitionerna": "cirkeldefinition",
    "cirkeldefinitionernas": "cirkeldefinition",
    "cirkeldefinitioners": "cirkeldefinition",
    "cirkeldefinitions": "cirkeldefinition",
    "cirkelformen": "cirkelform",
    "cirkelformens": "cirkelform",
    "cirkelforms": "cirkelform",
    "cirkelgången": "cirkelgång",
    "cirkelgångens": "cirkelgång",
    "cirkelgångs": "cirkelgång",
    "cirkelledar": "cirkelledare",
    "cirkelledaren": "cirkelledare",
    "cirkelledarens": "cirkelledare",
    "cirkelledares": "cirkelledare",
    "cirkelledarna": "cirkelledare",
    "cirkelledarnas": "cirkelledare",
    "cirkeln": "cirkel",
    "cirkelns": "cirkel",
    "cirkelperiferien": "cirkelperiferi",
    "cirkelperiferiens": "cirkelperiferi",
    "cirkelperiferier": "cirkelperiferi",
    "cirkelperiferierna": "cirkelperiferi",
    "cirkelperiferiernas": "cirkelperiferi",
    "cirkelperiferiers": "cirkelperiferi",
    "cirkelperiferin": "cirkelperiferi",
    "cirkelperiferins": "cirkelperiferi",
    "cirkelperiferis": "cirkelperiferi",
    "cirkelprocessen": "cirkelprocess",
    "cirkelprocessens": "cirkelprocess",
    "cirkelprocesser": "cirkelprocess",
    "cirkelprocesserna": "cirkelprocess",
    "cirkelprocessernas": "cirkelprocess",
    "cirkelprocessers": "cirkelprocess",
    "cirkelrunda": "cirkelrund",
    "cirkelrundare": "cirkelrund",
    "cirkelrundares": "cirkelrund",
    "cirkelrundas": "cirkelrund",
    "cirkelrundast": "cirkelrund",
    "cirkelrundaste": "cirkelrund",
    "cirkelrundastes": "cirkelrund",
    "cirkelrundasts": "cirkelrund",
    "cirkelrunde": "cirkelrund",
    "cirkelrundes": "cirkelrund",
    "cirkelrundheten": "cirkelrundhet",
    "cirkelrundhetens": "cirkelrundhet",
    "cirkelrundhets": "cirkelrundhet",
    "cirkelrunds": "cirkelrund",
    "cirkelrunt": "cirkelrund",
    "cirkelrunts": "cirkelrund",
    "cirkelrörelsen": "cirkelrörelse",
    "cirkelrörelsens": "cirkelrörelse",
    "cirkelrörelser": "cirkelrörelse",
    "cirkelrörelserna": "cirkelrörelse",
    "cirkelrörelsernas": "cirkelrörelse",
    "cirkelrörelsers": "cirkelrörelse",
    "cirkelrörelses": "cirkelrörelse",
    "cirkels": "cirkel",
    "cirkelsegmenten": "cirkelsegment",
    "cirkelsegmentens": "cirkelsegment",
    "cirkelsegmentet": "cirkelsegment",
    "cirkelsegmentets": "cirkelsegment",
    "cirkelsegments": "cirkelsegment",
    "cirkelsektorer": "cirkelsektor",
    "cirkelsektorerna": "cirkelsektor",
    "cirkelsektorernas": "cirkelsektor",
    "cirkelsektorers": "cirkelsektor",
    "cirkelsektorn": "cirkelsektor",
    "cirkelsektorns": "cirkelsektor",
    "cirkelsektors": "cirkelsektor",
    "cirkelsluten": "cirkelslut",
    "cirkelslutens": "cirkelslut",
    "cirkelslutet": "cirkelslut",
    "cirkelslutets": "cirkelslut",
    "cirkelsluts": "cirkelslut",
    "cirkelsågar": "cirkelsåg",
    "cirkelsågarna": "cirkelsåg",
    "cirkelsågarnas": "cirkelsåg",
    "cirkelsågars": "cirkelsåg",
    "cirkelsågen": "cirkelsåg",
    "cirkelsågens": "cirkelsåg",
    "cirkelsågs": "cirkelsåg",
    "cirklade": "cirkla",
    "cirklades": "cirkla",
    "cirklande": "cirkla",
    "cirklanden": "cirklande",
    "cirklandena": "cirklande",
    "cirklandenas": "cirklande",
    "cirklandens": "cirklande",
    "cirklandes": "cirklande",
    "cirklandet": "cirklande",
    "cirklandets": "cirklande",
    "cirklar": "cirkla",
    "cirklarna": "cirkel",
    "cirklarnas": "cirkel",
    "cirklars": "cirkel",
    "cirklas": "cirkla",
    "cirklat": "cirkla",
    "cirklats": "cirkla",
    "cirkulationen": "cirkulation",
    "cirkulationens": "cirkulation",
    "cirkulationer": "cirkulation",
    "cirkulationerna": "cirkulation",
    "cirkulationernas": "cirkulation",
    "cirkulationers": "cirkulation",
    "cirkulations": "cirkulation",
    "cirkulationsplatsen": "cirkulationsplats",
    "cirkulationsplatsens": "cirkulationsplats",
    "cirkulationsplatser": "cirkulationsplats",
    "cirkulationsplatserna": "cirkulationsplats",
    "cirkulationsplatsernas": "cirkulationsplats",
    "cirkulationsplatsers": "cirkulationsplats",
    "cirkulationspumpar": "cirkulationspump",
    "cirkulationspumparna": "cirkulationspump",
    "cirkulationspumparnas": "cirkulationspump",
    "cirkulationspumpars": "cirkulationspump",
    "cirkulationspumpen": "cirkulationspump",
    "cirkulationspumpens": "cirkulationspump",
    "cirkulationspumps": "cirkulationspump",
    "cirkulationsrubbningar": "cirkulationsrubbning",
    "cirkulationsrubbningarna": "cirkulationsrubbning",
    "cirkulationsrubbningarnas": "cirkulationsrubbning",
    "cirkulationsrubbningars": "cirkulationsrubbning",
    "cirkulationsrubbningen": "cirkulationsrubbning",
    "cirkulationsrubbningens": "cirkulationsrubbning",
    "cirkulationsrubbnings": "cirkulationsrubbning",
    "cirkulerad": "cirkulera",
    "cirkulerade": "cirkulera",
    "cirkulerades": "cirkulera",
    "cirkulerads": "cirkulera",
    "cirkulerande": "cirkulera",
    "cirkuleranden": "cirkulerande",
    "cirkulerandena": "cirkulerande",
    "cirkulerandenas": "cirkulerande",
    "cirkulerandens": "cirkulerande",
    "cirkulerandes": "cirkulerande",
    "cirkulerandet": "cirkulerande",
    "cirkulerandets": "cirkulerande",
    "cirkulerar": "cirkulera",
    "cirkuleras": "cirkulera",
    "cirkulerat": "cirkulera",
    "cirkulerats": "cirkulera",
    "cirkulerbara": "cirkulerbar",
    "cirkulerbarare": "cirkulerbar",
    "cirkulerbarares": "cirkulerbar",
    "cirkulerbaras": "cirkulerbar",
    "cirkulerbarast": "cirkulerbar",
    "cirkulerbaraste": "cirkulerbar",
    "cirkulerbarastes": "cirkulerbar",
    "cirkulerbarasts": "cirkulerbar",
    "cirkulerbare": "cirkulerbar",
    "cirkulerbares": "cirkulerbar",
    "cirkulerbarheten": "cirkulerbarhet",
    "cirkulerbarhetens": "cirkulerbarhet",
    "cirkulerbarhets": "cirkulerbarhet",
    "cirkulerbars": "cirkulerbar",
    "cirkulerbart": "cirkulerbar",
    "cirkulerbarts": "cirkulerbar",
    "cirkuleringar": "cirkulering",
    "cirkuleringarna": "cirkulering",
    "cirkuleringarnas": "cirkulering",
    "cirkuleringars": "cirkulering",
    "cirkuleringen": "cirkulering",
    "cirkuleringens": "cirkulering",
    "cirkulerings": "cirkulering",
    "cirkulära": "cirkulär",
    "cirkulärare": "cirkulär",
    "cirkulärares": "cirkulär",
    "cirkuläras": "cirkulär",
    "cirkulärast": "cirkulär",
    "cirkuläraste": "cirkulär",
    "cirkulärastes": "cirkulär",
    "cirkulärasts": "cirkulär",
    "cirkuläre": "cirkulär",
    "cirkulären": "cirkulär",
    "cirkulärens": "cirkulär",
    "cirkuläres": "cirkulär",
    "cirkuläret": "cirkulär",
    "cirkulärets": "cirkulär",
    "cirkulärledar": "cirkulärledare",
    "cirkulärledaren": "cirkulärledare",
    "cirkulärledarens": "cirkulärledare",
    "cirkulärledares": "cirkulärledare",
    "cirkulärledarna": "cirkulärledare",
    "cirkulärledarnas": "cirkulärledare",
    "cirkulärs": "cirkulär",
    "cirkulärt": "cirkulär",
    "cirkulärts": "cirkulär",
    "cirkumflexen": "cirkumflex",
    "cirkumflexens": "cirkumflex",
    "cirkumflexer": "cirkumflex",
    "cirkumflexerna": "cirkumflex",
    "cirkumflexernas": "cirkumflex",
    "cirkumflexers": "cirkumflex",
    "cirkumpolara": "cirkumpolar",
    "cirkumpolarare": "cirkumpolar",
    "cirkumpolarares": "cirkumpolar",
    "cirkumpolaras": "cirkumpolar",
    "cirkumpolarast": "cirkumpolar",
    "cirkumpolaraste": "cirkumpolar",
    "cirkumpolarastes": "cirkumpolar",
    "cirkumpolarasts": "cirkumpolar",
    "cirkumpolare": "cirkumpolar",
    "cirkumpolares": "cirkumpolar",
    "cirkumpolars": "cirkumpolar",
    "cirkumpolart": "cirkumpolar",
    "cirkumpolarts": "cirkumpolar",
    "cirkumpolära": "cirkumpolär",
    "cirkumpolärare": "cirkumpolär",
    "cirkumpolärares": "cirkumpolär",
    "cirkumpoläras": "cirkumpolär",
    "cirkumpolärast": "cirkumpolär",
    "cirkumpoläraste": "cirkumpolär",
    "cirkumpolärastes": "cirkumpolär",
    "cirkumpolärasts": "cirkumpolär",
    "cirkumpoläre": "cirkumpolär",
    "cirkumpoläres": "cirkumpolär",
    "cirkumpolärs": "cirkumpolär",
    "cirkumpolärt": "cirkumpolär",
    "cirkumpolärts": "cirkumpolär",
    "cirkusar": "cirkus",
    "cirkusarenan": "cirkusarena",
    "cirkusarenans": "cirkusarena",
    "cirkusarenas": "cirkusarena",
    "cirkusarenor": "cirkusarena",
    "cirkusarenorna": "cirkusarena",
    "cirkusarenornas": "cirkusarena",
    "cirkusarenors": "cirkusarena",
    "cirkusarna": "cirkus",
    "cirkusarnas": "cirkus",
    "cirkusars": "cirkus",
    "cirkusartisten": "cirkusartist",
    "cirkusartistens": "cirkusartist",
    "cirkusartister": "cirkusartist",
    "cirkusartisterna": "cirkusartist",
    "cirkusartisternas": "cirkusartist",
    "cirkusartisters": "cirkusartist",
    "cirkusartists": "cirkusartist",
    "cirkusdjuren": "cirkusdjur",
    "cirkusdjurens": "cirkusdjur",
    "cirkusdjuret": "cirkusdjur",
    "cirkusdjurets": "cirkusdjur",
    "cirkusdjurs": "cirkusdjur",
    "cirkuselefanten": "cirkuselefant",
    "cirkuselefantens": "cirkuselefant",
    "cirkuselefanter": "cirkuselefant",
    "cirkuselefanterna": "cirkuselefant",
    "cirkuselefanternas": "cirkuselefant",
    "cirkuselefanters": "cirkuselefant",
    "cirkuselefants": "cirkuselefant",
    "cirkusen": "cirkus",
    "cirkusens": "cirkus",
    "cirkusföreställningar": "cirkusföreställning",
    "cirkusföreställningarna": "cirkusföreställning",
    "cirkusföreställningarnas": "cirkusföreställning",
    "cirkusföreställningars": "cirkusföreställning",
    "cirkusföreställningen": "cirkusföreställning",
    "cirkusföreställningens": "cirkusföreställning",
    "cirkusföreställnings": "cirkusföreställning",
    "cirkusmanegen": "cirkusmanege",
    "cirkusmanegens": "cirkusmanege",
    "cirkusmaneger": "cirkusmanege",
    "cirkusmanegerna": "cirkusmanege",
    "cirkusmanegernas": "cirkusmanege",
    "cirkusmanegers": "cirkusmanege",
    "cirkusmaneges": "cirkusmanege",
    "cirkusmässiga": "cirkusmässig",
    "cirkusmässigare": "cirkusmässig",
    "cirkusmässigares": "cirkusmässig",
    "cirkusmässigas": "cirkusmässig",
    "cirkusmässigast": "cirkusmässig",
    "cirkusmässigaste": "cirkusmässig",
    "cirkusmässigastes": "cirkusmässig",
    "cirkusmässigasts": "cirkusmässig",
    "cirkusmässige": "cirkusmässig",
    "cirkusmässiges": "cirkusmässig",
    "cirkusmässigs": "cirkusmässig",
    "cirkusmässigt": "cirkusmässig",
    "cirkusmässigts": "cirkusmässig",
    "cirkusnummerna": "cirkusnummer",
    "cirkusnummernas": "cirkusnummer",
    "cirkusnummers": "cirkusnummer",
    "cirkusnumren": "cirkusnummer",
    "cirkusnumrens": "cirkusnummer",
    "cirkusnumret": "cirkusnummer",
    "cirkusnumrets": "cirkusnummer",
    "cirkustälten": "cirkustält",
    "cirkustältens": "cirkustält",
    "cirkustältet": "cirkustält",
    "cirkustältets": "cirkustält",
    "cirkustälts": "cirkustält",
    "cirkusvagnar": "cirkusvagn",
    "cirkusvagnarna": "cirkusvagn",
    "cirkusvagnarnas": "cirkusvagn",
    "cirkusvagnars": "cirkusvagn",
    "cirkusvagnen": "cirkusvagn",
    "cirkusvagnens": "cirkusvagn",
    "cirkusvagns": "cirkusvagn",
    "cirrusen": "cirrus",
    "cirrusens": "cirrus",
    "cirrusmolnen": "cirrusmoln",
    "cirrusmolnens": "cirrusmoln",
    "cirrusmolnet": "cirrusmoln",
    "cirrusmolnets": "cirrusmoln",
    "cirrusmolns": "cirrusmoln",
    "cisalpinska": "cisalpinsk",
    "cisalpinskare": "cisalpinsk",
    "cisalpinskares": "cisalpinsk",
    "cisalpinskas": "cisalpinsk",
    "cisalpinskast": "cisalpinsk",
    "cisalpinskaste": "cisalpinsk",
    "cisalpinskastes": "cisalpinsk",
    "cisalpinskasts": "cisalpinsk",
    "cisalpinske": "cisalpinsk",
    "cisalpinskes": "cisalpinsk",
    "cisalpinsks": "cisalpinsk",
    "cisalpinskt": "cisalpinsk",
    "cisalpinskts": "cisalpinsk",
    "ciselerad": "ciselera",
    "ciselerade": "ciselera",
    "ciselerades": "ciselera",
    "ciselerads": "ciselera",
    "ciselerande": "ciselera",
    "ciseleranden": "ciselerande",
    "ciselerandena": "ciselerande",
    "ciselerandenas": "ciselerande",
    "ciselerandens": "ciselerande",
    "ciselerandes": "ciselerande",
    "ciselerandet": "ciselerande",
    "ciselerandets": "ciselerande",
    "ciselerar": "ciselera",
    "ciseleras": "ciselera",
    "ciselerat": "ciselera",
    "ciselerats": "ciselera",
    "ciselerbara": "ciselerbar",
    "ciselerbarare": "ciselerbar",
    "ciselerbarares": "ciselerbar",
    "ciselerbaras": "ciselerbar",
    "ciselerbarast": "ciselerbar",
    "ciselerbaraste": "ciselerbar",
    "ciselerbarastes": "ciselerbar",
    "ciselerbarasts": "ciselerbar",
    "ciselerbare": "ciselerbar",
    "ciselerbares": "ciselerbar",
    "ciselerbarheten": "ciselerbarhet",
    "ciselerbarhetens": "ciselerbarhet",
    "ciselerbarhets": "ciselerbarhet",
    "ciselerbars": "ciselerbar",
    "ciselerbart": "ciselerbar",
    "ciselerbarts": "ciselerbar",
    "ciseleringar": "ciselering",
    "ciseleringarna": "ciselering",
    "ciseleringarnas": "ciselering",
    "ciseleringars": "ciselering",
    "ciseleringen": "ciselering",
    "ciseleringens": "ciselering",
    "ciselerings": "ciselering",
    "ciselören": "ciselör",
    "ciselörens": "ciselör",
    "ciselörer": "ciselör",
    "ciselörerna": "ciselör",
    "ciselörernas": "ciselör",
    "ciselörers": "ciselör",
    "ciselörs": "ciselör",
    "cissen": "ciss",
    "cissens": "ciss",
    "cisset": "ciss",
    "cissets": "ciss",
    "cissusar": "cissus",
    "cissusarna": "cissus",
    "cissusarnas": "cissus",
    "cissusars": "cissus",
    "cissusen": "cissus",
    "cissusens": "cissus",
    "cisterciensen": "cisterciens",
    "cisterciensens": "cisterciens",
    "cistercienser": "cisterciens",
    "cistercienserklosterna": "cistercienserkloster",
    "cistercienserklosternas": "cistercienserkloster",
    "cistercienserklosters": "cistercienserkloster",
    "cistercienserklostren": "cistercienserkloster",
    "cistercienserklostrens": "cistercienserkloster",
    "cistercienserklostret": "cistercienserkloster",
    "cistercienserklostrets": "cistercienserkloster",
    "cisterciensermunkar": "cisterciensermunk",
    "cisterciensermunkarna": "cisterciensermunk",
    "cisterciensermunkarnas": "cisterciensermunk",
    "cisterciensermunkars": "cisterciensermunk",
    "cisterciensermunken": "cisterciensermunk",
    "cisterciensermunkens": "cisterciensermunk",
    "cisterciensermunks": "cisterciensermunk",
    "cistercienserna": "cisterciens",
    "cisterciensernas": "cisterciens",
    "cistercienserordens": "cistercienserorden",
    "cistercienserordnar": "cistercienserorden",
    "cistercienserordnarna": "cistercienserorden",
    "cistercienserordnarnas": "cistercienserorden",
    "cistercienserordnars": "cistercienserorden",
    "cistercienserordnen": "cistercienserorden",
    "cistercienserordnens": "cistercienserorden",
    "cisterciensers": "cisterciens",
    "cisterciensordens": "cisterciensorden",
    "cisterciensordnar": "cisterciensorden",
    "cisterciensordnarna": "cisterciensorden",
    "cisterciensordnarnas": "cisterciensorden",
    "cisterciensordnars": "cisterciensorden",
    "cisterciensordnen": "cisterciensorden",
    "cisterciensordnens": "cisterciensorden",
    "cisternen": "cistern",
    "cisternens": "cistern",
    "cisterner": "cistern",
    "cisternerna": "cistern",
    "cisternernas": "cistern",
    "cisterners": "cistern",
    "cisterns": "cistern",
    "citadellen": "citadell",
    "citadellens": "citadell",
    "citadellet": "citadell",
    "citadellets": "citadell",
    "citadells": "citadell",
    "citaten": "citat",
    "citatens": "citat",
    "citatet": "citat",
    "citatets": "citat",
    "citationen": "citation",
    "citationens": "citation",
    "citationer": "citation",
    "citationerna": "citation",
    "citationernas": "citation",
    "citationers": "citation",
    "citations": "citation",
    "citationsteckens": "citationstecken",
    "citationstecknen": "citationstecken",
    "citationstecknens": "citationstecken",
    "citationstecknet": "citationstecken",
    "citationstecknets": "citationstecken",
    "citatorden": "citatord",
    "citatordens": "citatord",
    "citatordet": "citatord",
    "citatordets": "citatord",
    "citatords": "citatord",
    "citats": "citat",
    "citerad": "citera",
    "citerade": "citera",
    "citerades": "citera",
    "citerads": "citera",
    "citerande": "citera",
    "citeranden": "citerande",
    "citerandena": "citerande",
    "citerandenas": "citerande",
    "citerandens": "citerande",
    "citerandes": "citerande",
    "citerandet": "citerande",
    "citerandets": "citerande",
    "citerar": "citera",
    "citeras": "citera",
    "citerat": "citera",
    "citerats": "citera",
    "citerbara": "citerbar",
    "citerbarare": "citerbar",
    "citerbarares": "citerbar",
    "citerbaras": "citerbar",
    "citerbarast": "citerbar",
    "citerbaraste": "citerbar",
    "citerbarastes": "citerbar",
    "citerbarasts": "citerbar",
    "citerbare": "citerbar",
    "citerbares": "citerbar",
    "citerbarheten": "citerbarhet",
    "citerbarhetens": "citerbarhet",
    "citerbarhets": "citerbarhet",
    "citerbars": "citerbar",
    "citerbart": "citerbar",
    "citerbarts": "citerbar",
    "citeringar": "citering",
    "citeringarna": "citering",
    "citeringarnas": "citering",
    "citeringars": "citering",
    "citeringen": "citering",
    "citeringens": "citering",
    "citerings": "citering",
    "citratet": "citrat",
    "citratets": "citrat",
    "citrats": "citrat",
    "citrinen": "citrin",
    "citrinens": "citrin",
    "citriner": "citrin",
    "citrinerna": "citrin",
    "citrinernas": "citrin",
    "citriners": "citrin",
    "citrins": "citrin",
    "citroenen": "citroen",
    "citroener": "citroen",
    "citroenernas": "citroen",
    "citroens": "citroen",
    "citronbakelsen": "citronbakelse",
    "citronbakelsens": "citronbakelse",
    "citronbakelser": "citronbakelse",
    "citronbakelserna": "citronbakelse",
    "citronbakelsernas": "citronbakelse",
    "citronbakelsers": "citronbakelse",
    "citronbakelses": "citronbakelse",
    "citrondoften": "citrondoft",
    "citrondoftens": "citrondoft",
    "citrondofter": "citrondoft",
    "citrondofterna": "citrondoft",
    "citrondofternas": "citrondoft",
    "citrondofters": "citrondoft",
    "citrondofts": "citrondoft",
    "citronen": "citron",
    "citronens": "citron",
    "citroner": "citron",
    "citronerna": "citron",
    "citronernas": "citron",
    "citroners": "citron",
    "citronfjärilar": "citronfjäril",
    "citronfjärilarna": "citronfjäril",
    "citronfjärilarnas": "citronfjäril",
    "citronfjärilars": "citronfjäril",
    "citronfjärilen": "citronfjäril",
    "citronfjärilens": "citronfjäril",
    "citronfjäriln": "citronfjäril",
    "citronfjärilns": "citronfjäril",
    "citronfjärils": "citronfjäril",
    "citrongräsoljan": "citrongräsolja",
    "citrongräsoljans": "citrongräsolja",
    "citrongräsoljas": "citrongräsolja",
    "citrongräsolje": "citrongräsolja",
    "citrongula": "citrongul",
    "citrongulare": "citrongul",
    "citrongulares": "citrongul",
    "citrongulas": "citrongul",
    "citrongulast": "citrongul",
    "citrongulaste": "citrongul",
    "citrongulastes": "citrongul",
    "citrongulasts": "citrongul",
    "citrongule": "citrongul",
    "citrongules": "citrongul",
    "citronguls": "citrongul",
    "citrongult": "citrongul",
    "citrongults": "citrongul",
    "citronläsken": "citronläsk",
    "citronläskens": "citronläsk",
    "citronläsks": "citronläsk",
    "citronoljan": "citronolja",
    "citronoljans": "citronolja",
    "citronoljas": "citronolja",
    "citronolje": "citronolja",
    "citrons": "citron",
    "citronskalen": "citronskal",
    "citronskalens": "citronskal",
    "citronskalet": "citronskal",
    "citronskalets": "citronskal",
    "citronskals": "citronskal",
    "citronsyran": "citronsyra",
    "citronsyrans": "citronsyra",
    "citronsyras": "citronsyra",
    "citronsyre": "citronsyra",
    "citrusar": "citrus",
    "citrusarna": "citrus",
    "citrusarnas": "citrus",
    "citrusars": "citrus",
    "citrusen": "citrus",
    "citrusens": "citrus",
    "citrusfrukten": "citrusfrukt",
    "citrusfruktens": "citrusfrukt",
    "citrusfrukter": "citrusfrukt",
    "citrusfrukterna": "citrusfrukt",
    "citrusfrukternas": "citrusfrukt",
    "citrusfrukters": "citrusfrukt",
    "citrusfrukts": "citrusfrukt",
    "citrussmaken": "citrussmak",
    "citrussmakens": "citrussmak",
    "citrussmaks": "citrussmak",
    "citter": "cittra",
    "cittran": "cittra",
    "cittrans": "cittra",
    "cittras": "cittra",
    "cittre": "cittra",
    "cittror": "cittra",
    "cittrorna": "cittra",
    "cittrornas": "cittra",
    "cittrors": "cittra",
    "citydressar": "citydress",
    "citydressarna": "citydress",
    "citydressarnas": "citydress",
    "citydressars": "citydress",
    "citydressen": "citydress",
    "citydressens": "citydress",
    "citydresser": "citydress",
    "citydresserna": "citydress",
    "citydressernas": "citydress",
    "citydressers": "citydress",
    "cityn": "city",
    "cityna": "city",
    "citynas": "city",
    "cityns": "city",
    "citys": "city",
    "cityt": "city",
    "cityts": "city",
    "civila": "civil",
    "civilare": "civil",
    "civilares": "civil",
    "civilas": "civil",
    "civilast": "civil",
    "civilaste": "civil",
    "civilastes": "civil",
    "civilasts": "civil",
    "civilbefolkningar": "civilbefolkning",
    "civilbefolkningarna": "civilbefolkning",
    "civilbefolkningarnas": "civilbefolkning",
    "civilbefolkningars": "civilbefolkning",
    "civilbefolkningen": "civilbefolkning",
    "civilbefolkningens": "civilbefolkning",
    "civilbefolknings": "civilbefolkning",
    "civilbegravningar": "civilbegravning",
    "civilbegravningarna": "civilbegravning",
    "civilbegravningarnas": "civilbegravning",
    "civilbegravningars": "civilbegravning",
    "civilbegravningen": "civilbegravning",
    "civilbegravningens": "civilbegravning",
    "civilbegravnings": "civilbegravning",
    "civile": "civil",
    "civilekonomen": "civilekonom",
    "civilekonomens": "civilekonom",
    "civilekonomer": "civilekonom",
    "civilekonomerna": "civilekonom",
    "civilekonomernas": "civilekonom",
    "civilekonomers": "civilekonom",
    "civilekonoms": "civilekonom",
    "civiles": "civil",
    "civilflyget": "civilflyg",
    "civilflygets": "civilflyg",
    "civilflygs": "civilflyg",
    "civilförsvaret": "civilförsvar",
    "civilförsvarets": "civilförsvar",
    "civilförsvars": "civilförsvar",
    "civilingenjören": "civilingenjör",
    "civilingenjörens": "civilingenjör",
    "civilingenjörer": "civilingenjör",
    "civilingenjörerna": "civilingenjör",
    "civilingenjörernas": "civilingenjör",
    "civilingenjörers": "civilingenjör",
    "civilingenjörn": "civilingenjör",
    "civilingenjörns": "civilingenjör",
    "civilingenjörs": "civilingenjör",
    "civilisationen": "civilisation",
    "civilisationens": "civilisation",
    "civilisationer": "civilisation",
    "civilisationerna": "civilisation",
    "civilisationernas": "civilisation",
    "civilisationers": "civilisation",
    "civilisations": "civilisation",
    "civilisatoriska": "civilisatorisk",
    "civilisatoriskare": "civilisatorisk",
    "civilisatoriskares": "civilisatorisk",
    "civilisatoriskas": "civilisatorisk",
    "civilisatoriskast": "civilisatorisk",
    "civilisatoriskaste": "civilisatorisk",
    "civilisatoriskastes": "civilisatorisk",
    "civilisatoriskasts": "civilisatorisk",
    "civilisatoriske": "civilisatorisk",
    "civilisatoriskes": "civilisatorisk",
    "civilisatorisks": "civilisatorisk",
    "civilisatoriskt": "civilisatorisk",
    "civilisatoriskts": "civilisatorisk",
    "civiliserad": "civilisera",
    "civiliserade": "civiliserad",
    "civiliserades": "civiliserad",
    "civiliserads": "civiliserad",
    "civiliserande": "civilisera",
    "civiliseranden": "civiliserande",
    "civiliserandena": "civiliserande",
    "civiliserandenas": "civiliserande",
    "civiliserandens": "civiliserande",
    "civiliserandes": "civiliserande",
    "civiliserandet": "civiliserande",
    "civiliserandets": "civiliserande",
    "civiliserar": "civilisera",
    "civiliseras": "civilisera",
    "civiliserat": "civiliserad",
    "civiliserats": "civiliserad",
    "civiliserbara": "civiliserbar",
    "civiliserbarare": "civiliserbar",
    "civiliserbarares": "civiliserbar",
    "civiliserbaras": "civiliserbar",
    "civiliserbarast": "civiliserbar",
    "civiliserbaraste": "civiliserbar",
    "civiliserbarastes": "civiliserbar",
    "civiliserbarasts": "civiliserbar",
    "civiliserbare": "civiliserbar",
    "civiliserbares": "civiliserbar",
    "civiliserbarheten": "civiliserbarhet",
    "civiliserbarhetens": "civiliserbarhet",
    "civiliserbarhets": "civiliserbarhet",
    "civiliserbars": "civiliserbar",
    "civiliserbart": "civiliserbar",
    "civiliserbarts": "civiliserbar",
    "civiliseringar": "civilisering",
    "civiliseringarna": "civilisering",
    "civiliseringarnas": "civilisering",
    "civiliseringars": "civilisering",
    "civiliseringen": "civilisering",
    "civiliseringens": "civilisering",
    "civiliserings": "civilisering",
    "civilisten": "civilist",
    "civilistens": "civilist",
    "civilister": "civilist",
    "civilisterna": "civilist",
    "civilisternas": "civilist",
    "civilisters": "civilist",
    "civilists": "civilist",
    "civilklädda": "civilklädd",
    "civilkläddare": "civilklädd",
    "civilkläddares": "civilklädd",
    "civilkläddas": "civilklädd",
    "civilkläddast": "civilklädd",
    "civilkläddaste": "civilklädd",
    "civilkläddastes": "civilklädd",
    "civilkläddasts": "civilklädd",
    "civilklädde": "civilklädd",
    "civilkläddes": "civilklädd",
    "civilklädds": "civilklädd",
    "civilklätt": "civilklädd",
    "civilklätts": "civilklädd",
    "civilkurages": "civilkurage",
    "civilkuraget": "civilkurage",
    "civilkuragets": "civilkurage",
    "civillagar": "civillag",
    "civillagarna": "civillag",
    "civillagarnas": "civillag",
    "civillagars": "civillag",
    "civillagen": "civillag",
    "civillagens": "civillag",
    "civillags": "civillag",
    "civilmilitära": "civilmilitär",
    "civilmilitärare": "civilmilitär",
    "civilmilitärares": "civilmilitär",
    "civilmilitäras": "civilmilitär",
    "civilmilitärast": "civilmilitär",
    "civilmilitäraste": "civilmilitär",
    "civilmilitärastes": "civilmilitär",
    "civilmilitärasts": "civilmilitär",
    "civilmilitäre": "civilmilitär",
    "civilmilitären": "civilmilitär",
    "civilmilitärens": "civilmilitär",
    "civilmilitärer": "civilmilitär",
    "civilmilitärerna": "civilmilitär",
    "civilmilitärernas": "civilmilitär",
    "civilmilitärers": "civilmilitär",
    "civilmilitäres": "civilmilitär",
    "civilmilitärs": "civilmilitär",
    "civilmilitärt": "civilmilitär",
    "civilmilitärts": "civilmilitär",
    "civilmotståndet": "civilmotstånd",
    "civilmotståndets": "civilmotstånd",
    "civilmotstånds": "civilmotstånd",
    "civilmålen": "civilmål",
    "civilmålens": "civilmål",
    "civilmålet": "civilmål",
    "civilmålets": "civilmål",
    "civilmåls": "civilmål",
    "civilprocessen": "civilprocess",
    "civilprocessens": "civilprocess",
    "civilprocesser": "civilprocess",
    "civilprocesserna": "civilprocess",
    "civilprocessernas": "civilprocess",
    "civilprocessers": "civilprocess",
    "civilrätten": "civilrätt",
    "civilrättens": "civilrätt",
    "civilrätts": "civilrätt",
    "civilrättsliga": "civilrättslig",
    "civilrättsligas": "civilrättslig",
    "civilrättslige": "civilrättslig",
    "civilrättsliges": "civilrättslig",
    "civilrättsligs": "civilrättslig",
    "civilrättsligt": "civilrättslig",
    "civilrättsligts": "civilrättslig",
    "civils": "civil",
    "civilstaten": "civilstat",
    "civilstatens": "civilstat",
    "civilstater": "civilstat",
    "civilstaterna": "civilstat",
    "civilstaternas": "civilstat",
    "civilstaters": "civilstat",
    "civilstats": "civilstat",
    "civilstånden": "civilstånd",
    "civilståndens": "civilstånd",
    "civilståndet": "civilstånd",
    "civilståndets": "civilstånd",
    "civilstånds": "civilstånd",
    "civilt": "civil",
    "civilts": "civil",
    "civiläktenskapen": "civiläktenskap",
    "civiläktenskapens": "civiläktenskap",
    "civiläktenskapet": "civiläktenskap",
    "civiläktenskapets": "civiläktenskap",
    "civiläktenskaps": "civiläktenskap",
    "clairobscuren": "clairobscur",
    "clairobscurens": "clairobscur",
    "clairobscurer": "clairobscur",
    "clairobscurerna": "clairobscur",
    "clairobscurernas": "clairobscur",
    "clairobscurers": "clairobscur",
    "clairobscurs": "clairobscur",
    "clairvoyancen": "clairvoyance",
    "clairvoyancens": "clairvoyance",
    "clairvoyances": "clairvoyance",
    "clairvoyanta": "clairvoyant",
    "clairvoyantare": "clairvoyant",
    "clairvoyantares": "clairvoyant",
    "clairvoyantas": "clairvoyant",
    "clairvoyantast": "clairvoyant",
    "clairvoyantaste": "clairvoyant",
    "clairvoyantastes": "clairvoyant",
    "clairvoyantasts": "clairvoyant",
    "clairvoyante": "clairvoyant",
    "clairvoyantes": "clairvoyant",
    "clairvoyants": "clairvoyant",
    "clear": "cleara",
    "clearad": "cleara",
    "clearade": "cleara",
    "clearades": "cleara",
    "clearads": "cleara",
    "clearande": "cleara",
    "clearanden": "clearande",
    "clearandena": "clearande",
    "clearandenas": "clearande",
    "clearandens": "clearande",
    "clearandes": "clearande",
    "clearandet": "clearande",
    "clearandets": "clearande",
    "clearar": "cleara",
    "clearas": "cleara",
    "clearat": "cleara",
    "clearats": "cleara",
    "clearingen": "clearing",
    "clearingens": "clearing",
    "clearings": "clearing",
    "clematisar": "clematis",
    "clematisarna": "clematis",
    "clematisarnas": "clematis",
    "clematisars": "clematis",
    "clematisen": "clematis",
    "clematisens": "clematis",
    "clematiser": "clematis",
    "clematiserna": "clematis",
    "clematisernas": "clematis",
    "clematisers": "clematis",
    "clementinen": "clementin",
    "clementinens": "clementin",
    "clementiner": "clementin",
    "clementinerna": "clementin",
    "clementinernas": "clementin",
    "clementiners": "clementin",
    "clementins": "clementin",
    "clinchen": "clinch",
    "clinchens": "clinch",
    "clinchs": "clinch",
    "clipsen": "clips",
    "clipsens": "clips",
    "clipset": "clips",
    "clipsets": "clips",
    "clitorisar": "clitoris",
    "clitorisarna": "clitoris",
    "clitorisarnas": "clitoris",
    "clitorisars": "clitoris",
    "clitorisen": "clitoris",
    "clitorisens": "clitoris",
    "cloisonväggar": "cloisonvägg",
    "cloisonväggarna": "cloisonvägg",
    "cloisonväggarnas": "cloisonvägg",
    "cloisonväggars": "cloisonvägg",
    "cloisonväggen": "cloisonvägg",
    "cloisonväggens": "cloisonvägg",
    "cloisonväggs": "cloisonvägg",
    "cloquéer": "cloqué",
    "cloquéerna": "cloqué",
    "cloquéernas": "cloqué",
    "cloquéers": "cloqué",
    "cloquén": "cloqué",
    "cloquéns": "cloqué",
    "cloqués": "cloqué",
    "cloun": "clou",
    "clouns": "clou",
    "clous": "clou",
    "clownen": "clown",
    "clownens": "clown",
    "clowner": "clown",
    "clownerier": "clowneri",
    "clownerierna": "clowneri",
    "clowneriernas": "clowneri",
    "clowneriers": "clowneri",
    "clowneriet": "clowneri",
    "clowneriets": "clowneri",
    "clowneris": "clowneri",
    "clownerit": "clowneri",
    "clownerits": "clowneri",
    "clownerna": "clown",
    "clownernas": "clown",
    "clowners": "clown",
    "clowns": "clown",
    "club-blazern": "club-blazer",
    "club-blazerns": "club-blazer",
    "club-blazers": "club-blazer",
    "club-blazrar": "club-blazer",
    "club-blazrarna": "club-blazer",
    "club-blazrarnas": "club-blazer",
    "club-blazrars": "club-blazer",
    "clubstekar": "clubstek",
    "clubstekarna": "clubstek",
    "clubstekarnas": "clubstek",
    "clubstekars": "clubstek",
    "clubsteken": "clubstek",
    "clubstekens": "clubstek",
    "clubsteks": "clubstek",
    "coachar": "coach",
    "coacharna": "coach",
    "coacharnas": "coach",
    "coachars": "coach",
    "coachen": "coach",
    "coachens": "coach",
    "coacher": "coach",
    "coacherna": "coach",
    "coachernas": "coach",
    "coachers": "coach",
    "coachs": "coach",
    "cocacolan": "cocacola",
    "cocacolans": "cocacola",
    "cocacolas": "cocacola",
    "cocacolor": "cocacola",
    "cocacolorna": "cocacola",
    "cocacolornas": "cocacola",
    "cocacolors": "cocacola",
    "cocan": "coca",
    "cocans": "coca",
    "cocas": "coca",
    "cockerspanielar": "cockerspaniel",
    "cockerspanielarna": "cockerspaniel",
    "cockerspanielarnas": "cockerspaniel",
    "cockerspanielars": "cockerspaniel",
    "cockerspanieln": "cockerspaniel",
    "cockerspanielns": "cockerspaniel",
    "cockerspaniels": "cockerspaniel",
    "cockneyn": "cockney",
    "cockneyns": "cockney",
    "cockneys": "cockney",
    "cockpitar": "cockpit",
    "cockpitarna": "cockpit",
    "cockpitarnas": "cockpit",
    "cockpitars": "cockpit",
    "cockpiten": "cockpit",
    "cockpitens": "cockpit",
    "cockpits": "cockpit",
    "cocktailar": "cocktail",
    "cocktailarna": "cocktail",
    "cocktailarnas": "cocktail",
    "cocktailars": "cocktail",
    "cocktailbjudningar": "cocktailbjudning",
    "cocktailbjudningarna": "cocktailbjudning",
    "cocktailbjudningarnas": "cocktailbjudning",
    "cocktailbjudningars": "cocktailbjudning",
    "cocktailbjudningen": "cocktailbjudning",
    "cocktailbjudningens": "cocktailbjudning",
    "cocktailbjudnings": "cocktailbjudning",
    "cocktailborden": "cocktailbord",
    "cocktailbordens": "cocktailbord",
    "cocktailbordet": "cocktailbord",
    "cocktailbordets": "cocktailbord",
    "cocktailbords": "cocktailbord",
    "cocktailbären": "cocktailbär",
    "cocktailbärens": "cocktailbär",
    "cocktailbäret": "cocktailbär",
    "cocktailbärets": "cocktailbär",
    "cocktailbärs": "cocktailbär",
    "cocktailen": "cocktail",
    "cocktailens": "cocktail",
    "cocktailpartyn": "cocktailparty",
    "cocktailpartyna": "cocktailparty",
    "cocktailpartynas": "cocktailparty",
    "cocktailpartyns": "cocktailparty",
    "cocktailpartys": "cocktailparty",
    "cocktailpartyt": "cocktailparty",
    "cocktailpartyts": "cocktailparty",
    "cocktails": "cocktail",
    "cocktailsarna": "cocktail",
    "cocktailsarnas": "cocktail",
    "cocktailsen": "cocktail",
    "cocktailsens": "cocktail",
    "cocor": "coca",
    "cocorna": "coca",
    "cocornas": "coca",
    "cocors": "coca",
    "codexar": "codex",
    "codexarna": "codex",
    "codexarnas": "codex",
    "codexars": "codex",
    "codexen": "codex",
    "codexens": "codex",
    "cointreaun": "cointreau",
    "cointreauns": "cointreau",
    "cointreaus": "cointreau",
    "cokacolan": "cokacola",
    "cokacolans": "cokacola",
    "cokacolas": "cokacola",
    "cokacolor": "cokacola",
    "cokacolorna": "cokacola",
    "cokacolornas": "cokacola",
    "cokacolors": "cokacola",
    "cokakolan": "cokakola",
    "cokakolans": "cokakola",
    "cokakolas": "cokakola",
    "cokakolor": "cokakola",
    "cokakolorna": "cokakola",
    "cokakolornas": "cokakola",
    "cokakolors": "cokakola",
    "colan": "cola",
    "colans": "cola",
    "colas": "cola",
    "colibakterien": "colibakterie",
    "colibakteriens": "colibakterie",
    "colibakterier": "colibakterie",
    "colibakterierna": "colibakterie",
    "colibakteriernas": "colibakterie",
    "colibakteriers": "colibakterie",
    "colibakteries": "colibakterie",
    "collagen": "collage",
    "collagens": "collage",
    "collages": "collage",
    "collaget": "collage",
    "collagets": "collage",
    "collegeflick": "collegeflicka",
    "collegeflickan": "collegeflicka",
    "collegeflickans": "collegeflicka",
    "collegeflickas": "collegeflicka",
    "collegeflicke": "collegeflicka",
    "collegeflickor": "collegeflicka",
    "collegeflickorna": "collegeflicka",
    "collegeflickornas": "collegeflicka",
    "collegeflickors": "collegeflicka",
    "collegeflicks": "collegeflicka",
    "collegen": "college",
    "collegens": "college",
    "collegepojk": "collegepojke",
    "collegepojkar": "collegepojke",
    "collegepojkarna": "collegepojke",
    "collegepojkarnas": "collegepojke",
    "collegepojkars": "collegepojke",
    "collegepojken": "collegepojke",
    "collegepojkens": "collegepojke",
    "collegepojkes": "collegepojke",
    "collegepojks": "collegepojke",
    "colleges": "college",
    "colleget": "college",
    "collegetröj": "collegetröja",
    "collegetröjan": "collegetröja",
    "collegetröjans": "collegetröja",
    "collegetröjas": "collegetröja",
    "collegetröje": "collegetröja",
    "collegetröjor": "collegetröja",
    "collegetröjorna": "collegetröja",
    "collegetröjornas": "collegetröja",
    "collegetröjors": "collegetröja",
    "collegetröjs": "collegetröja",
    "collegets": "college",
    "collien": "collie",
    "colliens": "collie",
    "collier": "collie",
    "collieren": "collier",
    "collierens": "collier",
    "collierer": "collier",
    "colliererna": "collier",
    "collierernas": "collier",
    "collierers": "collier",
    "colliern": "collier",
    "collierna": "collie",
    "colliernas": "collie",
    "collierns": "collier",
    "colliers": "collier",
    "collies": "collie",
    "colliesen": "collie",
    "colliesens": "collie",
    "colombianen": "colombian",
    "colombianens": "colombian",
    "colombianer": "colombian",
    "colombianerna": "colombian",
    "colombianernas": "colombian",
    "colombianers": "colombian",
    "colombians": "colombian",
    "colombianska": "colombiansk",
    "colombianskan": "colombianska",
    "colombianskans": "colombianska",
    "colombianskare": "colombiansk",
    "colombianskares": "colombiansk",
    "colombianskas": "colombianska",
    "colombianskast": "colombiansk",
    "colombianskaste": "colombiansk",
    "colombianskastes": "colombiansk",
    "colombianskasts": "colombiansk",
    "colombianske": "colombianska",
    "colombianskes": "colombiansk",
    "colombianskor": "colombianska",
    "colombianskorna": "colombianska",
    "colombianskornas": "colombianska",
    "colombianskors": "colombianska",
    "colombiansks": "colombiansk",
    "colombianskt": "colombiansk",
    "colombianskts": "colombiansk",
    "color": "cola",
    "colorna": "cola",
    "colornas": "cola",
    "colors": "cola",
    "combin": "combi",
    "combins": "combi",
    "combis": "combi",
    "come-backen": "come-back",
    "come-backens": "come-back",
    "come-backer": "come-back",
    "come-backerna": "come-back",
    "come-backernas": "come-back",
    "come-backers": "come-back",
    "come-backs": "come-back",
    "comebacken": "comeback",
    "comebackens": "comeback",
    "comebacker": "comeback",
    "comebackerna": "comeback",
    "comebackernas": "comeback",
    "comebackers": "comeback",
    "comebacks": "comeback",
    "commandon": "commando",
    "commandons": "commando",
    "commandos": "commando",
    "commandosarna": "commando",
    "commandosarnas": "commando",
    "commandosen": "commando",
    "commandosens": "commando",
    "commandotruppen": "commandotrupp",
    "commandotruppens": "commandotrupp",
    "commandotrupper": "commandotrupp",
    "commandotrupperna": "commandotrupp",
    "commandotruppernas": "commandotrupp",
    "commandotruppers": "commandotrupp",
    "commandotrupps": "commandotrupp",
    "comoriern": "comorier",
    "comorierna": "comorier",
    "comoriernas": "comorier",
    "comorierns": "comorier",
    "comoriers": "comorier",
    "comoriska": "comorisk",
    "comoriskan": "comoriska",
    "comoriskans": "comoriska",
    "comoriskare": "comorisk",
    "comoriskares": "comorisk",
    "comoriskas": "comoriska",
    "comoriskast": "comorisk",
    "comoriskaste": "comorisk",
    "comoriskastes": "comorisk",
    "comoriskasts": "comorisk",
    "comoriske": "comoriska",
    "comoriskes": "comorisk",
    "comoriskor": "comoriska",
    "comoriskorna": "comoriska",
    "comoriskornas": "comoriska",
    "comoriskors": "comoriska",
    "comorisks": "comorisk",
    "comoriskt": "comorisk",
    "comoriskts": "comorisk",
    "complets": "complet",
    "conferencieren": "conferencier",
    "conferencierens": "conferencier",
    "conferencierer": "conferencier",
    "conferenciererna": "conferencier",
    "conferencierernas": "conferencier",
    "conferencierers": "conferencier",
    "conferenciern": "conferencier",
    "conferencierns": "conferencier",
    "conferenciers": "conferencier",
    "conférencieren": "conférencier",
    "conférencierens": "conférencier",
    "conférencierer": "conférencier",
    "conférenciererna": "conférencier",
    "conférencierernas": "conférencier",
    "conférencierers": "conférencier",
    "conférenciern": "conférencier",
    "conférencierns": "conférencier",
    "conférenciers": "conférencier",
    "consensusen": "consensus",
    "consensusens": "consensus",
    "consomméer": "consommé",
    "consomméerna": "consommé",
    "consomméernas": "consommé",
    "consomméers": "consommé",
    "consommén": "consommé",
    "consomméns": "consommé",
    "consommés": "consommé",
    "containern": "container",
    "containerns": "container",
    "containers": "container",
    "containersarna": "container",
    "containersarnas": "container",
    "containersen": "container",
    "containersens": "container",
    "containrar": "container",
    "containrarna": "container",
    "containrarnas": "container",
    "containrars": "container",
    "contortatallar": "contortatall",
    "contortatallarna": "contortatall",
    "contortatallarnas": "contortatall",
    "contortatallars": "contortatall",
    "contortatallen": "contortatall",
    "contortatallens": "contortatall",
    "contortatalls": "contortatall",
    "coola": "cool",
    "coolare": "cool",
    "coolares": "cool",
    "coolas": "cool",
    "coolast": "cool",
    "coolaste": "cool",
    "coolastes": "cool",
    "coolasts": "cool",
    "coole": "cool",
    "cooles": "cool",
    "coolheten": "coolhet",
    "coolhetens": "coolhet",
    "coolhets": "coolhet",
    "cools": "cool",
    "coolt": "cool",
    "coolts": "cool",
    "copy-caten": "copy-cat",
    "copy-catens": "copy-cat",
    "copy-cats": "copy-cat",
    "copy-catsarna": "copy-cat",
    "copy-catsarnas": "copy-cat",
    "copy-catsen": "copy-cat",
    "copy-catsens": "copy-cat",
    "copycaten": "copycat",
    "copycatens": "copycat",
    "copycats": "copycat",
    "copycatsarna": "copycat",
    "copycatsarnas": "copycat",
    "copycatsen": "copycat",
    "copycatsens": "copycat",
    "copyrighten": "copyright",
    "copyrightens": "copyright",
    "copyrights": "copyright",
    "copywritern": "copywriter",
    "copywriterns": "copywriter",
    "copywriters": "copywriter",
    "copywritersarna": "copywriter",
    "copywritersarnas": "copywriter",
    "copywritersen": "copywriter",
    "copywritersens": "copywriter",
    "corioliskraften": "corioliskraft",
    "corioliskraftens": "corioliskraft",
    "corioliskrafts": "corioliskraft",
    "cornflakesen": "cornflakes",
    "cornflakesens": "cornflakes",
    "cornichonen": "cornichon",
    "cornichonens": "cornichon",
    "cornichoner": "cornichon",
    "cornichonerna": "cornichon",
    "cornichonernas": "cornichon",
    "cornichoners": "cornichon",
    "cornichons": "cornichon",
    "coronacellen": "coronacell",
    "coronacellens": "coronacell",
    "coronaceller": "coronacell",
    "coronacellerna": "coronacell",
    "coronacellernas": "coronacell",
    "coronacellers": "coronacell",
    "coronacells": "coronacell",
    "corps-de-logier": "corps-de-logi",
    "corps-de-logierna": "corps-de-logi",
    "corps-de-logiernas": "corps-de-logi",
    "corps-de-logiers": "corps-de-logi",
    "corps-de-logiet": "corps-de-logi",
    "corps-de-logiets": "corps-de-logi",
    "corps-de-logis": "corps-de-logi",
    "corps-de-logit": "corps-de-logi",
    "corps-de-logits": "corps-de-logi",
    "corpusar": "corpus",
    "corpusarna": "corpus",
    "corpusarnas": "corpus",
    "corpusars": "corpus",
    "corpusen": "corpus",
    "corpusens": "corpus",
    "corpuset": "corpus",
    "corpusets": "corpus",
    "cortegen": "cortege",
    "cortegens": "cortege",
    "corteger": "cortege",
    "cortegerna": "cortege",
    "cortegernas": "cortege",
    "cortegers": "cortege",
    "corteges": "cortege",
    "cortexen": "cortex",
    "cortexens": "cortex",
    "corticala": "cortical",
    "corticalare": "cortical",
    "corticalares": "cortical",
    "corticalas": "cortical",
    "corticalast": "cortical",
    "corticalaste": "cortical",
    "corticalastes": "cortical",
    "corticalasts": "cortical",
    "corticale": "cortical",
    "corticales": "cortical",
    "corticals": "cortical",
    "corticalt": "cortical",
    "corticalts": "cortical",
    "cortisonbehandlingar": "cortisonbehandling",
    "cortisonbehandlingarna": "cortisonbehandling",
    "cortisonbehandlingarnas": "cortisonbehandling",
    "cortisonbehandlingars": "cortisonbehandling",
    "cortisonbehandlingen": "cortisonbehandling",
    "cortisonbehandlingens": "cortisonbehandling",
    "cortisonbehandlings": "cortisonbehandling",
    "cortisonen": "cortison",
    "cortisonens": "cortison",
    "cortisoner": "cortison",
    "cortisonerna": "cortison",
    "cortisonernas": "cortison",
    "cortisoners": "cortison",
    "cortisonet": "cortison",
    "cortisonets": "cortison",
    "cortisons": "cortison",
    "cortègen": "cortège",
    "cortègens": "cortège",
    "cortèger": "cortège",
    "cortègerna": "cortège",
    "cortègernas": "cortège",
    "cortègers": "cortège",
    "cortèges": "cortège",
    "cosinusar": "cosinus",
    "cosinusarna": "cosinus",
    "cosinusarnas": "cosinus",
    "cosinusars": "cosinus",
    "cosinusen": "cosinus",
    "cosinusens": "cosinus",
    "costaricanen": "costarican",
    "costaricanens": "costarican",
    "costaricaner": "costarican",
    "costaricanerna": "costarican",
    "costaricanernas": "costarican",
    "costaricaners": "costarican",
    "costaricans": "costarican",
    "costaricanska": "costaricansk",
    "costaricanskan": "costaricanska",
    "costaricanskans": "costaricanska",
    "costaricanskare": "costaricansk",
    "costaricanskares": "costaricansk",
    "costaricanskas": "costaricanska",
    "costaricanskast": "costaricansk",
    "costaricanskaste": "costaricansk",
    "costaricanskastes": "costaricansk",
    "costaricanskasts": "costaricansk",
    "costaricanske": "costaricanska",
    "costaricanskes": "costaricansk",
    "costaricanskor": "costaricanska",
    "costaricanskorna": "costaricanska",
    "costaricanskornas": "costaricanska",
    "costaricanskors": "costaricanska",
    "costaricansks": "costaricansk",
    "costaricanskt": "costaricansk",
    "costaricanskts": "costaricansk",
    "cotangensen": "cotangens",
    "cotangensens": "cotangens",
    "cotangenten": "cotangent",
    "cotangentens": "cotangent",
    "cotangenter": "cotangent",
    "cotangenterna": "cotangent",
    "cotangenternas": "cotangent",
    "cotangenters": "cotangent",
    "cotangents": "cotangent",
    "coulomben": "coulomb",
    "coulombens": "coulomb",
    "coulombs": "coulomb",
    "countrymusiken": "countrymusik",
    "countrymusikens": "countrymusik",
    "countrymusiks": "countrymusik",
    "countryn": "country",
    "countryns": "country",
    "countrys": "country",
    "coupen": "coupe",
    "coupens": "coupe",
    "couper": "coupe",
    "couperna": "coupe",
    "coupernas": "coupe",
    "coupers": "coupe",
    "coupes": "coupe",
    "couronnen": "couronne",
    "couronnens": "couronne",
    "couronnes": "couronne",
    "couronnet": "couronne",
    "couronnets": "couronne",
    "courtages": "courtage",
    "courtaget": "courtage",
    "courtagets": "courtage",
    "cous-cousen": "cous-cous",
    "cous-cousens": "cous-cous",
    "cous-couset": "cous-cous",
    "cous-cousets": "cous-cous",
    "couscousen": "couscous",
    "couscousens": "couscous",
    "couscouset": "couscous",
    "couscousets": "couscous",
    "covern": "cover",
    "coverns": "cover",
    "covers": "cover",
    "coversarna": "cover",
    "coversarnas": "cover",
    "coversen": "cover",
    "coversens": "cover",
    "cowboyen": "cowboy",
    "cowboyens": "cowboy",
    "cowboyer": "cowboy",
    "cowboyerna": "cowboy",
    "cowboyernas": "cowboy",
    "cowboyers": "cowboy",
    "cowboyhattar": "cowboyhatt",
    "cowboyhattarna": "cowboyhatt",
    "cowboyhattarnas": "cowboyhatt",
    "cowboyhattars": "cowboyhatt",
    "cowboyhatten": "cowboyhatt",
    "cowboyhattens": "cowboyhatt",
    "cowboyhatts": "cowboyhatt",
    "cowboys": "cowboy",
    "coyoten": "coyote",
    "coyotens": "coyote",
    "coyoter": "coyote",
    "coyoterna": "coyote",
    "coyoternas": "coyote",
    "coyoters": "coyote",
    "coyotes": "coyote",
    "cp-s": "cp",
    "cp-skadade": "cp-skadad",
    "cp-skadades": "cp-skadad",
    "cp-skadat": "cp-skadad",
    "cp:s": "cp",
    "cps": "cp",
    "crackersen": "crackers",
    "crackersens": "crackers",
    "crawlade": "crawla",
    "crawlades": "crawla",
    "crawlande": "crawla",
    "crawlanden": "crawlande",
    "crawlandena": "crawlande",
    "crawlandenas": "crawlande",
    "crawlandens": "crawlande",
    "crawlandes": "crawlande",
    "crawlandet": "crawlande",
    "crawlandets": "crawlande",
    "crawlar": "crawla",
    "crawlas": "crawla",
    "crawlat": "crawla",
    "crawlats": "crawla",
    "crawlen": "crawl",
    "crawlens": "crawl",
    "crawls": "crawl",
    "credon": "credo",
    "credona": "credo",
    "credonas": "credo",
    "credons": "credo",
    "credos": "credo",
    "credot": "credo",
    "credots": "credo",
    "cremen": "creme",
    "cremens": "creme",
    "cremer": "creme",
    "cremerna": "creme",
    "cremernas": "creme",
    "cremers": "creme",
    "cremes": "creme",
    "crepen": "crepe",
    "crepens": "crepe",
    "creper": "crepe",
    "creperna": "crepe",
    "crepernas": "crepe",
    "crepers": "crepe",
    "crepes": "crepe",
    "crepesen": "crepe",
    "crepesens": "crepe",
    "crescendon": "crescendo",
    "crescendona": "crescendo",
    "crescendonas": "crescendo",
    "crescendons": "crescendo",
    "crescendos": "crescendo",
    "crescendot": "crescendo",
    "crescendots": "crescendo",
    "cricketen": "cricket",
    "cricketens": "cricket",
    "cricketklubb": "cricketklubba",
    "cricketklubban": "cricketklubba",
    "cricketklubbans": "cricketklubba",
    "cricketklubbas": "cricketklubba",
    "cricketklubbe": "cricketklubba",
    "cricketklubbor": "cricketklubba",
    "cricketklubborna": "cricketklubba",
    "cricketklubbornas": "cricketklubba",
    "cricketklubbors": "cricketklubba",
    "cricketklubbs": "cricketklubba",
    "crickets": "cricket",
    "croissanten": "croissant",
    "croissantens": "croissant",
    "croissanter": "croissant",
    "croissanterna": "croissant",
    "croissanternas": "croissant",
    "croissanters": "croissant",
    "croissants": "croissant",
    "croquisen": "croquis",
    "croquisens": "croquis",
    "croquiser": "croquis",
    "croquiserna": "croquis",
    "croquisernas": "croquis",
    "croquisers": "croquis",
    "crosscheckingar": "crosschecking",
    "crosscheckingarna": "crosschecking",
    "crosscheckingarnas": "crosschecking",
    "crosscheckingars": "crosschecking",
    "crosscheckingen": "crosschecking",
    "crosscheckingens": "crosschecking",
    "crosscheckings": "crosschecking",
    "crossglasögonen": "crossglasögon",
    "crossglasögonens": "crossglasögon",
    "crossglasögons": "crossglasögon",
    "crosshandsk": "crosshandske",
    "crosshandskar": "crosshandske",
    "crosshandskarna": "crosshandske",
    "crosshandskarnas": "crosshandske",
    "crosshandskars": "crosshandske",
    "crosshandsken": "crosshandske",
    "crosshandskens": "crosshandske",
    "crosshandskes": "crosshandske",
    "crosshjälmar": "crosshjälm",
    "crosshjälmarna": "crosshjälm",
    "crosshjälmarnas": "crosshjälm",
    "crosshjälmars": "crosshjälm",
    "crosshjälmen": "crosshjälm",
    "crosshjälmens": "crosshjälm",
    "crosshjälms": "crosshjälm",
    "croupieren": "croupier",
    "croupierens": "croupier",
    "croupierer": "croupier",
    "croupiererna": "croupier",
    "croupierernas": "croupier",
    "croupierers": "croupier",
    "croupiern": "croupier",
    "croupierns": "croupier",
    "croupiers": "croupier",
    "crème-de-la-crèmen": "crème-de-la-crème",
    "crème-de-la-crèmens": "crème-de-la-crème",
    "crème-de-la-crèmes": "crème-de-la-crème",
    "crèmen": "crème",
    "crèmens": "crème",
    "crèmer": "crème",
    "crèmerna": "crème",
    "crèmernas": "crème",
    "crèmers": "crème",
    "crèmes": "crème",
    "crèpen": "crèpe",
    "crèpens": "crèpe",
    "crèper": "crèpe",
    "crèperna": "crèpe",
    "crèpernas": "crèpe",
    "crèpers": "crèpe",
    "crèpes": "crèpe",
    "crèpesen": "crèpe",
    "crèpesens": "crèpe",
    "crêpen": "crêpe",
    "crêpens": "crêpe",
    "crêper": "crêpe",
    "crêperna": "crêpe",
    "crêpernas": "crêpe",
    "crêpers": "crêpe",
    "crêpes": "crêpe",
    "crêpesen": "crêpe",
    "crêpesens": "crêpe",
    "csardasen": "csardas",
    "csardasens": "csardas",
    "cubanen": "cuban",
    "cubanens": "cuban",
    "cubaner": "cuban",
    "cubanerna": "cuban",
    "cubanernas": "cuban",
    "cubaners": "cuban",
    "cubans": "cuban",
    "cubanska": "cubansk",
    "cubanskare": "cubansk",
    "cubanskares": "cubansk",
    "cubanskas": "cubansk",
    "cubanskast": "cubansk",
    "cubanskaste": "cubansk",
    "cubanskastes": "cubansk",
    "cubanskasts": "cubansk",
    "cubanske": "cubansk",
    "cubanskes": "cubansk",
    "cubansks": "cubansk",
    "cubanskt": "cubansk",
    "cubanskts": "cubansk",
    "cumulusar": "cumulus",
    "cumulusarna": "cumulus",
    "cumulusarnas": "cumulus",
    "cumulusars": "cumulus",
    "cumuluscellen": "cumuluscell",
    "cumuluscellens": "cumuluscell",
    "cumulusceller": "cumuluscell",
    "cumuluscellerna": "cumuluscell",
    "cumuluscellernas": "cumuluscell",
    "cumuluscellers": "cumuluscell",
    "cumuluscells": "cumuluscell",
    "cumulusen": "cumulus",
    "cumulusens": "cumulus",
    "cumulusmolnen": "cumulusmoln",
    "cumulusmolnens": "cumulusmoln",
    "cumulusmolnet": "cumulusmoln",
    "cumulusmolnets": "cumulusmoln",
    "cumulusmolns": "cumulusmoln",
    "cupen": "cup",
    "cupens": "cup",
    "cuper": "cup",
    "cuperna": "cup",
    "cupernas": "cup",
    "cupers": "cup",
    "cups": "cup",
    "curares": "curare",
    "curaret": "curare",
    "curarets": "curare",
    "curaterad": "curatera",
    "curaterade": "curatera",
    "curaterades": "curatera",
    "curaterads": "curatera",
    "curaterande": "curatera",
    "curateranden": "curaterande",
    "curaterandena": "curaterande",
    "curaterandenas": "curaterande",
    "curaterandens": "curaterande",
    "curaterandes": "curaterande",
    "curaterandet": "curaterande",
    "curaterandets": "curaterande",
    "curaterar": "curatera",
    "curateras": "curatera",
    "curaterat": "curatera",
    "curaterats": "curatera",
    "curaterbara": "curaterbar",
    "curaterbarare": "curaterbar",
    "curaterbarares": "curaterbar",
    "curaterbaras": "curaterbar",
    "curaterbarast": "curaterbar",
    "curaterbaraste": "curaterbar",
    "curaterbarastes": "curaterbar",
    "curaterbarasts": "curaterbar",
    "curaterbare": "curaterbar",
    "curaterbares": "curaterbar",
    "curaterbarheten": "curaterbarhet",
    "curaterbarhetens": "curaterbarhet",
    "curaterbarhets": "curaterbarhet",
    "curaterbars": "curaterbar",
    "curaterbart": "curaterbar",
    "curaterbarts": "curaterbar",
    "curatorer": "curator",
    "curatorerna": "curator",
    "curatorernas": "curator",
    "curatorers": "curator",
    "curatorn": "curator",
    "curatorns": "curator",
    "curators": "curator",
    "curaçaon": "curaçao",
    "curaçaons": "curaçao",
    "curaçaos": "curaçao",
    "curerad": "curera",
    "curerade": "curera",
    "curerades": "curera",
    "curerads": "curera",
    "curerande": "curera",
    "cureranden": "curerande",
    "curerandena": "curerande",
    "curerandenas": "curerande",
    "curerandens": "curerande",
    "curerandes": "curerande",
    "curerandet": "curerande",
    "curerandets": "curerande",
    "curerar": "curera",
    "cureras": "curera",
    "curerat": "curera",
    "curerats": "curera",
    "curerbara": "curerbar",
    "curerbarare": "curerbar",
    "curerbarares": "curerbar",
    "curerbaras": "curerbar",
    "curerbarast": "curerbar",
    "curerbaraste": "curerbar",
    "curerbarastes": "curerbar",
    "curerbarasts": "curerbar",
    "curerbare": "curerbar",
    "curerbares": "curerbar",
    "curerbarheten": "curerbarhet",
    "curerbarhetens": "curerbarhet",
    "curerbarhets": "curerbarhet",
    "curerbars": "curerbar",
    "curerbart": "curerbar",
    "curerbarts": "curerbar",
    "curi": "curia",
    "curian": "curia",
    "curians": "curia",
    "curias": "curia",
    "curie": "curia",
    "curien": "curie",
    "curiena": "curie",
    "curienas": "curie",
    "curiens": "curie",
    "curies": "curie",
    "curiet": "curium",
    "curiets": "curium",
    "curior": "curia",
    "curiorna": "curia",
    "curiornas": "curia",
    "curiors": "curia",
    "curis": "curia",
    "curiumet": "curium",
    "curiumets": "curium",
    "curiums": "curium",
    "curlad": "curla",
    "curlade": "curla",
    "curlades": "curla",
    "curlads": "curla",
    "curlande": "curla",
    "curlanden": "curlande",
    "curlandena": "curlande",
    "curlandenas": "curlande",
    "curlandens": "curlande",
    "curlandes": "curlande",
    "curlandet": "curlande",
    "curlandets": "curlande",
    "curlar": "curla",
    "curlas": "curla",
    "curlat": "curla",
    "curlats": "curla",
    "curlingbarnen": "curlingbarn",
    "curlingbarnens": "curlingbarn",
    "curlingbarnet": "curlingbarn",
    "curlingbarnets": "curlingbarn",
    "curlingbarns": "curlingbarn",
    "curlingen": "curling",
    "curlingens": "curling",
    "curlingfinalen": "curlingfinal",
    "curlingfinalens": "curlingfinal",
    "curlingfinaler": "curlingfinal",
    "curlingfinalerna": "curlingfinal",
    "curlingfinalernas": "curlingfinal",
    "curlingfinalers": "curlingfinal",
    "curlingfinals": "curlingfinal",
    "curlingföräldern": "curlingförälder",
    "curlingförälderns": "curlingförälder",
    "curlingförälders": "curlingförälder",
    "curlingföräldrar": "curlingförälder",
    "curlingföräldrarna": "curlingförälder",
    "curlingföräldrarnas": "curlingförälder",
    "curlingföräldrars": "curlingförälder",
    "curlings": "curling",
    "curlingtävlingar": "curlingtävling",
    "curlingtävlingarna": "curlingtävling",
    "curlingtävlingarnas": "curlingtävling",
    "curlingtävlingars": "curlingtävling",
    "curlingtävlingen": "curlingtävling",
    "curlingtävlingens": "curlingtävling",
    "curlingtävlings": "curlingtävling",
    "currygryt": "currygryta",
    "currygrytan": "currygryta",
    "currygrytans": "currygryta",
    "currygrytas": "currygryta",
    "currygryte": "currygryta",
    "currygrytor": "currygryta",
    "currygrytorna": "currygryta",
    "currygrytornas": "currygryta",
    "currygrytors": "currygryta",
    "currygryts": "currygryta",
    "curryn": "curry",
    "curryns": "curry",
    "currys": "curry",
    "cyanblåa": "cyanblå",
    "cyanblåare": "cyanblå",
    "cyanblåares": "cyanblå",
    "cyanblåas": "cyanblå",
    "cyanblåast": "cyanblå",
    "cyanblåaste": "cyanblå",
    "cyanblåastes": "cyanblå",
    "cyanblåasts": "cyanblå",
    "cyanblåe": "cyanblå",
    "cyanblåes": "cyanblå",
    "cyanblås": "cyanblå",
    "cyanblått": "cyanblå",
    "cyanblåtts": "cyanblå",
    "cyanen": "cyan",
    "cyanens": "cyan",
    "cyanet": "cyan",
    "cyanets": "cyan",
    "cyaniden": "cyanid",
    "cyanidens": "cyanid",
    "cyanider": "cyanid",
    "cyaniderna": "cyanid",
    "cyanidernas": "cyanid",
    "cyaniders": "cyanid",
    "cyanids": "cyanid",
    "cyankaliet": "cyankalium",
    "cyankaliets": "cyankalium",
    "cyankaliumet": "cyankalium",
    "cyankaliumets": "cyankalium",
    "cyankaliums": "cyankalium",
    "cyanobakterien": "cyanobakterie",
    "cyanobakteriens": "cyanobakterie",
    "cyanobakterier": "cyanobakterie",
    "cyanobakterierna": "cyanobakterie",
    "cyanobakteriernas": "cyanobakterie",
    "cyanobakteriers": "cyanobakterie",
    "cyanobakteries": "cyanobakterie",
    "cyanosen": "cyanos",
    "cyanosens": "cyanos",
    "cyans": "cyan",
    "cyanvätes": "cyanväte",
    "cyanvätesyran": "cyanvätesyra",
    "cyanvätesyrans": "cyanvätesyra",
    "cyanvätesyras": "cyanvätesyra",
    "cyanvätesyre": "cyanvätesyra",
    "cyanvätet": "cyanväte",
    "cyanvätets": "cyanväte",
    "cyberbrottsligheten": "cyberbrottslighet",
    "cyberbrottslighetens": "cyberbrottslighet",
    "cyberbrottsligheter": "cyberbrottslighet",
    "cyberbrottsligheterna": "cyberbrottslighet",
    "cyberbrottsligheternas": "cyberbrottslighet",
    "cyberbrottsligheters": "cyberbrottslighet",
    "cyberbrottslighets": "cyberbrottslighet",
    "cybernetiken": "cybernetik",
    "cybernetikens": "cybernetik",
    "cybernetiks": "cybernetik",
    "cybernetiska": "cybernetisk",
    "cybernetiskare": "cybernetisk",
    "cybernetiskares": "cybernetisk",
    "cybernetiskas": "cybernetisk",
    "cybernetiskast": "cybernetisk",
    "cybernetiskaste": "cybernetisk",
    "cybernetiskastes": "cybernetisk",
    "cybernetiskasts": "cybernetisk",
    "cybernetiske": "cybernetisk",
    "cybernetiskes": "cybernetisk",
    "cybernetisks": "cybernetisk",
    "cybernetiskt": "cybernetisk",
    "cybernetiskts": "cybernetisk",
    "cyberrymden": "cyberrymd",
    "cyberrymdens": "cyberrymd",
    "cyberrymds": "cyberrymd",
    "cybersexet": "cybersex",
    "cybersexets": "cybersex",
    "cyberstrategien": "cyberstrategi",
    "cyberstrategiens": "cyberstrategi",
    "cyberstrategier": "cyberstrategi",
    "cyberstrategierna": "cyberstrategi",
    "cyberstrategiernas": "cyberstrategi",
    "cyberstrategiers": "cyberstrategi",
    "cyberstrategin": "cyberstrategi",
    "cyberstrategins": "cyberstrategi",
    "cyberstrategis": "cyberstrategi",
    "cybervärlden": "cybervärld",
    "cybervärldens": "cybervärld",
    "cybervärlds": "cybervärld",
    "cykelbanan": "cykelbana",
    "cykelbanans": "cykelbana",
    "cykelbanas": "cykelbana",
    "cykelbane": "cykelbana",
    "cykelbanor": "cykelbana",
    "cykelbanorna": "cykelbana",
    "cykelbanornas": "cykelbana",
    "cykelbanors": "cykelbana",
    "cykeldäcken": "cykeldäck",
    "cykeldäckens": "cykeldäck",
    "cykeldäcket": "cykeldäck",
    "cykeldäckets": "cykeldäck",
    "cykeldäcks": "cykeldäck",
    "cykelergometern": "cykelergometer",
    "cykelergometerns": "cykelergometer",
    "cykelergometers": "cykelergometer",
    "cykelergometrar": "cykelergometer",
    "cykelergometrarna": "cykelergometer",
    "cykelergometrarnas": "cykelergometer",
    "cykelergometrars": "cykelergometer",
    "cykelhjälmar": "cykelhjälm",
    "cykelhjälmarna": "cykelhjälm",
    "cykelhjälmarnas": "cykelhjälm",
    "cykelhjälmars": "cykelhjälm",
    "cykelhjälmen": "cykelhjälm",
    "cykelhjälmens": "cykelhjälm",
    "cykelhjälms": "cykelhjälm",
    "cykelkedjan": "cykelkedja",
    "cykelkedjans": "cykelkedja",
    "cykelkedjas": "cykelkedja",
    "cykelkedje": "cykelkedja",
    "cykelkedjor": "cykelkedja",
    "cykelkedjorna": "cykelkedja",
    "cykelkedjornas": "cykelkedja",
    "cykelkedjors": "cykelkedja",
    "cykelklämman": "cykelklämma",
    "cykelklämmans": "cykelklämma",
    "cykelklämmas": "cykelklämma",
    "cykelklämme": "cykelklämma",
    "cykelklämmor": "cykelklämma",
    "cykelklämmorna": "cykelklämma",
    "cykelklämmornas": "cykelklämma",
    "cykelklämmors": "cykelklämma",
    "cykelkrockar": "cykelkrock",
    "cykelkrockarna": "cykelkrock",
    "cykelkrockarnas": "cykelkrock",
    "cykelkrockars": "cykelkrock",
    "cykelkrocken": "cykelkrock",
    "cykelkrockens": "cykelkrock",
    "cykelkrocks": "cykelkrock",
    "cykelkrokar": "cykelkrok",
    "cykelkrokarna": "cykelkrok",
    "cykelkrokarnas": "cykelkrok",
    "cykelkrokars": "cykelkrok",
    "cykelkroken": "cykelkrok",
    "cykelkrokens": "cykelkrok",
    "cykelkroks": "cykelkrok",
    "cykellykt": "cykellykta",
    "cykellyktan": "cykellykta",
    "cykellyktans": "cykellykta",
    "cykellyktas": "cykellykta",
    "cykellykte": "cykellykta",
    "cykellyktor": "cykellykta",
    "cykellyktorna": "cykellykta",
    "cykellyktornas": "cykellykta",
    "cykellyktors": "cykellykta",
    "cykellykts": "cykellykta",
    "cykellåsen": "cykellås",
    "cykellåsens": "cykellås",
    "cykellåset": "cykellås",
    "cykellåsets": "cykellås",
    "cykeln": "cykel",
    "cykelns": "cykel",
    "cykelnyckeln": "cykelnyckel",
    "cykelnyckelns": "cykelnyckel",
    "cykelnyckels": "cykelnyckel",
    "cykelnycklar": "cykelnyckel",
    "cykelnycklarna": "cykelnyckel",
    "cykelnycklarnas": "cykelnyckel",
    "cykelnycklars": "cykelnyckel",
    "cykelpumpar": "cykelpump",
    "cykelpumparna": "cykelpump",
    "cykelpumparnas": "cykelpump",
    "cykelpumpars": "cykelpump",
    "cykelpumpen": "cykelpump",
    "cykelpumpens": "cykelpump",
    "cykelpumps": "cykelpump",
    "cykels": "cykel",
    "cykelsadeln": "cykelsadel",
    "cykelsadelns": "cykelsadel",
    "cykelsadels": "cykelsadel",
    "cykelsadlar": "cykelsadel",
    "cykelsadlarna": "cykelsadel",
    "cykelsadlarnas": "cykelsadel",
    "cykelsadlars": "cykelsadel",
    "cykelslangar": "cykelslang",
    "cykelslangarna": "cykelslang",
    "cykelslangarnas": "cykelslang",
    "cykelslangars": "cykelslang",
    "cykelslangen": "cykelslang",
    "cykelslangens": "cykelslang",
    "cykelslangs": "cykelslang",
    "cykelstyren": "cykelstyre",
    "cykelstyrena": "cykelstyre",
    "cykelstyrenas": "cykelstyre",
    "cykelstyrens": "cykelstyre",
    "cykelstyres": "cykelstyre",
    "cykelstyret": "cykelstyre",
    "cykelstyrets": "cykelstyre",
    "cykelställen": "cykelställ",
    "cykelställens": "cykelställ",
    "cykelstället": "cykelställ",
    "cykelställets": "cykelställ",
    "cykelställs": "cykelställ",
    "cykelstölden": "cykelstöld",
    "cykelstöldens": "cykelstöld",
    "cykelstölder": "cykelstöld",
    "cykelstölderna": "cykelstöld",
    "cykelstöldernas": "cykelstöld",
    "cykelstölders": "cykelstöld",
    "cykelstölds": "cykelstöld",
    "cykeltruppen": "cykeltrupp",
    "cykeltruppens": "cykeltrupp",
    "cykeltrupper": "cykeltrupp",
    "cykeltrupperna": "cykeltrupp",
    "cykeltruppernas": "cykeltrupp",
    "cykeltruppers": "cykeltrupp",
    "cykeltrupps": "cykeltrupp",
    "cykeltävlingar": "cykeltävling",
    "cykeltävlingarna": "cykeltävling",
    "cykeltävlingarnas": "cykeltävling",
    "cykeltävlingars": "cykeltävling",
    "cykeltävlingen": "cykeltävling",
    "cykeltävlingens": "cykeltävling",
    "cykeltävlings": "cykeltävling",
    "cykelventilen": "cykelventil",
    "cykelventilens": "cykelventil",
    "cykelventiler": "cykelventil",
    "cykelventilerna": "cykelventil",
    "cykelventilernas": "cykelventil",
    "cykelventilers": "cykelventil",
    "cykelventils": "cykelventil",
    "cykelåkningen": "cykelåkning",
    "cykelåkningens": "cykelåkning",
    "cykelåknings": "cykelåkning",
    "cyklad": "cykla",
    "cyklade": "cykla",
    "cyklades": "cykla",
    "cyklads": "cykla",
    "cyklamaten": "cyklamat",
    "cyklamatens": "cyklamat",
    "cyklamats": "cyklamat",
    "cyklamena": "cyklamen",
    "cyklamenas": "cyklamen",
    "cyklamens": "cyklamen",
    "cyklamer": "cyklamen",
    "cyklamerna": "cyklamen",
    "cyklamernas": "cyklamen",
    "cyklamers": "cyklamen",
    "cyklande": "cykla",
    "cyklanden": "cyklande",
    "cyklandena": "cyklande",
    "cyklandenas": "cyklande",
    "cyklandens": "cyklande",
    "cyklandes": "cyklande",
    "cyklandet": "cyklande",
    "cyklandets": "cyklande",
    "cyklar": "cykla",
    "cyklarna": "cykel",
    "cyklarnas": "cykel",
    "cyklars": "cykel",
    "cyklas": "cykla",
    "cyklat": "cykla",
    "cyklats": "cykla",
    "cykler": "cykel",
    "cyklerna": "cykel",
    "cyklernas": "cykel",
    "cyklers": "cykel",
    "cykliska": "cyklisk",
    "cykliskare": "cyklisk",
    "cykliskares": "cyklisk",
    "cykliskas": "cyklisk",
    "cykliskast": "cyklisk",
    "cykliskaste": "cyklisk",
    "cykliskastes": "cyklisk",
    "cykliskasts": "cyklisk",
    "cykliske": "cyklisk",
    "cykliskes": "cyklisk",
    "cyklisks": "cyklisk",
    "cykliskt": "cyklisk",
    "cykliskts": "cyklisk",
    "cyklisten": "cyklist",
    "cyklistens": "cyklist",
    "cyklister": "cyklist",
    "cyklisterna": "cyklist",
    "cyklisternas": "cyklist",
    "cyklisters": "cyklist",
    "cyklists": "cyklist",
    "cykloiden": "cykloid",
    "cykloidens": "cykloid",
    "cykloider": "cykloid",
    "cykloiderna": "cykloid",
    "cykloidernas": "cykloid",
    "cykloiders": "cykloid",
    "cykloids": "cykloid",
    "cyklometern": "cyklometer",
    "cyklometerns": "cyklometer",
    "cyklometers": "cyklometer",
    "cyklometrar": "cyklometer",
    "cyklometrarna": "cyklometer",
    "cyklometrarnas": "cyklometer",
    "cyklometrars": "cyklometer",
    "cyklonen": "cyklon",
    "cyklonens": "cyklon",
    "cykloner": "cyklon",
    "cyklonerna": "cyklon",
    "cyklonernas": "cyklon",
    "cykloners": "cyklon",
    "cyklonfamiljen": "cyklonfamilj",
    "cyklonfamiljens": "cyklonfamilj",
    "cyklonfamiljer": "cyklonfamilj",
    "cyklonfamiljerna": "cyklonfamilj",
    "cyklonfamiljernas": "cyklonfamilj",
    "cyklonfamiljers": "cyklonfamilj",
    "cyklonfamiljs": "cyklonfamilj",
    "cyklons": "cyklon",
    "cyklopen": "cyklop",
    "cyklopens": "cyklop",
    "cykloper": "cyklop",
    "cykloperna": "cyklop",
    "cyklopernas": "cyklop",
    "cyklopers": "cyklop",
    "cyklopet": "cyklop",
    "cyklopets": "cyklop",
    "cyklops": "cyklop",
    "cyklopögas": "cyklopöga",
    "cyklopögat": "cyklopöga",
    "cyklopögats": "cyklopöga",
    "cyklopögon": "cyklopöga",
    "cyklopögonen": "cyklopöga",
    "cyklopögonens": "cyklopöga",
    "cyklopögons": "cyklopöga",
    "cyklotronen": "cyklotron",
    "cyklotronens": "cyklotron",
    "cyklotroner": "cyklotron",
    "cyklotronerna": "cyklotron",
    "cyklotronernas": "cyklotron",
    "cyklotroners": "cyklotron",
    "cyklotrons": "cyklotron",
    "cyklotyma": "cyklotym",
    "cyklotymare": "cyklotym",
    "cyklotymares": "cyklotym",
    "cyklotymas": "cyklotym",
    "cyklotymast": "cyklotym",
    "cyklotymaste": "cyklotym",
    "cyklotymastes": "cyklotym",
    "cyklotymasts": "cyklotym",
    "cyklotyme": "cyklotym",
    "cyklotymes": "cyklotym",
    "cyklotyms": "cyklotym",
    "cyklotymt": "cyklotym",
    "cyklotymts": "cyklotym",
    "cylinderblocken": "cylinderblock",
    "cylinderblockens": "cylinderblock",
    "cylinderblocket": "cylinderblock",
    "cylinderblockets": "cylinderblock",
    "cylinderblocks": "cylinderblock",
    "cylinderformade": "cylinderformad",
    "cylinderformades": "cylinderformad",
    "cylinderformads": "cylinderformad",
    "cylinderformat": "cylinderformad",
    "cylinderformats": "cylinderformad",
    "cylinderglaset": "cylinderglas",
    "cylinderglasets": "cylinderglas",
    "cylinderhattar": "cylinderhatt",
    "cylinderhattarna": "cylinderhatt",
    "cylinderhattarnas": "cylinderhatt",
    "cylinderhattars": "cylinderhatt",
    "cylinderhatten": "cylinderhatt",
    "cylinderhattens": "cylinderhatt",
    "cylinderhatts": "cylinderhatt",
    "cylinderlåsen": "cylinderlås",
    "cylinderlåsens": "cylinderlås",
    "cylinderlåset": "cylinderlås",
    "cylinderlåsets": "cylinderlås",
    "cylindern": "cylinder",
    "cylinderns": "cylinder",
    "cylinderpressar": "cylinderpress",
    "cylinderpressarna": "cylinderpress",
    "cylinderpressarnas": "cylinderpress",
    "cylinderpressars": "cylinderpress",
    "cylinderpressen": "cylinderpress",
    "cylinderpressens": "cylinderpress",
    "cylinders": "cylinder",
    "cylindrar": "cylinder",
    "cylindrarna": "cylinder",
    "cylindrarnas": "cylinder",
    "cylindrars": "cylinder",
    "cylindriga": "cylindrig",
    "cylindrigare": "cylindrig",
    "cylindrigares": "cylindrig",
    "cylindrigas": "cylindrig",
    "cylindrigast": "cylindrig",
    "cylindrigaste": "cylindrig",
    "cylindrigastes": "cylindrig",
    "cylindrigasts": "cylindrig",
    "cylindrige": "cylindrig",
    "cylindriges": "cylindrig",
    "cylindrigs": "cylindrig",
    "cylindrigt": "cylindrig",
    "cylindrigts": "cylindrig",
    "cylindriska": "cylindrisk",
    "cylindriskare": "cylindrisk",
    "cylindriskares": "cylindrisk",
    "cylindriskas": "cylindrisk",
    "cylindriskast": "cylindrisk",
    "cylindriskaste": "cylindrisk",
    "cylindriskastes": "cylindrisk",
    "cylindriskasts": "cylindrisk",
    "cylindriske": "cylindrisk",
    "cylindriskes": "cylindrisk",
    "cylindrisks": "cylindrisk",
    "cylindriskt": "cylindrisk",
    "cylindriskts": "cylindrisk",
    "cymbalen": "cymbal",
    "cymbalens": "cymbal",
    "cymbaler": "cymbal",
    "cymbalerna": "cymbal",
    "cymbalernas": "cymbal",
    "cymbalers": "cymbal",
    "cymbals": "cymbal",
    "cynikern": "cyniker",
    "cynikerna": "cyniker",
    "cynikernas": "cyniker",
    "cynikerns": "cyniker",
    "cynikers": "cyniker",
    "cyniska": "cynisk",
    "cyniskare": "cynisk",
    "cyniskares": "cynisk",
    "cyniskas": "cynisk",
    "cyniskast": "cynisk",
    "cyniskaste": "cynisk",
    "cyniskastes": "cynisk",
    "cyniskasts": "cynisk",
    "cyniske": "cynisk",
    "cyniskes": "cynisk",
    "cynisks": "cynisk",
    "cyniskt": "cynisk",
    "cyniskts": "cynisk",
    "cynismen": "cynism",
    "cynismens": "cynism",
    "cynismer": "cynism",
    "cynismerna": "cynism",
    "cynismernas": "cynism",
    "cynismers": "cynism",
    "cynisms": "cynism",
    "cypressen": "cypress",
    "cypressens": "cypress",
    "cypresser": "cypress",
    "cypresserna": "cypress",
    "cypressernas": "cypress",
    "cypressers": "cypress",
    "cyprioten": "cypriot",
    "cypriotens": "cypriot",
    "cyprioter": "cypriot",
    "cyprioterna": "cypriot",
    "cyprioternas": "cypriot",
    "cyprioters": "cypriot",
    "cypriotiska": "cypriotisk",
    "cypriotiskan": "cypriotiska",
    "cypriotiskans": "cypriotiska",
    "cypriotiskare": "cypriotisk",
    "cypriotiskares": "cypriotisk",
    "cypriotiskas": "cypriotiska",
    "cypriotiskast": "cypriotisk",
    "cypriotiskaste": "cypriotisk",
    "cypriotiskastes": "cypriotisk",
    "cypriotiskasts": "cypriotisk",
    "cypriotiske": "cypriotiska",
    "cypriotiskes": "cypriotisk",
    "cypriotiskor": "cypriotiska",
    "cypriotiskorna": "cypriotiska",
    "cypriotiskornas": "cypriotiska",
    "cypriotiskors": "cypriotiska",
    "cypriotisks": "cypriotisk",
    "cypriotiskt": "cypriotisk",
    "cypriotiskts": "cypriotisk",
    "cypriots": "cypriot",
    "cyst": "cysta",
    "cystan": "cysta",
    "cystans": "cysta",
    "cystas": "cysta",
    "cyste": "cysta",
    "cystor": "cysta",
    "cystorna": "cysta",
    "cystornas": "cysta",
    "cystors": "cysta",
    "cystoskopen": "cystoskop",
    "cystoskopens": "cystoskop",
    "cystoskopet": "cystoskop",
    "cystoskopets": "cystoskop",
    "cystoskopien": "cystoskopi",
    "cystoskopiens": "cystoskopi",
    "cystoskopier": "cystoskopi",
    "cystoskopierna": "cystoskopi",
    "cystoskopiernas": "cystoskopi",
    "cystoskopiers": "cystoskopi",
    "cystoskopin": "cystoskopi",
    "cystoskopins": "cystoskopi",
    "cystoskopis": "cystoskopi",
    "cystoskops": "cystoskop",
    "cytologien": "cytologi",
    "cytologiens": "cytologi",
    "cytologin": "cytologi",
    "cytologins": "cytologi",
    "cytologis": "cytologi",
    "cytologiska": "cytologisk",
    "cytologiskare": "cytologisk",
    "cytologiskares": "cytologisk",
    "cytologiskas": "cytologisk",
    "cytologiskast": "cytologisk",
    "cytologiskaste": "cytologisk",
    "cytologiskastes": "cytologisk",
    "cytologiskasts": "cytologisk",
    "cytologiske": "cytologisk",
    "cytologiskes": "cytologisk",
    "cytologisks": "cytologisk",
    "cytologiskt": "cytologisk",
    "cytologiskts": "cytologisk",
    "cytoplasman": "cytoplasma",
    "cytoplasmans": "cytoplasma",
    "cytoplasmas": "cytoplasma",
    "cytoplasmat": "cytoplasma",
    "cytoplasmats": "cytoplasma",
    "d-et": "d",
    "d-ets": "d",
    "d-n": "d",
    "d-na": "d",
    "d-nas": "d",
    "d-ns": "d",
    "d-s": "d",
    "d-t": "d",
    "d-ts": "d",
    "d:et": "d",
    "d:ets": "d",
    "d:n": "d",
    "d:na": "d",
    "d:nas": "d",
    "d:ns": "d",
    "d:s": "d",
    "d:t": "d",
    "d:ts": "d",
    "dadaismen": "dadaism",
    "dadaismens": "dadaism",
    "dadaismer": "dadaism",
    "dadaismerna": "dadaism",
    "dadaismernas": "dadaism",
    "dadaismers": "dadaism",
    "dadaisms": "dadaism",
    "dadaisten": "dadaist",
    "dadaistens": "dadaist",
    "dadaister": "dadaist",
    "dadaisterna": "dadaist",
    "dadaisternas": "dadaist",
    "dadaisters": "dadaist",
    "dadaistiska": "dadaistisk",
    "dadaistiskare": "dadaistisk",
    "dadaistiskares": "dadaistisk",
    "dadaistiskas": "dadaistisk",
    "dadaistiskast": "dadaistisk",
    "dadaistiskaste": "dadaistisk",
    "dadaistiskastes": "dadaistisk",
    "dadaistiskasts": "dadaistisk",
    "dadaistiske": "dadaistisk",
    "dadaistiskes": "dadaistisk",
    "dadaistisks": "dadaistisk",
    "dadaistiskt": "dadaistisk",
    "dadaistiskts": "dadaistisk",
    "dadaists": "dadaist",
    "dadd": "dadda",
    "daddad": "dadda",
    "daddade": "dadda",
    "daddades": "dadda",
    "daddads": "dadda",
    "daddan": "dadda",
    "daddande": "dadda",
    "daddanden": "daddande",
    "daddandena": "daddande",
    "daddandenas": "daddande",
    "daddandens": "daddande",
    "daddandes": "daddande",
    "daddandet": "daddande",
    "daddandets": "daddande",
    "daddans": "dadda",
    "daddar": "dadda",
    "daddas": "dadda",
    "daddat": "dadda",
    "daddats": "dadda",
    "dadde": "dadda",
    "daddor": "dadda",
    "daddorna": "dadda",
    "daddornas": "dadda",
    "daddors": "dadda",
    "dadds": "dadda",
    "dadeln": "dadel",
    "dadelns": "dadel",
    "dadelpalmen": "dadelpalm",
    "dadelpalmens": "dadelpalm",
    "dadelpalmer": "dadelpalm",
    "dadelpalmerna": "dadelpalm",
    "dadelpalmernas": "dadelpalm",
    "dadelpalmers": "dadelpalm",
    "dadelpalms": "dadelpalm",
    "dadels": "dadel",
    "dadlar": "dadel",
    "dadlarna": "dadel",
    "dadlarnas": "dadel",
    "dadlars": "dadel",
    "dagades": "dagas",
    "dagakarlar": "dagakarl",
    "dagakarlarna": "dagakarl",
    "dagakarlarnas": "dagakarl",
    "dagakarlars": "dagakarl",
    "dagakarlen": "dagakarl",
    "dagakarlens": "dagakarl",
    "dagakarls": "dagakarl",
    "dagaktiva": "dagaktiv",
    "dagaktivare": "dagaktiv",
    "dagaktivares": "dagaktiv",
    "dagaktivas": "dagaktiv",
    "dagaktivast": "dagaktiv",
    "dagaktivaste": "dagaktiv",
    "dagaktivastes": "dagaktiv",
    "dagaktivasts": "dagaktiv",
    "dagaktive": "dagaktiv",
    "dagaktives": "dagaktiv",
    "dagaktivs": "dagaktiv",
    "dagaktivt": "dagaktiv",
    "dagaktivts": "dagaktiv",
    "dagar": "dag",
    "dagarna": "dag",
    "dagarnas": "dag",
    "dagars": "dag",
    "dagats": "dagas",
    "dagavdelningar": "dagavdelning",
    "dagavdelningarna": "dagavdelning",
    "dagavdelningarnas": "dagavdelning",
    "dagavdelningars": "dagavdelning",
    "dagavdelningen": "dagavdelning",
    "dagavdelningens": "dagavdelning",
    "dagavdelnings": "dagavdelning",
    "dagbarnen": "dagbarn",
    "dagbarnens": "dagbarn",
    "dagbarnet": "dagbarn",
    "dagbarnets": "dagbarn",
    "dagbarns": "dagbarn",
    "dagbarnvårdar": "dagbarnvårdare",
    "dagbarnvårdaren": "dagbarnvårdare",
    "dagbarnvårdarens": "dagbarnvårdare",
    "dagbarnvårdares": "dagbarnvårdare",
    "dagbarnvårdarna": "dagbarnvårdare",
    "dagbarnvårdarnas": "dagbarnvårdare",
    "dagbefälen": "dagbefäl",
    "dagbefälens": "dagbefäl",
    "dagbefälet": "dagbefäl",
    "dagbefälets": "dagbefäl",
    "dagbefäls": "dagbefäl",
    "dagbladen": "dagblad",
    "dagbladens": "dagblad",
    "dagbladet": "dagblad",
    "dagbladets": "dagblad",
    "dagblads": "dagblad",
    "dagblinda": "dagblind",
    "dagblindare": "dagblind",
    "dagblindares": "dagblind",
    "dagblindas": "dagblind",
    "dagblindast": "dagblind",
    "dagblindaste": "dagblind",
    "dagblindastes": "dagblind",
    "dagblindasts": "dagblind",
    "dagblinde": "dagblind",
    "dagblindes": "dagblind",
    "dagblindheten": "dagblindhet",
    "dagblindhetens": "dagblindhet",
    "dagblindhets": "dagblindhet",
    "dagblinds": "dagblind",
    "dagblint": "dagblind",
    "dagblints": "dagblind",
    "dagboken": "dagbok",
    "dagbokens": "dagbok",
    "dagboks": "dagbok",
    "dagbrotten": "dagbrott",
    "dagbrottens": "dagbrott",
    "dagbrottet": "dagbrott",
    "dagbrottets": "dagbrott",
    "dagbrotts": "dagbrott",
    "dagbrytningar": "dagbrytning",
    "dagbrytningarna": "dagbrytning",
    "dagbrytningarnas": "dagbrytning",
    "dagbrytningars": "dagbrytning",
    "dagbrytningen": "dagbrytning",
    "dagbrytningens": "dagbrytning",
    "dagbrytnings": "dagbrytning",
    "dagbräckningar": "dagbräckning",
    "dagbräckningarna": "dagbräckning",
    "dagbräckningarnas": "dagbräckning",
    "dagbräckningars": "dagbräckning",
    "dagbräckningen": "dagbräckning",
    "dagbräckningens": "dagbräckning",
    "dagbräcknings": "dagbräckning",
    "dagböcker": "dagbok",
    "dagböckerna": "dagbok",
    "dagböckernas": "dagbok",
    "dagböckers": "dagbok",
    "dagcentra": "dagcentrum",
    "dagcentralen": "dagcentral",
    "dagcentralens": "dagcentral",
    "dagcentraler": "dagcentral",
    "dagcentralerna": "dagcentral",
    "dagcentralernas": "dagcentral",
    "dagcentralers": "dagcentral",
    "dagcentrals": "dagcentral",
    "dagcentrana": "dagcentrum",
    "dagcentranas": "dagcentrum",
    "dagcentras": "dagcentrum",
    "dagcentrer": "dagcentrum",
    "dagcentrerna": "dagcentrum",
    "dagcentrernas": "dagcentrum",
    "dagcentrers": "dagcentrum",
    "dagcentret": "dagcentrum",
    "dagcentrets": "dagcentrum",
    "dagcentrumen": "dagcentrum",
    "dagcentrumens": "dagcentrum",
    "dagcentrumet": "dagcentrum",
    "dagcentrumets": "dagcentrum",
    "dagcentrums": "dagcentrum",
    "dagdjuren": "dagdjur",
    "dagdjurens": "dagdjur",
    "dagdjuret": "dagdjur",
    "dagdjurets": "dagdjur",
    "dagdjurs": "dagdjur",
    "dagdrivar": "dagdrivare",
    "dagdrivaren": "dagdrivare",
    "dagdrivarens": "dagdrivare",
    "dagdrivares": "dagdrivare",
    "dagdrivarlivet": "dagdrivarliv",
    "dagdrivarlivets": "dagdrivarliv",
    "dagdrivarlivs": "dagdrivarliv",
    "dagdrivarna": "dagdrivare",
    "dagdrivarnas": "dagdrivare",
    "dagdriveriet": "dagdriveri",
    "dagdriveriets": "dagdriveri",
    "dagdriveris": "dagdriveri",
    "dagdriverit": "dagdriveri",
    "dagdriverits": "dagdriveri",
    "dagdröm": "dagdrömma",
    "dagdrömde": "dagdrömma",
    "dagdrömmande": "dagdrömma",
    "dagdrömmanden": "dagdrömmande",
    "dagdrömmandena": "dagdrömmande",
    "dagdrömmandenas": "dagdrömmande",
    "dagdrömmandens": "dagdrömmande",
    "dagdrömmandes": "dagdrömmande",
    "dagdrömmandet": "dagdrömmande",
    "dagdrömmandets": "dagdrömmande",
    "dagdrömmar": "dagdrömmare",
    "dagdrömmaren": "dagdrömmare",
    "dagdrömmarens": "dagdrömmare",
    "dagdrömmares": "dagdrömmare",
    "dagdrömmarna": "dagdrömmare",
    "dagdrömmarnas": "dagdrömmare",
    "dagdrömmars": "dagdröm",
    "dagdrömmen": "dagdröm",
    "dagdrömmens": "dagdröm",
    "dagdrömmer": "dagdrömma",
    "dagdrömmerier": "dagdrömmeri",
    "dagdrömmerierna": "dagdrömmeri",
    "dagdrömmeriernas": "dagdrömmeri",
    "dagdrömmeriers": "dagdrömmeri",
    "dagdrömmeriet": "dagdrömmeri",
    "dagdrömmeriets": "dagdrömmeri",
    "dagdrömmeris": "dagdrömmeri",
    "dagdrömmerit": "dagdrömmeri",
    "dagdrömmerits": "dagdrömmeri",
    "dagdröms": "dagdröm",
    "dagdrömt": "dagdrömma",
    "dagen": "dag",
    "dagenefterhuvudvärken": "dagenefterhuvudvärk",
    "dagenefterhuvudvärkens": "dagenefterhuvudvärk",
    "dagenefterhuvudvärks": "dagenefterhuvudvärk",
    "dagenefterpillers": "dagenefterpiller",
    "dagenefterpillren": "dagenefterpiller",
    "dagenefterpillrens": "dagenefterpiller",
    "dagenefterpillret": "dagenefterpiller",
    "dagenefterpillrets": "dagenefterpiller",
    "dagenefterstämningar": "dagenefterstämning",
    "dagenefterstämningarna": "dagenefterstämning",
    "dagenefterstämningarnas": "dagenefterstämning",
    "dagenefterstämningars": "dagenefterstämning",
    "dagenefterstämningen": "dagenefterstämning",
    "dagenefterstämningens": "dagenefterstämning",
    "dagenefterstämnings": "dagenefterstämning",
    "dagens": "dag",
    "dagern": "dager",
    "dagerns": "dager",
    "dagerrotypen": "dagerrotyp",
    "dagerrotypens": "dagerrotyp",
    "dagerrotyper": "dagerrotyp",
    "dagerrotyperna": "dagerrotyp",
    "dagerrotypernas": "dagerrotyp",
    "dagerrotypers": "dagerrotyp",
    "dagerrotypien": "dagerrotypi",
    "dagerrotypiens": "dagerrotypi",
    "dagerrotypier": "dagerrotypi",
    "dagerrotypierna": "dagerrotypi",
    "dagerrotypiernas": "dagerrotypi",
    "dagerrotypiers": "dagerrotypi",
    "dagerrotypin": "dagerrotypi",
    "dagerrotypins": "dagerrotypi",
    "dagerrotypis": "dagerrotypi",
    "dagerrotyps": "dagerrotyp",
    "dagers": "dager",
    "dagfjärilar": "dagfjäril",
    "dagfjärilarna": "dagfjäril",
    "dagfjärilarnas": "dagfjäril",
    "dagfjärilars": "dagfjäril",
    "dagfjärilen": "dagfjäril",
    "dagfjärilens": "dagfjäril",
    "dagfjäriln": "dagfjäril",
    "dagfjärilns": "dagfjäril",
    "dagfjärils": "dagfjäril",
    "dagg": "dagga",
    "daggade": "dagga",
    "daggades": "dagga",
    "daggande": "dagga",
    "dagganden": "daggande",
    "daggandena": "daggande",
    "daggandenas": "daggande",
    "daggandens": "daggande",
    "daggandes": "daggande",
    "daggandet": "daggande",
    "daggandets": "daggande",
    "daggar": "dagga",
    "daggarna": "dagg",
    "daggarnas": "dagg",
    "daggars": "dagg",
    "daggas": "dagga",
    "daggat": "dagga",
    "daggats": "dagga",
    "daggdropp": "daggdroppe",
    "daggdroppar": "daggdroppe",
    "daggdropparna": "daggdroppe",
    "daggdropparnas": "daggdroppe",
    "daggdroppars": "daggdroppe",
    "daggdroppen": "daggdroppe",
    "daggdroppens": "daggdroppe",
    "daggdroppes": "daggdroppe",
    "daggdropps": "daggdroppe",
    "daggen": "dagg",
    "daggens": "dagg",
    "daggertar": "daggert",
    "daggertarna": "daggert",
    "daggertarnas": "daggert",
    "daggertars": "daggert",
    "daggerten": "daggert",
    "daggertens": "daggert",
    "daggerts": "daggert",
    "daggfriska": "daggfrisk",
    "daggfriskare": "daggfrisk",
    "daggfriskares": "daggfrisk",
    "daggfriskas": "daggfrisk",
    "daggfriskast": "daggfrisk",
    "daggfriskaste": "daggfrisk",
    "daggfriskastes": "daggfrisk",
    "daggfriskasts": "daggfrisk",
    "daggfriske": "daggfrisk",
    "daggfriskes": "daggfrisk",
    "daggfrisks": "daggfrisk",
    "daggfriskt": "daggfrisk",
    "daggfriskts": "daggfrisk",
    "daggiga": "daggig",
    "daggigare": "daggig",
    "daggigares": "daggig",
    "daggigas": "daggig",
    "daggigast": "daggig",
    "daggigaste": "daggig",
    "daggigastes": "daggig",
    "daggigasts": "daggig",
    "daggige": "daggig",
    "daggiges": "daggig",
    "daggigheten": "daggighet",
    "daggighetens": "daggighet",
    "daggighets": "daggighet",
    "daggigs": "daggig",
    "daggigt": "daggig",
    "daggigts": "daggig",
    "daggkåp": "daggkåpa",
    "daggkåpan": "daggkåpa",
    "daggkåpans": "daggkåpa",
    "daggkåpas": "daggkåpa",
    "daggkåpe": "daggkåpa",
    "daggkåpor": "daggkåpa",
    "daggkåporna": "daggkåpa",
    "daggkåpornas": "daggkåpa",
    "daggkåpors": "daggkåpa",
    "daggkåps": "daggkåpa",
    "daggmaskar": "daggmask",
    "daggmaskarna": "daggmask",
    "daggmaskarnas": "daggmask",
    "daggmaskars": "daggmask",
    "daggmasken": "daggmask",
    "daggmaskens": "daggmask",
    "daggmasks": "daggmask",
    "daggpunkten": "daggpunkt",
    "daggpunktens": "daggpunkt",
    "daggpunkter": "daggpunkt",
    "daggpunkterna": "daggpunkt",
    "daggpunkternas": "daggpunkt",
    "daggpunkters": "daggpunkt",
    "daggpunkts": "daggpunkt",
    "daggs": "dagg",
    "daggvåta": "daggvåt",
    "daggvåtare": "daggvåt",
    "daggvåtares": "daggvåt",
    "daggvåtas": "daggvåt",
    "daggvåtast": "daggvåt",
    "daggvåtaste": "daggvåt",
    "daggvåtastes": "daggvåt",
    "daggvåtasts": "daggvåt",
    "daggvåte": "daggvåt",
    "daggvåtes": "daggvåt",
    "daggvåts": "daggvåt",
    "daggvått": "daggvåt",
    "daggvåtts": "daggvåt",
    "daghavanden": "daghavande",
    "daghavandena": "daghavande",
    "daghavandenas": "daghavande",
    "daghavandens": "daghavande",
    "daghavandes": "daghavande",
    "daghemmen": "daghem",
    "daghemmens": "daghem",
    "daghemmet": "daghem",
    "daghemmets": "daghem",
    "daghems": "daghem",
    "daghemsföreståndar": "daghemsföreståndare",
    "daghemsföreståndaren": "daghemsföreståndare",
    "daghemsföreståndarens": "daghemsföreståndare",
    "daghemsföreståndares": "daghemsföreståndare",
    "daghemsföreståndarna": "daghemsföreståndare",
    "daghemsföreståndarnas": "daghemsföreståndare",
    "dagisen": "dagis",
    "dagisens": "dagis",
    "dagiset": "dagis",
    "dagisets": "dagis",
    "dagisfrökens": "dagisfröken",
    "dagisfröknar": "dagisfröken",
    "dagisfröknarna": "dagisfröken",
    "dagisfröknarnas": "dagisfröken",
    "dagisfröknars": "dagisfröken",
    "dagisfröknen": "dagisfröken",
    "dagisfröknens": "dagisfröken",
    "dagjämningar": "dagjämning",
    "dagjämningarna": "dagjämning",
    "dagjämningarnas": "dagjämning",
    "dagjämningars": "dagjämning",
    "dagjämningen": "dagjämning",
    "dagjämningens": "dagjämning",
    "dagjämnings": "dagjämning",
    "dagjämningspunkten": "dagjämningspunkt",
    "dagjämningspunktens": "dagjämningspunkt",
    "dagjämningspunkts": "dagjämningspunkt",
    "dagkarlar": "dagkarl",
    "dagkarlarna": "dagkarl",
    "dagkarlarnas": "dagkarl",
    "dagkarlars": "dagkarl",
    "dagkarlen": "dagkarl",
    "dagkarlens": "dagkarl",
    "dagkarls": "dagkarl",
    "dagleg": "daglega",
    "daglegan": "daglega",
    "daglegans": "daglega",
    "daglegas": "daglega",
    "daglege": "daglega",
    "daglegor": "daglega",
    "daglegorna": "daglega",
    "daglegornas": "daglega",
    "daglegors": "daglega",
    "daglegs": "daglega",
    "dagliga": "daglig",
    "dagligare": "daglig",
    "dagligares": "daglig",
    "dagligas": "daglig",
    "dagligast": "daglig",
    "dagligaste": "daglig",
    "dagligastes": "daglig",
    "dagligasts": "daglig",
    "daglige": "daglig",
    "dagliges": "daglig",
    "dagligheten": "daglighet",
    "daglighetens": "daglighet",
    "daglighets": "daglighet",
    "dagligs": "daglig",
    "dagligstugan": "dagligstuga",
    "dagligstugans": "dagligstuga",
    "dagligstugas": "dagligstuga",
    "dagligstuge": "dagligstuga",
    "dagligstugor": "dagligstuga",
    "dagligstugorna": "dagligstuga",
    "dagligstugornas": "dagligstuga",
    "dagligstugors": "dagligstuga",
    "dagligstugu": "dagligstuga",
    "dagligt": "daglig",
    "dagligts": "daglig",
    "dagligvar": "dagligvara",
    "dagligvaran": "dagligvara",
    "dagligvarans": "dagligvara",
    "dagligvaras": "dagligvara",
    "dagligvare": "dagligvara",
    "dagligvaror": "dagligvara",
    "dagligvarorna": "dagligvara",
    "dagligvarornas": "dagligvara",
    "dagligvarors": "dagligvara",
    "dagligvars": "dagligvara",
    "daglönar": "daglönare",
    "daglönaren": "daglönare",
    "daglönarens": "daglönare",
    "daglönares": "daglönare",
    "daglönarna": "daglönare",
    "daglönarnas": "daglönare",
    "daglönen": "daglön",
    "daglönens": "daglön",
    "daglöner": "daglön",
    "daglönerna": "daglön",
    "daglönernas": "daglön",
    "daglöners": "daglön",
    "daglöns": "daglön",
    "dagmamman": "dagmamma",
    "dagmammans": "dagmamma",
    "dagmammas": "dagmamma",
    "dagmamme": "dagmamma",
    "dagmammor": "dagmamma",
    "dagmammorna": "dagmamma",
    "dagmammornas": "dagmamma",
    "dagmammors": "dagmamma",
    "dagningar": "dagning",
    "dagningarna": "dagning",
    "dagningarnas": "dagning",
    "dagningars": "dagning",
    "dagningen": "dagning",
    "dagningens": "dagning",
    "dagnings": "dagning",
    "dagofficerare": "dagofficer",
    "dagofficerares": "dagofficer",
    "dagofficerarna": "dagofficer",
    "dagofficerarnas": "dagofficer",
    "dagofficeren": "dagofficer",
    "dagofficerens": "dagofficer",
    "dagofficern": "dagofficer",
    "dagofficerns": "dagofficer",
    "dagofficers": "dagofficer",
    "dagon": "dago",
    "dagons": "dago",
    "dagordern": "dagorder",
    "dagorderna": "dagorder",
    "dagordernas": "dagorder",
    "dagorderns": "dagorder",
    "dagorders": "dagorder",
    "dagordningar": "dagordning",
    "dagordningarna": "dagordning",
    "dagordningarnas": "dagordning",
    "dagordningars": "dagordning",
    "dagordningen": "dagordning",
    "dagordningens": "dagordning",
    "dagordnings": "dagordning",
    "dagordrar": "dagorder",
    "dagordrarna": "dagorder",
    "dagordrarnas": "dagorder",
    "dagordrars": "dagorder",
    "dagorten": "dagort",
    "dagortens": "dagort",
    "dagorter": "dagort",
    "dagorterna": "dagort",
    "dagorternas": "dagort",
    "dagorters": "dagort",
    "dagorts": "dagort",
    "dagos": "dago",
    "dagosarna": "dago",
    "dagosarnas": "dago",
    "dagosen": "dago",
    "dagosens": "dago",
    "dagpenningar": "dagpenning",
    "dagpenningarna": "dagpenning",
    "dagpenningarnas": "dagpenning",
    "dagpenningars": "dagpenning",
    "dagpenningen": "dagpenning",
    "dagpenningens": "dagpenning",
    "dagpennings": "dagpenning",
    "dagrar": "dager",
    "dagrarna": "dager",
    "dagrarnas": "dager",
    "dagrars": "dager",
    "dagrummen": "dagrum",
    "dagrummens": "dagrum",
    "dagrummet": "dagrum",
    "dagrummets": "dagrum",
    "dagrums": "dagrum",
    "dagsaktuella": "dagsaktuell",
    "dagsaktuellare": "dagsaktuell",
    "dagsaktuellares": "dagsaktuell",
    "dagsaktuellas": "dagsaktuell",
    "dagsaktuellast": "dagsaktuell",
    "dagsaktuellaste": "dagsaktuell",
    "dagsaktuellastes": "dagsaktuell",
    "dagsaktuellasts": "dagsaktuell",
    "dagsaktuelle": "dagsaktuell",
    "dagsaktuelles": "dagsaktuell",
    "dagsaktuells": "dagsaktuell",
    "dagsaktuellt": "dagsaktuell",
    "dagsaktuellts": "dagsaktuell",
    "dagsbehoven": "dagsbehov",
    "dagsbehovens": "dagsbehov",
    "dagsbehovet": "dagsbehov",
    "dagsbehovets": "dagsbehov",
    "dagsbehovs": "dagsbehov",
    "dagsboten": "dagsbot",
    "dagsbotens": "dagsbot",
    "dagsbots": "dagsbot",
    "dagsböter": "dagsbot",
    "dagsböterna": "dagsbot",
    "dagsböternas": "dagsbot",
    "dagsböters": "dagsbot",
    "dagsedeln": "dagsedel",
    "dagsedelns": "dagsedel",
    "dagsedels": "dagsedel",
    "dagsedlar": "dagsedel",
    "dagsedlarna": "dagsedel",
    "dagsedlarnas": "dagsedel",
    "dagsedlars": "dagsedel",
    "dagskassan": "dagskassa",
    "dagskassans": "dagskassa",
    "dagskassas": "dagskassa",
    "dagskasse": "dagskassa",
    "dagskassor": "dagskassa",
    "dagskassorna": "dagskassa",
    "dagskassornas": "dagskassa",
    "dagskassors": "dagskassa",
    "dagskryssningar": "dagskryssning",
    "dagskryssningarna": "dagskryssning",
    "dagskryssningarnas": "dagskryssning",
    "dagskryssningars": "dagskryssning",
    "dagskryssningen": "dagskryssning",
    "dagskryssningens": "dagskryssning",
    "dagskryssnings": "dagskryssning",
    "dagsleden": "dagsled",
    "dagsledens": "dagsled",
    "dagsleder": "dagsled",
    "dagslederna": "dagsled",
    "dagsledernas": "dagsled",
    "dagsleders": "dagsled",
    "dagsleds": "dagsled",
    "dagsljuset": "dagsljus",
    "dagsljusets": "dagsljus",
    "dagsläges": "dagsläge",
    "dagsläget": "dagsläge",
    "dagslägets": "dagsläge",
    "dagsländ": "dagslända",
    "dagsländan": "dagslända",
    "dagsländans": "dagslända",
    "dagsländas": "dagslända",
    "dagslände": "dagslända",
    "dagsländelivet": "dagsländeliv",
    "dagsländelivets": "dagsländeliv",
    "dagsländelivs": "dagsländeliv",
    "dagsländor": "dagslända",
    "dagsländorna": "dagslända",
    "dagsländornas": "dagslända",
    "dagsländors": "dagslända",
    "dagsländs": "dagslända",
    "dagslånga": "dagslång",
    "dagslångas": "dagslång",
    "dagslånge": "dagslång",
    "dagslånges": "dagslång",
    "dagslångs": "dagslång",
    "dagslångt": "dagslång",
    "dagslångts": "dagslång",
    "dagsmarschen": "dagsmarsch",
    "dagsmarschens": "dagsmarsch",
    "dagsmarscher": "dagsmarsch",
    "dagsmarscherna": "dagsmarsch",
    "dagsmarschernas": "dagsmarsch",
    "dagsmarschers": "dagsmarsch",
    "dagsmarschs": "dagsmarsch",
    "dagsmejan": "dagsmeja",
    "dagsmejans": "dagsmeja",
    "dagsmejas": "dagsmeja",
    "dagsnyheten": "dagsnyhet",
    "dagsnyhetens": "dagsnyhet",
    "dagsnyheter": "dagsnyhet",
    "dagsnyheterna": "dagsnyheter",
    "dagsnyheternas": "dagsnyheter",
    "dagsnyheters": "dagsnyheter",
    "dagsnyhets": "dagsnyheter",
    "dagspolitiska": "dagspolitisk",
    "dagspolitiskare": "dagspolitisk",
    "dagspolitiskares": "dagspolitisk",
    "dagspolitiskas": "dagspolitisk",
    "dagspolitiskast": "dagspolitisk",
    "dagspolitiskaste": "dagspolitisk",
    "dagspolitiskastes": "dagspolitisk",
    "dagspolitiskasts": "dagspolitisk",
    "dagspolitiske": "dagspolitisk",
    "dagspolitiskes": "dagspolitisk",
    "dagspolitisks": "dagspolitisk",
    "dagspolitiskt": "dagspolitisk",
    "dagspolitiskts": "dagspolitisk",
    "dagspressen": "dagspress",
    "dagspressens": "dagspress",
    "dagsprogrammen": "dagsprogram",
    "dagsprogrammens": "dagsprogram",
    "dagsprogrammet": "dagsprogram",
    "dagsprogrammets": "dagsprogram",
    "dagsprograms": "dagsprogram",
    "dagsransonen": "dagsranson",
    "dagsransonens": "dagsranson",
    "dagsransoner": "dagsranson",
    "dagsransonerna": "dagsranson",
    "dagsransonernas": "dagsranson",
    "dagsransoners": "dagsranson",
    "dagsransons": "dagsranson",
    "dagsresan": "dagsresa",
    "dagsresans": "dagsresa",
    "dagsresas": "dagsresa",
    "dagsrese": "dagsresa",
    "dagsresor": "dagsresa",
    "dagsresorna": "dagsresa",
    "dagsresornas": "dagsresa",
    "dagsresors": "dagsresa",
    "dagstemperaturen": "dagstemperatur",
    "dagstemperaturens": "dagstemperatur",
    "dagstemperaturer": "dagstemperatur",
    "dagstemperaturerna": "dagstemperatur",
    "dagstemperaturernas": "dagstemperatur",
    "dagstemperaturers": "dagstemperatur",
    "dagstemperaturs": "dagstemperatur",
    "dagstidningar": "dagstidning",
    "dagstidningarna": "dagstidning",
    "dagstidningarnas": "dagstidning",
    "dagstidningars": "dagstidning",
    "dagstidningen": "dagstidning",
    "dagstidningens": "dagstidning",
    "dagstidnings": "dagstidning",
    "dagstidningsredaktören": "dagstidningsredaktör",
    "dagstidningsredaktörens": "dagstidningsredaktör",
    "dagstidningsredaktörer": "dagstidningsredaktör",
    "dagstidningsredaktörerna": "dagstidningsredaktör",
    "dagstidningsredaktörernas": "dagstidningsredaktör",
    "dagstidningsredaktörers": "dagstidningsredaktör",
    "dagstidningsredaktörn": "dagstidningsredaktör",
    "dagstidningsredaktörns": "dagstidningsredaktör",
    "dagstidningsredaktörs": "dagstidningsredaktör",
    "dagsverkar": "dagsverkare",
    "dagsverkaren": "dagsverkare",
    "dagsverkarens": "dagsverkare",
    "dagsverkares": "dagsverkare",
    "dagsverkarna": "dagsverkare",
    "dagsverkarnas": "dagsverkare",
    "dagsverken": "dagsverke",
    "dagsverkena": "dagsverke",
    "dagsverkenas": "dagsverke",
    "dagsverkens": "dagsverke",
    "dagsverkes": "dagsverke",
    "dagsverket": "dagsverke",
    "dagsverkets": "dagsverke",
    "dagsverks": "dagsverke",
    "dagsversen": "dagsvers",
    "dagsversens": "dagsvers",
    "dagsverser": "dagsvers",
    "dagsverserna": "dagsvers",
    "dagsversernas": "dagsvers",
    "dagsversers": "dagsvers",
    "dagsversskribenten": "dagsversskribent",
    "dagsversskribentens": "dagsversskribent",
    "dagsversskribenter": "dagsversskribent",
    "dagsversskribenterna": "dagsversskribent",
    "dagsversskribenternas": "dagsversskribent",
    "dagsversskribenters": "dagsversskribent",
    "dagsversskribents": "dagsversskribent",
    "dagteckn": "dagteckna",
    "dagtecknad": "dagteckna",
    "dagtecknade": "dagteckna",
    "dagtecknades": "dagteckna",
    "dagtecknads": "dagteckna",
    "dagtecknande": "dagteckna",
    "dagtecknanden": "dagtecknande",
    "dagtecknandena": "dagtecknande",
    "dagtecknandenas": "dagtecknande",
    "dagtecknandens": "dagtecknande",
    "dagtecknandes": "dagtecknande",
    "dagtecknandet": "dagtecknande",
    "dagtecknandets": "dagtecknande",
    "dagtecknar": "dagteckna",
    "dagtecknas": "dagteckna",
    "dagtecknat": "dagteckna",
    "dagtecknats": "dagteckna",
    "dagtiden": "dagtid",
    "dagtidens": "dagtid",
    "dagtider": "dagtid",
    "dagtiderna": "dagtid",
    "dagtidernas": "dagtid",
    "dagtiders": "dagtid",
    "dagtids": "dagtid",
    "dagtingade": "dagtinga",
    "dagtingades": "dagtinga",
    "dagtingande": "dagtinga",
    "dagtinganden": "dagtingande",
    "dagtingandena": "dagtingande",
    "dagtingandenas": "dagtingande",
    "dagtingandens": "dagtingande",
    "dagtingandes": "dagtingande",
    "dagtingandet": "dagtingande",
    "dagtingandets": "dagtingande",
    "dagtingans": "dagtingan",
    "dagtingar": "dagtinga",
    "dagtingas": "dagtinga",
    "dagtingat": "dagtinga",
    "dagtingats": "dagtinga",
    "dagtraktamenten": "dagtraktamente",
    "dagtraktamentena": "dagtraktamente",
    "dagtraktamentenas": "dagtraktamente",
    "dagtraktamentens": "dagtraktamente",
    "dagtraktamentes": "dagtraktamente",
    "dagtraktamentet": "dagtraktamente",
    "dagtraktamentets": "dagtraktamente",
    "dagtågen": "dagtåg",
    "dagtågens": "dagtåg",
    "dagtåget": "dagtåg",
    "dagtågets": "dagtåg",
    "dagtågs": "dagtåg",
    "dagvattens": "dagvatten",
    "dagvattnen": "dagvatten",
    "dagvattnens": "dagvatten",
    "dagvattnet": "dagvatten",
    "dagvattnets": "dagvatten",
    "dagvilla": "dagvill",
    "dagvillare": "dagvill",
    "dagvillares": "dagvill",
    "dagvillas": "dagvill",
    "dagvillast": "dagvill",
    "dagvillaste": "dagvill",
    "dagvillastes": "dagvill",
    "dagvillasts": "dagvill",
    "dagville": "dagvill",
    "dagvilles": "dagvill",
    "dagvillheten": "dagvillhet",
    "dagvillhetens": "dagvillhet",
    "dagvillhets": "dagvillhet",
    "dagvills": "dagvill",
    "dagvården": "dagvård",
    "dagvårdens": "dagvård",
    "dagvårds": "dagvård",
    "dagöppningar": "dagöppning",
    "dagöppningarna": "dagöppning",
    "dagöppningarnas": "dagöppning",
    "dagöppningars": "dagöppning",
    "dagöppningen": "dagöppning",
    "dagöppningens": "dagöppning",
    "dagöppnings": "dagöppning",
    "dahli": "dahlia",
    "dahlian": "dahlia",
    "dahlians": "dahlia",
    "dahlias": "dahlia",
    "dahlie": "dahlia",
    "dahlior": "dahlia",
    "dahliorna": "dahlia",
    "dahliornas": "dahlia",
    "dahliors": "dahlia",
    "dahlis": "dahlia",
    "dakapon": "dakapo",
    "dakapona": "dakapo",
    "dakaponas": "dakapo",
    "dakapons": "dakapo",
    "dakapos": "dakapo",
    "dakapot": "dakapo",
    "dakapots": "dakapo",
    "daktylen": "daktyl",
    "daktylens": "daktyl",
    "daktyler": "daktyl",
    "daktylerna": "daktyl",
    "daktylernas": "daktyl",
    "daktylers": "daktyl",
    "daktyliska": "daktylisk",
    "daktyliskare": "daktylisk",
    "daktyliskares": "daktylisk",
    "daktyliskas": "daktylisk",
    "daktyliskast": "daktylisk",
    "daktyliskaste": "daktylisk",
    "daktyliskastes": "daktylisk",
    "daktyliskasts": "daktylisk",
    "daktyliske": "daktylisk",
    "daktyliskes": "daktylisk",
    "daktylisks": "daktylisk",
    "daktyliskt": "daktylisk",
    "daktyliskts": "daktylisk",
    "daktyls": "daktyl",
    "dalade": "dala",
    "dalades": "dala",
    "dalahästar": "dalahäst",
    "dalahästarna": "dalahäst",
    "dalahästarnas": "dalahäst",
    "dalahästars": "dalahäst",
    "dalahästen": "dalahäst",
    "dalahästens": "dalahäst",
    "dalahästs": "dalahäst",
    "dalamässiga": "dalamässig",
    "dalamässigare": "dalamässig",
    "dalamässigares": "dalamässig",
    "dalamässigas": "dalamässig",
    "dalamässigast": "dalamässig",
    "dalamässigaste": "dalamässig",
    "dalamässigastes": "dalamässig",
    "dalamässigasts": "dalamässig",
    "dalamässige": "dalamässig",
    "dalamässiges": "dalamässig",
    "dalamässigs": "dalamässig",
    "dalamässigt": "dalamässig",
    "dalamässigts": "dalamässig",
    "dalande": "dala",
    "dalanden": "dalande",
    "dalandena": "dalande",
    "dalandenas": "dalande",
    "dalandens": "dalande",
    "dalandes": "dalande",
    "dalandet": "dalande",
    "dalandets": "dalande",
    "dalar": "dala",
    "dalarna": "dal",
    "dalarnas": "dal",
    "dalars": "dal",
    "dalas": "dala",
    "dalat": "dala",
    "dalats": "dala",
    "dalbon": "dalbo",
    "dalbons": "dalbo",
    "dalbor": "dalbo",
    "dalborna": "dalbo",
    "dalbornas": "dalbo",
    "dalbors": "dalbo",
    "dalbos": "dalbo",
    "dalbottens": "dalbotten",
    "dalbottnar": "dalbotten",
    "dalbottnarna": "dalbotten",
    "dalbottnarnas": "dalbotten",
    "dalbottnars": "dalbotten",
    "dalbottnen": "dalbotten",
    "dalbottnens": "dalbotten",
    "daldansen": "daldans",
    "daldansens": "daldans",
    "daldanser": "daldans",
    "daldanserna": "daldans",
    "daldansernas": "daldans",
    "daldansers": "daldans",
    "dalen": "dal",
    "dalens": "dal",
    "dalern": "daler",
    "dalerna": "daler",
    "dalernas": "daler",
    "dalerns": "daler",
    "dalers": "daler",
    "dalgångar": "dalgång",
    "dalgångarna": "dalgång",
    "dalgångarnas": "dalgång",
    "dalgångars": "dalgång",
    "dalgången": "dalgång",
    "dalgångens": "dalgång",
    "dalgångs": "dalgång",
    "daljet": "dalj",
    "daljets": "dalj",
    "daljs": "dalj",
    "dalkarlar": "dalkarl",
    "dalkarlarna": "dalkarl",
    "dalkarlarnas": "dalkarl",
    "dalkarlars": "dalkarl",
    "dalkarlen": "dalkarl",
    "dalkarlens": "dalkarl",
    "dalkarls": "dalkarl",
    "dalkjus": "dalkjusa",
    "dalkjusan": "dalkjusa",
    "dalkjusans": "dalkjusa",
    "dalkjusas": "dalkjusa",
    "dalkjuse": "dalkjusa",
    "dalkjusor": "dalkjusa",
    "dalkjusorna": "dalkjusa",
    "dalkjusornas": "dalkjusa",
    "dalkjusors": "dalkjusa",
    "dalkull": "dalkulla",
    "dalkullan": "dalkulla",
    "dalkullans": "dalkulla",
    "dalkullas": "dalkulla",
    "dalkulle": "dalkulla",
    "dalkullor": "dalkulla",
    "dalkullorna": "dalkulla",
    "dalkullornas": "dalkulla",
    "dalkullors": "dalkulla",
    "dalkulls": "dalkulla",
    "daller": "dallra",
    "dallers": "daller",
    "dallrade": "dallra",
    "dallrades": "dallra",
    "dallrande": "dallra",
    "dallranden": "dallrande",
    "dallrandena": "dallrande",
    "dallrandenas": "dallrande",
    "dallrandens": "dallrande",
    "dallrandes": "dallrande",
    "dallrandet": "dallrande",
    "dallrandets": "dallrande",
    "dallrar": "dallra",
    "dallras": "dallra",
    "dallrat": "dallra",
    "dallrats": "dallra",
    "dallret": "daller",
    "dallrets": "daller",
    "dallringar": "dallring",
    "dallringarna": "dallring",
    "dallringarnas": "dallring",
    "dallringars": "dallring",
    "dallringen": "dallring",
    "dallringens": "dallring",
    "dallrings": "dallring",
    "dalmasar": "dalmas",
    "dalmasarna": "dalmas",
    "dalmasarnas": "dalmas",
    "dalmasars": "dalmas",
    "dalmasen": "dalmas",
    "dalmasens": "dalmas",
    "dalmatinern": "dalmatiner",
    "dalmatinerna": "dalmatiner",
    "dalmatinernas": "dalmatiner",
    "dalmatinerns": "dalmatiner",
    "dalmatiners": "dalmatiner",
    "dalmålen": "dalmål",
    "dalmålens": "dalmål",
    "dalmålet": "dalmål",
    "dalmålets": "dalmål",
    "dalmålningar": "dalmålning",
    "dalmålningarna": "dalmålning",
    "dalmålningarnas": "dalmålning",
    "dalmålningars": "dalmålning",
    "dalmålningen": "dalmålning",
    "dalmålningens": "dalmålning",
    "dalmålnings": "dalmålning",
    "dalmåls": "dalmål",
    "dalprofilen": "dalprofil",
    "dalprofilens": "dalprofil",
    "dalprofiler": "dalprofil",
    "dalprofilerna": "dalprofil",
    "dalprofilernas": "dalprofil",
    "dalprofilers": "dalprofil",
    "dalprofils": "dalprofil",
    "dalrip": "dalripa",
    "dalripan": "dalripa",
    "dalripans": "dalripa",
    "dalripas": "dalripa",
    "dalripe": "dalripa",
    "dalripor": "dalripa",
    "dalriporna": "dalripa",
    "dalripornas": "dalripa",
    "dalripors": "dalripa",
    "dalrips": "dalripa",
    "dals": "dal",
    "dalsk": "dalska",
    "dalska": "dalsk",
    "dalskan": "dalska",
    "dalskans": "dalska",
    "dalskare": "dalsk",
    "dalskares": "dalsk",
    "dalskas": "dalska",
    "dalskast": "dalsk",
    "dalskaste": "dalsk",
    "dalskastes": "dalsk",
    "dalskasts": "dalsk",
    "dalske": "dalsk",
    "dalskes": "dalsk",
    "dalskidan": "dalskida",
    "dalskidans": "dalskida",
    "dalskidas": "dalskida",
    "dalsks": "dalsk",
    "dalskt": "dalsk",
    "dalskts": "dalsk",
    "dalsluttningar": "dalsluttning",
    "dalsluttningarna": "dalsluttning",
    "dalsluttningarnas": "dalsluttning",
    "dalsluttningars": "dalsluttning",
    "dalsluttningen": "dalsluttning",
    "dalsluttningens": "dalsluttning",
    "dalsluttnings": "dalsluttning",
    "dalsländsk": "dalsländska",
    "dalsländska": "dalsländsk",
    "dalsländskan": "dalsländska",
    "dalsländskans": "dalsländska",
    "dalsländskare": "dalsländsk",
    "dalsländskares": "dalsländsk",
    "dalsländskas": "dalsländska",
    "dalsländskast": "dalsländsk",
    "dalsländskaste": "dalsländsk",
    "dalsländskastes": "dalsländsk",
    "dalsländskasts": "dalsländsk",
    "dalsländske": "dalsländska",
    "dalsländskes": "dalsländsk",
    "dalsländskor": "dalsländska",
    "dalsländskorna": "dalsländska",
    "dalsländskornas": "dalsländska",
    "dalsländskors": "dalsländska",
    "dalsländsks": "dalsländsk",
    "dalsländskt": "dalsländsk",
    "dalsländskts": "dalsländsk",
    "dalslänningar": "dalslänning",
    "dalslänningarna": "dalslänning",
    "dalslänningarnas": "dalslänning",
    "dalslänningars": "dalslänning",
    "dalslänningen": "dalslänning",
    "dalslänningens": "dalslänning",
    "dalslännings": "dalslänning",
    "dalsänk": "dalsänka",
    "dalsänkan": "dalsänka",
    "dalsänkans": "dalsänka",
    "dalsänkas": "dalsänka",
    "dalsänke": "dalsänka",
    "dalsänkor": "dalsänka",
    "dalsänkorna": "dalsänka",
    "dalsänkornas": "dalsänka",
    "dalsänkors": "dalsänka",
    "dalsänks": "dalsänka",
    "dalt": "dalta",
    "daltade": "dalta",
    "daltades": "dalta",
    "daltande": "dalta",
    "daltanden": "daltande",
    "daltandena": "daltande",
    "daltandenas": "daltande",
    "daltandens": "daltande",
    "daltandes": "daltande",
    "daltandet": "daltande",
    "daltandets": "daltande",
    "daltar": "dalta",
    "daltas": "dalta",
    "daltat": "dalta",
    "daltats": "dalta",
    "daltet": "dalt",
    "daltets": "dalt",
    "dalts": "dalt",
    "dalvindar": "dalvind",
    "dalvindarna": "dalvind",
    "dalvindarnas": "dalvind",
    "dalvindars": "dalvind",
    "dalvinden": "dalvind",
    "dalvindens": "dalvind",
    "dalvinds": "dalvind",
    "damasken": "damask",
    "damaskenerkling": "damaskenerklinga",
    "damaskenerklingan": "damaskenerklinga",
    "damaskenerklingans": "damaskenerklinga",
    "damaskenerklingas": "damaskenerklinga",
    "damaskenerklinge": "damaskenerklinga",
    "damaskenerklingor": "damaskenerklinga",
    "damaskenerklingorna": "damaskenerklinga",
    "damaskenerklingornas": "damaskenerklinga",
    "damaskenerklingors": "damaskenerklinga",
    "damaskenerklings": "damaskenerklinga",
    "damaskenerstålet": "damaskenerstål",
    "damaskenerstålets": "damaskenerstål",
    "damaskenerståls": "damaskenerstål",
    "damaskens": "damask",
    "damasker": "damask",
    "damaskerna": "damask",
    "damaskernas": "damask",
    "damaskers": "damask",
    "damasks": "damask",
    "damasten": "damast",
    "damastens": "damast",
    "damaster": "damast",
    "damasterna": "damast",
    "damasternas": "damast",
    "damasters": "damast",
    "damasts": "damast",
    "damastservetten": "damastservett",
    "damastservettens": "damastservett",
    "damastservetter": "damastservett",
    "damastservetterna": "damastservett",
    "damastservetternas": "damastservett",
    "damastservetters": "damastservett",
    "damastservetts": "damastservett",
    "dambesöken": "dambesök",
    "dambesökens": "dambesök",
    "dambesöket": "dambesök",
    "dambesökets": "dambesök",
    "dambesöks": "dambesök",
    "dambind": "dambinda",
    "dambindan": "dambinda",
    "dambindans": "dambinda",
    "dambindas": "dambinda",
    "dambinde": "dambinda",
    "dambindor": "dambinda",
    "dambindorna": "dambinda",
    "dambindornas": "dambinda",
    "dambindors": "dambinda",
    "dambinds": "dambinda",
    "dambjudningar": "dambjudning",
    "dambjudningarna": "dambjudning",
    "dambjudningarnas": "dambjudning",
    "dambjudningars": "dambjudning",
    "dambjudningen": "dambjudning",
    "dambjudningens": "dambjudning",
    "dambjudnings": "dambjudning",
    "damcykeln": "damcykel",
    "damcykelns": "damcykel",
    "damcykels": "damcykel",
    "damcyklar": "damcykel",
    "damcyklarna": "damcykel",
    "damcyklarnas": "damcykel",
    "damcyklars": "damcykel",
    "damejeannen": "damejeanne",
    "damejeannens": "damejeanne",
    "damejeanner": "damejeanne",
    "damejeannerna": "damejeanne",
    "damejeannernas": "damejeanne",
    "damejeanners": "damejeanne",
    "damejeannes": "damejeanne",
    "damen": "dam",
    "damens": "dam",
    "damer": "dam",
    "damerna": "dam",
    "damernas": "dam",
    "damers": "dam",
    "damfotbollen": "damfotboll",
    "damfotbollens": "damfotboll",
    "damfotbolls": "damfotboll",
    "damfriseringar": "damfrisering",
    "damfriseringarna": "damfrisering",
    "damfriseringarnas": "damfrisering",
    "damfriseringars": "damfrisering",
    "damfriseringen": "damfrisering",
    "damfriseringens": "damfrisering",
    "damfriserings": "damfrisering",
    "damfrisören": "damfrisör",
    "damfrisörens": "damfrisör",
    "damfrisörer": "damfrisör",
    "damfrisörerna": "damfrisör",
    "damfrisörernas": "damfrisör",
    "damfrisörers": "damfrisör",
    "damfrisörn": "damfrisör",
    "damfrisörns": "damfrisör",
    "damfrisörs": "damfrisör",
    "damfrisörskan": "damfrisörska",
    "damfrisörskans": "damfrisörska",
    "damfrisörskas": "damfrisörska",
    "damfrisörske": "damfrisörska",
    "damfrisörskor": "damfrisörska",
    "damfrisörskorna": "damfrisörska",
    "damfrisörskornas": "damfrisörska",
    "damfrisörskors": "damfrisörska",
    "damgambitar": "damgambit",
    "damgambitarna": "damgambit",
    "damgambitarnas": "damgambit",
    "damgambitars": "damgambit",
    "damgambiten": "damgambit",
    "damgambitens": "damgambit",
    "damgambiter": "damgambit",
    "damgambiterna": "damgambit",
    "damgambiternas": "damgambit",
    "damgambiters": "damgambit",
    "damgambits": "damgambit",
    "damhattar": "damhatt",
    "damhattarna": "damhatt",
    "damhattarnas": "damhatt",
    "damhattars": "damhatt",
    "damhatten": "damhatt",
    "damhattens": "damhatt",
    "damhatts": "damhatt",
    "damiga": "damig",
    "damigare": "damig",
    "damigares": "damig",
    "damigas": "damig",
    "damigast": "damig",
    "damigaste": "damig",
    "damigastes": "damig",
    "damigasts": "damig",
    "damige": "damig",
    "damiges": "damig",
    "damigs": "damig",
    "damigt": "damig",
    "damigts": "damig",
    "damkören": "damkör",
    "damkörens": "damkör",
    "damkörer": "damkör",
    "damkörerna": "damkör",
    "damkörernas": "damkör",
    "damkörers": "damkör",
    "damkörs": "damkör",
    "dammad": "damma",
    "dammade": "damma",
    "dammades": "damma",
    "dammads": "damma",
    "dammande": "damma",
    "dammanden": "dammande",
    "dammandena": "dammande",
    "dammandenas": "dammande",
    "dammandens": "dammande",
    "dammandes": "dammande",
    "dammandet": "dammande",
    "dammandets": "dammande",
    "dammanläggningar": "dammanläggning",
    "dammanläggningarna": "dammanläggning",
    "dammanläggningarnas": "dammanläggning",
    "dammanläggningars": "dammanläggning",
    "dammanläggningen": "dammanläggning",
    "dammanläggningens": "dammanläggning",
    "dammanläggnings": "dammanläggning",
    "dammar": "damma",
    "dammarna": "damm",
    "dammarnas": "damm",
    "dammars": "damm",
    "dammas": "damma",
    "dammat": "damma",
    "dammats": "damma",
    "dammbindningsmedels": "dammbindningsmedel",
    "dammbindningsmedlen": "dammbindningsmedel",
    "dammbindningsmedlens": "dammbindningsmedel",
    "dammbindningsmedlet": "dammbindningsmedel",
    "dammbindningsmedlets": "dammbindningsmedel",
    "dammen": "damm",
    "dammens": "damm",
    "dammet": "damm",
    "dammets": "damm",
    "dammförsöken": "dammförsök",
    "dammförsökens": "dammförsök",
    "dammförsöket": "dammförsök",
    "dammförsökets": "dammförsök",
    "dammförsöks": "dammförsök",
    "dammgöm": "dammgömma",
    "dammgömman": "dammgömma",
    "dammgömmans": "dammgömma",
    "dammgömmas": "dammgömma",
    "dammgömme": "dammgömma",
    "dammgömmor": "dammgömma",
    "dammgömmorna": "dammgömma",
    "dammgömmornas": "dammgömma",
    "dammgömmors": "dammgömma",
    "dammgöms": "dammgömma",
    "dammiga": "dammig",
    "dammigare": "dammig",
    "dammigares": "dammig",
    "dammigas": "dammig",
    "dammigast": "dammig",
    "dammigaste": "dammig",
    "dammigastes": "dammig",
    "dammigasts": "dammig",
    "dammige": "dammig",
    "dammiges": "dammig",
    "dammigheten": "dammighet",
    "dammighetens": "dammighet",
    "dammighets": "dammighet",
    "dammigs": "dammig",
    "dammigt": "dammig",
    "dammigts": "dammig",
    "dammkornen": "dammkorn",
    "dammkornens": "dammkorn",
    "dammkornet": "dammkorn",
    "dammkornets": "dammkorn",
    "dammkorns": "dammkorn",
    "dammkvalsterna": "dammkvalster",
    "dammkvalsternas": "dammkvalster",
    "dammkvalsters": "dammkvalster",
    "dammkvalstren": "dammkvalster",
    "dammkvalstrens": "dammkvalster",
    "dammkvalstret": "dammkvalster",
    "dammkvalstrets": "dammkvalster",
    "dammlagerna": "dammlager",
    "dammlagernas": "dammlager",
    "dammlagers": "dammlager",
    "dammlagren": "dammlager",
    "dammlagrens": "dammlager",
    "dammlagret": "dammlager",
    "dammlagrets": "dammlager",
    "dammluck": "dammlucka",
    "dammluckan": "dammlucka",
    "dammluckans": "dammlucka",
    "dammluckas": "dammlucka",
    "dammlucke": "dammlucka",
    "dammluckor": "dammlucka",
    "dammluckorna": "dammlucka",
    "dammluckornas": "dammlucka",
    "dammluckors": "dammlucka",
    "dammlucks": "dammlucka",
    "dammlungan": "dammlunga",
    "dammlungans": "dammlunga",
    "dammlungas": "dammlunga",
    "dammoden": "dammode",
    "dammodena": "dammode",
    "dammodenas": "dammode",
    "dammodens": "dammode",
    "dammodes": "dammode",
    "dammodet": "dammode",
    "dammodets": "dammode",
    "dammods": "dammode",
    "dammolnen": "dammoln",
    "dammolnens": "dammoln",
    "dammolnet": "dammoln",
    "dammolnets": "dammoln",
    "dammolns": "dammoln",
    "dammportar": "dammport",
    "dammportarna": "dammport",
    "dammportarnas": "dammport",
    "dammportars": "dammport",
    "dammporten": "dammport",
    "dammportens": "dammport",
    "dammports": "dammport",
    "dammpumpar": "dammpump",
    "dammpumparna": "dammpump",
    "dammpumparnas": "dammpump",
    "dammpumpars": "dammpump",
    "dammpumpen": "dammpump",
    "dammpumpens": "dammpump",
    "dammpumps": "dammpump",
    "damms": "damm",
    "dammsug": "dammsuga",
    "dammsugande": "dammsuga",
    "dammsuganden": "dammsugande",
    "dammsugandena": "dammsugande",
    "dammsugandenas": "dammsugande",
    "dammsugandens": "dammsugande",
    "dammsugandes": "dammsugande",
    "dammsugandet": "dammsugande",
    "dammsugandets": "dammsugande",
    "dammsugar": "dammsugare",
    "dammsugaren": "dammsugare",
    "dammsugarens": "dammsugare",
    "dammsugares": "dammsugare",
    "dammsugarförsäljningar": "dammsugarförsäljning",
    "dammsugarförsäljningarna": "dammsugarförsäljning",
    "dammsugarförsäljningarnas": "dammsugarförsäljning",
    "dammsugarförsäljningars": "dammsugarförsäljning",
    "dammsugarförsäljningen": "dammsugarförsäljning",
    "dammsugarförsäljningens": "dammsugarförsäljning",
    "dammsugarförsäljnings": "dammsugarförsäljning",
    "dammsugarna": "dammsugare",
    "dammsugarnas": "dammsugare",
    "dammsugarpås": "dammsugarpåse",
    "dammsugarpåsar": "dammsugarpåse",
    "dammsugarpåsarna": "dammsugarpåse",
    "dammsugarpåsarnas": "dammsugarpåse",
    "dammsugarpåsars": "dammsugarpåse",
    "dammsugarpåsen": "dammsugarpåse",
    "dammsugarpåsens": "dammsugarpåse",
    "dammsugarpåses": "dammsugarpåse",
    "dammsugas": "dammsuga",
    "dammsuge": "dammsuga",
    "dammsugen": "dammsuga",
    "dammsugens": "dammsuga",
    "dammsuger": "dammsuga",
    "dammsuges": "dammsuga",
    "dammsuget": "dammsuga",
    "dammsugets": "dammsuga",
    "dammsugit": "dammsuga",
    "dammsugits": "dammsuga",
    "dammsugna": "dammsuga",
    "dammsugnas": "dammsuga",
    "dammsugne": "dammsuga",
    "dammsugnes": "dammsuga",
    "dammsugningar": "dammsugning",
    "dammsugningarna": "dammsugning",
    "dammsugningarnas": "dammsugning",
    "dammsugningars": "dammsugning",
    "dammsugningen": "dammsugning",
    "dammsugningens": "dammsugning",
    "dammsugnings": "dammsugning",
    "dammsugs": "dammsuga",
    "dammsög": "dammsuga",
    "dammsöge": "dammsuga",
    "dammsöges": "dammsuga",
    "dammsögs": "dammsuga",
    "dammtork": "dammtorka",
    "dammtorkad": "dammtorka",
    "dammtorkade": "dammtorka",
    "dammtorkades": "dammtorka",
    "dammtorkads": "dammtorka",
    "dammtorkande": "dammtorka",
    "dammtorkanden": "dammtorkande",
    "dammtorkandena": "dammtorkande",
    "dammtorkandenas": "dammtorkande",
    "dammtorkandens": "dammtorkande",
    "dammtorkandes": "dammtorkande",
    "dammtorkandet": "dammtorkande",
    "dammtorkandets": "dammtorkande",
    "dammtorkar": "dammtorka",
    "dammtorkas": "dammtorka",
    "dammtorkat": "dammtorka",
    "dammtorkats": "dammtorka",
    "dammtras": "dammtrasa",
    "dammtrasan": "dammtrasa",
    "dammtrasans": "dammtrasa",
    "dammtrasas": "dammtrasa",
    "dammtrase": "dammtrasa",
    "dammtrasor": "dammtrasa",
    "dammtrasorna": "dammtrasa",
    "dammtrasornas": "dammtrasa",
    "dammtrasors": "dammtrasa",
    "dammussel": "dammussla",
    "dammusslan": "dammussla",
    "dammusslans": "dammussla",
    "dammusslas": "dammussla",
    "dammussle": "dammussla",
    "dammusslor": "dammussla",
    "dammusslorna": "dammussla",
    "dammusslornas": "dammussla",
    "dammusslors": "dammussla",
    "dammvipp": "dammvippa",
    "dammvippan": "dammvippa",
    "dammvippans": "dammvippa",
    "dammvippas": "dammvippa",
    "dammvippe": "dammvippa",
    "dammvippor": "dammvippa",
    "dammvipporna": "dammvippa",
    "dammvippornas": "dammvippa",
    "dammvippors": "dammvippa",
    "dammvipps": "dammvippa",
    "damningar": "damning",
    "damningarna": "damning",
    "damningarnas": "damning",
    "damningars": "damning",
    "damningen": "damning",
    "damningens": "damning",
    "damnings": "damning",
    "damoklessvärden": "damoklessvärd",
    "damoklessvärdens": "damoklessvärd",
    "damoklessvärdet": "damoklessvärd",
    "damoklessvärdets": "damoklessvärd",
    "damoklessvärds": "damoklessvärd",
    "damp": "dimpa",
    "damp-en": "damp",
    "damp-ens": "damp",
    "damp-et": "damp",
    "damp-ets": "damp",
    "damp-na": "damp",
    "damp-nas": "damp",
    "damp-s": "damp",
    "damp:en": "damp",
    "damp:et": "damp",
    "damp:na": "damp",
    "damp:s": "damp",
    "dampad": "dampa",
    "dampade": "dampa",
    "dampades": "dampa",
    "dampads": "dampa",
    "dampande": "dampa",
    "dampanden": "dampande",
    "dampandena": "dampande",
    "dampandenas": "dampande",
    "dampandens": "dampande",
    "dampandes": "dampande",
    "dampandet": "dampande",
    "dampandets": "dampande",
    "dampar": "dampa",
    "dampas": "dampa",
    "dampat": "dampa",
    "dampats": "dampa",
    "dampnas": "damp",
    "damps": "dimpa",
    "damrummen": "damrum",
    "damrummens": "damrum",
    "damrummet": "damrum",
    "damrummets": "damrum",
    "damrums": "damrum",
    "dams": "dam",
    "damsidan": "damsida",
    "damsidans": "damsida",
    "damsidas": "damsida",
    "damside": "damsida",
    "damsides": "damsida",
    "damsidor": "damsida",
    "damsidorna": "damsida",
    "damsidornas": "damsida",
    "damsidors": "damsida",
    "damskjort": "damskjorta",
    "damskjortan": "damskjorta",
    "damskjortans": "damskjorta",
    "damskjortas": "damskjorta",
    "damskjorte": "damskjorta",
    "damskjortor": "damskjorta",
    "damskjortorna": "damskjorta",
    "damskjortornas": "damskjorta",
    "damskjortors": "damskjorta",
    "damskjorts": "damskjorta",
    "damskon": "damsko",
    "damskons": "damsko",
    "damskor": "damsko",
    "damskorna": "damsko",
    "damskornas": "damsko",
    "damskors": "damsko",
    "damskos": "damsko",
    "damslalomen": "damslalom",
    "damslalomens": "damslalom",
    "damslaloms": "damslalom",
    "damspelen": "damspel",
    "damspelens": "damspel",
    "damspelet": "damspel",
    "damspelets": "damspel",
    "damspels": "damspel",
    "damstrump": "damstrumpa",
    "damstrumpan": "damstrumpa",
    "damstrumpans": "damstrumpa",
    "damstrumpas": "damstrumpa",
    "damstrumpe": "damstrumpa",
    "damstrumpor": "damstrumpa",
    "damstrumporna": "damstrumpa",
    "damstrumpornas": "damstrumpa",
    "damstrumpors": "damstrumpa",
    "damstrumps": "damstrumpa",
    "damsällskapen": "damsällskap",
    "damsällskapens": "damsällskap",
    "damsällskapet": "damsällskap",
    "damsällskapets": "damsällskap",
    "damsällskaps": "damsällskap",
    "damtidningar": "damtidning",
    "damtidningarna": "damtidning",
    "damtidningarnas": "damtidning",
    "damtidningars": "damtidning",
    "damtidningen": "damtidning",
    "damtidningens": "damtidning",
    "damtidnings": "damtidning",
    "damtoaletten": "damtoalett",
    "damtoalettens": "damtoalett",
    "damtoaletter": "damtoalett",
    "damtoaletterna": "damtoalett",
    "damtoaletternas": "damtoalett",
    "damtoaletters": "damtoalett",
    "damtoaletts": "damtoalett",
    "damunderkläderna": "damunderkläder",
    "damunderklädernas": "damunderkläder",
    "damunderkläders": "damunderkläder",
    "damunderklädes": "damunderkläder",
    "damunderkläds": "damunderkläder",
    "damväsk": "damväska",
    "damväskan": "damväska",
    "damväskans": "damväska",
    "damväskas": "damväska",
    "damväske": "damväska",
    "damväskor": "damväska",
    "damväskorna": "damväska",
    "damväskornas": "damväska",
    "damväskors": "damväska",
    "dan": "dana",
    "danaarven": "danaarv",
    "danaarvens": "danaarv",
    "danaarvet": "danaarv",
    "danaarvets": "danaarv",
    "danaarvs": "danaarv",
    "danad": "dana",
    "danade": "dana",
    "danades": "dana",
    "danads": "dana",
    "danande": "dana",
    "dananden": "danande",
    "danandena": "danande",
    "danandenas": "danande",
    "danandens": "danande",
    "danandes": "danande",
    "danandet": "danande",
    "danandets": "danande",
    "danar": "dana",
    "danas": "dana",
    "danat": "dana",
    "danats": "dana",
    "dandier": "dandy",
    "dandierna": "dandy",
    "dandiernas": "dandy",
    "dandiers": "dandy",
    "dandies": "dandy",
    "dandiesarna": "dandy",
    "dandiesarnas": "dandy",
    "dandyer": "dandy",
    "dandyerna": "dandy",
    "dandyernas": "dandy",
    "dandyers": "dandy",
    "dandyn": "dandy",
    "dandyns": "dandy",
    "dandys": "dandy",
    "dandysar": "dandy",
    "dandysarna": "dandy",
    "dandysarnas": "dandy",
    "dandysars": "dandy",
    "dangel": "dangla",
    "danglade": "dangla",
    "danglades": "dangla",
    "danglande": "dangla",
    "danglanden": "danglande",
    "danglandena": "danglande",
    "danglandenas": "danglande",
    "danglandens": "danglande",
    "danglandes": "danglande",
    "danglandet": "danglande",
    "danglandets": "danglande",
    "danglar": "dangla",
    "danglas": "dangla",
    "danglat": "dangla",
    "danglats": "dangla",
    "daningar": "daning",
    "daningarna": "daning",
    "daningarnas": "daning",
    "daningars": "daning",
    "daningen": "daning",
    "daningens": "daning",
    "danings": "daning",
    "danismen": "danism",
    "danismens": "danism",
    "danismer": "danism",
    "danismerna": "danism",
    "danismernas": "danism",
    "danismers": "danism",
    "danisms": "danism",
    "dankar": "dank",
    "dankarna": "dank",
    "dankarnas": "dank",
    "dankars": "dank",
    "danken": "dank",
    "dankens": "dank",
    "danks": "dank",
    "dannemannen": "danneman",
    "dannemannens": "danneman",
    "dannemans": "danneman",
    "dannemän": "danneman",
    "dannemännen": "danneman",
    "dannemännens": "danneman",
    "dannemäns": "danneman",
    "dans": "dansa",
    "dansade": "dansa",
    "dansades": "dansa",
    "dansande": "dansa",
    "dansanden": "dansande",
    "dansandena": "dansande",
    "dansandenas": "dansande",
    "dansandens": "dansande",
    "dansandes": "dansande",
    "dansandet": "dansande",
    "dansandets": "dansande",
    "dansanta": "dansant",
    "dansantare": "dansant",
    "dansantares": "dansant",
    "dansantas": "dansant",
    "dansantast": "dansant",
    "dansantaste": "dansant",
    "dansantastes": "dansant",
    "dansantasts": "dansant",
    "dansante": "dansant",
    "dansantes": "dansant",
    "dansants": "dansant",
    "dansar": "dansare",
    "dansaren": "dansare",
    "dansarens": "dansare",
    "dansares": "dansare",
    "dansarna": "dansare",
    "dansarnas": "dansare",
    "dansas": "dansa",
    "dansat": "dansa",
    "dansats": "dansa",
    "dansbanan": "dansbana",
    "dansbanans": "dansbana",
    "dansbanas": "dansbana",
    "dansbane": "dansbana",
    "dansbaneeländen": "dansbaneelände",
    "dansbaneeländena": "dansbaneelände",
    "dansbaneeländenas": "dansbaneelände",
    "dansbaneeländens": "dansbaneelände",
    "dansbaneeländes": "dansbaneelände",
    "dansbaneeländet": "dansbaneelände",
    "dansbaneeländets": "dansbaneelände",
    "dansbanor": "dansbana",
    "dansbanorna": "dansbana",
    "dansbanornas": "dansbana",
    "dansbanors": "dansbana",
    "dansen": "dans",
    "dansens": "dans",
    "danser": "dans",
    "danserna": "dans",
    "dansernas": "dans",
    "dansers": "dans",
    "dansgolven": "dansgolv",
    "dansgolvens": "dansgolv",
    "dansgolvet": "dansgolv",
    "dansgolvets": "dansgolv",
    "dansgolvs": "dansgolv",
    "danshaken": "danshak",
    "danshakens": "danshak",
    "danshaket": "danshak",
    "danshakets": "danshak",
    "danshaks": "danshak",
    "dansk": "danska",
    "danska": "dansk",
    "danskan": "danska",
    "danskans": "danska",
    "danskar": "dansk",
    "danskare": "dansk",
    "danskares": "dansk",
    "danskarna": "dansk",
    "danskarnas": "dansk",
    "danskars": "dansk",
    "danskas": "danska",
    "danskast": "dansk",
    "danskaste": "dansk",
    "danskastes": "dansk",
    "danskasts": "dansk",
    "danske": "danska",
    "dansken": "dansk",
    "danskens": "dansk",
    "danskes": "dansk",
    "danskhaten": "danskhat",
    "danskhatens": "danskhat",
    "danskhatet": "danskhat",
    "danskhatets": "danskhat",
    "danskhats": "danskhat",
    "danskheten": "danskhet",
    "danskhetens": "danskhet",
    "danskhets": "danskhet",
    "danskonsten": "danskonst",
    "danskonstens": "danskonst",
    "danskonster": "danskonst",
    "danskonsterna": "danskonst",
    "danskonsternas": "danskonst",
    "danskonsters": "danskonst",
    "danskonsts": "danskonst",
    "danskor": "danska",
    "danskorna": "danska",
    "danskornas": "danska",
    "danskors": "danska",
    "dansks": "dansk",
    "danskt": "dansk",
    "danskts": "dansk",
    "danslekar": "danslek",
    "danslekarna": "danslek",
    "danslekarnas": "danslek",
    "danslekars": "danslek",
    "dansleken": "danslek",
    "danslekens": "danslek",
    "dansleks": "danslek",
    "danslektionen": "danslektion",
    "danslektionens": "danslektion",
    "danslektioner": "danslektion",
    "danslektionerna": "danslektion",
    "danslektionernas": "danslektion",
    "danslektioners": "danslektion",
    "danslektions": "danslektion",
    "dansmusiken": "dansmusik",
    "dansmusikens": "dansmusik",
    "dansmusiks": "dansmusik",
    "dansmässiga": "dansmässig",
    "dansmässigare": "dansmässig",
    "dansmässigares": "dansmässig",
    "dansmässigas": "dansmässig",
    "dansmässigast": "dansmässig",
    "dansmässigaste": "dansmässig",
    "dansmässigastes": "dansmässig",
    "dansmässigasts": "dansmässig",
    "dansmässige": "dansmässig",
    "dansmässiges": "dansmässig",
    "dansmässigs": "dansmässig",
    "dansmässigt": "dansmässig",
    "dansmässigts": "dansmässig",
    "dansrestaurangen": "dansrestaurang",
    "dansrestaurangens": "dansrestaurang",
    "dansrestauranger": "dansrestaurang",
    "dansrestaurangerna": "dansrestaurang",
    "dansrestaurangernas": "dansrestaurang",
    "dansrestaurangers": "dansrestaurang",
    "dansrestaurangs": "dansrestaurang",
    "danssalongen": "danssalong",
    "danssalongens": "danssalong",
    "danssalonger": "danssalong",
    "danssalongerna": "danssalong",
    "danssalongernas": "danssalong",
    "danssalongers": "danssalong",
    "danssalongs": "danssalong",
    "danssjukan": "danssjuka",
    "danssjukans": "danssjuka",
    "danssjukas": "danssjuka",
    "danssjuke": "danssjuka",
    "danssjuks": "danssjuka",
    "dansstegen": "danssteg",
    "dansstegens": "danssteg",
    "danssteget": "danssteg",
    "dansstegets": "danssteg",
    "dansstegs": "danssteg",
    "dansställen": "dansställe",
    "dansställena": "dansställe",
    "dansställenas": "dansställe",
    "dansställens": "dansställe",
    "dansställes": "dansställe",
    "dansstället": "dansställe",
    "dansställets": "dansställe",
    "danstillställningar": "danstillställning",
    "danstillställningarna": "danstillställning",
    "danstillställningarnas": "danstillställning",
    "danstillställningars": "danstillställning",
    "danstillställningen": "danstillställning",
    "danstillställningens": "danstillställning",
    "danstillställnings": "danstillställning",
    "dansören": "dansör",
    "dansörens": "dansör",
    "dansörer": "dansör",
    "dansörerna": "dansör",
    "dansörernas": "dansör",
    "dansörers": "dansör",
    "dansörs": "dansör",
    "dansösen": "dansös",
    "dansösens": "dansös",
    "dansöser": "dansös",
    "dansöserna": "dansös",
    "dansösernas": "dansös",
    "dansösers": "dansös",
    "daphnie": "daphnier",
    "daphnierna": "daphnier",
    "daphniernas": "daphnier",
    "daphniers": "daphnier",
    "dar": "dag",
    "darna": "dag",
    "darnas": "dag",
    "darr": "darra",
    "darrade": "darra",
    "darrades": "darra",
    "darrande": "darra",
    "darranden": "darrande",
    "darrandena": "darrande",
    "darrandenas": "darrande",
    "darrandens": "darrande",
    "darrandes": "darrande",
    "darrandet": "darrande",
    "darrandets": "darrande",
    "darrar": "darra",
    "darras": "darra",
    "darrat": "darra",
    "darrats": "darra",
    "darret": "darr",
    "darrets": "darr",
    "darrgräset": "darrgräs",
    "darrgräsets": "darrgräs",
    "darrhänta": "darrhänt",
    "darrhäntare": "darrhänt",
    "darrhäntares": "darrhänt",
    "darrhäntas": "darrhänt",
    "darrhäntast": "darrhänt",
    "darrhäntaste": "darrhänt",
    "darrhäntastes": "darrhänt",
    "darrhäntasts": "darrhänt",
    "darrhänte": "darrhänt",
    "darrhäntes": "darrhänt",
    "darrhäntheten": "darrhänthet",
    "darrhänthetens": "darrhänthet",
    "darrhänthets": "darrhänthet",
    "darrhänts": "darrhänt",
    "darriga": "darrig",
    "darrigare": "darrig",
    "darrigares": "darrig",
    "darrigas": "darrig",
    "darrigast": "darrig",
    "darrigaste": "darrig",
    "darrigastes": "darrig",
    "darrigasts": "darrig",
    "darrige": "darrig",
    "darriges": "darrig",
    "darrigheten": "darrighet",
    "darrighetens": "darrighet",
    "darrighets": "darrighet",
    "darrigs": "darrig",
    "darrigt": "darrig",
    "darrigts": "darrig",
    "darrningar": "darrning",
    "darrningarna": "darrning",
    "darrningarnas": "darrning",
    "darrningars": "darrning",
    "darrningen": "darrning",
    "darrningens": "darrning",
    "darrnings": "darrning",
    "darrock": "darrocka",
    "darrockan": "darrocka",
    "darrockans": "darrocka",
    "darrockas": "darrocka",
    "darrocke": "darrocka",
    "darrockor": "darrocka",
    "darrockorna": "darrocka",
    "darrockornas": "darrocka",
    "darrockors": "darrocka",
    "darrocks": "darrocka",
    "darrs": "darr",
    "darrålar": "darrål",
    "darrålarna": "darrål",
    "darrålarnas": "darrål",
    "darrålars": "darrål",
    "darrålen": "darrål",
    "darrålens": "darrål",
    "darråls": "darrål",
    "dars": "dag",
    "darten": "dart",
    "dartens": "dart",
    "dartpilar": "dartpil",
    "dartpilarna": "dartpil",
    "dartpilarnas": "dartpil",
    "dartpilars": "dartpil",
    "dartpilen": "dartpil",
    "dartpilens": "dartpil",
    "dartpils": "dartpil",
    "darts": "dart",
    "dartspelen": "dartspel",
    "dartspelens": "dartspel",
    "dartspelet": "dartspel",
    "dartspelets": "dartspel",
    "dartspels": "dartspel",
    "darttavel": "darttavla",
    "darttavlan": "darttavla",
    "darttavlans": "darttavla",
    "darttavlas": "darttavla",
    "darttavle": "darttavla",
    "darttavlor": "darttavla",
    "darttavlorna": "darttavla",
    "darttavlornas": "darttavla",
    "darttavlors": "darttavla",
    "darwinfinkar": "darwinfink",
    "darwinfinkarna": "darwinfink",
    "darwinfinkarnas": "darwinfink",
    "darwinfinkars": "darwinfink",
    "darwinfinken": "darwinfink",
    "darwinfinkens": "darwinfink",
    "darwinfinks": "darwinfink",
    "darwinismen": "darwinism",
    "darwinismens": "darwinism",
    "darwinismer": "darwinism",
    "darwinismerna": "darwinism",
    "darwinismernas": "darwinism",
    "darwinismers": "darwinism",
    "darwinisms": "darwinism",
    "darwinisten": "darwinist",
    "darwinistens": "darwinist",
    "darwinister": "darwinist",
    "darwinisterna": "darwinist",
    "darwinisternas": "darwinist",
    "darwinisters": "darwinist",
    "darwinistiska": "darwinistisk",
    "darwinistiskare": "darwinistisk",
    "darwinistiskares": "darwinistisk",
    "darwinistiskas": "darwinistisk",
    "darwinistiskast": "darwinistisk",
    "darwinistiskaste": "darwinistisk",
    "darwinistiskastes": "darwinistisk",
    "darwinistiskasts": "darwinistisk",
    "darwinistiske": "darwinistisk",
    "darwinistiskes": "darwinistisk",
    "darwinistisks": "darwinistisk",
    "darwinistiskt": "darwinistisk",
    "darwinistiskts": "darwinistisk",
    "darwinists": "darwinist",
    "dask": "daska",
    "daskad": "daska",
    "daskade": "daska",
    "daskades": "daska",
    "daskads": "daska",
    "daskande": "daska",
    "daskanden": "daskande",
    "daskandena": "daskande",
    "daskandenas": "daskande",
    "daskandens": "daskande",
    "daskandes": "daskande",
    "daskandet": "daskande",
    "daskandets": "daskande",
    "daskar": "daska",
    "daskas": "daska",
    "daskat": "daska",
    "daskats": "daska",
    "dasket": "dask",
    "daskets": "dask",
    "daskiga": "daskig",
    "daskigare": "daskig",
    "daskigares": "daskig",
    "daskigas": "daskig",
    "daskigast": "daskig",
    "daskigaste": "daskig",
    "daskigastes": "daskig",
    "daskigasts": "daskig",
    "daskige": "daskig",
    "daskiges": "daskig",
    "daskigheten": "daskighet",
    "daskighetens": "daskighet",
    "daskighets": "daskighet",
    "daskigs": "daskig",
    "daskigt": "daskig",
    "daskigts": "daskig",
    "dasks": "dask",
    "dassade": "dassa",
    "dassades": "dassa",
    "dassande": "dassa",
    "dassanden": "dassande",
    "dassandena": "dassande",
    "dassandenas": "dassande",
    "dassandens": "dassande",
    "dassandes": "dassande",
    "dassandet": "dassande",
    "dassandets": "dassande",
    "dassar": "dassa",
    "dassas": "dassa",
    "dassat": "dassa",
    "dassats": "dassa",
    "dassen": "dass",
    "dassens": "dass",
    "dasset": "dass",
    "dassets": "dass",
    "dassiga": "dassig",
    "dassigare": "dassig",
    "dassigares": "dassig",
    "dassigas": "dassig",
    "dassigast": "dassig",
    "dassigaste": "dassig",
    "dassigastes": "dassig",
    "dassigasts": "dassig",
    "dassige": "dassig",
    "dassiges": "dassig",
    "dassigheten": "dassighet",
    "dassighetens": "dassighet",
    "dassighets": "dassighet",
    "dassigs": "dassig",
    "dassigt": "dassig",
    "dassigts": "dassig",
    "dasspapperet": "dasspapper",
    "dasspapperets": "dasspapper",
    "dasspappers": "dasspapper",
    "dasspappret": "dasspapper",
    "dasspapprets": "dasspapper",
    "dataanläggningar": "dataanläggning",
    "dataanläggningarna": "dataanläggning",
    "dataanläggningarnas": "dataanläggning",
    "dataanläggningars": "dataanläggning",
    "dataanläggningen": "dataanläggning",
    "dataanläggningens": "dataanläggning",
    "dataanläggnings": "dataanläggning",
    "databanken": "databank",
    "databankens": "databank",
    "databanker": "databank",
    "databankerna": "databank",
    "databankernas": "databank",
    "databankers": "databank",
    "databanks": "databank",
    "databasen": "databas",
    "databasens": "databas",
    "databaser": "databas",
    "databaserna": "databas",
    "databasernas": "databas",
    "databasers": "databas",
    "databehandlad": "databehandla",
    "databehandlade": "databehandla",
    "databehandlades": "databehandla",
    "databehandlads": "databehandla",
    "databehandlande": "databehandla",
    "databehandlanden": "databehandlande",
    "databehandlandena": "databehandlande",
    "databehandlandenas": "databehandlande",
    "databehandlandens": "databehandlande",
    "databehandlandes": "databehandlande",
    "databehandlandet": "databehandlande",
    "databehandlandets": "databehandlande",
    "databehandlar": "databehandla",
    "databehandlas": "databehandla",
    "databehandlat": "databehandla",
    "databehandlats": "databehandla",
    "databehandlingar": "databehandling",
    "databehandlingarna": "databehandling",
    "databehandlingarnas": "databehandling",
    "databehandlingars": "databehandling",
    "databehandlingen": "databehandling",
    "databehandlingens": "databehandling",
    "databehandlings": "databehandling",
    "datacentralen": "datacentral",
    "datacentralens": "datacentral",
    "datacentraler": "datacentral",
    "datacentralerna": "datacentral",
    "datacentralernas": "datacentral",
    "datacentralers": "datacentral",
    "datacentrals": "datacentral",
    "datafilen": "datafil",
    "datafilens": "datafil",
    "datafiler": "datafil",
    "datafilerna": "datafil",
    "datafilernas": "datafil",
    "datafilers": "datafil",
    "datafils": "datafil",
    "datahaverier": "datahaveri",
    "datahaverierna": "datahaveri",
    "datahaveriernas": "datahaveri",
    "datahaveriers": "datahaveri",
    "datahaveriet": "datahaveri",
    "datahaveriets": "datahaveri",
    "datahaveris": "datahaveri",
    "datahaverit": "datahaveri",
    "datahaverits": "datahaveri",
    "datainsamlingar": "datainsamling",
    "datainsamlingarna": "datainsamling",
    "datainsamlingarnas": "datainsamling",
    "datainsamlingars": "datainsamling",
    "datainsamlingen": "datainsamling",
    "datainsamlingens": "datainsamling",
    "datainsamlings": "datainsamling",
    "datainsamlingskampanjen": "datainsamlingskampanj",
    "datainsamlingskampanjens": "datainsamlingskampanj",
    "datainsamlingskampanjer": "datainsamlingskampanj",
    "datainsamlingskampanjerna": "datainsamlingskampanj",
    "datainsamlingskampanjernas": "datainsamlingskampanj",
    "datainsamlingskampanjers": "datainsamlingskampanj",
    "datainsamlingskampanjs": "datainsamlingskampanj",
    "dataintrången": "dataintrång",
    "dataintrångens": "dataintrång",
    "dataintrånget": "dataintrång",
    "dataintrångets": "dataintrång",
    "dataintrångs": "dataintrång",
    "dataintrångsskandalen": "dataintrångsskandal",
    "dataintrångsskandalens": "dataintrångsskandal",
    "dataintrångsskandaler": "dataintrångsskandal",
    "dataintrångsskandalerna": "dataintrångsskandal",
    "dataintrångsskandalernas": "dataintrångsskandal",
    "dataintrångsskandalers": "dataintrångsskandal",
    "dataintrångsskandals": "dataintrångsskandal",
    "datakommunikationen": "datakommunikation",
    "datakommunikationens": "datakommunikation",
    "datakommunikationer": "datakommunikation",
    "datakommunikationerna": "datakommunikation",
    "datakommunikationernas": "datakommunikation",
    "datakommunikationers": "datakommunikation",
    "datakommunikations": "datakommunikation",
    "datakraften": "datakraft",
    "datakraftens": "datakraft",
    "datakrafts": "datakraft",
    "datakörningar": "datakörning",
    "datakörningarna": "datakörning",
    "datakörningarnas": "datakörning",
    "datakörningars": "datakörning",
    "datakörningen": "datakörning",
    "datakörningens": "datakörning",
    "datakörnings": "datakörning",
    "datalagringen": "datalagring",
    "datalagringens": "datalagring",
    "datalagrings": "datalagring",
    "datalagringsdirektiven": "datalagringsdirektiv",
    "datalagringsdirektivens": "datalagringsdirektiv",
    "datalagringsdirektivet": "datalagringsdirektiv",
    "datalagringsdirektivets": "datalagringsdirektiv",
    "datalagringsdirektivs": "datalagringsdirektiv",
    "datalagringsföretagen": "datalagringsföretag",
    "datalagringsföretagens": "datalagringsföretag",
    "datalagringsföretaget": "datalagringsföretag",
    "datalagringsföretagets": "datalagringsföretag",
    "datalagringsföretags": "datalagringsföretag",
    "datalingvistiken": "datalingvistik",
    "datalingvistikens": "datalingvistik",
    "datalingvistiks": "datalingvistik",
    "datalogien": "datalogi",
    "datalogiens": "datalogi",
    "datalogin": "datalogi",
    "datalogins": "datalogi",
    "datalogis": "datalogi",
    "datamaskinella": "datamaskinell",
    "datamaskinellare": "datamaskinell",
    "datamaskinellares": "datamaskinell",
    "datamaskinellas": "datamaskinell",
    "datamaskinellast": "datamaskinell",
    "datamaskinellaste": "datamaskinell",
    "datamaskinellastes": "datamaskinell",
    "datamaskinellasts": "datamaskinell",
    "datamaskinelle": "datamaskinell",
    "datamaskinelles": "datamaskinell",
    "datamaskinells": "datamaskinell",
    "datamaskinellt": "datamaskinell",
    "datamaskinellts": "datamaskinell",
    "datamaskinen": "datamaskin",
    "datamaskinens": "datamaskin",
    "datamaskiner": "datamaskin",
    "datamaskinerna": "datamaskin",
    "datamaskinernas": "datamaskin",
    "datamaskiners": "datamaskin",
    "datamaskins": "datamaskin",
    "dataminnen": "dataminne",
    "dataminnena": "dataminne",
    "dataminnenas": "dataminne",
    "dataminnens": "dataminne",
    "dataminnes": "dataminne",
    "dataminnet": "dataminne",
    "dataminnets": "dataminne",
    "datamängden": "datamängd",
    "datamängdens": "datamängd",
    "datamängder": "datamängd",
    "datamängderna": "datamängd",
    "datamängdernas": "datamängd",
    "datamängders": "datamängd",
    "datamängds": "datamängd",
    "datan": "data",
    "datana": "data",
    "datanas": "data",
    "datans": "data",
    "datanäten": "datanät",
    "datanätens": "datanät",
    "datanätet": "datanät",
    "datanätets": "datanät",
    "datanäts": "datanät",
    "datapolitiken": "datapolitik",
    "datapolitikens": "datapolitik",
    "datapolitiks": "datapolitik",
    "datapolitiska": "datapolitisk",
    "datapolitiskas": "datapolitisk",
    "datapolitiske": "datapolitisk",
    "datapolitiskes": "datapolitisk",
    "datapolitisks": "datapolitisk",
    "datapolitiskt": "datapolitisk",
    "datapolitiskts": "datapolitisk",
    "dataprogrammen": "dataprogram",
    "dataprogrammens": "dataprogram",
    "dataprogrammet": "dataprogram",
    "dataprogrammets": "dataprogram",
    "dataprograms": "dataprogram",
    "dataregisterna": "dataregister",
    "dataregisternas": "dataregister",
    "dataregisters": "dataregister",
    "dataregistren": "dataregister",
    "dataregistrens": "dataregister",
    "dataregistret": "dataregister",
    "dataregistrets": "dataregister",
    "datas": "data",
    "datasimuleringar": "datasimulering",
    "datasimuleringarna": "datasimulering",
    "datasimuleringarnas": "datasimulering",
    "datasimuleringars": "datasimulering",
    "datasimuleringen": "datasimulering",
    "datasimuleringens": "datasimulering",
    "datasimulerings": "datasimulering",
    "dataskärmar": "dataskärm",
    "dataskärmarna": "dataskärm",
    "dataskärmarnas": "dataskärm",
    "dataskärmars": "dataskärm",
    "dataskärmen": "dataskärm",
    "dataskärmens": "dataskärm",
    "dataskärms": "dataskärm",
    "dataspelen": "dataspel",
    "dataspelens": "dataspel",
    "dataspelet": "dataspel",
    "dataspelets": "dataspel",
    "dataspels": "dataspel",
    "datat": "data",
    "datats": "data",
    "datavirusen": "datavirus",
    "datavirusens": "datavirus",
    "dataviruset": "datavirus",
    "datavirusets": "datavirus",
    "datavisions": "datavision",
    "daten": "date",
    "datens": "date",
    "dater": "date",
    "daterad": "datera",
    "daterade": "datera",
    "daterades": "datera",
    "daterads": "datera",
    "daterande": "datera",
    "dateranden": "daterande",
    "daterandena": "daterande",
    "daterandenas": "daterande",
    "daterandens": "daterande",
    "daterandes": "daterande",
    "daterandet": "daterande",
    "daterandets": "daterande",
    "daterar": "datera",
    "dateras": "datera",
    "daterat": "datera",
    "daterats": "datera",
    "daterbara": "daterbar",
    "daterbarare": "daterbar",
    "daterbarares": "daterbar",
    "daterbaras": "daterbar",
    "daterbarast": "daterbar",
    "daterbaraste": "daterbar",
    "daterbarastes": "daterbar",
    "daterbarasts": "daterbar",
    "daterbare": "daterbar",
    "daterbares": "daterbar",
    "daterbarheten": "daterbarhet",
    "daterbarhetens": "daterbarhet",
    "daterbarhets": "daterbarhet",
    "daterbars": "daterbar",
    "daterbart": "daterbar",
    "daterbarts": "daterbar",
    "dateringar": "datering",
    "dateringarna": "datering",
    "dateringarnas": "datering",
    "dateringars": "datering",
    "dateringen": "datering",
    "dateringens": "datering",
    "daterings": "datering",
    "daterna": "date",
    "daternas": "date",
    "daters": "date",
    "dates": "date",
    "dativen": "dativ",
    "dativens": "dativ",
    "dativer": "dativ",
    "dativerna": "dativ",
    "dativernas": "dativ",
    "dativers": "dativ",
    "dativobjekten": "dativobjekt",
    "dativobjektens": "dativobjekt",
    "dativobjektet": "dativobjekt",
    "dativobjektets": "dativobjekt",
    "dativobjekts": "dativobjekt",
    "dativs": "dativ",
    "dator": "data",
    "datoradressen": "datoradress",
    "datoradressens": "datoradress",
    "datoradresser": "datoradress",
    "datoradresserna": "datoradress",
    "datoradressernas": "datoradress",
    "datoradressers": "datoradress",
    "datoranläggningar": "datoranläggning",
    "datoranläggningarna": "datoranläggning",
    "datoranläggningarnas": "datoranläggning",
    "datoranläggningars": "datoranläggning",
    "datoranläggningen": "datoranläggning",
    "datoranläggningens": "datoranläggning",
    "datoranläggnings": "datoranläggning",
    "datorbehandlingar": "datorbehandling",
    "datorbehandlingarna": "datorbehandling",
    "datorbehandlingarnas": "datorbehandling",
    "datorbehandlingars": "datorbehandling",
    "datorbehandlingen": "datorbehandling",
    "datorbehandlingens": "datorbehandling",
    "datorbehandlings": "datorbehandling",
    "datorberäkningar": "datorberäkning",
    "datorberäkningarna": "datorberäkning",
    "datorberäkningarnas": "datorberäkning",
    "datorberäkningars": "datorberäkning",
    "datorberäkningen": "datorberäkning",
    "datorberäkningens": "datorberäkning",
    "datorberäknings": "datorberäkning",
    "datordriften": "datordrift",
    "datordriftens": "datordrift",
    "datordrifts": "datordrift",
    "datorer": "dator",
    "datorerna": "dator",
    "datorernas": "dator",
    "datorers": "dator",
    "datorfodralen": "datorfodral",
    "datorfodralens": "datorfodral",
    "datorfodralet": "datorfodral",
    "datorfodralets": "datorfodral",
    "datorfodrals": "datorfodral",
    "datorförsäljningen": "datorförsäljning",
    "datorförsäljningens": "datorförsäljning",
    "datorförsäljnings": "datorförsäljning",
    "datorglasögonen": "datorglasögon",
    "datorglasögonens": "datorglasögon",
    "datorglasögons": "datorglasögon",
    "datorhaverier": "datorhaveri",
    "datorhaverierna": "datorhaveri",
    "datorhaveriernas": "datorhaveri",
    "datorhaveriers": "datorhaveri",
    "datorhaveriet": "datorhaveri",
    "datorhaveriets": "datorhaveri",
    "datorhaveris": "datorhaveri",
    "datorhaverit": "datorhaveri",
    "datorhaverits": "datorhaveri",
    "datorintrången": "datorintrång",
    "datorintrångens": "datorintrång",
    "datorintrånget": "datorintrång",
    "datorintrångets": "datorintrång",
    "datorintrångs": "datorintrång",
    "datoriserad": "datorisera",
    "datoriserade": "datorisera",
    "datoriserades": "datorisera",
    "datoriserads": "datorisera",
    "datoriserande": "datorisera",
    "datoriseranden": "datoriserande",
    "datoriserandena": "datoriserande",
    "datoriserandenas": "datoriserande",
    "datoriserandens": "datoriserande",
    "datoriserandes": "datoriserande",
    "datoriserandet": "datoriserande",
    "datoriserandets": "datoriserande",
    "datoriserar": "datorisera",
    "datoriseras": "datorisera",
    "datoriserat": "datorisera",
    "datoriserats": "datorisera",
    "datoriserbara": "datoriserbar",
    "datoriserbarare": "datoriserbar",
    "datoriserbarares": "datoriserbar",
    "datoriserbaras": "datoriserbar",
    "datoriserbarast": "datoriserbar",
    "datoriserbaraste": "datoriserbar",
    "datoriserbarastes": "datoriserbar",
    "datoriserbarasts": "datoriserbar",
    "datoriserbare": "datoriserbar",
    "datoriserbares": "datoriserbar",
    "datoriserbarheten": "datoriserbarhet",
    "datoriserbarhetens": "datoriserbarhet",
    "datoriserbarhets": "datoriserbarhet",
    "datoriserbars": "datoriserbar",
    "datoriserbart": "datoriserbar",
    "datoriserbarts": "datoriserbar",
    "datoriseringen": "datorisering",
    "datoriseringens": "datorisering",
    "datoriserings": "datorisering",
    "datorkommunikationen": "datorkommunikation",
    "datorkommunikationens": "datorkommunikation",
    "datorkommunikations": "datorkommunikation",
    "datorkraften": "datorkraft",
    "datorkraftens": "datorkraft",
    "datorkrafts": "datorkraft",
    "datorlingvistiken": "datorlingvistik",
    "datorlingvistikens": "datorlingvistik",
    "datorlingvistiks": "datorlingvistik",
    "datorminnen": "datorminne",
    "datorminnena": "datorminne",
    "datorminnenas": "datorminne",
    "datorminnens": "datorminne",
    "datorminnes": "datorminne",
    "datorminnet": "datorminne",
    "datorminnets": "datorminne",
    "datormodellen": "datormodell",
    "datormodellens": "datormodell",
    "datormodeller": "datormodell",
    "datormodellerna": "datormodell",
    "datormodellernas": "datormodell",
    "datormodellers": "datormodell",
    "datormodells": "datormodell",
    "datormäss": "datormässa",
    "datormässan": "datormässa",
    "datormässans": "datormässa",
    "datormässas": "datormässa",
    "datormässe": "datormässa",
    "datormässor": "datormässa",
    "datormässorna": "datormässa",
    "datormässornas": "datormässa",
    "datormässors": "datormässa",
    "datorn": "dator",
    "datorna": "data",
    "datornas": "data",
    "datorns": "dator",
    "datorprogrammerar": "datorprogrammerare",
    "datorprogrammeraren": "datorprogrammerare",
    "datorprogrammerarens": "datorprogrammerare",
    "datorprogrammerares": "datorprogrammerare",
    "datorprogrammerarna": "datorprogrammerare",
    "datorprogrammerarnas": "datorprogrammerare",
    "datorrelaterade": "datorrelaterad",
    "datorrelaterades": "datorrelaterad",
    "datorrelaterads": "datorrelaterad",
    "datorrelaterat": "datorrelaterad",
    "datorrelaterats": "datorrelaterad",
    "dators": "dator",
    "datorsimulerad": "datorsimulera",
    "datorsimulerade": "datorsimulera",
    "datorsimulerades": "datorsimulera",
    "datorsimulerads": "datorsimulera",
    "datorsimulerande": "datorsimulera",
    "datorsimuleranden": "datorsimulerande",
    "datorsimulerandena": "datorsimulerande",
    "datorsimulerandenas": "datorsimulerande",
    "datorsimulerandens": "datorsimulerande",
    "datorsimulerandes": "datorsimulerande",
    "datorsimulerandet": "datorsimulerande",
    "datorsimulerandets": "datorsimulerande",
    "datorsimulerar": "datorsimulera",
    "datorsimuleras": "datorsimulera",
    "datorsimulerat": "datorsimulera",
    "datorsimulerats": "datorsimulera",
    "datorsimuleringar": "datorsimulering",
    "datorsimuleringarna": "datorsimulering",
    "datorsimuleringarnas": "datorsimulering",
    "datorsimuleringars": "datorsimulering",
    "datorsimuleringen": "datorsimulering",
    "datorsimuleringens": "datorsimulering",
    "datorsimulerings": "datorsimulering",
    "datorsladdar": "datorsladd",
    "datorsladdarna": "datorsladd",
    "datorsladdarnas": "datorsladd",
    "datorsladdars": "datorsladd",
    "datorsladden": "datorsladd",
    "datorsladdens": "datorsladd",
    "datorsladds": "datorsladd",
    "datorstöden": "datorstöd",
    "datorstödens": "datorstöd",
    "datorstödet": "datorstöd",
    "datorstödets": "datorstöd",
    "datorstöds": "datorstöd",
    "datorsystemen": "datorsystem",
    "datorsystemens": "datorsystem",
    "datorsystemet": "datorsystem",
    "datorsystemets": "datorsystem",
    "datorsystems": "datorsystem",
    "datortelefonen": "datortelefon",
    "datortelefonens": "datortelefon",
    "datortelefoner": "datortelefon",
    "datortelefonerna": "datortelefon",
    "datortelefonernas": "datortelefon",
    "datortelefoners": "datortelefon",
    "datortelefons": "datortelefon",
    "datorutrustningar": "datorutrustning",
    "datorutrustningarna": "datorutrustning",
    "datorutrustningarnas": "datorutrustning",
    "datorutrustningars": "datorutrustning",
    "datorutrustningen": "datorutrustning",
    "datorutrustningens": "datorutrustning",
    "datorutrustnings": "datorutrustning",
    "datorvirusen": "datorvirus",
    "datorvirusens": "datorvirus",
    "datorviruset": "datorvirus",
    "datorvirusets": "datorvirus",
    "datorväxeln": "datorväxel",
    "datorväxelns": "datorväxel",
    "datorväxels": "datorväxel",
    "datorväxlar": "datorväxel",
    "datorväxlarna": "datorväxel",
    "datorväxlarnas": "datorväxel",
    "datorväxlars": "datorväxel",
    "datos": "dato",
    "dats": "dat",
    "datt": "datta",
    "dattade": "datta",
    "dattades": "datta",
    "dattande": "datta",
    "dattanden": "dattande",
    "dattandena": "dattande",
    "dattandenas": "dattande",
    "dattandens": "dattande",
    "dattandes": "dattande",
    "dattandet": "dattande",
    "dattandets": "dattande",
    "dattar": "datta",
    "dattas": "datta",
    "dattat": "datta",
    "dattats": "datta",
    "dattens": "datten",
    "datumar": "datum",
    "datumarna": "datum",
    "datumarnas": "datum",
    "datumars": "datum",
    "datumen": "datum",
    "datumens": "datum",
    "datumer": "datum",
    "datumerna": "datum",
    "datumernas": "datum",
    "datumers": "datum",
    "datumet": "datum",
    "datumets": "datum",
    "datumgränsen": "datumgräns",
    "datumgränsens": "datumgräns",
    "datumgränser": "datumgräns",
    "datumgränserna": "datumgräns",
    "datumgränsernas": "datumgräns",
    "datumgränsers": "datumgräns",
    "datummärk": "datummärka",
    "datummärkande": "datummärka",
    "datummärkanden": "datummärkande",
    "datummärkandena": "datummärkande",
    "datummärkandenas": "datummärkande",
    "datummärkandens": "datummärkande",
    "datummärkandes": "datummärkande",
    "datummärkandet": "datummärkande",
    "datummärkandets": "datummärkande",
    "datummärkas": "datummärka",
    "datummärker": "datummärka",
    "datummärkes": "datummärka",
    "datummärks": "datummärka",
    "datummärkt": "datummärka",
    "datummärkta": "datummärka",
    "datummärktas": "datummärka",
    "datummärkte": "datummärka",
    "datummärktes": "datummärka",
    "datummärkts": "datummärka",
    "datumparkerad": "datumparkera",
    "datumparkerade": "datumparkera",
    "datumparkerades": "datumparkera",
    "datumparkerads": "datumparkera",
    "datumparkerande": "datumparkera",
    "datumparkeranden": "datumparkerande",
    "datumparkerandena": "datumparkerande",
    "datumparkerandenas": "datumparkerande",
    "datumparkerandens": "datumparkerande",
    "datumparkerandes": "datumparkerande",
    "datumparkerandet": "datumparkerande",
    "datumparkerandets": "datumparkerande",
    "datumparkerar": "datumparkera",
    "datumparkeras": "datumparkera",
    "datumparkerat": "datumparkera",
    "datumparkerats": "datumparkera",
    "datumparkerbara": "datumparkerbar",
    "datumparkerbarare": "datumparkerbar",
    "datumparkerbarares": "datumparkerbar",
    "datumparkerbaras": "datumparkerbar",
    "datumparkerbarast": "datumparkerbar",
    "datumparkerbaraste": "datumparkerbar",
    "datumparkerbarastes": "datumparkerbar",
    "datumparkerbarasts": "datumparkerbar",
    "datumparkerbare": "datumparkerbar",
    "datumparkerbares": "datumparkerbar",
    "datumparkerbarheten": "datumparkerbarhet",
    "datumparkerbarhetens": "datumparkerbarhet",
    "datumparkerbarhets": "datumparkerbarhet",
    "datumparkerbars": "datumparkerbar",
    "datumparkerbart": "datumparkerbar",
    "datumparkerbarts": "datumparkerbar",
    "datumparkeringar": "datumparkering",
    "datumparkeringarna": "datumparkering",
    "datumparkeringarnas": "datumparkering",
    "datumparkeringars": "datumparkering",
    "datumparkeringen": "datumparkering",
    "datumparkeringens": "datumparkering",
    "datumparkerings": "datumparkering",
    "datums": "datum",
    "davidsstjärnan": "davidsstjärna",
    "davidsstjärnans": "davidsstjärna",
    "davidsstjärnas": "davidsstjärna",
    "davidsstjärne": "davidsstjärna",
    "davidsstjärnor": "davidsstjärna",
    "davidsstjärnorna": "davidsstjärna",
    "davidsstjärnornas": "davidsstjärna",
    "davidsstjärnors": "davidsstjärna",
    "de": "en",
    "deadlinen": "deadline",
    "deadlinens": "deadline",
    "deadlines": "deadline",
    "debaclen": "debacle",
    "debaclens": "debacle",
    "debacles": "debacle",
    "debaclet": "debacle",
    "debaclets": "debacle",
    "debarkerad": "debarkera",
    "debarkerade": "debarkera",
    "debarkerades": "debarkera",
    "debarkerads": "debarkera",
    "debarkerande": "debarkera",
    "debarkeranden": "debarkerande",
    "debarkerandena": "debarkerande",
    "debarkerandenas": "debarkerande",
    "debarkerandens": "debarkerande",
    "debarkerandes": "debarkerande",
    "debarkerandet": "debarkerande",
    "debarkerandets": "debarkerande",
    "debarkerar": "debarkera",
    "debarkeras": "debarkera",
    "debarkerat": "debarkera",
    "debarkerats": "debarkera",
    "debarkerbara": "debarkerbar",
    "debarkerbarare": "debarkerbar",
    "debarkerbarares": "debarkerbar",
    "debarkerbaras": "debarkerbar",
    "debarkerbarast": "debarkerbar",
    "debarkerbaraste": "debarkerbar",
    "debarkerbarastes": "debarkerbar",
    "debarkerbarasts": "debarkerbar",
    "debarkerbare": "debarkerbar",
    "debarkerbares": "debarkerbar",
    "debarkerbarheten": "debarkerbarhet",
    "debarkerbarhetens": "debarkerbarhet",
    "debarkerbarhets": "debarkerbarhet",
    "debarkerbars": "debarkerbar",
    "debarkerbart": "debarkerbar",
    "debarkerbarts": "debarkerbar",
    "debarkeringar": "debarkering",
    "debarkeringarna": "debarkering",
    "debarkeringarnas": "debarkering",
    "debarkeringars": "debarkering",
    "debarkeringen": "debarkering",
    "debarkeringens": "debarkering",
    "debarkerings": "debarkering",
    "debattartikeln": "debattartikel",
    "debattartikelns": "debattartikel",
    "debattartikels": "debattartikel",
    "debattartiklar": "debattartikel",
    "debattartiklarna": "debattartikel",
    "debattartiklarnas": "debattartikel",
    "debattartiklars": "debattartikel",
    "debatten": "debatt",
    "debattens": "debatt",
    "debatter": "debatt",
    "debatterad": "debattera",
    "debatterade": "debattera",
    "debatterades": "debattera",
    "debatterads": "debattera",
    "debatterande": "debattera",
    "debatteranden": "debatterande",
    "debatterandena": "debatterande",
    "debatterandenas": "debatterande",
    "debatterandens": "debatterande",
    "debatterandes": "debatterande",
    "debatterandet": "debatterande",
    "debatterandets": "debatterande",
    "debatterar": "debattera",
    "debatteras": "debattera",
    "debatterat": "debattera",
    "debatterats": "debattera",
    "debatterbara": "debatterbar",
    "debatterbarare": "debatterbar",
    "debatterbarares": "debatterbar",
    "debatterbaras": "debatterbar",
    "debatterbarast": "debatterbar",
    "debatterbaraste": "debatterbar",
    "debatterbarastes": "debatterbar",
    "debatterbarasts": "debatterbar",
    "debatterbare": "debatterbar",
    "debatterbares": "debatterbar",
    "debatterbarheten": "debatterbarhet",
    "debatterbarhetens": "debatterbarhet",
    "debatterbarhets": "debatterbarhet",
    "debatterbars": "debatterbar",
    "debatterbart": "debatterbar",
    "debatterbarts": "debatterbar",
    "debatteringar": "debattering",
    "debatteringarna": "debattering",
    "debatteringarnas": "debattering",
    "debatteringars": "debattering",
    "debatteringen": "debattering",
    "debatteringens": "debattering",
    "debatterings": "debattering",
    "debatterna": "debatt",
    "debatternas": "debatt",
    "debatters": "debatt",
    "debattinläggen": "debattinlägg",
    "debattinläggens": "debattinlägg",
    "debattinlägget": "debattinlägg",
    "debattinläggets": "debattinlägg",
    "debattinläggs": "debattinlägg",
    "debattknepen": "debattknep",
    "debattknepens": "debattknep",
    "debattknepet": "debattknep",
    "debattknepets": "debattknep",
    "debattkneps": "debattknep",
    "debattmässiga": "debattmässig",
    "debattmässigare": "debattmässig",
    "debattmässigares": "debattmässig",
    "debattmässigas": "debattmässig",
    "debattmässigast": "debattmässig",
    "debattmässigaste": "debattmässig",
    "debattmässigastes": "debattmässig",
    "debattmässigasts": "debattmässig",
    "debattmässige": "debattmässig",
    "debattmässiges": "debattmässig",
    "debattmässigs": "debattmässig",
    "debattmässigt": "debattmässig",
    "debattmässigts": "debattmässig",
    "debatts": "debatt",
    "debattören": "debattör",
    "debattörens": "debattör",
    "debattörer": "debattör",
    "debattörerna": "debattör",
    "debattörernas": "debattör",
    "debattörers": "debattör",
    "debattörs": "debattör",
    "debets": "debet",
    "debetsedeln": "debetsedel",
    "debetsedelns": "debetsedel",
    "debetsedels": "debetsedel",
    "debetsedlar": "debetsedel",
    "debetsedlarna": "debetsedel",
    "debetsedlarnas": "debetsedel",
    "debetsedlars": "debetsedel",
    "debetsidan": "debetsida",
    "debetsidans": "debetsida",
    "debetsidas": "debetsida",
    "debetside": "debetsida",
    "debetsides": "debetsida",
    "debetsidor": "debetsida",
    "debetsidorna": "debetsida",
    "debetsidornas": "debetsida",
    "debetsidors": "debetsida",
    "debila": "debil",
    "debilare": "debil",
    "debilares": "debil",
    "debilas": "debil",
    "debilast": "debil",
    "debilaste": "debil",
    "debilastes": "debil",
    "debilasts": "debil",
    "debile": "debil",
    "debiles": "debil",
    "debiliteten": "debilitet",
    "debilitetens": "debilitet",
    "debiliteter": "debilitet",
    "debiliteterna": "debilitet",
    "debiliteternas": "debilitet",
    "debiliteters": "debilitet",
    "debilitets": "debilitet",
    "debils": "debil",
    "debilt": "debil",
    "debilts": "debil",
    "debiten": "debit",
    "debitens": "debit",
    "debiter": "debit",
    "debiterad": "debitera",
    "debiterade": "debitera",
    "debiterades": "debitera",
    "debiterads": "debitera",
    "debiterande": "debitera",
    "debiteranden": "debiterande",
    "debiterandena": "debiterande",
    "debiterandenas": "debiterande",
    "debiterandens": "debiterande",
    "debiterandes": "debiterande",
    "debiterandet": "debiterande",
    "debiterandets": "debiterande",
    "debiterar": "debitera",
    "debiteras": "debitera",
    "debiterat": "debitera",
    "debiterats": "debitera",
    "debiterbara": "debiterbar",
    "debiterbarare": "debiterbar",
    "debiterbarares": "debiterbar",
    "debiterbaras": "debiterbar",
    "debiterbarast": "debiterbar",
    "debiterbaraste": "debiterbar",
    "debiterbarastes": "debiterbar",
    "debiterbarasts": "debiterbar",
    "debiterbare": "debiterbar",
    "debiterbares": "debiterbar",
    "debiterbarheten": "debiterbarhet",
    "debiterbarhetens": "debiterbarhet",
    "debiterbarhets": "debiterbarhet",
    "debiterbars": "debiterbar",
    "debiterbart": "debiterbar",
    "debiterbarts": "debiterbar",
    "debiteringar": "debitering",
    "debiteringarna": "debitering",
    "debiteringarnas": "debitering",
    "debiteringars": "debitering",
    "debiteringen": "debitering",
    "debiteringens": "debitering",
    "debiterings": "debitering",
    "debiterna": "debit",
    "debiternas": "debit",
    "debiters": "debit",
    "debits": "debit",
    "debutanten": "debutant",
    "debutantens": "debutant",
    "debutanter": "debutant",
    "debutanterna": "debutant",
    "debutanternas": "debutant",
    "debutanters": "debutant",
    "debutants": "debutant",
    "debutboken": "debutbok",
    "debutbokens": "debutbok",
    "debutboks": "debutbok",
    "debutböcker": "debutbok",
    "debutböckerna": "debutbok",
    "debutböckernas": "debutbok",
    "debutböckers": "debutbok",
    "debuten": "debut",
    "debutens": "debut",
    "debuter": "debut",
    "debuterade": "debutera",
    "debuterades": "debutera",
    "debuterande": "debutera",
    "debuteranden": "debuterande",
    "debuterandena": "debuterande",
    "debuterandenas": "debuterande",
    "debuterandens": "debuterande",
    "debuterandes": "debuterande",
    "debuterandet": "debuterande",
    "debuterandets": "debuterande",
    "debuterar": "debutera",
    "debuteras": "debutera",
    "debuterat": "debutera",
    "debuterats": "debutera",
    "debuteringar": "debutering",
    "debuteringarna": "debutering",
    "debuteringarnas": "debutering",
    "debuteringars": "debutering",
    "debuteringen": "debutering",
    "debuteringens": "debutering",
    "debuterings": "debutering",
    "debuterna": "debut",
    "debuternas": "debut",
    "debuters": "debut",
    "debutromanen": "debutroman",
    "debutromanens": "debutroman",
    "debutromaner": "debutroman",
    "debutromanerna": "debutroman",
    "debutromanernas": "debutroman",
    "debutromaners": "debutroman",
    "debutromans": "debutroman",
    "debuts": "debut",
    "decemberkvällar": "decemberkväll",
    "decemberkvällarna": "decemberkväll",
    "decemberkvällarnas": "decemberkväll",
    "decemberkvällars": "decemberkväll",
    "decemberkvällen": "decemberkväll",
    "decemberkvällens": "decemberkväll",
    "decemberkvälls": "decemberkväll",
    "decembers": "december",
    "decennie": "decennium",
    "decennier": "decennium",
    "decennierna": "decennium",
    "decenniernas": "decennium",
    "decenniers": "decennium",
    "decenniet": "decennium",
    "decenniets": "decennium",
    "decenniums": "decennium",
    "decentralisationen": "decentralisation",
    "decentralisationens": "decentralisation",
    "decentralisationer": "decentralisation",
    "decentralisationerna": "decentralisation",
    "decentralisationernas": "decentralisation",
    "decentralisationers": "decentralisation",
    "decentralisations": "decentralisation",
    "decentraliserad": "decentralisera",
    "decentraliserade": "decentralisera",
    "decentraliserades": "decentralisera",
    "decentraliserads": "decentralisera",
    "decentraliserande": "decentralisera",
    "decentraliseranden": "decentraliserande",
    "decentraliserandena": "decentraliserande",
    "decentraliserandenas": "decentraliserande",
    "decentraliserandens": "decentraliserande",
    "decentraliserandes": "decentraliserande",
    "decentraliserandet": "decentraliserande",
    "decentraliserandets": "decentraliserande",
    "decentraliserar": "decentralisera",
    "decentraliseras": "decentralisera",
    "decentraliserat": "decentralisera",
    "decentraliserats": "decentralisera",
    "decentraliserbara": "decentraliserbar",
    "decentraliserbarare": "decentraliserbar",
    "decentraliserbarares": "decentraliserbar",
    "decentraliserbaras": "decentraliserbar",
    "decentraliserbarast": "decentraliserbar",
    "decentraliserbaraste": "decentraliserbar",
    "decentraliserbarastes": "decentraliserbar",
    "decentraliserbarasts": "decentraliserbar",
    "decentraliserbare": "decentraliserbar",
    "decentraliserbares": "decentraliserbar",
    "decentraliserbarheten": "decentraliserbarhet",
    "decentraliserbarhetens": "decentraliserbarhet",
    "decentraliserbarhets": "decentraliserbarhet",
    "decentraliserbars": "decentraliserbar",
    "decentraliserbart": "decentraliserbar",
    "decentraliserbarts": "decentraliserbar",
    "decentraliseringar": "decentralisering",
    "decentraliseringarna": "decentralisering",
    "decentraliseringarnas": "decentralisering",
    "decentraliseringars": "decentralisering",
    "decentraliseringen": "decentralisering",
    "decentraliseringens": "decentralisering",
    "decentraliserings": "decentralisering",
    "dechargedebatten": "dechargedebatt",
    "dechargedebattens": "dechargedebatt",
    "dechargedebatter": "dechargedebatt",
    "dechargedebatterna": "dechargedebatt",
    "dechargedebatternas": "dechargedebatt",
    "dechargedebatters": "dechargedebatt",
    "dechargedebatts": "dechargedebatt",
    "dechargen": "decharge",
    "dechargens": "decharge",
    "decharger": "decharge",
    "dechargerna": "decharge",
    "dechargernas": "decharge",
    "dechargers": "decharge",
    "decharges": "decharge",
    "dechiffrerad": "dechiffrera",
    "dechiffrerade": "dechiffrera",
    "dechiffrerades": "dechiffrera",
    "dechiffrerads": "dechiffrera",
    "dechiffrerande": "dechiffrera",
    "dechiffreranden": "dechiffrerande",
    "dechiffrerandena": "dechiffrerande",
    "dechiffrerandenas": "dechiffrerande",
    "dechiffrerandens": "dechiffrerande",
    "dechiffrerandes": "dechiffrerande",
    "dechiffrerandet": "dechiffrerande",
    "dechiffrerandets": "dechiffrerande",
    "dechiffrerar": "dechiffrera",
    "dechiffreras": "dechiffrera",
    "dechiffrerat": "dechiffrera",
    "dechiffrerats": "dechiffrera",
    "dechiffrerbara": "dechiffrerbar",
    "dechiffrerbarare": "dechiffrerbar",
    "dechiffrerbarares": "dechiffrerbar",
    "dechiffrerbaras": "dechiffrerbar",
    "dechiffrerbarast": "dechiffrerbar",
    "dechiffrerbaraste": "dechiffrerbar",
    "dechiffrerbarastes": "dechiffrerbar",
    "dechiffrerbarasts": "dechiffrerbar",
    "dechiffrerbare": "dechiffrerbar",
    "dechiffrerbares": "dechiffrerbar",
    "dechiffrerbarheten": "dechiffrerbarhet",
    "dechiffrerbarhetens": "dechiffrerbarhet",
    "dechiffrerbarhets": "dechiffrerbarhet",
    "dechiffrerbars": "dechiffrerbar",
    "dechiffrerbart": "dechiffrerbar",
    "dechiffrerbarts": "dechiffrerbar",
    "dechiffreringar": "dechiffrering",
    "dechiffreringarna": "dechiffrering",
    "dechiffreringarnas": "dechiffrering",
    "dechiffreringars": "dechiffrering",
    "dechiffreringen": "dechiffrering",
    "dechiffreringens": "dechiffrering",
    "dechiffrerings": "dechiffrering",
    "decibelen": "decibel",
    "decibelens": "decibel",
    "decibels": "decibel",
    "deciderade": "deciderad",
    "deciderades": "deciderad",
    "deciderads": "deciderad",
    "deciderat": "deciderad",
    "deciderats": "deciderad",
    "decilitermåtten": "decilitermått",
    "decilitermåttens": "decilitermått",
    "decilitermåttet": "decilitermått",
    "decilitermåttets": "decilitermått",
    "decilitermåtts": "decilitermått",
    "decilitern": "deciliter",
    "deciliterna": "deciliter",
    "deciliternas": "deciliter",
    "deciliterns": "deciliter",
    "deciliters": "deciliter",
    "decimalbråken": "decimalbråk",
    "decimalbråkens": "decimalbråk",
    "decimalbråket": "decimalbråk",
    "decimalbråkets": "decimalbråk",
    "decimalbråks": "decimalbråk",
    "decimalen": "decimal",
    "decimalens": "decimal",
    "decimaler": "decimal",
    "decimalerna": "decimal",
    "decimalernas": "decimal",
    "decimalers": "decimal",
    "decimalkomman": "decimalkomma",
    "decimalkommana": "decimalkomma",
    "decimalkommanas": "decimalkomma",
    "decimalkommans": "decimalkomma",
    "decimalkommas": "decimalkomma",
    "decimalkommat": "decimalkomma",
    "decimalkommats": "decimalkomma",
    "decimals": "decimal",
    "decimalsystemen": "decimalsystem",
    "decimalsystemens": "decimalsystem",
    "decimalsystemet": "decimalsystem",
    "decimalsystemets": "decimalsystem",
    "decimalsystems": "decimalsystem",
    "decimaltalen": "decimaltal",
    "decimaltalens": "decimaltal",
    "decimaltalet": "decimaltal",
    "decimaltalets": "decimaltal",
    "decimaltals": "decimaltal",
    "decimerad": "decimera",
    "decimerade": "decimera",
    "decimerades": "decimera",
    "decimerads": "decimera",
    "decimerande": "decimera",
    "decimeranden": "decimerande",
    "decimerandena": "decimerande",
    "decimerandenas": "decimerande",
    "decimerandens": "decimerande",
    "decimerandes": "decimerande",
    "decimerandet": "decimerande",
    "decimerandets": "decimerande",
    "decimerar": "decimera",
    "decimeras": "decimera",
    "decimerat": "decimera",
    "decimerats": "decimera",
    "decimerbara": "decimerbar",
    "decimerbarare": "decimerbar",
    "decimerbarares": "decimerbar",
    "decimerbaras": "decimerbar",
    "decimerbarast": "decimerbar",
    "decimerbaraste": "decimerbar",
    "decimerbarastes": "decimerbar",
    "decimerbarasts": "decimerbar",
    "decimerbare": "decimerbar",
    "decimerbares": "decimerbar",
    "decimerbarheten": "decimerbarhet",
    "decimerbarhetens": "decimerbarhet",
    "decimerbarhets": "decimerbarhet",
    "decimerbars": "decimerbar",
    "decimerbart": "decimerbar",
    "decimerbarts": "decimerbar",
    "decimeringar": "decimering",
    "decimeringarna": "decimering",
    "decimeringarnas": "decimering",
    "decimeringars": "decimering",
    "decimeringen": "decimering",
    "decimeringens": "decimering",
    "decimerings": "decimering",
    "decimetern": "decimeter",
    "decimeterna": "decimeter",
    "decimeternas": "decimeter",
    "decimeterns": "decimeter",
    "decimeters": "decimeter",
    "decimetrar": "decimeter",
    "decimetrarna": "decimeter",
    "decimetrarnas": "decimeter",
    "decimetrars": "decimeter",
    "deckar": "deckare",
    "deckaren": "deckare",
    "deckarens": "deckare",
    "deckares": "deckare",
    "deckarförfattar": "deckarförfattare",
    "deckarförfattaren": "deckarförfattare",
    "deckarförfattarens": "deckarförfattare",
    "deckarförfattares": "deckarförfattare",
    "deckarförfattarna": "deckarförfattare",
    "deckarförfattarnas": "deckarförfattare",
    "deckarna": "deckare",
    "deckarnas": "deckare",
    "dedicerad": "dedicera",
    "dedicerade": "dedicera",
    "dedicerades": "dedicera",
    "dedicerads": "dedicera",
    "dedicerande": "dedicera",
    "dediceranden": "dedicerande",
    "dedicerandena": "dedicerande",
    "dedicerandenas": "dedicerande",
    "dedicerandens": "dedicerande",
    "dedicerandes": "dedicerande",
    "dedicerandet": "dedicerande",
    "dedicerandets": "dedicerande",
    "dedicerar": "dedicera",
    "dediceras": "dedicera",
    "dedicerat": "dedicera",
    "dedicerats": "dedicera",
    "dedicerbara": "dedicerbar",
    "dedicerbarare": "dedicerbar",
    "dedicerbarares": "dedicerbar",
    "dedicerbaras": "dedicerbar",
    "dedicerbarast": "dedicerbar",
    "dedicerbaraste": "dedicerbar",
    "dedicerbarastes": "dedicerbar",
    "dedicerbarasts": "dedicerbar",
    "dedicerbare": "dedicerbar",
    "dedicerbares": "dedicerbar",
    "dedicerbarheten": "dedicerbarhet",
    "dedicerbarhetens": "dedicerbarhet",
    "dedicerbarhets": "dedicerbarhet",
    "dedicerbars": "dedicerbar",
    "dedicerbart": "dedicerbar",
    "dedicerbarts": "dedicerbar",
    "dediceringar": "dedicering",
    "dediceringarna": "dedicering",
    "dediceringarnas": "dedicering",
    "dediceringars": "dedicering",
    "dediceringen": "dedicering",
    "dediceringens": "dedicering",
    "dedicerings": "dedicering",
    "dedikationen": "dedikation",
    "dedikationens": "dedikation",
    "dedikationer": "dedikation",
    "dedikationerna": "dedikation",
    "dedikationernas": "dedikation",
    "dedikationers": "dedikation",
    "dedikations": "dedikation",
    "dedikationsexemplaren": "dedikationsexemplar",
    "dedikationsexemplarens": "dedikationsexemplar",
    "dedikationsexemplaret": "dedikationsexemplar",
    "dedikationsexemplarets": "dedikationsexemplar",
    "dedikationsexemplars": "dedikationsexemplar",
    "dedikerad": "dedikera",
    "dedikerade": "dedikera",
    "dedikerades": "dedikera",
    "dedikerads": "dedikera",
    "dedikerande": "dedikera",
    "dedikeranden": "dedikerande",
    "dedikerandena": "dedikerande",
    "dedikerandenas": "dedikerande",
    "dedikerandens": "dedikerande",
    "dedikerandes": "dedikerande",
    "dedikerandet": "dedikerande",
    "dedikerandets": "dedikerande",
    "dedikerar": "dedikera",
    "dedikeras": "dedikera",
    "dedikerat": "dedikera",
    "dedikerats": "dedikera",
    "dedikerbara": "dedikerbar",
    "dedikerbarare": "dedikerbar",
    "dedikerbarares": "dedikerbar",
    "dedikerbaras": "dedikerbar",
    "dedikerbarast": "dedikerbar",
    "dedikerbaraste": "dedikerbar",
    "dedikerbarastes": "dedikerbar",
    "dedikerbarasts": "dedikerbar",
    "dedikerbare": "dedikerbar",
    "dedikerbares": "dedikerbar",
    "dedikerbarheten": "dedikerbarhet",
    "dedikerbarhetens": "dedikerbarhet",
    "dedikerbarhets": "dedikerbarhet",
    "dedikerbars": "dedikerbar",
    "dedikerbart": "dedikerbar",
    "dedikerbarts": "dedikerbar",
    "dedikeringar": "dedikering",
    "dedikeringarna": "dedikering",
    "dedikeringarnas": "dedikering",
    "dedikeringars": "dedikering",
    "dedikeringen": "dedikering",
    "dedikeringens": "dedikering",
    "dedikerings": "dedikering",
    "deducerad": "deducera",
    "deducerade": "deducera",
    "deducerades": "deducera",
    "deducerads": "deducera",
    "deducerande": "deducera",
    "deduceranden": "deducerande",
    "deducerandena": "deducerande",
    "deducerandenas": "deducerande",
    "deducerandens": "deducerande",
    "deducerandes": "deducerande",
    "deducerandet": "deducerande",
    "deducerandets": "deducerande",
    "deducerar": "deducera",
    "deduceras": "deducera",
    "deducerat": "deducera",
    "deducerats": "deducera",
    "deducerbara": "deducerbar",
    "deducerbarare": "deducerbar",
    "deducerbarares": "deducerbar",
    "deducerbaras": "deducerbar",
    "deducerbarast": "deducerbar",
    "deducerbaraste": "deducerbar",
    "deducerbarastes": "deducerbar",
    "deducerbarasts": "deducerbar",
    "deducerbare": "deducerbar",
    "deducerbares": "deducerbar",
    "deducerbarheten": "deducerbarhet",
    "deducerbarhetens": "deducerbarhet",
    "deducerbarhets": "deducerbarhet",
    "deducerbars": "deducerbar",
    "deducerbart": "deducerbar",
    "deducerbarts": "deducerbar",
    "deduceringar": "deducering",
    "deduceringarna": "deducering",
    "deduceringarnas": "deducering",
    "deduceringars": "deducering",
    "deduceringen": "deducering",
    "deduceringens": "deducering",
    "deducerings": "deducering",
    "deduktionen": "deduktion",
    "deduktionens": "deduktion",
    "deduktioner": "deduktion",
    "deduktionerna": "deduktion",
    "deduktionernas": "deduktion",
    "deduktioners": "deduktion",
    "deduktions": "deduktion",
    "deduktiva": "deduktiv",
    "deduktivare": "deduktiv",
    "deduktivares": "deduktiv",
    "deduktivas": "deduktiv",
    "deduktivast": "deduktiv",
    "deduktivaste": "deduktiv",
    "deduktivastes": "deduktiv",
    "deduktivasts": "deduktiv",
    "deduktive": "deduktiv",
    "deduktives": "deduktiv",
    "deduktivs": "deduktiv",
    "deduktivt": "deduktiv",
    "deduktivts": "deduktiv",
    "defaitismen": "defaitism",
    "defaitismens": "defaitism",
    "defaitismer": "defaitism",
    "defaitismerna": "defaitism",
    "defaitismernas": "defaitism",
    "defaitismers": "defaitism",
    "defaitisms": "defaitism",
    "defaitisten": "defaitist",
    "defaitistens": "defaitist",
    "defaitister": "defaitist",
    "defaitisterna": "defaitist",
    "defaitisternas": "defaitist",
    "defaitisters": "defaitist",
    "defaitistiska": "defaitistisk",
    "defaitistiskare": "defaitistisk",
    "defaitistiskares": "defaitistisk",
    "defaitistiskas": "defaitistisk",
    "defaitistiskast": "defaitistisk",
    "defaitistiskaste": "defaitistisk",
    "defaitistiskastes": "defaitistisk",
    "defaitistiskasts": "defaitistisk",
    "defaitistiske": "defaitistisk",
    "defaitistiskes": "defaitistisk",
    "defaitistisks": "defaitistisk",
    "defaitistiskt": "defaitistisk",
    "defaitistiskts": "defaitistisk",
    "defaitists": "defaitist",
    "defekta": "defekt",
    "defektare": "defekt",
    "defektares": "defekt",
    "defektas": "defekt",
    "defektast": "defekt",
    "defektaste": "defekt",
    "defektastes": "defekt",
    "defektasts": "defekt",
    "defekte": "defekt",
    "defekten": "defekt",
    "defektens": "defekt",
    "defekter": "defekt",
    "defekterna": "defekt",
    "defekternas": "defekt",
    "defekters": "defekt",
    "defektes": "defekt",
    "defekts": "defekt",
    "defensiva": "defensiv",
    "defensivare": "defensiv",
    "defensivares": "defensiv",
    "defensivas": "defensiv",
    "defensivast": "defensiv",
    "defensivaste": "defensiv",
    "defensivastes": "defensiv",
    "defensivasts": "defensiv",
    "defensive": "defensiv",
    "defensiven": "defensiv",
    "defensivens": "defensiv",
    "defensives": "defensiv",
    "defensivs": "defensiv",
    "defensivt": "defensiv",
    "defensivts": "defensiv",
    "deficiten": "deficit",
    "deficitens": "deficit",
    "deficitet": "deficit",
    "deficitets": "deficit",
    "deficits": "deficit",
    "defilerad": "defilera",
    "defilerade": "defilera",
    "defilerades": "defilera",
    "defilerads": "defilera",
    "defilerande": "defilera",
    "defileranden": "defilerande",
    "defilerandena": "defilerande",
    "defilerandenas": "defilerande",
    "defilerandens": "defilerande",
    "defilerandes": "defilerande",
    "defilerandet": "defilerande",
    "defilerandets": "defilerande",
    "defilerar": "defilera",
    "defileras": "defilera",
    "defilerat": "defilera",
    "defilerats": "defilera",
    "defilerbara": "defilerbar",
    "defilerbarare": "defilerbar",
    "defilerbarares": "defilerbar",
    "defilerbaras": "defilerbar",
    "defilerbarast": "defilerbar",
    "defilerbaraste": "defilerbar",
    "defilerbarastes": "defilerbar",
    "defilerbarasts": "defilerbar",
    "defilerbare": "defilerbar",
    "defilerbares": "defilerbar",
    "defilerbarheten": "defilerbarhet",
    "defilerbarhetens": "defilerbarhet",
    "defilerbarhets": "defilerbarhet",
    "defilerbars": "defilerbar",
    "defilerbart": "defilerbar",
    "defilerbarts": "defilerbar",
    "defileringar": "defilering",
    "defileringarna": "defilering",
    "defileringarnas": "defilering",
    "defileringars": "defilering",
    "defileringen": "defilering",
    "defileringens": "defilering",
    "defilerings": "defilering",
    "defiléer": "defilé",
    "defiléerna": "defilé",
    "defiléernas": "defilé",
    "defiléers": "defilé",
    "defilén": "defilé",
    "defiléns": "defilé",
    "defilés": "defilé",
    "definierad": "definiera",
    "definierade": "definiera",
    "definierades": "definiera",
    "definierads": "definiera",
    "definierande": "definiera",
    "definieranden": "definierande",
    "definierandena": "definierande",
    "definierandenas": "definierande",
    "definierandens": "definierande",
    "definierandes": "definierande",
    "definierandet": "definierande",
    "definierandets": "definierande",
    "definierar": "definiera",
    "definieras": "definiera",
    "definierat": "definiera",
    "definierats": "definiera",
    "definierbara": "definierbar",
    "definierbarare": "definierbar",
    "definierbarares": "definierbar",
    "definierbaras": "definierbar",
    "definierbarast": "definierbar",
    "definierbaraste": "definierbar",
    "definierbarastes": "definierbar",
    "definierbarasts": "definierbar",
    "definierbare": "definierbar",
    "definierbares": "definierbar",
    "definierbarheten": "definierbarhet",
    "definierbarhetens": "definierbarhet",
    "definierbarhets": "definierbarhet",
    "definierbars": "definierbar",
    "definierbart": "definierbar",
    "definierbarts": "definierbar",
    "definieringar": "definiering",
    "definieringarna": "definiering",
    "definieringarnas": "definiering",
    "definieringars": "definiering",
    "definieringen": "definiering",
    "definieringens": "definiering",
    "definierings": "definiering",
    "definita": "definit",
    "definitare": "definit",
    "definitares": "definit",
    "definitas": "definit",
    "definitast": "definit",
    "definitaste": "definit",
    "definitastes": "definit",
    "definitasts": "definit",
    "definite": "definit",
    "definites": "definit",
    "definitheten": "definithet",
    "definithetens": "definithet",
    "definithets": "definithet",
    "definitionen": "definition",
    "definitionens": "definition",
    "definitioner": "definition",
    "definitionerna": "definition",
    "definitionernas": "definition",
    "definitioners": "definition",
    "definitions": "definition",
    "definitionsmängden": "definitionsmängd",
    "definitionsmängdens": "definitionsmängd",
    "definitionsmängder": "definitionsmängd",
    "definitionsmängderna": "definitionsmängd",
    "definitionsmängdernas": "definitionsmängd",
    "definitionsmängders": "definitionsmängd",
    "definitionsmängds": "definitionsmängd",
    "definitionsmässiga": "definitionsmässig",
    "definitionsmässigare": "definitionsmässig",
    "definitionsmässigares": "definitionsmässig",
    "definitionsmässigas": "definitionsmässig",
    "definitionsmässigast": "definitionsmässig",
    "definitionsmässigaste": "definitionsmässig",
    "definitionsmässigastes": "definitionsmässig",
    "definitionsmässigasts": "definitionsmässig",
    "definitionsmässige": "definitionsmässig",
    "definitionsmässiges": "definitionsmässig",
    "definitionsmässigheten": "definitionsmässighet",
    "definitionsmässighetens": "definitionsmässighet",
    "definitionsmässighets": "definitionsmässighet",
    "definitionsmässigs": "definitionsmässig",
    "definitionsmässigt": "definitionsmässig",
    "definitionsmässigts": "definitionsmässig",
    "definitiva": "definitiv",
    "definitivare": "definitiv",
    "definitivares": "definitiv",
    "definitivas": "definitiv",
    "definitivast": "definitiv",
    "definitivaste": "definitiv",
    "definitivastes": "definitiv",
    "definitivasts": "definitiv",
    "definitive": "definitiv",
    "definitives": "definitiv",
    "definitivs": "definitiv",
    "definitivt": "definitiv",
    "definitivts": "definitiv",
    "definits": "definit",
    "deflagrationen": "deflagration",
    "deflagrationens": "deflagration",
    "deflagrationer": "deflagration",
    "deflagrationerna": "deflagration",
    "deflagrationernas": "deflagration",
    "deflagrationers": "deflagration",
    "deflagrations": "deflagration",
    "deflationen": "deflation",
    "deflationens": "deflation",
    "deflationer": "deflation",
    "deflationerna": "deflation",
    "deflationernas": "deflation",
    "deflationers": "deflation",
    "deflations": "deflation",
    "deflorationen": "defloration",
    "deflorationens": "defloration",
    "deflorationer": "defloration",
    "deflorationerna": "defloration",
    "deflorationernas": "defloration",
    "deflorationers": "defloration",
    "deflorations": "defloration",
    "deflorerad": "deflorera",
    "deflorerade": "deflorera",
    "deflorerades": "deflorera",
    "deflorerads": "deflorera",
    "deflorerande": "deflorera",
    "defloreranden": "deflorerande",
    "deflorerandena": "deflorerande",
    "deflorerandenas": "deflorerande",
    "deflorerandens": "deflorerande",
    "deflorerandes": "deflorerande",
    "deflorerandet": "deflorerande",
    "deflorerandets": "deflorerande",
    "deflorerar": "deflorera",
    "defloreras": "deflorera",
    "deflorerat": "deflorera",
    "deflorerats": "deflorera",
    "deflorerbara": "deflorerbar",
    "deflorerbarare": "deflorerbar",
    "deflorerbarares": "deflorerbar",
    "deflorerbaras": "deflorerbar",
    "deflorerbarast": "deflorerbar",
    "deflorerbaraste": "deflorerbar",
    "deflorerbarastes": "deflorerbar",
    "deflorerbarasts": "deflorerbar",
    "deflorerbare": "deflorerbar",
    "deflorerbares": "deflorerbar",
    "deflorerbarheten": "deflorerbarhet",
    "deflorerbarhetens": "deflorerbarhet",
    "deflorerbarhets": "deflorerbarhet",
    "deflorerbars": "deflorerbar",
    "deflorerbart": "deflorerbar",
    "deflorerbarts": "deflorerbar",
    "defloreringar": "deflorering",
    "defloreringarna": "deflorering",
    "defloreringarnas": "deflorering",
    "defloreringars": "deflorering",
    "defloreringen": "deflorering",
    "defloreringens": "deflorering",
    "deflorerings": "deflorering",
    "deformationen": "deformation",
    "deformationens": "deformation",
    "deformationer": "deformation",
    "deformationerna": "deformation",
    "deformationernas": "deformation",
    "deformationers": "deformation",
    "deformations": "deformation",
    "deformerad": "deformera",
    "deformerade": "deformera",
    "deformerades": "deformera",
    "deformerads": "deformera",
    "deformerande": "deformera",
    "deformeranden": "deformerande",
    "deformerandena": "deformerande",
    "deformerandenas": "deformerande",
    "deformerandens": "deformerande",
    "deformerandes": "deformerande",
    "deformerandet": "deformerande",
    "deformerandets": "deformerande",
    "deformerar": "deformera",
    "deformeras": "deformera",
    "deformerat": "deformera",
    "deformerats": "deformera",
    "deformerbara": "deformerbar",
    "deformerbarare": "deformerbar",
    "deformerbarares": "deformerbar",
    "deformerbaras": "deformerbar",
    "deformerbarast": "deformerbar",
    "deformerbaraste": "deformerbar",
    "deformerbarastes": "deformerbar",
    "deformerbarasts": "deformerbar",
    "deformerbare": "deformerbar",
    "deformerbares": "deformerbar",
    "deformerbarheten": "deformerbarhet",
    "deformerbarhetens": "deformerbarhet",
    "deformerbarhets": "deformerbarhet",
    "deformerbars": "deformerbar",
    "deformerbart": "deformerbar",
    "deformerbarts": "deformerbar",
    "deformeringar": "deformering",
    "deformeringarna": "deformering",
    "deformeringarnas": "deformering",
    "deformeringars": "deformering",
    "deformeringen": "deformering",
    "deformeringens": "deformering",
    "deformerings": "deformering",
    "deformiteten": "deformitet",
    "deformitetens": "deformitet",
    "deformiteter": "deformitet",
    "deformiteterna": "deformitet",
    "deformiteternas": "deformitet",
    "deformiteters": "deformitet",
    "deformitets": "deformitet",
    "defrostern": "defroster",
    "defrosterna": "defroster",
    "defrosternas": "defroster",
    "defrosterns": "defroster",
    "defrosters": "defroster",
    "defrostrar": "defroster",
    "defrostrarna": "defroster",
    "defrostrarnas": "defroster",
    "defrostrars": "defroster",
    "degade": "dega",
    "degades": "dega",
    "degande": "dega",
    "deganden": "degande",
    "degandena": "degande",
    "degandenas": "degande",
    "degandens": "degande",
    "degandes": "degande",
    "degandet": "degande",
    "degandets": "degande",
    "degar": "dega",
    "degarna": "deg",
    "degarnas": "deg",
    "degars": "deg",
    "degas": "dega",
    "degat": "dega",
    "degats": "dega",
    "degeln": "degel",
    "degelns": "degel",
    "degels": "degel",
    "degen": "deg",
    "degenerationen": "degeneration",
    "degenerationens": "degeneration",
    "degenerationer": "degeneration",
    "degenerationerna": "degeneration",
    "degenerationernas": "degeneration",
    "degenerationers": "degeneration",
    "degenerations": "degeneration",
    "degenerativa": "degenerativ",
    "degenerativare": "degenerativ",
    "degenerativares": "degenerativ",
    "degenerativas": "degenerativ",
    "degenerativast": "degenerativ",
    "degenerativaste": "degenerativ",
    "degenerativastes": "degenerativ",
    "degenerativasts": "degenerativ",
    "degenerative": "degenerativ",
    "degeneratives": "degenerativ",
    "degenerativs": "degenerativ",
    "degenerativt": "degenerativ",
    "degenerativts": "degenerativ",
    "degenererad": "degenerera",
    "degenererade": "degenerera",
    "degenererades": "degenerera",
    "degenererads": "degenerera",
    "degenererande": "degenerera",
    "degenereranden": "degenererande",
    "degenererandena": "degenererande",
    "degenererandenas": "degenererande",
    "degenererandens": "degenererande",
    "degenererandes": "degenererande",
    "degenererandet": "degenererande",
    "degenererandets": "degenererande",
    "degenererar": "degenerera",
    "degenereras": "degenerera",
    "degenererat": "degenerera",
    "degenererats": "degenerera",
    "degenererbara": "degenererbar",
    "degenererbarare": "degenererbar",
    "degenererbarares": "degenererbar",
    "degenererbaras": "degenererbar",
    "degenererbarast": "degenererbar",
    "degenererbaraste": "degenererbar",
    "degenererbarastes": "degenererbar",
    "degenererbarasts": "degenererbar",
    "degenererbare": "degenererbar",
    "degenererbares": "degenererbar",
    "degenererbarheten": "degenererbarhet",
    "degenererbarhetens": "degenererbarhet",
    "degenererbarhets": "degenererbarhet",
    "degenererbars": "degenererbar",
    "degenererbart": "degenererbar",
    "degenererbarts": "degenererbar",
    "degenereringar": "degenerering",
    "degenereringarna": "degenerering",
    "degenereringarnas": "degenerering",
    "degenereringars": "degenerering",
    "degenereringen": "degenerering",
    "degenereringens": "degenerering",
    "degenererings": "degenerering",
    "degens": "deg",
    "degiga": "degig",
    "degigare": "degig",
    "degigares": "degig",
    "degigas": "degig",
    "degigast": "degig",
    "degigaste": "degig",
    "degigastes": "degig",
    "degigasts": "degig",
    "degige": "degig",
    "degiges": "degig",
    "degigs": "degig",
    "degigt": "degig",
    "degigts": "degig",
    "deglaciationen": "deglaciation",
    "deglaciationens": "deglaciation",
    "deglaciationer": "deglaciation",
    "deglaciationerna": "deglaciation",
    "deglaciationernas": "deglaciation",
    "deglaciationers": "deglaciation",
    "deglaciations": "deglaciation",
    "deglar": "degel",
    "deglarna": "degel",
    "deglarnas": "degel",
    "deglars": "degel",
    "degon": "dego",
    "degons": "dego",
    "degos": "dego",
    "degosarna": "dego",
    "degosarnas": "dego",
    "degosen": "dego",
    "degosens": "dego",
    "degradationen": "degradation",
    "degradationens": "degradation",
    "degradationer": "degradation",
    "degradationerna": "degradation",
    "degradationernas": "degradation",
    "degradationers": "degradation",
    "degradations": "degradation",
    "degraderad": "degradera",
    "degraderade": "degradera",
    "degraderades": "degradera",
    "degraderads": "degradera",
    "degraderande": "degradera",
    "degraderanden": "degraderande",
    "degraderandena": "degraderande",
    "degraderandenas": "degraderande",
    "degraderandens": "degraderande",
    "degraderandes": "degraderande",
    "degraderandet": "degraderande",
    "degraderandets": "degraderande",
    "degraderar": "degradera",
    "degraderas": "degradera",
    "degraderat": "degradera",
    "degraderats": "degradera",
    "degraderbara": "degraderbar",
    "degraderbarare": "degraderbar",
    "degraderbarares": "degraderbar",
    "degraderbaras": "degraderbar",
    "degraderbarast": "degraderbar",
    "degraderbaraste": "degraderbar",
    "degraderbarastes": "degraderbar",
    "degraderbarasts": "degraderbar",
    "degraderbare": "degraderbar",
    "degraderbares": "degraderbar",
    "degraderbarheten": "degraderbarhet",
    "degraderbarhetens": "degraderbarhet",
    "degraderbarhets": "degraderbarhet",
    "degraderbars": "degraderbar",
    "degraderbart": "degraderbar",
    "degraderbarts": "degraderbar",
    "degraderingar": "degradering",
    "degraderingarna": "degradering",
    "degraderingarnas": "degradering",
    "degraderingars": "degradering",
    "degraderingen": "degradering",
    "degraderingens": "degradering",
    "degraderings": "degradering",
    "degranden": "degrand",
    "degrandens": "degrand",
    "degrands": "degrand",
    "degressionen": "degression",
    "degressionens": "degression",
    "degressioner": "degression",
    "degressionerna": "degression",
    "degressionernas": "degression",
    "degressioners": "degression",
    "degressions": "degression",
    "degränder": "degrand",
    "degränderna": "degrand",
    "degrändernas": "degrand",
    "degränders": "degrand",
    "degs": "deg",
    "deiktiska": "deiktisk",
    "deiktiskare": "deiktisk",
    "deiktiskares": "deiktisk",
    "deiktiskas": "deiktisk",
    "deiktiskast": "deiktisk",
    "deiktiskaste": "deiktisk",
    "deiktiskastes": "deiktisk",
    "deiktiskasts": "deiktisk",
    "deiktiske": "deiktisk",
    "deiktiskes": "deiktisk",
    "deiktisks": "deiktisk",
    "deiktiskt": "deiktisk",
    "deiktiskts": "deiktisk",
    "deismen": "deism",
    "deismens": "deism",
    "deismer": "deism",
    "deismerna": "deism",
    "deismernas": "deism",
    "deismers": "deism",
    "deisms": "deism",
    "deisten": "deist",
    "deistens": "deist",
    "deister": "deist",
    "deisterna": "deist",
    "deisternas": "deist",
    "deisters": "deist",
    "deistiska": "deistisk",
    "deistiskare": "deistisk",
    "deistiskares": "deistisk",
    "deistiskas": "deistisk",
    "deistiskast": "deistisk",
    "deistiskaste": "deistisk",
    "deistiskastes": "deistisk",
    "deistiskasts": "deistisk",
    "deistiske": "deistisk",
    "deistiskes": "deistisk",
    "deistisks": "deistisk",
    "deistiskt": "deistisk",
    "deistiskts": "deistisk",
    "deists": "deist",
    "dej": "du",
    "dejan": "deja",
    "dejans": "deja",
    "dejas": "deja",
    "deje": "deja",
    "dejliga": "dejlig",
    "dejligare": "dejlig",
    "dejligares": "dejlig",
    "dejligas": "dejlig",
    "dejligast": "dejlig",
    "dejligaste": "dejlig",
    "dejligastes": "dejlig",
    "dejligasts": "dejlig",
    "dejlige": "dejlig",
    "dejliges": "dejlig",
    "dejligheten": "dejlighet",
    "dejlighetens": "dejlighet",
    "dejlighets": "dejlighet",
    "dejligs": "dejlig",
    "dejligt": "dejlig",
    "dejligts": "dejlig",
    "dejor": "deja",
    "dejorna": "deja",
    "dejornas": "deja",
    "dejors": "deja",
    "dejs": "dejsa",
    "dejsade": "dejsa",
    "dejsades": "dejsa",
    "dejsande": "dejsa",
    "dejsanden": "dejsande",
    "dejsandena": "dejsande",
    "dejsandenas": "dejsande",
    "dejsandens": "dejsande",
    "dejsandes": "dejsande",
    "dejsandet": "dejsande",
    "dejsandets": "dejsande",
    "dejsar": "dejsa",
    "dejsas": "dejsa",
    "dejsat": "dejsa",
    "dejsats": "dejsa",
    "dejt": "dejta",
    "dejtad": "dejta",
    "dejtade": "dejta",
    "dejtades": "dejta",
    "dejtads": "dejta",
    "dejtande": "dejta",
    "dejtanden": "dejtande",
    "dejtandena": "dejtande",
    "dejtandenas": "dejtande",
    "dejtandens": "dejtande",
    "dejtandes": "dejtande",
    "dejtandet": "dejtande",
    "dejtandets": "dejtande",
    "dejtar": "dejta",
    "dejtarna": "dejt",
    "dejtarnas": "dejt",
    "dejtars": "dejt",
    "dejtas": "dejta",
    "dejtat": "dejta",
    "dejtats": "dejta",
    "dejten": "dejt",
    "dejtens": "dejt",
    "dejter": "dejt",
    "dejterna": "dejt",
    "dejternas": "dejt",
    "dejters": "dejt",
    "dejtingen": "dejting",
    "dejtingens": "dejting",
    "dejtings": "dejting",
    "dejtingsajten": "dejtingsajt",
    "dejtingsajtens": "dejtingsajt",
    "dejtingsajter": "dejtingsajt",
    "dejtingsajterna": "dejtingsajt",
    "dejtingsajternas": "dejtingsajt",
    "dejtingsajters": "dejtingsajt",
    "dejtingsajts": "dejtingsajt",
    "dejtingtipsen": "dejtingtips",
    "dejtingtipsens": "dejtingtips",
    "dejtingtipset": "dejtingtips",
    "dejtingtipsets": "dejtingtips",
    "dejts": "dejt",
    "dekadansen": "dekadans",
    "dekadansens": "dekadans",
    "dekaden": "dekad",
    "dekadens": "dekad",
    "dekadensen": "dekadens",
    "dekadensens": "dekadens",
    "dekadenta": "dekadent",
    "dekadentare": "dekadent",
    "dekadentares": "dekadent",
    "dekadentas": "dekadent",
    "dekadentast": "dekadent",
    "dekadentaste": "dekadent",
    "dekadentastes": "dekadent",
    "dekadentasts": "dekadent",
    "dekadente": "dekadent",
    "dekadentes": "dekadent",
    "dekadents": "dekadent",
    "dekader": "dekad",
    "dekaderna": "dekad",
    "dekadernas": "dekad",
    "dekaders": "dekad",
    "dekadiska": "dekadisk",
    "dekadiskare": "dekadisk",
    "dekadiskares": "dekadisk",
    "dekadiskas": "dekadisk",
    "dekadiskast": "dekadisk",
    "dekadiskaste": "dekadisk",
    "dekadiskastes": "dekadisk",
    "dekadiskasts": "dekadisk",
    "dekadiske": "dekadisk",
    "dekadiskes": "dekadisk",
    "dekadisks": "dekadisk",
    "dekadiskt": "dekadisk",
    "dekadiskts": "dekadisk",
    "dekads": "dekad",
    "dekalen": "dekal",
    "dekalens": "dekal",
    "dekaler": "dekal",
    "dekalerna": "dekal",
    "dekalernas": "dekal",
    "dekalers": "dekal",
    "dekalkomanien": "dekalkomani",
    "dekalkomaniens": "dekalkomani",
    "dekalkomanin": "dekalkomani",
    "dekalkomanins": "dekalkomani",
    "dekalkomanis": "dekalkomani",
    "dekalogen": "dekalog",
    "dekalogens": "dekalog",
    "dekalogs": "dekalog",
    "dekals": "dekal",
    "dekanen": "dekan",
    "dekanens": "dekan",
    "dekaner": "dekan",
    "dekanerna": "dekan",
    "dekanernas": "dekan",
    "dekaners": "dekan",
    "dekans": "dekan",
    "dekanterad": "dekantera",
    "dekanterade": "dekantera",
    "dekanterades": "dekantera",
    "dekanterads": "dekantera",
    "dekanterande": "dekantera",
    "dekanteranden": "dekanterande",
    "dekanterandena": "dekanterande",
    "dekanterandenas": "dekanterande",
    "dekanterandens": "dekanterande",
    "dekanterandes": "dekanterande",
    "dekanterandet": "dekanterande",
    "dekanterandets": "dekanterande",
    "dekanterar": "dekantera",
    "dekanteras": "dekantera",
    "dekanterat": "dekantera",
    "dekanterats": "dekantera",
    "dekanterbara": "dekanterbar",
    "dekanterbarare": "dekanterbar",
    "dekanterbarares": "dekanterbar",
    "dekanterbaras": "dekanterbar",
    "dekanterbarast": "dekanterbar",
    "dekanterbaraste": "dekanterbar",
    "dekanterbarastes": "dekanterbar",
    "dekanterbarasts": "dekanterbar",
    "dekanterbare": "dekanterbar",
    "dekanterbares": "dekanterbar",
    "dekanterbarheten": "dekanterbarhet",
    "dekanterbarhetens": "dekanterbarhet",
    "dekanterbarhets": "dekanterbarhet",
    "dekanterbars": "dekanterbar",
    "dekanterbart": "dekanterbar",
    "dekanterbarts": "dekanterbar",
    "dekanteringar": "dekantering",
    "dekanteringarna": "dekantering",
    "dekanteringarnas": "dekantering",
    "dekanteringars": "dekantering",
    "dekanteringen": "dekantering",
    "dekanteringens": "dekantering",
    "dekanterings": "dekantering",
    "dekapiterad": "dekapitera",
    "dekapiterade": "dekapitera",
    "dekapiterades": "dekapitera",
    "dekapiterads": "dekapitera",
    "dekapiterande": "dekapitera",
    "dekapiteranden": "dekapiterande",
    "dekapiterandena": "dekapiterande",
    "dekapiterandenas": "dekapiterande",
    "dekapiterandens": "dekapiterande",
    "dekapiterandes": "dekapiterande",
    "dekapiterandet": "dekapiterande",
    "dekapiterandets": "dekapiterande",
    "dekapiterar": "dekapitera",
    "dekapiteras": "dekapitera",
    "dekapiterat": "dekapitera",
    "dekapiterats": "dekapitera",
    "dekapiterbara": "dekapiterbar",
    "dekapiterbarare": "dekapiterbar",
    "dekapiterbarares": "dekapiterbar",
    "dekapiterbaras": "dekapiterbar",
    "dekapiterbarast": "dekapiterbar",
    "dekapiterbaraste": "dekapiterbar",
    "dekapiterbarastes": "dekapiterbar",
    "dekapiterbarasts": "dekapiterbar",
    "dekapiterbare": "dekapiterbar",
    "dekapiterbares": "dekapiterbar",
    "dekapiterbarheten": "dekapiterbarhet",
    "dekapiterbarhetens": "dekapiterbarhet",
    "dekapiterbarhets": "dekapiterbarhet",
    "dekapiterbars": "dekapiterbar",
    "dekapiterbart": "dekapiterbar",
    "dekapiterbarts": "dekapiterbar",
    "dekapiteringar": "dekapitering",
    "dekapiteringarna": "dekapitering",
    "dekapiteringarnas": "dekapitering",
    "dekapiteringars": "dekapitering",
    "dekapiteringen": "dekapitering",
    "dekapiteringens": "dekapitering",
    "dekapiterings": "dekapitering",
    "deklamationen": "deklamation",
    "deklamationens": "deklamation",
    "deklamationer": "deklamation",
    "deklamationerna": "deklamation",
    "deklamationernas": "deklamation",
    "deklamationers": "deklamation",
    "deklamations": "deklamation",
    "deklamatoriska": "deklamatorisk",
    "deklamatoriskare": "deklamatorisk",
    "deklamatoriskares": "deklamatorisk",
    "deklamatoriskas": "deklamatorisk",
    "deklamatoriskast": "deklamatorisk",
    "deklamatoriskaste": "deklamatorisk",
    "deklamatoriskastes": "deklamatorisk",
    "deklamatoriskasts": "deklamatorisk",
    "deklamatoriske": "deklamatorisk",
    "deklamatoriskes": "deklamatorisk",
    "deklamatorisks": "deklamatorisk",
    "deklamatoriskt": "deklamatorisk",
    "deklamatoriskts": "deklamatorisk",
    "deklamatören": "deklamatör",
    "deklamatörens": "deklamatör",
    "deklamatörer": "deklamatör",
    "deklamatörerna": "deklamatör",
    "deklamatörernas": "deklamatör",
    "deklamatörers": "deklamatör",
    "deklamatörs": "deklamatör",
    "deklamerad": "deklamera",
    "deklamerade": "deklamera",
    "deklamerades": "deklamera",
    "deklamerads": "deklamera",
    "deklamerande": "deklamera",
    "deklameranden": "deklamerande",
    "deklamerandena": "deklamerande",
    "deklamerandenas": "deklamerande",
    "deklamerandens": "deklamerande",
    "deklamerandes": "deklamerande",
    "deklamerandet": "deklamerande",
    "deklamerandets": "deklamerande",
    "deklamerar": "deklamera",
    "deklameras": "deklamera",
    "deklamerat": "deklamera",
    "deklamerats": "deklamera",
    "deklamerbara": "deklamerbar",
    "deklamerbarare": "deklamerbar",
    "deklamerbarares": "deklamerbar",
    "deklamerbaras": "deklamerbar",
    "deklamerbarast": "deklamerbar",
    "deklamerbaraste": "deklamerbar",
    "deklamerbarastes": "deklamerbar",
    "deklamerbarasts": "deklamerbar",
    "deklamerbare": "deklamerbar",
    "deklamerbares": "deklamerbar",
    "deklamerbarheten": "deklamerbarhet",
    "deklamerbarhetens": "deklamerbarhet",
    "deklamerbarhets": "deklamerbarhet",
    "deklamerbars": "deklamerbar",
    "deklamerbart": "deklamerbar",
    "deklamerbarts": "deklamerbar",
    "deklameringar": "deklamering",
    "deklameringarna": "deklamering",
    "deklameringarnas": "deklamering",
    "deklameringars": "deklamering",
    "deklameringen": "deklamering",
    "deklameringens": "deklamering",
    "deklamerings": "deklamering",
    "deklaranten": "deklarant",
    "deklarantens": "deklarant",
    "deklaranter": "deklarant",
    "deklaranterna": "deklarant",
    "deklaranternas": "deklarant",
    "deklaranters": "deklarant",
    "deklarants": "deklarant",
    "deklarationen": "deklaration",
    "deklarationens": "deklaration",
    "deklarationer": "deklaration",
    "deklarationerna": "deklaration",
    "deklarationernas": "deklaration",
    "deklarationers": "deklaration",
    "deklarations": "deklaration",
    "deklarationsblanketten": "deklarationsblankett",
    "deklarationsblankettens": "deklarationsblankett",
    "deklarationsblanketter": "deklarationsblankett",
    "deklarationsblanketterna": "deklarationsblankett",
    "deklarationsblanketternas": "deklarationsblankett",
    "deklarationsblanketters": "deklarationsblankett",
    "deklarationsblanketts": "deklarationsblankett",
    "deklarerad": "deklarera",
    "deklarerade": "deklarera",
    "deklarerades": "deklarera",
    "deklarerads": "deklarera",
    "deklarerande": "deklarera",
    "deklareranden": "deklarerande",
    "deklarerandena": "deklarerande",
    "deklarerandenas": "deklarerande",
    "deklarerandens": "deklarerande",
    "deklarerandes": "deklarerande",
    "deklarerandet": "deklarerande",
    "deklarerandets": "deklarerande",
    "deklarerar": "deklarera",
    "deklareras": "deklarera",
    "deklarerat": "deklarera",
    "deklarerats": "deklarera",
    "deklarerbara": "deklarerbar",
    "deklarerbarare": "deklarerbar",
    "deklarerbarares": "deklarerbar",
    "deklarerbaras": "deklarerbar",
    "deklarerbarast": "deklarerbar",
    "deklarerbaraste": "deklarerbar",
    "deklarerbarastes": "deklarerbar",
    "deklarerbarasts": "deklarerbar",
    "deklarerbare": "deklarerbar",
    "deklarerbares": "deklarerbar",
    "deklarerbarheten": "deklarerbarhet",
    "deklarerbarhetens": "deklarerbarhet",
    "deklarerbarhets": "deklarerbarhet",
    "deklarerbars": "deklarerbar",
    "deklarerbart": "deklarerbar",
    "deklarerbarts": "deklarerbar",
    "deklareringar": "deklarering",
    "deklareringarna": "deklarering",
    "deklareringarnas": "deklarering",
    "deklareringars": "deklarering",
    "deklareringen": "deklarering",
    "deklareringens": "deklarering",
    "deklarerings": "deklarering",
    "deklasserad": "deklassera",
    "deklasserade": "deklassera",
    "deklasserades": "deklassera",
    "deklasserads": "deklassera",
    "deklasserande": "deklassera",
    "deklasseranden": "deklasserande",
    "deklasserandena": "deklasserande",
    "deklasserandenas": "deklasserande",
    "deklasserandens": "deklasserande",
    "deklasserandes": "deklasserande",
    "deklasserandet": "deklasserande",
    "deklasserandets": "deklasserande",
    "deklasserar": "deklassera",
    "deklasseras": "deklassera",
    "deklasserat": "deklassera",
    "deklasserats": "deklassera",
    "deklasserbara": "deklasserbar",
    "deklasserbarare": "deklasserbar",
    "deklasserbarares": "deklasserbar",
    "deklasserbaras": "deklasserbar",
    "deklasserbarast": "deklasserbar",
    "deklasserbaraste": "deklasserbar",
    "deklasserbarastes": "deklasserbar",
    "deklasserbarasts": "deklasserbar",
    "deklasserbare": "deklasserbar",
    "deklasserbares": "deklasserbar",
    "deklasserbarheten": "deklasserbarhet",
    "deklasserbarhetens": "deklasserbarhet",
    "deklasserbarhets": "deklasserbarhet",
    "deklasserbars": "deklasserbar",
    "deklasserbart": "deklasserbar",
    "deklasserbarts": "deklasserbar",
    "deklasseringar": "deklassering",
    "deklasseringarna": "deklassering",
    "deklasseringarnas": "deklassering",
    "deklasseringars": "deklassering",
    "deklasseringen": "deklassering",
    "deklasseringens": "deklassering",
    "deklasserings": "deklassering",
    "deklinationen": "deklination",
    "deklinationens": "deklination",
    "deklinationer": "deklination",
    "deklinationerna": "deklination",
    "deklinationernas": "deklination",
    "deklinationers": "deklination",
    "deklinations": "deklination",
    "deklinationsnålar": "deklinationsnål",
    "deklinationsnålarna": "deklinationsnål",
    "deklinationsnålarnas": "deklinationsnål",
    "deklinationsnålars": "deklinationsnål",
    "deklinationsnålen": "deklinationsnål",
    "deklinationsnålens": "deklinationsnål",
    "deklinationsnåls": "deklinationsnål",
    "deklinerad": "deklinera",
    "deklinerade": "deklinera",
    "deklinerades": "deklinera",
    "deklinerads": "deklinera",
    "deklinerande": "deklinera",
    "deklineranden": "deklinerande",
    "deklinerandena": "deklinerande",
    "deklinerandenas": "deklinerande",
    "deklinerandens": "deklinerande",
    "deklinerandes": "deklinerande",
    "deklinerandet": "deklinerande",
    "deklinerandets": "deklinerande",
    "deklinerar": "deklinera",
    "deklineras": "deklinera",
    "deklinerat": "deklinera",
    "deklinerats": "deklinera",
    "deklinerbara": "deklinerbar",
    "deklinerbarare": "deklinerbar",
    "deklinerbarares": "deklinerbar",
    "deklinerbaras": "deklinerbar",
    "deklinerbarast": "deklinerbar",
    "deklinerbaraste": "deklinerbar",
    "deklinerbarastes": "deklinerbar",
    "deklinerbarasts": "deklinerbar",
    "deklinerbare": "deklinerbar",
    "deklinerbares": "deklinerbar",
    "deklinerbarheten": "deklinerbarhet",
    "deklinerbarhetens": "deklinerbarhet",
    "deklinerbarhets": "deklinerbarhet",
    "deklinerbars": "deklinerbar",
    "deklinerbart": "deklinerbar",
    "deklinerbarts": "deklinerbar",
    "deklineringar": "deklinering",
    "deklineringarna": "deklinering",
    "deklineringarnas": "deklinering",
    "deklineringars": "deklinering",
    "deklineringen": "deklinering",
    "deklineringens": "deklinering",
    "deklinerings": "deklinering",
    "dekokten": "dekokt",
    "dekoktens": "dekokt",
    "dekokter": "dekokt",
    "dekokterna": "dekokt",
    "dekokternas": "dekokt",
    "dekokters": "dekokt",
    "dekokts": "dekokt",
    "dekolletagen": "dekolletage",
    "dekolletagens": "dekolletage",
    "dekolletages": "dekolletage",
    "dekolletaget": "dekolletage",
    "dekolletagets": "dekolletage",
    "dekolleterade": "dekolleterad",
    "dekolleterades": "dekolleterad",
    "dekolleterads": "dekolleterad",
    "dekolleterat": "dekolleterad",
    "dekolleterats": "dekolleterad",
    "dekolleteringar": "dekolletering",
    "dekolleteringarna": "dekolletering",
    "dekolleteringarnas": "dekolletering",
    "dekolleteringars": "dekolletering",
    "dekolleteringen": "dekolletering",
    "dekolleteringens": "dekolletering",
    "dekolleterings": "dekolletering",
    "dekorationen": "dekoration",
    "dekorationens": "dekoration",
    "dekorationer": "dekoration",
    "dekorationerna": "dekoration",
    "dekorationernas": "dekoration",
    "dekorationers": "dekoration",
    "dekorations": "dekoration",
    "dekorationsbras": "dekorationsbrasa",
    "dekorationsbrasan": "dekorationsbrasa",
    "dekorationsbrasans": "dekorationsbrasa",
    "dekorationsbrasas": "dekorationsbrasa",
    "dekorationsbrase": "dekorationsbrasa",
    "dekorationsbrasor": "dekorationsbrasa",
    "dekorationsbrasorna": "dekorationsbrasa",
    "dekorationsbrasornas": "dekorationsbrasa",
    "dekorationsbrasors": "dekorationsbrasa",
    "dekorationsgranar": "dekorationsgran",
    "dekorationsgranarna": "dekorationsgran",
    "dekorationsgranarnas": "dekorationsgran",
    "dekorationsgranars": "dekorationsgran",
    "dekorationsgranen": "dekorationsgran",
    "dekorationsgranens": "dekorationsgran",
    "dekorationsgrans": "dekorationsgran",
    "dekorationslisten": "dekorationslist",
    "dekorationslistens": "dekorationslist",
    "dekorationslister": "dekorationslist",
    "dekorationslisterna": "dekorationslist",
    "dekorationslisternas": "dekorationslist",
    "dekorationslisters": "dekorationslist",
    "dekorationslists": "dekorationslist",
    "dekorativa": "dekorativ",
    "dekorativare": "dekorativ",
    "dekorativares": "dekorativ",
    "dekorativas": "dekorativ",
    "dekorativast": "dekorativ",
    "dekorativaste": "dekorativ",
    "dekorativastes": "dekorativ",
    "dekorativasts": "dekorativ",
    "dekorative": "dekorativ",
    "dekoratives": "dekorativ",
    "dekorativs": "dekorativ",
    "dekorativt": "dekorativ",
    "dekorativts": "dekorativ",
    "dekoratören": "dekoratör",
    "dekoratörens": "dekoratör",
    "dekoratörer": "dekoratör",
    "dekoratörerna": "dekoratör",
    "dekoratörernas": "dekoratör",
    "dekoratörers": "dekoratör",
    "dekoratörs": "dekoratör",
    "dekoren": "dekor",
    "dekorens": "dekor",
    "dekorer": "dekor",
    "dekorerad": "dekorera",
    "dekorerade": "dekorera",
    "dekorerades": "dekorera",
    "dekorerads": "dekorera",
    "dekorerande": "dekorera",
    "dekoreranden": "dekorerande",
    "dekorerandena": "dekorerande",
    "dekorerandenas": "dekorerande",
    "dekorerandens": "dekorerande",
    "dekorerandes": "dekorerande",
    "dekorerandet": "dekorerande",
    "dekorerandets": "dekorerande",
    "dekorerar": "dekorera",
    "dekoreras": "dekorera",
    "dekorerat": "dekorera",
    "dekorerats": "dekorera",
    "dekorerbara": "dekorerbar",
    "dekorerbarare": "dekorerbar",
    "dekorerbarares": "dekorerbar",
    "dekorerbaras": "dekorerbar",
    "dekorerbarast": "dekorerbar",
    "dekorerbaraste": "dekorerbar",
    "dekorerbarastes": "dekorerbar",
    "dekorerbarasts": "dekorerbar",
    "dekorerbare": "dekorerbar",
    "dekorerbares": "dekorerbar",
    "dekorerbarheten": "dekorerbarhet",
    "dekorerbarhetens": "dekorerbarhet",
    "dekorerbarhets": "dekorerbarhet",
    "dekorerbars": "dekorerbar",
    "dekorerbart": "dekorerbar",
    "dekorerbarts": "dekorerbar",
    "dekoreringar": "dekorering",
    "dekoreringarna": "dekorering",
    "dekoreringarnas": "dekorering",
    "dekoreringars": "dekorering",
    "dekoreringen": "dekorering",
    "dekoreringens": "dekorering",
    "dekorerings": "dekorering",
    "dekorerna": "dekor",
    "dekorernas": "dekor",
    "dekorers": "dekor",
    "dekorglansen": "dekorglans",
    "dekorglansens": "dekorglans",
    "dekorputsen": "dekorputs",
    "dekorputsens": "dekorputs",
    "dekors": "dekor",
    "dekorumet": "dekorum",
    "dekorumets": "dekorum",
    "dekorums": "dekorum",
    "dekouragerad": "dekouragera",
    "dekouragerade": "dekouragera",
    "dekouragerades": "dekouragera",
    "dekouragerads": "dekouragera",
    "dekouragerande": "dekouragera",
    "dekourageranden": "dekouragerande",
    "dekouragerandena": "dekouragerande",
    "dekouragerandenas": "dekouragerande",
    "dekouragerandens": "dekouragerande",
    "dekouragerandes": "dekouragerande",
    "dekouragerandet": "dekouragerande",
    "dekouragerandets": "dekouragerande",
    "dekouragerar": "dekouragera",
    "dekourageras": "dekouragera",
    "dekouragerat": "dekouragera",
    "dekouragerats": "dekouragera",
    "dekouragerbara": "dekouragerbar",
    "dekouragerbarare": "dekouragerbar",
    "dekouragerbarares": "dekouragerbar",
    "dekouragerbaras": "dekouragerbar",
    "dekouragerbarast": "dekouragerbar",
    "dekouragerbaraste": "dekouragerbar",
    "dekouragerbarastes": "dekouragerbar",
    "dekouragerbarasts": "dekouragerbar",
    "dekouragerbare": "dekouragerbar",
    "dekouragerbares": "dekouragerbar",
    "dekouragerbarheten": "dekouragerbarhet",
    "dekouragerbarhetens": "dekouragerbarhet",
    "dekouragerbarhets": "dekouragerbarhet",
    "dekouragerbars": "dekouragerbar",
    "dekouragerbart": "dekouragerbar",
    "dekouragerbarts": "dekouragerbar",
    "dekourageringar": "dekouragering",
    "dekourageringarna": "dekouragering",
    "dekourageringarnas": "dekouragering",
    "dekourageringars": "dekouragering",
    "dekourageringen": "dekouragering",
    "dekourageringens": "dekouragering",
    "dekouragerings": "dekouragering",
    "dekreten": "dekret",
    "dekretens": "dekret",
    "dekreterad": "dekretera",
    "dekreterade": "dekretera",
    "dekreterades": "dekretera",
    "dekreterads": "dekretera",
    "dekreterande": "dekretera",
    "dekreteranden": "dekreterande",
    "dekreterandena": "dekreterande",
    "dekreterandenas": "dekreterande",
    "dekreterandens": "dekreterande",
    "dekreterandes": "dekreterande",
    "dekreterandet": "dekreterande",
    "dekreterandets": "dekreterande",
    "dekreterar": "dekretera",
    "dekreteras": "dekretera",
    "dekreterat": "dekretera",
    "dekreterats": "dekretera",
    "dekreterbara": "dekreterbar",
    "dekreterbarare": "dekreterbar",
    "dekreterbarares": "dekreterbar",
    "dekreterbaras": "dekreterbar",
    "dekreterbarast": "dekreterbar",
    "dekreterbaraste": "dekreterbar",
    "dekreterbarastes": "dekreterbar",
    "dekreterbarasts": "dekreterbar",
    "dekreterbare": "dekreterbar",
    "dekreterbares": "dekreterbar",
    "dekreterbarheten": "dekreterbarhet",
    "dekreterbarhetens": "dekreterbarhet",
    "dekreterbarhets": "dekreterbarhet",
    "dekreterbars": "dekreterbar",
    "dekreterbart": "dekreterbar",
    "dekreterbarts": "dekreterbar",
    "dekreteringar": "dekretering",
    "dekreteringarna": "dekretering",
    "dekreteringarnas": "dekretering",
    "dekreteringars": "dekretering",
    "dekreteringen": "dekretering",
    "dekreteringens": "dekretering",
    "dekreterings": "dekretering",
    "dekretet": "dekret",
    "dekretets": "dekret",
    "dekrets": "dekret",
    "del": "dela",
    "delabialiserade": "delabialiserad",
    "delabialiserades": "delabialiserad",
    "delabialiserads": "delabialiserad",
    "delabialiserat": "delabialiserad",
    "delabialiserats": "delabialiserad",
    "delad": "dela",
    "delade": "delad",
    "delades": "delad",
    "delads": "delad",
    "delaktiga": "delaktig",
    "delaktigare": "delaktig",
    "delaktigares": "delaktig",
    "delaktigas": "delaktig",
    "delaktigast": "delaktig",
    "delaktigaste": "delaktig",
    "delaktigastes": "delaktig",
    "delaktigasts": "delaktig",
    "delaktige": "delaktig",
    "delaktiges": "delaktig",
    "delaktigheten": "delaktighet",
    "delaktighetens": "delaktighet",
    "delaktigheter": "delaktighet",
    "delaktigheterna": "delaktighet",
    "delaktigheternas": "delaktighet",
    "delaktigheters": "delaktighet",
    "delaktighets": "delaktighet",
    "delaktigs": "delaktig",
    "delaktigt": "delaktig",
    "delaktigts": "delaktig",
    "delande": "dela",
    "delanden": "delande",
    "delandena": "delande",
    "delandenas": "delande",
    "delandens": "delande",
    "delandes": "delande",
    "delandet": "delande",
    "delandets": "delande",
    "delar": "dela",
    "delarna": "del",
    "delarnas": "del",
    "delars": "del",
    "delas": "dela",
    "delat": "delad",
    "delativen": "delativ",
    "delativens": "delativ",
    "delativer": "delativ",
    "delativerna": "delativ",
    "delativernas": "delativ",
    "delativers": "delativ",
    "delativs": "delativ",
    "delats": "delad",
    "delbara": "delbar",
    "delbarare": "delbar",
    "delbarares": "delbar",
    "delbaras": "delbar",
    "delbarast": "delbar",
    "delbaraste": "delbar",
    "delbarastes": "delbar",
    "delbarasts": "delbar",
    "delbare": "delbar",
    "delbares": "delbar",
    "delbarheten": "delbarhet",
    "delbarhetens": "delbarhet",
    "delbarhets": "delbarhet",
    "delbars": "delbar",
    "delbart": "delbar",
    "delbarts": "delbar",
    "delbetalningar": "delbetalning",
    "delbetalningarna": "delbetalning",
    "delbetalningarnas": "delbetalning",
    "delbetalningars": "delbetalning",
    "delbetalningen": "delbetalning",
    "delbetalningens": "delbetalning",
    "delbetalnings": "delbetalning",
    "delegaten": "delegat",
    "delegatens": "delegat",
    "delegater": "delegat",
    "delegaterna": "delegat",
    "delegaternas": "delegat",
    "delegaters": "delegat",
    "delegationen": "delegation",
    "delegationens": "delegation",
    "delegationer": "delegation",
    "delegationerna": "delegation",
    "delegationernas": "delegation",
    "delegationers": "delegation",
    "delegations": "delegation",
    "delegats": "delegat",
    "delegerad": "delegera",
    "delegerade": "delegera",
    "delegerades": "delegera",
    "delegerads": "delegera",
    "delegerande": "delegera",
    "delegeranden": "delegerande",
    "delegerandena": "delegerande",
    "delegerandenas": "delegerande",
    "delegerandens": "delegerande",
    "delegerandes": "delegerande",
    "delegerandet": "delegerande",
    "delegerandets": "delegerande",
    "delegerar": "delegera",
    "delegeras": "delegera",
    "delegerat": "delegera",
    "delegerats": "delegera",
    "delegerbara": "delegerbar",
    "delegerbarare": "delegerbar",
    "delegerbarares": "delegerbar",
    "delegerbaras": "delegerbar",
    "delegerbarast": "delegerbar",
    "delegerbaraste": "delegerbar",
    "delegerbarastes": "delegerbar",
    "delegerbarasts": "delegerbar",
    "delegerbare": "delegerbar",
    "delegerbares": "delegerbar",
    "delegerbarheten": "delegerbarhet",
    "delegerbarhetens": "delegerbarhet",
    "delegerbarhets": "delegerbarhet",
    "delegerbars": "delegerbar",
    "delegerbart": "delegerbar",
    "delegerbarts": "delegerbar",
    "delegeringar": "delegering",
    "delegeringarna": "delegering",
    "delegeringarnas": "delegering",
    "delegeringars": "delegering",
    "delegeringen": "delegering",
    "delegeringens": "delegering",
    "delegerings": "delegering",
    "delen": "del",
    "delens": "del",
    "delfinen": "delfin",
    "delfinens": "delfin",
    "delfiner": "delfin",
    "delfinerna": "delfin",
    "delfinernas": "delfin",
    "delfiners": "delfin",
    "delfins": "delfin",
    "delfåendes": "delfående",
    "delfåendet": "delfående",
    "delfåendets": "delfående",
    "delgav": "delge",
    "delgavs": "delge",
    "delgeende": "delge",
    "delgeendes": "delge",
    "delger": "delge",
    "delges": "delge",
    "delgett": "delge",
    "delgetts": "delge",
    "delgiv": "delge",
    "delgiva": "delge",
    "delgivande": "delge",
    "delgivanden": "delgivande",
    "delgivandena": "delgivande",
    "delgivandenas": "delgivande",
    "delgivandens": "delgivande",
    "delgivandes": "delgivande",
    "delgivandet": "delgivande",
    "delgivandets": "delgivande",
    "delgivas": "delge",
    "delgive": "delge",
    "delgiven": "delge",
    "delgivens": "delge",
    "delgiver": "delge",
    "delgives": "delge",
    "delgivet": "delge",
    "delgivets": "delge",
    "delgivit": "delge",
    "delgivits": "delge",
    "delgivna": "delge",
    "delgivnas": "delge",
    "delgivne": "delge",
    "delgivnes": "delge",
    "delgivningar": "delgivning",
    "delgivningarna": "delgivning",
    "delgivningarnas": "delgivning",
    "delgivningars": "delgivning",
    "delgivningen": "delgivning",
    "delgivningens": "delgivning",
    "delgivnings": "delgivning",
    "delgivs": "delge",
    "delgåve": "delge",
    "delgåves": "delge",
    "deliciösa": "deliciös",
    "deliciösare": "deliciös",
    "deliciösares": "deliciös",
    "deliciösas": "deliciös",
    "deliciösast": "deliciös",
    "deliciösaste": "deliciös",
    "deliciösastes": "deliciös",
    "deliciösasts": "deliciös",
    "deliciöse": "deliciös",
    "deliciöses": "deliciös",
    "deliciöst": "deliciös",
    "deliciösts": "deliciös",
    "delikata": "delikat",
    "delikatare": "delikat",
    "delikatares": "delikat",
    "delikatas": "delikat",
    "delikatast": "delikat",
    "delikataste": "delikat",
    "delikatastes": "delikat",
    "delikatasts": "delikat",
    "delikate": "delikat",
    "delikates": "delikat",
    "delikatessen": "delikatess",
    "delikatessens": "delikatess",
    "delikatesser": "delikatess",
    "delikatesserna": "delikatess",
    "delikatessernas": "delikatess",
    "delikatessers": "delikatess",
    "delikatessjäven": "delikatessjäv",
    "delikatessjävens": "delikatessjäv",
    "delikatessjävet": "delikatessjäv",
    "delikatessjävets": "delikatessjäv",
    "delikatessjävs": "delikatessjäv",
    "delikats": "delikat",
    "delikten": "delikt",
    "deliktens": "delikt",
    "delikter": "delikt",
    "delikterna": "delikt",
    "delikternas": "delikt",
    "delikters": "delikt",
    "deliktet": "delikt",
    "deliktets": "delikt",
    "delikts": "delikt",
    "delinkventen": "delinkvent",
    "delinkventens": "delinkvent",
    "delinkventer": "delinkvent",
    "delinkventerna": "delinkvent",
    "delinkventernas": "delinkvent",
    "delinkventers": "delinkvent",
    "delinkvents": "delinkvent",
    "deliranten": "delirant",
    "delirantens": "delirant",
    "deliranter": "delirant",
    "deliranterna": "delirant",
    "deliranternas": "delirant",
    "deliranters": "delirant",
    "delirants": "delirant",
    "deliriet": "delirium",
    "deliriets": "delirium",
    "deliriums": "delirium",
    "dellikviden": "dellikvid",
    "dellikvidens": "dellikvid",
    "dellikvider": "dellikvid",
    "dellikviderna": "dellikvid",
    "dellikvidernas": "dellikvid",
    "dellikviders": "dellikvid",
    "dellikvids": "dellikvid",
    "delmängden": "delmängd",
    "delmängdens": "delmängd",
    "delmängder": "delmängd",
    "delmängderna": "delmängd",
    "delmängdernas": "delmängd",
    "delmängders": "delmängd",
    "delmängds": "delmängd",
    "delningar": "delning",
    "delningarna": "delning",
    "delningarnas": "delning",
    "delningars": "delning",
    "delningen": "delning",
    "delningens": "delning",
    "delnings": "delning",
    "delperioden": "delperiod",
    "delperiodens": "delperiod",
    "delperioder": "delperiod",
    "delperioderna": "delperiod",
    "delperiodernas": "delperiod",
    "delperioders": "delperiod",
    "delperiods": "delperiod",
    "delprojekten": "delprojekt",
    "delprojektens": "delprojekt",
    "delprojektet": "delprojekt",
    "delprojektets": "delprojekt",
    "delprojekts": "delprojekt",
    "delrepubliken": "delrepublik",
    "delrepublikens": "delrepublik",
    "delrepubliker": "delrepublik",
    "delrepublikerna": "delrepublik",
    "delrepublikernas": "delrepublik",
    "delrepublikers": "delrepublik",
    "delrepubliks": "delrepublik",
    "dels": "del",
    "delstaten": "delstat",
    "delstatens": "delstat",
    "delstater": "delstat",
    "delstaterna": "delstat",
    "delstaternas": "delstat",
    "delstaters": "delstat",
    "delstats": "delstat",
    "delstrecken": "delstreck",
    "delstreckens": "delstreck",
    "delstrecket": "delstreck",
    "delstreckets": "delstreck",
    "delstrecks": "delstreck",
    "delsträck": "delsträcka",
    "delsträckan": "delsträcka",
    "delsträckans": "delsträcka",
    "delsträckas": "delsträcka",
    "delsträcke": "delsträcka",
    "delsträckor": "delsträcka",
    "delsträckorna": "delsträcka",
    "delsträckornas": "delsträcka",
    "delsträckors": "delsträcka",
    "delsträcks": "delsträcka",
    "deltaformade": "deltaformad",
    "deltaformades": "deltaformad",
    "deltaformads": "deltaformad",
    "deltaformat": "deltaformad",
    "deltaformats": "deltaformad",
    "deltag": "delta",
    "deltaga": "delta",
    "deltagande": "delta",
    "deltagandes": "deltagande",
    "deltagandet": "deltagande",
    "deltagandets": "deltagande",
    "deltagar": "deltagare",
    "deltagaren": "deltagare",
    "deltagarens": "deltagare",
    "deltagares": "deltagare",
    "deltagarna": "deltagare",
    "deltagarnas": "deltagare",
    "deltagas": "delta",
    "deltage": "delta",
    "deltagen": "delta",
    "deltagens": "delta",
    "deltager": "delta",
    "deltages": "delta",
    "deltaget": "delta",
    "deltagets": "delta",
    "deltagit": "delta",
    "deltagits": "delta",
    "deltagna": "delta",
    "deltagnas": "delta",
    "deltagne": "delta",
    "deltagnes": "delta",
    "deltags": "delta",
    "deltamuskeln": "deltamuskel",
    "deltamuskelns": "deltamuskel",
    "deltamuskels": "deltamuskel",
    "deltamuskler": "deltamuskel",
    "deltamusklerna": "deltamuskel",
    "deltamusklernas": "deltamuskel",
    "deltamusklers": "deltamuskel",
    "deltan": "delta",
    "deltana": "delta",
    "deltanas": "delta",
    "deltans": "delta",
    "deltar": "delta",
    "deltas": "delta",
    "deltat": "delta",
    "deltats": "delta",
    "deltaving": "deltavinge",
    "deltavingar": "deltavinge",
    "deltavingarna": "deltavinge",
    "deltavingarnas": "deltavinge",
    "deltavingars": "deltavinge",
    "deltavingen": "deltavinge",
    "deltavingens": "deltavinge",
    "deltavinges": "deltavinge",
    "deltavings": "deltavinge",
    "deltidar": "deltidare",
    "deltidaren": "deltidare",
    "deltidarens": "deltidare",
    "deltidares": "deltidare",
    "deltidarna": "deltidare",
    "deltidarnas": "deltidare",
    "deltiden": "deltid",
    "deltidens": "deltid",
    "deltider": "deltid",
    "deltiderna": "deltid",
    "deltidernas": "deltid",
    "deltiders": "deltid",
    "deltids": "deltid",
    "deltidsanställde": "deltidsanställd",
    "deltidsanställdes": "deltidsanställd",
    "deltidsanställds": "deltidsanställd",
    "deltidsanställt": "deltidsanställd",
    "deltidsanställts": "deltidsanställd",
    "deltidsarbetade": "deltidsarbeta",
    "deltidsarbetades": "deltidsarbeta",
    "deltidsarbetande": "deltidsarbeta",
    "deltidsarbetandes": "deltidsarbeta",
    "deltidsarbetar": "deltidsarbeta",
    "deltidsarbetas": "deltidsarbeta",
    "deltidsarbetat": "deltidsarbeta",
    "deltidsarbetats": "deltidsarbeta",
    "deltidsarbeten": "deltidsarbete",
    "deltidsarbetena": "deltidsarbete",
    "deltidsarbetenas": "deltidsarbete",
    "deltidsarbetens": "deltidsarbete",
    "deltidsarbetes": "deltidsarbete",
    "deltidsarbetet": "deltidsarbete",
    "deltidsarbetets": "deltidsarbete",
    "deltidsarbets": "deltidsarbete",
    "deltidssjuka": "deltidssjuk",
    "deltidssjukas": "deltidssjuk",
    "deltidssjuke": "deltidssjuk",
    "deltidssjukes": "deltidssjuk",
    "deltidssjuks": "deltidssjuk",
    "deltidssjukskrivens": "deltidssjukskriven",
    "deltidssjukskrivet": "deltidssjukskriven",
    "deltidssjukskrivets": "deltidssjukskriven",
    "deltidssjukskrivna": "deltidssjukskriven",
    "deltidssjukskrivnas": "deltidssjukskriven",
    "deltidssjukskrivne": "deltidssjukskriven",
    "deltidssjukskrivnes": "deltidssjukskriven",
    "deltidssjukt": "deltidssjuk",
    "deltidssjukts": "deltidssjuk",
    "deltog": "delta",
    "deltoge": "delta",
    "deltoges": "delta",
    "deltogs": "delta",
    "deltävlingar": "deltävling",
    "deltävlingarna": "deltävling",
    "deltävlingarnas": "deltävling",
    "deltävlingars": "deltävling",
    "deltävlingen": "deltävling",
    "deltävlingens": "deltävling",
    "deltävlings": "deltävling",
    "delvisa": "delvis",
    "delvisare": "delvis",
    "delvisares": "delvis",
    "delvisas": "delvis",
    "delvisast": "delvis",
    "delvisaste": "delvis",
    "delvisastes": "delvis",
    "delvisasts": "delvis",
    "delvise": "delvis",
    "delvises": "delvis",
    "delvist": "delvis",
    "delvists": "delvis",
    "delägar": "delägare",
    "delägaren": "delägare",
    "delägarens": "delägare",
    "delägares": "delägare",
    "delägarna": "delägare",
    "delägarnas": "delägare",
    "dem": "dema",
    "demad": "dema",
    "demade": "dema",
    "demades": "dema",
    "demads": "dema",
    "demagogen": "demagog",
    "demagogens": "demagog",
    "demagoger": "demagog",
    "demagogerna": "demagog",
    "demagogernas": "demagog",
    "demagogers": "demagog",
    "demagogien": "demagogi",
    "demagogiens": "demagogi",
    "demagogin": "demagogi",
    "demagogins": "demagogi",
    "demagogis": "demagogi",
    "demagogiska": "demagogisk",
    "demagogiskare": "demagogisk",
    "demagogiskares": "demagogisk",
    "demagogiskas": "demagogisk",
    "demagogiskast": "demagogisk",
    "demagogiskaste": "demagogisk",
    "demagogiskastes": "demagogisk",
    "demagogiskasts": "demagogisk",
    "demagogiske": "demagogisk",
    "demagogiskes": "demagogisk",
    "demagogisks": "demagogisk",
    "demagogiskt": "demagogisk",
    "demagogiskts": "demagogisk",
    "demagogs": "demagog",
    "demande": "dema",
    "demanden": "demande",
    "demandena": "demande",
    "demandenas": "demande",
    "demandens": "demande",
    "demandes": "demande",
    "demandet": "demande",
    "demandets": "demande",
    "demar": "dema",
    "demarkationslinjen": "demarkationslinje",
    "demarkationslinjens": "demarkationslinje",
    "demarkationslinjer": "demarkationslinje",
    "demarkationslinjerna": "demarkationslinje",
    "demarkationslinjernas": "demarkationslinje",
    "demarkationslinjers": "demarkationslinje",
    "demarkationslinjes": "demarkationslinje",
    "demarschen": "demarsch",
    "demarschens": "demarsch",
    "demarscher": "demarsch",
    "demarscherna": "demarsch",
    "demarschernas": "demarsch",
    "demarschers": "demarsch",
    "demarschs": "demarsch",
    "demas": "dema",
    "demaskerad": "demaskera",
    "demaskerade": "demaskera",
    "demaskerades": "demaskera",
    "demaskerads": "demaskera",
    "demaskerande": "demaskera",
    "demaskeranden": "demaskerande",
    "demaskerandena": "demaskerande",
    "demaskerandenas": "demaskerande",
    "demaskerandens": "demaskerande",
    "demaskerandes": "demaskerande",
    "demaskerandet": "demaskerande",
    "demaskerandets": "demaskerande",
    "demaskerar": "demaskera",
    "demaskeras": "demaskera",
    "demaskerat": "demaskera",
    "demaskerats": "demaskera",
    "demaskerbara": "demaskerbar",
    "demaskerbarare": "demaskerbar",
    "demaskerbarares": "demaskerbar",
    "demaskerbaras": "demaskerbar",
    "demaskerbarast": "demaskerbar",
    "demaskerbaraste": "demaskerbar",
    "demaskerbarastes": "demaskerbar",
    "demaskerbarasts": "demaskerbar",
    "demaskerbare": "demaskerbar",
    "demaskerbares": "demaskerbar",
    "demaskerbarheten": "demaskerbarhet",
    "demaskerbarhetens": "demaskerbarhet",
    "demaskerbarhets": "demaskerbarhet",
    "demaskerbars": "demaskerbar",
    "demaskerbart": "demaskerbar",
    "demaskerbarts": "demaskerbar",
    "demaskeringar": "demaskering",
    "demaskeringarna": "demaskering",
    "demaskeringarnas": "demaskering",
    "demaskeringars": "demaskering",
    "demaskeringen": "demaskering",
    "demaskeringens": "demaskering",
    "demaskerings": "demaskering",
    "demat": "dema",
    "demats": "dema",
    "demensen": "demens",
    "demensens": "demens",
    "demenspatienten": "demenspatient",
    "demenspatientens": "demenspatient",
    "demenspatienter": "demenspatient",
    "demenspatienterna": "demenspatient",
    "demenspatienternas": "demenspatient",
    "demenspatienters": "demenspatient",
    "demenspatients": "demenspatient",
    "demensrelaterade": "demensrelaterad",
    "demensrelaterades": "demensrelaterad",
    "demensrelaterads": "demensrelaterad",
    "demensrelaterat": "demensrelaterad",
    "demensrelaterats": "demensrelaterad",
    "demensrisken": "demensrisk",
    "demensriskens": "demensrisk",
    "demensrisker": "demensrisk",
    "demensriskerna": "demensrisk",
    "demensriskernas": "demensrisk",
    "demensriskers": "demensrisk",
    "demensrisks": "demensrisk",
    "demensutvecklingen": "demensutveckling",
    "demensutvecklingens": "demensutveckling",
    "demensutvecklings": "demensutveckling",
    "dementa": "dement",
    "dementare": "dement",
    "dementares": "dement",
    "dementas": "dement",
    "dementast": "dement",
    "dementaste": "dement",
    "dementastes": "dement",
    "dementasts": "dement",
    "demente": "dement",
    "dementerad": "dementera",
    "dementerade": "dementera",
    "dementerades": "dementera",
    "dementerads": "dementera",
    "dementerande": "dementera",
    "dementeranden": "dementerande",
    "dementerandena": "dementerande",
    "dementerandenas": "dementerande",
    "dementerandens": "dementerande",
    "dementerandes": "dementerande",
    "dementerandet": "dementerande",
    "dementerandets": "dementerande",
    "dementerar": "dementera",
    "dementeras": "dementera",
    "dementerat": "dementera",
    "dementerats": "dementera",
    "dementerbara": "dementerbar",
    "dementerbarare": "dementerbar",
    "dementerbarares": "dementerbar",
    "dementerbaras": "dementerbar",
    "dementerbarast": "dementerbar",
    "dementerbaraste": "dementerbar",
    "dementerbarastes": "dementerbar",
    "dementerbarasts": "dementerbar",
    "dementerbare": "dementerbar",
    "dementerbares": "dementerbar",
    "dementerbarheten": "dementerbarhet",
    "dementerbarhetens": "dementerbarhet",
    "dementerbarhets": "dementerbarhet",
    "dementerbars": "dementerbar",
    "dementerbart": "dementerbar",
    "dementerbarts": "dementerbar",
    "dementeringar": "dementering",
    "dementeringarna": "dementering",
    "dementeringarnas": "dementering",
    "dementeringars": "dementering",
    "dementeringen": "dementering",
    "dementeringens": "dementering",
    "dementerings": "dementering",
    "dementes": "dement",
    "dementien": "dementi",
    "dementiens": "dementi",
    "dementier": "dementi",
    "dementierna": "dementi",
    "dementiernas": "dementi",
    "dementiers": "dementi",
    "dementin": "dementi",
    "dementins": "dementi",
    "dementis": "dementi",
    "dements": "dement",
    "dementt": "dement",
    "dementts": "dement",
    "demi-secs": "demi-sec",
    "demilitariserad": "demilitarisera",
    "demilitariserade": "demilitarisera",
    "demilitariserades": "demilitarisera",
    "demilitariserads": "demilitarisera",
    "demilitariserande": "demilitarisera",
    "demilitariseranden": "demilitariserande",
    "demilitariserandena": "demilitariserande",
    "demilitariserandenas": "demilitariserande",
    "demilitariserandens": "demilitariserande",
    "demilitariserandes": "demilitariserande",
    "demilitariserandet": "demilitariserande",
    "demilitariserandets": "demilitariserande",
    "demilitariserar": "demilitarisera",
    "demilitariseras": "demilitarisera",
    "demilitariserat": "demilitarisera",
    "demilitariserats": "demilitarisera",
    "demilitariserbara": "demilitariserbar",
    "demilitariserbarare": "demilitariserbar",
    "demilitariserbarares": "demilitariserbar",
    "demilitariserbaras": "demilitariserbar",
    "demilitariserbarast": "demilitariserbar",
    "demilitariserbaraste": "demilitariserbar",
    "demilitariserbarastes": "demilitariserbar",
    "demilitariserbarasts": "demilitariserbar",
    "demilitariserbare": "demilitariserbar",
    "demilitariserbares": "demilitariserbar",
    "demilitariserbarheten": "demilitariserbarhet",
    "demilitariserbarhetens": "demilitariserbarhet",
    "demilitariserbarhets": "demilitariserbarhet",
    "demilitariserbars": "demilitariserbar",
    "demilitariserbart": "demilitariserbar",
    "demilitariserbarts": "demilitariserbar",
    "demilitariseringar": "demilitarisering",
    "demilitariseringarna": "demilitarisering",
    "demilitariseringarnas": "demilitarisering",
    "demilitariseringars": "demilitarisering",
    "demilitariseringen": "demilitarisering",
    "demilitariseringens": "demilitarisering",
    "demilitariserings": "demilitarisering",
    "demimonden": "demimond",
    "demimondens": "demimond",
    "demimonder": "demimond",
    "demimonderna": "demimond",
    "demimondernas": "demimond",
    "demimonders": "demimond",
    "demimonds": "demimond",
    "demissionen": "demission",
    "demissionens": "demission",
    "demissioner": "demission",
    "demissionerad": "demissionera",
    "demissionerade": "demissionera",
    "demissionerades": "demissionera",
    "demissionerads": "demissionera",
    "demissionerande": "demissionera",
    "demissioneranden": "demissionerande",
    "demissionerandena": "demissionerande",
    "demissionerandenas": "demissionerande",
    "demissionerandens": "demissionerande",
    "demissionerandes": "demissionerande",
    "demissionerandet": "demissionerande",
    "demissionerandets": "demissionerande",
    "demissionerar": "demissionera",
    "demissioneras": "demissionera",
    "demissionerat": "demissionera",
    "demissionerats": "demissionera",
    "demissioneringar": "demissionering",
    "demissioneringarna": "demissionering",
    "demissioneringarnas": "demissionering",
    "demissioneringars": "demissionering",
    "demissioneringen": "demissionering",
    "demissioneringens": "demissionering",
    "demissionerings": "demissionering",
    "demissionerna": "demission",
    "demissionernas": "demission",
    "demissioners": "demission",
    "demissions": "demission",
    "demiurgen": "demiurg",
    "demiurgens": "demiurg",
    "demiurger": "demiurg",
    "demiurgerna": "demiurg",
    "demiurgernas": "demiurg",
    "demiurgers": "demiurg",
    "demiurgs": "demiurg",
    "demobiliserad": "demobilisera",
    "demobiliserade": "demobilisera",
    "demobiliserades": "demobilisera",
    "demobiliserads": "demobilisera",
    "demobiliserande": "demobilisera",
    "demobiliseranden": "demobiliserande",
    "demobiliserandena": "demobiliserande",
    "demobiliserandenas": "demobiliserande",
    "demobiliserandens": "demobiliserande",
    "demobiliserandes": "demobiliserande",
    "demobiliserandet": "demobiliserande",
    "demobiliserandets": "demobiliserande",
    "demobiliserar": "demobilisera",
    "demobiliseras": "demobilisera",
    "demobiliserat": "demobilisera",
    "demobiliserats": "demobilisera",
    "demobiliserbara": "demobiliserbar",
    "demobiliserbarare": "demobiliserbar",
    "demobiliserbarares": "demobiliserbar",
    "demobiliserbaras": "demobiliserbar",
    "demobiliserbarast": "demobiliserbar",
    "demobiliserbaraste": "demobiliserbar",
    "demobiliserbarastes": "demobiliserbar",
    "demobiliserbarasts": "demobiliserbar",
    "demobiliserbare": "demobiliserbar",
    "demobiliserbares": "demobiliserbar",
    "demobiliserbarheten": "demobiliserbarhet",
    "demobiliserbarhetens": "demobiliserbarhet",
    "demobiliserbarhets": "demobiliserbarhet",
    "demobiliserbars": "demobiliserbar",
    "demobiliserbart": "demobiliserbar",
    "demobiliserbarts": "demobiliserbar",
    "demobiliseringar": "demobilisering",
    "demobiliseringarna": "demobilisering",
    "demobiliseringarnas": "demobilisering",
    "demobiliseringars": "demobilisering",
    "demobiliseringen": "demobilisering",
    "demobiliseringens": "demobilisering",
    "demobiliserings": "demobilisering",
    "demoeffekten": "demoeffekt",
    "demoeffektens": "demoeffekt",
    "demoeffekter": "demoeffekt",
    "demoeffekterna": "demoeffekt",
    "demoeffekternas": "demoeffekt",
    "demoeffekters": "demoeffekt",
    "demoeffekts": "demoeffekt",
    "demografien": "demografi",
    "demografiens": "demografi",
    "demografin": "demografi",
    "demografins": "demografi",
    "demografis": "demografi",
    "demografiska": "demografisk",
    "demografiskare": "demografisk",
    "demografiskares": "demografisk",
    "demografiskas": "demografisk",
    "demografiskast": "demografisk",
    "demografiskaste": "demografisk",
    "demografiskastes": "demografisk",
    "demografiskasts": "demografisk",
    "demografiske": "demografisk",
    "demografiskes": "demografisk",
    "demografisks": "demografisk",
    "demografiskt": "demografisk",
    "demografiskts": "demografisk",
    "demoinspelningar": "demoinspelning",
    "demoinspelningarna": "demoinspelning",
    "demoinspelningarnas": "demoinspelning",
    "demoinspelningars": "demoinspelning",
    "demoinspelningen": "demoinspelning",
    "demoinspelningens": "demoinspelning",
    "demoinspelnings": "demoinspelning",
    "demokraten": "demokrat",
    "demokratens": "demokrat",
    "demokrater": "demokrat",
    "demokraterna": "demokrat",
    "demokraternas": "demokrat",
    "demokraters": "demokrat",
    "demokratibyggen": "demokratibygge",
    "demokratibyggena": "demokratibygge",
    "demokratibyggenas": "demokratibygge",
    "demokratibyggens": "demokratibygge",
    "demokratibygges": "demokratibygge",
    "demokratibygget": "demokratibygge",
    "demokratibyggets": "demokratibygge",
    "demokratien": "demokrati",
    "demokratiens": "demokrati",
    "demokratier": "demokrati",
    "demokratierna": "demokrati",
    "demokratiernas": "demokrati",
    "demokratiers": "demokrati",
    "demokratin": "demokrati",
    "demokratins": "demokrati",
    "demokratis": "demokrati",
    "demokratiserad": "demokratisera",
    "demokratiserade": "demokratisera",
    "demokratiserades": "demokratisera",
    "demokratiserads": "demokratisera",
    "demokratiserande": "demokratisera",
    "demokratiseranden": "demokratiserande",
    "demokratiserandena": "demokratiserande",
    "demokratiserandenas": "demokratiserande",
    "demokratiserandens": "demokratiserande",
    "demokratiserandes": "demokratiserande",
    "demokratiserandet": "demokratiserande",
    "demokratiserandets": "demokratiserande",
    "demokratiserar": "demokratisera",
    "demokratiseras": "demokratisera",
    "demokratiserat": "demokratisera",
    "demokratiserats": "demokratisera",
    "demokratiserbara": "demokratiserbar",
    "demokratiserbarare": "demokratiserbar",
    "demokratiserbarares": "demokratiserbar",
    "demokratiserbaras": "demokratiserbar",
    "demokratiserbarast": "demokratiserbar",
    "demokratiserbaraste": "demokratiserbar",
    "demokratiserbarastes": "demokratiserbar",
    "demokratiserbarasts": "demokratiserbar",
    "demokratiserbare": "demokratiserbar",
    "demokratiserbares": "demokratiserbar",
    "demokratiserbarheten": "demokratiserbarhet",
    "demokratiserbarhetens": "demokratiserbarhet",
    "demokratiserbarhets": "demokratiserbarhet",
    "demokratiserbars": "demokratiserbar",
    "demokratiserbart": "demokratiserbar",
    "demokratiserbarts": "demokratiserbar",
    "demokratiseringar": "demokratisering",
    "demokratiseringarna": "demokratisering",
    "demokratiseringarnas": "demokratisering",
    "demokratiseringars": "demokratisering",
    "demokratiseringen": "demokratisering",
    "demokratiseringens": "demokratisering",
    "demokratiserings": "demokratisering",
    "demokratiska": "demokratisk",
    "demokratiskare": "demokratisk",
    "demokratiskares": "demokratisk",
    "demokratiskas": "demokratisk",
    "demokratiskast": "demokratisk",
    "demokratiskaste": "demokratisk",
    "demokratiskastes": "demokratisk",
    "demokratiskasts": "demokratisk",
    "demokratiske": "demokratisk",
    "demokratiskes": "demokratisk",
    "demokratisks": "demokratisk",
    "demokratiskt": "demokratisk",
    "demokratiskts": "demokratisk",
    "demokratismen": "demokratism",
    "demokratismens": "demokratism",
    "demokratismer": "demokratism",
    "demokratismerna": "demokratism",
    "demokratismernas": "demokratism",
    "demokratismers": "demokratism",
    "demokratisms": "demokratism",
    "demokrats": "demokrat",
    "demolerad": "demolera",
    "demolerade": "demolera",
    "demolerades": "demolera",
    "demolerads": "demolera",
    "demolerande": "demolera",
    "demoleranden": "demolerande",
    "demolerandena": "demolerande",
    "demolerandenas": "demolerande",
    "demolerandens": "demolerande",
    "demolerandes": "demolerande",
    "demolerandet": "demolerande",
    "demolerandets": "demolerande",
    "demolerar": "demolera",
    "demoleras": "demolera",
    "demolerat": "demolera",
    "demolerats": "demolera",
    "demolerbara": "demolerbar",
    "demolerbarare": "demolerbar",
    "demolerbarares": "demolerbar",
    "demolerbaras": "demolerbar",
    "demolerbarast": "demolerbar",
    "demolerbaraste": "demolerbar",
    "demolerbarastes": "demolerbar",
    "demolerbarasts": "demolerbar",
    "demolerbare": "demolerbar",
    "demolerbares": "demolerbar",
    "demolerbarheten": "demolerbarhet",
    "demolerbarhetens": "demolerbarhet",
    "demolerbarhets": "demolerbarhet",
    "demolerbars": "demolerbar",
    "demolerbart": "demolerbar",
    "demolerbarts": "demolerbar",
    "demoleringar": "demolering",
    "demoleringarna": "demolering",
    "demoleringarnas": "demolering",
    "demoleringars": "demolering",
    "demoleringen": "demolering",
    "demoleringens": "demolering",
    "demolerings": "demolering",
    "demon": "demo",
    "demona": "demo",
    "demonas": "demo",
    "demonen": "demon",
    "demonens": "demon",
    "demoner": "demon",
    "demonerna": "demon",
    "demonernas": "demon",
    "demoners": "demon",
    "demonien": "demoni",
    "demoniens": "demoni",
    "demonin": "demoni",
    "demonins": "demoni",
    "demonis": "demoni",
    "demoniska": "demonisk",
    "demoniskare": "demonisk",
    "demoniskares": "demonisk",
    "demoniskas": "demonisk",
    "demoniskast": "demonisk",
    "demoniskaste": "demonisk",
    "demoniskastes": "demonisk",
    "demoniskasts": "demonisk",
    "demoniske": "demonisk",
    "demoniskes": "demonisk",
    "demonisks": "demonisk",
    "demoniskt": "demonisk",
    "demoniskts": "demonisk",
    "demonregissören": "demonregissör",
    "demonregissörens": "demonregissör",
    "demonregissörer": "demonregissör",
    "demonregissörerna": "demonregissör",
    "demonregissörernas": "demonregissör",
    "demonregissörers": "demonregissör",
    "demonregissörs": "demonregissör",
    "demons": "demon",
    "demonstranten": "demonstrant",
    "demonstrantens": "demonstrant",
    "demonstranter": "demonstrant",
    "demonstranterna": "demonstrant",
    "demonstranternas": "demonstrant",
    "demonstranters": "demonstrant",
    "demonstrants": "demonstrant",
    "demonstrationen": "demonstration",
    "demonstrationens": "demonstration",
    "demonstrationer": "demonstration",
    "demonstrationerna": "demonstration",
    "demonstrationernas": "demonstration",
    "demonstrationers": "demonstration",
    "demonstrations": "demonstration",
    "demonstrationsfriheten": "demonstrationsfrihet",
    "demonstrationsfrihetens": "demonstrationsfrihet",
    "demonstrationsfriheter": "demonstrationsfrihet",
    "demonstrationsfriheterna": "demonstrationsfrihet",
    "demonstrationsfriheternas": "demonstrationsfrihet",
    "demonstrationsfriheters": "demonstrationsfrihet",
    "demonstrationsfrihets": "demonstrationsfrihet",
    "demonstrationstillstånden": "demonstrationstillstånd",
    "demonstrationstillståndens": "demonstrationstillstånd",
    "demonstrationstillståndet": "demonstrationstillstånd",
    "demonstrationstillståndets": "demonstrationstillstånd",
    "demonstrationstillstånds": "demonstrationstillstånd",
    "demonstrationstågen": "demonstrationståg",
    "demonstrationstågens": "demonstrationståg",
    "demonstrationståget": "demonstrationståg",
    "demonstrationstågets": "demonstrationståg",
    "demonstrationstågs": "demonstrationståg",
    "demonstrativa": "demonstrativ",
    "demonstrativare": "demonstrativ",
    "demonstrativares": "demonstrativ",
    "demonstrativas": "demonstrativ",
    "demonstrativast": "demonstrativ",
    "demonstrativaste": "demonstrativ",
    "demonstrativastes": "demonstrativ",
    "demonstrativasts": "demonstrativ",
    "demonstrative": "demonstrativ",
    "demonstratives": "demonstrativ",
    "demonstrativs": "demonstrativ",
    "demonstrativt": "demonstrativ",
    "demonstrativts": "demonstrativ",
    "demonstratrisen": "demonstratris",
    "demonstratrisens": "demonstratris",
    "demonstratriser": "demonstratris",
    "demonstratriserna": "demonstratris",
    "demonstratrisernas": "demonstratris",
    "demonstratrisers": "demonstratris",
    "demonstratören": "demonstratör",
    "demonstratörens": "demonstratör",
    "demonstratörer": "demonstratör",
    "demonstratörerna": "demonstratör",
    "demonstratörernas": "demonstratör",
    "demonstratörers": "demonstratör",
    "demonstratörs": "demonstratör",
    "demonstrerad": "demonstrera",
    "demonstrerade": "demonstrera",
    "demonstrerades": "demonstrera",
    "demonstrerads": "demonstrera",
    "demonstrerande": "demonstrera",
    "demonstreranden": "demonstrerande",
    "demonstrerandena": "demonstrerande",
    "demonstrerandenas": "demonstrerande",
    "demonstrerandens": "demonstrerande",
    "demonstrerandes": "demonstrerande",
    "demonstrerandet": "demonstrerande",
    "demonstrerandets": "demonstrerande",
    "demonstrerar": "demonstrera",
    "demonstreras": "demonstrera",
    "demonstrerat": "demonstrera",
    "demonstrerats": "demonstrera",
    "demonstrerbara": "demonstrerbar",
    "demonstrerbarare": "demonstrerbar",
    "demonstrerbarares": "demonstrerbar",
    "demonstrerbaras": "demonstrerbar",
    "demonstrerbarast": "demonstrerbar",
    "demonstrerbaraste": "demonstrerbar",
    "demonstrerbarastes": "demonstrerbar",
    "demonstrerbarasts": "demonstrerbar",
    "demonstrerbare": "demonstrerbar",
    "demonstrerbares": "demonstrerbar",
    "demonstrerbarheten": "demonstrerbarhet",
    "demonstrerbarhetens": "demonstrerbarhet",
    "demonstrerbarhets": "demonstrerbarhet",
    "demonstrerbars": "demonstrerbar",
    "demonstrerbart": "demonstrerbar",
    "demonstrerbarts": "demonstrerbar",
    "demonstreringar": "demonstrering",
    "demonstreringarna": "demonstrering",
    "demonstreringarnas": "demonstrering",
    "demonstreringars": "demonstrering",
    "demonstreringen": "demonstrering",
    "demonstreringens": "demonstrering",
    "demonstrerings": "demonstrering",
    "demonterad": "demontera",
    "demonterade": "demontera",
    "demonterades": "demontera",
    "demonterads": "demontera",
    "demonterande": "demontera",
    "demonteranden": "demonterande",
    "demonterandena": "demonterande",
    "demonterandenas": "demonterande",
    "demonterandens": "demonterande",
    "demonterandes": "demonterande",
    "demonterandet": "demonterande",
    "demonterandets": "demonterande",
    "demonterar": "demontera",
    "demonteras": "demontera",
    "demonterat": "demontera",
    "demonterats": "demontera",
    "demonterbara": "demonterbar",
    "demonterbarare": "demonterbar",
    "demonterbarares": "demonterbar",
    "demonterbaras": "demonterbar",
    "demonterbarast": "demonterbar",
    "demonterbaraste": "demonterbar",
    "demonterbarastes": "demonterbar",
    "demonterbarasts": "demonterbar",
    "demonterbare": "demonterbar",
    "demonterbares": "demonterbar",
    "demonterbarheten": "demonterbarhet",
    "demonterbarhetens": "demonterbarhet",
    "demonterbarhets": "demonterbarhet",
    "demonterbars": "demonterbar",
    "demonterbart": "demonterbar",
    "demonterbarts": "demonterbar",
    "demonteringar": "demontering",
    "demonteringarna": "demontering",
    "demonteringarnas": "demontering",
    "demonteringars": "demontering",
    "demonteringen": "demontering",
    "demonteringens": "demontering",
    "demonterings": "demontering",
    "demor": "demo",
    "demoralisationen": "demoralisation",
    "demoralisationens": "demoralisation",
    "demoralisationer": "demoralisation",
    "demoralisationerna": "demoralisation",
    "demoralisationernas": "demoralisation",
    "demoralisationers": "demoralisation",
    "demoralisations": "demoralisation",
    "demoraliserad": "demoralisera",
    "demoraliserade": "demoralisera",
    "demoraliserades": "demoralisera",
    "demoraliserads": "demoralisera",
    "demoraliserande": "demoralisera",
    "demoraliseranden": "demoraliserande",
    "demoraliserandena": "demoraliserande",
    "demoraliserandenas": "demoraliserande",
    "demoraliserandens": "demoraliserande",
    "demoraliserandes": "demoraliserande",
    "demoraliserandet": "demoraliserande",
    "demoraliserandets": "demoraliserande",
    "demoraliserar": "demoralisera",
    "demoraliseras": "demoralisera",
    "demoraliserat": "demoralisera",
    "demoraliserats": "demoralisera",
    "demoraliserbara": "demoraliserbar",
    "demoraliserbarare": "demoraliserbar",
    "demoraliserbarares": "demoraliserbar",
    "demoraliserbaras": "demoraliserbar",
    "demoraliserbarast": "demoraliserbar",
    "demoraliserbaraste": "demoraliserbar",
    "demoraliserbarastes": "demoraliserbar",
    "demoraliserbarasts": "demoraliserbar",
    "demoraliserbare": "demoraliserbar",
    "demoraliserbares": "demoraliserbar",
    "demoraliserbarheten": "demoraliserbarhet",
    "demoraliserbarhetens": "demoraliserbarhet",
    "demoraliserbarhets": "demoraliserbarhet",
    "demoraliserbars": "demoraliserbar",
    "demoraliserbart": "demoraliserbar",
    "demoraliserbarts": "demoraliserbar",
    "demoraliseringar": "demoralisering",
    "demoraliseringarna": "demoralisering",
    "demoraliseringarnas": "demoralisering",
    "demoraliseringars": "demoralisering",
    "demoraliseringen": "demoralisering",
    "demoraliseringens": "demoralisering",
    "demoraliserings": "demoralisering",
    "demorna": "demo",
    "demornas": "demo",
    "demors": "demo",
    "demos": "demo",
    "demosar": "demo",
    "demosarna": "demo",
    "demosarnas": "demo",
    "demosars": "demo",
    "demosen": "demo",
    "demosens": "demo",
    "demot": "demo",
    "demotapen": "demotape",
    "demotapens": "demotape",
    "demotaper": "demotape",
    "demotaperna": "demotape",
    "demotapernas": "demotape",
    "demotapers": "demotape",
    "demotapes": "demotape",
    "demots": "demo",
    "den": "en",
    "denaren": "denar",
    "denarens": "denar",
    "denarer": "denar",
    "denarerna": "denar",
    "denarernas": "denar",
    "denarers": "denar",
    "denars": "denar",
    "denaturalisationen": "denaturalisation",
    "denaturalisationens": "denaturalisation",
    "denaturalisationer": "denaturalisation",
    "denaturalisationerna": "denaturalisation",
    "denaturalisationernas": "denaturalisation",
    "denaturalisationers": "denaturalisation",
    "denaturalisations": "denaturalisation",
    "denaturaliserad": "denaturalisera",
    "denaturaliserade": "denaturalisera",
    "denaturaliserades": "denaturalisera",
    "denaturaliserads": "denaturalisera",
    "denaturaliserande": "denaturalisera",
    "denaturaliseranden": "denaturaliserande",
    "denaturaliserandena": "denaturaliserande",
    "denaturaliserandenas": "denaturaliserande",
    "denaturaliserandens": "denaturaliserande",
    "denaturaliserandes": "denaturaliserande",
    "denaturaliserandet": "denaturaliserande",
    "denaturaliserandets": "denaturaliserande",
    "denaturaliserar": "denaturalisera",
    "denaturaliseras": "denaturalisera",
    "denaturaliserat": "denaturalisera",
    "denaturaliserats": "denaturalisera",
    "denaturaliserbara": "denaturaliserbar",
    "denaturaliserbarare": "denaturaliserbar",
    "denaturaliserbarares": "denaturaliserbar",
    "denaturaliserbaras": "denaturaliserbar",
    "denaturaliserbarast": "denaturaliserbar",
    "denaturaliserbaraste": "denaturaliserbar",
    "denaturaliserbarastes": "denaturaliserbar",
    "denaturaliserbarasts": "denaturaliserbar",
    "denaturaliserbare": "denaturaliserbar",
    "denaturaliserbares": "denaturaliserbar",
    "denaturaliserbarheten": "denaturaliserbarhet",
    "denaturaliserbarhetens": "denaturaliserbarhet",
    "denaturaliserbarhets": "denaturaliserbarhet",
    "denaturaliserbars": "denaturaliserbar",
    "denaturaliserbart": "denaturaliserbar",
    "denaturaliserbarts": "denaturaliserbar",
    "denaturaliseringar": "denaturalisering",
    "denaturaliseringarna": "denaturalisering",
    "denaturaliseringarnas": "denaturalisering",
    "denaturaliseringars": "denaturalisering",
    "denaturaliseringen": "denaturalisering",
    "denaturaliseringens": "denaturalisering",
    "denaturaliserings": "denaturalisering",
    "denaturerad": "denaturera",
    "denaturerade": "denaturera",
    "denaturerades": "denaturera",
    "denaturerads": "denaturera",
    "denaturerande": "denaturera",
    "denatureranden": "denaturerande",
    "denaturerandena": "denaturerande",
    "denaturerandenas": "denaturerande",
    "denaturerandens": "denaturerande",
    "denaturerandes": "denaturerande",
    "denaturerandet": "denaturerande",
    "denaturerandets": "denaturerande",
    "denaturerar": "denaturera",
    "denatureras": "denaturera",
    "denaturerat": "denaturera",
    "denaturerats": "denaturera",
    "denaturerbara": "denaturerbar",
    "denaturerbarare": "denaturerbar",
    "denaturerbarares": "denaturerbar",
    "denaturerbaras": "denaturerbar",
    "denaturerbarast": "denaturerbar",
    "denaturerbaraste": "denaturerbar",
    "denaturerbarastes": "denaturerbar",
    "denaturerbarasts": "denaturerbar",
    "denaturerbare": "denaturerbar",
    "denaturerbares": "denaturerbar",
    "denaturerbarheten": "denaturerbarhet",
    "denaturerbarhetens": "denaturerbarhet",
    "denaturerbarhets": "denaturerbarhet",
    "denaturerbars": "denaturerbar",
    "denaturerbart": "denaturerbar",
    "denaturerbarts": "denaturerbar",
    "denatureringar": "denaturering",
    "denatureringarna": "denaturering",
    "denatureringarnas": "denaturering",
    "denatureringars": "denaturering",
    "denatureringen": "denaturering",
    "denatureringens": "denaturering",
    "denaturerings": "denaturering",
    "dendriten": "dendrit",
    "dendritens": "dendrit",
    "dendriter": "dendrit",
    "dendriterna": "dendrit",
    "dendriternas": "dendrit",
    "dendriters": "dendrit",
    "dendrits": "dendrit",
    "dendrokronologien": "dendrokronologi",
    "dendrokronologiens": "dendrokronologi",
    "dendrokronologin": "dendrokronologi",
    "dendrokronologins": "dendrokronologi",
    "dendrokronologis": "dendrokronologi",
    "dendrologen": "dendrolog",
    "dendrologens": "dendrolog",
    "dendrologer": "dendrolog",
    "dendrologerna": "dendrolog",
    "dendrologernas": "dendrolog",
    "dendrologers": "dendrolog",
    "dendrologien": "dendrologi",
    "dendrologiens": "dendrologi",
    "dendrologin": "dendrologi",
    "dendrologins": "dendrologi",
    "dendrologis": "dendrologi",
    "dendrologs": "dendrolog",
    "denieren": "denier",
    "denierens": "denier",
    "deniers": "denier",
    "denimen": "denim",
    "denimens": "denim",
    "denimet": "denim",
    "denimets": "denim",
    "denims": "denim",
    "dennas": "denna",
    "denne": "denna",
    "dennes": "denna",
    "denotationen": "denotation",
    "denotationens": "denotation",
    "denotationer": "denotation",
    "denotationerna": "denotation",
    "denotationernas": "denotation",
    "denotationers": "denotation",
    "denotations": "denotation",
    "denotativa": "denotativ",
    "denotativare": "denotativ",
    "denotativares": "denotativ",
    "denotativas": "denotativ",
    "denotativast": "denotativ",
    "denotativaste": "denotativ",
    "denotativastes": "denotativ",
    "denotativasts": "denotativ",
    "denotative": "denotativ",
    "denotatives": "denotativ",
    "denotativs": "denotativ",
    "denotativt": "denotativ",
    "denotativts": "denotativ",
    "denoterad": "denotera",
    "denoterade": "denotera",
    "denoterades": "denotera",
    "denoterads": "denotera",
    "denoterande": "denotera",
    "denoteranden": "denoterande",
    "denoterandena": "denoterande",
    "denoterandenas": "denoterande",
    "denoterandens": "denoterande",
    "denoterandes": "denoterande",
    "denoterandet": "denoterande",
    "denoterandets": "denoterande",
    "denoterar": "denotera",
    "denoteras": "denotera",
    "denoterat": "denotera",
    "denoterats": "denotera",
    "denoterbara": "denoterbar",
    "denoterbarare": "denoterbar",
    "denoterbarares": "denoterbar",
    "denoterbaras": "denoterbar",
    "denoterbarast": "denoterbar",
    "denoterbaraste": "denoterbar",
    "denoterbarastes": "denoterbar",
    "denoterbarasts": "denoterbar",
    "denoterbare": "denoterbar",
    "denoterbares": "denoterbar",
    "denoterbarheten": "denoterbarhet",
    "denoterbarhetens": "denoterbarhet",
    "denoterbarhets": "denoterbarhet",
    "denoterbars": "denoterbar",
    "denoterbart": "denoterbar",
    "denoterbarts": "denoterbar",
    "denoteringar": "denotering",
    "denoteringarna": "denotering",
    "denoteringarnas": "denotering",
    "denoteringars": "denotering",
    "denoteringen": "denotering",
    "denoteringens": "denotering",
    "denoterings": "denotering",
    "dens": "den",
    "densammas": "densamma",
    "densamme": "densamma",
    "densammes": "densamma",
    "densiteten": "densitet",
    "densitetens": "densitet",
    "densiteter": "densitet",
    "densiteterna": "densitet",
    "densiteternas": "densitet",
    "densiteters": "densitet",
    "densitets": "densitet",
    "densitometern": "densitometer",
    "densitometerns": "densitometer",
    "densitometers": "densitometer",
    "densitometrar": "densitometer",
    "densitometrarna": "densitometer",
    "densitometrarnas": "densitometer",
    "densitometrars": "densitometer",
    "densometern": "densometer",
    "densometerns": "densometer",
    "densometers": "densometer",
    "densometrar": "densometer",
    "densometrarna": "densometer",
    "densometrarnas": "densometer",
    "densometrars": "densometer",
    "dentala": "dental",
    "dentalare": "dental",
    "dentalares": "dental",
    "dentalas": "dental",
    "dentalast": "dental",
    "dentalaste": "dental",
    "dentalastes": "dental",
    "dentalasts": "dental",
    "dentale": "dental",
    "dentalen": "dental",
    "dentalens": "dental",
    "dentaler": "dental",
    "dentalerna": "dental",
    "dentalernas": "dental",
    "dentalers": "dental",
    "dentales": "dental",
    "dentals": "dental",
    "dentalt": "dental",
    "dentalts": "dental",
    "dentisten": "dentist",
    "dentistens": "dentist",
    "dentister": "dentist",
    "dentisterna": "dentist",
    "dentisternas": "dentist",
    "dentisters": "dentist",
    "dentists": "dentist",
    "denudationen": "denudation",
    "denudationens": "denudation",
    "denudationer": "denudation",
    "denudationerna": "denudation",
    "denudationernas": "denudation",
    "denudationers": "denudation",
    "denudations": "denudation",
    "denuderad": "denudera",
    "denuderade": "denudera",
    "denuderades": "denudera",
    "denuderads": "denudera",
    "denuderande": "denudera",
    "denuderanden": "denuderande",
    "denuderandena": "denuderande",
    "denuderandenas": "denuderande",
    "denuderandens": "denuderande",
    "denuderandes": "denuderande",
    "denuderandet": "denuderande",
    "denuderandets": "denuderande",
    "denuderar": "denudera",
    "denuderas": "denudera",
    "denuderat": "denudera",
    "denuderats": "denudera",
    "denuderbara": "denuderbar",
    "denuderbarare": "denuderbar",
    "denuderbarares": "denuderbar",
    "denuderbaras": "denuderbar",
    "denuderbarast": "denuderbar",
    "denuderbaraste": "denuderbar",
    "denuderbarastes": "denuderbar",
    "denuderbarasts": "denuderbar",
    "denuderbare": "denuderbar",
    "denuderbares": "denuderbar",
    "denuderbarheten": "denuderbarhet",
    "denuderbarhetens": "denuderbarhet",
    "denuderbarhets": "denuderbarhet",
    "denuderbars": "denuderbar",
    "denuderbart": "denuderbar",
    "denuderbarts": "denuderbar",
    "denuderingar": "denudering",
    "denuderingarna": "denudering",
    "denuderingarnas": "denudering",
    "denuderingars": "denudering",
    "denuderingen": "denudering",
    "denuderingens": "denudering",
    "denuderings": "denudering",
    "denukleariserade": "denukleariserad",
    "denukleariserades": "denukleariserad",
    "denukleariserads": "denukleariserad",
    "denukleariserat": "denukleariserad",
    "denukleariserats": "denukleariserad",
    "denukleariseringar": "denuklearisering",
    "denukleariseringarna": "denuklearisering",
    "denukleariseringarnas": "denuklearisering",
    "denukleariseringars": "denuklearisering",
    "denukleariseringen": "denuklearisering",
    "denukleariseringens": "denuklearisering",
    "denukleariserings": "denuklearisering",
    "deodoranten": "deodorant",
    "deodorantens": "deodorant",
    "deodoranter": "deodorant",
    "deodoranterna": "deodorant",
    "deodoranternas": "deodorant",
    "deodoranters": "deodorant",
    "deodorants": "deodorant",
    "deodoriserad": "deodorisera",
    "deodoriserade": "deodorisera",
    "deodoriserades": "deodorisera",
    "deodoriserads": "deodorisera",
    "deodoriserande": "deodorisera",
    "deodoriseranden": "deodoriserande",
    "deodoriserandena": "deodoriserande",
    "deodoriserandenas": "deodoriserande",
    "deodoriserandens": "deodoriserande",
    "deodoriserandes": "deodoriserande",
    "deodoriserandet": "deodoriserande",
    "deodoriserandets": "deodoriserande",
    "deodoriserar": "deodorisera",
    "deodoriseras": "deodorisera",
    "deodoriserat": "deodorisera",
    "deodoriserats": "deodorisera",
    "deodoriserbara": "deodoriserbar",
    "deodoriserbarare": "deodoriserbar",
    "deodoriserbarares": "deodoriserbar",
    "deodoriserbaras": "deodoriserbar",
    "deodoriserbarast": "deodoriserbar",
    "deodoriserbaraste": "deodoriserbar",
    "deodoriserbarastes": "deodoriserbar",
    "deodoriserbarasts": "deodoriserbar",
    "deodoriserbare": "deodoriserbar",
    "deodoriserbares": "deodoriserbar",
    "deodoriserbarheten": "deodoriserbarhet",
    "deodoriserbarhetens": "deodoriserbarhet",
    "deodoriserbarhets": "deodoriserbarhet",
    "deodoriserbars": "deodoriserbar",
    "deodoriserbart": "deodoriserbar",
    "deodoriserbarts": "deodoriserbar",
    "deodoriseringar": "deodorisering",
    "deodoriseringarna": "deodorisering",
    "deodoriseringarnas": "deodorisering",
    "deodoriseringars": "deodorisering",
    "deodoriseringen": "deodorisering",
    "deodoriseringens": "deodorisering",
    "deodoriserings": "deodorisering",
    "departementala": "departemental",
    "departementalare": "departemental",
    "departementalares": "departemental",
    "departementalas": "departemental",
    "departementalast": "departemental",
    "departementalaste": "departemental",
    "departementalastes": "departemental",
    "departementalasts": "departemental",
    "departementale": "departemental",
    "departementales": "departemental",
    "departementals": "departemental",
    "departementalt": "departemental",
    "departementalts": "departemental",
    "departementen": "departement",
    "departementens": "departement",
    "departementet": "departement",
    "departementets": "departement",
    "departements": "departement",
    "departementschefen": "departementschef",
    "departementschefens": "departementschef",
    "departementschefer": "departementschef",
    "departementscheferna": "departementschef",
    "departementschefernas": "departementschef",
    "departementschefers": "departementschef",
    "departementschefs": "departementschef",
    "departementsråden": "departementsråd",
    "departementsrådens": "departementsråd",
    "departementsrådet": "departementsråd",
    "departementsrådets": "departementsråd",
    "departementsråds": "departementsråd",
    "departementsärenden": "departementsärende",
    "departementsärendena": "departementsärende",
    "departementsärendenas": "departementsärende",
    "departementsärendens": "departementsärende",
    "departementsärendes": "departementsärende",
    "departementsärendet": "departementsärende",
    "departementsärendets": "departementsärende",
    "depatrierad": "depatriera",
    "depatrierade": "depatriera",
    "depatrierades": "depatriera",
    "depatrierads": "depatriera",
    "depatrierande": "depatriera",
    "depatrieranden": "depatrierande",
    "depatrierandena": "depatrierande",
    "depatrierandenas": "depatrierande",
    "depatrierandens": "depatrierande",
    "depatrierandes": "depatrierande",
    "depatrierandet": "depatrierande",
    "depatrierandets": "depatrierande",
    "depatrierar": "depatriera",
    "depatrieras": "depatriera",
    "depatrierat": "depatriera",
    "depatrierats": "depatriera",
    "depatrierbara": "depatrierbar",
    "depatrierbarare": "depatrierbar",
    "depatrierbarares": "depatrierbar",
    "depatrierbaras": "depatrierbar",
    "depatrierbarast": "depatrierbar",
    "depatrierbaraste": "depatrierbar",
    "depatrierbarastes": "depatrierbar",
    "depatrierbarasts": "depatrierbar",
    "depatrierbare": "depatrierbar",
    "depatrierbares": "depatrierbar",
    "depatrierbarheten": "depatrierbarhet",
    "depatrierbarhetens": "depatrierbarhet",
    "depatrierbarhets": "depatrierbarhet",
    "depatrierbars": "depatrierbar",
    "depatrierbart": "depatrierbar",
    "depatrierbarts": "depatrierbar",
    "depatrieringar": "depatriering",
    "depatrieringarna": "depatriering",
    "depatrieringarnas": "depatriering",
    "depatrieringars": "depatriering",
    "depatrieringen": "depatriering",
    "depatrieringens": "depatriering",
    "depatrierings": "depatriering",
    "depensen": "depens",
    "depensens": "depens",
    "depenser": "depens",
    "depenserad": "depensera",
    "depenserade": "depensera",
    "depenserades": "depensera",
    "depenserads": "depensera",
    "depenserande": "depensera",
    "depenseranden": "depenserande",
    "depenserandena": "depenserande",
    "depenserandenas": "depenserande",
    "depenserandens": "depenserande",
    "depenserandes": "depenserande",
    "depenserandet": "depenserande",
    "depenserandets": "depenserande",
    "depenserar": "depensera",
    "depenseras": "depensera",
    "depenserat": "depensera",
    "depenserats": "depensera",
    "depenserbara": "depenserbar",
    "depenserbarare": "depenserbar",
    "depenserbarares": "depenserbar",
    "depenserbaras": "depenserbar",
    "depenserbarast": "depenserbar",
    "depenserbaraste": "depenserbar",
    "depenserbarastes": "depenserbar",
    "depenserbarasts": "depenserbar",
    "depenserbare": "depenserbar",
    "depenserbares": "depenserbar",
    "depenserbarheten": "depenserbarhet",
    "depenserbarhetens": "depenserbarhet",
    "depenserbarhets": "depenserbarhet",
    "depenserbars": "depenserbar",
    "depenserbart": "depenserbar",
    "depenserbarts": "depenserbar",
    "depenseringar": "depensering",
    "depenseringarna": "depensering",
    "depenseringarnas": "depensering",
    "depenseringars": "depensering",
    "depenseringen": "depensering",
    "depenseringens": "depensering",
    "depenserings": "depensering",
    "depenserna": "depens",
    "depensernas": "depens",
    "depensers": "depens",
    "depersonalisationen": "depersonalisation",
    "depersonalisationens": "depersonalisation",
    "depersonalisationer": "depersonalisation",
    "depersonalisationerna": "depersonalisation",
    "depersonalisationernas": "depersonalisation",
    "depersonalisationers": "depersonalisation",
    "depersonalisations": "depersonalisation",
    "depeschbyråer": "depeschbyrå",
    "depeschbyråerna": "depeschbyrå",
    "depeschbyråernas": "depeschbyrå",
    "depeschbyråers": "depeschbyrå",
    "depeschbyrån": "depeschbyrå",
    "depeschbyråns": "depeschbyrå",
    "depeschbyrås": "depeschbyrå",
    "depeschen": "depesch",
    "depeschens": "depesch",
    "depescher": "depesch",
    "depescherna": "depesch",
    "depeschernas": "depesch",
    "depeschers": "depesch",
    "depeschs": "depesch",
    "deplacementet": "deplacement",
    "deplacementets": "deplacement",
    "deplacements": "deplacement",
    "deplacerad": "deplacera",
    "deplacerade": "deplacera",
    "deplacerades": "deplacera",
    "deplacerads": "deplacera",
    "deplacerande": "deplacera",
    "deplaceranden": "deplacerande",
    "deplacerandena": "deplacerande",
    "deplacerandenas": "deplacerande",
    "deplacerandens": "deplacerande",
    "deplacerandes": "deplacerande",
    "deplacerandet": "deplacerande",
    "deplacerandets": "deplacerande",
    "deplacerar": "deplacera",
    "deplaceras": "deplacera",
    "deplacerat": "deplacera",
    "deplacerats": "deplacera",
    "deplacerbara": "deplacerbar",
    "deplacerbarare": "deplacerbar",
    "deplacerbarares": "deplacerbar",
    "deplacerbaras": "deplacerbar",
    "deplacerbarast": "deplacerbar",
    "deplacerbaraste": "deplacerbar",
    "deplacerbarastes": "deplacerbar",
    "deplacerbarasts": "deplacerbar",
    "deplacerbare": "deplacerbar",
    "deplacerbares": "deplacerbar",
    "deplacerbarheten": "deplacerbarhet",
    "deplacerbarhetens": "deplacerbarhet",
    "deplacerbarhets": "deplacerbarhet",
    "deplacerbars": "deplacerbar",
    "deplacerbart": "deplacerbar",
    "deplacerbarts": "deplacerbar",
    "deplaceringar": "deplacering",
    "deplaceringarna": "deplacering",
    "deplaceringarnas": "deplacering",
    "deplaceringars": "deplacering",
    "deplaceringen": "deplacering",
    "deplaceringens": "deplacering",
    "deplacerings": "deplacering",
    "depolarisatorer": "depolarisator",
    "depolarisatorerna": "depolarisator",
    "depolarisatorernas": "depolarisator",
    "depolarisatorers": "depolarisator",
    "depolarisatorn": "depolarisator",
    "depolarisatorns": "depolarisator",
    "depolarisators": "depolarisator",
    "deponensen": "deponens",
    "deponensens": "deponens",
    "deponenten": "deponent",
    "deponentens": "deponent",
    "deponenter": "deponent",
    "deponenterna": "deponent",
    "deponenternas": "deponent",
    "deponenters": "deponent",
    "deponentiella": "deponentiell",
    "deponentiellare": "deponentiell",
    "deponentiellares": "deponentiell",
    "deponentiellas": "deponentiell",
    "deponentiellast": "deponentiell",
    "deponentiellaste": "deponentiell",
    "deponentiellastes": "deponentiell",
    "deponentiellasts": "deponentiell",
    "deponentielle": "deponentiell",
    "deponentielles": "deponentiell",
    "deponentiells": "deponentiell",
    "deponentiellt": "deponentiell",
    "deponentiellts": "deponentiell",
    "deponents": "deponent",
    "deponerad": "deponera",
    "deponerade": "deponera",
    "deponerades": "deponera",
    "deponerads": "deponera",
    "deponerande": "deponera",
    "deponeranden": "deponerande",
    "deponerandena": "deponerande",
    "deponerandenas": "deponerande",
    "deponerandens": "deponerande",
    "deponerandes": "deponerande",
    "deponerandet": "deponerande",
    "deponerandets": "deponerande",
    "deponerar": "deponera",
    "deponeras": "deponera",
    "deponerat": "deponera",
    "deponerats": "deponera",
    "deponerbara": "deponerbar",
    "deponerbarare": "deponerbar",
    "deponerbarares": "deponerbar",
    "deponerbaras": "deponerbar",
    "deponerbarast": "deponerbar",
    "deponerbaraste": "deponerbar",
    "deponerbarastes": "deponerbar",
    "deponerbarasts": "deponerbar",
    "deponerbare": "deponerbar",
    "deponerbares": "deponerbar",
    "deponerbarheten": "deponerbarhet",
    "deponerbarhetens": "deponerbarhet",
    "deponerbarhets": "deponerbarhet",
    "deponerbars": "deponerbar",
    "deponerbart": "deponerbar",
    "deponerbarts": "deponerbar",
    "deponeringar": "deponering",
    "deponeringarna": "deponering",
    "deponeringarnas": "deponering",
    "deponeringars": "deponering",
    "deponeringen": "deponering",
    "deponeringens": "deponering",
    "deponerings": "deponering",
    "deponien": "deponi",
    "deponiens": "deponi",
    "deponier": "deponi",
    "deponierna": "deponi",
    "deponiernas": "deponi",
    "deponiers": "deponi",
    "deponin": "deponi",
    "deponins": "deponi",
    "deponis": "deponi",
    "deportationen": "deportation",
    "deportationens": "deportation",
    "deportationer": "deportation",
    "deportationerna": "deportation",
    "deportationernas": "deportation",
    "deportationers": "deportation",
    "deportations": "deportation",
    "deportationsorten": "deportationsort",
    "deportationsortens": "deportationsort",
    "deportationsorter": "deportationsort",
    "deportationsorterna": "deportationsort",
    "deportationsorternas": "deportationsort",
    "deportationsorters": "deportationsort",
    "deportationsorts": "deportationsort",
    "deporterad": "deportera",
    "deporterade": "deportera",
    "deporterades": "deportera",
    "deporterads": "deportera",
    "deporterande": "deportera",
    "deporteranden": "deporterande",
    "deporterandena": "deporterande",
    "deporterandenas": "deporterande",
    "deporterandens": "deporterande",
    "deporterandes": "deporterande",
    "deporterandet": "deporterande",
    "deporterandets": "deporterande",
    "deporterar": "deportera",
    "deporteras": "deportera",
    "deporterat": "deportera",
    "deporterats": "deportera",
    "deporterbara": "deporterbar",
    "deporterbarare": "deporterbar",
    "deporterbarares": "deporterbar",
    "deporterbaras": "deporterbar",
    "deporterbarast": "deporterbar",
    "deporterbaraste": "deporterbar",
    "deporterbarastes": "deporterbar",
    "deporterbarasts": "deporterbar",
    "deporterbare": "deporterbar",
    "deporterbares": "deporterbar",
    "deporterbarheten": "deporterbarhet",
    "deporterbarhetens": "deporterbarhet",
    "deporterbarhets": "deporterbarhet",
    "deporterbars": "deporterbar",
    "deporterbart": "deporterbar",
    "deporterbarts": "deporterbar",
    "deporteringar": "deportering",
    "deporteringarna": "deportering",
    "deporteringarnas": "deportering",
    "deporteringars": "deportering",
    "deporteringen": "deportering",
    "deporteringens": "deportering",
    "deporterings": "deportering",
    "deposita": "depositum",
    "depositana": "depositum",
    "depositanas": "depositum",
    "depositas": "depositum",
    "depositionen": "deposition",
    "depositionens": "deposition",
    "depositioner": "deposition",
    "depositionerna": "deposition",
    "depositionernas": "deposition",
    "depositioners": "deposition",
    "depositions": "deposition",
    "depositionsbevisen": "depositionsbevis",
    "depositionsbevisens": "depositionsbevis",
    "depositionsbeviset": "depositionsbevis",
    "depositionsbevisets": "depositionsbevis",
    "depositumet": "depositum",
    "depositumets": "depositum",
    "depositums": "depositum",
    "depp": "deppa",
    "deppade": "deppad",
    "deppades": "deppad",
    "deppads": "deppad",
    "deppande": "deppa",
    "deppanden": "deppande",
    "deppandena": "deppande",
    "deppandenas": "deppande",
    "deppandens": "deppande",
    "deppandes": "deppande",
    "deppandet": "deppande",
    "deppandets": "deppande",
    "deppar": "deppa",
    "deppas": "deppa",
    "deppat": "deppad",
    "deppats": "deppad",
    "deppiga": "deppig",
    "deppigare": "deppig",
    "deppigares": "deppig",
    "deppigas": "deppig",
    "deppigast": "deppig",
    "deppigaste": "deppig",
    "deppigastes": "deppig",
    "deppigasts": "deppig",
    "deppige": "deppig",
    "deppiges": "deppig",
    "deppigheten": "deppighet",
    "deppighetens": "deppighet",
    "deppighets": "deppighet",
    "deppigs": "deppig",
    "deppigt": "deppig",
    "deppigts": "deppig",
    "depravationen": "depravation",
    "depravationens": "depravation",
    "depravationer": "depravation",
    "depravationerna": "depravation",
    "depravationernas": "depravation",
    "depravationers": "depravation",
    "depravations": "depravation",
    "depraverade": "depraverad",
    "depraverades": "depraverad",
    "depraverads": "depraverad",
    "depraverat": "depraverad",
    "depraverats": "depraverad",
    "deprecierad": "depreciera",
    "deprecierade": "depreciera",
    "deprecierades": "depreciera",
    "deprecierads": "depreciera",
    "deprecierande": "depreciera",
    "deprecieranden": "deprecierande",
    "deprecierandena": "deprecierande",
    "deprecierandenas": "deprecierande",
    "deprecierandens": "deprecierande",
    "deprecierandes": "deprecierande",
    "deprecierandet": "deprecierande",
    "deprecierandets": "deprecierande",
    "deprecierar": "depreciera",
    "deprecieras": "depreciera",
    "deprecierat": "depreciera",
    "deprecierats": "depreciera",
    "deprecierbara": "deprecierbar",
    "deprecierbarare": "deprecierbar",
    "deprecierbarares": "deprecierbar",
    "deprecierbaras": "deprecierbar",
    "deprecierbarast": "deprecierbar",
    "deprecierbaraste": "deprecierbar",
    "deprecierbarastes": "deprecierbar",
    "deprecierbarasts": "deprecierbar",
    "deprecierbare": "deprecierbar",
    "deprecierbares": "deprecierbar",
    "deprecierbarheten": "deprecierbarhet",
    "deprecierbarhetens": "deprecierbarhet",
    "deprecierbarhets": "deprecierbarhet",
    "deprecierbars": "deprecierbar",
    "deprecierbart": "deprecierbar",
    "deprecierbarts": "deprecierbar",
    "deprecieringar": "depreciering",
    "deprecieringarna": "depreciering",
    "deprecieringarnas": "depreciering",
    "deprecieringars": "depreciering",
    "deprecieringen": "depreciering",
    "deprecieringens": "depreciering",
    "deprecierings": "depreciering",
    "depressionen": "depression",
    "depressionens": "depression",
    "depressioner": "depression",
    "depressionerna": "depression",
    "depressionernas": "depression",
    "depressioners": "depression",
    "depressions": "depression",
    "depressionsdiagnosen": "depressionsdiagnos",
    "depressionsdiagnosens": "depressionsdiagnos",
    "depressionsdiagnoser": "depressionsdiagnos",
    "depressionsdiagnoserna": "depressionsdiagnos",
    "depressionsdiagnosernas": "depressionsdiagnos",
    "depressionsdiagnosers": "depressionsdiagnos",
    "depressiva": "depressiv",
    "depressivare": "depressiv",
    "depressivares": "depressiv",
    "depressivas": "depressiv",
    "depressivast": "depressiv",
    "depressivaste": "depressiv",
    "depressivastes": "depressiv",
    "depressivasts": "depressiv",
    "depressive": "depressiv",
    "depressives": "depressiv",
    "depressivs": "depressiv",
    "depressivt": "depressiv",
    "depressivts": "depressiv",
    "deprimerade": "deprimerad",
    "deprimerades": "deprimerad",
    "deprimerads": "deprimerad",
    "deprimerat": "deprimerad",
    "deprimerats": "deprimerad",
    "deprivationen": "deprivation",
    "deprivationens": "deprivation",
    "deprivationer": "deprivation",
    "deprivationerna": "deprivation",
    "deprivationernas": "deprivation",
    "deprivationers": "deprivation",
    "deprivations": "deprivation",
    "deputationen": "deputation",
    "deputationens": "deputation",
    "deputationer": "deputation",
    "deputationerna": "deputation",
    "deputationernas": "deputation",
    "deputationers": "deputation",
    "deputations": "deputation",
    "deputerade": "deputerad",
    "deputeraden": "deputerad",
    "deputeradena": "deputerad",
    "deputeradenas": "deputerad",
    "deputeradens": "deputerad",
    "deputerades": "deputerad",
    "deputerads": "deputerad",
    "depåer": "depå",
    "depåerna": "depå",
    "depåernas": "depå",
    "depåers": "depå",
    "depåfynden": "depåfynd",
    "depåfyndens": "depåfynd",
    "depåfyndet": "depåfynd",
    "depåfyndets": "depåfynd",
    "depåfynds": "depåfynd",
    "depån": "depå",
    "depåns": "depå",
    "depås": "depå",
    "depåstödet": "depåstöd",
    "depåstödets": "depåstöd",
    "depåstöds": "depåstöd",
    "derangerad": "derangera",
    "derangerade": "derangera",
    "derangerades": "derangera",
    "derangerads": "derangera",
    "derangerande": "derangera",
    "derangeranden": "derangerande",
    "derangerandena": "derangerande",
    "derangerandenas": "derangerande",
    "derangerandens": "derangerande",
    "derangerandes": "derangerande",
    "derangerandet": "derangerande",
    "derangerandets": "derangerande",
    "derangerar": "derangera",
    "derangeras": "derangera",
    "derangerat": "derangera",
    "derangerats": "derangera",
    "derangerbara": "derangerbar",
    "derangerbarare": "derangerbar",
    "derangerbarares": "derangerbar",
    "derangerbaras": "derangerbar",
    "derangerbarast": "derangerbar",
    "derangerbaraste": "derangerbar",
    "derangerbarastes": "derangerbar",
    "derangerbarasts": "derangerbar",
    "derangerbare": "derangerbar",
    "derangerbares": "derangerbar",
    "derangerbarheten": "derangerbarhet",
    "derangerbarhetens": "derangerbarhet",
    "derangerbarhets": "derangerbarhet",
    "derangerbars": "derangerbar",
    "derangerbart": "derangerbar",
    "derangerbarts": "derangerbar",
    "derangeringar": "derangering",
    "derangeringarna": "derangering",
    "derangeringarnas": "derangering",
    "derangeringars": "derangering",
    "derangeringen": "derangering",
    "derangeringens": "derangering",
    "derangerings": "derangering",
    "deras": "de",
    "derbyn": "derby",
    "derbyna": "derby",
    "derbynas": "derby",
    "derbyns": "derby",
    "derbys": "derby",
    "derbyt": "derby",
    "derbyts": "derby",
    "derivat": "derivata",
    "derivatan": "derivata",
    "derivatans": "derivata",
    "derivatas": "derivata",
    "derivate": "derivata",
    "derivaten": "derivat",
    "derivatens": "derivat",
    "derivatet": "derivat",
    "derivatets": "derivat",
    "derivationen": "derivation",
    "derivationens": "derivation",
    "derivationer": "derivation",
    "derivationerna": "derivation",
    "derivationernas": "derivation",
    "derivationers": "derivation",
    "derivations": "derivation",
    "derivator": "derivata",
    "derivatorna": "derivata",
    "derivatornas": "derivata",
    "derivators": "derivata",
    "derivats": "derivata",
    "deriverad": "derivera",
    "deriverade": "derivera",
    "deriverades": "derivera",
    "deriverads": "derivera",
    "deriverande": "derivera",
    "deriveranden": "deriverande",
    "deriverandena": "deriverande",
    "deriverandenas": "deriverande",
    "deriverandens": "deriverande",
    "deriverandes": "deriverande",
    "deriverandet": "deriverande",
    "deriverandets": "deriverande",
    "deriverar": "derivera",
    "deriveras": "derivera",
    "deriverat": "derivera",
    "deriverats": "derivera",
    "deriverbara": "deriverbar",
    "deriverbarare": "deriverbar",
    "deriverbarares": "deriverbar",
    "deriverbaras": "deriverbar",
    "deriverbarast": "deriverbar",
    "deriverbaraste": "deriverbar",
    "deriverbarastes": "deriverbar",
    "deriverbarasts": "deriverbar",
    "deriverbare": "deriverbar",
    "deriverbares": "deriverbar",
    "deriverbarheten": "deriverbarhet",
    "deriverbarhetens": "deriverbarhet",
    "deriverbarhets": "deriverbarhet",
    "deriverbars": "deriverbar",
    "deriverbart": "deriverbar",
    "deriverbarts": "deriverbar",
    "deriveringar": "derivering",
    "deriveringarna": "derivering",
    "deriveringarnas": "derivering",
    "deriveringars": "derivering",
    "deriveringen": "derivering",
    "deriveringens": "derivering",
    "deriverings": "derivering",
    "dermatiten": "dermatit",
    "dermatitens": "dermatit",
    "dermatiter": "dermatit",
    "dermatiterna": "dermatit",
    "dermatiternas": "dermatit",
    "dermatiters": "dermatit",
    "dermatits": "dermatit",
    "dermatologen": "dermatolog",
    "dermatologens": "dermatolog",
    "dermatologer": "dermatolog",
    "dermatologerna": "dermatolog",
    "dermatologernas": "dermatolog",
    "dermatologers": "dermatolog",
    "dermatologien": "dermatologi",
    "dermatologiens": "dermatologi",
    "dermatologin": "dermatologi",
    "dermatologins": "dermatologi",
    "dermatologis": "dermatologi",
    "dermatologiska": "dermatologisk",
    "dermatologiskare": "dermatologisk",
    "dermatologiskares": "dermatologisk",
    "dermatologiskas": "dermatologisk",
    "dermatologiskast": "dermatologisk",
    "dermatologiskaste": "dermatologisk",
    "dermatologiskastes": "dermatologisk",
    "dermatologiskasts": "dermatologisk",
    "dermatologiske": "dermatologisk",
    "dermatologiskes": "dermatologisk",
    "dermatologisks": "dermatologisk",
    "dermatologiskt": "dermatologisk",
    "dermatologiskts": "dermatologisk",
    "dermatologs": "dermatolog",
    "dervischdansen": "dervischdans",
    "dervischdansens": "dervischdans",
    "dervischdanser": "dervischdans",
    "dervischdanserna": "dervischdans",
    "dervischdansernas": "dervischdans",
    "dervischdansers": "dervischdans",
    "dervischen": "dervisch",
    "dervischens": "dervisch",
    "dervischer": "dervisch",
    "dervischerna": "dervisch",
    "dervischernas": "dervisch",
    "dervischers": "dervisch",
    "dervischs": "dervisch",
    "desamma": "densamma",
    "desammas": "densamma",
    "desarmerad": "desarmera",
    "desarmerade": "desarmera",
    "desarmerades": "desarmera",
    "desarmerads": "desarmera",
    "desarmerande": "desarmera",
    "desarmeranden": "desarmerande",
    "desarmerandena": "desarmerande",
    "desarmerandenas": "desarmerande",
    "desarmerandens": "desarmerande",
    "desarmerandes": "desarmerande",
    "desarmerandet": "desarmerande",
    "desarmerandets": "desarmerande",
    "desarmerar": "desarmera",
    "desarmeras": "desarmera",
    "desarmerat": "desarmera",
    "desarmerats": "desarmera",
    "desarmerbara": "desarmerbar",
    "desarmerbarare": "desarmerbar",
    "desarmerbarares": "desarmerbar",
    "desarmerbaras": "desarmerbar",
    "desarmerbarast": "desarmerbar",
    "desarmerbaraste": "desarmerbar",
    "desarmerbarastes": "desarmerbar",
    "desarmerbarasts": "desarmerbar",
    "desarmerbare": "desarmerbar",
    "desarmerbares": "desarmerbar",
    "desarmerbarheten": "desarmerbarhet",
    "desarmerbarhetens": "desarmerbarhet",
    "desarmerbarhets": "desarmerbarhet",
    "desarmerbars": "desarmerbar",
    "desarmerbart": "desarmerbar",
    "desarmerbarts": "desarmerbar",
    "desarmeringar": "desarmering",
    "desarmeringarna": "desarmering",
    "desarmeringarnas": "desarmering",
    "desarmeringars": "desarmering",
    "desarmeringen": "desarmering",
    "desarmeringens": "desarmering",
    "desarmerings": "desarmering",
    "desavouerad": "desavouera",
    "desavouerade": "desavouera",
    "desavouerades": "desavouera",
    "desavouerads": "desavouera",
    "desavouerande": "desavouera",
    "desavoueranden": "desavouerande",
    "desavouerandena": "desavouerande",
    "desavouerandenas": "desavouerande",
    "desavouerandens": "desavouerande",
    "desavouerandes": "desavouerande",
    "desavouerandet": "desavouerande",
    "desavouerandets": "desavouerande",
    "desavouerar": "desavouera",
    "desavoueras": "desavouera",
    "desavouerat": "desavouera",
    "desavouerats": "desavouera",
    "desavouerbara": "desavouerbar",
    "desavouerbarare": "desavouerbar",
    "desavouerbarares": "desavouerbar",
    "desavouerbaras": "desavouerbar",
    "desavouerbarast": "desavouerbar",
    "desavouerbaraste": "desavouerbar",
    "desavouerbarastes": "desavouerbar",
    "desavouerbarasts": "desavouerbar",
    "desavouerbare": "desavouerbar",
    "desavouerbares": "desavouerbar",
    "desavouerbarheten": "desavouerbarhet",
    "desavouerbarhetens": "desavouerbarhet",
    "desavouerbarhets": "desavouerbarhet",
    "desavouerbars": "desavouerbar",
    "desavouerbart": "desavouerbar",
    "desavouerbarts": "desavouerbar",
    "desavoueringar": "desavouering",
    "desavoueringarna": "desavouering",
    "desavoueringarnas": "desavouering",
    "desavoueringars": "desavouering",
    "desavoueringen": "desavouering",
    "desavoueringens": "desavouering",
    "desavouerings": "desavouering",
    "descendensen": "descendens",
    "descendensens": "descendens",
    "descendenten": "descendent",
    "descendentens": "descendent",
    "descendenter": "descendent",
    "descendenterna": "descendent",
    "descendenternas": "descendent",
    "descendenters": "descendent",
    "descendents": "descendent",
    "desegregationen": "desegregation",
    "desegregationens": "desegregation",
    "desegregationer": "desegregation",
    "desegregationerna": "desegregation",
    "desegregationernas": "desegregation",
    "desegregationers": "desegregation",
    "desegregations": "desegregation",
    "desengagemanget": "desengagemang",
    "desengagemangets": "desengagemang",
    "desengagemangs": "desengagemang",
    "desensibiliserad": "desensibilisera",
    "desensibiliserade": "desensibilisera",
    "desensibiliserades": "desensibilisera",
    "desensibiliserads": "desensibilisera",
    "desensibiliserande": "desensibilisera",
    "desensibiliseranden": "desensibiliserande",
    "desensibiliserandena": "desensibiliserande",
    "desensibiliserandenas": "desensibiliserande",
    "desensibiliserandens": "desensibiliserande",
    "desensibiliserandes": "desensibiliserande",
    "desensibiliserandet": "desensibiliserande",
    "desensibiliserandets": "desensibiliserande",
    "desensibiliserar": "desensibilisera",
    "desensibiliseras": "desensibilisera",
    "desensibiliserat": "desensibilisera",
    "desensibiliserats": "desensibilisera",
    "desensibiliserbara": "desensibiliserbar",
    "desensibiliserbarare": "desensibiliserbar",
    "desensibiliserbarares": "desensibiliserbar",
    "desensibiliserbaras": "desensibiliserbar",
    "desensibiliserbarast": "desensibiliserbar",
    "desensibiliserbaraste": "desensibiliserbar",
    "desensibiliserbarastes": "desensibiliserbar",
    "desensibiliserbarasts": "desensibiliserbar",
    "desensibiliserbare": "desensibiliserbar",
    "desensibiliserbares": "desensibiliserbar",
    "desensibiliserbarheten": "desensibiliserbarhet",
    "desensibiliserbarhetens": "desensibiliserbarhet",
    "desensibiliserbarhets": "desensibiliserbarhet",
    "desensibiliserbars": "desensibiliserbar",
    "desensibiliserbart": "desensibiliserbar",
    "desensibiliserbarts": "desensibiliserbar",
    "desensibiliseringar": "desensibilisering",
    "desensibiliseringarna": "desensibilisering",
    "desensibiliseringarnas": "desensibilisering",
    "desensibiliseringars": "desensibilisering",
    "desensibiliseringen": "desensibilisering",
    "desensibiliseringens": "desensibilisering",
    "desensibiliserings": "desensibilisering",
    "deserterade": "desertera",
    "deserterades": "desertera",
    "deserterande": "desertera",
    "deserteranden": "deserterande",
    "deserterandena": "deserterande",
    "deserterandenas": "deserterande",
    "deserterandens": "deserterande",
    "deserterandes": "deserterande",
    "deserterandet": "deserterande",
    "deserterandets": "deserterande",
    "deserterar": "desertera",
    "deserteras": "desertera",
    "deserterat": "desertera",
    "deserterats": "desertera",
    "deserteringar": "desertering",
    "deserteringarna": "desertering",
    "deserteringarnas": "desertering",
    "deserteringars": "desertering",
    "deserteringen": "desertering",
    "deserteringens": "desertering",
    "deserterings": "desertering",
    "desertören": "desertör",
    "desertörens": "desertör",
    "desertörer": "desertör",
    "desertörerna": "desertör",
    "desertörernas": "desertör",
    "desertörers": "desertör",
    "desertörs": "desertör",
    "deshabilléer": "deshabillé",
    "deshabilléerna": "deshabillé",
    "deshabilléernas": "deshabillé",
    "deshabilléers": "deshabillé",
    "deshabillén": "deshabillé",
    "deshabilléns": "deshabillé",
    "deshabillés": "deshabillé",
    "design": "designa",
    "designad": "designa",
    "designade": "designa",
    "designades": "designa",
    "designads": "designa",
    "designande": "designa",
    "designanden": "designande",
    "designandena": "designande",
    "designandenas": "designande",
    "designandens": "designande",
    "designandes": "designande",
    "designandet": "designande",
    "designandets": "designande",
    "designar": "designa",
    "designas": "designa",
    "designat": "designa",
    "designats": "designa",
    "designen": "design",
    "designens": "design",
    "designerad": "designera",
    "designerade": "designera",
    "designerades": "designera",
    "designerads": "designera",
    "designerande": "designera",
    "designeranden": "designerande",
    "designerandena": "designerande",
    "designerandenas": "designerande",
    "designerandens": "designerande",
    "designerandes": "designerande",
    "designerandet": "designerande",
    "designerandets": "designerande",
    "designerar": "designera",
    "designeras": "designera",
    "designerat": "designera",
    "designerats": "designera",
    "designerbara": "designerbar",
    "designerbarare": "designerbar",
    "designerbarares": "designerbar",
    "designerbaras": "designerbar",
    "designerbarast": "designerbar",
    "designerbaraste": "designerbar",
    "designerbarastes": "designerbar",
    "designerbarasts": "designerbar",
    "designerbare": "designerbar",
    "designerbares": "designerbar",
    "designerbarheten": "designerbarhet",
    "designerbarhetens": "designerbarhet",
    "designerbarhets": "designerbarhet",
    "designerbars": "designerbar",
    "designerbart": "designerbar",
    "designerbarts": "designerbar",
    "designeringar": "designering",
    "designeringarna": "designering",
    "designeringarnas": "designering",
    "designeringars": "designering",
    "designeringen": "designering",
    "designeringens": "designering",
    "designerings": "designering",
    "designern": "designer",
    "designerna": "designer",
    "designernas": "designer",
    "designerns": "designer",
    "designers": "designer",
    "designersarna": "designer",
    "designersarnas": "designer",
    "designersen": "designer",
    "designersens": "designer",
    "designmässiga": "designmässig",
    "designmässigare": "designmässig",
    "designmässigares": "designmässig",
    "designmässigas": "designmässig",
    "designmässigast": "designmässig",
    "designmässigaste": "designmässig",
    "designmässigastes": "designmässig",
    "designmässigasts": "designmässig",
    "designmässige": "designmässig",
    "designmässiges": "designmässig",
    "designmässigs": "designmässig",
    "designmässigt": "designmässig",
    "designmässigts": "designmässig",
    "designs": "design",
    "designtävlingar": "designtävling",
    "designtävlingarna": "designtävling",
    "designtävlingarnas": "designtävling",
    "designtävlingars": "designtävling",
    "designtävlingen": "designtävling",
    "designtävlingens": "designtävling",
    "designtävlings": "designtävling",
    "desillusionen": "desillusion",
    "desillusionens": "desillusion",
    "desillusioner": "desillusion",
    "desillusionerade": "desillusionerad",
    "desillusionerades": "desillusionerad",
    "desillusionerads": "desillusionerad",
    "desillusionerat": "desillusionerad",
    "desillusionerats": "desillusionerad",
    "desillusionerna": "desillusion",
    "desillusionernas": "desillusion",
    "desillusioners": "desillusion",
    "desillusions": "desillusion",
    "desinfekterad": "desinfektera",
    "desinfekterade": "desinfektera",
    "desinfekterades": "desinfektera",
    "desinfekterads": "desinfektera",
    "desinfekterande": "desinfektera",
    "desinfekteranden": "desinfekterande",
    "desinfekterandena": "desinfekterande",
    "desinfekterandenas": "desinfekterande",
    "desinfekterandens": "desinfekterande",
    "desinfekterandes": "desinfekterande",
    "desinfekterandet": "desinfekterande",
    "desinfekterandets": "desinfekterande",
    "desinfekterar": "desinfektera",
    "desinfekteras": "desinfektera",
    "desinfekterat": "desinfektera",
    "desinfekterats": "desinfektera",
    "desinfekterbara": "desinfekterbar",
    "desinfekterbarare": "desinfekterbar",
    "desinfekterbarares": "desinfekterbar",
    "desinfekterbaras": "desinfekterbar",
    "desinfekterbarast": "desinfekterbar",
    "desinfekterbaraste": "desinfekterbar",
    "desinfekterbarastes": "desinfekterbar",
    "desinfekterbarasts": "desinfekterbar",
    "desinfekterbare": "desinfekterbar",
    "desinfekterbares": "desinfekterbar",
    "desinfekterbarheten": "desinfekterbarhet",
    "desinfekterbarhetens": "desinfekterbarhet",
    "desinfekterbarhets": "desinfekterbarhet",
    "desinfekterbars": "desinfekterbar",
    "desinfekterbart": "desinfekterbar",
    "desinfekterbarts": "desinfekterbar",
    "desinfekteringar": "desinfektering",
    "desinfekteringarna": "desinfektering",
    "desinfekteringarnas": "desinfektering",
    "desinfekteringars": "desinfektering",
    "desinfekteringen": "desinfektering",
    "desinfekteringens": "desinfektering",
    "desinfekterings": "desinfektering",
    "desinfektionen": "desinfektion",
    "desinfektionens": "desinfektion",
    "desinfektioner": "desinfektion",
    "desinfektionerna": "desinfektion",
    "desinfektionernas": "desinfektion",
    "desinfektioners": "desinfektion",
    "desinfektions": "desinfektion",
    "desinfektionsmedels": "desinfektionsmedel",
    "desinfektionsmedlen": "desinfektionsmedel",
    "desinfektionsmedlens": "desinfektionsmedel",
    "desinfektionsmedlet": "desinfektionsmedel",
    "desinfektionsmedlets": "desinfektionsmedel",
    "desinfektören": "desinfektör",
    "desinfektörens": "desinfektör",
    "desinfektörer": "desinfektör",
    "desinfektörerna": "desinfektör",
    "desinfektörernas": "desinfektör",
    "desinfektörers": "desinfektör",
    "desinfektörs": "desinfektör",
    "desinficerad": "desinficera",
    "desinficerade": "desinficera",
    "desinficerades": "desinficera",
    "desinficerads": "desinficera",
    "desinficerande": "desinficera",
    "desinficeranden": "desinficerande",
    "desinficerandena": "desinficerande",
    "desinficerandenas": "desinficerande",
    "desinficerandens": "desinficerande",
    "desinficerandes": "desinficerande",
    "desinficerandet": "desinficerande",
    "desinficerandets": "desinficerande",
    "desinficerar": "desinficera",
    "desinficeras": "desinficera",
    "desinficerat": "desinficera",
    "desinficerats": "desinficera",
    "desinficerbara": "desinficerbar",
    "desinficerbarare": "desinficerbar",
    "desinficerbarares": "desinficerbar",
    "desinficerbaras": "desinficerbar",
    "desinficerbarast": "desinficerbar",
    "desinficerbaraste": "desinficerbar",
    "desinficerbarastes": "desinficerbar",
    "desinficerbarasts": "desinficerbar",
    "desinficerbare": "desinficerbar",
    "desinficerbares": "desinficerbar",
    "desinficerbarheten": "desinficerbarhet",
    "desinficerbarhetens": "desinficerbarhet",
    "desinficerbarhets": "desinficerbarhet",
    "desinficerbars": "desinficerbar",
    "desinficerbart": "desinficerbar",
    "desinficerbarts": "desinficerbar",
    "desinficeringar": "desinficering",
    "desinficeringarna": "desinficering",
    "desinficeringarnas": "desinficering",
    "desinficeringars": "desinficering",
    "desinficeringen": "desinficering",
    "desinficeringens": "desinficering",
    "desinficerings": "desinficering",
    "desinficeringsmedels": "desinficeringsmedel",
    "desinficeringsmedlen": "desinficeringsmedel",
    "desinficeringsmedlens": "desinficeringsmedel",
    "desinficeringsmedlet": "desinficeringsmedel",
    "desinficeringsmedlets": "desinficeringsmedel",
    "desinformationen": "desinformation",
    "desinformationens": "desinformation",
    "desinformationer": "desinformation",
    "desinformationerna": "desinformation",
    "desinformationernas": "desinformation",
    "desinformationers": "desinformation",
    "desinformations": "desinformation",
    "desinformerad": "desinformera",
    "desinformerade": "desinformera",
    "desinformerades": "desinformera",
    "desinformerads": "desinformera",
    "desinformerande": "desinformera",
    "desinformeranden": "desinformerande",
    "desinformerandena": "desinformerande",
    "desinformerandenas": "desinformerande",
    "desinformerandens": "desinformerande",
    "desinformerandes": "desinformerande",
    "desinformerandet": "desinformerande",
    "desinformerandets": "desinformerande",
    "desinformerar": "desinformera",
    "desinformeras": "desinformera",
    "desinformerat": "desinformera",
    "desinformerats": "desinformera",
    "desinformerbara": "desinformerbar",
    "desinformerbarare": "desinformerbar",
    "desinformerbarares": "desinformerbar",
    "desinformerbaras": "desinformerbar",
    "desinformerbarast": "desinformerbar",
    "desinformerbaraste": "desinformerbar",
    "desinformerbarastes": "desinformerbar",
    "desinformerbarasts": "desinformerbar",
    "desinformerbare": "desinformerbar",
    "desinformerbares": "desinformerbar",
    "desinformerbarheten": "desinformerbarhet",
    "desinformerbarhetens": "desinformerbarhet",
    "desinformerbarhets": "desinformerbarhet",
    "desinformerbars": "desinformerbar",
    "desinformerbart": "desinformerbar",
    "desinformerbarts": "desinformerbar",
    "desinformeringar": "desinformering",
    "desinformeringarna": "desinformering",
    "desinformeringarnas": "desinformering",
    "desinformeringars": "desinformering",
    "desinformeringen": "desinformering",
    "desinformeringens": "desinformering",
    "desinformerings": "desinformering",
    "desinsektionen": "desinsektion",
    "desinsektionens": "desinsektion",
    "desinsektioner": "desinsektion",
    "desinsektionerna": "desinsektion",
    "desinsektionernas": "desinsektion",
    "desinsektioners": "desinsektion",
    "desinsektions": "desinsektion",
    "desintegrationen": "desintegration",
    "desintegrationens": "desintegration",
    "desintegrationer": "desintegration",
    "desintegrationerna": "desintegration",
    "desintegrationernas": "desintegration",
    "desintegrationers": "desintegration",
    "desintegrations": "desintegration",
    "desintresserade": "desintresserad",
    "desintresserades": "desintresserad",
    "desintresserads": "desintresserad",
    "desintresserat": "desintresserad",
    "desintresserats": "desintresserad",
    "deskriptionen": "deskription",
    "deskriptionens": "deskription",
    "deskriptioner": "deskription",
    "deskriptionerna": "deskription",
    "deskriptionernas": "deskription",
    "deskriptioners": "deskription",
    "deskriptions": "deskription",
    "deskriptiva": "deskriptiv",
    "deskriptivare": "deskriptiv",
    "deskriptivares": "deskriptiv",
    "deskriptivas": "deskriptiv",
    "deskriptivast": "deskriptiv",
    "deskriptivaste": "deskriptiv",
    "deskriptivastes": "deskriptiv",
    "deskriptivasts": "deskriptiv",
    "deskriptive": "deskriptiv",
    "deskriptives": "deskriptiv",
    "deskriptivs": "deskriptiv",
    "deskriptivt": "deskriptiv",
    "deskriptivts": "deskriptiv",
    "desorganisationen": "desorganisation",
    "desorganisationens": "desorganisation",
    "desorganisationer": "desorganisation",
    "desorganisationerna": "desorganisation",
    "desorganisationernas": "desorganisation",
    "desorganisationers": "desorganisation",
    "desorganisations": "desorganisation",
    "desorganiserad": "desorganisera",
    "desorganiserade": "desorganisera",
    "desorganiserades": "desorganisera",
    "desorganiserads": "desorganisera",
    "desorganiserande": "desorganisera",
    "desorganiseranden": "desorganiserande",
    "desorganiserandena": "desorganiserande",
    "desorganiserandenas": "desorganiserande",
    "desorganiserandens": "desorganiserande",
    "desorganiserandes": "desorganiserande",
    "desorganiserandet": "desorganiserande",
    "desorganiserandets": "desorganiserande",
    "desorganiserar": "desorganisera",
    "desorganiseras": "desorganisera",
    "desorganiserat": "desorganisera",
    "desorganiserats": "desorganisera",
    "desorganiserbara": "desorganiserbar",
    "desorganiserbarare": "desorganiserbar",
    "desorganiserbarares": "desorganiserbar",
    "desorganiserbaras": "desorganiserbar",
    "desorganiserbarast": "desorganiserbar",
    "desorganiserbaraste": "desorganiserbar",
    "desorganiserbarastes": "desorganiserbar",
    "desorganiserbarasts": "desorganiserbar",
    "desorganiserbare": "desorganiserbar",
    "desorganiserbares": "desorganiserbar",
    "desorganiserbarheten": "desorganiserbarhet",
    "desorganiserbarhetens": "desorganiserbarhet",
    "desorganiserbarhets": "desorganiserbarhet",
    "desorganiserbars": "desorganiserbar",
    "desorganiserbart": "desorganiserbar",
    "desorganiserbarts": "desorganiserbar",
    "desorganiseringar": "desorganisering",
    "desorganiseringarna": "desorganisering",
    "desorganiseringarnas": "desorganisering",
    "desorganiseringars": "desorganisering",
    "desorganiseringen": "desorganisering",
    "desorganiseringens": "desorganisering",
    "desorganiserings": "desorganisering",
    "desorienterade": "desorienterad",
    "desorienterades": "desorienterad",
    "desorienterads": "desorienterad",
    "desorienterat": "desorienterad",
    "desorienterats": "desorienterad",
    "desorienteringar": "desorientering",
    "desorienteringarna": "desorientering",
    "desorienteringarnas": "desorientering",
    "desorienteringars": "desorientering",
    "desorienteringen": "desorientering",
    "desorienteringens": "desorientering",
    "desorienterings": "desorientering",
    "desperadon": "desperado",
    "desperadons": "desperado",
    "desperador": "desperado",
    "desperadorna": "desperado",
    "desperadornas": "desperado",
    "desperadors": "desperado",
    "desperados": "desperado",
    "desperadosen": "desperado",
    "desperadosens": "desperado",
    "desperata": "desperat",
    "desperatare": "desperat",
    "desperatares": "desperat",
    "desperatas": "desperat",
    "desperatast": "desperat",
    "desperataste": "desperat",
    "desperatastes": "desperat",
    "desperatasts": "desperat",
    "desperate": "desperat",
    "desperates": "desperat",
    "desperationen": "desperation",
    "desperationens": "desperation",
    "desperationer": "desperation",
    "desperationerna": "desperation",
    "desperationernas": "desperation",
    "desperationers": "desperation",
    "desperations": "desperation",
    "desperats": "desperat",
    "despoten": "despot",
    "despotens": "despot",
    "despoter": "despot",
    "despoterna": "despot",
    "despoternas": "despot",
    "despoters": "despot",
    "despotien": "despoti",
    "despotiens": "despoti",
    "despotier": "despoti",
    "despotierna": "despoti",
    "despotiernas": "despoti",
    "despotiers": "despoti",
    "despotin": "despoti",
    "despotins": "despoti",
    "despotis": "despoti",
    "despotiska": "despotisk",
    "despotiskare": "despotisk",
    "despotiskares": "despotisk",
    "despotiskas": "despotisk",
    "despotiskast": "despotisk",
    "despotiskaste": "despotisk",
    "despotiskastes": "despotisk",
    "despotiskasts": "despotisk",
    "despotiske": "despotisk",
    "despotiskes": "despotisk",
    "despotisks": "despotisk",
    "despotiskt": "despotisk",
    "despotiskts": "despotisk",
    "despotismen": "despotism",
    "despotismens": "despotism",
    "despotismer": "despotism",
    "despotismerna": "despotism",
    "despotismernas": "despotism",
    "despotismers": "despotism",
    "despotisms": "despotism",
    "despots": "despot",
    "dess": "den",
    "dessa": "denna",
    "dessas": "denna",
    "desserten": "dessert",
    "dessertens": "dessert",
    "desserter": "dessert",
    "desserterna": "dessert",
    "desserternas": "dessert",
    "desserters": "dessert",
    "dessertgaffeln": "dessertgaffel",
    "dessertgaffelns": "dessertgaffel",
    "dessertgaffels": "dessertgaffel",
    "dessertgafflar": "dessertgaffel",
    "dessertgafflarna": "dessertgaffel",
    "dessertgafflarnas": "dessertgaffel",
    "dessertgafflars": "dessertgaffel",
    "dessertknivar": "dessertkniv",
    "dessertknivarna": "dessertkniv",
    "dessertknivarnas": "dessertkniv",
    "dessertknivars": "dessertkniv",
    "dessertkniven": "dessertkniv",
    "dessertknivens": "dessertkniv",
    "dessertknivs": "dessertkniv",
    "dessertostar": "dessertost",
    "dessertostarna": "dessertost",
    "dessertostarnas": "dessertost",
    "dessertostars": "dessertost",
    "dessertosten": "dessertost",
    "dessertostens": "dessertost",
    "dessertosts": "dessertost",
    "desserts": "dessert",
    "dessertskedar": "dessertsked",
    "dessertskedarna": "dessertsked",
    "dessertskedarnas": "dessertsked",
    "dessertskedars": "dessertsked",
    "dessertskeden": "dessertsked",
    "dessertskedens": "dessertsked",
    "dessertskeds": "dessertsked",
    "dessertsåsen": "dessertsås",
    "dessertsåsens": "dessertsås",
    "dessertsåser": "dessertsås",
    "dessertsåserna": "dessertsås",
    "dessertsåsernas": "dessertsås",
    "dessertsåsers": "dessertsås",
    "desserttallrikar": "desserttallrik",
    "desserttallrikarna": "desserttallrik",
    "desserttallrikarnas": "desserttallrik",
    "desserttallrikars": "desserttallrik",
    "desserttallriken": "desserttallrik",
    "desserttallrikens": "desserttallrik",
    "desserttallriks": "desserttallrik",
    "dessertviner": "dessertvin",
    "dessertvinerna": "dessertvin",
    "dessertvinernas": "dessertvin",
    "dessertviners": "dessertvin",
    "dessertvinet": "dessertvin",
    "dessertvinets": "dessertvin",
    "dessertvins": "dessertvin",
    "dessinatören": "dessinatör",
    "dessinatörens": "dessinatör",
    "dessinatörer": "dessinatör",
    "dessinatörerna": "dessinatör",
    "dessinatörernas": "dessinatör",
    "dessinatörers": "dessinatör",
    "dessinatörs": "dessinatör",
    "dessängen": "dessäng",
    "dessängens": "dessäng",
    "dessänger": "dessäng",
    "dessängerna": "dessäng",
    "dessängernas": "dessäng",
    "dessängers": "dessäng",
    "dessängs": "dessäng",
    "destabiliserad": "destabilisera",
    "destabiliserade": "destabilisera",
    "destabiliserades": "destabilisera",
    "destabiliserads": "destabilisera",
    "destabiliserande": "destabilisera",
    "destabiliseranden": "destabiliserande",
    "destabiliserandena": "destabiliserande",
    "destabiliserandenas": "destabiliserande",
    "destabiliserandens": "destabiliserande",
    "destabiliserandes": "destabiliserande",
    "destabiliserandet": "destabiliserande",
    "destabiliserandets": "destabiliserande",
    "destabiliserar": "destabilisera",
    "destabiliseras": "destabilisera",
    "destabiliserat": "destabilisera",
    "destabiliserats": "destabilisera",
    "destabiliserbara": "destabiliserbar",
    "destabiliserbarare": "destabiliserbar",
    "destabiliserbarares": "destabiliserbar",
    "destabiliserbaras": "destabiliserbar",
    "destabiliserbarast": "destabiliserbar",
    "destabiliserbaraste": "destabiliserbar",
    "destabiliserbarastes": "destabiliserbar",
    "destabiliserbarasts": "destabiliserbar",
    "destabiliserbare": "destabiliserbar",
    "destabiliserbares": "destabiliserbar",
    "destabiliserbarheten": "destabiliserbarhet",
    "destabiliserbarhetens": "destabiliserbarhet",
    "destabiliserbarhets": "destabiliserbarhet",
    "destabiliserbars": "destabiliserbar",
    "destabiliserbart": "destabiliserbar",
    "destabiliserbarts": "destabiliserbar",
    "destillaten": "destillat",
    "destillatens": "destillat",
    "destillatet": "destillat",
    "destillatets": "destillat",
    "destillationen": "destillation",
    "destillationens": "destillation",
    "destillationer": "destillation",
    "destillationerna": "destillation",
    "destillationernas": "destillation",
    "destillationers": "destillation",
    "destillations": "destillation",
    "destillationsapparaten": "destillationsapparat",
    "destillationsapparatens": "destillationsapparat",
    "destillationsapparater": "destillationsapparat",
    "destillationsapparaterna": "destillationsapparat",
    "destillationsapparaternas": "destillationsapparat",
    "destillationsapparaters": "destillationsapparat",
    "destillationsapparats": "destillationsapparat",
    "destillats": "destillat",
    "destillerad": "destillera",
    "destillerade": "destillera",
    "destillerades": "destillera",
    "destillerads": "destillera",
    "destillerande": "destillera",
    "destilleranden": "destillerande",
    "destillerandena": "destillerande",
    "destillerandenas": "destillerande",
    "destillerandens": "destillerande",
    "destillerandes": "destillerande",
    "destillerandet": "destillerande",
    "destillerandets": "destillerande",
    "destillerar": "destillera",
    "destilleras": "destillera",
    "destillerat": "destillera",
    "destillerats": "destillera",
    "destillerbara": "destillerbar",
    "destillerbarare": "destillerbar",
    "destillerbarares": "destillerbar",
    "destillerbaras": "destillerbar",
    "destillerbarast": "destillerbar",
    "destillerbaraste": "destillerbar",
    "destillerbarastes": "destillerbar",
    "destillerbarasts": "destillerbar",
    "destillerbare": "destillerbar",
    "destillerbares": "destillerbar",
    "destillerbarheten": "destillerbarhet",
    "destillerbarhetens": "destillerbarhet",
    "destillerbarhets": "destillerbarhet",
    "destillerbars": "destillerbar",
    "destillerbart": "destillerbar",
    "destillerbarts": "destillerbar",
    "destilleringar": "destillering",
    "destilleringarna": "destillering",
    "destilleringarnas": "destillering",
    "destilleringars": "destillering",
    "destilleringen": "destillering",
    "destilleringens": "destillering",
    "destillerings": "destillering",
    "destinationen": "destination",
    "destinationens": "destination",
    "destinationer": "destination",
    "destinationerna": "destination",
    "destinationernas": "destination",
    "destinationers": "destination",
    "destinations": "destination",
    "destinationsorten": "destinationsort",
    "destinationsortens": "destinationsort",
    "destinationsorter": "destinationsort",
    "destinationsorterna": "destinationsort",
    "destinationsorternas": "destinationsort",
    "destinationsorters": "destinationsort",
    "destinationsorts": "destinationsort",
    "destinatären": "destinatär",
    "destinatärens": "destinatär",
    "destinatärer": "destinatär",
    "destinatärerna": "destinatär",
    "destinatärernas": "destinatär",
    "destinatärers": "destinatär",
    "destinatärs": "destinatär",
    "destinatören": "destinatör",
    "destinatörens": "destinatör",
    "destinatörer": "destinatör",
    "destinatörerna": "destinatör",
    "destinatörernas": "destinatör",
    "destinatörers": "destinatör",
    "destinatörs": "destinatör",
    "destinerad": "destinera",
    "destinerade": "destinera",
    "destinerades": "destinera",
    "destinerads": "destinera",
    "destinerande": "destinera",
    "destineranden": "destinerande",
    "destinerandena": "destinerande",
    "destinerandenas": "destinerande",
    "destinerandens": "destinerande",
    "destinerandes": "destinerande",
    "destinerandet": "destinerande",
    "destinerandets": "destinerande",
    "destinerar": "destinera",
    "destineras": "destinera",
    "destinerat": "destinera",
    "destinerats": "destinera",
    "destinerbara": "destinerbar",
    "destinerbarare": "destinerbar",
    "destinerbarares": "destinerbar",
    "destinerbaras": "destinerbar",
    "destinerbarast": "destinerbar",
    "destinerbaraste": "destinerbar",
    "destinerbarastes": "destinerbar",
    "destinerbarasts": "destinerbar",
    "destinerbare": "destinerbar",
    "destinerbares": "destinerbar",
    "destinerbarheten": "destinerbarhet",
    "destinerbarhetens": "destinerbarhet",
    "destinerbarhets": "destinerbarhet",
    "destinerbars": "destinerbar",
    "destinerbart": "destinerbar",
    "destinerbarts": "destinerbar",
    "destineringar": "destinering",
    "destineringarna": "destinering",
    "destineringarnas": "destinering",
    "destineringars": "destinering",
    "destineringen": "destinering",
    "destineringens": "destinering",
    "destinerings": "destinering",
    "destruenten": "destruent",
    "destruentens": "destruent",
    "destruenter": "destruent",
    "destruenterna": "destruent",
    "destruenternas": "destruent",
    "destruenters": "destruent",
    "destruents": "destruent",
    "destruerad": "destruera",
    "destruerade": "destruera",
    "destruerades": "destruera",
    "destruerads": "destruera",
    "destruerande": "destruera",
    "destrueranden": "destruerande",
    "destruerandena": "destruerande",
    "destruerandenas": "destruerande",
    "destruerandens": "destruerande",
    "destruerandes": "destruerande",
    "destruerandet": "destruerande",
    "destruerandets": "destruerande",
    "destruerar": "destruera",
    "destrueras": "destruera",
    "destruerat": "destruera",
    "destruerats": "destruera",
    "destruerbara": "destruerbar",
    "destruerbarare": "destruerbar",
    "destruerbarares": "destruerbar",
    "destruerbaras": "destruerbar",
    "destruerbarast": "destruerbar",
    "destruerbaraste": "destruerbar",
    "destruerbarastes": "destruerbar",
    "destruerbarasts": "destruerbar",
    "destruerbare": "destruerbar",
    "destruerbares": "destruerbar",
    "destruerbarheten": "destruerbarhet",
    "destruerbarhetens": "destruerbarhet",
    "destruerbarhets": "destruerbarhet",
    "destruerbars": "destruerbar",
    "destruerbart": "destruerbar",
    "destruerbarts": "destruerbar",
    "destrueringar": "destruering",
    "destrueringarna": "destruering",
    "destrueringarnas": "destruering",
    "destrueringars": "destruering",
    "destrueringen": "destruering",
    "destrueringens": "destruering",
    "destruerings": "destruering",
    "destruktionen": "destruktion",
    "destruktionens": "destruktion",
    "destruktioner": "destruktion",
    "destruktionerna": "destruktion",
    "destruktionernas": "destruktion",
    "destruktioners": "destruktion",
    "destruktions": "destruktion",
    "destruktionsanläggningar": "destruktionsanläggning",
    "destruktionsanläggningarna": "destruktionsanläggning",
    "destruktionsanläggningarnas": "destruktionsanläggning",
    "destruktionsanläggningars": "destruktionsanläggning",
    "destruktionsanläggningen": "destruktionsanläggning",
    "destruktionsanläggningens": "destruktionsanläggning",
    "destruktionsanläggnings": "destruktionsanläggning",
    "destruktiva": "destruktiv",
    "destruktivare": "destruktiv",
    "destruktivares": "destruktiv",
    "destruktivas": "destruktiv",
    "destruktivast": "destruktiv",
    "destruktivaste": "destruktiv",
    "destruktivastes": "destruktiv",
    "destruktivasts": "destruktiv",
    "destruktive": "destruktiv",
    "destruktives": "destruktiv",
    "destruktivs": "destruktiv",
    "destruktivt": "destruktiv",
    "destruktivts": "destruktiv",
    "det": "en",
    "detachementen": "detachement",
    "detachementens": "detachement",
    "detachementet": "detachement",
    "detachementets": "detachement",
    "detachements": "detachement",
    "detacherad": "detachera",
    "detacherade": "detachera",
    "detacherades": "detachera",
    "detacherads": "detachera",
    "detacherande": "detachera",
    "detacheranden": "detacherande",
    "detacherandena": "detacherande",
    "detacherandenas": "detacherande",
    "detacherandens": "detacherande",
    "detacherandes": "detacherande",
    "detacherandet": "detacherande",
    "detacherandets": "detacherande",
    "detacherar": "detachera",
    "detacheras": "detachera",
    "detacherat": "detachera",
    "detacherats": "detachera",
    "detacherbara": "detacherbar",
    "detacherbarare": "detacherbar",
    "detacherbarares": "detacherbar",
    "detacherbaras": "detacherbar",
    "detacherbarast": "detacherbar",
    "detacherbaraste": "detacherbar",
    "detacherbarastes": "detacherbar",
    "detacherbarasts": "detacherbar",
    "detacherbare": "detacherbar",
    "detacherbares": "detacherbar",
    "detacherbarheten": "detacherbarhet",
    "detacherbarhetens": "detacherbarhet",
    "detacherbarhets": "detacherbarhet",
    "detacherbars": "detacherbar",
    "detacherbart": "detacherbar",
    "detacherbarts": "detacherbar",
    "detacheringar": "detachering",
    "detacheringarna": "detachering",
    "detacheringarnas": "detachering",
    "detacheringars": "detachering",
    "detacheringen": "detachering",
    "detacheringens": "detachering",
    "detacherings": "detachering",
    "detachören": "detachör",
    "detachörens": "detachör",
    "detachörer": "detachör",
    "detachörerna": "detachör",
    "detachörernas": "detachör",
    "detachörers": "detachör",
    "detachörs": "detachör",
    "detaljanmärkningar": "detaljanmärkning",
    "detaljanmärkningarna": "detaljanmärkning",
    "detaljanmärkningarnas": "detaljanmärkning",
    "detaljanmärkningars": "detaljanmärkning",
    "detaljanmärkningen": "detaljanmärkning",
    "detaljanmärkningens": "detaljanmärkning",
    "detaljanmärknings": "detaljanmärkning",
    "detaljen": "detalj",
    "detaljens": "detalj",
    "detaljer": "detalj",
    "detaljerade": "detaljerad",
    "detaljerades": "detaljerad",
    "detaljerads": "detaljerad",
    "detaljerat": "detaljerad",
    "detaljerats": "detaljerad",
    "detaljerna": "detalj",
    "detaljernas": "detalj",
    "detaljers": "detalj",
    "detaljfixerade": "detaljfixerad",
    "detaljfixerades": "detaljfixerad",
    "detaljfixerads": "detaljfixerad",
    "detaljfixerat": "detaljfixerad",
    "detaljfixerats": "detaljfixerad",
    "detaljfrågan": "detaljfråga",
    "detaljfrågans": "detaljfråga",
    "detaljfrågas": "detaljfråga",
    "detaljfråge": "detaljfråga",
    "detaljfrågor": "detaljfråga",
    "detaljfrågorna": "detaljfråga",
    "detaljfrågornas": "detaljfråga",
    "detaljfrågors": "detaljfråga",
    "detaljgranskad": "detaljgranska",
    "detaljgranskade": "detaljgranska",
    "detaljgranskades": "detaljgranska",
    "detaljgranskads": "detaljgranska",
    "detaljgranskande": "detaljgranska",
    "detaljgranskanden": "detaljgranskande",
    "detaljgranskandena": "detaljgranskande",
    "detaljgranskandenas": "detaljgranskande",
    "detaljgranskandens": "detaljgranskande",
    "detaljgranskandes": "detaljgranskande",
    "detaljgranskandet": "detaljgranskande",
    "detaljgranskandets": "detaljgranskande",
    "detaljgranskar": "detaljgranska",
    "detaljgranskas": "detaljgranska",
    "detaljgranskat": "detaljgranska",
    "detaljgranskats": "detaljgranska",
    "detaljhandeln": "detaljhandel",
    "detaljhandelns": "detaljhandel",
    "detaljhandels": "detaljhandel",
    "detaljhandlar": "detaljhandlare",
    "detaljhandlaren": "detaljhandlare",
    "detaljhandlarens": "detaljhandlare",
    "detaljhandlares": "detaljhandlare",
    "detaljhandlarna": "detaljhandlare",
    "detaljhandlarnas": "detaljhandlare",
    "detaljisten": "detaljist",
    "detaljistens": "detaljist",
    "detaljister": "detaljist",
    "detaljisterna": "detaljist",
    "detaljisternas": "detaljist",
    "detaljisters": "detaljist",
    "detaljists": "detaljist",
    "detaljkart": "detaljkarta",
    "detaljkartan": "detaljkarta",
    "detaljkartans": "detaljkarta",
    "detaljkartas": "detaljkarta",
    "detaljkarte": "detaljkarta",
    "detaljkartor": "detaljkarta",
    "detaljkartorna": "detaljkarta",
    "detaljkartornas": "detaljkarta",
    "detaljkartors": "detaljkarta",
    "detaljkarts": "detaljkarta",
    "detaljkännedomar": "detaljkännedom",
    "detaljkännedomarna": "detaljkännedom",
    "detaljkännedomarnas": "detaljkännedom",
    "detaljkännedomars": "detaljkännedom",
    "detaljkännedomen": "detaljkännedom",
    "detaljkännedomens": "detaljkännedom",
    "detaljkännedoms": "detaljkännedom",
    "detaljprisen": "detaljpris",
    "detaljprisens": "detaljpris",
    "detaljpriser": "detaljpris",
    "detaljpriserna": "detaljpris",
    "detaljprisernas": "detaljpris",
    "detaljprisers": "detaljpris",
    "detaljpriset": "detaljpris",
    "detaljprisets": "detaljpris",
    "detaljrika": "detaljrik",
    "detaljrikare": "detaljrik",
    "detaljrikares": "detaljrik",
    "detaljrikas": "detaljrik",
    "detaljrikast": "detaljrik",
    "detaljrikaste": "detaljrik",
    "detaljrikastes": "detaljrik",
    "detaljrikasts": "detaljrik",
    "detaljrike": "detaljrik",
    "detaljrikedomar": "detaljrikedom",
    "detaljrikedomarna": "detaljrikedom",
    "detaljrikedomarnas": "detaljrikedom",
    "detaljrikedomars": "detaljrikedom",
    "detaljrikedomen": "detaljrikedom",
    "detaljrikedomens": "detaljrikedom",
    "detaljrikedoms": "detaljrikedom",
    "detaljrikes": "detaljrik",
    "detaljrikheten": "detaljrikhet",
    "detaljrikhetens": "detaljrikhet",
    "detaljrikhets": "detaljrikhet",
    "detaljriks": "detaljrik",
    "detaljrikt": "detaljrik",
    "detaljrikts": "detaljrik",
    "detaljritningar": "detaljritning",
    "detaljritningarna": "detaljritning",
    "detaljritningarnas": "detaljritning",
    "detaljritningars": "detaljritning",
    "detaljritningen": "detaljritning",
    "detaljritningens": "detaljritning",
    "detaljritnings": "detaljritning",
    "detaljs": "detalj",
    "detaljskärpan": "detaljskärpa",
    "detaljskärpans": "detaljskärpa",
    "detaljskärpas": "detaljskärpa",
    "detaljstudie": "detaljstudium",
    "detaljstudier": "detaljstudium",
    "detaljstudierna": "detaljstudium",
    "detaljstudiernas": "detaljstudium",
    "detaljstudiers": "detaljstudium",
    "detaljstudiet": "detaljstudium",
    "detaljstudiets": "detaljstudium",
    "detaljstudiums": "detaljstudium",
    "detaljutföranden": "detaljutförande",
    "detaljutförandena": "detaljutförande",
    "detaljutförandenas": "detaljutförande",
    "detaljutförandens": "detaljutförande",
    "detaljutförandes": "detaljutförande",
    "detaljutförandet": "detaljutförande",
    "detaljutförandets": "detaljutförande",
    "detekterad": "detektera",
    "detekterade": "detektera",
    "detekterades": "detektera",
    "detekterads": "detektera",
    "detekterande": "detektera",
    "detekteranden": "detekterande",
    "detekterandena": "detekterande",
    "detekterandenas": "detekterande",
    "detekterandens": "detekterande",
    "detekterandes": "detekterande",
    "detekterandet": "detekterande",
    "detekterandets": "detekterande",
    "detekterar": "detektera",
    "detekteras": "detektera",
    "detekterat": "detektera",
    "detekterats": "detektera",
    "detekterbara": "detekterbar",
    "detekterbarare": "detekterbar",
    "detekterbarares": "detekterbar",
    "detekterbaras": "detekterbar",
    "detekterbarast": "detekterbar",
    "detekterbaraste": "detekterbar",
    "detekterbarastes": "detekterbar",
    "detekterbarasts": "detekterbar",
    "detekterbare": "detekterbar",
    "detekterbares": "detekterbar",
    "detekterbarheten": "detekterbarhet",
    "detekterbarhetens": "detekterbarhet",
    "detekterbarhets": "detekterbarhet",
    "detekterbars": "detekterbar",
    "detekterbart": "detekterbar",
    "detekterbarts": "detekterbar",
    "detekteringar": "detektering",
    "detekteringarna": "detektering",
    "detekteringarnas": "detektering",
    "detekteringars": "detektering",
    "detekteringen": "detektering",
    "detekteringens": "detektering",
    "detekterings": "detektering",
    "detektiva": "detektiv",
    "detektivarbeten": "detektivarbete",
    "detektivarbetena": "detektivarbete",
    "detektivarbetenas": "detektivarbete",
    "detektivarbetens": "detektivarbete",
    "detektivarbetes": "detektivarbete",
    "detektivarbetet": "detektivarbete",
    "detektivarbetets": "detektivarbete",
    "detektivarbets": "detektivarbete",
    "detektivare": "detektiv",
    "detektivares": "detektiv",
    "detektivas": "detektiv",
    "detektivast": "detektiv",
    "detektivaste": "detektiv",
    "detektivastes": "detektiv",
    "detektivasts": "detektiv",
    "detektivberättelsen": "detektivberättelse",
    "detektivberättelsens": "detektivberättelse",
    "detektivberättelser": "detektivberättelse",
    "detektivberättelserna": "detektivberättelse",
    "detektivberättelsernas": "detektivberättelse",
    "detektivberättelsers": "detektivberättelse",
    "detektivberättelses": "detektivberättelse",
    "detektive": "detektiv",
    "detektiven": "detektiv",
    "detektivens": "detektiv",
    "detektiver": "detektiv",
    "detektiverna": "detektiv",
    "detektivernas": "detektiv",
    "detektivers": "detektiv",
    "detektives": "detektiv",
    "detektivromanen": "detektivroman",
    "detektivromanens": "detektivroman",
    "detektivromaner": "detektivroman",
    "detektivromanerna": "detektivroman",
    "detektivromanernas": "detektivroman",
    "detektivromaners": "detektivroman",
    "detektivromans": "detektivroman",
    "detektivs": "detektiv",
    "detektivt": "detektiv",
    "detektivts": "detektiv",
    "detektorer": "detektor",
    "detektorerna": "detektor",
    "detektorernas": "detektor",
    "detektorers": "detektor",
    "detektorn": "detektor",
    "detektorns": "detektor",
    "detektors": "detektor",
    "detergenten": "detergent",
    "detergentens": "detergent",
    "detergenter": "detergent",
    "detergenterna": "detergent",
    "detergenternas": "detergent",
    "detergenters": "detergent",
    "detergents": "detergent",
    "determinationen": "determination",
    "determinationens": "determination",
    "determinationer": "determination",
    "determinationerna": "determination",
    "determinationernas": "determination",
    "determinationers": "determination",
    "determinations": "determination",
    "determinativa": "determinativ",
    "determinativare": "determinativ",
    "determinativares": "determinativ",
    "determinativas": "determinativ",
    "determinativast": "determinativ",
    "determinativaste": "determinativ",
    "determinativastes": "determinativ",
    "determinativasts": "determinativ",
    "determinative": "determinativ",
    "determinatives": "determinativ",
    "determinativs": "determinativ",
    "determinativt": "determinativ",
    "determinativts": "determinativ",
    "determinerad": "determinera",
    "determinerade": "determinera",
    "determinerades": "determinera",
    "determinerads": "determinera",
    "determinerande": "determinera",
    "determineranden": "determinerande",
    "determinerandena": "determinerande",
    "determinerandenas": "determinerande",
    "determinerandens": "determinerande",
    "determinerandes": "determinerande",
    "determinerandet": "determinerande",
    "determinerandets": "determinerande",
    "determinerar": "determinera",
    "determineras": "determinera",
    "determinerat": "determinera",
    "determinerats": "determinera",
    "determinerbara": "determinerbar",
    "determinerbarare": "determinerbar",
    "determinerbarares": "determinerbar",
    "determinerbaras": "determinerbar",
    "determinerbarast": "determinerbar",
    "determinerbaraste": "determinerbar",
    "determinerbarastes": "determinerbar",
    "determinerbarasts": "determinerbar",
    "determinerbare": "determinerbar",
    "determinerbares": "determinerbar",
    "determinerbarheten": "determinerbarhet",
    "determinerbarhetens": "determinerbarhet",
    "determinerbarhets": "determinerbarhet",
    "determinerbars": "determinerbar",
    "determinerbart": "determinerbar",
    "determinerbarts": "determinerbar",
    "determineringar": "determinering",
    "determineringarna": "determinering",
    "determineringarnas": "determinering",
    "determineringars": "determinering",
    "determineringen": "determinering",
    "determineringens": "determinering",
    "determinerings": "determinering",
    "determinismen": "determinism",
    "determinismens": "determinism",
    "determinismer": "determinism",
    "determinismerna": "determinism",
    "determinismernas": "determinism",
    "determinismers": "determinism",
    "determinisms": "determinism",
    "deterministen": "determinist",
    "deterministens": "determinist",
    "determinister": "determinist",
    "deterministerna": "determinist",
    "deterministernas": "determinist",
    "deterministers": "determinist",
    "deterministiska": "deterministisk",
    "deterministiskare": "deterministisk",
    "deterministiskares": "deterministisk",
    "deterministiskas": "deterministisk",
    "deterministiskast": "deterministisk",
    "deterministiskaste": "deterministisk",
    "deterministiskastes": "deterministisk",
    "deterministiskasts": "deterministisk",
    "deterministiske": "deterministisk",
    "deterministiskes": "deterministisk",
    "deterministisks": "deterministisk",
    "deterministiskt": "deterministisk",
    "deterministiskts": "deterministisk",
    "determinists": "determinist",
    "detonationen": "detonation",
    "detonationens": "detonation",
    "detonationer": "detonation",
    "detonationerna": "detonation",
    "detonationernas": "detonation",
    "detonationers": "detonation",
    "detonations": "detonation",
    "detonationshastigheten": "detonationshastighet",
    "detonationshastighetens": "detonationshastighet",
    "detonationshastigheter": "detonationshastighet",
    "detonationshastigheterna": "detonationshastighet",
    "detonationshastigheternas": "detonationshastighet",
    "detonationshastigheters": "detonationshastighet",
    "detonationshastighets": "detonationshastighet",
    "detonationstrycken": "detonationstryck",
    "detonationstryckens": "detonationstryck",
    "detonationstrycket": "detonationstryck",
    "detonationstryckets": "detonationstryck",
    "detonationstrycks": "detonationstryck",
    "detonationszonen": "detonationszon",
    "detonationszonens": "detonationszon",
    "detonationszoner": "detonationszon",
    "detonationszonerna": "detonationszon",
    "detonationszonernas": "detonationszon",
    "detonationszoners": "detonationszon",
    "detonationszons": "detonationszon",
    "detonatorer": "detonator",
    "detonatorerna": "detonator",
    "detonatorernas": "detonator",
    "detonatorers": "detonator",
    "detonatorn": "detonator",
    "detonatorns": "detonator",
    "detonators": "detonator",
    "detonerad": "detonera",
    "detonerade": "detonera",
    "detonerades": "detonera",
    "detonerads": "detonera",
    "detonerande": "detonera",
    "detoneranden": "detonerande",
    "detonerandena": "detonerande",
    "detonerandenas": "detonerande",
    "detonerandens": "detonerande",
    "detonerandes": "detonerande",
    "detonerandet": "detonerande",
    "detonerandets": "detonerande",
    "detonerar": "detonera",
    "detoneras": "detonera",
    "detonerat": "detonera",
    "detonerats": "detonera",
    "detonerbara": "detonerbar",
    "detonerbarare": "detonerbar",
    "detonerbarares": "detonerbar",
    "detonerbaras": "detonerbar",
    "detonerbarast": "detonerbar",
    "detonerbaraste": "detonerbar",
    "detonerbarastes": "detonerbar",
    "detonerbarasts": "detonerbar",
    "detonerbare": "detonerbar",
    "detonerbares": "detonerbar",
    "detonerbarheten": "detonerbarhet",
    "detonerbarhetens": "detonerbarhet",
    "detonerbarhets": "detonerbarhet",
    "detonerbars": "detonerbar",
    "detonerbart": "detonerbar",
    "detonerbarts": "detonerbar",
    "detoneringar": "detonering",
    "detoneringarna": "detonering",
    "detoneringarnas": "detonering",
    "detoneringars": "detonering",
    "detoneringen": "detonering",
    "detoneringens": "detonering",
    "detonerings": "detonering",
    "detroniserad": "detronisera",
    "detroniserade": "detronisera",
    "detroniserades": "detronisera",
    "detroniserads": "detronisera",
    "detroniserande": "detronisera",
    "detroniseranden": "detroniserande",
    "detroniserandena": "detroniserande",
    "detroniserandenas": "detroniserande",
    "detroniserandens": "detroniserande",
    "detroniserandes": "detroniserande",
    "detroniserandet": "detroniserande",
    "detroniserandets": "detroniserande",
    "detroniserar": "detronisera",
    "detroniseras": "detronisera",
    "detroniserat": "detronisera",
    "detroniserats": "detronisera",
    "detroniserbara": "detroniserbar",
    "detroniserbarare": "detroniserbar",
    "detroniserbarares": "detroniserbar",
    "detroniserbaras": "detroniserbar",
    "detroniserbarast": "detroniserbar",
    "detroniserbaraste": "detroniserbar",
    "detroniserbarastes": "detroniserbar",
    "detroniserbarasts": "detroniserbar",
    "detroniserbare": "detroniserbar",
    "detroniserbares": "detroniserbar",
    "detroniserbarheten": "detroniserbarhet",
    "detroniserbarhetens": "detroniserbarhet",
    "detroniserbarhets": "detroniserbarhet",
    "detroniserbars": "detroniserbar",
    "detroniserbart": "detroniserbar",
    "detroniserbarts": "detroniserbar",
    "detroniseringar": "detronisering",
    "detroniseringarna": "detronisering",
    "detroniseringarnas": "detronisering",
    "detroniseringars": "detronisering",
    "detroniseringen": "detronisering",
    "detroniseringens": "detronisering",
    "detroniserings": "detronisering",
    "detsamma": "densamma",
    "detsammas": "densamma",
    "detta": "denna",
    "dettas": "denna",
    "deuteriet": "deuterium",
    "deuteriets": "deuterium",
    "deuteriumet": "deuterium",
    "deuteriumets": "deuterium",
    "deuteriums": "deuterium",
    "deuteronen": "deuteron",
    "deuteronens": "deuteron",
    "deuteroner": "deuteron",
    "deuteronerna": "deuteron",
    "deuteronernas": "deuteron",
    "deuteroners": "deuteron",
    "deuterons": "deuteron",
    "deutronen": "deutron",
    "deutronens": "deutron",
    "deutroner": "deutron",
    "deutronerna": "deutron",
    "deutronernas": "deutron",
    "deutroners": "deutron",
    "deutrons": "deutron",
    "devalverad": "devalvera",
    "devalverade": "devalvera",
    "devalverades": "devalvera",
    "devalverads": "devalvera",
    "devalverande": "devalvera",
    "devalveranden": "devalverande",
    "devalverandena": "devalverande",
    "devalverandenas": "devalverande",
    "devalverandens": "devalverande",
    "devalverandes": "devalverande",
    "devalverandet": "devalverande",
    "devalverandets": "devalverande",
    "devalverar": "devalvera",
    "devalveras": "devalvera",
    "devalverat": "devalvera",
    "devalverats": "devalvera",
    "devalverbara": "devalverbar",
    "devalverbarare": "devalverbar",
    "devalverbarares": "devalverbar",
    "devalverbaras": "devalverbar",
    "devalverbarast": "devalverbar",
    "devalverbaraste": "devalverbar",
    "devalverbarastes": "devalverbar",
    "devalverbarasts": "devalverbar",
    "devalverbare": "devalverbar",
    "devalverbares": "devalverbar",
    "devalverbarheten": "devalverbarhet",
    "devalverbarhetens": "devalverbarhet",
    "devalverbarhets": "devalverbarhet",
    "devalverbars": "devalverbar",
    "devalverbart": "devalverbar",
    "devalverbarts": "devalverbar",
    "devalveringar": "devalvering",
    "devalveringarna": "devalvering",
    "devalveringarnas": "devalvering",
    "devalveringars": "devalvering",
    "devalveringen": "devalvering",
    "devalveringens": "devalvering",
    "devalverings": "devalvering",
    "deviationen": "deviation",
    "deviationens": "deviation",
    "deviationer": "deviation",
    "deviationerna": "deviation",
    "deviationernas": "deviation",
    "deviationers": "deviation",
    "deviations": "deviation",
    "devierade": "deviera",
    "devierades": "deviera",
    "devierande": "deviera",
    "devieranden": "devierande",
    "devierandena": "devierande",
    "devierandenas": "devierande",
    "devierandens": "devierande",
    "devierandes": "devierande",
    "devierandet": "devierande",
    "devierandets": "devierande",
    "devierar": "deviera",
    "devieras": "deviera",
    "devierat": "deviera",
    "devierats": "deviera",
    "devieringar": "deviering",
    "devieringarna": "deviering",
    "devieringarnas": "deviering",
    "devieringars": "deviering",
    "devieringen": "deviering",
    "devieringens": "deviering",
    "devierings": "deviering",
    "devisen": "devis",
    "devisens": "devis",
    "deviser": "devis",
    "deviserna": "devis",
    "devisernas": "devis",
    "devisers": "devis",
    "devons": "devon",
    "devota": "devot",
    "devotare": "devot",
    "devotares": "devot",
    "devotas": "devot",
    "devotast": "devot",
    "devotaste": "devot",
    "devotastes": "devot",
    "devotasts": "devot",
    "devote": "devot",
    "devotes": "devot",
    "devots": "devot",
    "dextranen": "dextran",
    "dextranens": "dextran",
    "dextraner": "dextran",
    "dextranerna": "dextran",
    "dextranernas": "dextran",
    "dextraners": "dextran",
    "dextranet": "dextran",
    "dextranets": "dextran",
    "dextrans": "dextran",
    "dextrinen": "dextrin",
    "dextrinens": "dextrin",
    "dextriner": "dextrin",
    "dextrinerna": "dextrin",
    "dextrinernas": "dextrin",
    "dextriners": "dextrin",
    "dextrinet": "dextrin",
    "dextrinets": "dextrin",
    "dextrins": "dextrin",
    "dhivehis": "dhivehi",
    "di": "dia",
    "diabasen": "diabas",
    "diabasens": "diabas",
    "diabaser": "diabas",
    "diabaserna": "diabas",
    "diabasernas": "diabas",
    "diabasers": "diabas",
    "diabetikern": "diabetiker",
    "diabetikerna": "diabetiker",
    "diabetikernas": "diabetiker",
    "diabetikerns": "diabetiker",
    "diabetikers": "diabetiker",
    "diabilden": "diabild",
    "diabildens": "diabild",
    "diabilder": "diabild",
    "diabilderna": "diabild",
    "diabildernas": "diabild",
    "diabilders": "diabild",
    "diabilds": "diabild",
    "diaboliska": "diabolisk",
    "diaboliskare": "diabolisk",
    "diaboliskares": "diabolisk",
    "diaboliskas": "diabolisk",
    "diaboliskast": "diabolisk",
    "diaboliskaste": "diabolisk",
    "diaboliskastes": "diabolisk",
    "diaboliskasts": "diabolisk",
    "diaboliske": "diabolisk",
    "diaboliskes": "diabolisk",
    "diabolisks": "diabolisk",
    "diaboliskt": "diabolisk",
    "diaboliskts": "diabolisk",
    "diad": "dia",
    "diade": "dia",
    "diademen": "diadem",
    "diademens": "diadem",
    "diademet": "diadem",
    "diademets": "diadem",
    "diadems": "diadem",
    "diades": "dia",
    "diads": "dia",
    "diafilmen": "diafilm",
    "diafilmens": "diafilm",
    "diafilmer": "diafilm",
    "diafilmerna": "diafilm",
    "diafilmernas": "diafilm",
    "diafilmers": "diafilm",
    "diafilms": "diafilm",
    "diafragman": "diafragma",
    "diafragmans": "diafragma",
    "diafragmas": "diafragma",
    "diafragmat": "diafragma",
    "diafragmats": "diafragma",
    "diafragmer": "diafragma",
    "diafragmerna": "diafragma",
    "diafragmernas": "diafragma",
    "diafragmers": "diafragma",
    "diafragmor": "diafragma",
    "diafragmorna": "diafragma",
    "diafragmornas": "diafragma",
    "diafragmors": "diafragma",
    "diagnosen": "diagnos",
    "diagnosens": "diagnos",
    "diagnoser": "diagnos",
    "diagnoserna": "diagnos",
    "diagnosernas": "diagnos",
    "diagnosers": "diagnos",
    "diagnosticerad": "diagnosticera",
    "diagnosticerade": "diagnosticera",
    "diagnosticerades": "diagnosticera",
    "diagnosticerads": "diagnosticera",
    "diagnosticerande": "diagnosticera",
    "diagnosticeranden": "diagnosticerande",
    "diagnosticerandena": "diagnosticerande",
    "diagnosticerandenas": "diagnosticerande",
    "diagnosticerandens": "diagnosticerande",
    "diagnosticerandes": "diagnosticerande",
    "diagnosticerandet": "diagnosticerande",
    "diagnosticerandets": "diagnosticerande",
    "diagnosticerar": "diagnosticera",
    "diagnosticeras": "diagnosticera",
    "diagnosticerat": "diagnosticera",
    "diagnosticerats": "diagnosticera",
    "diagnosticerbara": "diagnosticerbar",
    "diagnosticerbarare": "diagnosticerbar",
    "diagnosticerbarares": "diagnosticerbar",
    "diagnosticerbaras": "diagnosticerbar",
    "diagnosticerbarast": "diagnosticerbar",
    "diagnosticerbaraste": "diagnosticerbar",
    "diagnosticerbarastes": "diagnosticerbar",
    "diagnosticerbarasts": "diagnosticerbar",
    "diagnosticerbare": "diagnosticerbar",
    "diagnosticerbares": "diagnosticerbar",
    "diagnosticerbarheten": "diagnosticerbarhet",
    "diagnosticerbarhetens": "diagnosticerbarhet",
    "diagnosticerbarhets": "diagnosticerbarhet",
    "diagnosticerbars": "diagnosticerbar",
    "diagnosticerbart": "diagnosticerbar",
    "diagnosticerbarts": "diagnosticerbar",
    "diagnosticeringar": "diagnosticering",
    "diagnosticeringarna": "diagnosticering",
    "diagnosticeringarnas": "diagnosticering",
    "diagnosticeringars": "diagnosticering",
    "diagnosticeringen": "diagnosticering",
    "diagnosticeringens": "diagnosticering",
    "diagnosticerings": "diagnosticering",
    "diagnostiken": "diagnostik",
    "diagnostikens": "diagnostik",
    "diagnostikern": "diagnostiker",
    "diagnostikerna": "diagnostiker",
    "diagnostikernas": "diagnostiker",
    "diagnostikerns": "diagnostiker",
    "diagnostikers": "diagnostiker",
    "diagnostiks": "diagnostik",
    "diagnostiserad": "diagnostisera",
    "diagnostiserade": "diagnostisera",
    "diagnostiserades": "diagnostisera",
    "diagnostiserads": "diagnostisera",
    "diagnostiserande": "diagnostisera",
    "diagnostiseranden": "diagnostiserande",
    "diagnostiserandena": "diagnostiserande",
    "diagnostiserandenas": "diagnostiserande",
    "diagnostiserandens": "diagnostiserande",
    "diagnostiserandes": "diagnostiserande",
    "diagnostiserandet": "diagnostiserande",
    "diagnostiserandets": "diagnostiserande",
    "diagnostiserar": "diagnostisera",
    "diagnostiseras": "diagnostisera",
    "diagnostiserat": "diagnostisera",
    "diagnostiserats": "diagnostisera",
    "diagnostiserbara": "diagnostiserbar",
    "diagnostiserbarare": "diagnostiserbar",
    "diagnostiserbarares": "diagnostiserbar",
    "diagnostiserbaras": "diagnostiserbar",
    "diagnostiserbarast": "diagnostiserbar",
    "diagnostiserbaraste": "diagnostiserbar",
    "diagnostiserbarastes": "diagnostiserbar",
    "diagnostiserbarasts": "diagnostiserbar",
    "diagnostiserbare": "diagnostiserbar",
    "diagnostiserbares": "diagnostiserbar",
    "diagnostiserbarheten": "diagnostiserbarhet",
    "diagnostiserbarhetens": "diagnostiserbarhet",
    "diagnostiserbarhets": "diagnostiserbarhet",
    "diagnostiserbars": "diagnostiserbar",
    "diagnostiserbart": "diagnostiserbar",
    "diagnostiserbarts": "diagnostiserbar",
    "diagnostiseringar": "diagnostisering",
    "diagnostiseringarna": "diagnostisering",
    "diagnostiseringarnas": "diagnostisering",
    "diagnostiseringars": "diagnostisering",
    "diagnostiseringen": "diagnostisering",
    "diagnostiseringens": "diagnostisering",
    "diagnostiserings": "diagnostisering",
    "diagnostiska": "diagnostisk",
    "diagnostiskare": "diagnostisk",
    "diagnostiskares": "diagnostisk",
    "diagnostiskas": "diagnostisk",
    "diagnostiskast": "diagnostisk",
    "diagnostiskaste": "diagnostisk",
    "diagnostiskastes": "diagnostisk",
    "diagnostiskasts": "diagnostisk",
    "diagnostiske": "diagnostisk",
    "diagnostiskes": "diagnostisk",
    "diagnostisks": "diagnostisk",
    "diagnostiskt": "diagnostisk",
    "diagnostiskts": "diagnostisk",
    "diagonala": "diagonal",
    "diagonalade": "diagonala",
    "diagonalades": "diagonala",
    "diagonalande": "diagonala",
    "diagonalanden": "diagonalande",
    "diagonalandena": "diagonalande",
    "diagonalandenas": "diagonalande",
    "diagonalandens": "diagonalande",
    "diagonalandes": "diagonalande",
    "diagonalandet": "diagonalande",
    "diagonalandets": "diagonalande",
    "diagonalar": "diagonala",
    "diagonalare": "diagonal",
    "diagonalares": "diagonal",
    "diagonalas": "diagonala",
    "diagonalast": "diagonal",
    "diagonalaste": "diagonal",
    "diagonalastes": "diagonal",
    "diagonalasts": "diagonal",
    "diagonalat": "diagonala",
    "diagonalats": "diagonala",
    "diagonale": "diagonal",
    "diagonalen": "diagonal",
    "diagonalens": "diagonal",
    "diagonaler": "diagonal",
    "diagonalerna": "diagonal",
    "diagonalernas": "diagonal",
    "diagonalers": "diagonal",
    "diagonales": "diagonal",
    "diagonals": "diagonal",
    "diagonalt": "diagonal",
    "diagonalts": "diagonal",
    "diagrammen": "diagram",
    "diagrammens": "diagram",
    "diagrammet": "diagram",
    "diagrammets": "diagram",
    "diagrams": "diagram",
    "diakonen": "diakon",
    "diakonens": "diakon",
    "diakoner": "diakon",
    "diakonerna": "diakon",
    "diakonernas": "diakon",
    "diakoners": "diakon",
    "diakonien": "diakoni",
    "diakoniens": "diakoni",
    "diakonin": "diakoni",
    "diakonins": "diakoni",
    "diakonis": "diakoni",
    "diakoniss": "diakonissa",
    "diakonissan": "diakonissa",
    "diakonissans": "diakonissa",
    "diakonissas": "diakonissa",
    "diakonisse": "diakonissa",
    "diakonissor": "diakonissa",
    "diakonissorna": "diakonissa",
    "diakonissornas": "diakonissa",
    "diakonissors": "diakonissa",
    "diakonistyrelsen": "diakonistyrelse",
    "diakonistyrelsens": "diakonistyrelse",
    "diakonistyrelser": "diakonistyrelse",
    "diakonistyrelserna": "diakonistyrelse",
    "diakonistyrelsernas": "diakonistyrelse",
    "diakonistyrelsers": "diakonistyrelse",
    "diakonistyrelses": "diakonistyrelse",
    "diakons": "diakon",
    "diakritiska": "diakritisk",
    "diakritiskare": "diakritisk",
    "diakritiskares": "diakritisk",
    "diakritiskas": "diakritisk",
    "diakritiskast": "diakritisk",
    "diakritiskaste": "diakritisk",
    "diakritiskastes": "diakritisk",
    "diakritiskasts": "diakritisk",
    "diakritiske": "diakritisk",
    "diakritiskes": "diakritisk",
    "diakritisks": "diakritisk",
    "diakritiskt": "diakritisk",
    "diakritiskts": "diakritisk",
    "diakrona": "diakron",
    "diakronare": "diakron",
    "diakronares": "diakron",
    "diakronas": "diakron",
    "diakronast": "diakron",
    "diakronaste": "diakron",
    "diakronastes": "diakron",
    "diakronasts": "diakron",
    "diakrone": "diakron",
    "diakrones": "diakron",
    "diakroniska": "diakronisk",
    "diakroniskare": "diakronisk",
    "diakroniskares": "diakronisk",
    "diakroniskas": "diakronisk",
    "diakroniskast": "diakronisk",
    "diakroniskaste": "diakronisk",
    "diakroniskastes": "diakronisk",
    "diakroniskasts": "diakronisk",
    "diakroniske": "diakronisk",
    "diakroniskes": "diakronisk",
    "diakronisks": "diakronisk",
    "diakroniskt": "diakronisk",
    "diakroniskts": "diakronisk",
    "diakrons": "diakron",
    "diakront": "diakron",
    "diakronts": "diakron",
    "dialektala": "dialektal",
    "dialektalare": "dialektal",
    "dialektalares": "dialektal",
    "dialektalas": "dialektal",
    "dialektalast": "dialektal",
    "dialektalaste": "dialektal",
    "dialektalastes": "dialektal",
    "dialektalasts": "dialektal",
    "dialektale": "dialektal",
    "dialektales": "dialektal",
    "dialektals": "dialektal",
    "dialektalt": "dialektal",
    "dialektalts": "dialektal",
    "dialekten": "dialekt",
    "dialektens": "dialekt",
    "dialekter": "dialekt",
    "dialekterna": "dialekt",
    "dialekternas": "dialekt",
    "dialekters": "dialekt",
    "dialektgeografien": "dialektgeografi",
    "dialektgeografiens": "dialektgeografi",
    "dialektgeografin": "dialektgeografi",
    "dialektgeografins": "dialektgeografi",
    "dialektgeografis": "dialektgeografi",
    "dialektgeografiska": "dialektgeografisk",
    "dialektgeografiskare": "dialektgeografisk",
    "dialektgeografiskares": "dialektgeografisk",
    "dialektgeografiskas": "dialektgeografisk",
    "dialektgeografiskast": "dialektgeografisk",
    "dialektgeografiskaste": "dialektgeografisk",
    "dialektgeografiskastes": "dialektgeografisk",
    "dialektgeografiskasts": "dialektgeografisk",
    "dialektgeografiske": "dialektgeografisk",
    "dialektgeografiskes": "dialektgeografisk",
    "dialektgeografisks": "dialektgeografisk",
    "dialektgeografiskt": "dialektgeografisk",
    "dialektgeografiskts": "dialektgeografisk",
    "dialektiken": "dialektik",
    "dialektikens": "dialektik",
    "dialektikern": "dialektiker",
    "dialektikerna": "dialektiker",
    "dialektikernas": "dialektiker",
    "dialektikerns": "dialektiker",
    "dialektikers": "dialektiker",
    "dialektiks": "dialektik",
    "dialektiska": "dialektisk",
    "dialektiskare": "dialektisk",
    "dialektiskares": "dialektisk",
    "dialektiskas": "dialektisk",
    "dialektiskast": "dialektisk",
    "dialektiskaste": "dialektisk",
    "dialektiskastes": "dialektisk",
    "dialektiskasts": "dialektisk",
    "dialektiske": "dialektisk",
    "dialektiskes": "dialektisk",
    "dialektisks": "dialektisk",
    "dialektiskt": "dialektisk",
    "dialektiskts": "dialektisk",
    "dialektologen": "dialektolog",
    "dialektologens": "dialektolog",
    "dialektologer": "dialektolog",
    "dialektologerna": "dialektolog",
    "dialektologernas": "dialektolog",
    "dialektologers": "dialektolog",
    "dialektologien": "dialektologi",
    "dialektologiens": "dialektologi",
    "dialektologin": "dialektologi",
    "dialektologins": "dialektologi",
    "dialektologis": "dialektologi",
    "dialektologiska": "dialektologisk",
    "dialektologiskare": "dialektologisk",
    "dialektologiskares": "dialektologisk",
    "dialektologiskas": "dialektologisk",
    "dialektologiskast": "dialektologisk",
    "dialektologiskaste": "dialektologisk",
    "dialektologiskastes": "dialektologisk",
    "dialektologiskasts": "dialektologisk",
    "dialektologiske": "dialektologisk",
    "dialektologiskes": "dialektologisk",
    "dialektologisks": "dialektologisk",
    "dialektologiskt": "dialektologisk",
    "dialektologiskts": "dialektologisk",
    "dialektologs": "dialektolog",
    "dialekts": "dialekt",
    "dialogen": "dialog",
    "dialogens": "dialog",
    "dialoger": "dialog",
    "dialogerna": "dialog",
    "dialogernas": "dialog",
    "dialogers": "dialog",
    "dialogpartier": "dialogparti",
    "dialogpartierna": "dialogparti",
    "dialogpartiernas": "dialogparti",
    "dialogpartiers": "dialogparti",
    "dialogpartiet": "dialogparti",
    "dialogpartiets": "dialogparti",
    "dialogpartis": "dialogparti",
    "dialogpartit": "dialogparti",
    "dialogpartits": "dialogparti",
    "dialogpedagogiken": "dialogpedagogik",
    "dialogpedagogikens": "dialogpedagogik",
    "dialogpedagogiks": "dialogpedagogik",
    "dialogs": "dialog",
    "dialysen": "dialys",
    "dialysens": "dialys",
    "dialyser": "dialys",
    "dialyserad": "dialysera",
    "dialyserade": "dialysera",
    "dialyserades": "dialysera",
    "dialyserads": "dialysera",
    "dialyserande": "dialysera",
    "dialyseranden": "dialyserande",
    "dialyserandena": "dialyserande",
    "dialyserandenas": "dialyserande",
    "dialyserandens": "dialyserande",
    "dialyserandes": "dialyserande",
    "dialyserandet": "dialyserande",
    "dialyserandets": "dialyserande",
    "dialyserar": "dialysera",
    "dialyseras": "dialysera",
    "dialyserat": "dialysera",
    "dialyserats": "dialysera",
    "dialyserbara": "dialyserbar",
    "dialyserbarare": "dialyserbar",
    "dialyserbarares": "dialyserbar",
    "dialyserbaras": "dialyserbar",
    "dialyserbarast": "dialyserbar",
    "dialyserbaraste": "dialyserbar",
    "dialyserbarastes": "dialyserbar",
    "dialyserbarasts": "dialyserbar",
    "dialyserbare": "dialyserbar",
    "dialyserbares": "dialyserbar",
    "dialyserbarheten": "dialyserbarhet",
    "dialyserbarhetens": "dialyserbarhet",
    "dialyserbarhets": "dialyserbarhet",
    "dialyserbars": "dialyserbar",
    "dialyserbart": "dialyserbar",
    "dialyserbarts": "dialyserbar",
    "dialyseringar": "dialysering",
    "dialyseringarna": "dialysering",
    "dialyseringarnas": "dialysering",
    "dialyseringars": "dialysering",
    "dialyseringen": "dialysering",
    "dialyseringens": "dialysering",
    "dialyserings": "dialysering",
    "dialyserna": "dialys",
    "dialysernas": "dialys",
    "dialysers": "dialys",
    "dialytiska": "dialytisk",
    "dialytiskare": "dialytisk",
    "dialytiskares": "dialytisk",
    "dialytiskas": "dialytisk",
    "dialytiskast": "dialytisk",
    "dialytiskaste": "dialytisk",
    "dialytiskastes": "dialytisk",
    "dialytiskasts": "dialytisk",
    "dialytiske": "dialytisk",
    "dialytiskes": "dialytisk",
    "dialytisks": "dialytisk",
    "dialytiskt": "dialytisk",
    "dialytiskts": "dialytisk",
    "diamantbelagda": "diamantbelagd",
    "diamantbelagdare": "diamantbelagd",
    "diamantbelagdares": "diamantbelagd",
    "diamantbelagdas": "diamantbelagd",
    "diamantbelagdast": "diamantbelagd",
    "diamantbelagdaste": "diamantbelagd",
    "diamantbelagdastes": "diamantbelagd",
    "diamantbelagdasts": "diamantbelagd",
    "diamantbelagde": "diamantbelagd",
    "diamantbelagdes": "diamantbelagd",
    "diamantbelagds": "diamantbelagd",
    "diamantbelagt": "diamantbelagd",
    "diamantbelagts": "diamantbelagd",
    "diamantborrar": "diamantborr",
    "diamantborrarna": "diamantborr",
    "diamantborrarnas": "diamantborr",
    "diamantborrars": "diamantborr",
    "diamantborren": "diamantborr",
    "diamantborrens": "diamantborr",
    "diamantborret": "diamantborr",
    "diamantborrets": "diamantborr",
    "diamantborrs": "diamantborr",
    "diamantbrynstålen": "diamantbrynstål",
    "diamantbrynstålens": "diamantbrynstål",
    "diamantbrynstålet": "diamantbrynstål",
    "diamantbrynstålets": "diamantbrynstål",
    "diamantbrynståls": "diamantbrynstål",
    "diamantbröllopen": "diamantbröllop",
    "diamantbröllopens": "diamantbröllop",
    "diamantbröllopet": "diamantbröllop",
    "diamantbröllopets": "diamantbröllop",
    "diamantbröllops": "diamantbröllop",
    "diamanten": "diamant",
    "diamantens": "diamant",
    "diamanter": "diamant",
    "diamanterna": "diamant",
    "diamanternas": "diamant",
    "diamanters": "diamant",
    "diamants": "diamant",
    "diametern": "diameter",
    "diameterns": "diameter",
    "diameters": "diameter",
    "diametrala": "diametral",
    "diametralare": "diametral",
    "diametralares": "diametral",
    "diametralas": "diametral",
    "diametralast": "diametral",
    "diametralaste": "diametral",
    "diametralastes": "diametral",
    "diametralasts": "diametral",
    "diametrale": "diametral",
    "diametrales": "diametral",
    "diametrals": "diametral",
    "diametralt": "diametral",
    "diametralts": "diametral",
    "diametrar": "diameter",
    "diametrarna": "diameter",
    "diametrarnas": "diameter",
    "diametrars": "diameter",
    "dian": "dia",
    "diande": "dia",
    "dianden": "diande",
    "diandena": "diande",
    "diandenas": "diande",
    "diandens": "diande",
    "diandes": "diande",
    "diandet": "diande",
    "diandets": "diande",
    "dians": "dia",
    "diapositiven": "diapositiv",
    "diapositivens": "diapositiv",
    "diapositivet": "diapositiv",
    "diapositivets": "diapositiv",
    "diapositivs": "diapositiv",
    "diar": "dia",
    "diarie": "diarium",
    "diarieför": "diarieföra",
    "diarieförande": "diarieföra",
    "diarieföranden": "diarieförande",
    "diarieförandena": "diarieförande",
    "diarieförandenas": "diarieförande",
    "diarieförandens": "diarieförande",
    "diarieförandes": "diarieförande",
    "diarieförandet": "diarieförande",
    "diarieförandets": "diarieförande",
    "diarieföras": "diarieföra",
    "diarieförd": "diarieföra",
    "diarieförda": "diarieföra",
    "diariefördas": "diarieföra",
    "diarieförde": "diarieföra",
    "diariefördes": "diarieföra",
    "diarieförds": "diarieföra",
    "diarieföres": "diarieföra",
    "diarieförs": "diarieföra",
    "diariefört": "diarieföra",
    "diarieförts": "diarieföra",
    "diarienummerna": "diarienummer",
    "diarienummernas": "diarienummer",
    "diarienummers": "diarienummer",
    "diarienumren": "diarienummer",
    "diarienumrens": "diarienummer",
    "diarienumret": "diarienummer",
    "diarienumrets": "diarienummer",
    "diarier": "diarium",
    "diarierna": "diarium",
    "diariernas": "diarium",
    "diariers": "diarium",
    "diariet": "diarium",
    "diariets": "diarium",
    "diariums": "diarium",
    "diarréer": "diarré",
    "diarréerna": "diarré",
    "diarréernas": "diarré",
    "diarréers": "diarré",
    "diarrén": "diarré",
    "diarréns": "diarré",
    "diarrés": "diarré",
    "dias": "dia",
    "diasporan": "diaspora",
    "diasporans": "diaspora",
    "diasporas": "diaspora",
    "diastasen": "diastas",
    "diastasens": "diastas",
    "diastaser": "diastas",
    "diastaserna": "diastas",
    "diastasernas": "diastas",
    "diastasers": "diastas",
    "diastoliska": "diastolisk",
    "diastoliskare": "diastolisk",
    "diastoliskares": "diastolisk",
    "diastoliskas": "diastolisk",
    "diastoliskast": "diastolisk",
    "diastoliskaste": "diastolisk",
    "diastoliskastes": "diastolisk",
    "diastoliskasts": "diastolisk",
    "diastoliske": "diastolisk",
    "diastoliskes": "diastolisk",
    "diastolisks": "diastolisk",
    "diastoliskt": "diastolisk",
    "diastoliskts": "diastolisk",
    "diat": "dia",
    "diatermien": "diatermi",
    "diatermiens": "diatermi",
    "diatermin": "diatermi",
    "diatermins": "diatermi",
    "diatermis": "diatermi",
    "diatoniska": "diatonisk",
    "diatoniskare": "diatonisk",
    "diatoniskares": "diatonisk",
    "diatoniskas": "diatonisk",
    "diatoniskast": "diatonisk",
    "diatoniskaste": "diatonisk",
    "diatoniskastes": "diatonisk",
    "diatoniskasts": "diatonisk",
    "diatoniske": "diatonisk",
    "diatoniskes": "diatonisk",
    "diatonisks": "diatonisk",
    "diatoniskt": "diatonisk",
    "diatoniskts": "diatonisk",
    "diatriben": "diatrib",
    "diatribens": "diatrib",
    "diatriber": "diatrib",
    "diatriberna": "diatrib",
    "diatribernas": "diatrib",
    "diatribers": "diatrib",
    "diatribs": "diatrib",
    "diats": "dia",
    "dibarnen": "dibarn",
    "dibarnens": "dibarn",
    "dibarnet": "dibarn",
    "dibarnets": "dibarn",
    "dibarns": "dibarn",
    "dibbel": "dibbla",
    "dibblad": "dibbla",
    "dibblade": "dibbla",
    "dibblades": "dibbla",
    "dibblads": "dibbla",
    "dibblande": "dibbla",
    "dibblanden": "dibblande",
    "dibblandena": "dibblande",
    "dibblandenas": "dibblande",
    "dibblandens": "dibblande",
    "dibblandes": "dibblande",
    "dibblandet": "dibblande",
    "dibblandets": "dibblande",
    "dibblar": "dibbla",
    "dibblas": "dibbla",
    "dibblat": "dibbla",
    "dibblats": "dibbla",
    "didaktiken": "didaktik",
    "didaktikens": "didaktik",
    "didaktikern": "didaktiker",
    "didaktikerna": "didaktiker",
    "didaktikernas": "didaktiker",
    "didaktikerns": "didaktiker",
    "didaktikers": "didaktiker",
    "didaktiks": "didaktik",
    "didaktiska": "didaktisk",
    "didaktiskare": "didaktisk",
    "didaktiskares": "didaktisk",
    "didaktiskas": "didaktisk",
    "didaktiskast": "didaktisk",
    "didaktiskaste": "didaktisk",
    "didaktiskastes": "didaktisk",
    "didaktiskasts": "didaktisk",
    "didaktiske": "didaktisk",
    "didaktiskes": "didaktisk",
    "didaktisks": "didaktisk",
    "didaktiskt": "didaktisk",
    "didaktiskts": "didaktisk",
    "diddlingen": "diddling",
    "diddlingens": "diddling",
    "diddlings": "diddling",
    "dieseldrivens": "dieseldriven",
    "dieseldrivet": "dieseldriven",
    "dieseldrivets": "dieseldriven",
    "dieseldrivna": "dieseldriven",
    "dieseldrivnas": "dieseldriven",
    "dieseldrivne": "dieseldriven",
    "dieseldrivnes": "dieseldriven",
    "dieselgeneratorer": "dieselgenerator",
    "dieselgeneratorerna": "dieselgenerator",
    "dieselgeneratorernas": "dieselgenerator",
    "dieselgeneratorers": "dieselgenerator",
    "dieselgeneratorn": "dieselgenerator",
    "dieselgeneratorns": "dieselgenerator",
    "dieselgenerators": "dieselgenerator",
    "dieselmotorer": "dieselmotor",
    "dieselmotorerna": "dieselmotor",
    "dieselmotorernas": "dieselmotor",
    "dieselmotorers": "dieselmotor",
    "dieselmotorn": "dieselmotor",
    "dieselmotorns": "dieselmotor",
    "dieselmotorrengöringen": "dieselmotorrengöring",
    "dieselmotorrengöringens": "dieselmotorrengöring",
    "dieselmotorrengörings": "dieselmotorrengöring",
    "dieselmotors": "dieselmotor",
    "dieseln": "diesel",
    "dieselns": "diesel",
    "dieseloljan": "dieselolja",
    "dieseloljans": "dieselolja",
    "dieseloljas": "dieselolja",
    "dieselolje": "dieselolja",
    "dieseloljor": "dieselolja",
    "dieseloljorna": "dieselolja",
    "dieseloljornas": "dieselolja",
    "dieseloljors": "dieselolja",
    "diesels": "diesel",
    "dieslar": "diesel",
    "dieslarna": "diesel",
    "dieslarnas": "diesel",
    "dieslars": "diesel",
    "dieten": "diet",
    "dietens": "diet",
    "dieter": "diet",
    "dieterna": "diet",
    "dieternas": "diet",
    "dieters": "diet",
    "dietetiken": "dietetik",
    "dietetikens": "dietetik",
    "dietetiks": "dietetik",
    "dietetiska": "dietetisk",
    "dietetiskare": "dietetisk",
    "dietetiskares": "dietetisk",
    "dietetiskas": "dietetisk",
    "dietetiskast": "dietetisk",
    "dietetiskaste": "dietetisk",
    "dietetiskastes": "dietetisk",
    "dietetiskasts": "dietetisk",
    "dietetiske": "dietetisk",
    "dietetiskes": "dietetisk",
    "dietetisks": "dietetisk",
    "dietetiskt": "dietetisk",
    "dietetiskts": "dietetisk",
    "dietiken": "dietik",
    "dietikens": "dietik",
    "dietiks": "dietik",
    "dietiska": "dietisk",
    "dietiskare": "dietisk",
    "dietiskares": "dietisk",
    "dietiskas": "dietisk",
    "dietiskast": "dietisk",
    "dietiskaste": "dietisk",
    "dietiskastes": "dietisk",
    "dietiskasts": "dietisk",
    "dietiske": "dietisk",
    "dietiskes": "dietisk",
    "dietisks": "dietisk",
    "dietiskt": "dietisk",
    "dietiskts": "dietisk",
    "dietisten": "dietist",
    "dietistens": "dietist",
    "dietister": "dietist",
    "dietisterna": "dietist",
    "dietisternas": "dietist",
    "dietisters": "dietist",
    "dietists": "dietist",
    "diets": "diet",
    "differensen": "differens",
    "differensens": "differens",
    "differenser": "differens",
    "differenserna": "differens",
    "differensernas": "differens",
    "differensers": "differens",
    "differenta": "different",
    "differentare": "different",
    "differentares": "different",
    "differentas": "different",
    "differentast": "different",
    "differentaste": "different",
    "differentastes": "different",
    "differentasts": "different",
    "differente": "different",
    "differentes": "different",
    "differentialekvationen": "differentialekvation",
    "differentialekvationens": "differentialekvation",
    "differentialekvationer": "differentialekvation",
    "differentialekvationerna": "differentialekvation",
    "differentialekvationernas": "differentialekvation",
    "differentialekvationers": "differentialekvation",
    "differentialekvations": "differentialekvation",
    "differentialen": "differential",
    "differentialens": "differential",
    "differentialer": "differential",
    "differentialerna": "differential",
    "differentialernas": "differential",
    "differentialers": "differential",
    "differentialkalkylen": "differentialkalkyl",
    "differentialkalkylens": "differentialkalkyl",
    "differentialkalkyler": "differentialkalkyl",
    "differentialkalkylerna": "differentialkalkyl",
    "differentialkalkylernas": "differentialkalkyl",
    "differentialkalkylers": "differentialkalkyl",
    "differentialkalkyls": "differentialkalkyl",
    "differentials": "differential",
    "differentialspärrar": "differentialspärr",
    "differentialspärrarna": "differentialspärr",
    "differentialspärrarnas": "differentialspärr",
    "differentialspärrars": "differentialspärr",
    "differentialspärren": "differentialspärr",
    "differentialspärrens": "differentialspärr",
    "differentialspärrs": "differentialspärr",
    "differentialväxeln": "differentialväxel",
    "differentialväxelns": "differentialväxel",
    "differentialväxels": "differentialväxel",
    "differentialväxlar": "differentialväxel",
    "differentialväxlarna": "differentialväxel",
    "differentialväxlarnas": "differentialväxel",
    "differentialväxlars": "differentialväxel",
    "differentiella": "differentiell",
    "differentiellare": "differentiell",
    "differentiellares": "differentiell",
    "differentiellas": "differentiell",
    "differentiellast": "differentiell",
    "differentiellaste": "differentiell",
    "differentiellastes": "differentiell",
    "differentiellasts": "differentiell",
    "differentielle": "differentiell",
    "differentielles": "differentiell",
    "differentiells": "differentiell",
    "differentiellt": "differentiell",
    "differentiellts": "differentiell",
    "differentierad": "differentiera",
    "differentierade": "differentiera",
    "differentierades": "differentiera",
    "differentierads": "differentiera",
    "differentierande": "differentiera",
    "differentieranden": "differentierande",
    "differentierandena": "differentierande",
    "differentierandenas": "differentierande",
    "differentierandens": "differentierande",
    "differentierandes": "differentierande",
    "differentierandet": "differentierande",
    "differentierandets": "differentierande",
    "differentierar": "differentiera",
    "differentieras": "differentiera",
    "differentierat": "differentiera",
    "differentierats": "differentiera",
    "differentierbara": "differentierbar",
    "differentierbarare": "differentierbar",
    "differentierbarares": "differentierbar",
    "differentierbaras": "differentierbar",
    "differentierbarast": "differentierbar",
    "differentierbaraste": "differentierbar",
    "differentierbarastes": "differentierbar",
    "differentierbarasts": "differentierbar",
    "differentierbare": "differentierbar",
    "differentierbares": "differentierbar",
    "differentierbarheten": "differentierbarhet",
    "differentierbarhetens": "differentierbarhet",
    "differentierbarhets": "differentierbarhet",
    "differentierbars": "differentierbar",
    "differentierbart": "differentierbar",
    "differentierbarts": "differentierbar",
    "differentieringar": "differentiering",
    "differentieringarna": "differentiering",
    "differentieringarnas": "differentiering",
    "differentieringars": "differentiering",
    "differentieringen": "differentiering",
    "differentieringens": "differentiering",
    "differentierings": "differentiering",
    "differents": "different",
    "diffraktionen": "diffraktion",
    "diffraktionens": "diffraktion",
    "diffraktioner": "diffraktion",
    "diffraktionerna": "diffraktion",
    "diffraktionernas": "diffraktion",
    "diffraktioners": "diffraktion",
    "diffraktions": "diffraktion",
    "diffraktionsspektra": "diffraktionsspektrum",
    "diffraktionsspektrana": "diffraktionsspektrum",
    "diffraktionsspektranas": "diffraktionsspektrum",
    "diffraktionsspektras": "diffraktionsspektrum",
    "diffraktionsspektrena": "diffraktionsspektrum",
    "diffraktionsspektrenas": "diffraktionsspektrum",
    "diffraktionsspektrer": "diffraktionsspektrum",
    "diffraktionsspektrers": "diffraktionsspektrum",
    "diffraktionsspektret": "diffraktionsspektrum",
    "diffraktionsspektrets": "diffraktionsspektrum",
    "diffraktionsspektrumen": "diffraktionsspektrum",
    "diffraktionsspektrumens": "diffraktionsspektrum",
    "diffraktionsspektrumet": "diffraktionsspektrum",
    "diffraktionsspektrumets": "diffraktionsspektrum",
    "diffraktionsspektrums": "diffraktionsspektrum",
    "diffunderad": "diffundera",
    "diffunderade": "diffundera",
    "diffunderades": "diffundera",
    "diffunderads": "diffundera",
    "diffunderande": "diffundera",
    "diffunderanden": "diffunderande",
    "diffunderandena": "diffunderande",
    "diffunderandenas": "diffunderande",
    "diffunderandens": "diffunderande",
    "diffunderandes": "diffunderande",
    "diffunderandet": "diffunderande",
    "diffunderandets": "diffunderande",
    "diffunderar": "diffundera",
    "diffunderas": "diffundera",
    "diffunderat": "diffundera",
    "diffunderats": "diffundera",
    "diffunderbara": "diffunderbar",
    "diffunderbarare": "diffunderbar",
    "diffunderbarares": "diffunderbar",
    "diffunderbaras": "diffunderbar",
    "diffunderbarast": "diffunderbar",
    "diffunderbaraste": "diffunderbar",
    "diffunderbarastes": "diffunderbar",
    "diffunderbarasts": "diffunderbar",
    "diffunderbare": "diffunderbar",
    "diffunderbares": "diffunderbar",
    "diffunderbarheten": "diffunderbarhet",
    "diffunderbarhetens": "diffunderbarhet",
    "diffunderbarhets": "diffunderbarhet",
    "diffunderbars": "diffunderbar",
    "diffunderbart": "diffunderbar",
    "diffunderbarts": "diffunderbar",
    "diffunderingar": "diffundering",
    "diffunderingarna": "diffundering",
    "diffunderingarnas": "diffundering",
    "diffunderingars": "diffundering",
    "diffunderingen": "diffundering",
    "diffunderingens": "diffundering",
    "diffunderings": "diffundering",
    "diffusa": "diffus",
    "diffusare": "diffus",
    "diffusares": "diffus",
    "diffusas": "diffus",
    "diffusast": "diffus",
    "diffusaste": "diffus",
    "diffusastes": "diffus",
    "diffusasts": "diffus",
    "diffuse": "diffus",
    "diffuses": "diffus",
    "diffusionen": "diffusion",
    "diffusionens": "diffusion",
    "diffusioner": "diffusion",
    "diffusionerna": "diffusion",
    "diffusionernas": "diffusion",
    "diffusioners": "diffusion",
    "diffusions": "diffusion",
    "diffust": "diffus",
    "diffusts": "diffus",
    "difterien": "difteri",
    "difteriens": "difteri",
    "difterin": "difteri",
    "difterins": "difteri",
    "difteris": "difteri",
    "diftongen": "diftong",
    "diftongens": "diftong",
    "diftonger": "diftong",
    "diftongerad": "diftongera",
    "diftongerade": "diftongera",
    "diftongerades": "diftongera",
    "diftongerads": "diftongera",
    "diftongerande": "diftongera",
    "diftongeranden": "diftongerande",
    "diftongerandena": "diftongerande",
    "diftongerandenas": "diftongerande",
    "diftongerandens": "diftongerande",
    "diftongerandes": "diftongerande",
    "diftongerandet": "diftongerande",
    "diftongerandets": "diftongerande",
    "diftongerar": "diftongera",
    "diftongeras": "diftongera",
    "diftongerat": "diftongera",
    "diftongerats": "diftongera",
    "diftongerbara": "diftongerbar",
    "diftongerbarare": "diftongerbar",
    "diftongerbarares": "diftongerbar",
    "diftongerbaras": "diftongerbar",
    "diftongerbarast": "diftongerbar",
    "diftongerbaraste": "diftongerbar",
    "diftongerbarastes": "diftongerbar",
    "diftongerbarasts": "diftongerbar",
    "diftongerbare": "diftongerbar",
    "diftongerbares": "diftongerbar",
    "diftongerbarheten": "diftongerbarhet",
    "diftongerbarhetens": "diftongerbarhet",
    "diftongerbarhets": "diftongerbarhet",
    "diftongerbars": "diftongerbar",
    "diftongerbart": "diftongerbar",
    "diftongerbarts": "diftongerbar",
    "diftongeringar": "diftongering",
    "diftongeringarna": "diftongering",
    "diftongeringarnas": "diftongering",
    "diftongeringars": "diftongering",
    "diftongeringen": "diftongering",
    "diftongeringens": "diftongering",
    "diftongerings": "diftongering",
    "diftongerna": "diftong",
    "diftongernas": "diftong",
    "diftongers": "diftong",
    "diftongs": "diftong",
    "dig": "du",
    "digeln": "digel",
    "digelns": "digel",
    "digelpressar": "digelpress",
    "digelpressarna": "digelpress",
    "digelpressarnas": "digelpress",
    "digelpressars": "digelpress",
    "digelpressen": "digelpress",
    "digelpressens": "digelpress",
    "digels": "digel",
    "digerdöden": "digerdöd",
    "digerdödens": "digerdöd",
    "digerdöds": "digerdöd",
    "digererad": "digerera",
    "digererade": "digerera",
    "digererades": "digerera",
    "digererads": "digerera",
    "digererande": "digerera",
    "digereranden": "digererande",
    "digererandena": "digererande",
    "digererandenas": "digererande",
    "digererandens": "digererande",
    "digererandes": "digererande",
    "digererandet": "digererande",
    "digererandets": "digererande",
    "digererar": "digerera",
    "digereras": "digerera",
    "digererat": "digerera",
    "digererats": "digerera",
    "digererbara": "digererbar",
    "digererbarare": "digererbar",
    "digererbarares": "digererbar",
    "digererbaras": "digererbar",
    "digererbarast": "digererbar",
    "digererbaraste": "digererbar",
    "digererbarastes": "digererbar",
    "digererbarasts": "digererbar",
    "digererbare": "digererbar",
    "digererbares": "digererbar",
    "digererbarheten": "digererbarhet",
    "digererbarhetens": "digererbarhet",
    "digererbarhets": "digererbarhet",
    "digererbars": "digererbar",
    "digererbart": "digererbar",
    "digererbarts": "digererbar",
    "digereringar": "digerering",
    "digereringarna": "digerering",
    "digereringarnas": "digerering",
    "digereringars": "digerering",
    "digereringen": "digerering",
    "digereringens": "digerering",
    "digererings": "digerering",
    "digers": "diger",
    "digert": "diger",
    "digerts": "diger",
    "digestionen": "digestion",
    "digestionens": "digestion",
    "digestioner": "digestion",
    "digestionerna": "digestion",
    "digestionernas": "digestion",
    "digestioners": "digestion",
    "digestions": "digestion",
    "digg": "digga",
    "diggad": "digga",
    "diggade": "digga",
    "diggades": "digga",
    "diggads": "digga",
    "diggande": "digga",
    "digganden": "diggande",
    "diggandena": "diggande",
    "diggandenas": "diggande",
    "diggandens": "diggande",
    "diggandes": "diggande",
    "diggandet": "diggande",
    "diggandets": "diggande",
    "diggar": "digga",
    "diggas": "digga",
    "diggat": "digga",
    "diggats": "digga",
    "digital-TV-s": "digital-TV",
    "digital-TVs": "digital-TV",
    "digital-tevear": "digital-teve",
    "digital-tevearna": "digital-teve",
    "digital-tevearnas": "digital-teve",
    "digital-tevears": "digital-teve",
    "digital-teven": "digital-teve",
    "digital-tevena": "digital-teve",
    "digital-tevenas": "digital-teve",
    "digital-tevens": "digital-teve",
    "digital-teves": "digital-teve",
    "digital-tv:s": "digital-tv",
    "digitala": "digital",
    "digitalare": "digital",
    "digitalares": "digital",
    "digitalas": "digital",
    "digitalast": "digital",
    "digitalaste": "digital",
    "digitalastes": "digital",
    "digitalasts": "digital",
    "digitale": "digital",
    "digitales": "digital",
    "digitalisen": "digitalis",
    "digitalisens": "digitalis",
    "digitals": "digital",
    "digitalt": "digital",
    "digitaltevear": "digitalteve",
    "digitaltevearna": "digitalteve",
    "digitaltevearnas": "digitalteve",
    "digitaltevears": "digitalteve",
    "digitalteven": "digitalteve",
    "digitaltevena": "digitalteve",
    "digitaltevenas": "digitalteve",
    "digitaltevens": "digitalteve",
    "digitalteves": "digitalteve",
    "digitalts": "digital",
    "digivningar": "digivning",
    "digivningarna": "digivning",
    "digivningarnas": "digivning",
    "digivningars": "digivning",
    "digivningen": "digivning",
    "digivningens": "digivning",
    "digivnings": "digivning",
    "diglar": "digel",
    "diglarna": "digel",
    "diglarnas": "digel",
    "diglars": "digel",
    "diglossien": "diglossi",
    "diglossiens": "diglossi",
    "diglossin": "diglossi",
    "diglossins": "diglossi",
    "diglossis": "diglossi",
    "dignade": "digna",
    "dignades": "digna",
    "dignande": "digna",
    "dignanden": "dignande",
    "dignandena": "dignande",
    "dignandenas": "dignande",
    "dignandens": "dignande",
    "dignandes": "dignande",
    "dignandet": "dignande",
    "dignandets": "dignande",
    "dignar": "digna",
    "dignas": "digna",
    "dignat": "digna",
    "dignats": "digna",
    "digniteten": "dignitet",
    "dignitetens": "dignitet",
    "digniteter": "dignitet",
    "digniteterna": "dignitet",
    "digniteternas": "dignitet",
    "digniteters": "dignitet",
    "dignitets": "dignitet",
    "dignitären": "dignitär",
    "dignitärens": "dignitär",
    "dignitärer": "dignitär",
    "dignitärerna": "dignitär",
    "dignitärernas": "dignitär",
    "dignitärers": "dignitär",
    "dignitärs": "dignitär",
    "digra": "diger",
    "digrare": "diger",
    "digrares": "diger",
    "digras": "diger",
    "digrast": "diger",
    "digraste": "diger",
    "digrastes": "diger",
    "digrasts": "diger",
    "digre": "diger",
    "digres": "diger",
    "digressionen": "digression",
    "digressionens": "digression",
    "digressioner": "digression",
    "digressionerna": "digression",
    "digressionernas": "digression",
    "digressioners": "digression",
    "digressions": "digression",
    "dik": "dika",
    "dikad": "dika",
    "dikade": "dika",
    "dikades": "dika",
    "dikads": "dika",
    "dikande": "dika",
    "dikanden": "dikande",
    "dikandena": "dikande",
    "dikandenas": "dikande",
    "dikandens": "dikande",
    "dikandes": "dikande",
    "dikandet": "dikande",
    "dikandets": "dikande",
    "dikar": "dikare",
    "dikaren": "dikare",
    "dikarens": "dikare",
    "dikares": "dikare",
    "dikarna": "dikare",
    "dikarnas": "dikare",
    "dikas": "dika",
    "dikat": "dika",
    "dikats": "dika",
    "diken": "dike",
    "dikena": "dike",
    "dikenas": "dike",
    "dikens": "dike",
    "dikes": "dike",
    "dikeskörningar": "dikeskörning",
    "dikeskörningarna": "dikeskörning",
    "dikeskörningarnas": "dikeskörning",
    "dikeskörningars": "dikeskörning",
    "dikeskörningen": "dikeskörning",
    "dikeskörningens": "dikeskörning",
    "dikeskörnings": "dikeskörning",
    "dikesrenar": "dikesren",
    "dikesrenarna": "dikesren",
    "dikesrenarnas": "dikesren",
    "dikesrenars": "dikesren",
    "dikesrenen": "dikesren",
    "dikesrenens": "dikesren",
    "dikesrens": "dikesren",
    "diket": "dike",
    "dikets": "dike",
    "diklina": "diklin",
    "diklinare": "diklin",
    "diklinares": "diklin",
    "diklinas": "diklin",
    "diklinast": "diklin",
    "diklinaste": "diklin",
    "diklinastes": "diklin",
    "diklinasts": "diklin",
    "dikline": "diklin",
    "diklinen": "diklin",
    "diklinens": "diklin",
    "dikliner": "diklin",
    "diklinerna": "diklin",
    "diklinernas": "diklin",
    "dikliners": "diklin",
    "diklines": "diklin",
    "diklins": "diklin",
    "diklint": "diklin",
    "diklints": "diklin",
    "dikningar": "dikning",
    "dikningarna": "dikning",
    "dikningarnas": "dikning",
    "dikningars": "dikning",
    "dikningen": "dikning",
    "dikningens": "dikning",
    "diknings": "dikning",
    "dikotomien": "dikotomi",
    "dikotomiens": "dikotomi",
    "dikotomier": "dikotomi",
    "dikotomierna": "dikotomi",
    "dikotomiernas": "dikotomi",
    "dikotomiers": "dikotomi",
    "dikotomin": "dikotomi",
    "dikotomins": "dikotomi",
    "dikotomis": "dikotomi",
    "dikotyledona": "dikotyledon",
    "dikotyledonare": "dikotyledon",
    "dikotyledonares": "dikotyledon",
    "dikotyledonas": "dikotyledon",
    "dikotyledonast": "dikotyledon",
    "dikotyledonaste": "dikotyledon",
    "dikotyledonastes": "dikotyledon",
    "dikotyledonasts": "dikotyledon",
    "dikotyledone": "dikotyledon",
    "dikotyledonen": "dikotyledon",
    "dikotyledonens": "dikotyledon",
    "dikotyledoner": "dikotyledon",
    "dikotyledonerna": "dikotyledon",
    "dikotyledonernas": "dikotyledon",
    "dikotyledoners": "dikotyledon",
    "dikotyledones": "dikotyledon",
    "dikotyledons": "dikotyledon",
    "dikotyledont": "dikotyledon",
    "dikotyledonts": "dikotyledon",
    "dikt": "dikta",
    "diktad": "dikta",
    "diktade": "dikta",
    "diktades": "dikta",
    "diktads": "dikta",
    "diktafonen": "diktafon",
    "diktafonens": "diktafon",
    "diktafoner": "diktafon",
    "diktafonerna": "diktafon",
    "diktafonernas": "diktafon",
    "diktafoners": "diktafon",
    "diktafons": "diktafon",
    "diktamens": "diktamen",
    "diktamina": "diktamen",
    "diktaminas": "diktamen",
    "diktande": "dikta",
    "diktanden": "diktande",
    "diktandena": "diktande",
    "diktandenas": "diktande",
    "diktandens": "diktande",
    "diktandes": "diktande",
    "diktandet": "diktande",
    "diktandets": "diktande",
    "diktans": "diktan",
    "diktar": "diktare",
    "diktarbegåvningar": "diktarbegåvning",
    "diktarbegåvningarna": "diktarbegåvning",
    "diktarbegåvningarnas": "diktarbegåvning",
    "diktarbegåvningars": "diktarbegåvning",
    "diktarbegåvningen": "diktarbegåvning",
    "diktarbegåvningens": "diktarbegåvning",
    "diktarbegåvnings": "diktarbegåvning",
    "diktaren": "diktare",
    "diktarens": "diktare",
    "diktares": "diktare",
    "diktarfurstar": "diktarfurste",
    "diktarfurstarna": "diktarfurste",
    "diktarfurstarnas": "diktarfurste",
    "diktarfurstars": "diktarfurste",
    "diktarfursten": "diktarfurste",
    "diktarfurstens": "diktarfurste",
    "diktarfursterollen": "diktarfursteroll",
    "diktarfursterollens": "diktarfursteroll",
    "diktarfursteroller": "diktarfursteroll",
    "diktarfursterollerna": "diktarfursteroll",
    "diktarfursterollernas": "diktarfursteroll",
    "diktarfursterollers": "diktarfursteroll",
    "diktarfursterolls": "diktarfursteroll",
    "diktarfurstes": "diktarfurste",
    "diktargruppen": "diktargrupp",
    "diktargruppens": "diktargrupp",
    "diktargrupper": "diktargrupp",
    "diktargrupperna": "diktargrupp",
    "diktargruppernas": "diktargrupp",
    "diktargruppers": "diktargrupp",
    "diktargrupps": "diktargrupp",
    "diktarna": "diktare",
    "diktarnas": "diktare",
    "diktas": "dikta",
    "diktat": "dikta",
    "diktaten": "diktat",
    "diktatens": "diktat",
    "diktatet": "diktat",
    "diktatets": "diktat",
    "diktatorer": "diktator",
    "diktatorerna": "diktator",
    "diktatorernas": "diktator",
    "diktatorers": "diktator",
    "diktatoriska": "diktatorisk",
    "diktatoriskare": "diktatorisk",
    "diktatoriskares": "diktatorisk",
    "diktatoriskas": "diktatorisk",
    "diktatoriskast": "diktatorisk",
    "diktatoriskaste": "diktatorisk",
    "diktatoriskastes": "diktatorisk",
    "diktatoriskasts": "diktatorisk",
    "diktatoriske": "diktatorisk",
    "diktatoriskes": "diktatorisk",
    "diktatorisks": "diktatorisk",
    "diktatoriskt": "diktatorisk",
    "diktatoriskts": "diktatorisk",
    "diktatorn": "diktator",
    "diktatorns": "diktator",
    "diktators": "diktator",
    "diktats": "diktat",
    "diktaturen": "diktatur",
    "diktaturens": "diktatur",
    "diktaturer": "diktatur",
    "diktaturerna": "diktatur",
    "diktaturernas": "diktatur",
    "diktaturers": "diktatur",
    "diktaturregimen": "diktaturregim",
    "diktaturregimens": "diktaturregim",
    "diktaturregimer": "diktaturregim",
    "diktaturregimerna": "diktaturregim",
    "diktaturregimernas": "diktaturregim",
    "diktaturregimers": "diktaturregim",
    "diktaturregims": "diktaturregim",
    "diktaturs": "diktatur",
    "diktcykeln": "diktcykel",
    "diktcykelns": "diktcykel",
    "diktcykels": "diktcykel",
    "diktcyklar": "diktcykel",
    "diktcyklarna": "diktcykel",
    "diktcyklarnas": "diktcykel",
    "diktcyklars": "diktcykel",
    "diktcykler": "diktcykel",
    "diktcyklerna": "diktcykel",
    "diktcyklernas": "diktcykel",
    "diktcyklers": "diktcykel",
    "dikten": "dikt",
    "diktens": "dikt",
    "dikter": "dikt",
    "dikterad": "diktera",
    "dikterade": "diktera",
    "dikterades": "diktera",
    "dikterads": "diktera",
    "dikterande": "diktera",
    "dikteranden": "dikterande",
    "dikterandena": "dikterande",
    "dikterandenas": "dikterande",
    "dikterandens": "dikterande",
    "dikterandes": "dikterande",
    "dikterandet": "dikterande",
    "dikterandets": "dikterande",
    "dikterar": "diktera",
    "dikteras": "diktera",
    "dikterat": "diktera",
    "dikterats": "diktera",
    "dikterbara": "dikterbar",
    "dikterbarare": "dikterbar",
    "dikterbarares": "dikterbar",
    "dikterbaras": "dikterbar",
    "dikterbarast": "dikterbar",
    "dikterbaraste": "dikterbar",
    "dikterbarastes": "dikterbar",
    "dikterbarasts": "dikterbar",
    "dikterbare": "dikterbar",
    "dikterbares": "dikterbar",
    "dikterbarheten": "dikterbarhet",
    "dikterbarhetens": "dikterbarhet",
    "dikterbarhets": "dikterbarhet",
    "dikterbars": "dikterbar",
    "dikterbart": "dikterbar",
    "dikterbarts": "dikterbar",
    "dikteringar": "diktering",
    "dikteringarna": "diktering",
    "dikteringarnas": "diktering",
    "dikteringars": "diktering",
    "dikteringen": "diktering",
    "dikteringens": "diktering",
    "dikterings": "diktering",
    "dikteringsmaskinen": "dikteringsmaskin",
    "dikteringsmaskinens": "dikteringsmaskin",
    "dikteringsmaskiner": "dikteringsmaskin",
    "dikteringsmaskinerna": "dikteringsmaskin",
    "dikteringsmaskinernas": "dikteringsmaskin",
    "dikteringsmaskiners": "dikteringsmaskin",
    "dikteringsmaskins": "dikteringsmaskin",
    "dikterna": "dikt",
    "dikternas": "dikt",
    "dikters": "dikt",
    "diktionen": "diktion",
    "diktionens": "diktion",
    "diktioner": "diktion",
    "diktionerna": "diktion",
    "diktionernas": "diktion",
    "diktioners": "diktion",
    "diktions": "diktion",
    "diktkonsten": "diktkonst",
    "diktkonstens": "diktkonst",
    "diktkonsts": "diktkonst",
    "diktmässiga": "diktmässig",
    "diktmässigare": "diktmässig",
    "diktmässigares": "diktmässig",
    "diktmässigas": "diktmässig",
    "diktmässigast": "diktmässig",
    "diktmässigaste": "diktmässig",
    "diktmässigastes": "diktmässig",
    "diktmässigasts": "diktmässig",
    "diktmässige": "diktmässig",
    "diktmässiges": "diktmässig",
    "diktmässigs": "diktmässig",
    "diktmässigt": "diktmässig",
    "diktmässigts": "diktmässig",
    "diktningar": "diktning",
    "diktningarna": "diktning",
    "diktningarnas": "diktning",
    "diktningars": "diktning",
    "diktningen": "diktning",
    "diktningens": "diktning",
    "diktnings": "diktning",
    "dikts": "dikt",
    "diktsamlingar": "diktsamling",
    "diktsamlingarna": "diktsamling",
    "diktsamlingarnas": "diktsamling",
    "diktsamlingars": "diktsamling",
    "diktsamlingen": "diktsamling",
    "diktsamlingens": "diktsamling",
    "diktsamlings": "diktsamling",
    "diktverken": "diktverk",
    "diktverkens": "diktverk",
    "diktverket": "diktverk",
    "diktverkets": "diktverk",
    "diktverks": "diktverk",
    "dilatationen": "dilatation",
    "dilatationens": "dilatation",
    "dilatationer": "dilatation",
    "dilatationerna": "dilatation",
    "dilatationernas": "dilatation",
    "dilatationers": "dilatation",
    "dilatations": "dilatation",
    "dilatationsfogar": "dilatationsfog",
    "dilatationsfogarna": "dilatationsfog",
    "dilatationsfogarnas": "dilatationsfog",
    "dilatationsfogars": "dilatationsfog",
    "dilatationsfogen": "dilatationsfog",
    "dilatationsfogens": "dilatationsfog",
    "dilatationsfogs": "dilatationsfog",
    "dildoar": "dildo",
    "dildoarna": "dildo",
    "dildoarnas": "dildo",
    "dildoars": "dildo",
    "dildon": "dildo",
    "dildons": "dildo",
    "dildos": "dildo",
    "dilemman": "dilemma",
    "dilemmana": "dilemma",
    "dilemmanas": "dilemma",
    "dilemmans": "dilemma",
    "dilemmas": "dilemma",
    "dilemmat": "dilemma",
    "dilemmats": "dilemma",
    "dilettanten": "dilettant",
    "dilettantens": "dilettant",
    "dilettanter": "dilettant",
    "dilettanteriet": "dilettanteri",
    "dilettanteriets": "dilettanteri",
    "dilettanteris": "dilettanteri",
    "dilettanterit": "dilettanteri",
    "dilettanterits": "dilettanteri",
    "dilettanterna": "dilettant",
    "dilettanternas": "dilettant",
    "dilettanters": "dilettant",
    "dilettantiska": "dilettantisk",
    "dilettantiskare": "dilettantisk",
    "dilettantiskares": "dilettantisk",
    "dilettantiskas": "dilettantisk",
    "dilettantiskast": "dilettantisk",
    "dilettantiskaste": "dilettantisk",
    "dilettantiskastes": "dilettantisk",
    "dilettantiskasts": "dilettantisk",
    "dilettantiske": "dilettantisk",
    "dilettantiskes": "dilettantisk",
    "dilettantisks": "dilettantisk",
    "dilettantiskt": "dilettantisk",
    "dilettantiskts": "dilettantisk",
    "dilettantismen": "dilettantism",
    "dilettantismens": "dilettantism",
    "dilettantismer": "dilettantism",
    "dilettantismerna": "dilettantism",
    "dilettantismernas": "dilettantism",
    "dilettantismers": "dilettantism",
    "dilettantisms": "dilettantism",
    "dilettantmässiga": "dilettantmässig",
    "dilettantmässigare": "dilettantmässig",
    "dilettantmässigares": "dilettantmässig",
    "dilettantmässigas": "dilettantmässig",
    "dilettantmässigast": "dilettantmässig",
    "dilettantmässigaste": "dilettantmässig",
    "dilettantmässigastes": "dilettantmässig",
    "dilettantmässigasts": "dilettantmässig",
    "dilettantmässige": "dilettantmässig",
    "dilettantmässiges": "dilettantmässig",
    "dilettantmässigheten": "dilettantmässighet",
    "dilettantmässighetens": "dilettantmässighet",
    "dilettantmässighets": "dilettantmässighet",
    "dilettantmässigs": "dilettantmässig",
    "dilettantmässigt": "dilettantmässig",
    "dilettantmässigts": "dilettantmässig",
    "dilettants": "dilettant",
    "diligensen": "diligens",
    "diligensens": "diligens",
    "diligenser": "diligens",
    "diligenserna": "diligens",
    "diligensernas": "diligens",
    "diligensers": "diligens",
    "dill": "dilla",
    "dillade": "dilla",
    "dillades": "dilla",
    "dillande": "dilla",
    "dillanden": "dillande",
    "dillandena": "dillande",
    "dillandenas": "dillande",
    "dillandens": "dillande",
    "dillandes": "dillande",
    "dillandet": "dillande",
    "dillandets": "dillande",
    "dillar": "dilla",
    "dillas": "dilla",
    "dillat": "dilla",
    "dillats": "dilla",
    "dillen": "dille",
    "dillens": "dille",
    "dillerier": "dilleri",
    "dillerierna": "dilleri",
    "dilleriernas": "dilleri",
    "dilleriers": "dilleri",
    "dilleriet": "dilleri",
    "dilleriets": "dilleri",
    "dilleris": "dilleri",
    "dillerit": "dilleri",
    "dillerits": "dilleri",
    "dilles": "dille",
    "dillet": "dille",
    "dillets": "dille",
    "dillköttet": "dillkött",
    "dillköttets": "dillkött",
    "dillkötts": "dillkött",
    "dills": "dill",
    "dillsåsen": "dillsås",
    "dillsåsens": "dillsås",
    "dillsåser": "dillsås",
    "dillsåserna": "dillsås",
    "dillsåsernas": "dillsås",
    "dillsåsers": "dillsås",
    "dim": "dimma",
    "dimbankar": "dimbank",
    "dimbankarna": "dimbank",
    "dimbankarnas": "dimbank",
    "dimbankars": "dimbank",
    "dimbanken": "dimbank",
    "dimbankens": "dimbank",
    "dimbanks": "dimbank",
    "dimbildningar": "dimbildning",
    "dimbildningarna": "dimbildning",
    "dimbildningarnas": "dimbildning",
    "dimbildningars": "dimbildning",
    "dimbildningen": "dimbildning",
    "dimbildningens": "dimbildning",
    "dimbildnings": "dimbildning",
    "dimblåa": "dimblå",
    "dimblåare": "dimblå",
    "dimblåares": "dimblå",
    "dimblåas": "dimblå",
    "dimblåast": "dimblå",
    "dimblåaste": "dimblå",
    "dimblåastes": "dimblå",
    "dimblåasts": "dimblå",
    "dimblåe": "dimblå",
    "dimblåes": "dimblå",
    "dimblås": "dimblå",
    "dimblått": "dimblå",
    "dimblåtts": "dimblå",
    "dimbåg": "dimbåge",
    "dimbågar": "dimbåge",
    "dimbågarna": "dimbåge",
    "dimbågarnas": "dimbåge",
    "dimbågars": "dimbåge",
    "dimbågen": "dimbåge",
    "dimbågens": "dimbåge",
    "dimbåges": "dimbåge",
    "dimbågs": "dimbåge",
    "dimensionella": "dimensionell",
    "dimensionellare": "dimensionell",
    "dimensionellares": "dimensionell",
    "dimensionellas": "dimensionell",
    "dimensionellast": "dimensionell",
    "dimensionellaste": "dimensionell",
    "dimensionellastes": "dimensionell",
    "dimensionellasts": "dimensionell",
    "dimensionelle": "dimensionell",
    "dimensionelles": "dimensionell",
    "dimensionells": "dimensionell",
    "dimensionellt": "dimensionell",
    "dimensionellts": "dimensionell",
    "dimensionen": "dimension",
    "dimensionens": "dimension",
    "dimensioner": "dimension",
    "dimensionerad": "dimensionera",
    "dimensionerade": "dimensionera",
    "dimensionerades": "dimensionera",
    "dimensionerads": "dimensionera",
    "dimensionerande": "dimensionera",
    "dimensioneranden": "dimensionerande",
    "dimensionerandena": "dimensionerande",
    "dimensionerandenas": "dimensionerande",
    "dimensionerandens": "dimensionerande",
    "dimensionerandes": "dimensionerande",
    "dimensionerandet": "dimensionerande",
    "dimensionerandets": "dimensionerande",
    "dimensionerar": "dimensionera",
    "dimensioneras": "dimensionera",
    "dimensionerat": "dimensionera",
    "dimensionerats": "dimensionera",
    "dimensionerbara": "dimensionerbar",
    "dimensionerbarare": "dimensionerbar",
    "dimensionerbarares": "dimensionerbar",
    "dimensionerbaras": "dimensionerbar",
    "dimensionerbarast": "dimensionerbar",
    "dimensionerbaraste": "dimensionerbar",
    "dimensionerbarastes": "dimensionerbar",
    "dimensionerbarasts": "dimensionerbar",
    "dimensionerbare": "dimensionerbar",
    "dimensionerbares": "dimensionerbar",
    "dimensionerbarheten": "dimensionerbarhet",
    "dimensionerbarhetens": "dimensionerbarhet",
    "dimensionerbarhets": "dimensionerbarhet",
    "dimensionerbars": "dimensionerbar",
    "dimensionerbart": "dimensionerbar",
    "dimensionerbarts": "dimensionerbar",
    "dimensioneringar": "dimensionering",
    "dimensioneringarna": "dimensionering",
    "dimensioneringarnas": "dimensionering",
    "dimensioneringars": "dimensionering",
    "dimensioneringen": "dimensionering",
    "dimensioneringens": "dimensionering",
    "dimensionerings": "dimensionering",
    "dimensionerna": "dimension",
    "dimensionernas": "dimension",
    "dimensioners": "dimension",
    "dimensions": "dimension",
    "dimensionsavverkningar": "dimensionsavverkning",
    "dimensionsavverkningarna": "dimensionsavverkning",
    "dimensionsavverkningarnas": "dimensionsavverkning",
    "dimensionsavverkningars": "dimensionsavverkning",
    "dimensionsavverkningen": "dimensionsavverkning",
    "dimensionsavverkningens": "dimensionsavverkning",
    "dimensionsavverknings": "dimensionsavverkning",
    "dimfrosten": "dimfrost",
    "dimfrostens": "dimfrost",
    "dimfrosts": "dimfrost",
    "dimhöljda": "dimhöljd",
    "dimhöljdare": "dimhöljd",
    "dimhöljdares": "dimhöljd",
    "dimhöljdas": "dimhöljd",
    "dimhöljdast": "dimhöljd",
    "dimhöljdaste": "dimhöljd",
    "dimhöljdastes": "dimhöljd",
    "dimhöljdasts": "dimhöljd",
    "dimhöljde": "dimhöljd",
    "dimhöljdes": "dimhöljd",
    "dimhöljds": "dimhöljd",
    "dimhöljt": "dimhöljd",
    "dimhöljts": "dimhöljd",
    "diminuendon": "diminuendo",
    "diminuendona": "diminuendo",
    "diminuendonas": "diminuendo",
    "diminuendons": "diminuendo",
    "diminuendos": "diminuendo",
    "diminuendot": "diminuendo",
    "diminuendots": "diminuendo",
    "diminutiva": "diminutiv",
    "diminutivare": "diminutiv",
    "diminutivares": "diminutiv",
    "diminutivas": "diminutiv",
    "diminutivast": "diminutiv",
    "diminutivaste": "diminutiv",
    "diminutivastes": "diminutiv",
    "diminutivasts": "diminutiv",
    "diminutive": "diminutiv",
    "diminutiven": "diminutiv",
    "diminutivens": "diminutiv",
    "diminutiver": "diminutiv",
    "diminutiverna": "diminutiv",
    "diminutivernas": "diminutiv",
    "diminutivers": "diminutiv",
    "diminutives": "diminutiv",
    "diminutivet": "diminutiv",
    "diminutivets": "diminutiv",
    "diminutivs": "diminutiv",
    "diminutivt": "diminutiv",
    "diminutivts": "diminutiv",
    "dimissionen": "dimission",
    "dimissionens": "dimission",
    "dimissioner": "dimission",
    "dimissionerna": "dimission",
    "dimissionernas": "dimission",
    "dimissioners": "dimission",
    "dimissions": "dimission",
    "dimkammar": "dimkammare",
    "dimkammaren": "dimkammare",
    "dimkammarens": "dimkammare",
    "dimkammares": "dimkammare",
    "dimkamrar": "dimkammare",
    "dimkamrarna": "dimkammare",
    "dimkamrarnas": "dimkammare",
    "dimkamrars": "dimkammare",
    "dimljusen": "dimljus",
    "dimljusens": "dimljus",
    "dimljuset": "dimljus",
    "dimljusets": "dimljus",
    "dimman": "dimma",
    "dimmans": "dimma",
    "dimmas": "dimma",
    "dimme": "dimma",
    "dimmiga": "dimmig",
    "dimmigare": "dimmig",
    "dimmigares": "dimmig",
    "dimmigas": "dimmig",
    "dimmigast": "dimmig",
    "dimmigaste": "dimmig",
    "dimmigastes": "dimmig",
    "dimmigasts": "dimmig",
    "dimmige": "dimmig",
    "dimmiges": "dimmig",
    "dimmigheten": "dimmighet",
    "dimmighetens": "dimmighet",
    "dimmighets": "dimmighet",
    "dimmigs": "dimmig",
    "dimmigt": "dimmig",
    "dimmigts": "dimmig",
    "dimmolnen": "dimmoln",
    "dimmolnens": "dimmoln",
    "dimmolnet": "dimmoln",
    "dimmolnets": "dimmoln",
    "dimmolns": "dimmoln",
    "dimmor": "dimma",
    "dimmorna": "dimma",
    "dimmornas": "dimma",
    "dimmors": "dimma",
    "dimorfa": "dimorf",
    "dimorfare": "dimorf",
    "dimorfares": "dimorf",
    "dimorfas": "dimorf",
    "dimorfast": "dimorf",
    "dimorfaste": "dimorf",
    "dimorfastes": "dimorf",
    "dimorfasts": "dimorf",
    "dimorfe": "dimorf",
    "dimorfes": "dimorf",
    "dimorfien": "dimorfi",
    "dimorfiens": "dimorfi",
    "dimorfier": "dimorfi",
    "dimorfierna": "dimorfi",
    "dimorfiernas": "dimorfi",
    "dimorfiers": "dimorfi",
    "dimorfin": "dimorfi",
    "dimorfins": "dimorfi",
    "dimorfis": "dimorfi",
    "dimorfismen": "dimorfism",
    "dimorfismens": "dimorfism",
    "dimorfismer": "dimorfism",
    "dimorfismerna": "dimorfism",
    "dimorfismernas": "dimorfism",
    "dimorfismers": "dimorfism",
    "dimorfisms": "dimorfism",
    "dimorfs": "dimorf",
    "dimorft": "dimorf",
    "dimorfts": "dimorf",
    "dimp": "dimpa",
    "dimpande": "dimpa",
    "dimpanden": "dimpande",
    "dimpandena": "dimpande",
    "dimpandenas": "dimpande",
    "dimpandens": "dimpande",
    "dimpandes": "dimpande",
    "dimpandet": "dimpande",
    "dimpandets": "dimpande",
    "dimpas": "dimpa",
    "dimpe": "dimpa",
    "dimper": "dimpa",
    "dimpes": "dimpa",
    "dimps": "dimpa",
    "dimridåer": "dimridå",
    "dimridåerna": "dimridå",
    "dimridåernas": "dimridå",
    "dimridåers": "dimridå",
    "dimridån": "dimridå",
    "dimridåns": "dimridå",
    "dimridås": "dimridå",
    "dims": "dimma",
    "dimslöjan": "dimslöja",
    "dimslöjans": "dimslöja",
    "dimslöjas": "dimslöja",
    "dimslöje": "dimslöja",
    "dimslöjor": "dimslöja",
    "dimslöjorna": "dimslöja",
    "dimslöjornas": "dimslöja",
    "dimslöjors": "dimslöja",
    "din": "di",
    "dina": "du",
    "dinaren": "dinar",
    "dinarens": "dinar",
    "dinarer": "dinar",
    "dinarerna": "dinar",
    "dinarernas": "dinar",
    "dinarers": "dinar",
    "dinars": "dinar",
    "dinatriumvätefosfaten": "dinatriumvätefosfat",
    "dinatriumvätefosfatens": "dinatriumvätefosfat",
    "dinatriumvätefosfater": "dinatriumvätefosfat",
    "dinatriumvätefosfaterna": "dinatriumvätefosfat",
    "dinatriumvätefosfaternas": "dinatriumvätefosfat",
    "dinatriumvätefosfaters": "dinatriumvätefosfat",
    "dinatriumvätefosfatet": "dinatriumvätefosfat",
    "dinatriumvätefosfatets": "dinatriumvätefosfat",
    "dinatriumvätefosfats": "dinatriumvätefosfat",
    "dinerade": "dinera",
    "dinerades": "dinera",
    "dinerande": "dinera",
    "dineranden": "dinerande",
    "dinerandena": "dinerande",
    "dinerandenas": "dinerande",
    "dinerandens": "dinerande",
    "dinerandes": "dinerande",
    "dinerandet": "dinerande",
    "dinerandets": "dinerande",
    "dinerar": "dinera",
    "dineras": "dinera",
    "dinerat": "dinera",
    "dinerats": "dinera",
    "dineringar": "dinering",
    "dineringarna": "dinering",
    "dineringarnas": "dinering",
    "dineringars": "dinering",
    "dineringen": "dinering",
    "dineringens": "dinering",
    "dinerings": "dinering",
    "ding": "dinge",
    "dinga": "ding",
    "dingar": "dinge",
    "dingare": "ding",
    "dingares": "ding",
    "dingarna": "dinge",
    "dingarnas": "dinge",
    "dingars": "dinge",
    "dingas": "ding",
    "dingast": "ding",
    "dingaste": "ding",
    "dingastes": "ding",
    "dingasts": "ding",
    "dinge": "ding",
    "dingel": "dingla",
    "dingeldangels": "dingeldangel",
    "dingeldanglet": "dingeldangel",
    "dingeldanglets": "dingeldangel",
    "dingen": "dinge",
    "dingens": "dinge",
    "dinges": "dinge",
    "dingheten": "dinghet",
    "dinghetens": "dinghet",
    "dinghets": "dinghet",
    "dinglade": "dingla",
    "dinglades": "dingla",
    "dinglande": "dingla",
    "dinglanden": "dinglande",
    "dinglandena": "dinglande",
    "dinglandenas": "dinglande",
    "dinglandens": "dinglande",
    "dinglandes": "dinglande",
    "dinglandet": "dinglande",
    "dinglandets": "dinglande",
    "dinglar": "dingla",
    "dinglas": "dingla",
    "dinglat": "dingla",
    "dinglats": "dingla",
    "dingon": "dingo",
    "dingons": "dingo",
    "dingor": "dingo",
    "dingorna": "dingo",
    "dingornas": "dingo",
    "dingors": "dingo",
    "dingos": "dingo",
    "dings": "dinge",
    "dinkelen": "dinkel",
    "dinkelens": "dinkel",
    "dinkeln": "dinkel",
    "dinkelns": "dinkel",
    "dinkels": "dinkel",
    "dinosauren": "dinosaur",
    "dinosaurens": "dinosaur",
    "dinosaurer": "dinosaur",
    "dinosaurerna": "dinosaur",
    "dinosaurernas": "dinosaur",
    "dinosaurers": "dinosaur",
    "dinosauriearten": "dinosaurieart",
    "dinosaurieartens": "dinosaurieart",
    "dinosauriearter": "dinosaurieart",
    "dinosauriearterna": "dinosaurieart",
    "dinosauriearternas": "dinosaurieart",
    "dinosauriearters": "dinosaurieart",
    "dinosauriearts": "dinosaurieart",
    "dinosaurien": "dinosaurie",
    "dinosauriens": "dinosaurie",
    "dinosaurier": "dinosaurie",
    "dinosaurierna": "dinosaurie",
    "dinosauriernas": "dinosaurie",
    "dinosauriers": "dinosaurie",
    "dinosauries": "dinosaurie",
    "dinosaurs": "dinosaur",
    "dins": "di",
    "dinéer": "diné",
    "dinéerna": "diné",
    "dinéernas": "diné",
    "dinéers": "diné",
    "dinén": "diné",
    "dinéns": "diné",
    "dinés": "diné",
    "dioden": "diod",
    "diodens": "diod",
    "dioder": "diod",
    "dioderna": "diod",
    "diodernas": "diod",
    "dioders": "diod",
    "diods": "diod",
    "dionysiska": "dionysisk",
    "dionysiskare": "dionysisk",
    "dionysiskares": "dionysisk",
    "dionysiskas": "dionysisk",
    "dionysiskast": "dionysisk",
    "dionysiskaste": "dionysisk",
    "dionysiskastes": "dionysisk",
    "dionysiskasts": "dionysisk",
    "dionysiske": "dionysisk",
    "dionysiskes": "dionysisk",
    "dionysisks": "dionysisk",
    "dionysiskt": "dionysisk",
    "dionysiskts": "dionysisk",
    "dioptern": "diopter",
    "diopterns": "diopter",
    "diopters": "diopter",
    "dioptrar": "diopter",
    "dioptrarna": "diopter",
    "dioptrarnas": "diopter",
    "dioptrars": "diopter",
    "dioptrien": "dioptri",
    "dioptriens": "dioptri",
    "dioptrier": "dioptri",
    "dioptrierna": "dioptri",
    "dioptriernas": "dioptri",
    "dioptriers": "dioptri",
    "dioptriken": "dioptrik",
    "dioptrikens": "dioptrik",
    "dioptriks": "dioptrik",
    "dioptrin": "dioptri",
    "dioptrins": "dioptri",
    "dioptris": "dioptri",
    "dioptriska": "dioptrisk",
    "dioptriskare": "dioptrisk",
    "dioptriskares": "dioptrisk",
    "dioptriskas": "dioptrisk",
    "dioptriskast": "dioptrisk",
    "dioptriskaste": "dioptrisk",
    "dioptriskastes": "dioptrisk",
    "dioptriskasts": "dioptrisk",
    "dioptriske": "dioptrisk",
    "dioptriskes": "dioptrisk",
    "dioptrisks": "dioptrisk",
    "dioptriskt": "dioptrisk",
    "dioptriskts": "dioptrisk",
    "dior": "dia",
    "dioraman": "diorama",
    "dioramana": "diorama",
    "dioramanas": "diorama",
    "dioramans": "diorama",
    "dioramas": "diorama",
    "dioramat": "diorama",
    "dioramats": "diorama",
    "dioramor": "diorama",
    "dioramorna": "diorama",
    "dioramornas": "diorama",
    "dioramors": "diorama",
    "dioriten": "diorit",
    "dioritens": "diorit",
    "dioriter": "diorit",
    "dioriterna": "diorit",
    "dioriternas": "diorit",
    "dioriters": "diorit",
    "diorits": "diorit",
    "diorna": "dia",
    "diornas": "dia",
    "diors": "dia",
    "dioskuren": "dioskur",
    "dioskurens": "dioskur",
    "dioskurer": "dioskur",
    "dioskurerna": "dioskur",
    "dioskurernas": "dioskur",
    "dioskurers": "dioskur",
    "dioskurs": "dioskur",
    "dioxiner": "dioxin",
    "dioxinerna": "dioxin",
    "dioxinernas": "dioxin",
    "dioxiners": "dioxin",
    "dioxinet": "dioxin",
    "dioxinets": "dioxin",
    "dioxins": "dioxin",
    "dipar": "dip",
    "diparna": "dip",
    "diparnas": "dip",
    "dipars": "dip",
    "dipen": "dip",
    "dipens": "dip",
    "diperioden": "diperiod",
    "diperiodens": "diperiod",
    "diperioder": "diperiod",
    "diperioderna": "diperiod",
    "diperiodernas": "diperiod",
    "diperioders": "diperiod",
    "diperiods": "diperiod",
    "diploida": "diploid",
    "diploidare": "diploid",
    "diploidares": "diploid",
    "diploidas": "diploid",
    "diploidast": "diploid",
    "diploidaste": "diploid",
    "diploidastes": "diploid",
    "diploidasts": "diploid",
    "diploide": "diploid",
    "diploides": "diploid",
    "diploids": "diploid",
    "diplomatarie": "diplomatarium",
    "diplomatarier": "diplomatarium",
    "diplomatarierna": "diplomatarium",
    "diplomatariernas": "diplomatarium",
    "diplomatariers": "diplomatarium",
    "diplomatariet": "diplomatarium",
    "diplomatariets": "diplomatarium",
    "diplomatariska": "diplomatarisk",
    "diplomatariskare": "diplomatarisk",
    "diplomatariskares": "diplomatarisk",
    "diplomatariskas": "diplomatarisk",
    "diplomatariskast": "diplomatarisk",
    "diplomatariskaste": "diplomatarisk",
    "diplomatariskastes": "diplomatarisk",
    "diplomatariskasts": "diplomatarisk",
    "diplomatariske": "diplomatarisk",
    "diplomatariskes": "diplomatarisk",
    "diplomatarisks": "diplomatarisk",
    "diplomatariskt": "diplomatarisk",
    "diplomatariskts": "diplomatarisk",
    "diplomatariums": "diplomatarium",
    "diplomatbostaden": "diplomatbostad",
    "diplomatbostadens": "diplomatbostad",
    "diplomatbostads": "diplomatbostad",
    "diplomatbostan": "diplomatbostad",
    "diplomatbostans": "diplomatbostad",
    "diplomatbostäder": "diplomatbostad",
    "diplomatbostäderna": "diplomatbostad",
    "diplomatbostädernas": "diplomatbostad",
    "diplomatbostäders": "diplomatbostad",
    "diplomatdottern": "diplomatdotter",
    "diplomatdotterns": "diplomatdotter",
    "diplomatdotters": "diplomatdotter",
    "diplomatdöttrar": "diplomatdotter",
    "diplomatdöttrarna": "diplomatdotter",
    "diplomatdöttrarnas": "diplomatdotter",
    "diplomatdöttrars": "diplomatdotter",
    "diplomaten": "diplomat",
    "diplomatens": "diplomat",
    "diplomater": "diplomat",
    "diplomaterna": "diplomat",
    "diplomaternas": "diplomat",
    "diplomaters": "diplomat",
    "diplomathustrun": "diplomathustru",
    "diplomathustruns": "diplomathustru",
    "diplomathustrur": "diplomathustru",
    "diplomathustrurna": "diplomathustru",
    "diplomathustrurnas": "diplomathustru",
    "diplomathustrurs": "diplomathustru",
    "diplomathustrus": "diplomathustru",
    "diplomatien": "diplomati",
    "diplomatiens": "diplomati",
    "diplomatiken": "diplomatik",
    "diplomatikens": "diplomatik",
    "diplomatiks": "diplomatik",
    "diplomatin": "diplomati",
    "diplomatins": "diplomati",
    "diplomatis": "diplomati",
    "diplomatiska": "diplomatisk",
    "diplomatiskare": "diplomatisk",
    "diplomatiskares": "diplomatisk",
    "diplomatiskas": "diplomatisk",
    "diplomatiskast": "diplomatisk",
    "diplomatiskaste": "diplomatisk",
    "diplomatiskastes": "diplomatisk",
    "diplomatiskasts": "diplomatisk",
    "diplomatiske": "diplomatisk",
    "diplomatiskes": "diplomatisk",
    "diplomatisks": "diplomatisk",
    "diplomatiskt": "diplomatisk",
    "diplomatiskts": "diplomatisk",
    "diplomatkretsar": "diplomatkrets",
    "diplomatkretsarna": "diplomatkrets",
    "diplomatkretsarnas": "diplomatkrets",
    "diplomatkretsars": "diplomatkrets",
    "diplomatkretsen": "diplomatkrets",
    "diplomatkretsens": "diplomatkrets",
    "diplomatpassen": "diplomatpass",
    "diplomatpassens": "diplomatpass",
    "diplomatpasset": "diplomatpass",
    "diplomatpassets": "diplomatpass",
    "diplomatportföljen": "diplomatportfölj",
    "diplomatportföljens": "diplomatportfölj",
    "diplomatportföljer": "diplomatportfölj",
    "diplomatportföljerna": "diplomatportfölj",
    "diplomatportföljernas": "diplomatportfölj",
    "diplomatportföljers": "diplomatportfölj",
    "diplomatportföljs": "diplomatportfölj",
    "diplomatposten": "diplomatpost",
    "diplomatpostens": "diplomatpost",
    "diplomatposts": "diplomatpost",
    "diplomats": "diplomat",
    "diplomen": "diplom",
    "diplomens": "diplom",
    "diplomerad": "diplomera",
    "diplomerade": "diplomera",
    "diplomerades": "diplomera",
    "diplomerads": "diplomera",
    "diplomerande": "diplomera",
    "diplomeranden": "diplomerande",
    "diplomerandena": "diplomerande",
    "diplomerandenas": "diplomerande",
    "diplomerandens": "diplomerande",
    "diplomerandes": "diplomerande",
    "diplomerandet": "diplomerande",
    "diplomerandets": "diplomerande",
    "diplomerar": "diplomera",
    "diplomeras": "diplomera",
    "diplomerat": "diplomera",
    "diplomerats": "diplomera",
    "diplomerbara": "diplomerbar",
    "diplomerbarare": "diplomerbar",
    "diplomerbarares": "diplomerbar",
    "diplomerbaras": "diplomerbar",
    "diplomerbarast": "diplomerbar",
    "diplomerbaraste": "diplomerbar",
    "diplomerbarastes": "diplomerbar",
    "diplomerbarasts": "diplomerbar",
    "diplomerbare": "diplomerbar",
    "diplomerbares": "diplomerbar",
    "diplomerbarheten": "diplomerbarhet",
    "diplomerbarhetens": "diplomerbarhet",
    "diplomerbarhets": "diplomerbarhet",
    "diplomerbars": "diplomerbar",
    "diplomerbart": "diplomerbar",
    "diplomerbarts": "diplomerbar",
    "diplomeringar": "diplomering",
    "diplomeringarna": "diplomering",
    "diplomeringarnas": "diplomering",
    "diplomeringars": "diplomering",
    "diplomeringen": "diplomering",
    "diplomeringens": "diplomering",
    "diplomerings": "diplomering",
    "diplomet": "diplom",
    "diplomets": "diplom",
    "diplomingenjören": "diplomingenjör",
    "diplomingenjörens": "diplomingenjör",
    "diplomingenjörer": "diplomingenjör",
    "diplomingenjörerna": "diplomingenjör",
    "diplomingenjörernas": "diplomingenjör",
    "diplomingenjörers": "diplomingenjör",
    "diplomingenjörn": "diplomingenjör",
    "diplomingenjörns": "diplomingenjör",
    "diplomingenjörs": "diplomingenjör",
    "diploms": "diplom",
    "dipmixen": "dipmix",
    "dipmixens": "dipmix",
    "dipolen": "dipol",
    "dipolens": "dipol",
    "dipoler": "dipol",
    "dipolerna": "dipol",
    "dipolernas": "dipol",
    "dipolers": "dipol",
    "dipols": "dipol",
    "dipp": "dippa",
    "dippad": "dippa",
    "dippade": "dippa",
    "dippades": "dippa",
    "dippads": "dippa",
    "dippande": "dippa",
    "dippanden": "dippande",
    "dippandena": "dippande",
    "dippandenas": "dippande",
    "dippandens": "dippande",
    "dippandes": "dippande",
    "dippandet": "dippande",
    "dippandets": "dippande",
    "dippar": "dippa",
    "dipparna": "dipp",
    "dipparnas": "dipp",
    "dippars": "dipp",
    "dippas": "dippa",
    "dippat": "dippa",
    "dippats": "dippa",
    "dippen": "dipp",
    "dippens": "dipp",
    "dipps": "dipp",
    "dips": "dip",
    "dipsanet": "dipsan",
    "dipsanets": "dipsan",
    "dipsans": "dipsan",
    "dipsomanen": "dipsoman",
    "dipsomanens": "dipsoman",
    "dipsomaner": "dipsoman",
    "dipsomanerna": "dipsoman",
    "dipsomanernas": "dipsoman",
    "dipsomaners": "dipsoman",
    "dipsomanien": "dipsomani",
    "dipsomaniens": "dipsomani",
    "dipsomanin": "dipsomani",
    "dipsomanins": "dipsomani",
    "dipsomanis": "dipsomani",
    "dipsomans": "dipsoman",
    "diptyken": "diptyk",
    "diptykens": "diptyk",
    "diptyker": "diptyk",
    "diptykerna": "diptyk",
    "diptykernas": "diptyk",
    "diptykers": "diptyk",
    "diptyks": "diptyk",
    "direkta": "direkt",
    "direktare": "direkt",
    "direktares": "direkt",
    "direktas": "direkt",
    "direktast": "direkt",
    "direktaste": "direkt",
    "direktastes": "direkt",
    "direktasts": "direkt",
    "direktdemokratien": "direktdemokrati",
    "direktdemokratiens": "direktdemokrati",
    "direktdemokratin": "direktdemokrati",
    "direktdemokratins": "direktdemokrati",
    "direktdemokratis": "direktdemokrati",
    "direkte": "direkt",
    "direktes": "direkt",
    "direktflyget": "direktflyg",
    "direktflygets": "direktflyg",
    "direktflygs": "direktflyg",
    "direktheten": "direkthet",
    "direkthetens": "direkthet",
    "direktheter": "direkthet",
    "direktheterna": "direkthet",
    "direktheternas": "direkthet",
    "direktheters": "direkthet",
    "direkthets": "direkthet",
    "direktinflytanden": "direktinflytande",
    "direktinflytandena": "direktinflytande",
    "direktinflytandenas": "direktinflytande",
    "direktinflytandens": "direktinflytande",
    "direktinflytandes": "direktinflytande",
    "direktinflytandet": "direktinflytande",
    "direktinflytandets": "direktinflytande",
    "direktinsprutningar": "direktinsprutning",
    "direktinsprutningarna": "direktinsprutning",
    "direktinsprutningarnas": "direktinsprutning",
    "direktinsprutningars": "direktinsprutning",
    "direktinsprutningen": "direktinsprutning",
    "direktinsprutningens": "direktinsprutning",
    "direktinsprutnings": "direktinsprutning",
    "direktionen": "direktion",
    "direktionens": "direktion",
    "direktioner": "direktion",
    "direktionerna": "direktion",
    "direktionernas": "direktion",
    "direktioners": "direktion",
    "direktions": "direktion",
    "direktionskraften": "direktionskraft",
    "direktionskraftens": "direktionskraft",
    "direktionskrafts": "direktionskraft",
    "direktiven": "direktiv",
    "direktivens": "direktiv",
    "direktivet": "direktiv",
    "direktivets": "direktiv",
    "direktivs": "direktiv",
    "direktkontakten": "direktkontakt",
    "direktkontaktens": "direktkontakt",
    "direktkontakter": "direktkontakt",
    "direktkontakterna": "direktkontakt",
    "direktkontakternas": "direktkontakt",
    "direktkontakters": "direktkontakt",
    "direktkontakts": "direktkontakt",
    "direktlinjen": "direktlinje",
    "direktlinjens": "direktlinje",
    "direktlinjer": "direktlinje",
    "direktlinjerna": "direktlinje",
    "direktlinjernas": "direktlinje",
    "direktlinjers": "direktlinje",
    "direktlinjes": "direktlinje",
    "direktmetoden": "direktmetod",
    "direktmetodens": "direktmetod",
    "direktmetoder": "direktmetod",
    "direktmetoderna": "direktmetod",
    "direktmetodernas": "direktmetod",
    "direktmetoders": "direktmetod",
    "direktmetods": "direktmetod",
    "direktoren": "direktor",
    "direktorens": "direktor",
    "direktorer": "direktor",
    "direktorerna": "direktor",
    "direktorernas": "direktor",
    "direktorers": "direktor",
    "direktorn": "direktor",
    "direktorns": "direktor",
    "direktors": "direktor",
    "direktreferaten": "direktreferat",
    "direktreferatens": "direktreferat",
    "direktreferatet": "direktreferat",
    "direktreferatets": "direktreferat",
    "direktreferats": "direktreferat",
    "direktreklamen": "direktreklam",
    "direktreklamens": "direktreklam",
    "direktreklams": "direktreklam",
    "direktrisen": "direktris",
    "direktrisens": "direktris",
    "direktriser": "direktris",
    "direktriserna": "direktris",
    "direktrisernas": "direktris",
    "direktrisers": "direktris",
    "direkts": "direkt",
    "direktskotten": "direktskott",
    "direktskottens": "direktskott",
    "direktskottet": "direktskott",
    "direktskottets": "direktskott",
    "direktskotts": "direktskott",
    "direktsänd": "direktsända",
    "direktsändande": "direktsända",
    "direktsändandes": "direktsändande",
    "direktsändandet": "direktsändande",
    "direktsändandets": "direktsändande",
    "direktsändas": "direktsända",
    "direktsände": "direktsända",
    "direktsänder": "direktsända",
    "direktsändes": "direktsända",
    "direktsändningar": "direktsändning",
    "direktsändningarna": "direktsändning",
    "direktsändningarnas": "direktsändning",
    "direktsändningars": "direktsändning",
    "direktsändningen": "direktsändning",
    "direktsändningens": "direktsändning",
    "direktsändnings": "direktsändning",
    "direktsänds": "direktsända",
    "direktsänt": "direktsända",
    "direktsänts": "direktsända",
    "direktväxeln": "direktväxel",
    "direktväxelns": "direktväxel",
    "direktväxels": "direktväxel",
    "direktväxlar": "direktväxel",
    "direktväxlarna": "direktväxel",
    "direktväxlarnas": "direktväxel",
    "direktväxlars": "direktväxel",
    "direktören": "direktör",
    "direktörens": "direktör",
    "direktörer": "direktör",
    "direktörerna": "direktör",
    "direktörernas": "direktör",
    "direktörers": "direktör",
    "direktörn": "direktör",
    "direktörns": "direktör",
    "direktörs": "direktör",
    "dirigenten": "dirigent",
    "dirigentens": "dirigent",
    "dirigenter": "dirigent",
    "dirigenterna": "dirigent",
    "dirigenternas": "dirigent",
    "dirigenters": "dirigent",
    "dirigents": "dirigent",
    "dirigerad": "dirigera",
    "dirigerade": "dirigera",
    "dirigerades": "dirigera",
    "dirigerads": "dirigera",
    "dirigerande": "dirigera",
    "dirigeranden": "dirigerande",
    "dirigerandena": "dirigerande",
    "dirigerandenas": "dirigerande",
    "dirigerandens": "dirigerande",
    "dirigerandes": "dirigerande",
    "dirigerandet": "dirigerande",
    "dirigerandets": "dirigerande",
    "dirigerar": "dirigera",
    "dirigeras": "dirigera",
    "dirigerat": "dirigera",
    "dirigerats": "dirigera",
    "dirigerbara": "dirigerbar",
    "dirigerbarare": "dirigerbar",
    "dirigerbarares": "dirigerbar",
    "dirigerbaras": "dirigerbar",
    "dirigerbarast": "dirigerbar",
    "dirigerbaraste": "dirigerbar",
    "dirigerbarastes": "dirigerbar",
    "dirigerbarasts": "dirigerbar",
    "dirigerbare": "dirigerbar",
    "dirigerbares": "dirigerbar",
    "dirigerbarheten": "dirigerbarhet",
    "dirigerbarhetens": "dirigerbarhet",
    "dirigerbarhets": "dirigerbarhet",
    "dirigerbars": "dirigerbar",
    "dirigerbart": "dirigerbar",
    "dirigerbarts": "dirigerbar",
    "dirigeringar": "dirigering",
    "dirigeringarna": "dirigering",
    "dirigeringarnas": "dirigering",
    "dirigeringars": "dirigering",
    "dirigeringen": "dirigering",
    "dirigeringens": "dirigering",
    "dirigerings": "dirigering",
    "dirigismen": "dirigism",
    "dirigismens": "dirigism",
    "dirigismer": "dirigism",
    "dirigismerna": "dirigism",
    "dirigismernas": "dirigism",
    "dirigismers": "dirigism",
    "dirigisms": "dirigism",
    "dirk": "dirka",
    "dirkade": "dirka",
    "dirkades": "dirka",
    "dirkande": "dirka",
    "dirkanden": "dirkande",
    "dirkandena": "dirkande",
    "dirkandenas": "dirkande",
    "dirkandens": "dirkande",
    "dirkandes": "dirkande",
    "dirkandet": "dirkande",
    "dirkandets": "dirkande",
    "dirkar": "dirka",
    "dirkarna": "dirk",
    "dirkarnas": "dirk",
    "dirkars": "dirk",
    "dirkas": "dirka",
    "dirkat": "dirka",
    "dirkats": "dirka",
    "dirken": "dirk",
    "dirkens": "dirk",
    "dirks": "dirk",
    "dirr": "dirra",
    "dirrade": "dirra",
    "dirrades": "dirra",
    "dirrande": "dirra",
    "dirranden": "dirrande",
    "dirrandena": "dirrande",
    "dirrandenas": "dirrande",
    "dirrandens": "dirrande",
    "dirrandes": "dirrande",
    "dirrandet": "dirrande",
    "dirrandets": "dirrande",
    "dirrar": "dirra",
    "dirras": "dirra",
    "dirrat": "dirra",
    "dirrats": "dirra",
    "dis": "di",
    "disackariden": "disackarid",
    "disackaridens": "disackarid",
    "disackarider": "disackarid",
    "disackariderna": "disackarid",
    "disackaridernas": "disackarid",
    "disackariders": "disackarid",
    "disackarids": "disackarid",
    "disagios": "disagio",
    "disagiot": "disagio",
    "disagiots": "disagio",
    "disambiguerad": "disambiguera",
    "disambiguerade": "disambiguera",
    "disambiguerades": "disambiguera",
    "disambiguerads": "disambiguera",
    "disambiguerande": "disambiguera",
    "disambigueranden": "disambiguerande",
    "disambiguerandena": "disambiguerande",
    "disambiguerandenas": "disambiguerande",
    "disambiguerandens": "disambiguerande",
    "disambiguerandes": "disambiguerande",
    "disambiguerandet": "disambiguerande",
    "disambiguerandets": "disambiguerande",
    "disambiguerar": "disambiguera",
    "disambigueras": "disambiguera",
    "disambiguerat": "disambiguera",
    "disambiguerats": "disambiguera",
    "disambiguerbara": "disambiguerbar",
    "disambiguerbarare": "disambiguerbar",
    "disambiguerbarares": "disambiguerbar",
    "disambiguerbaras": "disambiguerbar",
    "disambiguerbarast": "disambiguerbar",
    "disambiguerbaraste": "disambiguerbar",
    "disambiguerbarastes": "disambiguerbar",
    "disambiguerbarasts": "disambiguerbar",
    "disambiguerbare": "disambiguerbar",
    "disambiguerbares": "disambiguerbar",
    "disambiguerbarheten": "disambiguerbarhet",
    "disambiguerbarhetens": "disambiguerbarhet",
    "disambiguerbarhets": "disambiguerbarhet",
    "disambiguerbars": "disambiguerbar",
    "disambiguerbart": "disambiguerbar",
    "disambiguerbarts": "disambiguerbar",
    "discipeln": "discipel",
    "discipelns": "discipel",
    "discipels": "discipel",
    "disciplar": "discipel",
    "disciplarna": "discipel",
    "disciplarnas": "discipel",
    "disciplars": "discipel",
    "disciplinboten": "disciplinbot",
    "disciplinbotens": "disciplinbot",
    "disciplinbots": "disciplinbot",
    "disciplinböter": "disciplinbot",
    "disciplinböterna": "disciplinbot",
    "disciplinböternas": "disciplinbot",
    "disciplinböters": "disciplinbot",
    "disciplinen": "disciplin",
    "disciplinens": "disciplin",
    "discipliner": "disciplin",
    "disciplinerad": "disciplinera",
    "disciplinerade": "disciplinerad",
    "disciplinerades": "disciplinerad",
    "disciplinerads": "disciplinerad",
    "disciplinerande": "disciplinera",
    "disciplineranden": "disciplinerande",
    "disciplinerandena": "disciplinerande",
    "disciplinerandenas": "disciplinerande",
    "disciplinerandens": "disciplinerande",
    "disciplinerandes": "disciplinerande",
    "disciplinerandet": "disciplinerande",
    "disciplinerandets": "disciplinerande",
    "disciplinerar": "disciplinera",
    "disciplineras": "disciplinera",
    "disciplinerat": "disciplinerad",
    "disciplinerats": "disciplinerad",
    "disciplinerbara": "disciplinerbar",
    "disciplinerbarare": "disciplinerbar",
    "disciplinerbarares": "disciplinerbar",
    "disciplinerbaras": "disciplinerbar",
    "disciplinerbarast": "disciplinerbar",
    "disciplinerbaraste": "disciplinerbar",
    "disciplinerbarastes": "disciplinerbar",
    "disciplinerbarasts": "disciplinerbar",
    "disciplinerbare": "disciplinerbar",
    "disciplinerbares": "disciplinerbar",
    "disciplinerbarheten": "disciplinerbarhet",
    "disciplinerbarhetens": "disciplinerbarhet",
    "disciplinerbarhets": "disciplinerbarhet",
    "disciplinerbars": "disciplinerbar",
    "disciplinerbart": "disciplinerbar",
    "disciplinerbarts": "disciplinerbar",
    "disciplineringar": "disciplinering",
    "disciplineringarna": "disciplinering",
    "disciplineringarnas": "disciplinering",
    "disciplineringars": "disciplinering",
    "disciplineringen": "disciplinering",
    "disciplineringens": "disciplinering",
    "disciplinerings": "disciplinering",
    "disciplinerna": "disciplin",
    "disciplinernas": "disciplin",
    "discipliners": "disciplin",
    "disciplinmålen": "disciplinmål",
    "disciplinmålens": "disciplinmål",
    "disciplinmålet": "disciplinmål",
    "disciplinmålets": "disciplinmål",
    "disciplinmåls": "disciplinmål",
    "disciplinpåföljden": "disciplinpåföljd",
    "disciplinpåföljdens": "disciplinpåföljd",
    "disciplinpåföljder": "disciplinpåföljd",
    "disciplinpåföljderna": "disciplinpåföljd",
    "disciplinpåföljdernas": "disciplinpåföljd",
    "disciplinpåföljders": "disciplinpåföljd",
    "disciplinpåföljds": "disciplinpåföljd",
    "disciplins": "disciplin",
    "disciplinstraffen": "disciplinstraff",
    "disciplinstraffens": "disciplinstraff",
    "disciplinstraffet": "disciplinstraff",
    "disciplinstraffets": "disciplinstraff",
    "disciplinstraffs": "disciplinstraff",
    "disciplinära": "disciplinär",
    "disciplinärare": "disciplinär",
    "disciplinärares": "disciplinär",
    "disciplinäras": "disciplinär",
    "disciplinärast": "disciplinär",
    "disciplinäraste": "disciplinär",
    "disciplinärastes": "disciplinär",
    "disciplinärasts": "disciplinär",
    "disciplinäre": "disciplinär",
    "disciplinäres": "disciplinär",
    "disciplinärs": "disciplinär",
    "disciplinärt": "disciplinär",
    "disciplinärts": "disciplinär",
    "discjockeyar": "discjockey",
    "discjockeyarna": "discjockey",
    "discjockeyarnas": "discjockey",
    "discjockeyars": "discjockey",
    "discjockeyen": "discjockey",
    "discjockeyens": "discjockey",
    "discjockeyer": "discjockey",
    "discjockeyerna": "discjockey",
    "discjockeyernas": "discjockey",
    "discjockeyers": "discjockey",
    "discjockeyn": "discjockey",
    "discjockeyns": "discjockey",
    "discjockeys": "discjockey",
    "discjockeysar": "discjockey",
    "discjockeysarna": "discjockey",
    "discjockeysarnas": "discjockey",
    "discjockeysars": "discjockey",
    "discomusiken": "discomusik",
    "discomusikens": "discomusik",
    "discomusiks": "discomusik",
    "discon": "disco",
    "discona": "disco",
    "disconas": "disco",
    "discons": "disco",
    "discos": "disco",
    "discot": "disco",
    "discots": "disco",
    "disen": "dis",
    "disens": "dis",
    "diser": "dis",
    "diserna": "dis",
    "disernas": "dis",
    "disers": "dis",
    "diset": "dis",
    "disets": "dis",
    "disharmonien": "disharmoni",
    "disharmoniens": "disharmoni",
    "disharmonier": "disharmoni",
    "disharmonierad": "disharmoniera",
    "disharmonierade": "disharmoniera",
    "disharmonierades": "disharmoniera",
    "disharmonierads": "disharmoniera",
    "disharmonierande": "disharmoniera",
    "disharmonieranden": "disharmonierande",
    "disharmonierandena": "disharmonierande",
    "disharmonierandenas": "disharmonierande",
    "disharmonierandens": "disharmonierande",
    "disharmonierandes": "disharmonierande",
    "disharmonierandet": "disharmonierande",
    "disharmonierandets": "disharmonierande",
    "disharmonierar": "disharmoniera",
    "disharmonieras": "disharmoniera",
    "disharmonierat": "disharmoniera",
    "disharmonierats": "disharmoniera",
    "disharmonierbara": "disharmonierbar",
    "disharmonierbarare": "disharmonierbar",
    "disharmonierbarares": "disharmonierbar",
    "disharmonierbaras": "disharmonierbar",
    "disharmonierbarast": "disharmonierbar",
    "disharmonierbaraste": "disharmonierbar",
    "disharmonierbarastes": "disharmonierbar",
    "disharmonierbarasts": "disharmonierbar",
    "disharmonierbare": "disharmonierbar",
    "disharmonierbares": "disharmonierbar",
    "disharmonierbarheten": "disharmonierbarhet",
    "disharmonierbarhetens": "disharmonierbarhet",
    "disharmonierbarhets": "disharmonierbarhet",
    "disharmonierbars": "disharmonierbar",
    "disharmonierbart": "disharmonierbar",
    "disharmonierbarts": "disharmonierbar",
    "disharmonieringar": "disharmoniering",
    "disharmonieringarna": "disharmoniering",
    "disharmonieringarnas": "disharmoniering",
    "disharmonieringars": "disharmoniering",
    "disharmonieringen": "disharmoniering",
    "disharmonieringens": "disharmoniering",
    "disharmonierings": "disharmoniering",
    "disharmonierna": "disharmoni",
    "disharmoniernas": "disharmoni",
    "disharmoniers": "disharmoni",
    "disharmonin": "disharmoni",
    "disharmonins": "disharmoni",
    "disharmonis": "disharmoni",
    "disharmoniska": "disharmonisk",
    "disharmoniskare": "disharmonisk",
    "disharmoniskares": "disharmonisk",
    "disharmoniskas": "disharmonisk",
    "disharmoniskast": "disharmonisk",
    "disharmoniskaste": "disharmonisk",
    "disharmoniskastes": "disharmonisk",
    "disharmoniskasts": "disharmonisk",
    "disharmoniske": "disharmonisk",
    "disharmoniskes": "disharmonisk",
    "disharmonisks": "disharmonisk",
    "disharmoniskt": "disharmonisk",
    "disharmoniskts": "disharmonisk",
    "disiga": "disig",
    "disigare": "disig",
    "disigares": "disig",
    "disigas": "disig",
    "disigast": "disig",
    "disigaste": "disig",
    "disigastes": "disig",
    "disigasts": "disig",
    "disige": "disig",
    "disiges": "disig",
    "disigs": "disig",
    "disigt": "disig",
    "disigts": "disig",
    "disjunkta": "disjunkt",
    "disjunktare": "disjunkt",
    "disjunktares": "disjunkt",
    "disjunktas": "disjunkt",
    "disjunktast": "disjunkt",
    "disjunktaste": "disjunkt",
    "disjunktastes": "disjunkt",
    "disjunktasts": "disjunkt",
    "disjunkte": "disjunkt",
    "disjunktes": "disjunkt",
    "disjunktionen": "disjunktion",
    "disjunktionens": "disjunktion",
    "disjunktioner": "disjunktion",
    "disjunktionerna": "disjunktion",
    "disjunktionernas": "disjunktion",
    "disjunktioners": "disjunktion",
    "disjunktions": "disjunktion",
    "disjunktiva": "disjunktiv",
    "disjunktivare": "disjunktiv",
    "disjunktivares": "disjunktiv",
    "disjunktivas": "disjunktiv",
    "disjunktivast": "disjunktiv",
    "disjunktivaste": "disjunktiv",
    "disjunktivastes": "disjunktiv",
    "disjunktivasts": "disjunktiv",
    "disjunktive": "disjunktiv",
    "disjunktives": "disjunktiv",
    "disjunktivs": "disjunktiv",
    "disjunktivt": "disjunktiv",
    "disjunktivts": "disjunktiv",
    "disjunkts": "disjunkt",
    "diskad": "diska",
    "diskade": "diska",
    "diskades": "diska",
    "diskads": "diska",
    "diskande": "diska",
    "diskanden": "diskande",
    "diskandena": "diskande",
    "diskandenas": "diskande",
    "diskandens": "diskande",
    "diskandes": "diskande",
    "diskandet": "diskande",
    "diskandets": "diskande",
    "diskanten": "diskant",
    "diskantens": "diskant",
    "diskanter": "diskant",
    "diskanterna": "diskant",
    "diskanternas": "diskant",
    "diskanters": "diskant",
    "diskantklaven": "diskantklav",
    "diskantklavens": "diskantklav",
    "diskantklaver": "diskantklav",
    "diskantklaverna": "diskantklav",
    "diskantklavernas": "diskantklav",
    "diskantklavers": "diskantklav",
    "diskantklavs": "diskantklav",
    "diskants": "diskant",
    "diskar": "diskare",
    "diskaren": "diskare",
    "diskarens": "diskare",
    "diskares": "diskare",
    "diskarna": "diskare",
    "diskarnas": "diskare",
    "diskars": "disk",
    "diskas": "diska",
    "diskat": "diska",
    "diskats": "diska",
    "diskblom": "diskblomma",
    "diskblomman": "diskblomma",
    "diskblommans": "diskblomma",
    "diskblommas": "diskblomma",
    "diskblomme": "diskblomma",
    "diskblommor": "diskblomma",
    "diskblommorna": "diskblomma",
    "diskblommornas": "diskblomma",
    "diskblommors": "diskblomma",
    "diskbloms": "diskblomma",
    "diskbrocken": "diskbrock",
    "diskbrockens": "diskbrock",
    "diskbrocket": "diskbrock",
    "diskbrockets": "diskbrock",
    "diskbrocks": "diskbrock",
    "diskbråcken": "diskbråck",
    "diskbråckens": "diskbråck",
    "diskbråcket": "diskbråck",
    "diskbråckets": "diskbråck",
    "diskbråcks": "diskbråck",
    "diskbänkar": "diskbänk",
    "diskbänkarna": "diskbänk",
    "diskbänkarnas": "diskbänk",
    "diskbänkars": "diskbänk",
    "diskbänken": "diskbänk",
    "diskbänkens": "diskbänk",
    "diskbänks": "diskbänk",
    "disken": "disk",
    "diskens": "disk",
    "disketten": "diskett",
    "diskettens": "diskett",
    "disketter": "diskett",
    "disketterna": "diskett",
    "disketternas": "diskett",
    "disketters": "diskett",
    "disketts": "diskett",
    "diskhoar": "diskho",
    "diskhoarna": "diskho",
    "diskhoarnas": "diskho",
    "diskhoars": "diskho",
    "diskhon": "diskho",
    "diskhons": "diskho",
    "diskhos": "diskho",
    "diskjockeyar": "diskjockey",
    "diskjockeyarna": "diskjockey",
    "diskjockeyarnas": "diskjockey",
    "diskjockeyars": "diskjockey",
    "diskjockeyen": "diskjockey",
    "diskjockeyens": "diskjockey",
    "diskjockeyer": "diskjockey",
    "diskjockeyerna": "diskjockey",
    "diskjockeyernas": "diskjockey",
    "diskjockeyers": "diskjockey",
    "diskjockeyn": "diskjockey",
    "diskjockeyns": "diskjockey",
    "diskjockeys": "diskjockey",
    "diskjockeysar": "diskjockey",
    "diskjockeysarna": "diskjockey",
    "diskjockeysarnas": "diskjockey",
    "diskjockeysars": "diskjockey",
    "diskmaskinen": "diskmaskin",
    "diskmaskinens": "diskmaskin",
    "diskmaskiner": "diskmaskin",
    "diskmaskinerna": "diskmaskin",
    "diskmaskinernas": "diskmaskin",
    "diskmaskiners": "diskmaskin",
    "diskmaskins": "diskmaskin",
    "diskmedels": "diskmedel",
    "diskmedlen": "diskmedel",
    "diskmedlens": "diskmedel",
    "diskmedlet": "diskmedel",
    "diskmedlets": "diskmedel",
    "diskofilen": "diskofil",
    "diskofilens": "diskofil",
    "diskofiler": "diskofil",
    "diskofilerna": "diskofil",
    "diskofilernas": "diskofil",
    "diskofilers": "diskofil",
    "diskofils": "diskofil",
    "diskomusiken": "diskomusik",
    "diskomusikens": "diskomusik",
    "diskomusiks": "diskomusik",
    "diskon": "disko",
    "diskona": "disko",
    "diskonas": "disko",
    "diskons": "disko",
    "diskonterad": "diskontera",
    "diskonterade": "diskontera",
    "diskonterades": "diskontera",
    "diskonterads": "diskontera",
    "diskonterande": "diskontera",
    "diskonteranden": "diskonterande",
    "diskonterandena": "diskonterande",
    "diskonterandenas": "diskonterande",
    "diskonterandens": "diskonterande",
    "diskonterandes": "diskonterande",
    "diskonterandet": "diskonterande",
    "diskonterandets": "diskonterande",
    "diskonterar": "diskontera",
    "diskonteras": "diskontera",
    "diskonterat": "diskontera",
    "diskonterats": "diskontera",
    "diskonterbara": "diskonterbar",
    "diskonterbarare": "diskonterbar",
    "diskonterbarares": "diskonterbar",
    "diskonterbaras": "diskonterbar",
    "diskonterbarast": "diskonterbar",
    "diskonterbaraste": "diskonterbar",
    "diskonterbarastes": "diskonterbar",
    "diskonterbarasts": "diskonterbar",
    "diskonterbare": "diskonterbar",
    "diskonterbares": "diskonterbar",
    "diskonterbarheten": "diskonterbarhet",
    "diskonterbarhetens": "diskonterbarhet",
    "diskonterbarhets": "diskonterbarhet",
    "diskonterbars": "diskonterbar",
    "diskonterbart": "diskonterbar",
    "diskonterbarts": "diskonterbar",
    "diskonteringar": "diskontering",
    "diskonteringarna": "diskontering",
    "diskonteringarnas": "diskontering",
    "diskonteringars": "diskontering",
    "diskonteringen": "diskontering",
    "diskonteringens": "diskontering",
    "diskonterings": "diskontering",
    "diskontinuerliga": "diskontinuerlig",
    "diskontinuerligare": "diskontinuerlig",
    "diskontinuerligares": "diskontinuerlig",
    "diskontinuerligas": "diskontinuerlig",
    "diskontinuerligast": "diskontinuerlig",
    "diskontinuerligaste": "diskontinuerlig",
    "diskontinuerligastes": "diskontinuerlig",
    "diskontinuerligasts": "diskontinuerlig",
    "diskontinuerlige": "diskontinuerlig",
    "diskontinuerliges": "diskontinuerlig",
    "diskontinuerligheten": "diskontinuerlighet",
    "diskontinuerlighetens": "diskontinuerlighet",
    "diskontinuerlighets": "diskontinuerlighet",
    "diskontinuerligs": "diskontinuerlig",
    "diskontinuerligt": "diskontinuerlig",
    "diskontinuerligts": "diskontinuerlig",
    "diskontinuiteten": "diskontinuitet",
    "diskontinuitetens": "diskontinuitet",
    "diskontinuiteter": "diskontinuitet",
    "diskontinuiteterna": "diskontinuitet",
    "diskontinuiteternas": "diskontinuitet",
    "diskontinuiteters": "diskontinuitet",
    "diskontinuitets": "diskontinuitet",
    "diskontnot": "diskontnota",
    "diskontnotan": "diskontnota",
    "diskontnotans": "diskontnota",
    "diskontnotas": "diskontnota",
    "diskontnote": "diskontnota",
    "diskontnotor": "diskontnota",
    "diskontnotorna": "diskontnota",
    "diskontnotornas": "diskontnota",
    "diskontnotors": "diskontnota",
    "diskontnots": "diskontnota",
    "diskonton": "diskonto",
    "diskontona": "diskonto",
    "diskontonas": "diskonto",
    "diskontons": "diskonto",
    "diskontos": "diskonto",
    "diskontot": "diskonto",
    "diskontots": "diskonto",
    "diskontören": "diskontör",
    "diskontörens": "diskontör",
    "diskontörer": "diskontör",
    "diskontörerna": "diskontör",
    "diskontörernas": "diskontör",
    "diskontörers": "diskontör",
    "diskontörs": "diskontör",
    "diskordansen": "diskordans",
    "diskordansens": "diskordans",
    "diskordanser": "diskordans",
    "diskordanserna": "diskordans",
    "diskordansernas": "diskordans",
    "diskordansers": "diskordans",
    "diskordanta": "diskordant",
    "diskordantare": "diskordant",
    "diskordantares": "diskordant",
    "diskordantas": "diskordant",
    "diskordantast": "diskordant",
    "diskordantaste": "diskordant",
    "diskordantastes": "diskordant",
    "diskordantasts": "diskordant",
    "diskordante": "diskordant",
    "diskordantes": "diskordant",
    "diskordants": "diskordant",
    "diskos": "disko",
    "diskot": "disko",
    "diskoteken": "diskotek",
    "diskotekens": "diskotek",
    "diskoteket": "diskotek",
    "diskotekets": "diskotek",
    "diskoteks": "diskotek",
    "diskots": "disko",
    "diskplockar": "diskplockare",
    "diskplockaren": "diskplockare",
    "diskplockarens": "diskplockare",
    "diskplockares": "diskplockare",
    "diskplockarna": "diskplockare",
    "diskplockarnas": "diskplockare",
    "diskrediterad": "diskreditera",
    "diskrediterade": "diskreditera",
    "diskrediterades": "diskreditera",
    "diskrediterads": "diskreditera",
    "diskrediterande": "diskreditera",
    "diskrediteranden": "diskrediterande",
    "diskrediterandena": "diskrediterande",
    "diskrediterandenas": "diskrediterande",
    "diskrediterandens": "diskrediterande",
    "diskrediterandes": "diskrediterande",
    "diskrediterandet": "diskrediterande",
    "diskrediterandets": "diskrediterande",
    "diskrediterar": "diskreditera",
    "diskrediteras": "diskreditera",
    "diskrediterat": "diskreditera",
    "diskrediterats": "diskreditera",
    "diskrediterbara": "diskrediterbar",
    "diskrediterbarare": "diskrediterbar",
    "diskrediterbarares": "diskrediterbar",
    "diskrediterbaras": "diskrediterbar",
    "diskrediterbarast": "diskrediterbar",
    "diskrediterbaraste": "diskrediterbar",
    "diskrediterbarastes": "diskrediterbar",
    "diskrediterbarasts": "diskrediterbar",
    "diskrediterbare": "diskrediterbar",
    "diskrediterbares": "diskrediterbar",
    "diskrediterbarheten": "diskrediterbarhet",
    "diskrediterbarhetens": "diskrediterbarhet",
    "diskrediterbarhets": "diskrediterbarhet",
    "diskrediterbars": "diskrediterbar",
    "diskrediterbart": "diskrediterbar",
    "diskrediterbarts": "diskrediterbar",
    "diskrediteringar": "diskreditering",
    "diskrediteringarna": "diskreditering",
    "diskrediteringarnas": "diskreditering",
    "diskrediteringars": "diskreditering",
    "diskrediteringen": "diskreditering",
    "diskrediteringens": "diskreditering",
    "diskrediterings": "diskreditering",
    "diskrepansen": "diskrepans",
    "diskrepansens": "diskrepans",
    "diskrepanser": "diskrepans",
    "diskrepanserna": "diskrepans",
    "diskrepansernas": "diskrepans",
    "diskrepansers": "diskrepans",
    "diskreta": "diskret",
    "diskretare": "diskret",
    "diskretares": "diskret",
    "diskretas": "diskret",
    "diskretast": "diskret",
    "diskretaste": "diskret",
    "diskretastes": "diskret",
    "diskretasts": "diskret",
    "diskrete": "diskret",
    "diskretes": "diskret",
    "diskretionen": "diskretion",
    "diskretionens": "diskretion",
    "diskretioner": "diskretion",
    "diskretionerna": "diskretion",
    "diskretionernas": "diskretion",
    "diskretioners": "diskretion",
    "diskretions": "diskretion",
    "diskrets": "diskret",
    "diskriminerad": "diskriminera",
    "diskriminerade": "diskriminera",
    "diskriminerades": "diskriminera",
    "diskriminerads": "diskriminera",
    "diskriminerande": "diskriminera",
    "diskrimineranden": "diskriminerande",
    "diskriminerandena": "diskriminerande",
    "diskriminerandenas": "diskriminerande",
    "diskriminerandens": "diskriminerande",
    "diskriminerandes": "diskriminerande",
    "diskriminerandet": "diskriminerande",
    "diskriminerandets": "diskriminerande",
    "diskriminerar": "diskriminera",
    "diskrimineras": "diskriminera",
    "diskriminerat": "diskriminera",
    "diskriminerats": "diskriminera",
    "diskriminerbara": "diskriminerbar",
    "diskriminerbarare": "diskriminerbar",
    "diskriminerbarares": "diskriminerbar",
    "diskriminerbaras": "diskriminerbar",
    "diskriminerbarast": "diskriminerbar",
    "diskriminerbaraste": "diskriminerbar",
    "diskriminerbarastes": "diskriminerbar",
    "diskriminerbarasts": "diskriminerbar",
    "diskriminerbare": "diskriminerbar",
    "diskriminerbares": "diskriminerbar",
    "diskriminerbarheten": "diskriminerbarhet",
    "diskriminerbarhetens": "diskriminerbarhet",
    "diskriminerbarhets": "diskriminerbarhet",
    "diskriminerbars": "diskriminerbar",
    "diskriminerbart": "diskriminerbar",
    "diskriminerbarts": "diskriminerbar",
    "diskrimineringar": "diskriminering",
    "diskrimineringarna": "diskriminering",
    "diskrimineringarnas": "diskriminering",
    "diskrimineringars": "diskriminering",
    "diskrimineringen": "diskriminering",
    "diskrimineringens": "diskriminering",
    "diskriminerings": "diskriminering",
    "diskrimineringsbekämpningen": "diskrimineringsbekämpning",
    "diskrimineringsbekämpningens": "diskrimineringsbekämpning",
    "diskrimineringsbekämpnings": "diskrimineringsbekämpning",
    "diskrimineringslagstiftningar": "diskrimineringslagstiftning",
    "diskrimineringslagstiftningarna": "diskrimineringslagstiftning",
    "diskrimineringslagstiftningarnas": "diskrimineringslagstiftning",
    "diskrimineringslagstiftningars": "diskrimineringslagstiftning",
    "diskrimineringslagstiftningen": "diskrimineringslagstiftning",
    "diskrimineringslagstiftningens": "diskrimineringslagstiftning",
    "diskrimineringslagstiftnings": "diskrimineringslagstiftning",
    "disks": "disk",
    "diskställen": "diskställ",
    "diskställens": "diskställ",
    "diskstället": "diskställ",
    "diskställets": "diskställ",
    "diskställs": "diskställ",
    "disktorkningar": "disktorkning",
    "disktorkningarna": "disktorkning",
    "disktorkningarnas": "disktorkning",
    "disktorkningars": "disktorkning",
    "disktorkningen": "disktorkning",
    "disktorkningens": "disktorkning",
    "disktorknings": "disktorkning",
    "disktras": "disktrasa",
    "disktrasan": "disktrasa",
    "disktrasans": "disktrasa",
    "disktrasas": "disktrasa",
    "disktrase": "disktrasa",
    "disktrasor": "disktrasa",
    "disktrasorna": "disktrasa",
    "disktrasornas": "disktrasa",
    "disktrasors": "disktrasa",
    "diskursen": "diskurs",
    "diskursens": "diskurs",
    "diskurser": "diskurs",
    "diskurserna": "diskurs",
    "diskursernas": "diskurs",
    "diskursers": "diskurs",
    "diskursiva": "diskursiv",
    "diskursivare": "diskursiv",
    "diskursivares": "diskursiv",
    "diskursivas": "diskursiv",
    "diskursivast": "diskursiv",
    "diskursivaste": "diskursiv",
    "diskursivastes": "diskursiv",
    "diskursivasts": "diskursiv",
    "diskursive": "diskursiv",
    "diskursives": "diskursiv",
    "diskursivs": "diskursiv",
    "diskursivt": "diskursiv",
    "diskursivts": "diskursiv",
    "diskusar": "diskus",
    "diskusarna": "diskus",
    "diskusarnas": "diskus",
    "diskusars": "diskus",
    "diskusen": "diskus",
    "diskusens": "diskus",
    "diskuskastningar": "diskuskastning",
    "diskuskastningarna": "diskuskastning",
    "diskuskastningarnas": "diskuskastning",
    "diskuskastningars": "diskuskastning",
    "diskuskastningen": "diskuskastning",
    "diskuskastningens": "diskuskastning",
    "diskuskastnings": "diskuskastning",
    "diskussionen": "diskussion",
    "diskussionens": "diskussion",
    "diskussioner": "diskussion",
    "diskussionerna": "diskussion",
    "diskussionernas": "diskussion",
    "diskussioners": "diskussion",
    "diskussions": "diskussion",
    "diskussionsprotokollen": "diskussionsprotokoll",
    "diskussionsprotokollens": "diskussionsprotokoll",
    "diskussionsprotokollet": "diskussionsprotokoll",
    "diskussionsprotokollets": "diskussionsprotokoll",
    "diskussionsprotokolls": "diskussionsprotokoll",
    "diskutabels": "diskutabel",
    "diskutabelt": "diskutabel",
    "diskutabelts": "diskutabel",
    "diskutabla": "diskutabel",
    "diskutablare": "diskutabel",
    "diskutablares": "diskutabel",
    "diskutablas": "diskutabel",
    "diskutablast": "diskutabel",
    "diskutablaste": "diskutabel",
    "diskutablastes": "diskutabel",
    "diskutablasts": "diskutabel",
    "diskutable": "diskutabel",
    "diskutables": "diskutabel",
    "diskuterad": "diskutera",
    "diskuterade": "diskutera",
    "diskuterades": "diskutera",
    "diskuterads": "diskutera",
    "diskuterande": "diskutera",
    "diskuteranden": "diskuterande",
    "diskuterandena": "diskuterande",
    "diskuterandenas": "diskuterande",
    "diskuterandens": "diskuterande",
    "diskuterandes": "diskuterande",
    "diskuterandet": "diskuterande",
    "diskuterandets": "diskuterande",
    "diskuterar": "diskutera",
    "diskuteras": "diskutera",
    "diskuterat": "diskutera",
    "diskuterats": "diskutera",
    "diskuterbara": "diskuterbar",
    "diskuterbarare": "diskuterbar",
    "diskuterbarares": "diskuterbar",
    "diskuterbaras": "diskuterbar",
    "diskuterbarast": "diskuterbar",
    "diskuterbaraste": "diskuterbar",
    "diskuterbarastes": "diskuterbar",
    "diskuterbarasts": "diskuterbar",
    "diskuterbare": "diskuterbar",
    "diskuterbares": "diskuterbar",
    "diskuterbarheten": "diskuterbarhet",
    "diskuterbarhetens": "diskuterbarhet",
    "diskuterbarhets": "diskuterbarhet",
    "diskuterbars": "diskuterbar",
    "diskuterbart": "diskuterbar",
    "diskuterbarts": "diskuterbar",
    "diskuteringar": "diskutering",
    "diskuteringarna": "diskutering",
    "diskuteringarnas": "diskutering",
    "diskuteringars": "diskutering",
    "diskuteringen": "diskutering",
    "diskuteringens": "diskutering",
    "diskuterings": "diskutering",
    "diskvalificerad": "diskvalificera",
    "diskvalificerade": "diskvalificera",
    "diskvalificerades": "diskvalificera",
    "diskvalificerads": "diskvalificera",
    "diskvalificerande": "diskvalificera",
    "diskvalificeranden": "diskvalificerande",
    "diskvalificerandena": "diskvalificerande",
    "diskvalificerandenas": "diskvalificerande",
    "diskvalificerandens": "diskvalificerande",
    "diskvalificerandes": "diskvalificerande",
    "diskvalificerandet": "diskvalificerande",
    "diskvalificerandets": "diskvalificerande",
    "diskvalificerar": "diskvalificera",
    "diskvalificeras": "diskvalificera",
    "diskvalificerat": "diskvalificera",
    "diskvalificerats": "diskvalificera",
    "diskvalificerbara": "diskvalificerbar",
    "diskvalificerbarare": "diskvalificerbar",
    "diskvalificerbarares": "diskvalificerbar",
    "diskvalificerbaras": "diskvalificerbar",
    "diskvalificerbarast": "diskvalificerbar",
    "diskvalificerbaraste": "diskvalificerbar",
    "diskvalificerbarastes": "diskvalificerbar",
    "diskvalificerbarasts": "diskvalificerbar",
    "diskvalificerbare": "diskvalificerbar",
    "diskvalificerbares": "diskvalificerbar",
    "diskvalificerbarheten": "diskvalificerbarhet",
    "diskvalificerbarhetens": "diskvalificerbarhet",
    "diskvalificerbarhets": "diskvalificerbarhet",
    "diskvalificerbars": "diskvalificerbar",
    "diskvalificerbart": "diskvalificerbar",
    "diskvalificerbarts": "diskvalificerbar",
    "diskvalificeringar": "diskvalificering",
    "diskvalificeringarna": "diskvalificering",
    "diskvalificeringarnas": "diskvalificering",
    "diskvalificeringars": "diskvalificering",
    "diskvalificeringen": "diskvalificering",
    "diskvalificeringens": "diskvalificering",
    "diskvalificerings": "diskvalificering",
    "diskvalifikationen": "diskvalifikation",
    "diskvalifikationens": "diskvalifikation",
    "diskvalifikationer": "diskvalifikation",
    "diskvalifikationerna": "diskvalifikation",
    "diskvalifikationernas": "diskvalifikation",
    "diskvalifikationers": "diskvalifikation",
    "diskvalifikations": "diskvalifikation",
    "dislokationen": "dislokation",
    "dislokationens": "dislokation",
    "dislokationer": "dislokation",
    "dislokationerna": "dislokation",
    "dislokationernas": "dislokation",
    "dislokationers": "dislokation",
    "dislokations": "dislokation",
    "disparata": "disparat",
    "disparatare": "disparat",
    "disparatares": "disparat",
    "disparatas": "disparat",
    "disparatast": "disparat",
    "disparataste": "disparat",
    "disparatastes": "disparat",
    "disparatasts": "disparat",
    "disparate": "disparat",
    "disparates": "disparat",
    "disparats": "disparat",
    "dispaschen": "dispasch",
    "dispaschens": "dispasch",
    "dispascher": "dispasch",
    "dispascherad": "dispaschera",
    "dispascherade": "dispaschera",
    "dispascherades": "dispaschera",
    "dispascherads": "dispaschera",
    "dispascherande": "dispaschera",
    "dispascheranden": "dispascherande",
    "dispascherandena": "dispascherande",
    "dispascherandenas": "dispascherande",
    "dispascherandens": "dispascherande",
    "dispascherandes": "dispascherande",
    "dispascherandet": "dispascherande",
    "dispascherandets": "dispascherande",
    "dispascherar": "dispaschera",
    "dispascheras": "dispaschera",
    "dispascherat": "dispaschera",
    "dispascherats": "dispaschera",
    "dispascherbara": "dispascherbar",
    "dispascherbarare": "dispascherbar",
    "dispascherbarares": "dispascherbar",
    "dispascherbaras": "dispascherbar",
    "dispascherbarast": "dispascherbar",
    "dispascherbaraste": "dispascherbar",
    "dispascherbarastes": "dispascherbar",
    "dispascherbarasts": "dispascherbar",
    "dispascherbare": "dispascherbar",
    "dispascherbares": "dispascherbar",
    "dispascherbarheten": "dispascherbarhet",
    "dispascherbarhetens": "dispascherbarhet",
    "dispascherbarhets": "dispascherbarhet",
    "dispascherbars": "dispascherbar",
    "dispascherbart": "dispascherbar",
    "dispascherbarts": "dispascherbar",
    "dispascheringar": "dispaschering",
    "dispascheringarna": "dispaschering",
    "dispascheringarnas": "dispaschering",
    "dispascheringars": "dispaschering",
    "dispascheringen": "dispaschering",
    "dispascheringens": "dispaschering",
    "dispascherings": "dispaschering",
    "dispascherna": "dispasch",
    "dispaschernas": "dispasch",
    "dispaschers": "dispasch",
    "dispaschs": "dispasch",
    "dispaschören": "dispaschör",
    "dispaschörens": "dispaschör",
    "dispaschörer": "dispaschör",
    "dispaschörerna": "dispaschör",
    "dispaschörernas": "dispaschör",
    "dispaschörers": "dispaschör",
    "dispaschörn": "dispaschör",
    "dispaschörns": "dispaschör",
    "dispaschörs": "dispaschör",
    "dispensen": "dispens",
    "dispensens": "dispens",
    "dispenser": "dispens",
    "dispenserad": "dispensera",
    "dispenserade": "dispensera",
    "dispenserades": "dispensera",
    "dispenserads": "dispensera",
    "dispenserande": "dispensera",
    "dispenseranden": "dispenserande",
    "dispenserandena": "dispenserande",
    "dispenserandenas": "dispenserande",
    "dispenserandens": "dispenserande",
    "dispenserandes": "dispenserande",
    "dispenserandet": "dispenserande",
    "dispenserandets": "dispenserande",
    "dispenserar": "dispensera",
    "dispenseras": "dispensera",
    "dispenserat": "dispensera",
    "dispenserats": "dispensera",
    "dispenserbara": "dispenserbar",
    "dispenserbarare": "dispenserbar",
    "dispenserbarares": "dispenserbar",
    "dispenserbaras": "dispenserbar",
    "dispenserbarast": "dispenserbar",
    "dispenserbaraste": "dispenserbar",
    "dispenserbarastes": "dispenserbar",
    "dispenserbarasts": "dispenserbar",
    "dispenserbare": "dispenserbar",
    "dispenserbares": "dispenserbar",
    "dispenserbarheten": "dispenserbarhet",
    "dispenserbarhetens": "dispenserbarhet",
    "dispenserbarhets": "dispenserbarhet",
    "dispenserbars": "dispenserbar",
    "dispenserbart": "dispenserbar",
    "dispenserbarts": "dispenserbar",
    "dispenseringar": "dispensering",
    "dispenseringarna": "dispensering",
    "dispenseringarnas": "dispensering",
    "dispenseringars": "dispensering",
    "dispenseringen": "dispensering",
    "dispenseringens": "dispensering",
    "dispenserings": "dispensering",
    "dispenserna": "dispens",
    "dispensernas": "dispens",
    "dispensers": "dispens",
    "dispensären": "dispensär",
    "dispensärens": "dispensär",
    "dispensärer": "dispensär",
    "dispensärerna": "dispensär",
    "dispensärernas": "dispensär",
    "dispensärers": "dispensär",
    "dispensärs": "dispensär",
    "dispergerad": "dispergera",
    "dispergerade": "dispergera",
    "dispergerades": "dispergera",
    "dispergerads": "dispergera",
    "dispergerande": "dispergera",
    "dispergeranden": "dispergerande",
    "dispergerandena": "dispergerande",
    "dispergerandenas": "dispergerande",
    "dispergerandens": "dispergerande",
    "dispergerandes": "dispergerande",
    "dispergerandet": "dispergerande",
    "dispergerandets": "dispergerande",
    "dispergerar": "dispergera",
    "dispergeras": "dispergera",
    "dispergerat": "dispergera",
    "dispergerats": "dispergera",
    "dispergerbara": "dispergerbar",
    "dispergerbarare": "dispergerbar",
    "dispergerbarares": "dispergerbar",
    "dispergerbaras": "dispergerbar",
    "dispergerbarast": "dispergerbar",
    "dispergerbaraste": "dispergerbar",
    "dispergerbarastes": "dispergerbar",
    "dispergerbarasts": "dispergerbar",
    "dispergerbare": "dispergerbar",
    "dispergerbares": "dispergerbar",
    "dispergerbarheten": "dispergerbarhet",
    "dispergerbarhetens": "dispergerbarhet",
    "dispergerbarhets": "dispergerbarhet",
    "dispergerbars": "dispergerbar",
    "dispergerbart": "dispergerbar",
    "dispergerbarts": "dispergerbar",
    "dispergeringar": "dispergering",
    "dispergeringarna": "dispergering",
    "dispergeringarnas": "dispergering",
    "dispergeringars": "dispergering",
    "dispergeringen": "dispergering",
    "dispergeringens": "dispergering",
    "dispergerings": "dispergering",
    "dispersa": "dispers",
    "dispersare": "dispers",
    "dispersares": "dispers",
    "dispersas": "dispers",
    "dispersast": "dispers",
    "dispersaste": "dispers",
    "dispersastes": "dispers",
    "dispersasts": "dispers",
    "disperse": "dispers",
    "disperses": "dispers",
    "dispersionen": "dispersion",
    "dispersionens": "dispersion",
    "dispersioner": "dispersion",
    "dispersionerna": "dispersion",
    "dispersionernas": "dispersion",
    "dispersioners": "dispersion",
    "dispersions": "dispersion",
    "disperst": "dispers",
    "dispersts": "dispers",
    "displayen": "display",
    "displayens": "display",
    "displayer": "display",
    "displayerna": "display",
    "displayernas": "display",
    "displayers": "display",
    "displays": "display",
    "disponenten": "disponent",
    "disponentens": "disponent",
    "disponenter": "disponent",
    "disponenterna": "disponent",
    "disponenternas": "disponent",
    "disponenters": "disponent",
    "disponents": "disponent",
    "disponerad": "disponera",
    "disponerade": "disponerad",
    "disponerades": "disponerad",
    "disponerads": "disponerad",
    "disponerande": "disponera",
    "disponeranden": "disponerande",
    "disponerandena": "disponerande",
    "disponerandenas": "disponerande",
    "disponerandens": "disponerande",
    "disponerandes": "disponerande",
    "disponerandet": "disponerande",
    "disponerandets": "disponerande",
    "disponerar": "disponera",
    "disponeras": "disponera",
    "disponerat": "disponerad",
    "disponerats": "disponerad",
    "disponerbara": "disponerbar",
    "disponerbarare": "disponerbar",
    "disponerbarares": "disponerbar",
    "disponerbaras": "disponerbar",
    "disponerbarast": "disponerbar",
    "disponerbaraste": "disponerbar",
    "disponerbarastes": "disponerbar",
    "disponerbarasts": "disponerbar",
    "disponerbare": "disponerbar",
    "disponerbares": "disponerbar",
    "disponerbarheten": "disponerbarhet",
    "disponerbarhetens": "disponerbarhet",
    "disponerbarhets": "disponerbarhet",
    "disponerbars": "disponerbar",
    "disponerbart": "disponerbar",
    "disponerbarts": "disponerbar",
    "disponeringar": "disponering",
    "disponeringarna": "disponering",
    "disponeringarnas": "disponering",
    "disponeringars": "disponering",
    "disponeringen": "disponering",
    "disponeringens": "disponering",
    "disponerings": "disponering",
    "disponibels": "disponibel",
    "disponibelt": "disponibel",
    "disponibelts": "disponibel",
    "disponibiliteten": "disponibilitet",
    "disponibilitetens": "disponibilitet",
    "disponibiliteter": "disponibilitet",
    "disponibiliteterna": "disponibilitet",
    "disponibiliteternas": "disponibilitet",
    "disponibiliteters": "disponibilitet",
    "disponibilitets": "disponibilitet",
    "disponibla": "disponibel",
    "disponiblare": "disponibel",
    "disponiblares": "disponibel",
    "disponiblas": "disponibel",
    "disponiblast": "disponibel",
    "disponiblaste": "disponibel",
    "disponiblastes": "disponibel",
    "disponiblasts": "disponibel",
    "disponible": "disponibel",
    "disponibles": "disponibel",
    "dispositionen": "disposition",
    "dispositionens": "disposition",
    "dispositioner": "disposition",
    "dispositionerna": "disposition",
    "dispositionernas": "disposition",
    "dispositioners": "disposition",
    "dispositions": "disposition",
    "dispositionsfonden": "dispositionsfond",
    "dispositionsfondens": "dispositionsfond",
    "dispositionsfonder": "dispositionsfond",
    "dispositionsfonderna": "dispositionsfond",
    "dispositionsfondernas": "dispositionsfond",
    "dispositionsfonders": "dispositionsfond",
    "dispositionsfonds": "dispositionsfond",
    "dispositiva": "dispositiv",
    "dispositivare": "dispositiv",
    "dispositivares": "dispositiv",
    "dispositivas": "dispositiv",
    "dispositivast": "dispositiv",
    "dispositivaste": "dispositiv",
    "dispositivastes": "dispositiv",
    "dispositivasts": "dispositiv",
    "dispositive": "dispositiv",
    "dispositives": "dispositiv",
    "dispositivs": "dispositiv",
    "dispositivt": "dispositiv",
    "dispositivts": "dispositiv",
    "disproportionen": "disproportion",
    "disproportionens": "disproportion",
    "disproportioner": "disproportion",
    "disproportionerliga": "disproportionerlig",
    "disproportionerligare": "disproportionerlig",
    "disproportionerligares": "disproportionerlig",
    "disproportionerligas": "disproportionerlig",
    "disproportionerligast": "disproportionerlig",
    "disproportionerligaste": "disproportionerlig",
    "disproportionerligastes": "disproportionerlig",
    "disproportionerligasts": "disproportionerlig",
    "disproportionerlige": "disproportionerlig",
    "disproportionerliges": "disproportionerlig",
    "disproportionerligheten": "disproportionerlighet",
    "disproportionerlighetens": "disproportionerlighet",
    "disproportionerlighets": "disproportionerlighet",
    "disproportionerligs": "disproportionerlig",
    "disproportionerligt": "disproportionerlig",
    "disproportionerligts": "disproportionerlig",
    "disproportionerna": "disproportion",
    "disproportionernas": "disproportion",
    "disproportioners": "disproportion",
    "disproportions": "disproportion",
    "disputationen": "disputation",
    "disputationens": "disputation",
    "disputationer": "disputation",
    "disputationerna": "disputation",
    "disputationernas": "disputation",
    "disputationers": "disputation",
    "disputations": "disputation",
    "disputerad": "disputera",
    "disputerade": "disputera",
    "disputerades": "disputera",
    "disputerads": "disputera",
    "disputerande": "disputera",
    "disputeranden": "disputerande",
    "disputerandena": "disputerande",
    "disputerandenas": "disputerande",
    "disputerandens": "disputerande",
    "disputerandes": "disputerande",
    "disputerandet": "disputerande",
    "disputerandets": "disputerande",
    "disputerar": "disputera",
    "disputeras": "disputera",
    "disputerat": "disputera",
    "disputerats": "disputera",
    "disputerbara": "disputerbar",
    "disputerbarare": "disputerbar",
    "disputerbarares": "disputerbar",
    "disputerbaras": "disputerbar",
    "disputerbarast": "disputerbar",
    "disputerbaraste": "disputerbar",
    "disputerbarastes": "disputerbar",
    "disputerbarasts": "disputerbar",
    "disputerbare": "disputerbar",
    "disputerbares": "disputerbar",
    "disputerbarheten": "disputerbarhet",
    "disputerbarhetens": "disputerbarhet",
    "disputerbarhets": "disputerbarhet",
    "disputerbars": "disputerbar",
    "disputerbart": "disputerbar",
    "disputerbarts": "disputerbar",
    "disputeringar": "disputering",
    "disputeringarna": "disputering",
    "disputeringarnas": "disputering",
    "disputeringars": "disputering",
    "disputeringen": "disputering",
    "disputeringens": "disputering",
    "disputerings": "disputering",
    "dispyten": "dispyt",
    "dispytens": "dispyt",
    "dispyter": "dispyt",
    "dispyterna": "dispyt",
    "dispyternas": "dispyt",
    "dispyters": "dispyt",
    "dispyts": "dispyt",
    "diss": "dissa",
    "dissad": "dissa",
    "dissade": "dissa",
    "dissades": "dissa",
    "dissads": "dissa",
    "dissande": "dissa",
    "dissanden": "dissande",
    "dissandena": "dissande",
    "dissandenas": "dissande",
    "dissandens": "dissande",
    "dissandes": "dissande",
    "dissandet": "dissande",
    "dissandets": "dissande",
    "dissar": "dissa",
    "dissas": "dissa",
    "dissat": "dissa",
    "dissats": "dissa",
    "dissekerad": "dissekera",
    "dissekerade": "dissekera",
    "dissekerades": "dissekera",
    "dissekerads": "dissekera",
    "dissekerande": "dissekera",
    "dissekeranden": "dissekerande",
    "dissekerandena": "dissekerande",
    "dissekerandenas": "dissekerande",
    "dissekerandens": "dissekerande",
    "dissekerandes": "dissekerande",
    "dissekerandet": "dissekerande",
    "dissekerandets": "dissekerande",
    "dissekerar": "dissekera",
    "dissekeras": "dissekera",
    "dissekerat": "dissekera",
    "dissekerats": "dissekera",
    "dissekerbara": "dissekerbar",
    "dissekerbarare": "dissekerbar",
    "dissekerbarares": "dissekerbar",
    "dissekerbaras": "dissekerbar",
    "dissekerbarast": "dissekerbar",
    "dissekerbaraste": "dissekerbar",
    "dissekerbarastes": "dissekerbar",
    "dissekerbarasts": "dissekerbar",
    "dissekerbare": "dissekerbar",
    "dissekerbares": "dissekerbar",
    "dissekerbarheten": "dissekerbarhet",
    "dissekerbarhetens": "dissekerbarhet",
    "dissekerbarhets": "dissekerbarhet",
    "dissekerbars": "dissekerbar",
    "dissekerbart": "dissekerbar",
    "dissekerbarts": "dissekerbar",
    "dissekeringar": "dissekering",
    "dissekeringarna": "dissekering",
    "dissekeringarnas": "dissekering",
    "dissekeringars": "dissekering",
    "dissekeringen": "dissekering",
    "dissekeringens": "dissekering",
    "dissekerings": "dissekering",
    "dissektionen": "dissektion",
    "dissektionens": "dissektion",
    "dissektioner": "dissektion",
    "dissektionerna": "dissektion",
    "dissektionernas": "dissektion",
    "dissektioners": "dissektion",
    "dissektions": "dissektion",
    "dissentern": "dissenter",
    "dissenterna": "dissenter",
    "dissenternas": "dissenter",
    "dissenterns": "dissenter",
    "dissenters": "dissenter",
    "dissentersarna": "dissenter",
    "dissentersarnas": "dissenter",
    "dissentersen": "dissenter",
    "dissentersens": "dissenter",
    "dissertationen": "dissertation",
    "dissertationens": "dissertation",
    "dissertationer": "dissertation",
    "dissertationerna": "dissertation",
    "dissertationernas": "dissertation",
    "dissertationers": "dissertation",
    "dissertations": "dissertation",
    "dissidenten": "dissident",
    "dissidentens": "dissident",
    "dissidenter": "dissident",
    "dissidenterna": "dissident",
    "dissidenternas": "dissident",
    "dissidenters": "dissident",
    "dissidents": "dissident",
    "dissimilationen": "dissimilation",
    "dissimilationens": "dissimilation",
    "dissimilationer": "dissimilation",
    "dissimilationerna": "dissimilation",
    "dissimilationernas": "dissimilation",
    "dissimilationers": "dissimilation",
    "dissimilations": "dissimilation",
    "dissimilerad": "dissimilera",
    "dissimilerade": "dissimilera",
    "dissimilerades": "dissimilera",
    "dissimilerads": "dissimilera",
    "dissimilerande": "dissimilera",
    "dissimileranden": "dissimilerande",
    "dissimilerandena": "dissimilerande",
    "dissimilerandenas": "dissimilerande",
    "dissimilerandens": "dissimilerande",
    "dissimilerandes": "dissimilerande",
    "dissimilerandet": "dissimilerande",
    "dissimilerandets": "dissimilerande",
    "dissimilerar": "dissimilera",
    "dissimileras": "dissimilera",
    "dissimilerat": "dissimilera",
    "dissimilerats": "dissimilera",
    "dissimilerbara": "dissimilerbar",
    "dissimilerbarare": "dissimilerbar",
    "dissimilerbarares": "dissimilerbar",
    "dissimilerbaras": "dissimilerbar",
    "dissimilerbarast": "dissimilerbar",
    "dissimilerbaraste": "dissimilerbar",
    "dissimilerbarastes": "dissimilerbar",
    "dissimilerbarasts": "dissimilerbar",
    "dissimilerbare": "dissimilerbar",
    "dissimilerbares": "dissimilerbar",
    "dissimilerbarheten": "dissimilerbarhet",
    "dissimilerbarhetens": "dissimilerbarhet",
    "dissimilerbarhets": "dissimilerbarhet",
    "dissimilerbars": "dissimilerbar",
    "dissimilerbart": "dissimilerbar",
    "dissimilerbarts": "dissimilerbar",
    "dissimileringen": "dissimilering",
    "dissimileringens": "dissimilering",
    "dissimilerings": "dissimilering",
    "dissociationen": "dissociation",
    "dissociationens": "dissociation",
    "dissociationer": "dissociation",
    "dissociationerna": "dissociation",
    "dissociationernas": "dissociation",
    "dissociationers": "dissociation",
    "dissociations": "dissociation",
    "dissocierad": "dissociera",
    "dissocierade": "dissociera",
    "dissocierades": "dissociera",
    "dissocierads": "dissociera",
    "dissocierande": "dissociera",
    "dissocieranden": "dissocierande",
    "dissocierandena": "dissocierande",
    "dissocierandenas": "dissocierande",
    "dissocierandens": "dissocierande",
    "dissocierandes": "dissocierande",
    "dissocierandet": "dissocierande",
    "dissocierandets": "dissocierande",
    "dissocierar": "dissociera",
    "dissocieras": "dissociera",
    "dissocierat": "dissociera",
    "dissocierats": "dissociera",
    "dissocierbara": "dissocierbar",
    "dissocierbarare": "dissocierbar",
    "dissocierbarares": "dissocierbar",
    "dissocierbaras": "dissocierbar",
    "dissocierbarast": "dissocierbar",
    "dissocierbaraste": "dissocierbar",
    "dissocierbarastes": "dissocierbar",
    "dissocierbarasts": "dissocierbar",
    "dissocierbare": "dissocierbar",
    "dissocierbares": "dissocierbar",
    "dissocierbarheten": "dissocierbarhet",
    "dissocierbarhetens": "dissocierbarhet",
    "dissocierbarhets": "dissocierbarhet",
    "dissocierbars": "dissocierbar",
    "dissocierbart": "dissocierbar",
    "dissocierbarts": "dissocierbar",
    "dissocieringar": "dissociering",
    "dissocieringarna": "dissociering",
    "dissocieringarnas": "dissociering",
    "dissocieringars": "dissociering",
    "dissocieringen": "dissociering",
    "dissocieringens": "dissociering",
    "dissocierings": "dissociering",
    "dissonansen": "dissonans",
    "dissonansens": "dissonans",
    "dissonanser": "dissonans",
    "dissonanserna": "dissonans",
    "dissonansernas": "dissonans",
    "dissonansers": "dissonans",
    "dissonanta": "dissonant",
    "dissonantare": "dissonant",
    "dissonantares": "dissonant",
    "dissonantas": "dissonant",
    "dissonantast": "dissonant",
    "dissonantaste": "dissonant",
    "dissonantastes": "dissonant",
    "dissonantasts": "dissonant",
    "dissonante": "dissonant",
    "dissonanten": "dissonant",
    "dissonantens": "dissonant",
    "dissonanter": "dissonant",
    "dissonanterna": "dissonant",
    "dissonanternas": "dissonant",
    "dissonanters": "dissonant",
    "dissonantes": "dissonant",
    "dissonants": "dissonant",
    "dissonerade": "dissonera",
    "dissonerades": "dissonera",
    "dissonerande": "dissonera",
    "dissoneranden": "dissonerande",
    "dissonerandena": "dissonerande",
    "dissonerandenas": "dissonerande",
    "dissonerandens": "dissonerande",
    "dissonerandes": "dissonerande",
    "dissonerandet": "dissonerande",
    "dissonerandets": "dissonerande",
    "dissonerar": "dissonera",
    "dissoneras": "dissonera",
    "dissonerat": "dissonera",
    "dissonerats": "dissonera",
    "dissoneringar": "dissonering",
    "dissoneringarna": "dissonering",
    "dissoneringarnas": "dissonering",
    "dissoneringars": "dissonering",
    "dissoneringen": "dissonering",
    "dissoneringens": "dissonering",
    "dissonerings": "dissonering",
    "distansbygeln": "distansbygel",
    "distansbygelns": "distansbygel",
    "distansbygels": "distansbygel",
    "distansbyglar": "distansbygel",
    "distansbyglarna": "distansbygel",
    "distansbyglarnas": "distansbygel",
    "distansbyglars": "distansbygel",
    "distansen": "distans",
    "distansens": "distans",
    "distanser": "distans",
    "distanserad": "distansera",
    "distanserade": "distansera",
    "distanserades": "distansera",
    "distanserads": "distansera",
    "distanserande": "distansera",
    "distanseranden": "distanserande",
    "distanserandena": "distanserande",
    "distanserandenas": "distanserande",
    "distanserandens": "distanserande",
    "distanserandes": "distanserande",
    "distanserandet": "distanserande",
    "distanserandets": "distanserande",
    "distanserar": "distansera",
    "distanseras": "distansera",
    "distanserat": "distansera",
    "distanserats": "distansera",
    "distanserbara": "distanserbar",
    "distanserbarare": "distanserbar",
    "distanserbarares": "distanserbar",
    "distanserbaras": "distanserbar",
    "distanserbarast": "distanserbar",
    "distanserbaraste": "distanserbar",
    "distanserbarastes": "distanserbar",
    "distanserbarasts": "distanserbar",
    "distanserbare": "distanserbar",
    "distanserbares": "distanserbar",
    "distanserbarheten": "distanserbarhet",
    "distanserbarhetens": "distanserbarhet",
    "distanserbarhets": "distanserbarhet",
    "distanserbars": "distanserbar",
    "distanserbart": "distanserbar",
    "distanserbarts": "distanserbar",
    "distanseringar": "distansering",
    "distanseringarna": "distansering",
    "distanseringarnas": "distansering",
    "distanseringars": "distansering",
    "distanseringen": "distansering",
    "distanseringens": "distansering",
    "distanserings": "distansering",
    "distanserna": "distans",
    "distansernas": "distans",
    "distansers": "distans",
    "distansflygningar": "distansflygning",
    "distansflygningarna": "distansflygning",
    "distansflygningarnas": "distansflygning",
    "distansflygningars": "distansflygning",
    "distansflygningen": "distansflygning",
    "distansflygningens": "distansflygning",
    "distansflygnings": "distansflygning",
    "distanshögskolan": "distanshögskola",
    "distanshögskolans": "distanshögskola",
    "distanshögskolas": "distanshögskola",
    "distanshögskole": "distanshögskola",
    "distanshögskolor": "distanshögskola",
    "distanshögskolorna": "distanshögskola",
    "distanshögskolornas": "distanshögskola",
    "distanshögskolors": "distanshögskola",
    "distansminuten": "distansminut",
    "distansminutens": "distansminut",
    "distansminuter": "distansminut",
    "distansminuterna": "distansminut",
    "distansminuternas": "distansminut",
    "distansminuters": "distansminut",
    "distansminutrar": "distansminut",
    "distansminutrarna": "distansminut",
    "distansminutrarnas": "distansminut",
    "distansminutrars": "distansminut",
    "distansminuts": "distansminut",
    "distansundervisningar": "distansundervisning",
    "distansundervisningarna": "distansundervisning",
    "distansundervisningarnas": "distansundervisning",
    "distansundervisningars": "distansundervisning",
    "distansundervisningen": "distansundervisning",
    "distansundervisningens": "distansundervisning",
    "distansundervisnings": "distansundervisning",
    "distika": "distikon",
    "distikas": "distikon",
    "distikonen": "distikon",
    "distikonens": "distikon",
    "distikonet": "distikon",
    "distikonets": "distikon",
    "distikons": "distikon",
    "distingerade": "distingerad",
    "distingerades": "distingerad",
    "distingerads": "distingerad",
    "distingerat": "distingerad",
    "distingerats": "distingerad",
    "distinkta": "distinkt",
    "distinktare": "distinkt",
    "distinktares": "distinkt",
    "distinktas": "distinkt",
    "distinktast": "distinkt",
    "distinktaste": "distinkt",
    "distinktastes": "distinkt",
    "distinktasts": "distinkt",
    "distinkte": "distinkt",
    "distinktes": "distinkt",
    "distinktionen": "distinktion",
    "distinktionens": "distinktion",
    "distinktioner": "distinktion",
    "distinktionerna": "distinktion",
    "distinktionernas": "distinktion",
    "distinktioners": "distinktion",
    "distinktions": "distinktion",
    "distinkts": "distinkt",
    "distorsionen": "distorsion",
    "distorsionens": "distorsion",
    "distorsioner": "distorsion",
    "distorsionerna": "distorsion",
    "distorsionernas": "distorsion",
    "distorsioners": "distorsion",
    "distorsions": "distorsion",
    "distraherad": "distrahera",
    "distraherade": "distraherad",
    "distraherades": "distraherad",
    "distraherads": "distraherad",
    "distraherande": "distrahera",
    "distraheranden": "distraherande",
    "distraherandena": "distraherande",
    "distraherandenas": "distraherande",
    "distraherandens": "distraherande",
    "distraherandes": "distraherande",
    "distraherandet": "distraherande",
    "distraherandets": "distraherande",
    "distraherar": "distrahera",
    "distraheras": "distrahera",
    "distraherat": "distraherad",
    "distraherats": "distraherad",
    "distraherbara": "distraherbar",
    "distraherbarare": "distraherbar",
    "distraherbarares": "distraherbar",
    "distraherbaras": "distraherbar",
    "distraherbarast": "distraherbar",
    "distraherbaraste": "distraherbar",
    "distraherbarastes": "distraherbar",
    "distraherbarasts": "distraherbar",
    "distraherbare": "distraherbar",
    "distraherbares": "distraherbar",
    "distraherbarheten": "distraherbarhet",
    "distraherbarhetens": "distraherbarhet",
    "distraherbarhets": "distraherbarhet",
    "distraherbars": "distraherbar",
    "distraherbart": "distraherbar",
    "distraherbarts": "distraherbar",
    "distraheringar": "distrahering",
    "distraheringarna": "distrahering",
    "distraheringarnas": "distrahering",
    "distraheringars": "distrahering",
    "distraheringen": "distrahering",
    "distraheringens": "distrahering",
    "distraherings": "distrahering",
    "distraktionen": "distraktion",
    "distraktionens": "distraktion",
    "distraktioner": "distraktion",
    "distraktionerna": "distraktion",
    "distraktionernas": "distraktion",
    "distraktioners": "distraktion",
    "distraktions": "distraktion",
    "distraktorer": "distraktor",
    "distraktorerna": "distraktor",
    "distraktorernas": "distraktor",
    "distraktorers": "distraktor",
    "distraktorn": "distraktor",
    "distraktorns": "distraktor",
    "distraktors": "distraktor",
    "distribuenten": "distribuent",
    "distribuentens": "distribuent",
    "distribuenter": "distribuent",
    "distribuenterna": "distribuent",
    "distribuenternas": "distribuent",
    "distribuenters": "distribuent",
    "distribuents": "distribuent",
    "distribuerad": "distribuera",
    "distribuerade": "distribuera",
    "distribuerades": "distribuera",
    "distribuerads": "distribuera",
    "distribuerande": "distribuera",
    "distribueranden": "distribuerande",
    "distribuerandena": "distribuerande",
    "distribuerandenas": "distribuerande",
    "distribuerandens": "distribuerande",
    "distribuerandes": "distribuerande",
    "distribuerandet": "distribuerande",
    "distribuerandets": "distribuerande",
    "distribuerar": "distribuera",
    "distribueras": "distribuera",
    "distribuerat": "distribuera",
    "distribuerats": "distribuera",
    "distribuerbara": "distribuerbar",
    "distribuerbarare": "distribuerbar",
    "distribuerbarares": "distribuerbar",
    "distribuerbaras": "distribuerbar",
    "distribuerbarast": "distribuerbar",
    "distribuerbaraste": "distribuerbar",
    "distribuerbarastes": "distribuerbar",
    "distribuerbarasts": "distribuerbar",
    "distribuerbare": "distribuerbar",
    "distribuerbares": "distribuerbar",
    "distribuerbarheten": "distribuerbarhet",
    "distribuerbarhetens": "distribuerbarhet",
    "distribuerbarhets": "distribuerbarhet",
    "distribuerbars": "distribuerbar",
    "distribuerbart": "distribuerbar",
    "distribuerbarts": "distribuerbar",
    "distribueringar": "distribuering",
    "distribueringarna": "distribuering",
    "distribueringarnas": "distribuering",
    "distribueringars": "distribuering",
    "distribueringen": "distribuering",
    "distribueringens": "distribuering",
    "distribuerings": "distribuering",
    "distribunalen": "distribunal",
    "distribunalens": "distribunal",
    "distribunaler": "distribunal",
    "distribunalerna": "distribunal",
    "distribunalernas": "distribunal",
    "distribunalers": "distribunal",
    "distribunals": "distribunal",
    "distributionen": "distribution",
    "distributionens": "distribution",
    "distributioner": "distribution",
    "distributionerna": "distribution",
    "distributionernas": "distribution",
    "distributioners": "distribution",
    "distributions": "distribution",
    "distributionscentralen": "distributionscentral",
    "distributionscentralens": "distributionscentral",
    "distributionscentraler": "distributionscentral",
    "distributionscentralerna": "distributionscentral",
    "distributionscentralernas": "distributionscentral",
    "distributionscentralers": "distributionscentral",
    "distributionscentrals": "distributionscentral",
    "distributionsföretagen": "distributionsföretag",
    "distributionsföretagens": "distributionsföretag",
    "distributionsföretaget": "distributionsföretag",
    "distributionsföretagets": "distributionsföretag",
    "distributionsföretags": "distributionsföretag",
    "distributiva": "distributiv",
    "distributivare": "distributiv",
    "distributivares": "distributiv",
    "distributivas": "distributiv",
    "distributivast": "distributiv",
    "distributivaste": "distributiv",
    "distributivastes": "distributiv",
    "distributivasts": "distributiv",
    "distributive": "distributiv",
    "distributives": "distributiv",
    "distributivs": "distributiv",
    "distributivt": "distributiv",
    "distributivts": "distributiv",
    "distributören": "distributör",
    "distributörens": "distributör",
    "distributörer": "distributör",
    "distributörerna": "distributör",
    "distributörernas": "distributör",
    "distributörers": "distributör",
    "distributörs": "distributör",
    "distrikten": "distrikt",
    "distriktens": "distrikt",
    "distriktet": "distrikt",
    "distriktets": "distrikt",
    "distrikts": "distrikt",
    "distriktsläkar": "distriktsläkare",
    "distriktsläkaren": "distriktsläkare",
    "distriktsläkarens": "distriktsläkare",
    "distriktsläkares": "distriktsläkare",
    "distriktsläkarna": "distriktsläkare",
    "distriktsläkarnas": "distriktsläkare",
    "distriktsmästar": "distriktsmästare",
    "distriktsmästaren": "distriktsmästare",
    "distriktsmästarens": "distriktsmästare",
    "distriktsmästares": "distriktsmästare",
    "distriktsmästarna": "distriktsmästare",
    "distriktsmästarnas": "distriktsmästare",
    "distriktsmästerskapen": "distriktsmästerskap",
    "distriktsmästerskapens": "distriktsmästerskap",
    "distriktsmästerskapet": "distriktsmästerskap",
    "distriktsmästerskapets": "distriktsmästerskap",
    "distriktsmästerskaps": "distriktsmästerskap",
    "distriktsordföranden": "distriktsordförande",
    "distriktsordförandena": "distriktsordförande",
    "distriktsordförandenas": "distriktsordförande",
    "distriktsordförandens": "distriktsordförande",
    "distriktsordförandes": "distriktsordförande",
    "disträa": "disträ",
    "disträare": "disträ",
    "disträares": "disträ",
    "disträas": "disträ",
    "disträast": "disträ",
    "disträaste": "disträ",
    "disträastes": "disträ",
    "disträasts": "disträ",
    "disträe": "disträ",
    "disträes": "disträ",
    "disträs": "disträ",
    "disösen": "disös",
    "disösens": "disös",
    "disöser": "disös",
    "disöserna": "disös",
    "disösernas": "disös",
    "disösers": "disös",
    "ditresan": "ditresa",
    "ditresans": "ditresa",
    "ditresas": "ditresa",
    "ditrese": "ditresa",
    "ditresor": "ditresa",
    "ditresorna": "ditresa",
    "ditresornas": "ditresa",
    "ditresors": "ditresa",
    "ditvägens": "ditvägen",
    "dityramben": "dityramb",
    "dityrambens": "dityramb",
    "dityramber": "dityramb",
    "dityramberna": "dityramb",
    "dityrambernas": "dityramb",
    "dityrambers": "dityramb",
    "dityrambiska": "dityrambisk",
    "dityrambiskare": "dityrambisk",
    "dityrambiskares": "dityrambisk",
    "dityrambiskas": "dityrambisk",
    "dityrambiskast": "dityrambisk",
    "dityrambiskaste": "dityrambisk",
    "dityrambiskastes": "dityrambisk",
    "dityrambiskasts": "dityrambisk",
    "dityrambiske": "dityrambisk",
    "dityrambiskes": "dityrambisk",
    "dityrambisks": "dityrambisk",
    "dityrambiskt": "dityrambisk",
    "dityrambiskts": "dityrambisk",
    "dityrambs": "dityramb",
    "div": "diva",
    "divalaterna": "divalater",
    "divalaternas": "divalater",
    "divalaters": "divalater",
    "divalats": "divalater",
    "divan": "diva",
    "divanen": "divan",
    "divanens": "divan",
    "divaner": "divan",
    "divanerna": "divan",
    "divanernas": "divan",
    "divaners": "divan",
    "divans": "divan",
    "divas": "diva",
    "dive": "diva",
    "divergensen": "divergens",
    "divergensens": "divergens",
    "divergenser": "divergens",
    "divergenserna": "divergens",
    "divergensernas": "divergens",
    "divergensers": "divergens",
    "divergenta": "divergent",
    "divergentare": "divergent",
    "divergentares": "divergent",
    "divergentas": "divergent",
    "divergentast": "divergent",
    "divergentaste": "divergent",
    "divergentastes": "divergent",
    "divergentasts": "divergent",
    "divergente": "divergent",
    "divergentes": "divergent",
    "divergents": "divergent",
    "divergerad": "divergera",
    "divergerade": "divergera",
    "divergerades": "divergera",
    "divergerads": "divergera",
    "divergerande": "divergera",
    "divergeranden": "divergerande",
    "divergerandena": "divergerande",
    "divergerandenas": "divergerande",
    "divergerandens": "divergerande",
    "divergerandes": "divergerande",
    "divergerandet": "divergerande",
    "divergerandets": "divergerande",
    "divergerar": "divergera",
    "divergeras": "divergera",
    "divergerat": "divergera",
    "divergerats": "divergera",
    "divergerbara": "divergerbar",
    "divergerbarare": "divergerbar",
    "divergerbarares": "divergerbar",
    "divergerbaras": "divergerbar",
    "divergerbarast": "divergerbar",
    "divergerbaraste": "divergerbar",
    "divergerbarastes": "divergerbar",
    "divergerbarasts": "divergerbar",
    "divergerbare": "divergerbar",
    "divergerbares": "divergerbar",
    "divergerbarheten": "divergerbarhet",
    "divergerbarhetens": "divergerbarhet",
    "divergerbarhets": "divergerbarhet",
    "divergerbars": "divergerbar",
    "divergerbart": "divergerbar",
    "divergerbarts": "divergerbar",
    "divergeringar": "divergering",
    "divergeringarna": "divergering",
    "divergeringarnas": "divergering",
    "divergeringars": "divergering",
    "divergeringen": "divergering",
    "divergeringens": "divergering",
    "divergerings": "divergering",
    "diversearbetar": "diversearbetare",
    "diversearbetaren": "diversearbetare",
    "diversearbetarens": "diversearbetare",
    "diversearbetares": "diversearbetare",
    "diversearbetarna": "diversearbetare",
    "diversearbetarnas": "diversearbetare",
    "diversehandeln": "diversehandel",
    "diversehandelns": "diversehandel",
    "diversehandels": "diversehandel",
    "diversehandlar": "diversehandel",
    "diversehandlarna": "diversehandel",
    "diversehandlarnas": "diversehandel",
    "diversehandlars": "diversehandel",
    "diversifierad": "diversifiera",
    "diversifierade": "diversifiera",
    "diversifierades": "diversifiera",
    "diversifierads": "diversifiera",
    "diversifierande": "diversifiera",
    "diversifieranden": "diversifierande",
    "diversifierandena": "diversifierande",
    "diversifierandenas": "diversifierande",
    "diversifierandens": "diversifierande",
    "diversifierandes": "diversifierande",
    "diversifierandet": "diversifierande",
    "diversifierandets": "diversifierande",
    "diversifierar": "diversifiera",
    "diversifieras": "diversifiera",
    "diversifierat": "diversifiera",
    "diversifierats": "diversifiera",
    "diversifierbara": "diversifierbar",
    "diversifierbarare": "diversifierbar",
    "diversifierbarares": "diversifierbar",
    "diversifierbaras": "diversifierbar",
    "diversifierbarast": "diversifierbar",
    "diversifierbaraste": "diversifierbar",
    "diversifierbarastes": "diversifierbar",
    "diversifierbarasts": "diversifierbar",
    "diversifierbare": "diversifierbar",
    "diversifierbares": "diversifierbar",
    "diversifierbarheten": "diversifierbarhet",
    "diversifierbarhetens": "diversifierbarhet",
    "diversifierbarhets": "diversifierbarhet",
    "diversifierbars": "diversifierbar",
    "diversifierbart": "diversifierbar",
    "diversifierbarts": "diversifierbar",
    "diversifieringar": "diversifiering",
    "diversifieringarna": "diversifiering",
    "diversifieringarnas": "diversifiering",
    "diversifieringars": "diversifiering",
    "diversifieringen": "diversifiering",
    "diversifieringens": "diversifiering",
    "diversifierings": "diversifiering",
    "diversionen": "diversion",
    "diversionens": "diversion",
    "diversioner": "diversion",
    "diversionerna": "diversion",
    "diversionernas": "diversion",
    "diversioners": "diversion",
    "diversions": "diversion",
    "divertissemangen": "divertissemang",
    "divertissemangens": "divertissemang",
    "divertissemanger": "divertissemang",
    "divertissemangerna": "divertissemang",
    "divertissemangernas": "divertissemang",
    "divertissemangers": "divertissemang",
    "divertissemanget": "divertissemang",
    "divertissemangets": "divertissemang",
    "divertissemangs": "divertissemang",
    "dividenden": "dividend",
    "dividendens": "dividend",
    "dividender": "dividend",
    "dividenderna": "dividend",
    "dividendernas": "dividend",
    "dividenders": "dividend",
    "dividends": "dividend",
    "dividerad": "dividera",
    "dividerade": "dividera",
    "dividerades": "dividera",
    "dividerads": "dividera",
    "dividerande": "dividera",
    "divideranden": "dividerande",
    "dividerandena": "dividerande",
    "dividerandenas": "dividerande",
    "dividerandens": "dividerande",
    "dividerandes": "dividerande",
    "dividerandet": "dividerande",
    "dividerandets": "dividerande",
    "dividerar": "dividera",
    "divideras": "dividera",
    "dividerat": "dividera",
    "dividerats": "dividera",
    "dividerbara": "dividerbar",
    "dividerbarare": "dividerbar",
    "dividerbarares": "dividerbar",
    "dividerbaras": "dividerbar",
    "dividerbarast": "dividerbar",
    "dividerbaraste": "dividerbar",
    "dividerbarastes": "dividerbar",
    "dividerbarasts": "dividerbar",
    "dividerbare": "dividerbar",
    "dividerbares": "dividerbar",
    "dividerbarheten": "dividerbarhet",
    "dividerbarhetens": "dividerbarhet",
    "dividerbarhets": "dividerbarhet",
    "dividerbars": "dividerbar",
    "dividerbart": "dividerbar",
    "dividerbarts": "dividerbar",
    "divideringar": "dividering",
    "divideringarna": "dividering",
    "divideringarnas": "dividering",
    "divideringars": "dividering",
    "divideringen": "dividering",
    "divideringens": "dividering",
    "dividerings": "dividering",
    "diviga": "divig",
    "divigare": "divig",
    "divigares": "divig",
    "divigas": "divig",
    "divigast": "divig",
    "divigaste": "divig",
    "divigastes": "divig",
    "divigasts": "divig",
    "divige": "divig",
    "diviges": "divig",
    "divigs": "divig",
    "divigt": "divig",
    "divigts": "divig",
    "divinatoriska": "divinatorisk",
    "divinatoriskare": "divinatorisk",
    "divinatoriskares": "divinatorisk",
    "divinatoriskas": "divinatorisk",
    "divinatoriskast": "divinatorisk",
    "divinatoriskaste": "divinatorisk",
    "divinatoriskastes": "divinatorisk",
    "divinatoriskasts": "divinatorisk",
    "divinatoriske": "divinatorisk",
    "divinatoriskes": "divinatorisk",
    "divinatorisks": "divinatorisk",
    "divinatoriskt": "divinatorisk",
    "divinatoriskts": "divinatorisk",
    "divisen": "divis",
    "divisens": "divis",
    "diviser": "divis",
    "diviserna": "divis",
    "divisernas": "divis",
    "divisers": "divis",
    "divisionen": "division",
    "divisionens": "division",
    "divisioner": "division",
    "divisionerna": "division",
    "divisionernas": "division",
    "divisioners": "division",
    "divisions": "division",
    "divisorer": "divisor",
    "divisorerna": "divisor",
    "divisorernas": "divisor",
    "divisorers": "divisor",
    "divisorn": "divisor",
    "divisorns": "divisor",
    "divisors": "divisor",
    "divor": "diva",
    "divorna": "diva",
    "divornas": "diva",
    "divors": "diva",
    "divs": "diva",
    "dixielands": "dixieland",
    "djiboutiern": "djiboutier",
    "djiboutierna": "djiboutier",
    "djiboutiernas": "djiboutier",
    "djiboutierns": "djiboutier",
    "djiboutiers": "djiboutier",
    "djiboutiska": "djiboutisk",
    "djiboutiskan": "djiboutiska",
    "djiboutiskans": "djiboutiska",
    "djiboutiskare": "djiboutisk",
    "djiboutiskares": "djiboutisk",
    "djiboutiskas": "djiboutiska",
    "djiboutiskast": "djiboutisk",
    "djiboutiskaste": "djiboutisk",
    "djiboutiskastes": "djiboutisk",
    "djiboutiskasts": "djiboutisk",
    "djiboutiske": "djiboutiska",
    "djiboutiskes": "djiboutisk",
    "djiboutiskor": "djiboutiska",
    "djiboutiskorna": "djiboutiska",
    "djiboutiskornas": "djiboutiska",
    "djiboutiskors": "djiboutiska",
    "djiboutisks": "djiboutisk",
    "djiboutiskt": "djiboutisk",
    "djiboutiskts": "djiboutisk",
    "djonken": "djonk",
    "djonkens": "djonk",
    "djonker": "djonk",
    "djonkerna": "djonk",
    "djonkernas": "djonk",
    "djonkers": "djonk",
    "djonks": "djonk",
    "djungeln": "djungel",
    "djungelns": "djungel",
    "djungels": "djungel",
    "djungeltelegrafen": "djungeltelegraf",
    "djungeltelegrafens": "djungeltelegraf",
    "djungeltelegrafs": "djungeltelegraf",
    "djungler": "djungel",
    "djunglerna": "djungel",
    "djunglernas": "djungel",
    "djunglers": "djungel",
    "djupa": "djup",
    "djupare": "djup",
    "djupares": "djup",
    "djupas": "djup",
    "djupast": "djup",
    "djupaste": "djup",
    "djupastes": "djup",
    "djupasts": "djup",
    "djupbergarten": "djupbergart",
    "djupbergartens": "djupbergart",
    "djupbergarter": "djupbergart",
    "djupbergarterna": "djupbergart",
    "djupbergarternas": "djupbergart",
    "djupbergarters": "djupbergart",
    "djupbergarts": "djupbergart",
    "djupbilden": "djupbild",
    "djupbildens": "djupbild",
    "djupbilder": "djupbild",
    "djupbilderna": "djupbild",
    "djupbildernas": "djupbild",
    "djupbilders": "djupbild",
    "djupbilds": "djupbild",
    "djupblåa": "djupblå",
    "djupblåare": "djupblå",
    "djupblåares": "djupblå",
    "djupblåas": "djupblå",
    "djupblåast": "djupblå",
    "djupblåaste": "djupblå",
    "djupblåastes": "djupblå",
    "djupblåasts": "djupblå",
    "djupblåe": "djupblå",
    "djupblåes": "djupblå",
    "djupblås": "djupblå",
    "djupblått": "djupblå",
    "djupblåtts": "djupblå",
    "djupborrade": "djupborrad",
    "djupborrades": "djupborrad",
    "djupborrads": "djupborrad",
    "djupborrat": "djupborrad",
    "djupborrats": "djupborrad",
    "djupborrningar": "djupborrning",
    "djupborrningarna": "djupborrning",
    "djupborrningarnas": "djupborrning",
    "djupborrningars": "djupborrning",
    "djupborrningen": "djupborrning",
    "djupborrningens": "djupborrning",
    "djupborrnings": "djupborrning",
    "djupbrytningar": "djupbrytning",
    "djupbrytningarna": "djupbrytning",
    "djupbrytningarnas": "djupbrytning",
    "djupbrytningars": "djupbrytning",
    "djupbrytningen": "djupbrytning",
    "djupbrytningens": "djupbrytning",
    "djupbrytnings": "djupbrytning",
    "djupdimensionen": "djupdimension",
    "djupdimensionens": "djupdimension",
    "djupdimensioner": "djupdimension",
    "djupdimensionerna": "djupdimension",
    "djupdimensionernas": "djupdimension",
    "djupdimensioners": "djupdimension",
    "djupdimensions": "djupdimension",
    "djupdykningar": "djupdykning",
    "djupdykningarna": "djupdykning",
    "djupdykningarnas": "djupdykning",
    "djupdykningars": "djupdykning",
    "djupdykningen": "djupdykning",
    "djupdykningens": "djupdykning",
    "djupdyknings": "djupdykning",
    "djupe": "djup",
    "djupen": "djup",
    "djupens": "djup",
    "djupes": "djup",
    "djupet": "djup",
    "djupets": "djup",
    "djupfrys": "djupfrysa",
    "djupfrysande": "djupfrysa",
    "djupfrysanden": "djupfrysande",
    "djupfrysandena": "djupfrysande",
    "djupfrysandenas": "djupfrysande",
    "djupfrysandens": "djupfrysande",
    "djupfrysandes": "djupfrysande",
    "djupfrysandet": "djupfrysande",
    "djupfrysandets": "djupfrysande",
    "djupfrysas": "djupfrysa",
    "djupfryser": "djupfrysa",
    "djupfryses": "djupfrysa",
    "djupfryst": "djupfrysa",
    "djupfrysta": "djupfrysa",
    "djupfrystas": "djupfrysa",
    "djupfryste": "djupfrysa",
    "djupfrystes": "djupfrysa",
    "djupfrysts": "djupfrysa",
    "djupgröna": "djupgrön",
    "djupgrönare": "djupgrön",
    "djupgrönares": "djupgrön",
    "djupgrönas": "djupgrön",
    "djupgrönast": "djupgrön",
    "djupgrönaste": "djupgrön",
    "djupgrönastes": "djupgrön",
    "djupgrönasts": "djupgrön",
    "djupgröne": "djupgrön",
    "djupgrönes": "djupgrön",
    "djupgröns": "djupgrön",
    "djupgrönt": "djupgrön",
    "djupgrönts": "djupgrön",
    "djupgåendes": "djupgående",
    "djupgåendet": "djupgående",
    "djupgåendets": "djupgående",
    "djuphavet": "djuphav",
    "djuphavets": "djuphav",
    "djuphavs": "djuphav",
    "djuphavsbottens": "djuphavsbotten",
    "djuphavsbottnar": "djuphavsbotten",
    "djuphavsbottnarna": "djuphavsbotten",
    "djuphavsbottnarnas": "djuphavsbotten",
    "djuphavsbottnars": "djuphavsbotten",
    "djuphavsbottnen": "djuphavsbotten",
    "djuphavsbottnens": "djuphavsbotten",
    "djuphavsfiskar": "djuphavsfisk",
    "djuphavsfiskarna": "djuphavsfisk",
    "djuphavsfiskarnas": "djuphavsfisk",
    "djuphavsfiskars": "djuphavsfisk",
    "djuphavsfisken": "djuphavsfisk",
    "djuphavsfiskens": "djuphavsfisk",
    "djuphavsfisks": "djuphavsfisk",
    "djuphavsvattens": "djuphavsvatten",
    "djuphavsvattnen": "djuphavsvatten",
    "djuphavsvattnens": "djuphavsvatten",
    "djuphavsvattnet": "djuphavsvatten",
    "djuphavsvattnets": "djuphavsvatten",
    "djupheten": "djuphet",
    "djuphetens": "djuphet",
    "djuphets": "djuphet",
    "djupingar": "djuping",
    "djupingarna": "djuping",
    "djupingarnas": "djuping",
    "djupingars": "djuping",
    "djupingen": "djuping",
    "djupingens": "djuping",
    "djupings": "djuping",
    "djupintervjuer": "djupintervju",
    "djupintervjuerna": "djupintervju",
    "djupintervjuernas": "djupintervju",
    "djupintervjuers": "djupintervju",
    "djupintervjun": "djupintervju",
    "djupintervjuns": "djupintervju",
    "djupintervjus": "djupintervju",
    "djupkulturen": "djupkultur",
    "djupkulturens": "djupkultur",
    "djupkulturs": "djupkultur",
    "djuplekar": "djuplek",
    "djuplekarna": "djuplek",
    "djuplekarnas": "djuplek",
    "djuplekars": "djuplek",
    "djupleken": "djuplek",
    "djuplekens": "djuplek",
    "djupleks": "djuplek",
    "djuplod": "djuploda",
    "djuplodad": "djuploda",
    "djuplodade": "djuploda",
    "djuplodades": "djuploda",
    "djuplodads": "djuploda",
    "djuplodande": "djuploda",
    "djuplodanden": "djuplodande",
    "djuplodandena": "djuplodande",
    "djuplodandenas": "djuplodande",
    "djuplodandens": "djuplodande",
    "djuplodandes": "djuplodande",
    "djuplodandet": "djuplodande",
    "djuplodandets": "djuplodande",
    "djuplodar": "djuploda",
    "djuplodas": "djuploda",
    "djuplodat": "djuploda",
    "djuplodats": "djuploda",
    "djuploden": "djuplod",
    "djuplodens": "djuplod",
    "djuplodet": "djuplod",
    "djuplodets": "djuplod",
    "djuplods": "djuplod",
    "djupmaskar": "djupmask",
    "djupmaskarna": "djupmask",
    "djupmaskarnas": "djupmask",
    "djupmaskars": "djupmask",
    "djupmasken": "djupmask",
    "djupmaskens": "djupmask",
    "djupmasks": "djupmask",
    "djupnade": "djupna",
    "djupnades": "djupna",
    "djupnande": "djupna",
    "djupnanden": "djupnande",
    "djupnandena": "djupnande",
    "djupnandenas": "djupnande",
    "djupnandens": "djupnande",
    "djupnandes": "djupnande",
    "djupnandet": "djupnande",
    "djupnandets": "djupnande",
    "djupnar": "djupna",
    "djupnas": "djupna",
    "djupnat": "djupna",
    "djupnats": "djupna",
    "djuppsykologien": "djuppsykologi",
    "djuppsykologiens": "djuppsykologi",
    "djuppsykologin": "djuppsykologi",
    "djuppsykologins": "djuppsykologi",
    "djuppsykologis": "djuppsykologi",
    "djuprotade": "djuprotad",
    "djuprotades": "djuprotad",
    "djuprotads": "djuprotad",
    "djuprotat": "djuprotad",
    "djuprotats": "djuprotad",
    "djupröda": "djupröd",
    "djuprödare": "djupröd",
    "djuprödares": "djupröd",
    "djuprödas": "djupröd",
    "djuprödast": "djupröd",
    "djuprödaste": "djupröd",
    "djuprödastes": "djupröd",
    "djuprödasts": "djupröd",
    "djupröde": "djupröd",
    "djuprödes": "djupröd",
    "djupröds": "djupröd",
    "djuprött": "djupröd",
    "djuprötts": "djupröd",
    "djups": "djup",
    "djupsinnes": "djupsinne",
    "djupsinnet": "djupsinne",
    "djupsinnets": "djupsinne",
    "djupsinniga": "djupsinnig",
    "djupsinnigare": "djupsinnig",
    "djupsinnigares": "djupsinnig",
    "djupsinnigas": "djupsinnig",
    "djupsinnigast": "djupsinnig",
    "djupsinnigaste": "djupsinnig",
    "djupsinnigastes": "djupsinnig",
    "djupsinnigasts": "djupsinnig",
    "djupsinnige": "djupsinnig",
    "djupsinniges": "djupsinnig",
    "djupsinnigheten": "djupsinnighet",
    "djupsinnighetens": "djupsinnighet",
    "djupsinnigheter": "djupsinnighet",
    "djupsinnigheterna": "djupsinnighet",
    "djupsinnigheternas": "djupsinnighet",
    "djupsinnigheters": "djupsinnighet",
    "djupsinnighets": "djupsinnighet",
    "djupsinnigs": "djupsinnig",
    "djupsinnigt": "djupsinnig",
    "djupsinnigts": "djupsinnig",
    "djupstrukturen": "djupstruktur",
    "djupstrukturens": "djupstruktur",
    "djupstrukturer": "djupstruktur",
    "djupstrukturerna": "djupstruktur",
    "djupstrukturernas": "djupstruktur",
    "djupstrukturers": "djupstruktur",
    "djupstrukturs": "djupstruktur",
    "djupsömnen": "djupsömn",
    "djupsömnens": "djupsömn",
    "djupsömns": "djupsömn",
    "djupt": "djup",
    "djuptallrikar": "djuptallrik",
    "djuptallrikarna": "djuptallrik",
    "djuptallrikarnas": "djuptallrik",
    "djuptallrikars": "djuptallrik",
    "djuptallriken": "djuptallrik",
    "djuptallrikens": "djuptallrik",
    "djuptallriks": "djuptallrik",
    "djuptrycken": "djuptryck",
    "djuptryckens": "djuptryck",
    "djuptrycket": "djuptryck",
    "djuptryckets": "djuptryck",
    "djuptrycks": "djuptryck",
    "djupts": "djup",
    "djuptänkta": "djuptänkt",
    "djuptänktare": "djuptänkt",
    "djuptänktares": "djuptänkt",
    "djuptänktas": "djuptänkt",
    "djuptänktast": "djuptänkt",
    "djuptänktaste": "djuptänkt",
    "djuptänktastes": "djuptänkt",
    "djuptänktasts": "djuptänkt",
    "djuptänkte": "djuptänkt",
    "djuptänktes": "djuptänkt",
    "djuptänktheten": "djuptänkthet",
    "djuptänkthetens": "djuptänkthet",
    "djuptänkthets": "djuptänkthet",
    "djuptänkts": "djuptänkt",
    "djupurladdningar": "djupurladdning",
    "djupurladdningarna": "djupurladdning",
    "djupurladdningarnas": "djupurladdning",
    "djupurladdningars": "djupurladdning",
    "djupurladdningen": "djupurladdning",
    "djupurladdningens": "djupurladdning",
    "djupurladdnings": "djupurladdning",
    "djupvattens": "djupvatten",
    "djupvattnen": "djupvatten",
    "djupvattnens": "djupvatten",
    "djupvattnet": "djupvatten",
    "djupvattnets": "djupvatten",
    "djupverkans": "djupverkan",
    "djuranatomien": "djuranatomi",
    "djuranatomiens": "djuranatomi",
    "djuranatomin": "djuranatomi",
    "djuranatomins": "djuranatomi",
    "djuranatomis": "djuranatomi",
    "djurangreppen": "djurangrepp",
    "djurangreppens": "djurangrepp",
    "djurangreppet": "djurangrepp",
    "djurangreppets": "djurangrepp",
    "djurangrepps": "djurangrepp",
    "djurarten": "djurart",
    "djurartens": "djurart",
    "djurarter": "djurart",
    "djurarterna": "djurart",
    "djurarternas": "djurart",
    "djurarters": "djurart",
    "djurarts": "djurart",
    "djurbenen": "djurben",
    "djurbenens": "djurben",
    "djurbenet": "djurben",
    "djurbenets": "djurben",
    "djurbens": "djurben",
    "djurbloden": "djurblod",
    "djurblodens": "djurblod",
    "djurblodet": "djurblod",
    "djurblodets": "djurblod",
    "djurblods": "djurblod",
    "djurboken": "djurbok",
    "djurbokens": "djurbok",
    "djurboks": "djurbok",
    "djurböcker": "djurbok",
    "djurböckerna": "djurbok",
    "djurböckernas": "djurbok",
    "djurböckers": "djurbok",
    "djurdelar": "djurdel",
    "djurdelarna": "djurdel",
    "djurdelarnas": "djurdel",
    "djurdelars": "djurdel",
    "djurdelen": "djurdel",
    "djurdelens": "djurdel",
    "djurdels": "djurdel",
    "djurdyrkans": "djurdyrkan",
    "djuren": "djur",
    "djurens": "djur",
    "djuret": "djur",
    "djurets": "djur",
    "djurfabeln": "djurfabel",
    "djurfabelns": "djurfabel",
    "djurfabels": "djurfabel",
    "djurfabler": "djurfabel",
    "djurfablerna": "djurfabel",
    "djurfablernas": "djurfabel",
    "djurfablers": "djurfabel",
    "djurfoderna": "djurfoder",
    "djurfodernas": "djurfoder",
    "djurfoders": "djurfoder",
    "djurfodren": "djurfoder",
    "djurfodrens": "djurfoder",
    "djurfodret": "djurfoder",
    "djurfodrets": "djurfoder",
    "djurförsöken": "djurförsök",
    "djurförsökens": "djurförsök",
    "djurförsöket": "djurförsök",
    "djurförsökets": "djurförsök",
    "djurförsöks": "djurförsök",
    "djurförädlingar": "djurförädling",
    "djurförädlingarna": "djurförädling",
    "djurförädlingarnas": "djurförädling",
    "djurförädlingars": "djurförädling",
    "djurförädlingen": "djurförädling",
    "djurförädlingens": "djurförädling",
    "djurförädlings": "djurförädling",
    "djurgeografien": "djurgeografi",
    "djurgeografiens": "djurgeografi",
    "djurgeografin": "djurgeografi",
    "djurgeografins": "djurgeografi",
    "djurgeografis": "djurgeografi",
    "djurgruppen": "djurgrupp",
    "djurgruppens": "djurgrupp",
    "djurgrupper": "djurgrupp",
    "djurgrupperna": "djurgrupp",
    "djurgruppernas": "djurgrupp",
    "djurgruppers": "djurgrupp",
    "djurgrupps": "djurgrupp",
    "djurgårdar": "djurgård",
    "djurgårdarna": "djurgård",
    "djurgårdarnas": "djurgård",
    "djurgårdars": "djurgård",
    "djurgården": "djurgård",
    "djurgårdens": "djurgård",
    "djurgårds": "djurgård",
    "djurhudar": "djurhud",
    "djurhudarna": "djurhud",
    "djurhudarnas": "djurhud",
    "djurhudars": "djurhud",
    "djurhuden": "djurhud",
    "djurhudens": "djurhud",
    "djurhuds": "djurhud",
    "djurhuvuden": "djurhuvud",
    "djurhuvudena": "djurhuvud",
    "djurhuvudenas": "djurhuvud",
    "djurhuvudens": "djurhuvud",
    "djurhuvudet": "djurhuvud",
    "djurhuvudets": "djurhuvud",
    "djurhuvuds": "djurhuvud",
    "djurhälsan": "djurhälsa",
    "djurhälsans": "djurhälsa",
    "djurhälsas": "djurhälsa",
    "djurhälse": "djurhälsa",
    "djurhälso": "djurhälsa",
    "djurhållningen": "djurhållning",
    "djurhållningens": "djurhållning",
    "djurhållnings": "djurhållning",
    "djurhövdade": "djurhövdad",
    "djurhövdades": "djurhövdad",
    "djurhövdads": "djurhövdad",
    "djurhövdat": "djurhövdad",
    "djurhövdats": "djurhövdad",
    "djuriska": "djurisk",
    "djuriskare": "djurisk",
    "djuriskares": "djurisk",
    "djuriskas": "djurisk",
    "djuriskast": "djurisk",
    "djuriskaste": "djurisk",
    "djuriskastes": "djurisk",
    "djuriskasts": "djurisk",
    "djuriske": "djurisk",
    "djuriskes": "djurisk",
    "djurisks": "djurisk",
    "djuriskt": "djurisk",
    "djuriskts": "djurisk",
    "djurkretsen": "djurkrets",
    "djurkretsens": "djurkrets",
    "djurkroppar": "djurkropp",
    "djurkropparna": "djurkropp",
    "djurkropparnas": "djurkropp",
    "djurkroppars": "djurkropp",
    "djurkroppen": "djurkropp",
    "djurkroppens": "djurkropp",
    "djurkropps": "djurkropp",
    "djurlivet": "djurliv",
    "djurlivets": "djurliv",
    "djurlivs": "djurliv",
    "djurläkar": "djurläkare",
    "djurläkaren": "djurläkare",
    "djurläkarens": "djurläkare",
    "djurläkares": "djurläkare",
    "djurläkarna": "djurläkare",
    "djurläkarnas": "djurläkare",
    "djurmaten": "djurmat",
    "djurmatens": "djurmat",
    "djurmats": "djurmat",
    "djurornamentiken": "djurornamentik",
    "djurornamentikens": "djurornamentik",
    "djurornamentiks": "djurornamentik",
    "djurparken": "djurpark",
    "djurparkens": "djurpark",
    "djurparker": "djurpark",
    "djurparkerna": "djurpark",
    "djurparkernas": "djurpark",
    "djurparkers": "djurpark",
    "djurparks": "djurpark",
    "djurparksvargar": "djurparksvarg",
    "djurparksvargarna": "djurparksvarg",
    "djurparksvargarnas": "djurparksvarg",
    "djurparksvargars": "djurparksvarg",
    "djurparksvargen": "djurparksvarg",
    "djurparksvargens": "djurparksvarg",
    "djurparksvargs": "djurparksvarg",
    "djurplanktonen": "djurplankton",
    "djurplanktonens": "djurplankton",
    "djurplanktonet": "djurplankton",
    "djurplanktonets": "djurplankton",
    "djurplanktons": "djurplankton",
    "djurplågar": "djurplågare",
    "djurplågaren": "djurplågare",
    "djurplågarens": "djurplågare",
    "djurplågares": "djurplågare",
    "djurplågarna": "djurplågare",
    "djurplågarnas": "djurplågare",
    "djurplågeriet": "djurplågeri",
    "djurplågeriets": "djurplågeri",
    "djurplågeris": "djurplågeri",
    "djurplågerit": "djurplågeri",
    "djurplågerits": "djurplågeri",
    "djurpsykologien": "djurpsykologi",
    "djurpsykologiens": "djurpsykologi",
    "djurpsykologin": "djurpsykologi",
    "djurpsykologins": "djurpsykologi",
    "djurpsykologis": "djurpsykologi",
    "djurrikes": "djurrike",
    "djurriket": "djurrike",
    "djurrikets": "djurrike",
    "djurrättsaktivisten": "djurrättsaktivist",
    "djurrättsaktivistens": "djurrättsaktivist",
    "djurrättsaktivister": "djurrättsaktivist",
    "djurrättsaktivisterna": "djurrättsaktivist",
    "djurrättsaktivisternas": "djurrättsaktivist",
    "djurrättsaktivisters": "djurrättsaktivist",
    "djurrättsaktivists": "djurrättsaktivist",
    "djurrättsfrågan": "djurrättsfråga",
    "djurrättsfrågans": "djurrättsfråga",
    "djurrättsfrågas": "djurrättsfråga",
    "djurrättsfråge": "djurrättsfråga",
    "djurrättsfrågor": "djurrättsfråga",
    "djurrättsfrågorna": "djurrättsfråga",
    "djurrättsfrågornas": "djurrättsfråga",
    "djurrättsfrågors": "djurrättsfråga",
    "djurs": "djur",
    "djursjukhusen": "djursjukhus",
    "djursjukhusens": "djursjukhus",
    "djursjukhuset": "djursjukhus",
    "djursjukhusets": "djursjukhus",
    "djurskinnen": "djurskinn",
    "djurskinnens": "djurskinn",
    "djurskinnet": "djurskinn",
    "djurskinnets": "djurskinn",
    "djurskinns": "djurskinn",
    "djurskyddet": "djurskydd",
    "djurskyddets": "djurskydd",
    "djurskydds": "djurskydd",
    "djurskyddsinspektören": "djurskyddsinspektör",
    "djurskyddsinspektörens": "djurskyddsinspektör",
    "djurskyddsinspektörer": "djurskyddsinspektör",
    "djurskyddsinspektörerna": "djurskyddsinspektör",
    "djurskyddsinspektörernas": "djurskyddsinspektör",
    "djurskyddsinspektörers": "djurskyddsinspektör",
    "djurskyddsinspektörn": "djurskyddsinspektör",
    "djurskyddsinspektörns": "djurskyddsinspektör",
    "djurskyddsinspektörs": "djurskyddsinspektör",
    "djurskyddslagstiftningar": "djurskyddslagstiftning",
    "djurskyddslagstiftningarna": "djurskyddslagstiftning",
    "djurskyddslagstiftningarnas": "djurskyddslagstiftning",
    "djurskyddslagstiftningars": "djurskyddslagstiftning",
    "djurskyddslagstiftningen": "djurskyddslagstiftning",
    "djurskyddslagstiftningens": "djurskyddslagstiftning",
    "djurskyddslagstiftnings": "djurskyddslagstiftning",
    "djurskyddsmässiga": "djurskyddsmässig",
    "djurskyddsmässigare": "djurskyddsmässig",
    "djurskyddsmässigares": "djurskyddsmässig",
    "djurskyddsmässigas": "djurskyddsmässig",
    "djurskyddsmässigast": "djurskyddsmässig",
    "djurskyddsmässigaste": "djurskyddsmässig",
    "djurskyddsmässigastes": "djurskyddsmässig",
    "djurskyddsmässigasts": "djurskyddsmässig",
    "djurskyddsmässige": "djurskyddsmässig",
    "djurskyddsmässiges": "djurskyddsmässig",
    "djurskyddsmässigs": "djurskyddsmässig",
    "djurskyddsmässigt": "djurskyddsmässig",
    "djurskyddsmässigts": "djurskyddsmässig",
    "djurskötar": "djurskötare",
    "djurskötaren": "djurskötare",
    "djurskötarens": "djurskötare",
    "djurskötares": "djurskötare",
    "djurskötarna": "djurskötare",
    "djurskötarnas": "djurskötare",
    "djurslagen": "djurslag",
    "djurslagens": "djurslag",
    "djurslaget": "djurslag",
    "djurslagets": "djurslag",
    "djurslags": "djurslag",
    "djurtarmar": "djurtarm",
    "djurtarmarna": "djurtarm",
    "djurtarmarnas": "djurtarm",
    "djurtarmars": "djurtarm",
    "djurtarmen": "djurtarm",
    "djurtarmens": "djurtarm",
    "djurtarms": "djurtarm",
    "djurtillsynen": "djurtillsyn",
    "djurtillsynens": "djurtillsyn",
    "djurtillsyns": "djurtillsyn",
    "djuruppfödningen": "djuruppfödning",
    "djuruppfödningens": "djuruppfödning",
    "djuruppfödnings": "djuruppfödning",
    "djurutställningar": "djurutställning",
    "djurutställningarna": "djurutställning",
    "djurutställningarnas": "djurutställning",
    "djurutställningars": "djurutställning",
    "djurutställningen": "djurutställning",
    "djurutställningens": "djurutställning",
    "djurutställnings": "djurutställning",
    "djurvänliga": "djurvänlig",
    "djurvänligare": "djurvänlig",
    "djurvänligares": "djurvänlig",
    "djurvänligas": "djurvänlig",
    "djurvänligast": "djurvänlig",
    "djurvänligaste": "djurvänlig",
    "djurvänligastes": "djurvänlig",
    "djurvänligasts": "djurvänlig",
    "djurvänlige": "djurvänlig",
    "djurvänliges": "djurvänlig",
    "djurvänligheten": "djurvänlighet",
    "djurvänlighetens": "djurvänlighet",
    "djurvänlighets": "djurvänlighet",
    "djurvänligs": "djurvänlig",
    "djurvänligt": "djurvänlig",
    "djurvänligts": "djurvänlig",
    "djurvännen": "djurvän",
    "djurvännens": "djurvän",
    "djurvänner": "djurvän",
    "djurvännerna": "djurvän",
    "djurvännernas": "djurvän",
    "djurvänners": "djurvän",
    "djurväns": "djurvän",
    "djurvärlden": "djurvärld",
    "djurvärldens": "djurvärld",
    "djurvärlds": "djurvärld",
    "djäkliga": "djäklig",
    "djäkligare": "djäklig",
    "djäkligares": "djäklig",
    "djäkligas": "djäklig",
    "djäkligast": "djäklig",
    "djäkligaste": "djäklig",
    "djäkligastes": "djäklig",
    "djäkligasts": "djäklig",
    "djäklige": "djäklig",
    "djäkliges": "djäklig",
    "djäkligheten": "djäklighet",
    "djäklighetens": "djäklighet",
    "djäkligheter": "djäklighet",
    "djäkligheterna": "djäklighet",
    "djäkligheternas": "djäklighet",
    "djäkligheters": "djäklighet",
    "djäklighets": "djäklighet",
    "djäkligs": "djäklig",
    "djäkligt": "djäklig",
    "djäkligts": "djäklig",
    "djäknar": "djäkne",
    "djäknarna": "djäkne",
    "djäknarnas": "djäkne",
    "djäknars": "djäkne",
    "djäknen": "djäkne",
    "djäknens": "djäkne",
    "djäknes": "djäkne",
    "djärva": "djärv",
    "djärvare": "djärv",
    "djärvares": "djärv",
    "djärvas": "djärv",
    "djärvast": "djärv",
    "djärvaste": "djärv",
    "djärvastes": "djärv",
    "djärvasts": "djärv",
    "djärvdes": "djärvas",
    "djärve": "djärv",
    "djärves": "djärvas",
    "djärvheten": "djärvhet",
    "djärvhetens": "djärvhet",
    "djärvheter": "djärvhet",
    "djärvheterna": "djärvhet",
    "djärvheternas": "djärvhet",
    "djärvheters": "djärvhet",
    "djärvhets": "djärvhet",
    "djärvs": "djärvas",
    "djärvt": "djärv",
    "djärvts": "djärvas",
    "djäveln": "djävel",
    "djävelns": "djävel",
    "djävels": "djävel",
    "djävelska": "djävelsk",
    "djävelskapen": "djävelskap",
    "djävelskapens": "djävelskap",
    "djävelskaper": "djävelskap",
    "djävelskaperna": "djävelskap",
    "djävelskapernas": "djävelskap",
    "djävelskapers": "djävelskap",
    "djävelskapet": "djävelskap",
    "djävelskapets": "djävelskap",
    "djävelskaps": "djävelskap",
    "djävelskare": "djävelsk",
    "djävelskares": "djävelsk",
    "djävelskas": "djävelsk",
    "djävelskast": "djävelsk",
    "djävelskaste": "djävelsk",
    "djävelskastes": "djävelsk",
    "djävelskasts": "djävelsk",
    "djävelske": "djävelsk",
    "djävelskes": "djävelsk",
    "djävelsks": "djävelsk",
    "djävelskt": "djävelsk",
    "djävelskts": "djävelsk",
    "djävelstygen": "djävelstyg",
    "djävelstygens": "djävelstyg",
    "djävelstyget": "djävelstyg",
    "djävelstygets": "djävelstyg",
    "djävelstygs": "djävelstyg",
    "djävlades": "djävlas",
    "djävlar": "djävul",
    "djävlarna": "djävul",
    "djävlarnas": "djävul",
    "djävlars": "djävul",
    "djävlats": "djävlas",
    "djävliga": "djävlig",
    "djävligare": "djävlig",
    "djävligares": "djävlig",
    "djävligas": "djävlig",
    "djävligast": "djävlig",
    "djävligaste": "djävlig",
    "djävligastes": "djävlig",
    "djävligasts": "djävlig",
    "djävlige": "djävlig",
    "djävliges": "djävlig",
    "djävligheten": "djävlighet",
    "djävlighetens": "djävlighet",
    "djävligheter": "djävlighet",
    "djävligheterna": "djävlighet",
    "djävligheternas": "djävlighet",
    "djävligheters": "djävlighet",
    "djävlighets": "djävlighet",
    "djävligs": "djävlig",
    "djävligt": "djävlig",
    "djävligts": "djävlig",
    "djävulen": "djävul",
    "djävulens": "djävul",
    "djävuls": "djävul",
    "djävulska": "djävulsk",
    "djävulskapen": "djävulskap",
    "djävulskapens": "djävulskap",
    "djävulskaper": "djävulskap",
    "djävulskaperna": "djävulskap",
    "djävulskapernas": "djävulskap",
    "djävulskapers": "djävulskap",
    "djävulskapet": "djävulskap",
    "djävulskapets": "djävulskap",
    "djävulskaps": "djävulskap",
    "djävulskare": "djävulsk",
    "djävulskares": "djävulsk",
    "djävulskas": "djävulsk",
    "djävulskast": "djävulsk",
    "djävulskaste": "djävulsk",
    "djävulskastes": "djävulsk",
    "djävulskasts": "djävulsk",
    "djävulske": "djävulsk",
    "djävulskes": "djävulsk",
    "djävulsks": "djävulsk",
    "djävulskt": "djävulsk",
    "djävulskts": "djävulsk",
    "djävulstygen": "djävulstyg",
    "djävulstygens": "djävulstyg",
    "djävulstyget": "djävulstyg",
    "djävulstygets": "djävulstyg",
    "djävulstygs": "djävulstyg",
    "djävulusiska": "djävulusisk",
    "djävulusiskare": "djävulusisk",
    "djävulusiskares": "djävulusisk",
    "djävulusiskas": "djävulusisk",
    "djävulusiskast": "djävulusisk",
    "djävulusiskaste": "djävulusisk",
    "djävulusiskastes": "djävulusisk",
    "djävulusiskasts": "djävulusisk",
    "djävulusiske": "djävulusisk",
    "djävulusiskes": "djävulusisk",
    "djävulusisks": "djävulusisk",
    "djävulusiskt": "djävulusisk",
    "djävulusiskts": "djävulusisk",
    "dna-ernas": "dna",
    "dna-kedjans": "dna-kedja",
    "dna-kedje": "dna-kedja",
    "dna-kedjor": "dna-kedja",
    "dna-kedjornas": "dna-kedja",
    "dna-kedjors": "dna-kedja",
    "dna-molekylens": "dna-molekyl",
    "dna-molekylernas": "dna-molekyl",
    "dna-molekylers": "dna-molekyl",
    "dna-molekyls": "dna-molekyl",
    "dna-nas": "dna",
    "dna-ns": "dna",
    "dna-s": "dna",
    "dna-t": "dna",
    "dna-ts": "dna",
    "dna-uppsättningar": "dna-uppsättning",
    "dna-uppsättningarnas": "dna-uppsättning",
    "dna-uppsättningen": "dna-uppsättning",
    "dna:erna": "dna",
    "dna:ers": "dna",
    "dna:na": "dna",
    "dna:ns": "dna",
    "dna:t": "dna",
    "dnaer": "dna",
    "dnaerna": "dna",
    "dnaers": "dna",
    "dnan": "dna",
    "dnana": "dna",
    "doade": "doa",
    "doades": "doa",
    "doakören": "doakör",
    "doakörens": "doakör",
    "doakörer": "doakör",
    "doakörerna": "doakör",
    "doakörernas": "doakör",
    "doakörers": "doakör",
    "doakörs": "doakör",
    "doande": "doa",
    "doanden": "doande",
    "doandena": "doande",
    "doandenas": "doande",
    "doandens": "doande",
    "doandes": "doande",
    "doandet": "doande",
    "doandets": "doande",
    "doar": "doa",
    "doas": "doa",
    "doat": "doa",
    "doats": "doa",
    "dobbel": "dobbla",
    "dobbels": "dobbel",
    "dobblade": "dobbla",
    "dobblades": "dobbla",
    "dobblande": "dobbla",
    "dobblanden": "dobblande",
    "dobblandena": "dobblande",
    "dobblandenas": "dobblande",
    "dobblandens": "dobblande",
    "dobblandes": "dobblande",
    "dobblandet": "dobblande",
    "dobblandets": "dobblande",
    "dobblar": "dobbla",
    "dobblas": "dobbla",
    "dobblat": "dobbla",
    "dobblats": "dobbla",
    "dobblet": "dobbel",
    "dobblets": "dobbel",
    "docenten": "docent",
    "docentens": "docent",
    "docenter": "docent",
    "docenterna": "docent",
    "docenternas": "docent",
    "docenters": "docent",
    "docents": "docent",
    "docenturen": "docentur",
    "docenturens": "docentur",
    "docenturer": "docentur",
    "docenturerna": "docentur",
    "docenturernas": "docentur",
    "docenturers": "docentur",
    "docenturs": "docentur",
    "docerad": "docera",
    "docerade": "docera",
    "docerades": "docera",
    "docerads": "docera",
    "docerande": "docera",
    "doceranden": "docerande",
    "docerandena": "docerande",
    "docerandenas": "docerande",
    "docerandens": "docerande",
    "docerandes": "docerande",
    "docerandet": "docerande",
    "docerandets": "docerande",
    "docerar": "docera",
    "doceras": "docera",
    "docerat": "docera",
    "docerats": "docera",
    "docerbara": "docerbar",
    "docerbarare": "docerbar",
    "docerbarares": "docerbar",
    "docerbaras": "docerbar",
    "docerbarast": "docerbar",
    "docerbaraste": "docerbar",
    "docerbarastes": "docerbar",
    "docerbarasts": "docerbar",
    "docerbare": "docerbar",
    "docerbares": "docerbar",
    "docerbarheten": "docerbarhet",
    "docerbarhetens": "docerbarhet",
    "docerbarhets": "docerbarhet",
    "docerbars": "docerbar",
    "docerbart": "docerbar",
    "docerbarts": "docerbar",
    "doceringar": "docering",
    "doceringarna": "docering",
    "doceringarnas": "docering",
    "doceringars": "docering",
    "doceringen": "docering",
    "doceringens": "docering",
    "docerings": "docering",
    "dock": "docka",
    "dockad": "docka",
    "dockade": "docka",
    "dockades": "docka",
    "dockads": "docka",
    "dockan": "docka",
    "dockande": "docka",
    "dockanden": "dockande",
    "dockandena": "dockande",
    "dockandenas": "dockande",
    "dockandens": "dockande",
    "dockandes": "dockande",
    "dockandet": "dockande",
    "dockandets": "dockande",
    "dockans": "docka",
    "dockansikten": "dockansikte",
    "dockansiktena": "dockansikte",
    "dockansiktenas": "dockansikte",
    "dockansiktens": "dockansikte",
    "dockansiktes": "dockansikte",
    "dockansiktet": "dockansikte",
    "dockansiktets": "dockansikte",
    "dockansikts": "dockansikte",
    "dockar": "docka",
    "dockas": "docka",
    "dockat": "docka",
    "dockats": "docka",
    "docke": "docka",
    "dockkuddar": "dockkudde",
    "dockkuddarna": "dockkudde",
    "dockkuddarnas": "dockkudde",
    "dockkuddars": "dockkudde",
    "dockkudden": "dockkudde",
    "dockkuddens": "dockkudde",
    "dockkuddes": "dockkudde",
    "dockor": "docka",
    "dockorna": "docka",
    "dockornas": "docka",
    "dockors": "docka",
    "dockperuken": "dockperuk",
    "dockperukens": "dockperuk",
    "dockperuker": "dockperuk",
    "dockperukerna": "dockperuk",
    "dockperukernas": "dockperuk",
    "dockperukers": "dockperuk",
    "dockperuks": "dockperuk",
    "docks": "docka",
    "dockskåpen": "dockskåp",
    "dockskåpens": "dockskåp",
    "dockskåpet": "dockskåp",
    "dockskåpets": "dockskåp",
    "dockskåps": "dockskåp",
    "docksöta": "docksöt",
    "docksötare": "docksöt",
    "docksötares": "docksöt",
    "docksötas": "docksöt",
    "docksötast": "docksöt",
    "docksötaste": "docksöt",
    "docksötastes": "docksöt",
    "docksötasts": "docksöt",
    "docksöte": "docksöt",
    "docksötes": "docksöt",
    "docksöts": "docksöt",
    "docksött": "docksöt",
    "docksötts": "docksöt",
    "dockteatern": "dockteater",
    "dockteaterns": "dockteater",
    "dockteaters": "dockteater",
    "dockteatrar": "dockteater",
    "dockteatrarna": "dockteater",
    "dockteatrarnas": "dockteater",
    "dockteatrars": "dockteater",
    "dodekaedern": "dodekaeder",
    "dodekaederns": "dodekaeder",
    "dodekaeders": "dodekaeder",
    "dodekaedrar": "dodekaeder",
    "dodekaedrarna": "dodekaeder",
    "dodekaedrarnas": "dodekaeder",
    "dodekaedrars": "dodekaeder",
    "doft": "dofta",
    "doftade": "dofta",
    "doftades": "dofta",
    "doftande": "dofta",
    "doftanden": "doftande",
    "doftandena": "doftande",
    "doftandenas": "doftande",
    "doftandens": "doftande",
    "doftandes": "doftande",
    "doftandet": "doftande",
    "doftandets": "doftande",
    "doftar": "dofta",
    "doftas": "dofta",
    "doftat": "dofta",
    "doftats": "dofta",
    "doften": "doft",
    "doftens": "doft",
    "dofter": "doft",
    "dofterna": "doft",
    "dofternas": "doft",
    "dofters": "doft",
    "doftet": "doft",
    "doftets": "doft",
    "doftljusen": "doftljus",
    "doftljusens": "doftljus",
    "doftljuset": "doftljus",
    "doftljusets": "doftljus",
    "doftlösa": "doftlös",
    "doftlösare": "doftlös",
    "doftlösares": "doftlös",
    "doftlösas": "doftlös",
    "doftlösast": "doftlös",
    "doftlösaste": "doftlös",
    "doftlösastes": "doftlös",
    "doftlösasts": "doftlös",
    "doftlöse": "doftlös",
    "doftlöses": "doftlös",
    "doftlösheten": "doftlöshet",
    "doftlöshetens": "doftlöshet",
    "doftlöshets": "doftlöshet",
    "doftlöst": "doftlös",
    "doftlösts": "doftlös",
    "doftmarkerad": "doftmarkera",
    "doftmarkerade": "doftmarkera",
    "doftmarkerades": "doftmarkera",
    "doftmarkerads": "doftmarkera",
    "doftmarkerande": "doftmarkera",
    "doftmarkeranden": "doftmarkerande",
    "doftmarkerandena": "doftmarkerande",
    "doftmarkerandenas": "doftmarkerande",
    "doftmarkerandens": "doftmarkerande",
    "doftmarkerandes": "doftmarkerande",
    "doftmarkerandet": "doftmarkerande",
    "doftmarkerandets": "doftmarkerande",
    "doftmarkerar": "doftmarkera",
    "doftmarkeras": "doftmarkera",
    "doftmarkerat": "doftmarkera",
    "doftmarkerats": "doftmarkera",
    "doftmarkerbara": "doftmarkerbar",
    "doftmarkerbarare": "doftmarkerbar",
    "doftmarkerbarares": "doftmarkerbar",
    "doftmarkerbaras": "doftmarkerbar",
    "doftmarkerbarast": "doftmarkerbar",
    "doftmarkerbaraste": "doftmarkerbar",
    "doftmarkerbarastes": "doftmarkerbar",
    "doftmarkerbarasts": "doftmarkerbar",
    "doftmarkerbare": "doftmarkerbar",
    "doftmarkerbares": "doftmarkerbar",
    "doftmarkerbarheten": "doftmarkerbarhet",
    "doftmarkerbarhetens": "doftmarkerbarhet",
    "doftmarkerbarhets": "doftmarkerbarhet",
    "doftmarkerbars": "doftmarkerbar",
    "doftmarkerbart": "doftmarkerbar",
    "doftmarkerbarts": "doftmarkerbar",
    "doftmarkeringar": "doftmarkering",
    "doftmarkeringarna": "doftmarkering",
    "doftmarkeringarnas": "doftmarkering",
    "doftmarkeringars": "doftmarkering",
    "doftmarkeringen": "doftmarkering",
    "doftmarkeringens": "doftmarkering",
    "doftmarkerings": "doftmarkering",
    "dofts": "doft",
    "doftämnen": "doftämne",
    "doftämnena": "doftämne",
    "doftämnenas": "doftämne",
    "doftämnens": "doftämne",
    "doftämnes": "doftämne",
    "doftämnet": "doftämne",
    "doftämnets": "doftämne",
    "dog": "dö",
    "dogcarten": "dogcart",
    "dogcartens": "dogcart",
    "dogcarter": "dogcart",
    "dogcarterna": "dogcart",
    "dogcarternas": "dogcart",
    "dogcarters": "dogcart",
    "dogcarts": "dogcart",
    "doge": "dö",
    "dogen": "doge",
    "dogens": "doge",
    "doger": "doge",
    "dogerna": "doge",
    "dogernas": "doge",
    "dogers": "doge",
    "doges": "doge",
    "doggar": "dogg",
    "doggarna": "dogg",
    "doggarnas": "dogg",
    "doggars": "dogg",
    "doggen": "dogg",
    "doggens": "dogg",
    "doggs": "dogg",
    "dogmatiken": "dogmatik",
    "dogmatikens": "dogmatik",
    "dogmatikern": "dogmatiker",
    "dogmatikerna": "dogmatiker",
    "dogmatikernas": "dogmatiker",
    "dogmatikerns": "dogmatiker",
    "dogmatikers": "dogmatiker",
    "dogmatiks": "dogmatik",
    "dogmatiserad": "dogmatisera",
    "dogmatiserade": "dogmatisera",
    "dogmatiserades": "dogmatisera",
    "dogmatiserads": "dogmatisera",
    "dogmatiserande": "dogmatisera",
    "dogmatiseranden": "dogmatiserande",
    "dogmatiserandena": "dogmatiserande",
    "dogmatiserandenas": "dogmatiserande",
    "dogmatiserandens": "dogmatiserande",
    "dogmatiserandes": "dogmatiserande",
    "dogmatiserandet": "dogmatiserande",
    "dogmatiserandets": "dogmatiserande",
    "dogmatiserar": "dogmatisera",
    "dogmatiseras": "dogmatisera",
    "dogmatiserat": "dogmatisera",
    "dogmatiserats": "dogmatisera",
    "dogmatiserbara": "dogmatiserbar",
    "dogmatiserbarare": "dogmatiserbar",
    "dogmatiserbarares": "dogmatiserbar",
    "dogmatiserbaras": "dogmatiserbar",
    "dogmatiserbarast": "dogmatiserbar",
    "dogmatiserbaraste": "dogmatiserbar",
    "dogmatiserbarastes": "dogmatiserbar",
    "dogmatiserbarasts": "dogmatiserbar",
    "dogmatiserbare": "dogmatiserbar",
    "dogmatiserbares": "dogmatiserbar",
    "dogmatiserbarheten": "dogmatiserbarhet",
    "dogmatiserbarhetens": "dogmatiserbarhet",
    "dogmatiserbarhets": "dogmatiserbarhet",
    "dogmatiserbars": "dogmatiserbar",
    "dogmatiserbart": "dogmatiserbar",
    "dogmatiserbarts": "dogmatiserbar",
    "dogmatiseringar": "dogmatisering",
    "dogmatiseringarna": "dogmatisering",
    "dogmatiseringarnas": "dogmatisering",
    "dogmatiseringars": "dogmatisering",
    "dogmatiseringen": "dogmatisering",
    "dogmatiseringens": "dogmatisering",
    "dogmatiserings": "dogmatisering",
    "dogmatiska": "dogmatisk",
    "dogmatiskare": "dogmatisk",
    "dogmatiskares": "dogmatisk",
    "dogmatiskas": "dogmatisk",
    "dogmatiskast": "dogmatisk",
    "dogmatiskaste": "dogmatisk",
    "dogmatiskastes": "dogmatisk",
    "dogmatiskasts": "dogmatisk",
    "dogmatiske": "dogmatisk",
    "dogmatiskes": "dogmatisk",
    "dogmatisks": "dogmatisk",
    "dogmatiskt": "dogmatisk",
    "dogmatiskts": "dogmatisk",
    "dogmatismen": "dogmatism",
    "dogmatismens": "dogmatism",
    "dogmatismer": "dogmatism",
    "dogmatismerna": "dogmatism",
    "dogmatismernas": "dogmatism",
    "dogmatismers": "dogmatism",
    "dogmatisms": "dogmatism",
    "dogmen": "dogm",
    "dogmens": "dogm",
    "dogmer": "dogm",
    "dogmerna": "dogm",
    "dogmernas": "dogm",
    "dogmers": "dogm",
    "dogms": "dogm",
    "dogs": "dö",
    "doj": "doja",
    "dojan": "doja",
    "dojans": "doja",
    "dojas": "doja",
    "doje": "doja",
    "dojor": "doja",
    "dojorna": "doja",
    "dojornas": "doja",
    "dojors": "doja",
    "dojs": "doja",
    "doken": "dok",
    "dokens": "dok",
    "doket": "dok",
    "dokets": "dok",
    "doks": "dok",
    "doktoranden": "doktorand",
    "doktorandens": "doktorand",
    "doktorander": "doktorand",
    "doktoranderna": "doktorand",
    "doktorandernas": "doktorand",
    "doktoranders": "doktorand",
    "doktorands": "doktorand",
    "doktorer": "doktor",
    "doktorerad": "doktorera",
    "doktorerade": "doktorera",
    "doktorerades": "doktorera",
    "doktorerads": "doktorera",
    "doktorerande": "doktorera",
    "doktoreranden": "doktorerande",
    "doktorerandena": "doktorerande",
    "doktorerandenas": "doktorerande",
    "doktorerandens": "doktorerande",
    "doktorerandes": "doktorerande",
    "doktorerandet": "doktorerande",
    "doktorerandets": "doktorerande",
    "doktorerar": "doktorera",
    "doktoreras": "doktorera",
    "doktorerat": "doktorera",
    "doktorerats": "doktorera",
    "doktoreringar": "doktorering",
    "doktoreringarna": "doktorering",
    "doktoreringarnas": "doktorering",
    "doktoreringars": "doktorering",
    "doktoreringen": "doktorering",
    "doktoreringens": "doktorering",
    "doktorerings": "doktorering",
    "doktorerna": "doktor",
    "doktorernas": "doktor",
    "doktorers": "doktor",
    "doktorn": "doktor",
    "doktorns": "doktor",
    "doktors": "doktor",
    "doktorsavhandlingar": "doktorsavhandling",
    "doktorsavhandlingarna": "doktorsavhandling",
    "doktorsavhandlingarnas": "doktorsavhandling",
    "doktorsavhandlingars": "doktorsavhandling",
    "doktorsavhandlingen": "doktorsavhandling",
    "doktorsavhandlingens": "doktorsavhandling",
    "doktorsavhandlings": "doktorsavhandling",
    "doktorsdisputationen": "doktorsdisputation",
    "doktorsdisputationens": "doktorsdisputation",
    "doktorsdisputationer": "doktorsdisputation",
    "doktorsdisputationerna": "doktorsdisputation",
    "doktorsdisputationernas": "doktorsdisputation",
    "doktorsdisputationers": "doktorsdisputation",
    "doktorsdisputations": "doktorsdisputation",
    "doktorsexamens": "doktorsexamen",
    "doktorsexamina": "doktorsexamen",
    "doktorsexaminas": "doktorsexamen",
    "doktorsgraden": "doktorsgrad",
    "doktorsgradens": "doktorsgrad",
    "doktorsgrader": "doktorsgrad",
    "doktorsgraderna": "doktorsgrad",
    "doktorsgradernas": "doktorsgrad",
    "doktorsgraders": "doktorsgrad",
    "doktorsgrads": "doktorsgrad",
    "doktorshattar": "doktorshatt",
    "doktorshattarna": "doktorshatt",
    "doktorshattarnas": "doktorshatt",
    "doktorshattars": "doktorshatt",
    "doktorshatten": "doktorshatt",
    "doktorshattens": "doktorshatt",
    "doktorshatts": "doktorshatt",
    "doktorskan": "doktorska",
    "doktorskans": "doktorska",
    "doktorskas": "doktorska",
    "doktorske": "doktorska",
    "doktorskor": "doktorska",
    "doktorskorna": "doktorska",
    "doktorskornas": "doktorska",
    "doktorskors": "doktorska",
    "doktorspromotionen": "doktorspromotion",
    "doktorspromotionens": "doktorspromotion",
    "doktorspromotioner": "doktorspromotion",
    "doktorspromotionerna": "doktorspromotion",
    "doktorspromotionernas": "doktorspromotion",
    "doktorspromotioners": "doktorspromotion",
    "doktorspromotions": "doktorspromotion",
    "doktrinarismen": "doktrinarism",
    "doktrinarismens": "doktrinarism",
    "doktrinarismer": "doktrinarism",
    "doktrinarismerna": "doktrinarism",
    "doktrinarismernas": "doktrinarism",
    "doktrinarismers": "doktrinarism",
    "doktrinarisms": "doktrinarism",
    "doktrinen": "doktrin",
    "doktrinens": "doktrin",
    "doktriner": "doktrin",
    "doktrinerna": "doktrin",
    "doktrinernas": "doktrin",
    "doktriners": "doktrin",
    "doktrins": "doktrin",
    "doktrinära": "doktrinär",
    "doktrinärare": "doktrinär",
    "doktrinärares": "doktrinär",
    "doktrinäras": "doktrinär",
    "doktrinärast": "doktrinär",
    "doktrinäraste": "doktrinär",
    "doktrinärastes": "doktrinär",
    "doktrinärasts": "doktrinär",
    "doktrinäre": "doktrinär",
    "doktrinäres": "doktrinär",
    "doktrinärs": "doktrinär",
    "doktrinärt": "doktrinär",
    "doktrinärts": "doktrinär",
    "dokumentalisten": "dokumentalist",
    "dokumentalistens": "dokumentalist",
    "dokumentalister": "dokumentalist",
    "dokumentalisterna": "dokumentalist",
    "dokumentalisternas": "dokumentalist",
    "dokumentalisters": "dokumentalist",
    "dokumentalists": "dokumentalist",
    "dokumentariska": "dokumentarisk",
    "dokumentariskare": "dokumentarisk",
    "dokumentariskares": "dokumentarisk",
    "dokumentariskas": "dokumentarisk",
    "dokumentariskast": "dokumentarisk",
    "dokumentariskaste": "dokumentarisk",
    "dokumentariskastes": "dokumentarisk",
    "dokumentariskasts": "dokumentarisk",
    "dokumentariske": "dokumentarisk",
    "dokumentariskes": "dokumentarisk",
    "dokumentarisks": "dokumentarisk",
    "dokumentariskt": "dokumentarisk",
    "dokumentariskts": "dokumentarisk",
    "dokumentationen": "dokumentation",
    "dokumentationens": "dokumentation",
    "dokumentationer": "dokumentation",
    "dokumentationerna": "dokumentation",
    "dokumentationernas": "dokumentation",
    "dokumentationers": "dokumentation",
    "dokumentations": "dokumentation",
    "dokumenten": "dokument",
    "dokumentens": "dokument",
    "dokumenterad": "dokumentera",
    "dokumenterade": "dokumentera",
    "dokumenterades": "dokumentera",
    "dokumenterads": "dokumentera",
    "dokumenterande": "dokumentera",
    "dokumenteranden": "dokumenterande",
    "dokumenterandena": "dokumenterande",
    "dokumenterandenas": "dokumenterande",
    "dokumenterandens": "dokumenterande",
    "dokumenterandes": "dokumenterande",
    "dokumenterandet": "dokumenterande",
    "dokumenterandets": "dokumenterande",
    "dokumenterar": "dokumentera",
    "dokumenteras": "dokumentera",
    "dokumenterat": "dokumentera",
    "dokumenterats": "dokumentera",
    "dokumenterbara": "dokumenterbar",
    "dokumenterbarare": "dokumenterbar",
    "dokumenterbarares": "dokumenterbar",
    "dokumenterbaras": "dokumenterbar",
    "dokumenterbarast": "dokumenterbar",
    "dokumenterbaraste": "dokumenterbar",
    "dokumenterbarastes": "dokumenterbar",
    "dokumenterbarasts": "dokumenterbar",
    "dokumenterbare": "dokumenterbar",
    "dokumenterbares": "dokumenterbar",
    "dokumenterbarheten": "dokumenterbarhet",
    "dokumenterbarhetens": "dokumenterbarhet",
    "dokumenterbarhets": "dokumenterbarhet",
    "dokumenterbars": "dokumenterbar",
    "dokumenterbart": "dokumenterbar",
    "dokumenterbarts": "dokumenterbar",
    "dokumenteringar": "dokumentering",
    "dokumenteringarna": "dokumentering",
    "dokumenteringarnas": "dokumentering",
    "dokumenteringars": "dokumentering",
    "dokumenteringen": "dokumentering",
    "dokumenteringens": "dokumentering",
    "dokumenterings": "dokumentering",
    "dokumentet": "dokument",
    "dokumentets": "dokument",
    "dokumentkreditiven": "dokumentkreditiv",
    "dokumentkreditivens": "dokumentkreditiv",
    "dokumentkreditivet": "dokumentkreditiv",
    "dokumentkreditivets": "dokumentkreditiv",
    "dokumentkreditivs": "dokumentkreditiv",
    "dokumentpapperet": "dokumentpapper",
    "dokumentpapperets": "dokumentpapper",
    "dokumentpappers": "dokumentpapper",
    "dokumentpappret": "dokumentpapper",
    "dokumentpapprets": "dokumentpapper",
    "dokumentportföljen": "dokumentportfölj",
    "dokumentportföljens": "dokumentportfölj",
    "dokumentportföljer": "dokumentportfölj",
    "dokumentportföljerna": "dokumentportfölj",
    "dokumentportföljernas": "dokumentportfölj",
    "dokumentportföljers": "dokumentportfölj",
    "dokumentportföljs": "dokumentportfölj",
    "dokuments": "dokument",
    "dokumentsamlingar": "dokumentsamling",
    "dokumentsamlingarna": "dokumentsamling",
    "dokumentsamlingarnas": "dokumentsamling",
    "dokumentsamlingars": "dokumentsamling",
    "dokumentsamlingen": "dokumentsamling",
    "dokumentsamlingens": "dokumentsamling",
    "dokumentsamlings": "dokumentsamling",
    "dokumentskåpen": "dokumentskåp",
    "dokumentskåpens": "dokumentskåp",
    "dokumentskåpet": "dokumentskåp",
    "dokumentskåpets": "dokumentskåp",
    "dokumentskåps": "dokumentskåp",
    "dokumentära": "dokumentär",
    "dokumentärare": "dokumentär",
    "dokumentärares": "dokumentär",
    "dokumentäras": "dokumentär",
    "dokumentärast": "dokumentär",
    "dokumentäraste": "dokumentär",
    "dokumentärastes": "dokumentär",
    "dokumentärasts": "dokumentär",
    "dokumentäre": "dokumentär",
    "dokumentären": "dokumentär",
    "dokumentärens": "dokumentär",
    "dokumentärer": "dokumentär",
    "dokumentärerna": "dokumentär",
    "dokumentärernas": "dokumentär",
    "dokumentärers": "dokumentär",
    "dokumentäres": "dokumentär",
    "dokumentärfilmen": "dokumentärfilm",
    "dokumentärfilmens": "dokumentärfilm",
    "dokumentärfilmer": "dokumentärfilm",
    "dokumentärfilmerna": "dokumentärfilm",
    "dokumentärfilmernas": "dokumentärfilm",
    "dokumentärfilmers": "dokumentärfilm",
    "dokumentärfilms": "dokumentärfilm",
    "dokumentärprogrammen": "dokumentärprogram",
    "dokumentärprogrammens": "dokumentärprogram",
    "dokumentärprogrammet": "dokumentärprogram",
    "dokumentärprogrammets": "dokumentärprogram",
    "dokumentärprograms": "dokumentärprogram",
    "dokumentärromanen": "dokumentärroman",
    "dokumentärromanens": "dokumentärroman",
    "dokumentärromaner": "dokumentärroman",
    "dokumentärromanerna": "dokumentärroman",
    "dokumentärromanernas": "dokumentärroman",
    "dokumentärromaners": "dokumentärroman",
    "dokumentärromans": "dokumentärroman",
    "dokumentärs": "dokumentär",
    "dokumentärt": "dokumentär",
    "dokumentärts": "dokumentär",
    "dokusåpakändisar": "dokusåpakändis",
    "dokusåpakändisarna": "dokusåpakändis",
    "dokusåpakändisarnas": "dokusåpakändis",
    "dokusåpakändisars": "dokusåpakändis",
    "dokusåpakändisen": "dokusåpakändis",
    "dokusåpakändisens": "dokusåpakändis",
    "dokusåpan": "dokusåpa",
    "dokusåpans": "dokusåpa",
    "dokusåpas": "dokusåpa",
    "dokusåpor": "dokusåpa",
    "dokusåporna": "dokusåpa",
    "dokusåpornas": "dokusåpa",
    "dokusåpors": "dokusåpa",
    "dold": "dölja",
    "dolda": "dölja",
    "doldare": "dold",
    "doldares": "dold",
    "doldas": "dölja",
    "doldast": "dold",
    "doldaste": "dold",
    "doldastes": "dold",
    "doldasts": "dold",
    "dolde": "dölja",
    "doldes": "dölja",
    "doldheten": "doldhet",
    "doldhetens": "doldhet",
    "doldhets": "doldhet",
    "doldisar": "doldis",
    "doldisarna": "doldis",
    "doldisarnas": "doldis",
    "doldisars": "doldis",
    "doldisen": "doldis",
    "doldisens": "doldis",
    "dolds": "dölja",
    "dolikocefala": "dolikocefal",
    "dolikocefalare": "dolikocefal",
    "dolikocefalares": "dolikocefal",
    "dolikocefalas": "dolikocefal",
    "dolikocefalast": "dolikocefal",
    "dolikocefalaste": "dolikocefal",
    "dolikocefalastes": "dolikocefal",
    "dolikocefalasts": "dolikocefal",
    "dolikocefale": "dolikocefal",
    "dolikocefalen": "dolikocefal",
    "dolikocefalens": "dolikocefal",
    "dolikocefaler": "dolikocefal",
    "dolikocefalerna": "dolikocefal",
    "dolikocefalernas": "dolikocefal",
    "dolikocefalers": "dolikocefal",
    "dolikocefales": "dolikocefal",
    "dolikocefalien": "dolikocefali",
    "dolikocefaliens": "dolikocefali",
    "dolikocefalier": "dolikocefali",
    "dolikocefalierna": "dolikocefali",
    "dolikocefaliernas": "dolikocefali",
    "dolikocefaliers": "dolikocefali",
    "dolikocefalin": "dolikocefali",
    "dolikocefalins": "dolikocefali",
    "dolikocefalis": "dolikocefali",
    "dolikocefals": "dolikocefal",
    "dolikocefalt": "dolikocefal",
    "dolikocefalts": "dolikocefal",
    "dolkar": "dolk",
    "dolkarna": "dolk",
    "dolkarnas": "dolk",
    "dolkars": "dolk",
    "dolken": "dolk",
    "dolkens": "dolk",
    "dolks": "dolk",
    "dolkstötar": "dolkstöt",
    "dolkstötarna": "dolkstöt",
    "dolkstötarnas": "dolkstöt",
    "dolkstötars": "dolkstöt",
    "dolkstöten": "dolkstöt",
    "dolkstötens": "dolkstöt",
    "dolkstöts": "dolkstöt",
    "dolkstötslegenden": "dolkstötslegend",
    "dolkstötslegendens": "dolkstötslegend",
    "dolkstötslegender": "dolkstötslegend",
    "dolkstötslegenderna": "dolkstötslegend",
    "dolkstötslegendernas": "dolkstötslegend",
    "dolkstötslegenders": "dolkstötslegend",
    "dolkstötslegends": "dolkstötslegend",
    "dollardiplomatien": "dollardiplomati",
    "dollardiplomatiens": "dollardiplomati",
    "dollardiplomatin": "dollardiplomati",
    "dollardiplomatins": "dollardiplomati",
    "dollardiplomatis": "dollardiplomati",
    "dollargrinen": "dollargrin",
    "dollargrinens": "dollargrin",
    "dollargrinet": "dollargrin",
    "dollargrinets": "dollargrin",
    "dollargrins": "dollargrin",
    "dollarn": "dollar",
    "dollarna": "dollar",
    "dollarnas": "dollar",
    "dollarns": "dollar",
    "dollarprinsess": "dollarprinsessa",
    "dollarprinsessan": "dollarprinsessa",
    "dollarprinsessans": "dollarprinsessa",
    "dollarprinsessas": "dollarprinsessa",
    "dollarprinsesse": "dollarprinsessa",
    "dollarprinsessor": "dollarprinsessa",
    "dollarprinsessorna": "dollarprinsessa",
    "dollarprinsessornas": "dollarprinsessa",
    "dollarprinsessors": "dollarprinsessa",
    "dollars": "dollar",
    "dollarturisten": "dollarturist",
    "dollarturistens": "dollarturist",
    "dollarturister": "dollarturist",
    "dollarturisterna": "dollarturist",
    "dollarturisternas": "dollarturist",
    "dollarturisters": "dollarturist",
    "dollarturists": "dollarturist",
    "dolman": "dolma",
    "dolmans": "dolma",
    "dolmar": "dolma",
    "dolmarna": "dolma",
    "dolmarnas": "dolma",
    "dolmars": "dolma",
    "dolmas": "dolma",
    "dolmor": "dolma",
    "dolmorna": "dolma",
    "dolmornas": "dolma",
    "dolmors": "dolma",
    "dolomiten": "dolomit",
    "dolomitens": "dolomit",
    "dolomiter": "dolomit",
    "dolomiterna": "dolomit",
    "dolomiternas": "dolomit",
    "dolomiters": "dolomit",
    "dolomits": "dolomit",
    "dolska": "dolsk",
    "dolskare": "dolsk",
    "dolskares": "dolsk",
    "dolskas": "dolsk",
    "dolskast": "dolsk",
    "dolskaste": "dolsk",
    "dolskastes": "dolsk",
    "dolskasts": "dolsk",
    "dolske": "dolsk",
    "dolskes": "dolsk",
    "dolskheten": "dolskhet",
    "dolskhetens": "dolskhet",
    "dolskhets": "dolskhet",
    "dolsks": "dolsk",
    "dolskt": "dolsk",
    "dolskts": "dolsk",
    "dolt": "dölja",
    "dolts": "dölja",
    "dom": "en",
    "domar": "domare",
    "domaredansen": "domaredans",
    "domaredansens": "domaredans",
    "domaredanser": "domaredans",
    "domaredanserna": "domaredans",
    "domaredansernas": "domaredans",
    "domaredansers": "domaredans",
    "domareden": "domared",
    "domaredens": "domared",
    "domareder": "domared",
    "domarederna": "domared",
    "domaredernas": "domared",
    "domareders": "domared",
    "domareds": "domared",
    "domaren": "domare",
    "domarens": "domare",
    "domares": "domare",
    "domarna": "domare",
    "domarnas": "domare",
    "domarposten": "domarpost",
    "domarpostens": "domarpost",
    "domarposter": "domarpost",
    "domarposterna": "domarpost",
    "domarposternas": "domarpost",
    "domarposters": "domarpost",
    "domarposts": "domarpost",
    "domarringar": "domarring",
    "domarringarna": "domarring",
    "domarringarnas": "domarring",
    "domarringars": "domarring",
    "domarringen": "domarring",
    "domarringens": "domarring",
    "domarrings": "domarring",
    "domars": "dom",
    "domboken": "dombok",
    "dombokens": "dombok",
    "domboks": "dombok",
    "domböcker": "dombok",
    "domböckerna": "dombok",
    "domböckernas": "dombok",
    "domböckers": "dombok",
    "domderade": "domdera",
    "domderades": "domdera",
    "domderande": "domdera",
    "domderanden": "domderande",
    "domderandena": "domderande",
    "domderandenas": "domderande",
    "domderandens": "domderande",
    "domderandes": "domderande",
    "domderandet": "domderande",
    "domderandets": "domderande",
    "domderar": "domdera",
    "domderas": "domdera",
    "domderat": "domdera",
    "domderats": "domdera",
    "domderingar": "domdering",
    "domderingarna": "domdering",
    "domderingarnas": "domdering",
    "domderingars": "domdering",
    "domderingen": "domdering",
    "domderingens": "domdering",
    "domderings": "domdering",
    "domedagen": "domedag",
    "domedagens": "domedag",
    "domedags": "domedag",
    "domedagspredikans": "domedagspredikan",
    "domedagspredikanten": "domedagspredikant",
    "domedagspredikantens": "domedagspredikant",
    "domedagspredikanter": "domedagspredikant",
    "domedagspredikanterna": "domedagspredikant",
    "domedagspredikanternas": "domedagspredikant",
    "domedagspredikanters": "domedagspredikant",
    "domedagspredikants": "domedagspredikant",
    "domedagspredikningar": "domedagspredikning",
    "domedagspredikningarna": "domedagspredikning",
    "domedagspredikningarnas": "domedagspredikning",
    "domedagspredikningars": "domedagspredikning",
    "domedagspredikningen": "domedagspredikning",
    "domedagspredikningens": "domedagspredikning",
    "domedagsprediknings": "domedagspredikning",
    "domedagsprofeten": "domedagsprofet",
    "domedagsprofetens": "domedagsprofet",
    "domedagsprofeter": "domedagsprofet",
    "domedagsprofeterna": "domedagsprofet",
    "domedagsprofeternas": "domedagsprofet",
    "domedagsprofeters": "domedagsprofet",
    "domedagsprofets": "domedagsprofet",
    "domedagsvapens": "domedagsvapen",
    "domedagsvapnen": "domedagsvapen",
    "domedagsvapnens": "domedagsvapen",
    "domedagsvapnet": "domedagsvapen",
    "domedagsvapnets": "domedagsvapen",
    "domen": "dom",
    "domens": "dom",
    "domer": "dom",
    "domerna": "dom",
    "domernas": "dom",
    "domers": "dom",
    "domesticerad": "domesticera",
    "domesticerade": "domesticera",
    "domesticerades": "domesticera",
    "domesticerads": "domesticera",
    "domesticerande": "domesticera",
    "domesticeranden": "domesticerande",
    "domesticerandena": "domesticerande",
    "domesticerandenas": "domesticerande",
    "domesticerandens": "domesticerande",
    "domesticerandes": "domesticerande",
    "domesticerandet": "domesticerande",
    "domesticerandets": "domesticerande",
    "domesticerar": "domesticera",
    "domesticeras": "domesticera",
    "domesticerat": "domesticera",
    "domesticerats": "domesticera",
    "domesticerbara": "domesticerbar",
    "domesticerbarare": "domesticerbar",
    "domesticerbarares": "domesticerbar",
    "domesticerbaras": "domesticerbar",
    "domesticerbarast": "domesticerbar",
    "domesticerbaraste": "domesticerbar",
    "domesticerbarastes": "domesticerbar",
    "domesticerbarasts": "domesticerbar",
    "domesticerbare": "domesticerbar",
    "domesticerbares": "domesticerbar",
    "domesticerbarheten": "domesticerbarhet",
    "domesticerbarhetens": "domesticerbarhet",
    "domesticerbarhets": "domesticerbarhet",
    "domesticerbars": "domesticerbar",
    "domesticerbart": "domesticerbar",
    "domesticerbarts": "domesticerbar",
    "domesticeringar": "domesticering",
    "domesticeringarna": "domesticering",
    "domesticeringarnas": "domesticering",
    "domesticeringars": "domesticering",
    "domesticeringen": "domesticering",
    "domesticeringens": "domesticering",
    "domesticerings": "domesticering",
    "domestiken": "domestik",
    "domestikens": "domestik",
    "domestiker": "domestik",
    "domestikerna": "domestik",
    "domestikernas": "domestik",
    "domestikers": "domestik",
    "domestiks": "domestik",
    "domfäll": "domfälla",
    "domfällande": "domfälla",
    "domfällanden": "domfällande",
    "domfällandena": "domfällande",
    "domfällandenas": "domfällande",
    "domfällandens": "domfällande",
    "domfällandes": "domfällande",
    "domfällandet": "domfällande",
    "domfällandets": "domfällande",
    "domfällas": "domfälla",
    "domfälld": "domfälla",
    "domfällda": "domfälla",
    "domfälldas": "domfälla",
    "domfällde": "domfälla",
    "domfälldes": "domfälla",
    "domfällds": "domfälla",
    "domfäller": "domfälla",
    "domfälles": "domfälla",
    "domfälls": "domfälla",
    "domfällt": "domfälla",
    "domfällts": "domfälla",
    "domföra": "domför",
    "domförare": "domför",
    "domförares": "domför",
    "domföras": "domför",
    "domförast": "domför",
    "domföraste": "domför",
    "domförastes": "domför",
    "domförasts": "domför",
    "domföre": "domför",
    "domföres": "domför",
    "domförs": "domför",
    "domfört": "domför",
    "domförts": "domför",
    "domherr": "domherre",
    "domherrar": "domherre",
    "domherrarna": "domherre",
    "domherrarnas": "domherre",
    "domherrars": "domherre",
    "domherren": "domherre",
    "domherrens": "domherre",
    "domherres": "domherre",
    "domherrs": "domherre",
    "domicilen": "domicil",
    "domicilens": "domicil",
    "domicilet": "domicil",
    "domicilets": "domicil",
    "domicilierad": "domiciliera",
    "domicilierade": "domiciliera",
    "domicilierades": "domiciliera",
    "domicilierads": "domiciliera",
    "domicilierande": "domiciliera",
    "domicilieranden": "domicilierande",
    "domicilierandena": "domicilierande",
    "domicilierandenas": "domicilierande",
    "domicilierandens": "domicilierande",
    "domicilierandes": "domicilierande",
    "domicilierandet": "domicilierande",
    "domicilierandets": "domicilierande",
    "domicilierar": "domiciliera",
    "domicilieras": "domiciliera",
    "domicilierat": "domiciliera",
    "domicilierats": "domiciliera",
    "domicilierbara": "domicilierbar",
    "domicilierbarare": "domicilierbar",
    "domicilierbarares": "domicilierbar",
    "domicilierbaras": "domicilierbar",
    "domicilierbarast": "domicilierbar",
    "domicilierbaraste": "domicilierbar",
    "domicilierbarastes": "domicilierbar",
    "domicilierbarasts": "domicilierbar",
    "domicilierbare": "domicilierbar",
    "domicilierbares": "domicilierbar",
    "domicilierbarheten": "domicilierbarhet",
    "domicilierbarhetens": "domicilierbarhet",
    "domicilierbarhets": "domicilierbarhet",
    "domicilierbars": "domicilierbar",
    "domicilierbart": "domicilierbar",
    "domicilierbarts": "domicilierbar",
    "domicilieringar": "domiciliering",
    "domicilieringarna": "domiciliering",
    "domicilieringarnas": "domiciliering",
    "domicilieringars": "domiciliering",
    "domicilieringen": "domiciliering",
    "domicilieringens": "domiciliering",
    "domicilierings": "domiciliering",
    "domicils": "domicil",
    "dominansen": "dominans",
    "dominansens": "dominans",
    "dominanta": "dominant",
    "dominantare": "dominant",
    "dominantares": "dominant",
    "dominantas": "dominant",
    "dominantast": "dominant",
    "dominantaste": "dominant",
    "dominantastes": "dominant",
    "dominantasts": "dominant",
    "dominante": "dominant",
    "dominanten": "dominant",
    "dominantens": "dominant",
    "dominanter": "dominant",
    "dominanterna": "dominant",
    "dominanternas": "dominant",
    "dominanters": "dominant",
    "dominantes": "dominant",
    "dominants": "dominant",
    "dominerad": "dominera",
    "dominerade": "dominera",
    "dominerades": "dominera",
    "dominerads": "dominera",
    "dominerande": "dominera",
    "domineranden": "dominerande",
    "dominerandena": "dominerande",
    "dominerandenas": "dominerande",
    "dominerandens": "dominerande",
    "dominerandes": "dominerande",
    "dominerandet": "dominerande",
    "dominerandets": "dominerande",
    "dominerar": "dominera",
    "domineras": "dominera",
    "dominerat": "dominera",
    "dominerats": "dominera",
    "dominerbara": "dominerbar",
    "dominerbarare": "dominerbar",
    "dominerbarares": "dominerbar",
    "dominerbaras": "dominerbar",
    "dominerbarast": "dominerbar",
    "dominerbaraste": "dominerbar",
    "dominerbarastes": "dominerbar",
    "dominerbarasts": "dominerbar",
    "dominerbare": "dominerbar",
    "dominerbares": "dominerbar",
    "dominerbarheten": "dominerbarhet",
    "dominerbarhetens": "dominerbarhet",
    "dominerbarhets": "dominerbarhet",
    "dominerbars": "dominerbar",
    "dominerbart": "dominerbar",
    "dominerbarts": "dominerbar",
    "domineringar": "dominering",
    "domineringarna": "dominering",
    "domineringarnas": "dominering",
    "domineringars": "dominering",
    "domineringen": "dominering",
    "domineringens": "dominering",
    "dominerings": "dominering",
    "dominier": "dominion",
    "dominierna": "dominion",
    "dominiernas": "dominion",
    "dominiers": "dominion",
    "dominikanen": "dominikan",
    "dominikanens": "dominikan",
    "dominikaner": "dominikan",
    "dominikanermunkar": "dominikanermunk",
    "dominikanermunkarna": "dominikanermunk",
    "dominikanermunkarnas": "dominikanermunk",
    "dominikanermunkars": "dominikanermunk",
    "dominikanermunken": "dominikanermunk",
    "dominikanermunkens": "dominikanermunk",
    "dominikanermunks": "dominikanermunk",
    "dominikanerna": "dominikan",
    "dominikanernas": "dominikan",
    "dominikanerordens": "dominikanerorden",
    "dominikanerordnar": "dominikanerorden",
    "dominikanerordnarna": "dominikanerorden",
    "dominikanerordnarnas": "dominikanerorden",
    "dominikanerordnars": "dominikanerorden",
    "dominikanerordnen": "dominikanerorden",
    "dominikanerordnens": "dominikanerorden",
    "dominikaners": "dominikan",
    "dominikanmunkar": "dominikanmunk",
    "dominikanmunkarna": "dominikanmunk",
    "dominikanmunkarnas": "dominikanmunk",
    "dominikanmunkars": "dominikanmunk",
    "dominikanmunken": "dominikanmunk",
    "dominikanmunkens": "dominikanmunk",
    "dominikanmunks": "dominikanmunk",
    "dominikanordens": "dominikanorden",
    "dominikanordnar": "dominikanorden",
    "dominikanordnarna": "dominikanorden",
    "dominikanordnarnas": "dominikanorden",
    "dominikanordnars": "dominikanorden",
    "dominikanordnen": "dominikanorden",
    "dominikanordnens": "dominikanorden",
    "dominikans": "dominikan",
    "dominikanska": "dominikansk",
    "dominikanskan": "dominikanska",
    "dominikanskans": "dominikanska",
    "dominikanskare": "dominikansk",
    "dominikanskares": "dominikansk",
    "dominikanskas": "dominikanska",
    "dominikanskast": "dominikansk",
    "dominikanskaste": "dominikansk",
    "dominikanskastes": "dominikansk",
    "dominikanskasts": "dominikansk",
    "dominikanske": "dominikanska",
    "dominikanskes": "dominikansk",
    "dominikanskor": "dominikanska",
    "dominikanskorna": "dominikanska",
    "dominikanskornas": "dominikanska",
    "dominikanskors": "dominikanska",
    "dominikansks": "dominikansk",
    "dominikanskt": "dominikansk",
    "dominikanskts": "dominikansk",
    "dominikern": "dominiker",
    "dominikerna": "dominiker",
    "dominikernas": "dominiker",
    "dominikerns": "dominiker",
    "dominikers": "dominiker",
    "dominikiska": "dominikisk",
    "dominikiskan": "dominikiska",
    "dominikiskans": "dominikiska",
    "dominikiskare": "dominikisk",
    "dominikiskares": "dominikisk",
    "dominikiskas": "dominikiska",
    "dominikiskast": "dominikisk",
    "dominikiskaste": "dominikisk",
    "dominikiskastes": "dominikisk",
    "dominikiskasts": "dominikisk",
    "dominikiske": "dominikiska",
    "dominikiskes": "dominikisk",
    "dominikiskor": "dominikiska",
    "dominikiskorna": "dominikiska",
    "dominikiskornas": "dominikiska",
    "dominikiskors": "dominikiska",
    "dominikisks": "dominikisk",
    "dominikiskt": "dominikisk",
    "dominikiskts": "dominikisk",
    "dominions": "dominion",
    "dominobrick": "dominobricka",
    "dominobrickan": "dominobricka",
    "dominobrickans": "dominobricka",
    "dominobrickas": "dominobricka",
    "dominobricke": "dominobricka",
    "dominobrickor": "dominobricka",
    "dominobrickorna": "dominobricka",
    "dominobrickornas": "dominobricka",
    "dominobrickors": "dominobricka",
    "dominobricks": "dominobricka",
    "dominon": "domino",
    "dominons": "domino",
    "dominor": "domino",
    "dominorna": "domino",
    "dominornas": "domino",
    "dominors": "domino",
    "dominos": "domino",
    "dominot": "domino",
    "dominoteorien": "dominoteori",
    "dominoteoriens": "dominoteori",
    "dominoteorier": "dominoteori",
    "dominoteorierna": "dominoteori",
    "dominoteoriernas": "dominoteori",
    "dominoteoriers": "dominoteori",
    "dominoteorin": "dominoteori",
    "dominoteorins": "dominoteori",
    "dominoteoris": "dominoteori",
    "dominots": "domino",
    "domkapitels": "domkapitel",
    "domkapitlen": "domkapitel",
    "domkapitlens": "domkapitel",
    "domkapitlet": "domkapitel",
    "domkapitlets": "domkapitel",
    "domkraften": "domkraft",
    "domkraftens": "domkraft",
    "domkrafter": "domkraft",
    "domkrafterna": "domkraft",
    "domkrafternas": "domkraft",
    "domkrafters": "domkraft",
    "domkrafts": "domkraft",
    "domkraftsoljan": "domkraftsolja",
    "domkraftsoljans": "domkraftsolja",
    "domkraftsoljas": "domkraftsolja",
    "domkraftsolje": "domkraftsolja",
    "domkraftsoljor": "domkraftsolja",
    "domkraftsoljorna": "domkraftsolja",
    "domkraftsoljornas": "domkraftsolja",
    "domkraftsoljors": "domkraftsolja",
    "domkvalen": "domkval",
    "domkvalens": "domkval",
    "domkvalet": "domkval",
    "domkvalets": "domkval",
    "domkvals": "domkval",
    "domkyrk": "domkyrka",
    "domkyrkan": "domkyrka",
    "domkyrkans": "domkyrka",
    "domkyrkas": "domkyrka",
    "domkyrke": "domkyrka",
    "domkyrko": "domkyrka",
    "domkyrkor": "domkyrka",
    "domkyrkorna": "domkyrka",
    "domkyrkornas": "domkyrka",
    "domkyrkors": "domkyrka",
    "domkyrks": "domkyrka",
    "domn": "domna",
    "domnad": "domna",
    "domnade": "domna",
    "domnades": "domna",
    "domnads": "domna",
    "domnande": "domna",
    "domnanden": "domnande",
    "domnandena": "domnande",
    "domnandenas": "domnande",
    "domnandens": "domnande",
    "domnandes": "domnande",
    "domnandet": "domnande",
    "domnandets": "domnande",
    "domnar": "domna",
    "domnas": "domna",
    "domnat": "domna",
    "domnats": "domna",
    "domprostar": "domprost",
    "domprostarna": "domprost",
    "domprostarnas": "domprost",
    "domprostars": "domprost",
    "domprosten": "domprost",
    "domprostens": "domprost",
    "domprosts": "domprost",
    "dompterad": "domptera",
    "dompterade": "domptera",
    "dompterades": "domptera",
    "dompterads": "domptera",
    "dompterande": "domptera",
    "dompteranden": "dompterande",
    "dompterandena": "dompterande",
    "dompterandenas": "dompterande",
    "dompterandens": "dompterande",
    "dompterandes": "dompterande",
    "dompterandet": "dompterande",
    "dompterandets": "dompterande",
    "dompterar": "domptera",
    "dompteras": "domptera",
    "dompterat": "domptera",
    "dompterats": "domptera",
    "dompterbara": "dompterbar",
    "dompterbarare": "dompterbar",
    "dompterbarares": "dompterbar",
    "dompterbaras": "dompterbar",
    "dompterbarast": "dompterbar",
    "dompterbaraste": "dompterbar",
    "dompterbarastes": "dompterbar",
    "dompterbarasts": "dompterbar",
    "dompterbare": "dompterbar",
    "dompterbares": "dompterbar",
    "dompterbarheten": "dompterbarhet",
    "dompterbarhetens": "dompterbarhet",
    "dompterbarhets": "dompterbarhet",
    "dompterbars": "dompterbar",
    "dompterbart": "dompterbar",
    "dompterbarts": "dompterbar",
    "dompteringar": "domptering",
    "dompteringarna": "domptering",
    "dompteringarnas": "domptering",
    "dompteringars": "domptering",
    "dompteringen": "domptering",
    "dompteringens": "domptering",
    "dompterings": "domptering",
    "domptören": "domptör",
    "domptörens": "domptör",
    "domptörer": "domptör",
    "domptörerna": "domptör",
    "domptörernas": "domptör",
    "domptörers": "domptör",
    "domptörs": "domptör",
    "doms": "dom",
    "domsagan": "domsaga",
    "domsagans": "domsaga",
    "domsagas": "domsaga",
    "domsage": "domsaga",
    "domsago": "domsaga",
    "domsagor": "domsaga",
    "domsagorna": "domsaga",
    "domsagornas": "domsaga",
    "domsagors": "domsaga",
    "domskälen": "domskäl",
    "domskälens": "domskäl",
    "domskälet": "domskäl",
    "domskälets": "domskäl",
    "domskäls": "domskäl",
    "domsluten": "domslut",
    "domslutens": "domslut",
    "domslutet": "domslut",
    "domslutets": "domslut",
    "domsluts": "domslut",
    "domsrätten": "domsrätt",
    "domsrättens": "domsrätt",
    "domsrätts": "domsrätt",
    "domssöndagar": "domssöndag",
    "domssöndagarna": "domssöndag",
    "domssöndagarnas": "domssöndag",
    "domssöndagars": "domssöndag",
    "domssöndagen": "domssöndag",
    "domssöndagens": "domssöndag",
    "domssöndags": "domssöndag",
    "domstolar": "domstol",
    "domstolarna": "domstol",
    "domstolarnas": "domstol",
    "domstolars": "domstol",
    "domstolen": "domstol",
    "domstolens": "domstol",
    "domstols": "domstol",
    "domstolsbesluten": "domstolsbeslut",
    "domstolsbeslutens": "domstolsbeslut",
    "domstolsbeslutet": "domstolsbeslut",
    "domstolsbeslutets": "domstolsbeslut",
    "domstolsbesluts": "domstolsbeslut",
    "domstolsbetjänten": "domstolsbetjänt",
    "domstolsbetjäntens": "domstolsbetjänt",
    "domstolsbetjänter": "domstolsbetjänt",
    "domstolsbetjänterna": "domstolsbetjänt",
    "domstolsbetjänternas": "domstolsbetjänt",
    "domstolsbetjänters": "domstolsbetjänt",
    "domstolsbetjänts": "domstolsbetjänt",
    "domstolsförhandlingar": "domstolsförhandling",
    "domstolsförhandlingarna": "domstolsförhandling",
    "domstolsförhandlingarnas": "domstolsförhandling",
    "domstolsförhandlingars": "domstolsförhandling",
    "domstolsförhandlingen": "domstolsförhandling",
    "domstolsförhandlingens": "domstolsförhandling",
    "domstolsförhandlings": "domstolsförhandling",
    "domstolsmässiga": "domstolsmässig",
    "domstolsmässigare": "domstolsmässig",
    "domstolsmässigares": "domstolsmässig",
    "domstolsmässigas": "domstolsmässig",
    "domstolsmässigast": "domstolsmässig",
    "domstolsmässigaste": "domstolsmässig",
    "domstolsmässigastes": "domstolsmässig",
    "domstolsmässigasts": "domstolsmässig",
    "domstolsmässige": "domstolsmässig",
    "domstolsmässiges": "domstolsmässig",
    "domstolsmässigs": "domstolsmässig",
    "domstolsmässigt": "domstolsmässig",
    "domstolsmässigts": "domstolsmässig",
    "domstolsmålen": "domstolsmål",
    "domstolsmålens": "domstolsmål",
    "domstolsmålet": "domstolsmål",
    "domstolsmålets": "domstolsmål",
    "domstolsmåls": "domstolsmål",
    "domstolsprotokollen": "domstolsprotokoll",
    "domstolsprotokollens": "domstolsprotokoll",
    "domstolsprotokollet": "domstolsprotokoll",
    "domstolsprotokollets": "domstolsprotokoll",
    "domstolsprotokolls": "domstolsprotokoll",
    "domstolsverken": "domstolsverk",
    "domstolsverkens": "domstolsverk",
    "domstolsverket": "domstolsverk",
    "domstolsverkets": "domstolsverk",
    "domstolsverks": "domstolsverk",
    "domsöndagar": "domsöndag",
    "domsöndagarna": "domsöndag",
    "domsöndagarnas": "domsöndag",
    "domsöndagars": "domsöndag",
    "domsöndagen": "domsöndag",
    "domsöndagens": "domsöndag",
    "domsöndags": "domsöndag",
    "domvill": "domvilla",
    "domvillan": "domvilla",
    "domvillans": "domvilla",
    "domvillas": "domvilla",
    "domville": "domvilla",
    "domvillor": "domvilla",
    "domvillorna": "domvilla",
    "domvillornas": "domvilla",
    "domvillors": "domvilla",
    "domvills": "domvilla",
    "domvärjos": "domvärjo",
    "domänen": "domän",
    "domänens": "domän",
    "domäner": "domän",
    "domänerna": "domän",
    "domänernas": "domän",
    "domäners": "domän",
    "domäns": "domän",
    "domänverken": "domänverk",
    "domänverkens": "domänverk",
    "domänverket": "domänverk",
    "domänverkets": "domänverk",
    "domänverks": "domänverk",
    "don": "dona",
    "donade": "dona",
    "donades": "dona",
    "donan": "dona",
    "donande": "dona",
    "donanden": "donande",
    "donandena": "donande",
    "donandenas": "donande",
    "donandens": "donande",
    "donandes": "donande",
    "donandet": "donande",
    "donandets": "donande",
    "donans": "dona",
    "donar": "dona",
    "donas": "dona",
    "donat": "dona",
    "donationen": "donation",
    "donationens": "donation",
    "donationer": "donation",
    "donationerna": "donation",
    "donationernas": "donation",
    "donationers": "donation",
    "donations": "donation",
    "donationsbreven": "donationsbrev",
    "donationsbrevens": "donationsbrev",
    "donationsbrevet": "donationsbrev",
    "donationsbrevets": "donationsbrev",
    "donationsbrevs": "donationsbrev",
    "donatorer": "donator",
    "donatorerna": "donator",
    "donatorernas": "donator",
    "donatorers": "donator",
    "donatorn": "donator",
    "donatorns": "donator",
    "donators": "donator",
    "donats": "dona",
    "done": "dona",
    "donen": "don",
    "donens": "don",
    "donerad": "donera",
    "donerade": "donera",
    "donerades": "donera",
    "donerads": "donera",
    "donerande": "donera",
    "doneranden": "donerande",
    "donerandena": "donerande",
    "donerandenas": "donerande",
    "donerandens": "donerande",
    "donerandes": "donerande",
    "donerandet": "donerande",
    "donerandets": "donerande",
    "donerar": "donera",
    "doneras": "donera",
    "donerat": "donera",
    "donerats": "donera",
    "donerbara": "donerbar",
    "donerbarare": "donerbar",
    "donerbarares": "donerbar",
    "donerbaras": "donerbar",
    "donerbarast": "donerbar",
    "donerbaraste": "donerbar",
    "donerbarastes": "donerbar",
    "donerbarasts": "donerbar",
    "donerbare": "donerbar",
    "donerbares": "donerbar",
    "donerbarheten": "donerbarhet",
    "donerbarhetens": "donerbarhet",
    "donerbarhets": "donerbarhet",
    "donerbars": "donerbar",
    "donerbart": "donerbar",
    "donerbarts": "donerbar",
    "doneringar": "donering",
    "doneringarna": "donering",
    "doneringarnas": "donering",
    "doneringars": "donering",
    "doneringen": "donering",
    "doneringens": "donering",
    "donerings": "donering",
    "donet": "don",
    "donets": "don",
    "doningar": "doning",
    "doningarna": "doning",
    "doningarnas": "doning",
    "doningars": "doning",
    "doningen": "doning",
    "doningens": "doning",
    "donings": "doning",
    "donjuaner": "donjuan",
    "donjuanerna": "donjuan",
    "donjuanernas": "donjuan",
    "donjuaners": "donjuan",
    "donjuans": "donjuan",
    "donk": "donka",
    "donkad": "donka",
    "donkade": "donka",
    "donkades": "donka",
    "donkads": "donka",
    "donkande": "donka",
    "donkanden": "donkande",
    "donkandena": "donkande",
    "donkandenas": "donkande",
    "donkandens": "donkande",
    "donkandes": "donkande",
    "donkandet": "donkande",
    "donkandets": "donkande",
    "donkar": "donka",
    "donkas": "donka",
    "donkat": "donka",
    "donkats": "donka",
    "donket": "donk",
    "donkets": "donk",
    "donkeypann": "donkeypanna",
    "donkeypannan": "donkeypanna",
    "donkeypannans": "donkeypanna",
    "donkeypannas": "donkeypanna",
    "donkeypanne": "donkeypanna",
    "donkeypannor": "donkeypanna",
    "donkeypannorna": "donkeypanna",
    "donkeypannornas": "donkeypanna",
    "donkeypannors": "donkeypanna",
    "donkeypanns": "donkeypanna",
    "donks": "donk",
    "donlägen": "donläge",
    "donlägena": "donläge",
    "donlägenas": "donläge",
    "donlägens": "donläge",
    "donläges": "donläge",
    "donläget": "donläge",
    "donlägets": "donläge",
    "donnan": "donna",
    "donnans": "donna",
    "donnas": "donna",
    "donnor": "donna",
    "donnorna": "donna",
    "donnornas": "donna",
    "donnors": "donna",
    "donor": "dona",
    "donorna": "dona",
    "donornas": "dona",
    "donors": "dona",
    "dons": "dona",
    "dop": "dopa",
    "dopad": "dopa",
    "dopade": "dopa",
    "dopades": "dopa",
    "dopads": "dopa",
    "dopaminblås": "dopaminblåsa",
    "dopaminblåsan": "dopaminblåsa",
    "dopaminblåsans": "dopaminblåsa",
    "dopaminblåsas": "dopaminblåsa",
    "dopaminblåse": "dopaminblåsa",
    "dopaminblåsor": "dopaminblåsa",
    "dopaminblåsorna": "dopaminblåsa",
    "dopaminblåsornas": "dopaminblåsa",
    "dopaminblåsors": "dopaminblåsa",
    "dopaminen": "dopamin",
    "dopaminens": "dopamin",
    "dopaminer": "dopamin",
    "dopaminerna": "dopamin",
    "dopaminernas": "dopamin",
    "dopaminers": "dopamin",
    "dopaminet": "dopamin",
    "dopaminets": "dopamin",
    "dopaminkänsliga": "dopaminkänslig",
    "dopaminkänsligare": "dopaminkänslig",
    "dopaminkänsligares": "dopaminkänslig",
    "dopaminkänsligas": "dopaminkänslig",
    "dopaminkänsligast": "dopaminkänslig",
    "dopaminkänsligaste": "dopaminkänslig",
    "dopaminkänsligastes": "dopaminkänslig",
    "dopaminkänsligasts": "dopaminkänslig",
    "dopaminkänslige": "dopaminkänslig",
    "dopaminkänsliges": "dopaminkänslig",
    "dopaminkänsligheten": "dopaminkänslighet",
    "dopaminkänslighetens": "dopaminkänslighet",
    "dopaminkänslighets": "dopaminkänslighet",
    "dopaminkänsligs": "dopaminkänslig",
    "dopaminkänsligt": "dopaminkänslig",
    "dopaminkänsligts": "dopaminkänslig",
    "dopamins": "dopamin",
    "dopande": "dopa",
    "dopanden": "dopande",
    "dopandena": "dopande",
    "dopandenas": "dopande",
    "dopandens": "dopande",
    "dopandes": "dopande",
    "dopandet": "dopande",
    "dopandets": "dopande",
    "dopar": "dopa",
    "dopas": "dopa",
    "dopat": "dopa",
    "dopats": "dopa",
    "dopattesten": "dopattest",
    "dopattestens": "dopattest",
    "dopattester": "dopattest",
    "dopattesterna": "dopattest",
    "dopattesternas": "dopattest",
    "dopattesters": "dopattest",
    "dopattests": "dopattest",
    "dopbassängen": "dopbassäng",
    "dopbassängens": "dopbassäng",
    "dopbassänger": "dopbassäng",
    "dopbassängerna": "dopbassäng",
    "dopbassängernas": "dopbassäng",
    "dopbassängers": "dopbassäng",
    "dopbassängs": "dopbassäng",
    "dopen": "dop",
    "dopens": "dop",
    "dopet": "dop",
    "dopets": "dop",
    "dopfuntar": "dopfunt",
    "dopfuntarna": "dopfunt",
    "dopfuntarnas": "dopfunt",
    "dopfuntars": "dopfunt",
    "dopfunten": "dopfunt",
    "dopfuntens": "dopfunt",
    "dopfunts": "dopfunt",
    "dopingbrotten": "dopingbrott",
    "dopingbrottens": "dopingbrott",
    "dopingbrottet": "dopingbrott",
    "dopingbrottets": "dopingbrott",
    "dopingbrotts": "dopingbrott",
    "dopingen": "doping",
    "dopingens": "doping",
    "dopinghärvan": "dopinghärva",
    "dopinghärvans": "dopinghärva",
    "dopinghärvas": "dopinghärva",
    "dopinghärve": "dopinghärva",
    "dopinghärvor": "dopinghärva",
    "dopinghärvorna": "dopinghärva",
    "dopinghärvornas": "dopinghärva",
    "dopinghärvors": "dopinghärva",
    "dopingpreparaten": "dopingpreparat",
    "dopingpreparatens": "dopingpreparat",
    "dopingpreparatet": "dopingpreparat",
    "dopingpreparatets": "dopingpreparat",
    "dopingpreparats": "dopingpreparat",
    "dopings": "doping",
    "dopnamnen": "dopnamn",
    "dopnamnens": "dopnamn",
    "dopnamnet": "dopnamn",
    "dopnamnets": "dopnamn",
    "dopnamns": "dopnamn",
    "dopningar": "dopning",
    "dopningarna": "dopning",
    "dopningarnas": "dopning",
    "dopningars": "dopning",
    "dopningen": "dopning",
    "dopningens": "dopning",
    "dopnings": "dopning",
    "dopningsbrotten": "dopningsbrott",
    "dopningsbrottens": "dopningsbrott",
    "dopningsbrottet": "dopningsbrott",
    "dopningsbrottets": "dopningsbrott",
    "dopningsbrotts": "dopningsbrott",
    "dopningshärvan": "dopningshärva",
    "dopningshärvans": "dopningshärva",
    "dopningshärvas": "dopningshärva",
    "dopningshärve": "dopningshärva",
    "dopningshärvor": "dopningshärva",
    "dopningshärvorna": "dopningshärva",
    "dopningshärvornas": "dopningshärva",
    "dopningshärvors": "dopningshärva",
    "dopningspreparaten": "dopningspreparat",
    "dopningspreparatens": "dopningspreparat",
    "dopningspreparatet": "dopningspreparat",
    "dopningspreparatets": "dopningspreparat",
    "dopningspreparats": "dopningspreparat",
    "dopp": "doppa",
    "doppad": "doppa",
    "doppade": "doppa",
    "doppades": "doppa",
    "doppads": "doppa",
    "doppande": "doppa",
    "doppanden": "doppande",
    "doppandena": "doppande",
    "doppandenas": "doppande",
    "doppandens": "doppande",
    "doppandes": "doppande",
    "doppandet": "doppande",
    "doppandets": "doppande",
    "doppar": "doppa",
    "doppardagen": "doppardag",
    "doppardagens": "doppardag",
    "doppardags": "doppardag",
    "doppardans": "doppardan",
    "dopparedagen": "dopparedag",
    "dopparedagens": "dopparedag",
    "dopparedags": "dopparedag",
    "dopparedans": "dopparedan",
    "doppas": "doppa",
    "doppat": "doppa",
    "doppats": "doppa",
    "doppen": "dopp",
    "doppens": "dopp",
    "doppet": "dopp",
    "doppets": "dopp",
    "doppingar": "dopping",
    "doppingarna": "dopping",
    "doppingarnas": "dopping",
    "doppingars": "dopping",
    "doppingen": "dopping",
    "doppingens": "dopping",
    "doppings": "dopping",
    "dopplereffekten": "dopplereffekt",
    "dopplereffektens": "dopplereffekt",
    "dopplereffekts": "dopplereffekt",
    "dopps": "dopp",
    "doppskon": "doppsko",
    "doppskons": "doppsko",
    "doppskor": "doppsko",
    "doppskorna": "doppsko",
    "doppskornas": "doppsko",
    "doppskors": "doppsko",
    "doppskos": "doppsko",
    "doppvärmar": "doppvärmare",
    "doppvärmaren": "doppvärmare",
    "doppvärmarens": "doppvärmare",
    "doppvärmares": "doppvärmare",
    "doppvärmarna": "doppvärmare",
    "doppvärmarnas": "doppvärmare",
    "dops": "dop",
    "dopvattens": "dopvatten",
    "dopvattnet": "dopvatten",
    "dopvattnets": "dopvatten",
    "dopvittnen": "dopvittne",
    "dopvittnena": "dopvittne",
    "dopvittnenas": "dopvittne",
    "dopvittnens": "dopvittne",
    "dopvittnes": "dopvittne",
    "dopvittnet": "dopvittne",
    "dopvittnets": "dopvittne",
    "dorern": "dorer",
    "dorerna": "dorer",
    "dorernas": "dorer",
    "dorerns": "dorer",
    "dorers": "dorer",
    "doriska": "dorisk",
    "doriskare": "dorisk",
    "doriskares": "dorisk",
    "doriskas": "dorisk",
    "doriskast": "dorisk",
    "doriskaste": "dorisk",
    "doriskastes": "dorisk",
    "doriskasts": "dorisk",
    "doriske": "dorisk",
    "doriskes": "dorisk",
    "dorisks": "dorisk",
    "doriskt": "dorisk",
    "doriskts": "dorisk",
    "dormitorie": "dormitorium",
    "dormitorier": "dormitorium",
    "dormitorierna": "dormitorium",
    "dormitoriernas": "dormitorium",
    "dormitoriers": "dormitorium",
    "dormitoriet": "dormitorium",
    "dormitoriets": "dormitorium",
    "dormitoriums": "dormitorium",
    "dornar": "dorn",
    "dornarna": "dorn",
    "dornarnas": "dorn",
    "dornars": "dorn",
    "dornen": "dorn",
    "dornens": "dorn",
    "dorns": "dorn",
    "dorsala": "dorsal",
    "dorsalare": "dorsal",
    "dorsalares": "dorsal",
    "dorsalas": "dorsal",
    "dorsalast": "dorsal",
    "dorsalaste": "dorsal",
    "dorsalastes": "dorsal",
    "dorsalasts": "dorsal",
    "dorsale": "dorsal",
    "dorsalen": "dorsal",
    "dorsalens": "dorsal",
    "dorsaler": "dorsal",
    "dorsalerna": "dorsal",
    "dorsalernas": "dorsal",
    "dorsalers": "dorsal",
    "dorsales": "dorsal",
    "dorsals": "dorsal",
    "dorsalt": "dorsal",
    "dorsalts": "dorsal",
    "dorska": "dorsk",
    "dorskare": "dorsk",
    "dorskares": "dorsk",
    "dorskas": "dorsk",
    "dorskast": "dorsk",
    "dorskaste": "dorsk",
    "dorskastes": "dorsk",
    "dorskasts": "dorsk",
    "dorske": "dorsk",
    "dorskes": "dorsk",
    "dorskheten": "dorskhet",
    "dorskhetens": "dorskhet",
    "dorskhets": "dorskhet",
    "dorsks": "dorsk",
    "dorskt": "dorsk",
    "dorskts": "dorsk",
    "dos": "dosa",
    "dosan": "dosa",
    "dosans": "dosa",
    "dosas": "dosa",
    "dosbarometern": "dosbarometer",
    "dosbarometerns": "dosbarometer",
    "dosbarometers": "dosbarometer",
    "dosbarometrar": "dosbarometer",
    "dosbarometrarna": "dosbarometer",
    "dosbarometrarnas": "dosbarometer",
    "dosbarometrars": "dosbarometer",
    "dose": "dosa",
    "dosekvivalenten": "dosekvivalent",
    "dosekvivalentens": "dosekvivalent",
    "dosekvivalenter": "dosekvivalent",
    "dosekvivalenterna": "dosekvivalent",
    "dosekvivalenternas": "dosekvivalent",
    "dosekvivalenters": "dosekvivalent",
    "dosekvivalents": "dosekvivalent",
    "dosen": "dos",
    "dosens": "dos",
    "doser": "dos",
    "doserad": "dosera",
    "doserade": "dosera",
    "doserades": "dosera",
    "doserads": "dosera",
    "doserande": "dosera",
    "doseranden": "doserande",
    "doserandena": "doserande",
    "doserandenas": "doserande",
    "doserandens": "doserande",
    "doserandes": "doserande",
    "doserandet": "doserande",
    "doserandets": "doserande",
    "doserar": "dosera",
    "doseras": "dosera",
    "doserat": "dosera",
    "doserats": "dosera",
    "doserbara": "doserbar",
    "doserbarare": "doserbar",
    "doserbarares": "doserbar",
    "doserbaras": "doserbar",
    "doserbarast": "doserbar",
    "doserbaraste": "doserbar",
    "doserbarastes": "doserbar",
    "doserbarasts": "doserbar",
    "doserbare": "doserbar",
    "doserbares": "doserbar",
    "doserbarheten": "doserbarhet",
    "doserbarhetens": "doserbarhet",
    "doserbarhets": "doserbarhet",
    "doserbars": "doserbar",
    "doserbart": "doserbar",
    "doserbarts": "doserbar",
    "doseringar": "dosering",
    "doseringarna": "dosering",
    "doseringarnas": "dosering",
    "doseringars": "dosering",
    "doseringen": "dosering",
    "doseringens": "dosering",
    "doserings": "dosering",
    "doserna": "dos",
    "dosernas": "dos",
    "dosers": "dos",
    "dosimetern": "dosimeter",
    "dosimeterns": "dosimeter",
    "dosimeters": "dosimeter",
    "dosimetrar": "dosimeter",
    "dosimetrarna": "dosimeter",
    "dosimetrarnas": "dosimeter",
    "dosimetrars": "dosimeter",
    "dosimetrien": "dosimetri",
    "dosimetriens": "dosimetri",
    "dosimetrin": "dosimetri",
    "dosimetrins": "dosimetri",
    "dosimetris": "dosimetri",
    "doslibellen": "doslibell",
    "doslibellens": "doslibell",
    "doslibeller": "doslibell",
    "doslibellerna": "doslibell",
    "doslibellernas": "doslibell",
    "doslibellers": "doslibell",
    "doslibells": "doslibell",
    "dosmätar": "dosmätare",
    "dosmätaren": "dosmätare",
    "dosmätarens": "dosmätare",
    "dosmätares": "dosmätare",
    "dosmätarna": "dosmätare",
    "dosmätarnas": "dosmätare",
    "dosor": "dosa",
    "dosorna": "dosa",
    "dosornas": "dosa",
    "dosors": "dosa",
    "dosserad": "dossera",
    "dosserade": "dossera",
    "dosserades": "dossera",
    "dosserads": "dossera",
    "dosserande": "dossera",
    "dosseranden": "dosserande",
    "dosserandena": "dosserande",
    "dosserandenas": "dosserande",
    "dosserandens": "dosserande",
    "dosserandes": "dosserande",
    "dosserandet": "dosserande",
    "dosserandets": "dosserande",
    "dosserar": "dossera",
    "dosseras": "dossera",
    "dosserat": "dossera",
    "dosserats": "dossera",
    "dosserbara": "dosserbar",
    "dosserbarare": "dosserbar",
    "dosserbarares": "dosserbar",
    "dosserbaras": "dosserbar",
    "dosserbarast": "dosserbar",
    "dosserbaraste": "dosserbar",
    "dosserbarastes": "dosserbar",
    "dosserbarasts": "dosserbar",
    "dosserbare": "dosserbar",
    "dosserbares": "dosserbar",
    "dosserbarheten": "dosserbarhet",
    "dosserbarhetens": "dosserbarhet",
    "dosserbarhets": "dosserbarhet",
    "dosserbars": "dosserbar",
    "dosserbart": "dosserbar",
    "dosserbarts": "dosserbar",
    "dosseringar": "dossering",
    "dosseringarna": "dossering",
    "dosseringarnas": "dossering",
    "dosseringars": "dossering",
    "dosseringen": "dossering",
    "dosseringens": "dossering",
    "dosserings": "dossering",
    "dossierer": "dossier",
    "dossiererna": "dossier",
    "dossierernas": "dossier",
    "dossierers": "dossier",
    "dossiern": "dossier",
    "dossierns": "dossier",
    "dossiers": "dossier",
    "dossiéer": "dossié",
    "dossiéerna": "dossié",
    "dossiéernas": "dossié",
    "dossiéers": "dossié",
    "dossién": "dossié",
    "dossiéns": "dossié",
    "dossiés": "dossié",
    "dotationen": "dotation",
    "dotationens": "dotation",
    "dotationer": "dotation",
    "dotationerna": "dotation",
    "dotationernas": "dotation",
    "dotationers": "dotation",
    "dotations": "dotation",
    "doterad": "dotera",
    "doterade": "dotera",
    "doterades": "dotera",
    "doterads": "dotera",
    "doterande": "dotera",
    "doteranden": "doterande",
    "doterandena": "doterande",
    "doterandenas": "doterande",
    "doterandens": "doterande",
    "doterandes": "doterande",
    "doterandet": "doterande",
    "doterandets": "doterande",
    "doterar": "dotera",
    "doteras": "dotera",
    "doterat": "dotera",
    "doterats": "dotera",
    "doterbara": "doterbar",
    "doterbarare": "doterbar",
    "doterbarares": "doterbar",
    "doterbaras": "doterbar",
    "doterbarast": "doterbar",
    "doterbaraste": "doterbar",
    "doterbarastes": "doterbar",
    "doterbarasts": "doterbar",
    "doterbare": "doterbar",
    "doterbares": "doterbar",
    "doterbarheten": "doterbarhet",
    "doterbarhetens": "doterbarhet",
    "doterbarhets": "doterbarhet",
    "doterbars": "doterbar",
    "doterbart": "doterbar",
    "doterbarts": "doterbar",
    "doteringar": "dotering",
    "doteringarna": "dotering",
    "doteringarnas": "dotering",
    "doteringars": "dotering",
    "doteringen": "dotering",
    "doteringens": "dotering",
    "doterings": "dotering",
    "dotterbolagen": "dotterbolag",
    "dotterbolagens": "dotterbolag",
    "dotterbolaget": "dotterbolag",
    "dotterbolagets": "dotterbolag",
    "dotterbolags": "dotterbolag",
    "dottercellen": "dottercell",
    "dottercellens": "dottercell",
    "dotterceller": "dottercell",
    "dottercellerna": "dottercell",
    "dottercellernas": "dottercell",
    "dottercellers": "dottercell",
    "dottercells": "dottercell",
    "dotterdottern": "dotterdotter",
    "dotterdotterns": "dotterdotter",
    "dotterdotters": "dotterdotter",
    "dotterdöttrar": "dotterdotter",
    "dotterdöttrarna": "dotterdotter",
    "dotterdöttrarnas": "dotterdotter",
    "dotterdöttrars": "dotterdotter",
    "dotterföretagen": "dotterföretag",
    "dotterföretagens": "dotterföretag",
    "dotterföretaget": "dotterföretag",
    "dotterföretagets": "dotterföretag",
    "dotterföretags": "dotterföretag",
    "dotterförsamlingar": "dotterförsamling",
    "dotterförsamlingarna": "dotterförsamling",
    "dotterförsamlingarnas": "dotterförsamling",
    "dotterförsamlingars": "dotterförsamling",
    "dotterförsamlingen": "dotterförsamling",
    "dotterförsamlingens": "dotterförsamling",
    "dotterförsamlings": "dotterförsamling",
    "dotterliga": "dotterlig",
    "dotterligare": "dotterlig",
    "dotterligares": "dotterlig",
    "dotterligas": "dotterlig",
    "dotterligast": "dotterlig",
    "dotterligaste": "dotterlig",
    "dotterligastes": "dotterlig",
    "dotterligasts": "dotterlig",
    "dotterlige": "dotterlig",
    "dotterliges": "dotterlig",
    "dotterligheten": "dotterlighet",
    "dotterlighetens": "dotterlighet",
    "dotterlighets": "dotterlighet",
    "dotterligs": "dotterlig",
    "dotterligt": "dotterlig",
    "dotterligts": "dotterlig",
    "dottern": "dotter",
    "dotterns": "dotter",
    "dotters": "dotter",
    "dottersonen": "dotterson",
    "dottersonens": "dotterson",
    "dottersons": "dotterson",
    "dotterspråken": "dotterspråk",
    "dotterspråkens": "dotterspråk",
    "dotterspråket": "dotterspråk",
    "dotterspråkets": "dotterspråk",
    "dotterspråks": "dotterspråk",
    "dottersvulsten": "dottersvulst",
    "dottersvulstens": "dottersvulst",
    "dottersvulster": "dottersvulst",
    "dottersvulsterna": "dottersvulst",
    "dottersvulsternas": "dottersvulst",
    "dottersvulsters": "dottersvulst",
    "dottersvulsts": "dottersvulst",
    "dottersöner": "dotterson",
    "dottersönerna": "dotterson",
    "dottersönernas": "dotterson",
    "dottersöners": "dotterson",
    "dottertumören": "dottertumör",
    "dottertumörens": "dottertumör",
    "dottertumörer": "dottertumör",
    "dottertumörerna": "dottertumör",
    "dottertumörernas": "dottertumör",
    "dottertumörers": "dottertumör",
    "dottertumörs": "dottertumör",
    "doubléer": "doublé",
    "doubléerna": "doublé",
    "doubléernas": "doublé",
    "doubléers": "doublé",
    "doublén": "doublé",
    "doubléns": "doublé",
    "doublés": "doublé",
    "dova": "dov",
    "dovare": "dov",
    "dovares": "dov",
    "dovas": "dov",
    "dovast": "dov",
    "dovaste": "dov",
    "dovastes": "dov",
    "dovasts": "dov",
    "dove": "dov",
    "doves": "dov",
    "dovheten": "dovhet",
    "dovhetens": "dovhet",
    "dovhets": "dovhet",
    "dovhjortar": "dovhjort",
    "dovhjortarna": "dovhjort",
    "dovhjortarnas": "dovhjort",
    "dovhjortars": "dovhjort",
    "dovhjorten": "dovhjort",
    "dovhjortens": "dovhjort",
    "dovhjorts": "dovhjort",
    "dovs": "dov",
    "dovt": "dov",
    "dovts": "dov",
    "downperioden": "downperiod",
    "downperiodens": "downperiod",
    "downperioder": "downperiod",
    "downperioderna": "downperiod",
    "downperiodernas": "downperiod",
    "downperioders": "downperiod",
    "downperiods": "downperiod",
    "doyenen": "doyen",
    "doyenens": "doyen",
    "doyener": "doyen",
    "doyenerna": "doyen",
    "doyenernas": "doyen",
    "doyeners": "doyen",
    "doyens": "doyen",
    "drabanten": "drabant",
    "drabantens": "drabant",
    "drabanter": "drabant",
    "drabanterna": "drabant",
    "drabanternas": "drabant",
    "drabanters": "drabant",
    "drabants": "drabant",
    "drabantstaten": "drabantstat",
    "drabantstatens": "drabantstat",
    "drabantstater": "drabantstat",
    "drabantstaterna": "drabantstat",
    "drabantstaternas": "drabantstat",
    "drabantstaters": "drabantstat",
    "drabantstats": "drabantstat",
    "drabb": "drabba",
    "drabbad": "drabba",
    "drabbade": "drabba",
    "drabbades": "drabba",
    "drabbads": "drabba",
    "drabbande": "drabba",
    "drabbanden": "drabbande",
    "drabbandena": "drabbande",
    "drabbandenas": "drabbande",
    "drabbandens": "drabbande",
    "drabbandes": "drabbande",
    "drabbandet": "drabbande",
    "drabbandets": "drabbande",
    "drabbar": "drabba",
    "drabbas": "drabba",
    "drabbat": "drabba",
    "drabbats": "drabba",
    "drabbningar": "drabbning",
    "drabbningarna": "drabbning",
    "drabbningarnas": "drabbning",
    "drabbningars": "drabbning",
    "drabbningen": "drabbning",
    "drabbningens": "drabbning",
    "drabbnings": "drabbning",
    "drachman": "drachma",
    "drachmans": "drachma",
    "drachmas": "drachma",
    "drachmer": "drachma",
    "drachmerna": "drachma",
    "drachmernas": "drachma",
    "drachmers": "drachma",
    "drack": "dricka",
    "dracks": "dricka",
    "drag": "dra",
    "draga": "dra",
    "dragande": "dra",
    "draganden": "dragande",
    "dragandena": "dragande",
    "dragandenas": "dragande",
    "dragandens": "dragande",
    "dragandes": "dragande",
    "dragandet": "dragande",
    "dragandets": "dragande",
    "dragar": "dragare",
    "dragaren": "dragare",
    "dragarens": "dragare",
    "dragares": "dragare",
    "dragarna": "dragare",
    "dragarnas": "dragare",
    "dragas": "dra",
    "dragbanden": "dragband",
    "dragbandens": "dragband",
    "dragbandet": "dragband",
    "dragbandets": "dragband",
    "dragbands": "dragband",
    "dragbasunen": "dragbasun",
    "dragbasunens": "dragbasun",
    "dragbasuner": "dragbasun",
    "dragbasunerna": "dragbasun",
    "dragbasunernas": "dragbasun",
    "dragbasuners": "dragbasun",
    "dragbasuns": "dragbasun",
    "dragbilar": "dragbil",
    "dragbilarna": "dragbil",
    "dragbilarnas": "dragbil",
    "dragbilars": "dragbil",
    "dragbilen": "dragbil",
    "dragbilens": "dragbil",
    "dragbils": "dragbil",
    "dragbänkar": "dragbänk",
    "dragbänkarna": "dragbänk",
    "dragbänkarnas": "dragbänk",
    "dragbänkars": "dragbänk",
    "dragbänken": "dragbänk",
    "dragbänkens": "dragbänk",
    "dragbänks": "dragbänk",
    "dragdjuren": "dragdjur",
    "dragdjurens": "dragdjur",
    "dragdjuret": "dragdjur",
    "dragdjurets": "dragdjur",
    "dragdjurs": "dragdjur",
    "drage": "dra",
    "dragen": "drag",
    "dragenheten": "dragenhet",
    "dragenhetens": "dragenhet",
    "dragenheter": "dragenhet",
    "dragenheterna": "dragenhet",
    "dragenheternas": "dragenhet",
    "dragenheters": "dragenhet",
    "dragenhets": "dragenhet",
    "dragens": "dragen",
    "drager": "dra",
    "dragerad": "dragera",
    "dragerade": "dragera",
    "dragerades": "dragera",
    "dragerads": "dragera",
    "dragerande": "dragera",
    "drageranden": "dragerande",
    "dragerandena": "dragerande",
    "dragerandenas": "dragerande",
    "dragerandens": "dragerande",
    "dragerandes": "dragerande",
    "dragerandet": "dragerande",
    "dragerandets": "dragerande",
    "dragerar": "dragera",
    "drageras": "dragera",
    "dragerat": "dragera",
    "dragerats": "dragera",
    "dragerbara": "dragerbar",
    "dragerbarare": "dragerbar",
    "dragerbarares": "dragerbar",
    "dragerbaras": "dragerbar",
    "dragerbarast": "dragerbar",
    "dragerbaraste": "dragerbar",
    "dragerbarastes": "dragerbar",
    "dragerbarasts": "dragerbar",
    "dragerbare": "dragerbar",
    "dragerbares": "dragerbar",
    "dragerbarheten": "dragerbarhet",
    "dragerbarhetens": "dragerbarhet",
    "dragerbarhets": "dragerbarhet",
    "dragerbars": "dragerbar",
    "dragerbart": "dragerbar",
    "dragerbarts": "dragerbar",
    "drageringar": "dragering",
    "drageringarna": "dragering",
    "drageringarnas": "dragering",
    "drageringars": "dragering",
    "drageringen": "dragering",
    "drageringens": "dragering",
    "dragerings": "dragering",
    "drages": "dra",
    "draget": "dragen",
    "dragets": "dragen",
    "dragg": "dragga",
    "draggad": "dragga",
    "draggade": "dragga",
    "draggades": "dragga",
    "draggads": "dragga",
    "draggande": "dragga",
    "dragganden": "draggande",
    "draggandena": "draggande",
    "draggandenas": "draggande",
    "draggandens": "draggande",
    "draggandes": "draggande",
    "draggandet": "draggande",
    "draggandets": "draggande",
    "draggar": "dragga",
    "draggarna": "dragg",
    "draggarnas": "dragg",
    "draggars": "dragg",
    "draggas": "dragga",
    "draggat": "dragga",
    "draggats": "dragga",
    "draggen": "dragg",
    "draggens": "dragg",
    "draggs": "dragg",
    "dragharmonik": "dragharmonika",
    "dragharmonikan": "dragharmonika",
    "dragharmonikans": "dragharmonika",
    "dragharmonikas": "dragharmonika",
    "dragharmonike": "dragharmonika",
    "dragharmonikor": "dragharmonika",
    "dragharmonikorna": "dragharmonika",
    "dragharmonikornas": "dragharmonika",
    "dragharmonikors": "dragharmonika",
    "dragharmoniks": "dragharmonika",
    "draghjälpen": "draghjälp",
    "draghjälpens": "draghjälp",
    "draghjälps": "draghjälp",
    "draghållfastheten": "draghållfasthet",
    "draghållfasthetens": "draghållfasthet",
    "draghållfastheter": "draghållfasthet",
    "draghållfastheterna": "draghållfasthet",
    "draghållfastheternas": "draghållfasthet",
    "draghållfastheters": "draghållfasthet",
    "draghållfasthets": "draghållfasthet",
    "dragiga": "dragig",
    "dragigare": "dragig",
    "dragigares": "dragig",
    "dragigas": "dragig",
    "dragigast": "dragig",
    "dragigaste": "dragig",
    "dragigastes": "dragig",
    "dragigasts": "dragig",
    "dragige": "dragig",
    "dragiges": "dragig",
    "dragigs": "dragig",
    "dragigt": "dragig",
    "dragigts": "dragig",
    "dragit": "dra",
    "dragits": "dras",
    "dragkampen": "dragkamp",
    "dragkampens": "dragkamp",
    "dragkamper": "dragkamp",
    "dragkamperna": "dragkamp",
    "dragkampernas": "dragkamp",
    "dragkampers": "dragkamp",
    "dragkamps": "dragkamp",
    "dragkedjan": "dragkedja",
    "dragkedjans": "dragkedja",
    "dragkedjas": "dragkedja",
    "dragkedje": "dragkedja",
    "dragkedjor": "dragkedja",
    "dragkedjorna": "dragkedja",
    "dragkedjornas": "dragkedja",
    "dragkedjors": "dragkedja",
    "dragkist": "dragkista",
    "dragkistan": "dragkista",
    "dragkistans": "dragkista",
    "dragkistas": "dragkista",
    "dragkiste": "dragkista",
    "dragkistor": "dragkista",
    "dragkistorna": "dragkista",
    "dragkistornas": "dragkista",
    "dragkistors": "dragkista",
    "dragkrokar": "dragkrok",
    "dragkrokarna": "dragkrok",
    "dragkrokarnas": "dragkrok",
    "dragkrokars": "dragkrok",
    "dragkroken": "dragkrok",
    "dragkrokens": "dragkrok",
    "dragkroks": "dragkrok",
    "draglappar": "draglapp",
    "draglapparna": "draglapp",
    "draglapparnas": "draglapp",
    "draglappars": "draglapp",
    "draglappen": "draglapp",
    "draglappens": "draglapp",
    "draglapps": "draglapp",
    "draglin": "draglina",
    "draglinan": "draglina",
    "draglinans": "draglina",
    "draglinas": "draglina",
    "dragline": "draglina",
    "draglinor": "draglina",
    "draglinorna": "draglina",
    "draglinornas": "draglina",
    "draglinors": "draglina",
    "draglins": "draglina",
    "dragna": "dragen",
    "dragnageln": "dragnagel",
    "dragnagelns": "dragnagel",
    "dragnagels": "dragnagel",
    "dragnaglar": "dragnagel",
    "dragnaglarna": "dragnagel",
    "dragnaglarnas": "dragnagel",
    "dragnaglars": "dragnagel",
    "dragnare": "dragen",
    "dragnares": "dragen",
    "dragnas": "dragen",
    "dragnast": "dragen",
    "dragnaste": "dragen",
    "dragnastes": "dragen",
    "dragnasts": "dragen",
    "dragne": "dragen",
    "dragnes": "dragen",
    "dragningar": "dragning",
    "dragningarna": "dragning",
    "dragningarnas": "dragning",
    "dragningars": "dragning",
    "dragningen": "dragning",
    "dragningens": "dragning",
    "dragnings": "dragning",
    "dragningskraften": "dragningskraft",
    "dragningskraftens": "dragningskraft",
    "dragningskrafts": "dragningskraft",
    "dragningslistan": "dragningslista",
    "dragningslistans": "dragningslista",
    "dragningslistas": "dragningslista",
    "dragningsliste": "dragningslista",
    "dragningslistor": "dragningslista",
    "dragningslistorna": "dragningslista",
    "dragningslistornas": "dragningslista",
    "dragningslistors": "dragningslista",
    "dragomanen": "dragoman",
    "dragomanens": "dragoman",
    "dragomaner": "dragoman",
    "dragomanerna": "dragoman",
    "dragomanernas": "dragoman",
    "dragomaners": "dragoman",
    "dragomans": "dragoman",
    "dragonen": "dragon",
    "dragonens": "dragon",
    "dragoner": "dragon",
    "dragonerna": "dragon",
    "dragonernas": "dragon",
    "dragoners": "dragon",
    "dragons": "dragon",
    "dragplåsters": "dragplåster",
    "dragplåstren": "dragplåster",
    "dragplåstrens": "dragplåster",
    "dragplåstret": "dragplåster",
    "dragplåstrets": "dragplåster",
    "dragpressar": "dragpress",
    "dragpressarna": "dragpress",
    "dragpressarnas": "dragpress",
    "dragpressars": "dragpress",
    "dragpressen": "dragpress",
    "dragpressens": "dragpress",
    "dragpressningar": "dragpressning",
    "dragpressningarna": "dragpressning",
    "dragpressningarnas": "dragpressning",
    "dragpressningars": "dragpressning",
    "dragpressningen": "dragpressning",
    "dragpressningens": "dragpressning",
    "dragpressnings": "dragpressning",
    "dragproven": "dragprov",
    "dragprovens": "dragprov",
    "dragprovet": "dragprov",
    "dragprovets": "dragprov",
    "dragprovs": "dragprov",
    "dragracingen": "dragracing",
    "dragracingens": "dragracing",
    "dragracings": "dragracing",
    "dragrepen": "dragrep",
    "dragrepens": "dragrep",
    "dragrepet": "dragrep",
    "dragrepets": "dragrep",
    "dragreps": "dragrep",
    "drags": "drag",
    "dragshowen": "dragshow",
    "dragshowens": "dragshow",
    "dragshower": "dragshow",
    "dragshowerna": "dragshow",
    "dragshowernas": "dragshow",
    "dragshowers": "dragshow",
    "dragshows": "dragshow",
    "dragskivan": "dragskiva",
    "dragskivans": "dragskiva",
    "dragskivas": "dragskiva",
    "dragskive": "dragskiva",
    "dragskivor": "dragskiva",
    "dragskivorna": "dragskiva",
    "dragskivornas": "dragskiva",
    "dragskivors": "dragskiva",
    "dragskon": "dragsko",
    "dragskons": "dragsko",
    "dragskor": "dragsko",
    "dragskorna": "dragsko",
    "dragskornas": "dragsko",
    "dragskors": "dragsko",
    "dragskos": "dragsko",
    "dragskåpen": "dragskåp",
    "dragskåpens": "dragskåp",
    "dragskåpet": "dragskåp",
    "dragskåpets": "dragskåp",
    "dragskåps": "dragskåp",
    "dragsnör": "dragsnöre",
    "dragsnören": "dragsnöre",
    "dragsnörena": "dragsnöre",
    "dragsnörenas": "dragsnöre",
    "dragsnörens": "dragsnöre",
    "dragsnöres": "dragsnöre",
    "dragsnöret": "dragsnöre",
    "dragsnörets": "dragsnöre",
    "dragsnörs": "dragsnöre",
    "dragspelen": "dragspel",
    "dragspelens": "dragspel",
    "dragspelet": "dragspel",
    "dragspelets": "dragspel",
    "dragspels": "dragspel",
    "dragstiften": "dragstift",
    "dragstiftens": "dragstift",
    "dragstiftet": "dragstift",
    "dragstiftets": "dragstift",
    "dragstifts": "dragstift",
    "dragstyrkan": "dragstyrka",
    "dragstyrkans": "dragstyrka",
    "dragstyrkas": "dragstyrka",
    "dragstyrke": "dragstyrka",
    "dragstyrkor": "dragstyrka",
    "dragstyrkorna": "dragstyrka",
    "dragstyrkornas": "dragstyrka",
    "dragstyrkors": "dragstyrka",
    "dragvägar": "dragväg",
    "dragvägarna": "dragväg",
    "dragvägarnas": "dragväg",
    "dragvägars": "dragväg",
    "dragvägen": "dragväg",
    "dragvägens": "dragväg",
    "dragvägs": "dragväg",
    "dragéer": "dragé",
    "dragéerna": "dragé",
    "dragéernas": "dragé",
    "dragéers": "dragé",
    "dragén": "dragé",
    "dragéns": "dragé",
    "dragés": "dragé",
    "drak": "drake",
    "drakar": "drake",
    "drakarna": "drake",
    "drakarnas": "drake",
    "drakars": "drake",
    "drakblodet": "drakblod",
    "drakblodets": "drakblod",
    "drakblods": "drakblod",
    "drakblodsträden": "drakblodsträd",
    "drakblodsträdens": "drakblodsträd",
    "drakblodsträdet": "drakblodsträd",
    "drakblodsträdets": "drakblodsträd",
    "drakblodsträds": "drakblodsträd",
    "draken": "drake",
    "drakens": "drake",
    "drakes": "drake",
    "drakflygar": "drakflygare",
    "drakflygaren": "drakflygare",
    "drakflygarens": "drakflygare",
    "drakflygares": "drakflygare",
    "drakflygarna": "drakflygare",
    "drakflygarnas": "drakflygare",
    "drakhuvudfiskar": "drakhuvudfisk",
    "drakhuvudfiskarna": "drakhuvudfisk",
    "drakhuvudfiskarnas": "drakhuvudfisk",
    "drakhuvudfiskars": "drakhuvudfisk",
    "drakhuvudfisken": "drakhuvudfisk",
    "drakhuvudfiskens": "drakhuvudfisk",
    "drakhuvudfisks": "drakhuvudfisk",
    "drakman": "drakma",
    "drakmans": "drakma",
    "drakmas": "drakma",
    "drakmer": "drakma",
    "drakmerna": "drakma",
    "drakmernas": "drakma",
    "drakmers": "drakma",
    "drakoniska": "drakonisk",
    "drakoniskare": "drakonisk",
    "drakoniskares": "drakonisk",
    "drakoniskas": "drakonisk",
    "drakoniskast": "drakonisk",
    "drakoniskaste": "drakonisk",
    "drakoniskastes": "drakonisk",
    "drakoniskasts": "drakonisk",
    "drakoniske": "drakonisk",
    "drakoniskes": "drakonisk",
    "drakonisks": "drakonisk",
    "drakoniskt": "drakonisk",
    "drakoniskts": "drakonisk",
    "draks": "drake",
    "drakskeppen": "drakskepp",
    "drakskeppens": "drakskepp",
    "drakskeppet": "drakskepp",
    "drakskeppets": "drakskepp",
    "drakskepps": "drakskepp",
    "draksling": "drakslinga",
    "drakslingan": "drakslinga",
    "drakslingans": "drakslinga",
    "drakslingas": "drakslinga",
    "drakslinge": "drakslinga",
    "drakslingor": "drakslinga",
    "drakslingorna": "drakslinga",
    "drakslingornas": "drakslinga",
    "drakslingors": "drakslinga",
    "drakslings": "drakslinga",
    "drakstjärtar": "drakstjärt",
    "drakstjärtarna": "drakstjärt",
    "drakstjärtarnas": "drakstjärt",
    "drakstjärtars": "drakstjärt",
    "drakstjärten": "drakstjärt",
    "drakstjärtens": "drakstjärt",
    "drakstjärts": "drakstjärt",
    "draksådden": "draksådd",
    "draksåddens": "draksådd",
    "draksådder": "draksådd",
    "draksådderna": "draksådd",
    "draksåddernas": "draksådd",
    "draksådders": "draksådd",
    "draksådds": "draksådd",
    "draködlan": "draködla",
    "draködlans": "draködla",
    "draködlas": "draködla",
    "draködle": "draködla",
    "draködlor": "draködla",
    "draködlorna": "draködla",
    "draködlornas": "draködla",
    "draködlors": "draködla",
    "draman": "drama",
    "dramana": "drama",
    "dramanas": "drama",
    "dramans": "drama",
    "dramas": "drama",
    "dramat": "drama",
    "dramatiken": "dramatik",
    "dramatikens": "dramatik",
    "dramatikern": "dramatiker",
    "dramatikerna": "dramatiker",
    "dramatikernas": "dramatiker",
    "dramatikerns": "dramatiker",
    "dramatikers": "dramatiker",
    "dramatiks": "dramatik",
    "dramatiserad": "dramatisera",
    "dramatiserade": "dramatisera",
    "dramatiserades": "dramatisera",
    "dramatiserads": "dramatisera",
    "dramatiserande": "dramatisera",
    "dramatiseranden": "dramatiserande",
    "dramatiserandena": "dramatiserande",
    "dramatiserandenas": "dramatiserande",
    "dramatiserandens": "dramatiserande",
    "dramatiserandes": "dramatiserande",
    "dramatiserandet": "dramatiserande",
    "dramatiserandets": "dramatiserande",
    "dramatiserar": "dramatisera",
    "dramatiseras": "dramatisera",
    "dramatiserat": "dramatisera",
    "dramatiserats": "dramatisera",
    "dramatiserbara": "dramatiserbar",
    "dramatiserbarare": "dramatiserbar",
    "dramatiserbarares": "dramatiserbar",
    "dramatiserbaras": "dramatiserbar",
    "dramatiserbarast": "dramatiserbar",
    "dramatiserbaraste": "dramatiserbar",
    "dramatiserbarastes": "dramatiserbar",
    "dramatiserbarasts": "dramatiserbar",
    "dramatiserbare": "dramatiserbar",
    "dramatiserbares": "dramatiserbar",
    "dramatiserbarheten": "dramatiserbarhet",
    "dramatiserbarhetens": "dramatiserbarhet",
    "dramatiserbarhets": "dramatiserbarhet",
    "dramatiserbars": "dramatiserbar",
    "dramatiserbart": "dramatiserbar",
    "dramatiserbarts": "dramatiserbar",
    "dramatiseringar": "dramatisering",
    "dramatiseringarna": "dramatisering",
    "dramatiseringarnas": "dramatisering",
    "dramatiseringars": "dramatisering",
    "dramatiseringen": "dramatisering",
    "dramatiseringens": "dramatisering",
    "dramatiserings": "dramatisering",
    "dramatiska": "dramatisk",
    "dramatiskare": "dramatisk",
    "dramatiskares": "dramatisk",
    "dramatiskas": "dramatisk",
    "dramatiskast": "dramatisk",
    "dramatiskaste": "dramatisk",
    "dramatiskastes": "dramatisk",
    "dramatiskasts": "dramatisk",
    "dramatiske": "dramatisk",
    "dramatiskes": "dramatisk",
    "dramatisks": "dramatisk",
    "dramatiskt": "dramatisk",
    "dramatiskts": "dramatisk",
    "dramats": "drama",
    "dramaturgen": "dramaturg",
    "dramaturgens": "dramaturg",
    "dramaturger": "dramaturg",
    "dramaturgerna": "dramaturg",
    "dramaturgernas": "dramaturg",
    "dramaturgers": "dramaturg",
    "dramaturgier": "dramaturgi",
    "dramaturgierna": "dramaturgi",
    "dramaturgiernas": "dramaturgi",
    "dramaturgiers": "dramaturgi",
    "dramaturgin": "dramaturgi",
    "dramaturgins": "dramaturgi",
    "dramaturgis": "dramaturgi",
    "dramaturgs": "dramaturg",
    "dramen": "dram",
    "dramens": "dram",
    "dramer": "drama",
    "dramerna": "drama",
    "dramernas": "drama",
    "dramers": "drama",
    "drams": "dram",
    "dranken": "drank",
    "drankens": "drank",
    "dranks": "drank",
    "drap": "drapa",
    "drapan": "drapa",
    "drapans": "drapa",
    "drapas": "drapa",
    "drape": "drapa",
    "draperad": "drapera",
    "draperade": "drapera",
    "draperades": "drapera",
    "draperads": "drapera",
    "draperande": "drapera",
    "draperanden": "draperande",
    "draperandena": "draperande",
    "draperandenas": "draperande",
    "draperandens": "draperande",
    "draperandes": "draperande",
    "draperandet": "draperande",
    "draperandets": "draperande",
    "draperar": "drapera",
    "draperas": "drapera",
    "draperat": "drapera",
    "draperats": "drapera",
    "draperbara": "draperbar",
    "draperbarare": "draperbar",
    "draperbarares": "draperbar",
    "draperbaras": "draperbar",
    "draperbarast": "draperbar",
    "draperbaraste": "draperbar",
    "draperbarastes": "draperbar",
    "draperbarasts": "draperbar",
    "draperbare": "draperbar",
    "draperbares": "draperbar",
    "draperbarheten": "draperbarhet",
    "draperbarhetens": "draperbarhet",
    "draperbarhets": "draperbarhet",
    "draperbars": "draperbar",
    "draperbart": "draperbar",
    "draperbarts": "draperbar",
    "draperier": "draperi",
    "draperierna": "draperi",
    "draperiernas": "draperi",
    "draperiers": "draperi",
    "draperiet": "draperi",
    "draperiets": "draperi",
    "draperingar": "drapering",
    "draperingarna": "drapering",
    "draperingarnas": "drapering",
    "draperingars": "drapering",
    "draperingen": "drapering",
    "draperingens": "drapering",
    "draperings": "drapering",
    "draperis": "draperi",
    "draperit": "draperi",
    "draperits": "draperi",
    "drapor": "drapa",
    "draporna": "drapa",
    "drapornas": "drapa",
    "drapors": "drapa",
    "draps": "drapa",
    "drar": "dra",
    "dras": "dra",
    "drastiska": "drastisk",
    "drastiskare": "drastisk",
    "drastiskares": "drastisk",
    "drastiskas": "drastisk",
    "drastiskast": "drastisk",
    "drastiskaste": "drastisk",
    "drastiskastes": "drastisk",
    "drastiskasts": "drastisk",
    "drastiske": "drastisk",
    "drastiskes": "drastisk",
    "drastisks": "drastisk",
    "drastiskt": "drastisk",
    "drastiskts": "drastisk",
    "drasuten": "drasut",
    "drasutens": "drasut",
    "drasuter": "drasut",
    "drasuterna": "drasut",
    "drasuternas": "drasut",
    "drasuters": "drasut",
    "drasuts": "drasut",
    "dratt": "dratta",
    "drattad": "dratta",
    "drattade": "dratta",
    "drattades": "dratta",
    "drattads": "dratta",
    "drattande": "dratta",
    "drattanden": "drattande",
    "drattandena": "drattande",
    "drattandenas": "drattande",
    "drattandens": "drattande",
    "drattandes": "drattande",
    "drattandet": "drattande",
    "drattandets": "drattande",
    "drattar": "dratta",
    "drattas": "dratta",
    "drattat": "dratta",
    "drattats": "dratta",
    "dravel": "dravla",
    "dravels": "dravel",
    "draven": "drav",
    "dravens": "drav",
    "dravet": "drav",
    "dravets": "drav",
    "dravlade": "dravla",
    "dravlades": "dravla",
    "dravlande": "dravla",
    "dravlanden": "dravlande",
    "dravlandena": "dravlande",
    "dravlandenas": "dravlande",
    "dravlandens": "dravlande",
    "dravlandes": "dravlande",
    "dravlandet": "dravlande",
    "dravlandets": "dravlande",
    "dravlar": "dravla",
    "dravlas": "dravla",
    "dravlat": "dravla",
    "dravlats": "dravla",
    "dravlet": "dravel",
    "dravlets": "dravel",
    "dravs": "drav",
    "dregel": "dregla",
    "dregeln": "dregel",
    "dregelns": "dregel",
    "dregels": "dregel",
    "dreglade": "dregla",
    "dreglades": "dregla",
    "dreglande": "dregla",
    "dreglanden": "dreglande",
    "dreglandena": "dreglande",
    "dreglandenas": "dreglande",
    "dreglandens": "dreglande",
    "dreglandes": "dreglande",
    "dreglandet": "dreglande",
    "dreglandets": "dreglande",
    "dreglar": "dregla",
    "dreglas": "dregla",
    "dreglat": "dregla",
    "dreglats": "dregla",
    "dreglet": "dregel",
    "dreglets": "dregel",
    "drej": "dreja",
    "drejad": "dreja",
    "drejade": "dreja",
    "drejades": "dreja",
    "drejads": "dreja",
    "drejande": "dreja",
    "drejanden": "drejande",
    "drejandena": "drejande",
    "drejandenas": "drejande",
    "drejandens": "drejande",
    "drejandes": "drejande",
    "drejandet": "drejande",
    "drejandets": "drejande",
    "drejar": "dreja",
    "drejas": "dreja",
    "drejat": "dreja",
    "drejats": "dreja",
    "drejskivan": "drejskiva",
    "drejskivans": "drejskiva",
    "drejskivas": "drejskiva",
    "drejskive": "drejskiva",
    "drejskivor": "drejskiva",
    "drejskivorna": "drejskiva",
    "drejskivornas": "drejskiva",
    "drejskivors": "drejskiva",
    "drejvänd": "drejvända",
    "drejvändande": "drejvända",
    "drejvändanden": "drejvändande",
    "drejvändandena": "drejvändande",
    "drejvändandenas": "drejvändande",
    "drejvändandens": "drejvändande",
    "drejvändandes": "drejvändande",
    "drejvändandet": "drejvändande",
    "drejvändandets": "drejvändande",
    "drejvändas": "drejvända",
    "drejvände": "drejvända",
    "drejvänder": "drejvända",
    "drejvändes": "drejvända",
    "drejvänds": "drejvända",
    "drejvänt": "drejvända",
    "drejvänts": "drejvända",
    "dressar": "dress",
    "dressarna": "dress",
    "dressarnas": "dress",
    "dressars": "dress",
    "dressen": "dress",
    "dressens": "dress",
    "dresser": "dress",
    "dresserad": "dressera",
    "dresserade": "dressera",
    "dresserades": "dressera",
    "dresserads": "dressera",
    "dresserande": "dressera",
    "dresseranden": "dresserande",
    "dresserandena": "dresserande",
    "dresserandenas": "dresserande",
    "dresserandens": "dresserande",
    "dresserandes": "dresserande",
    "dresserandet": "dresserande",
    "dresserandets": "dresserande",
    "dresserar": "dressera",
    "dresseras": "dressera",
    "dresserat": "dressera",
    "dresserats": "dressera",
    "dresserbara": "dresserbar",
    "dresserbarare": "dresserbar",
    "dresserbarares": "dresserbar",
    "dresserbaras": "dresserbar",
    "dresserbarast": "dresserbar",
    "dresserbaraste": "dresserbar",
    "dresserbarastes": "dresserbar",
    "dresserbarasts": "dresserbar",
    "dresserbare": "dresserbar",
    "dresserbares": "dresserbar",
    "dresserbarheten": "dresserbarhet",
    "dresserbarhetens": "dresserbarhet",
    "dresserbarhets": "dresserbarhet",
    "dresserbars": "dresserbar",
    "dresserbart": "dresserbar",
    "dresserbarts": "dresserbar",
    "dresseringar": "dressering",
    "dresseringarna": "dressering",
    "dresseringarnas": "dressering",
    "dresseringars": "dressering",
    "dresseringen": "dressering",
    "dresseringens": "dressering",
    "dresserings": "dressering",
    "dresserna": "dress",
    "dressernas": "dress",
    "dressers": "dress",
    "dressinen": "dressin",
    "dressinens": "dressin",
    "dressiner": "dressin",
    "dressinerna": "dressin",
    "dressinernas": "dressin",
    "dressiners": "dressin",
    "dressingar": "dressing",
    "dressingarna": "dressing",
    "dressingarnas": "dressing",
    "dressingars": "dressing",
    "dressingen": "dressing",
    "dressingens": "dressing",
    "dressings": "dressing",
    "dressins": "dressin",
    "dressyren": "dressyr",
    "dressyrens": "dressyr",
    "dressyrer": "dressyr",
    "dressyrerna": "dressyr",
    "dressyrernas": "dressyr",
    "dressyrers": "dressyr",
    "dressyrridningar": "dressyrridning",
    "dressyrridningarna": "dressyrridning",
    "dressyrridningarnas": "dressyrridning",
    "dressyrridningars": "dressyrridning",
    "dressyrridningen": "dressyrridning",
    "dressyrridningens": "dressyrridning",
    "dressyrridnings": "dressyrridning",
    "dressyrs": "dressyr",
    "dressören": "dressör",
    "dressörens": "dressör",
    "dressörer": "dressör",
    "dressörerna": "dressör",
    "dressörernas": "dressör",
    "dressörers": "dressör",
    "dressörs": "dressör",
    "drev": "driva",
    "drevad": "dreva",
    "drevade": "dreva",
    "drevades": "dreva",
    "drevads": "dreva",
    "drevande": "dreva",
    "drevanden": "drevande",
    "drevandena": "drevande",
    "drevandenas": "drevande",
    "drevandens": "drevande",
    "drevandes": "drevande",
    "drevandet": "drevande",
    "drevandets": "drevande",
    "drevar": "dreva",
    "drevas": "dreva",
    "drevat": "dreva",
    "drevats": "dreva",
    "dreven": "drev",
    "drevens": "drev",
    "drevern": "drever",
    "dreverns": "drever",
    "drevers": "drever",
    "drevet": "drev",
    "drevets": "drev",
    "drevhundar": "drevhund",
    "drevhundarna": "drevhund",
    "drevhundarnas": "drevhund",
    "drevhundars": "drevhund",
    "drevhunden": "drevhund",
    "drevhundens": "drevhund",
    "drevhunds": "drevhund",
    "drevjakten": "drevjakt",
    "drevjaktens": "drevjakt",
    "drevjakter": "drevjakt",
    "drevjakterna": "drevjakt",
    "drevjakternas": "drevjakt",
    "drevjakters": "drevjakt",
    "drevjakts": "drevjakt",
    "drevkarlar": "drevkarl",
    "drevkarlarna": "drevkarl",
    "drevkarlarnas": "drevkarl",
    "drevkarlars": "drevkarl",
    "drevkarlen": "drevkarl",
    "drevkarlens": "drevkarl",
    "drevkarls": "drevkarl",
    "drevrar": "drever",
    "drevrarna": "drever",
    "drevrarnas": "drever",
    "drevrars": "drever",
    "drevs": "driva",
    "dribbel": "dribbla",
    "dribblad": "dribbla",
    "dribblade": "dribbla",
    "dribblades": "dribbla",
    "dribblads": "dribbla",
    "dribblande": "dribbla",
    "dribblanden": "dribblande",
    "dribblandena": "dribblande",
    "dribblandenas": "dribblande",
    "dribblandens": "dribblande",
    "dribblandes": "dribblande",
    "dribblandet": "dribblande",
    "dribblandets": "dribblande",
    "dribblar": "dribbla",
    "dribblas": "dribbla",
    "dribblat": "dribbla",
    "dribblats": "dribbla",
    "dribblern": "dribbler",
    "dribblerna": "dribbler",
    "dribblernas": "dribbler",
    "dribblerns": "dribbler",
    "dribblers": "dribbler",
    "dribblersarna": "dribbler",
    "dribblersarnas": "dribbler",
    "dribblersen": "dribbler",
    "dribblersens": "dribbler",
    "dribblingar": "dribbling",
    "dribblingarna": "dribbling",
    "dribblingarnas": "dribbling",
    "dribblingars": "dribbling",
    "dribblingen": "dribbling",
    "dribblingens": "dribbling",
    "dribblings": "dribbling",
    "drick": "dricka",
    "drickan": "dricka",
    "drickande": "dricka",
    "drickanden": "drickande",
    "drickandena": "drickande",
    "drickandenas": "drickande",
    "drickandens": "drickande",
    "drickandes": "drickande",
    "drickandet": "drickande",
    "drickandets": "drickande",
    "drickankar": "drickankare",
    "drickankaren": "drickankare",
    "drickankarens": "drickankare",
    "drickankares": "drickankare",
    "drickankaret": "drickankare",
    "drickankarets": "drickankare",
    "drickankarna": "drickankare",
    "drickankarnas": "drickankare",
    "drickans": "dricka",
    "drickas": "dricka",
    "drickat": "dricka",
    "drickats": "dricka",
    "drickbara": "drickbar",
    "drickbarare": "drickbar",
    "drickbarares": "drickbar",
    "drickbaras": "drickbar",
    "drickbarast": "drickbar",
    "drickbaraste": "drickbar",
    "drickbarastes": "drickbar",
    "drickbarasts": "drickbar",
    "drickbare": "drickbar",
    "drickbares": "drickbar",
    "drickbarheten": "drickbarhet",
    "drickbarhetens": "drickbarhet",
    "drickbarhets": "drickbarhet",
    "drickbars": "drickbar",
    "drickbart": "drickbar",
    "drickbarts": "drickbar",
    "dricke": "dricka",
    "dricker": "dricka",
    "drickes": "dricka",
    "drickor": "dricka",
    "drickorna": "dricka",
    "drickornas": "dricka",
    "drickors": "dricka",
    "dricks": "dricka",
    "dricksen": "dricks",
    "dricksens": "dricks",
    "dricksglasen": "dricksglas",
    "dricksglasens": "dricksglas",
    "dricksglaset": "dricksglas",
    "dricksglasets": "dricksglas",
    "drickspengar": "drickspeng",
    "drickspengarna": "drickspeng",
    "drickspengarnas": "drickspeng",
    "drickspengars": "drickspeng",
    "drickspengen": "drickspeng",
    "drickspengens": "drickspeng",
    "drickspengs": "drickspeng",
    "dricksvattens": "dricksvatten",
    "dricksvattnen": "dricksvatten",
    "dricksvattnens": "dricksvatten",
    "dricksvattnet": "dricksvatten",
    "dricksvattnets": "dricksvatten",
    "driftbudgetar": "driftbudget",
    "driftbudgetarna": "driftbudget",
    "driftbudgetarnas": "driftbudget",
    "driftbudgetars": "driftbudget",
    "driftbudgeten": "driftbudget",
    "driftbudgetens": "driftbudget",
    "driftbudgeter": "driftbudget",
    "driftbudgeterna": "driftbudget",
    "driftbudgeternas": "driftbudget",
    "driftbudgeters": "driftbudget",
    "driftbudgets": "driftbudget",
    "driften": "drift",
    "driftens": "drift",
    "drifter": "drift",
    "drifterna": "drift",
    "drifternas": "drift",
    "drifters": "drift",
    "driftiga": "driftig",
    "driftigare": "driftig",
    "driftigares": "driftig",
    "driftigas": "driftig",
    "driftigast": "driftig",
    "driftigaste": "driftig",
    "driftigastes": "driftig",
    "driftigasts": "driftig",
    "driftige": "driftig",
    "driftiges": "driftig",
    "driftigheten": "driftighet",
    "driftighetens": "driftighet",
    "driftighets": "driftighet",
    "driftigs": "driftig",
    "driftigt": "driftig",
    "driftigts": "driftig",
    "driftkostnaden": "driftkostnad",
    "driftkostnadens": "driftkostnad",
    "driftkostnader": "driftkostnad",
    "driftkostnaderna": "driftkostnad",
    "driftkostnadernas": "driftkostnad",
    "driftkostnaders": "driftkostnad",
    "driftkostnads": "driftkostnad",
    "driftkuckuar": "driftkucku",
    "driftkuckuarna": "driftkucku",
    "driftkuckuarnas": "driftkucku",
    "driftkuckuars": "driftkucku",
    "driftkuckun": "driftkucku",
    "driftkuckuns": "driftkucku",
    "driftkuckus": "driftkucku",
    "driftlivet": "driftliv",
    "driftlivets": "driftliv",
    "driftlivs": "driftliv",
    "driftmässiga": "driftmässig",
    "driftmässigare": "driftmässig",
    "driftmässigares": "driftmässig",
    "driftmässigas": "driftmässig",
    "driftmässigast": "driftmässig",
    "driftmässigaste": "driftmässig",
    "driftmässigastes": "driftmässig",
    "driftmässigasts": "driftmässig",
    "driftmässige": "driftmässig",
    "driftmässiges": "driftmässig",
    "driftmässigs": "driftmässig",
    "driftmässigt": "driftmässig",
    "driftmässigts": "driftmässig",
    "drifts": "drift",
    "driftskostnaden": "driftskostnad",
    "driftskostnadens": "driftskostnad",
    "driftskostnader": "driftskostnad",
    "driftskostnaderna": "driftskostnad",
    "driftskostnadernas": "driftskostnad",
    "driftskostnaders": "driftskostnad",
    "driftskostnads": "driftskostnad",
    "driftsmässiga": "driftsmässig",
    "driftsmässigare": "driftsmässig",
    "driftsmässigares": "driftsmässig",
    "driftsmässigas": "driftsmässig",
    "driftsmässigast": "driftsmässig",
    "driftsmässigaste": "driftsmässig",
    "driftsmässigastes": "driftsmässig",
    "driftsmässigasts": "driftsmässig",
    "driftsmässige": "driftsmässig",
    "driftsmässiges": "driftsmässig",
    "driftsmässigs": "driftsmässig",
    "driftsmässigt": "driftsmässig",
    "driftsmässigts": "driftsmässig",
    "driftsstöden": "driftsstöd",
    "driftsstödens": "driftsstöd",
    "driftsstödet": "driftsstöd",
    "driftsstödets": "driftsstöd",
    "driftsstöds": "driftsstöd",
    "driftstillstånden": "driftstillstånd",
    "driftstillståndens": "driftstillstånd",
    "driftstillståndet": "driftstillstånd",
    "driftstillståndets": "driftstillstånd",
    "driftstillstånds": "driftstillstånd",
    "driftstoppen": "driftstopp",
    "driftstoppens": "driftstopp",
    "driftstoppet": "driftstopp",
    "driftstoppets": "driftstopp",
    "driftstopps": "driftstopp",
    "driftsäkerheten": "driftsäkerhet",
    "driftsäkerhetens": "driftsäkerhet",
    "driftsäkerhets": "driftsäkerhet",
    "driftsäkerhetsmässiga": "driftsäkerhetsmässig",
    "driftsäkerhetsmässigare": "driftsäkerhetsmässig",
    "driftsäkerhetsmässigares": "driftsäkerhetsmässig",
    "driftsäkerhetsmässigas": "driftsäkerhetsmässig",
    "driftsäkerhetsmässigast": "driftsäkerhetsmässig",
    "driftsäkerhetsmässigaste": "driftsäkerhetsmässig",
    "driftsäkerhetsmässigastes": "driftsäkerhetsmässig",
    "driftsäkerhetsmässigasts": "driftsäkerhetsmässig",
    "driftsäkerhetsmässige": "driftsäkerhetsmässig",
    "driftsäkerhetsmässiges": "driftsäkerhetsmässig",
    "driftsäkerhetsmässigs": "driftsäkerhetsmässig",
    "driftsäkerhetsmässigt": "driftsäkerhetsmässig",
    "driftsäkerhetsmässigts": "driftsäkerhetsmässig",
    "driftsäkers": "driftsäker",
    "driftsäkert": "driftsäker",
    "driftsäkerts": "driftsäker",
    "driftsäkra": "driftsäker",
    "driftsäkrare": "driftsäker",
    "driftsäkrares": "driftsäker",
    "driftsäkras": "driftsäker",
    "driftsäkrast": "driftsäker",
    "driftsäkraste": "driftsäker",
    "driftsäkrastes": "driftsäker",
    "driftsäkrasts": "driftsäker",
    "driftsäkre": "driftsäker",
    "driftsäkres": "driftsäker",
    "drifttiden": "drifttid",
    "drifttidens": "drifttid",
    "drifttider": "drifttid",
    "drifttiderna": "drifttid",
    "drifttidernas": "drifttid",
    "drifttiders": "drifttid",
    "drifttids": "drifttid",
    "driftvärnet": "driftvärn",
    "driftvärnets": "driftvärn",
    "driftvärns": "driftvärn",
    "drill": "drilla",
    "drillad": "drilla",
    "drillade": "drilla",
    "drillades": "drilla",
    "drillads": "drilla",
    "drillande": "drilla",
    "drillanden": "drillande",
    "drillandena": "drillande",
    "drillandenas": "drillande",
    "drillandens": "drillande",
    "drillandes": "drillande",
    "drillandet": "drillande",
    "drillandets": "drillande",
    "drillar": "drilla",
    "drillarna": "drill",
    "drillarnas": "drill",
    "drillars": "drill",
    "drillas": "drilla",
    "drillat": "drilla",
    "drillats": "drilla",
    "drillborrar": "drillborr",
    "drillborrarna": "drillborr",
    "drillborrarnas": "drillborr",
    "drillborrars": "drillborr",
    "drillborren": "drillborr",
    "drillborrens": "drillborr",
    "drillborret": "drillborr",
    "drillborrets": "drillborr",
    "drillborrs": "drillborr",
    "drillen": "drill",
    "drillens": "drill",
    "drillingar": "drilling",
    "drillingarna": "drilling",
    "drillingarnas": "drilling",
    "drillingars": "drilling",
    "drillingen": "drilling",
    "drillingens": "drilling",
    "drillings": "drilling",
    "drillprogrammen": "drillprogram",
    "drillprogrammens": "drillprogram",
    "drillprogrammet": "drillprogram",
    "drillprogrammets": "drillprogram",
    "drillprograms": "drillprogram",
    "drills": "drill",
    "drillsnäpp": "drillsnäppa",
    "drillsnäppan": "drillsnäppa",
    "drillsnäppans": "drillsnäppa",
    "drillsnäppas": "drillsnäppa",
    "drillsnäppe": "drillsnäppa",
    "drillsnäppor": "drillsnäppa",
    "drillsnäpporna": "drillsnäppa",
    "drillsnäppornas": "drillsnäppa",
    "drillsnäppors": "drillsnäppa",
    "drillsnäpps": "drillsnäppa",
    "drinkar": "drinkare",
    "drinkaren": "drinkare",
    "drinkarens": "drinkare",
    "drinkares": "drinkare",
    "drinkarna": "drinkare",
    "drinkarnas": "drinkare",
    "drinkars": "drink",
    "drinken": "drink",
    "drinkens": "drink",
    "drinks": "drink",
    "dristiga": "dristig",
    "dristigare": "dristig",
    "dristigares": "dristig",
    "dristigas": "dristig",
    "dristigast": "dristig",
    "dristigaste": "dristig",
    "dristigastes": "dristig",
    "dristigasts": "dristig",
    "dristige": "dristig",
    "dristiges": "dristig",
    "dristigheten": "dristighet",
    "dristighetens": "dristighet",
    "dristighets": "dristighet",
    "dristigs": "dristig",
    "dristigt": "dristig",
    "dristigts": "dristig",
    "dritteln": "drittel",
    "drittelns": "drittel",
    "drittels": "drittel",
    "drittlar": "drittel",
    "drittlarna": "drittel",
    "drittlarnas": "drittel",
    "drittlars": "drittel",
    "driv": "driva",
    "drivan": "driva",
    "drivande": "driva",
    "drivanden": "drivande",
    "drivandena": "drivande",
    "drivandenas": "drivande",
    "drivandens": "drivande",
    "drivandes": "drivande",
    "drivandet": "drivande",
    "drivandets": "drivande",
    "drivankar": "drivankare",
    "drivankaren": "drivankare",
    "drivankarens": "drivankare",
    "drivankares": "drivankare",
    "drivankaret": "drivankare",
    "drivankarets": "drivankare",
    "drivankarna": "drivankare",
    "drivankarnas": "drivankare",
    "drivans": "driva",
    "drivar": "drive",
    "drivarna": "drive",
    "drivarnas": "drive",
    "drivars": "drive",
    "drivas": "driva",
    "drivaxeln": "drivaxel",
    "drivaxelns": "drivaxel",
    "drivaxels": "drivaxel",
    "drivaxlar": "drivaxel",
    "drivaxlarna": "drivaxel",
    "drivaxlarnas": "drivaxel",
    "drivaxlars": "drivaxel",
    "drivbanden": "drivband",
    "drivbandens": "drivband",
    "drivbandet": "drivband",
    "drivbandets": "drivband",
    "drivbands": "drivband",
    "drivbänkar": "drivbänk",
    "drivbänkarna": "drivbänk",
    "drivbänkarnas": "drivbänk",
    "drivbänkars": "drivbänk",
    "drivbänken": "drivbänk",
    "drivbänkens": "drivbänk",
    "drivbänks": "drivbänk",
    "drive": "driva",
    "driven": "drive",
    "drivenheten": "drivenhet",
    "drivenhetens": "drivenhet",
    "drivenhets": "drivenhet",
    "drivens": "driven",
    "driver": "driva",
    "drives": "drive",
    "drivet": "driven",
    "drivets": "driven",
    "drivfjädern": "drivfjäder",
    "drivfjäderns": "drivfjäder",
    "drivfjäders": "drivfjäder",
    "drivfjädrar": "drivfjäder",
    "drivfjädrarna": "drivfjäder",
    "drivfjädrarnas": "drivfjäder",
    "drivfjädrars": "drivfjäder",
    "drivflykten": "drivflykt",
    "drivflyktens": "drivflykt",
    "drivflykts": "drivflykt",
    "drivgarnen": "drivgarn",
    "drivgarnens": "drivgarn",
    "drivgarnet": "drivgarn",
    "drivgarnets": "drivgarn",
    "drivgarns": "drivgarn",
    "drivhjulen": "drivhjul",
    "drivhjulens": "drivhjul",
    "drivhjulet": "drivhjul",
    "drivhjulets": "drivhjul",
    "drivhjuls": "drivhjul",
    "drivhuseffekten": "drivhuseffekt",
    "drivhuseffektens": "drivhuseffekt",
    "drivhuseffekts": "drivhuseffekt",
    "drivhusen": "drivhus",
    "drivhusens": "drivhus",
    "drivhuset": "drivhus",
    "drivhusets": "drivhus",
    "drivhusklimatet": "drivhusklimat",
    "drivhusklimatets": "drivhusklimat",
    "drivhusklimats": "drivhusklimat",
    "drivhusplant": "drivhusplanta",
    "drivhusplantan": "drivhusplanta",
    "drivhusplantans": "drivhusplanta",
    "drivhusplantas": "drivhusplanta",
    "drivhusplante": "drivhusplanta",
    "drivhusplantor": "drivhusplanta",
    "drivhusplantorna": "drivhusplanta",
    "drivhusplantornas": "drivhusplanta",
    "drivhusplantors": "drivhusplanta",
    "drivhusplants": "drivhusplanta",
    "drivisen": "drivis",
    "drivisens": "drivis",
    "drivit": "driva",
    "drivits": "driva",
    "drivkedjan": "drivkedja",
    "drivkedjans": "drivkedja",
    "drivkedjas": "drivkedja",
    "drivkedje": "drivkedja",
    "drivkedjor": "drivkedja",
    "drivkedjorna": "drivkedja",
    "drivkedjornas": "drivkedja",
    "drivkedjors": "drivkedja",
    "drivkraften": "drivkraft",
    "drivkraftens": "drivkraft",
    "drivkrafter": "drivkraft",
    "drivkrafterna": "drivkraft",
    "drivkrafternas": "drivkraft",
    "drivkrafters": "drivkraft",
    "drivkrafts": "drivkraft",
    "drivlin": "drivlina",
    "drivlinan": "drivlina",
    "drivlinans": "drivlina",
    "drivlinas": "drivlina",
    "drivline": "drivlina",
    "drivlinor": "drivlina",
    "drivlinorna": "drivlina",
    "drivlinornas": "drivlina",
    "drivlinors": "drivlina",
    "drivlins": "drivlina",
    "drivmedels": "drivmedel",
    "drivmedelsbehoven": "drivmedelsbehov",
    "drivmedelsbehovens": "drivmedelsbehov",
    "drivmedelsbehovet": "drivmedelsbehov",
    "drivmedelsbehovets": "drivmedelsbehov",
    "drivmedelsbehovs": "drivmedelsbehov",
    "drivmedlen": "drivmedel",
    "drivmedlens": "drivmedel",
    "drivmedlet": "drivmedel",
    "drivmedlets": "drivmedel",
    "drivna": "driven",
    "drivnare": "driven",
    "drivnares": "driven",
    "drivnas": "driven",
    "drivnast": "driven",
    "drivnaste": "driven",
    "drivnastes": "driven",
    "drivnasts": "driven",
    "drivne": "driven",
    "drivnes": "driven",
    "drivningar": "drivning",
    "drivningarna": "drivning",
    "drivningarnas": "drivning",
    "drivningars": "drivning",
    "drivningen": "drivning",
    "drivningens": "drivning",
    "drivnings": "drivning",
    "drivor": "driva",
    "drivorna": "driva",
    "drivornas": "driva",
    "drivors": "driva",
    "drivremmar": "drivrem",
    "drivremmarna": "drivrem",
    "drivremmarnas": "drivrem",
    "drivremmars": "drivrem",
    "drivremmen": "drivrem",
    "drivremmens": "drivrem",
    "drivrems": "drivrem",
    "drivs": "driva",
    "drivsanden": "drivsand",
    "drivsandens": "drivsand",
    "drivsands": "drivsand",
    "drivsnön": "drivsnö",
    "drivsnöns": "drivsnö",
    "drivsnös": "drivsnö",
    "drivveden": "drivved",
    "drivvedens": "drivved",
    "drivveds": "drivved",
    "drog": "droga",
    "drogad": "droga",
    "drogade": "droga",
    "drogades": "droga",
    "drogads": "droga",
    "drogande": "droga",
    "droganden": "drogande",
    "drogandena": "drogande",
    "drogandenas": "drogande",
    "drogandens": "drogande",
    "drogandes": "drogande",
    "drogandet": "drogande",
    "drogandets": "drogande",
    "drogar": "droga",
    "drogas": "droga",
    "drogat": "droga",
    "drogats": "droga",
    "drogberoendes": "drogberoende",
    "drogberoendet": "drogberoende",
    "drogberoendets": "drogberoende",
    "droge": "dra",
    "drogen": "drog",
    "drogens": "drog",
    "droger": "drog",
    "drogerier": "drogeri",
    "drogerierna": "drogeri",
    "drogeriernas": "drogeri",
    "drogeriers": "drogeri",
    "drogeriet": "drogeri",
    "drogeriets": "drogeri",
    "drogeris": "drogeri",
    "drogerit": "drogeri",
    "drogerits": "drogeri",
    "drogerna": "drog",
    "drogernas": "drog",
    "drogers": "drog",
    "droges": "dra",
    "droghandeln": "droghandel",
    "droghandelns": "droghandel",
    "droghandels": "droghandel",
    "droghandlar": "droghandel",
    "droghandlarna": "droghandel",
    "droghandlarnas": "droghandel",
    "droghandlars": "droghandel",
    "drogmissbrukar": "drogmissbrukare",
    "drogmissbrukaren": "drogmissbrukare",
    "drogmissbrukarens": "drogmissbrukare",
    "drogmissbrukares": "drogmissbrukare",
    "drogmissbrukarna": "drogmissbrukare",
    "drogmissbrukarnas": "drogmissbrukare",
    "drogmissbruken": "drogmissbruk",
    "drogmissbrukens": "drogmissbruk",
    "drogmissbruket": "drogmissbruk",
    "drogmissbrukets": "drogmissbruk",
    "drogmissbruks": "drogmissbruk",
    "drogpolicier": "drogpolicy",
    "drogpolicierna": "drogpolicy",
    "drogpoliciernas": "drogpolicy",
    "drogpoliciers": "drogpolicy",
    "drogpolicies": "drogpolicy",
    "drogpoliciesarna": "drogpolicy",
    "drogpoliciesarnas": "drogpolicy",
    "drogpolicyer": "drogpolicy",
    "drogpolicyerna": "drogpolicy",
    "drogpolicyernas": "drogpolicy",
    "drogpolicyers": "drogpolicy",
    "drogpolicyn": "drogpolicy",
    "drogpolicyns": "drogpolicy",
    "drogpolicys": "drogpolicy",
    "drogpolicysar": "drogpolicy",
    "drogpolicysarna": "drogpolicy",
    "drogpolicysarnas": "drogpolicy",
    "drogpolicysars": "drogpolicy",
    "drogpåverkade": "drogpåverkad",
    "drogpåverkades": "drogpåverkad",
    "drogpåverkads": "drogpåverkad",
    "drogpåverkat": "drogpåverkad",
    "drogpåverkats": "drogpåverkad",
    "drogs": "drog",
    "drogsuget": "drogsug",
    "drogsugets": "drogsug",
    "drogsugs": "drogsug",
    "dromedaren": "dromedar",
    "dromedarens": "dromedar",
    "dromedarer": "dromedar",
    "dromedarerna": "dromedar",
    "dromedarernas": "dromedar",
    "dromedarers": "dromedar",
    "dromedars": "dromedar",
    "dronten": "dront",
    "drontens": "dront",
    "dronter": "dront",
    "dronterna": "dront",
    "dronternas": "dront",
    "dronters": "dront",
    "dronts": "dront",
    "drop-ins": "drop-in",
    "dropins": "dropin",
    "dropp": "droppe",
    "droppad": "droppa",
    "droppade": "droppa",
    "droppades": "droppa",
    "droppads": "droppa",
    "droppande": "droppa",
    "droppanden": "droppande",
    "droppandena": "droppande",
    "droppandenas": "droppande",
    "droppandens": "droppande",
    "droppandes": "droppande",
    "droppandet": "droppande",
    "droppandets": "droppande",
    "droppar": "droppe",
    "dropparna": "droppe",
    "dropparnas": "droppe",
    "droppars": "droppe",
    "droppas": "droppa",
    "droppat": "droppa",
    "droppats": "droppa",
    "droppen": "droppe",
    "droppens": "droppe",
    "droppes": "droppe",
    "droppet": "dropp",
    "droppets": "dropp",
    "droppflask": "droppflaska",
    "droppflaskan": "droppflaska",
    "droppflaskans": "droppflaska",
    "droppflaskas": "droppflaska",
    "droppflaske": "droppflaska",
    "droppflaskor": "droppflaska",
    "droppflaskorna": "droppflaska",
    "droppflaskornas": "droppflaska",
    "droppflaskors": "droppflaska",
    "droppfria": "droppfri",
    "droppfriare": "droppfri",
    "droppfriares": "droppfri",
    "droppfrias": "droppfri",
    "droppfriast": "droppfri",
    "droppfriaste": "droppfri",
    "droppfriastes": "droppfri",
    "droppfriasts": "droppfri",
    "droppfrie": "droppfri",
    "droppfries": "droppfri",
    "droppfris": "droppfri",
    "droppfritt": "droppfri",
    "droppfritts": "droppfri",
    "droppglasen": "droppglas",
    "droppglasens": "droppglas",
    "droppglaset": "droppglas",
    "droppglasets": "droppglas",
    "droppinfektionen": "droppinfektion",
    "droppinfektionens": "droppinfektion",
    "droppinfektioner": "droppinfektion",
    "droppinfektionerna": "droppinfektion",
    "droppinfektionernas": "droppinfektion",
    "droppinfektioners": "droppinfektion",
    "droppinfektions": "droppinfektion",
    "droppkorkar": "droppkork",
    "droppkorkarna": "droppkork",
    "droppkorkarnas": "droppkork",
    "droppkorkars": "droppkork",
    "droppkorken": "droppkork",
    "droppkorkens": "droppkork",
    "droppkorks": "droppkork",
    "dropps": "droppe",
    "droppspetsar": "droppspets",
    "droppspetsarna": "droppspets",
    "droppspetsarnas": "droppspets",
    "droppspetsars": "droppspets",
    "droppspetsen": "droppspets",
    "droppspetsens": "droppspets",
    "droppstenar": "droppsten",
    "droppstenarna": "droppsten",
    "droppstenarnas": "droppsten",
    "droppstenars": "droppsten",
    "droppstenen": "droppsten",
    "droppstenens": "droppsten",
    "droppstens": "droppsten",
    "drosk": "droska",
    "droskan": "droska",
    "droskans": "droska",
    "droskas": "droska",
    "droske": "droska",
    "droskförar": "droskförare",
    "droskföraren": "droskförare",
    "droskförarens": "droskförare",
    "droskförares": "droskförare",
    "droskförarna": "droskförare",
    "droskförarnas": "droskförare",
    "droskor": "droska",
    "droskorna": "droska",
    "droskornas": "droska",
    "droskors": "droska",
    "drosseln": "drossel",
    "drosselns": "drossel",
    "drossels": "drossel",
    "drosslar": "drossel",
    "drosslarna": "drossel",
    "drosslarnas": "drossel",
    "drosslars": "drossel",
    "drotsar": "drots",
    "drotsarna": "drots",
    "drotsarnas": "drots",
    "drotsars": "drots",
    "drotsen": "drots",
    "drotsens": "drots",
    "drottar": "drott",
    "drottarna": "drott",
    "drottarnas": "drott",
    "drottars": "drott",
    "drotten": "drott",
    "drottens": "drott",
    "drottkväden": "drottkväde",
    "drottkvädena": "drottkväde",
    "drottkvädenas": "drottkväde",
    "drottkvädens": "drottkväde",
    "drottkvädes": "drottkväde",
    "drottkvädet": "drottkväde",
    "drottkvädets": "drottkväde",
    "drottkväds": "drottkväde",
    "drottningar": "drottning",
    "drottningarna": "drottning",
    "drottningarnas": "drottning",
    "drottningars": "drottning",
    "drottningen": "drottning",
    "drottningens": "drottning",
    "drottnings": "drottning",
    "drottningsylten": "drottningsylt",
    "drottningsyltens": "drottningsylt",
    "drottningsylts": "drottningsylt",
    "drotts": "drott",
    "drucke": "dricka",
    "drucken": "dricka",
    "druckenheten": "druckenhet",
    "druckenhetens": "druckenhet",
    "druckenhets": "druckenhet",
    "druckens": "drucken",
    "druckes": "dricka",
    "drucket": "drucken",
    "druckets": "drucken",
    "druckit": "dricka",
    "druckits": "dricka",
    "druckna": "drucken",
    "drucknare": "drucken",
    "drucknares": "drucken",
    "drucknas": "drucken",
    "drucknast": "drucken",
    "drucknaste": "drucken",
    "drucknastes": "drucken",
    "drucknasts": "drucken",
    "druckne": "drucken",
    "drucknes": "drucken",
    "drufsar": "drufs",
    "drufsarna": "drufs",
    "drufsarnas": "drufs",
    "drufsars": "drufs",
    "drufsen": "drufs",
    "drufsens": "drufs",
    "druiden": "druid",
    "druidens": "druid",
    "druider": "druid",
    "druiderna": "druid",
    "druidernas": "druid",
    "druiders": "druid",
    "druids": "druid",
    "drular": "drul",
    "drularna": "drul",
    "drularnas": "drul",
    "drulars": "drul",
    "drulen": "drul",
    "drulens": "drul",
    "drull": "drulle",
    "drullade": "drulla",
    "drullades": "drulla",
    "drullande": "drulla",
    "drullanden": "drullande",
    "drullandena": "drullande",
    "drullandenas": "drullande",
    "drullandens": "drullande",
    "drullandes": "drullande",
    "drullandet": "drullande",
    "drullandets": "drullande",
    "drullar": "drulle",
    "drullarna": "drulle",
    "drullarnas": "drulle",
    "drullars": "drulle",
    "drullas": "drulla",
    "drullat": "drulla",
    "drullats": "drulla",
    "drulleförsäkringar": "drulleförsäkring",
    "drulleförsäkringarna": "drulleförsäkring",
    "drulleförsäkringarnas": "drulleförsäkring",
    "drulleförsäkringars": "drulleförsäkring",
    "drulleförsäkringen": "drulleförsäkring",
    "drulleförsäkringens": "drulleförsäkring",
    "drulleförsäkrings": "drulleförsäkring",
    "drullen": "drulle",
    "drullens": "drulle",
    "drulles": "drulle",
    "drulliga": "drullig",
    "drulligare": "drullig",
    "drulligares": "drullig",
    "drulligas": "drullig",
    "drulligast": "drullig",
    "drulligaste": "drullig",
    "drulligastes": "drullig",
    "drulligasts": "drullig",
    "drullige": "drullig",
    "drulliges": "drullig",
    "drulligheten": "drullighet",
    "drullighetens": "drullighet",
    "drulligheter": "drullighet",
    "drulligheterna": "drullighet",
    "drulligheternas": "drullighet",
    "drulligheters": "drullighet",
    "drullighets": "drullighet",
    "drulligs": "drullig",
    "drulligt": "drullig",
    "drulligts": "drullig",
    "drullputtar": "drullputt",
    "drullputtarna": "drullputt",
    "drullputtarnas": "drullputt",
    "drullputtars": "drullputt",
    "drullputten": "drullputt",
    "drullputtens": "drullputt",
    "drullputts": "drullputt",
    "drulls": "drulle",
    "druls": "drul",
    "drumlade": "drumla",
    "drumlades": "drumla",
    "drumlande": "drumla",
    "drumlanden": "drumlande",
    "drumlandena": "drumlande",
    "drumlandenas": "drumlande",
    "drumlandens": "drumlande",
    "drumlandes": "drumlande",
    "drumlandet": "drumlande",
    "drumlandets": "drumlande",
    "drumlar": "drummel",
    "drumlarna": "drummel",
    "drumlarnas": "drummel",
    "drumlars": "drummel",
    "drumlas": "drumla",
    "drumlat": "drumla",
    "drumlats": "drumla",
    "drumliga": "drumlig",
    "drumligare": "drumlig",
    "drumligares": "drumlig",
    "drumligas": "drumlig",
    "drumligast": "drumlig",
    "drumligaste": "drumlig",
    "drumligastes": "drumlig",
    "drumligasts": "drumlig",
    "drumlige": "drumlig",
    "drumliges": "drumlig",
    "drumligheten": "drumlighet",
    "drumlighetens": "drumlighet",
    "drumligheter": "drumlighet",
    "drumligheterna": "drumlighet",
    "drumligheternas": "drumlighet",
    "drumligheters": "drumlighet",
    "drumlighets": "drumlighet",
    "drumligs": "drumlig",
    "drumligt": "drumlig",
    "drumligts": "drumlig",
    "drummel": "drumla",
    "drummelaktiga": "drummelaktig",
    "drummelaktigare": "drummelaktig",
    "drummelaktigares": "drummelaktig",
    "drummelaktigas": "drummelaktig",
    "drummelaktigast": "drummelaktig",
    "drummelaktigaste": "drummelaktig",
    "drummelaktigastes": "drummelaktig",
    "drummelaktigasts": "drummelaktig",
    "drummelaktige": "drummelaktig",
    "drummelaktiges": "drummelaktig",
    "drummelaktigheten": "drummelaktighet",
    "drummelaktighetens": "drummelaktighet",
    "drummelaktighets": "drummelaktighet",
    "drummelaktigs": "drummelaktig",
    "drummelaktigt": "drummelaktig",
    "drummelaktigts": "drummelaktig",
    "drummeln": "drummel",
    "drummelns": "drummel",
    "drummels": "drummel",
    "drummlar": "drummel",
    "drummlarna": "drummel",
    "drummlarnas": "drummel",
    "drummlars": "drummel",
    "drunknad": "drunkna",
    "drunknade": "drunkna",
    "drunknades": "drunkna",
    "drunknads": "drunkna",
    "drunknande": "drunkna",
    "drunknanden": "drunknande",
    "drunknandena": "drunknande",
    "drunknandenas": "drunknande",
    "drunknandens": "drunknande",
    "drunknandes": "drunknande",
    "drunknandet": "drunknande",
    "drunknandets": "drunknande",
    "drunknar": "drunkna",
    "drunknas": "drunkna",
    "drunknat": "drunkna",
    "drunknats": "drunkna",
    "drunkningar": "drunkning",
    "drunkningarna": "drunkning",
    "drunkningarnas": "drunkning",
    "drunkningars": "drunkning",
    "drunkningen": "drunkning",
    "drunkningens": "drunkning",
    "drunknings": "drunkning",
    "drunkningsolyck": "drunkningsolycka",
    "drunkningsolyckan": "drunkningsolycka",
    "drunkningsolyckans": "drunkningsolycka",
    "drunkningsolyckas": "drunkningsolycka",
    "drunkningsolycke": "drunkningsolycka",
    "drunkningsolyckor": "drunkningsolycka",
    "drunkningsolyckorna": "drunkningsolycka",
    "drunkningsolyckornas": "drunkningsolycka",
    "drunkningsolyckors": "drunkningsolycka",
    "drunkningsolycks": "drunkningsolycka",
    "drupit": "drypa",
    "drusen": "drus",
    "drusens": "drus",
    "druser": "drus",
    "druserna": "drus",
    "drusernas": "drus",
    "drusers": "drus",
    "druv": "druva",
    "druvan": "druva",
    "druvans": "druva",
    "druvas": "druva",
    "druvblåa": "druvblå",
    "druvblåare": "druvblå",
    "druvblåares": "druvblå",
    "druvblåas": "druvblå",
    "druvblåast": "druvblå",
    "druvblåaste": "druvblå",
    "druvblåastes": "druvblå",
    "druvblåasts": "druvblå",
    "druvblåe": "druvblå",
    "druvblåes": "druvblå",
    "druvblås": "druvblå",
    "druvblått": "druvblå",
    "druvblåtts": "druvblå",
    "druvbörden": "druvbörd",
    "druvbördens": "druvbörd",
    "druvbörder": "druvbörd",
    "druvbörderna": "druvbörd",
    "druvbördernas": "druvbörd",
    "druvbörders": "druvbörd",
    "druvbörds": "druvbörd",
    "druve": "druva",
    "druvflädern": "druvfläder",
    "druvfläderns": "druvfläder",
    "druvfläders": "druvfläder",
    "druvflädrar": "druvfläder",
    "druvflädrarna": "druvfläder",
    "druvflädrarnas": "druvfläder",
    "druvflädrars": "druvfläder",
    "druvgurk": "druvgurka",
    "druvgurkan": "druvgurka",
    "druvgurkans": "druvgurka",
    "druvgurkas": "druvgurka",
    "druvgurke": "druvgurka",
    "druvgurkor": "druvgurka",
    "druvgurkorna": "druvgurka",
    "druvgurkornas": "druvgurka",
    "druvgurkors": "druvgurka",
    "druvgurks": "druvgurka",
    "druvhagels": "druvhagel",
    "druvhaglen": "druvhagel",
    "druvhaglens": "druvhagel",
    "druvhaglet": "druvhagel",
    "druvhaglets": "druvhagel",
    "druvklas": "druvklase",
    "druvklasar": "druvklase",
    "druvklasarna": "druvklase",
    "druvklasarnas": "druvklase",
    "druvklasars": "druvklase",
    "druvklasen": "druvklase",
    "druvklasens": "druvklase",
    "druvklases": "druvklase",
    "druvor": "druva",
    "druvorna": "druva",
    "druvornas": "druva",
    "druvors": "druva",
    "druvrussinen": "druvrussin",
    "druvrussinens": "druvrussin",
    "druvrussinet": "druvrussin",
    "druvrussinets": "druvrussin",
    "druvrussins": "druvrussin",
    "druvs": "druva",
    "druvsockers": "druvsocker",
    "druvsockret": "druvsocker",
    "druvsockrets": "druvsocker",
    "dryaden": "dryad",
    "dryadens": "dryad",
    "dryader": "dryad",
    "dryaderna": "dryad",
    "dryadernas": "dryad",
    "dryaders": "dryad",
    "dryads": "dryad",
    "drycken": "dryck",
    "dryckens": "dryck",
    "dryckenskapen": "dryckenskap",
    "dryckenskapens": "dryckenskap",
    "dryckenskaps": "dryckenskap",
    "drycker": "dryck",
    "dryckerna": "dryck",
    "dryckernas": "dryck",
    "dryckers": "dryck",
    "dryckesbrodern": "dryckesbroder",
    "dryckesbroderns": "dryckesbroder",
    "dryckesbroders": "dryckesbroder",
    "dryckesbröder": "dryckesbroder",
    "dryckesbröderna": "dryckesbroder",
    "dryckesbrödernas": "dryckesbroder",
    "dryckesbröders": "dryckesbroder",
    "dryckesbägar": "dryckesbägare",
    "dryckesbägaren": "dryckesbägare",
    "dryckesbägarens": "dryckesbägare",
    "dryckesbägares": "dryckesbägare",
    "dryckesbägarna": "dryckesbägare",
    "dryckesbägarnas": "dryckesbägare",
    "dryckeshornen": "dryckeshorn",
    "dryckeshornens": "dryckeshorn",
    "dryckeshornet": "dryckeshorn",
    "dryckeshornets": "dryckeshorn",
    "dryckeshorns": "dryckeshorn",
    "dryckeskärlen": "dryckeskärl",
    "dryckeskärlens": "dryckeskärl",
    "dryckeskärlet": "dryckeskärl",
    "dryckeskärlets": "dryckeskärl",
    "dryckeskärls": "dryckeskärl",
    "dryckeslagen": "dryckeslag",
    "dryckeslagens": "dryckeslag",
    "dryckeslaget": "dryckeslag",
    "dryckeslagets": "dryckeslag",
    "dryckeslags": "dryckeslag",
    "dryckesoffers": "dryckesoffer",
    "dryckesoffren": "dryckesoffer",
    "dryckesoffrens": "dryckesoffer",
    "dryckesoffret": "dryckesoffer",
    "dryckesoffrets": "dryckesoffer",
    "dryckesservisen": "dryckesservis",
    "dryckesservisens": "dryckesservis",
    "dryckesserviser": "dryckesservis",
    "dryckesserviserna": "dryckesservis",
    "dryckesservisernas": "dryckesservis",
    "dryckesservisers": "dryckesservis",
    "dryckesvis": "dryckesvisa",
    "dryckesvisan": "dryckesvisa",
    "dryckesvisans": "dryckesvisa",
    "dryckesvisas": "dryckesvisa",
    "dryckesvise": "dryckesvisa",
    "dryckesvisor": "dryckesvisa",
    "dryckesvisorna": "dryckesvisa",
    "dryckesvisornas": "dryckesvisa",
    "dryckesvisors": "dryckesvisa",
    "dryckjomen": "dryckjom",
    "dryckjomens": "dryckjom",
    "dryckjomet": "dryckjom",
    "dryckjomets": "dryckjom",
    "dryckjoms": "dryckjom",
    "drycks": "dryck",
    "dryft": "dryfta",
    "dryftad": "dryfta",
    "dryftade": "dryfta",
    "dryftades": "dryfta",
    "dryftads": "dryfta",
    "dryftande": "dryfta",
    "dryftanden": "dryftande",
    "dryftandena": "dryftande",
    "dryftandenas": "dryftande",
    "dryftandens": "dryftande",
    "dryftandes": "dryftande",
    "dryftandet": "dryftande",
    "dryftandets": "dryftande",
    "dryftar": "dryfta",
    "dryftas": "dryfta",
    "dryftat": "dryfta",
    "dryftats": "dryfta",
    "dryga": "dryg",
    "drygare": "dryg",
    "drygares": "dryg",
    "drygas": "dryg",
    "drygast": "dryg",
    "drygaste": "dryg",
    "drygastes": "dryg",
    "drygasts": "dryg",
    "dryge": "dryg",
    "dryges": "dryg",
    "drygheten": "dryghet",
    "dryghetens": "dryghet",
    "drygheter": "dryghet",
    "drygheterna": "dryghet",
    "drygheternas": "dryghet",
    "drygheters": "dryghet",
    "dryghets": "dryghet",
    "drygs": "dryg",
    "drygseln": "drygsel",
    "drygselns": "drygsel",
    "drygsels": "drygsel",
    "drygt": "dryg",
    "drygts": "dryg",
    "dryp": "drypa",
    "drypande": "drypa",
    "drypanden": "drypande",
    "drypandena": "drypande",
    "drypandenas": "drypande",
    "drypandens": "drypande",
    "drypandes": "drypande",
    "drypandet": "drypande",
    "drypandets": "drypande",
    "drype": "drypa",
    "dryper": "drypa",
    "drypt": "drypa",
    "drägel": "drägla",
    "drägeln": "drägel",
    "drägelns": "drägel",
    "drägels": "drägel",
    "dräggen": "drägg",
    "dräggens": "drägg",
    "dräggs": "drägg",
    "dräglade": "drägla",
    "dräglades": "drägla",
    "dräglande": "drägla",
    "dräglanden": "dräglande",
    "dräglandena": "dräglande",
    "dräglandenas": "dräglande",
    "dräglandens": "dräglande",
    "dräglandes": "dräglande",
    "dräglandet": "dräglande",
    "dräglandets": "dräglande",
    "dräglar": "drägla",
    "dräglas": "drägla",
    "dräglat": "drägla",
    "dräglats": "drägla",
    "dräglet": "drägel",
    "dräglets": "drägel",
    "drägliga": "dräglig",
    "drägligare": "dräglig",
    "drägligares": "dräglig",
    "drägligas": "dräglig",
    "drägligast": "dräglig",
    "drägligaste": "dräglig",
    "drägligastes": "dräglig",
    "drägligasts": "dräglig",
    "dräglige": "dräglig",
    "drägliges": "dräglig",
    "drägligheten": "dräglighet",
    "dräglighetens": "dräglighet",
    "dräglighets": "dräglighet",
    "drägligs": "dräglig",
    "drägligt": "dräglig",
    "drägligts": "dräglig",
    "dräkten": "dräkt",
    "dräktens": "dräkt",
    "dräkter": "dräkt",
    "dräkterna": "dräkt",
    "dräkternas": "dräkt",
    "dräkters": "dräkt",
    "dräktiga": "dräktig",
    "dräktigare": "dräktig",
    "dräktigares": "dräktig",
    "dräktigas": "dräktig",
    "dräktigast": "dräktig",
    "dräktigaste": "dräktig",
    "dräktigastes": "dräktig",
    "dräktigasts": "dräktig",
    "dräktige": "dräktig",
    "dräktiges": "dräktig",
    "dräktigheten": "dräktighet",
    "dräktighetens": "dräktighet",
    "dräktigheter": "dräktighet",
    "dräktigheterna": "dräktighet",
    "dräktigheternas": "dräktighet",
    "dräktigheters": "dräktighet",
    "dräktighets": "dräktighet",
    "dräktigs": "dräktig",
    "dräktigt": "dräktig",
    "dräktigts": "dräktig",
    "dräkts": "dräkt",
    "dräktspännen": "dräktspänne",
    "dräktspännena": "dräktspänne",
    "dräktspännenas": "dräktspänne",
    "dräktspännens": "dräktspänne",
    "dräktspännes": "dräktspänne",
    "dräktspännet": "dräktspänne",
    "dräktspännets": "dräktspänne",
    "dräktspänns": "dräktspänne",
    "dräll": "drälla",
    "drällande": "drälla",
    "drällanden": "drällande",
    "drällandena": "drällande",
    "drällandenas": "drällande",
    "drällandens": "drällande",
    "drällandes": "drällande",
    "drällandet": "drällande",
    "drällandets": "drällande",
    "drällde": "drälla",
    "drällen": "dräll",
    "drällens": "dräll",
    "dräller": "drälla",
    "drälls": "dräll",
    "drällt": "drälla",
    "dräm": "drämma",
    "drämd": "drämma",
    "drämda": "drämma",
    "drämdas": "drämma",
    "drämde": "drämma",
    "drämdes": "drämma",
    "drämds": "drämma",
    "drämmande": "drämma",
    "drämmanden": "drämmande",
    "drämmandena": "drämmande",
    "drämmandenas": "drämmande",
    "drämmandens": "drämmande",
    "drämmandes": "drämmande",
    "drämmandet": "drämmande",
    "drämmandets": "drämmande",
    "drämmas": "drämma",
    "drämmer": "drämma",
    "dräms": "drämma",
    "drämt": "drämma",
    "drämts": "drämma",
    "dränages": "dränage",
    "dränaget": "dränage",
    "dränagets": "dränage",
    "dränen": "drän",
    "dränens": "drän",
    "dräner": "drän",
    "dränerad": "dränera",
    "dränerade": "dränera",
    "dränerades": "dränera",
    "dränerads": "dränera",
    "dränerande": "dränera",
    "dräneranden": "dränerande",
    "dränerandena": "dränerande",
    "dränerandenas": "dränerande",
    "dränerandens": "dränerande",
    "dränerandes": "dränerande",
    "dränerandet": "dränerande",
    "dränerandets": "dränerande",
    "dränerar": "dränera",
    "dräneras": "dränera",
    "dränerat": "dränera",
    "dränerats": "dränera",
    "dränerbara": "dränerbar",
    "dränerbarare": "dränerbar",
    "dränerbarares": "dränerbar",
    "dränerbaras": "dränerbar",
    "dränerbarast": "dränerbar",
    "dränerbaraste": "dränerbar",
    "dränerbarastes": "dränerbar",
    "dränerbarasts": "dränerbar",
    "dränerbare": "dränerbar",
    "dränerbares": "dränerbar",
    "dränerbarheten": "dränerbarhet",
    "dränerbarhetens": "dränerbarhet",
    "dränerbarhets": "dränerbarhet",
    "dränerbars": "dränerbar",
    "dränerbart": "dränerbar",
    "dränerbarts": "dränerbar",
    "dräneringar": "dränering",
    "dräneringarna": "dränering",
    "dräneringarnas": "dränering",
    "dräneringars": "dränering",
    "dräneringen": "dränering",
    "dräneringens": "dränering",
    "dränerings": "dränering",
    "dräneringsdiken": "dräneringsdike",
    "dräneringsdikena": "dräneringsdike",
    "dräneringsdikenas": "dräneringsdike",
    "dräneringsdikens": "dräneringsdike",
    "dräneringsdikes": "dräneringsdike",
    "dräneringsdiket": "dräneringsdike",
    "dräneringsdikets": "dräneringsdike",
    "dräneringsområden": "dräneringsområde",
    "dräneringsområdena": "dräneringsområde",
    "dräneringsområdenas": "dräneringsområde",
    "dräneringsområdens": "dräneringsområde",
    "dräneringsområdes": "dräneringsområde",
    "dräneringsområdet": "dräneringsområde",
    "dräneringsområdets": "dräneringsområde",
    "dränerna": "drän",
    "dränernas": "drän",
    "dräners": "drän",
    "drängar": "dräng",
    "drängarna": "dräng",
    "drängarnas": "dräng",
    "drängars": "dräng",
    "drängen": "dräng",
    "drängens": "dräng",
    "drängs": "dräng",
    "drängtjänsten": "drängtjänst",
    "drängtjänstens": "drängtjänst",
    "drängtjänster": "drängtjänst",
    "drängtjänsterna": "drängtjänst",
    "drängtjänsternas": "drängtjänst",
    "drängtjänsters": "drängtjänst",
    "drängtjänsts": "drängtjänst",
    "dränk": "dränka",
    "dränkande": "dränka",
    "dränkanden": "dränkande",
    "dränkandena": "dränkande",
    "dränkandenas": "dränkande",
    "dränkandens": "dränkande",
    "dränkandes": "dränkande",
    "dränkandet": "dränkande",
    "dränkandets": "dränkande",
    "dränkas": "dränka",
    "dränkbara": "dränkbar",
    "dränkbarare": "dränkbar",
    "dränkbarares": "dränkbar",
    "dränkbaras": "dränkbar",
    "dränkbarast": "dränkbar",
    "dränkbaraste": "dränkbar",
    "dränkbarastes": "dränkbar",
    "dränkbarasts": "dränkbar",
    "dränkbare": "dränkbar",
    "dränkbares": "dränkbar",
    "dränkbarheten": "dränkbarhet",
    "dränkbarhetens": "dränkbarhet",
    "dränkbarhets": "dränkbarhet",
    "dränkbars": "dränkbar",
    "dränkbart": "dränkbar",
    "dränkbarts": "dränkbar",
    "dränker": "dränka",
    "dränkes": "dränka",
    "dränks": "dränka",
    "dränkt": "dränka",
    "dränkta": "dränka",
    "dränktas": "dränka",
    "dränkte": "dränka",
    "dränktes": "dränka",
    "dränkts": "dränka",
    "dräns": "drän",
    "dräp": "dräpa",
    "dräpande": "dräpa",
    "dräpanden": "dräpande",
    "dräpandena": "dräpande",
    "dräpandenas": "dräpande",
    "dräpandens": "dräpande",
    "dräpandes": "dräpande",
    "dräpandet": "dräpande",
    "dräpandets": "dräpande",
    "dräpas": "dräpa",
    "dräper": "dräpa",
    "dräpes": "dräpa",
    "dräps": "dräpa",
    "dräpt": "dräpa",
    "dräpta": "dräpa",
    "dräptas": "dräpa",
    "dräpte": "dräpa",
    "dräptes": "dräpa",
    "dräpts": "dräpa",
    "drätselkammar": "drätselkammare",
    "drätselkammaren": "drätselkammare",
    "drätselkammarens": "drätselkammare",
    "drätselkammares": "drätselkammare",
    "drätselkamrar": "drätselkammare",
    "drätselkamrarna": "drätselkammare",
    "drätselkamrarnas": "drätselkammare",
    "drätselkamrars": "drätselkammare",
    "drätseln": "drätsel",
    "drätselns": "drätsel",
    "drätsels": "drätsel",
    "drättar": "drätt",
    "drättarna": "drätt",
    "drättarnas": "drätt",
    "drättars": "drätt",
    "drätten": "drätt",
    "drättens": "drätt",
    "drätts": "drätt",
    "dråpar": "dråpare",
    "dråparen": "dråpare",
    "dråparens": "dråpare",
    "dråpares": "dråpare",
    "dråparna": "dråpare",
    "dråparnas": "dråpare",
    "dråpen": "dråp",
    "dråpens": "dråp",
    "dråpet": "dråp",
    "dråpets": "dråp",
    "dråpliga": "dråplig",
    "dråpligare": "dråplig",
    "dråpligares": "dråplig",
    "dråpligas": "dråplig",
    "dråpligast": "dråplig",
    "dråpligaste": "dråplig",
    "dråpligastes": "dråplig",
    "dråpligasts": "dråplig",
    "dråplige": "dråplig",
    "dråpliges": "dråplig",
    "dråpligheten": "dråplighet",
    "dråplighetens": "dråplighet",
    "dråpligheter": "dråplighet",
    "dråpligheterna": "dråplighet",
    "dråpligheternas": "dråplighet",
    "dråpligheters": "dråplighet",
    "dråplighets": "dråplighet",
    "dråpligs": "dråplig",
    "dråpligt": "dråplig",
    "dråpligts": "dråplig",
    "dråps": "dråp",
    "dråpslagen": "dråpslag",
    "dråpslagens": "dråpslag",
    "dråpslaget": "dråpslag",
    "dråpslagets": "dråpslag",
    "dråpslags": "dråpslag",
    "drås": "dråse",
    "dråsade": "dråsa",
    "dråsades": "dråsa",
    "dråsande": "dråsa",
    "dråsanden": "dråsande",
    "dråsandena": "dråsande",
    "dråsandenas": "dråsande",
    "dråsandens": "dråsande",
    "dråsandes": "dråsande",
    "dråsandet": "dråsande",
    "dråsandets": "dråsande",
    "dråsar": "dråse",
    "dråsarna": "dråse",
    "dråsarnas": "dråse",
    "dråsars": "dråse",
    "dråsas": "dråsa",
    "dråsat": "dråsa",
    "dråsats": "dråsa",
    "dråsen": "dråse",
    "dråsens": "dråse",
    "dråses": "dråse",
    "drögar": "drög",
    "drögarna": "drög",
    "drögarnas": "drög",
    "drögars": "drög",
    "drögen": "drög",
    "drögens": "drög",
    "dröglappar": "dröglapp",
    "dröglapparna": "dröglapp",
    "dröglapparnas": "dröglapp",
    "dröglappars": "dröglapp",
    "dröglappen": "dröglapp",
    "dröglappens": "dröglapp",
    "dröglapps": "dröglapp",
    "drögs": "drög",
    "dröj": "dröja",
    "dröjande": "dröja",
    "dröjanden": "dröjande",
    "dröjandena": "dröjande",
    "dröjandenas": "dröjande",
    "dröjandens": "dröjande",
    "dröjandes": "dröjande",
    "dröjandet": "dröjande",
    "dröjandets": "dröjande",
    "dröjde": "dröja",
    "dröjer": "dröja",
    "dröjsmålen": "dröjsmål",
    "dröjsmålens": "dröjsmål",
    "dröjsmålet": "dröjsmål",
    "dröjsmålets": "dröjsmål",
    "dröjsmåls": "dröjsmål",
    "dröjsmålsräntan": "dröjsmålsränta",
    "dröjsmålsräntans": "dröjsmålsränta",
    "dröjsmålsräntas": "dröjsmålsränta",
    "dröjsmålsränte": "dröjsmålsränta",
    "dröjsmålsräntor": "dröjsmålsränta",
    "dröjsmålsräntorna": "dröjsmålsränta",
    "dröjsmålsräntornas": "dröjsmålsränta",
    "dröjsmålsräntors": "dröjsmålsränta",
    "dröjt": "dröja",
    "dröm": "drömma",
    "drömboken": "drömbok",
    "drömbokens": "drömbok",
    "drömboks": "drömbok",
    "drömböcker": "drömbok",
    "drömböckerna": "drömbok",
    "drömböckernas": "drömbok",
    "drömböckers": "drömbok",
    "drömd": "drömma",
    "drömda": "drömma",
    "drömdas": "drömma",
    "drömde": "drömma",
    "drömdejtar": "drömdejt",
    "drömdejtarna": "drömdejt",
    "drömdejtarnas": "drömdejt",
    "drömdejtars": "drömdejt",
    "drömdejten": "drömdejt",
    "drömdejtens": "drömdejt",
    "drömdejts": "drömdejt",
    "drömdes": "drömma",
    "drömds": "drömma",
    "drömgränsen": "drömgräns",
    "drömgränsens": "drömgräns",
    "drömgränser": "drömgräns",
    "drömgränserna": "drömgräns",
    "drömgränsernas": "drömgräns",
    "drömgränsers": "drömgräns",
    "drömkandidaten": "drömkandidat",
    "drömkandidatens": "drömkandidat",
    "drömkandidater": "drömkandidat",
    "drömkandidaterna": "drömkandidat",
    "drömkandidaternas": "drömkandidat",
    "drömkandidaters": "drömkandidat",
    "drömkandidats": "drömkandidat",
    "drömlandskapen": "drömlandskap",
    "drömlandskapens": "drömlandskap",
    "drömlandskapet": "drömlandskap",
    "drömlandskapets": "drömlandskap",
    "drömlandskaps": "drömlandskap",
    "drömmande": "drömma",
    "drömmanden": "drömmande",
    "drömmandena": "drömmande",
    "drömmandenas": "drömmande",
    "drömmandens": "drömmande",
    "drömmandes": "drömmande",
    "drömmandet": "drömmande",
    "drömmandets": "drömmande",
    "drömmar": "drömmare",
    "drömmaren": "drömmare",
    "drömmarens": "drömmare",
    "drömmares": "drömmare",
    "drömmarna": "drömmare",
    "drömmarnas": "drömmare",
    "drömmars": "dröm",
    "drömmas": "drömma",
    "drömmen": "dröm",
    "drömmens": "dröm",
    "drömmer": "drömma",
    "drömmerier": "drömmeri",
    "drömmerierna": "drömmeri",
    "drömmeriernas": "drömmeri",
    "drömmeriers": "drömmeri",
    "drömmeriet": "drömmeri",
    "drömmeriets": "drömmeri",
    "drömmeris": "drömmeri",
    "drömmerit": "drömmeri",
    "drömmerits": "drömmeri",
    "drömmilen": "drömmil",
    "drömmilens": "drömmil",
    "drömmils": "drömmil",
    "drömmålen": "drömmål",
    "drömmålens": "drömmål",
    "drömmålet": "drömmål",
    "drömmålets": "drömmål",
    "drömmåls": "drömmål",
    "drömresan": "drömresa",
    "drömresans": "drömresa",
    "drömresas": "drömresa",
    "drömrese": "drömresa",
    "drömresor": "drömresa",
    "drömresorna": "drömresa",
    "drömresornas": "drömresa",
    "drömresors": "drömresa",
    "dröms": "drömma",
    "drömska": "drömsk",
    "drömskare": "drömsk",
    "drömskares": "drömsk",
    "drömskas": "drömsk",
    "drömskast": "drömsk",
    "drömskaste": "drömsk",
    "drömskastes": "drömsk",
    "drömskasts": "drömsk",
    "drömske": "drömsk",
    "drömskes": "drömsk",
    "drömskheten": "drömskhet",
    "drömskhetens": "drömskhet",
    "drömskhets": "drömskhet",
    "drömsks": "drömsk",
    "drömskt": "drömsk",
    "drömskts": "drömsk",
    "drömslotten": "drömslott",
    "drömslottens": "drömslott",
    "drömslottet": "drömslott",
    "drömslottets": "drömslott",
    "drömslotts": "drömslott",
    "drömstarten": "drömstart",
    "drömstartens": "drömstart",
    "drömstarter": "drömstart",
    "drömstarterna": "drömstart",
    "drömstarternas": "drömstart",
    "drömstarters": "drömstart",
    "drömstarts": "drömstart",
    "drömsällskapen": "drömsällskap",
    "drömsällskapens": "drömsällskap",
    "drömsällskapet": "drömsällskap",
    "drömsällskapets": "drömsällskap",
    "drömsällskaps": "drömsällskap",
    "drömsömnen": "drömsömn",
    "drömsömnens": "drömsömn",
    "drömsömns": "drömsömn",
    "drömt": "drömma",
    "drömts": "drömma",
    "drömtydanden": "drömtydande",
    "drömtydandena": "drömtydande",
    "drömtydandenas": "drömtydande",
    "drömtydandens": "drömtydande",
    "drömtydandes": "drömtydande",
    "drömtydandet": "drömtydande",
    "drömtydandets": "drömtydande",
    "drömtydningar": "drömtydning",
    "drömtydningarna": "drömtydning",
    "drömtydningarnas": "drömtydning",
    "drömtydningars": "drömtydning",
    "drömtydningen": "drömtydning",
    "drömtydningens": "drömtydning",
    "drömtydnings": "drömtydning",
    "drömvärldar": "drömvärld",
    "drömvärldarna": "drömvärld",
    "drömvärldarnas": "drömvärld",
    "drömvärldars": "drömvärld",
    "drömvärlden": "drömvärld",
    "drömvärldens": "drömvärld",
    "drömvärlds": "drömvärld",
    "drön": "dröna",
    "drönade": "dröna",
    "drönades": "dröna",
    "drönande": "dröna",
    "drönanden": "drönande",
    "drönandena": "drönande",
    "drönandenas": "drönande",
    "drönandens": "drönande",
    "drönandes": "drönande",
    "drönandet": "drönande",
    "drönandets": "drönande",
    "drönar": "drönare",
    "drönaren": "drönare",
    "drönarens": "drönare",
    "drönares": "drönare",
    "drönarna": "drönare",
    "drönarnas": "drönare",
    "drönarräden": "drönarräd",
    "drönarrädens": "drönarräd",
    "drönarräder": "drönarräd",
    "drönarräderna": "drönarräd",
    "drönarrädernas": "drönarräd",
    "drönarräders": "drönarräd",
    "drönarräds": "drönarräd",
    "drönas": "dröna",
    "drönat": "dröna",
    "drönats": "dröna",
    "dröp": "drypa",
    "dröpe": "drypa",
    "dröppeln": "dröppel",
    "dröppelns": "dröppel",
    "dröppels": "dröppel",
    "drös": "dröse",
    "drösade": "drösa",
    "drösades": "drösa",
    "drösande": "drösa",
    "drösanden": "drösande",
    "drösandena": "drösande",
    "drösandenas": "drösande",
    "drösandens": "drösande",
    "drösandes": "drösande",
    "drösandet": "drösande",
    "drösandets": "drösande",
    "drösar": "dröse",
    "drösarna": "dröse",
    "drösarnas": "dröse",
    "drösars": "dröse",
    "drösas": "drösa",
    "drösat": "drösa",
    "drösats": "drösa",
    "drösen": "dröse",
    "drösens": "dröse",
    "dröser": "drösa",
    "dröses": "dröse",
    "dröst": "drösa",
    "dröste": "drösa",
    "dröstes": "drösa",
    "drösts": "drösa",
    "du": "dua",
    "duad": "dua",
    "duade": "dua",
    "duades": "dua",
    "duads": "dua",
    "dualisen": "dualis",
    "dualisens": "dualis",
    "dualismen": "dualism",
    "dualismens": "dualism",
    "dualismer": "dualism",
    "dualismerna": "dualism",
    "dualismernas": "dualism",
    "dualismers": "dualism",
    "dualisms": "dualism",
    "dualisten": "dualist",
    "dualistens": "dualist",
    "dualister": "dualist",
    "dualisterna": "dualist",
    "dualisternas": "dualist",
    "dualisters": "dualist",
    "dualistiska": "dualistisk",
    "dualistiskare": "dualistisk",
    "dualistiskares": "dualistisk",
    "dualistiskas": "dualistisk",
    "dualistiskast": "dualistisk",
    "dualistiskaste": "dualistisk",
    "dualistiskastes": "dualistisk",
    "dualistiskasts": "dualistisk",
    "dualistiske": "dualistisk",
    "dualistiskes": "dualistisk",
    "dualistisks": "dualistisk",
    "dualistiskt": "dualistisk",
    "dualistiskts": "dualistisk",
    "dualists": "dualist",
    "duande": "dua",
    "duanden": "duande",
    "duandena": "duande",
    "duandenas": "duande",
    "duandens": "duande",
    "duandes": "duande",
    "duandet": "duande",
    "duandets": "duande",
    "duar": "dua",
    "duas": "dua",
    "duat": "dua",
    "duats": "dua",
    "dubb": "dubba",
    "dubbad": "dubba",
    "dubbade": "dubba",
    "dubbades": "dubba",
    "dubbads": "dubba",
    "dubbande": "dubba",
    "dubbanden": "dubbande",
    "dubbandena": "dubbande",
    "dubbandenas": "dubbande",
    "dubbandens": "dubbande",
    "dubbandes": "dubbande",
    "dubbandet": "dubbande",
    "dubbandets": "dubbande",
    "dubbar": "dubba",
    "dubbarna": "dubb",
    "dubbarnas": "dubb",
    "dubbars": "dubb",
    "dubbas": "dubba",
    "dubbat": "dubba",
    "dubbats": "dubba",
    "dubbdäcken": "dubbdäck",
    "dubbdäckens": "dubbdäck",
    "dubbdäcket": "dubbdäck",
    "dubbdäckets": "dubbdäck",
    "dubbdäcks": "dubbdäck",
    "dubbelagenten": "dubbelagent",
    "dubbelagentens": "dubbelagent",
    "dubbelagenter": "dubbelagent",
    "dubbelagenterna": "dubbelagent",
    "dubbelagenternas": "dubbelagent",
    "dubbelagenters": "dubbelagent",
    "dubbelagents": "dubbelagent",
    "dubbelansikten": "dubbelansikte",
    "dubbelansiktena": "dubbelansikte",
    "dubbelansiktenas": "dubbelansikte",
    "dubbelansiktens": "dubbelansikte",
    "dubbelansiktes": "dubbelansikte",
    "dubbelansiktet": "dubbelansikte",
    "dubbelansiktets": "dubbelansikte",
    "dubbelansikts": "dubbelansikte",
    "dubbelbeckasinen": "dubbelbeckasin",
    "dubbelbeckasinens": "dubbelbeckasin",
    "dubbelbeckasiner": "dubbelbeckasin",
    "dubbelbeckasinerna": "dubbelbeckasin",
    "dubbelbeckasinernas": "dubbelbeckasin",
    "dubbelbeckasiners": "dubbelbeckasin",
    "dubbelbeckasins": "dubbelbeckasin",
    "dubbelbeskatt": "dubbelbeskatta",
    "dubbelbeskattad": "dubbelbeskatta",
    "dubbelbeskattade": "dubbelbeskatta",
    "dubbelbeskattades": "dubbelbeskatta",
    "dubbelbeskattads": "dubbelbeskatta",
    "dubbelbeskattande": "dubbelbeskatta",
    "dubbelbeskattanden": "dubbelbeskattande",
    "dubbelbeskattandena": "dubbelbeskattande",
    "dubbelbeskattandenas": "dubbelbeskattande",
    "dubbelbeskattandens": "dubbelbeskattande",
    "dubbelbeskattandes": "dubbelbeskattande",
    "dubbelbeskattandet": "dubbelbeskattande",
    "dubbelbeskattandets": "dubbelbeskattande",
    "dubbelbeskattar": "dubbelbeskatta",
    "dubbelbeskattas": "dubbelbeskatta",
    "dubbelbeskattat": "dubbelbeskatta",
    "dubbelbeskattats": "dubbelbeskatta",
    "dubbelbiffar": "dubbelbiff",
    "dubbelbiffarna": "dubbelbiff",
    "dubbelbiffarnas": "dubbelbiff",
    "dubbelbiffars": "dubbelbiff",
    "dubbelbiffen": "dubbelbiff",
    "dubbelbiffens": "dubbelbiff",
    "dubbelbiffs": "dubbelbiff",
    "dubbelbindningar": "dubbelbindning",
    "dubbelbindningarna": "dubbelbindning",
    "dubbelbindningarnas": "dubbelbindning",
    "dubbelbindningars": "dubbelbindning",
    "dubbelbindningen": "dubbelbindning",
    "dubbelbindningens": "dubbelbindning",
    "dubbelbindnings": "dubbelbindning",
    "dubbelbluffar": "dubbelbluff",
    "dubbelbluffarna": "dubbelbluff",
    "dubbelbluffarnas": "dubbelbluff",
    "dubbelbluffars": "dubbelbluff",
    "dubbelbluffen": "dubbelbluff",
    "dubbelbluffens": "dubbelbluff",
    "dubbelbluffs": "dubbelbluff",
    "dubbelbottens": "dubbelbotten",
    "dubbelbottnade": "dubbelbottnad",
    "dubbelbottnades": "dubbelbottnad",
    "dubbelbottnads": "dubbelbottnad",
    "dubbelbottnar": "dubbelbotten",
    "dubbelbottnarna": "dubbelbotten",
    "dubbelbottnarnas": "dubbelbotten",
    "dubbelbottnars": "dubbelbotten",
    "dubbelbottnat": "dubbelbottnad",
    "dubbelbottnats": "dubbelbottnad",
    "dubbelbottnen": "dubbelbotten",
    "dubbelbottnens": "dubbelbotten",
    "dubbelbredden": "dubbelbredd",
    "dubbelbreddens": "dubbelbredd",
    "dubbelbredder": "dubbelbredd",
    "dubbelbredderna": "dubbelbredd",
    "dubbelbreddernas": "dubbelbredd",
    "dubbelbredders": "dubbelbredd",
    "dubbelbredds": "dubbelbredd",
    "dubbelbrytningar": "dubbelbrytning",
    "dubbelbrytningarna": "dubbelbrytning",
    "dubbelbrytningarnas": "dubbelbrytning",
    "dubbelbrytningars": "dubbelbrytning",
    "dubbelbrytningen": "dubbelbrytning",
    "dubbelbrytningens": "dubbelbrytning",
    "dubbelbrytnings": "dubbelbrytning",
    "dubbelbröllopen": "dubbelbröllop",
    "dubbelbröllopens": "dubbelbröllop",
    "dubbelbröllopet": "dubbelbröllop",
    "dubbelbröllopets": "dubbelbröllop",
    "dubbelbröllops": "dubbelbröllop",
    "dubbelböss": "dubbelbössa",
    "dubbelbössan": "dubbelbössa",
    "dubbelbössans": "dubbelbössa",
    "dubbelbössas": "dubbelbössa",
    "dubbelbösse": "dubbelbössa",
    "dubbelbössor": "dubbelbössa",
    "dubbelbössorna": "dubbelbössa",
    "dubbelbössornas": "dubbelbössa",
    "dubbelbössors": "dubbelbössa",
    "dubbeldäckar": "dubbeldäckare",
    "dubbeldäckaren": "dubbeldäckare",
    "dubbeldäckarens": "dubbeldäckare",
    "dubbeldäckares": "dubbeldäckare",
    "dubbeldäckarna": "dubbeldäckare",
    "dubbeldäckarnas": "dubbeldäckare",
    "dubbeldörrar": "dubbeldörr",
    "dubbeldörrarna": "dubbeldörr",
    "dubbeldörrarnas": "dubbeldörr",
    "dubbeldörrars": "dubbeldörr",
    "dubbeldörren": "dubbeldörr",
    "dubbeldörrens": "dubbeldörr",
    "dubbeldörrs": "dubbeldörr",
    "dubbelexponerad": "dubbelexponera",
    "dubbelexponerade": "dubbelexponera",
    "dubbelexponerades": "dubbelexponera",
    "dubbelexponerads": "dubbelexponera",
    "dubbelexponerande": "dubbelexponera",
    "dubbelexponeranden": "dubbelexponerande",
    "dubbelexponerandena": "dubbelexponerande",
    "dubbelexponerandenas": "dubbelexponerande",
    "dubbelexponerandens": "dubbelexponerande",
    "dubbelexponerandes": "dubbelexponerande",
    "dubbelexponerandet": "dubbelexponerande",
    "dubbelexponerandets": "dubbelexponerande",
    "dubbelexponerar": "dubbelexponera",
    "dubbelexponeras": "dubbelexponera",
    "dubbelexponerat": "dubbelexponera",
    "dubbelexponerats": "dubbelexponera",
    "dubbelexponerbara": "dubbelexponerbar",
    "dubbelexponerbarare": "dubbelexponerbar",
    "dubbelexponerbarares": "dubbelexponerbar",
    "dubbelexponerbaras": "dubbelexponerbar",
    "dubbelexponerbarast": "dubbelexponerbar",
    "dubbelexponerbaraste": "dubbelexponerbar",
    "dubbelexponerbarastes": "dubbelexponerbar",
    "dubbelexponerbarasts": "dubbelexponerbar",
    "dubbelexponerbare": "dubbelexponerbar",
    "dubbelexponerbares": "dubbelexponerbar",
    "dubbelexponerbarheten": "dubbelexponerbarhet",
    "dubbelexponerbarhetens": "dubbelexponerbarhet",
    "dubbelexponerbarhets": "dubbelexponerbarhet",
    "dubbelexponerbars": "dubbelexponerbar",
    "dubbelexponerbart": "dubbelexponerbar",
    "dubbelexponerbarts": "dubbelexponerbar",
    "dubbelexponeringar": "dubbelexponering",
    "dubbelexponeringarna": "dubbelexponering",
    "dubbelexponeringarnas": "dubbelexponering",
    "dubbelexponeringars": "dubbelexponering",
    "dubbelexponeringen": "dubbelexponering",
    "dubbelexponeringens": "dubbelexponering",
    "dubbelexponerings": "dubbelexponering",
    "dubbelfelen": "dubbelfel",
    "dubbelfelens": "dubbelfel",
    "dubbelfelet": "dubbelfel",
    "dubbelfelets": "dubbelfel",
    "dubbelfels": "dubbelfel",
    "dubbelfönsterna": "dubbelfönster",
    "dubbelfönsternas": "dubbelfönster",
    "dubbelfönsters": "dubbelfönster",
    "dubbelfönstren": "dubbelfönster",
    "dubbelfönstrens": "dubbelfönster",
    "dubbelfönstret": "dubbelfönster",
    "dubbelfönstrets": "dubbelfönster",
    "dubbelgaragen": "dubbelgarage",
    "dubbelgaragens": "dubbelgarage",
    "dubbelgarages": "dubbelgarage",
    "dubbelgaraget": "dubbelgarage",
    "dubbelgaragets": "dubbelgarage",
    "dubbelgreppen": "dubbelgrepp",
    "dubbelgreppens": "dubbelgrepp",
    "dubbelgreppet": "dubbelgrepp",
    "dubbelgreppets": "dubbelgrepp",
    "dubbelgrepps": "dubbelgrepp",
    "dubbelgångar": "dubbelgångare",
    "dubbelgångaren": "dubbelgångare",
    "dubbelgångarens": "dubbelgångare",
    "dubbelgångares": "dubbelgångare",
    "dubbelgångarna": "dubbelgångare",
    "dubbelgångarnas": "dubbelgångare",
    "dubbelhak": "dubbelhaka",
    "dubbelhakan": "dubbelhaka",
    "dubbelhakans": "dubbelhaka",
    "dubbelhakas": "dubbelhaka",
    "dubbelhake": "dubbelhaka",
    "dubbelhakor": "dubbelhaka",
    "dubbelhakorna": "dubbelhaka",
    "dubbelhakornas": "dubbelhaka",
    "dubbelhakors": "dubbelhaka",
    "dubbelhaks": "dubbelhaka",
    "dubbelhandsfattningen": "dubbelhandsfattning",
    "dubbelhandsfattningens": "dubbelhandsfattning",
    "dubbelhandsfattnings": "dubbelhandsfattning",
    "dubbelheten": "dubbelhet",
    "dubbelhetens": "dubbelhet",
    "dubbelheter": "dubbelhet",
    "dubbelheterna": "dubbelhet",
    "dubbelheternas": "dubbelhet",
    "dubbelheters": "dubbelhet",
    "dubbelhets": "dubbelhet",
    "dubbelhytten": "dubbelhytt",
    "dubbelhyttens": "dubbelhytt",
    "dubbelhytter": "dubbelhytt",
    "dubbelhytterna": "dubbelhytt",
    "dubbelhytternas": "dubbelhytt",
    "dubbelhytters": "dubbelhytt",
    "dubbelhytts": "dubbelhytt",
    "dubbelhölsters": "dubbelhölster",
    "dubbelhölstren": "dubbelhölster",
    "dubbelhölstrens": "dubbelhölster",
    "dubbelhölstret": "dubbelhölster",
    "dubbelhölstrets": "dubbelhölster",
    "dubbelkommandon": "dubbelkommando",
    "dubbelkommandona": "dubbelkommando",
    "dubbelkommandonas": "dubbelkommando",
    "dubbelkommandons": "dubbelkommando",
    "dubbelkommandos": "dubbelkommando",
    "dubbelkommandot": "dubbelkommando",
    "dubbelkommandots": "dubbelkommando",
    "dubbelkontakten": "dubbelkontakt",
    "dubbelkontaktens": "dubbelkontakt",
    "dubbelkontakter": "dubbelkontakt",
    "dubbelkontakterna": "dubbelkontakt",
    "dubbelkontakternas": "dubbelkontakt",
    "dubbelkontakters": "dubbelkontakt",
    "dubbelkontakts": "dubbelkontakt",
    "dubbellivet": "dubbelliv",
    "dubbellivets": "dubbelliv",
    "dubbellivs": "dubbelliv",
    "dubbelmadrassen": "dubbelmadrass",
    "dubbelmadrassens": "dubbelmadrass",
    "dubbelmadrasser": "dubbelmadrass",
    "dubbelmadrasserna": "dubbelmadrass",
    "dubbelmadrassernas": "dubbelmadrass",
    "dubbelmadrassers": "dubbelmadrass",
    "dubbelmeningar": "dubbelmening",
    "dubbelmeningarna": "dubbelmening",
    "dubbelmeningarnas": "dubbelmening",
    "dubbelmeningars": "dubbelmening",
    "dubbelmeningen": "dubbelmening",
    "dubbelmeningens": "dubbelmening",
    "dubbelmenings": "dubbelmening",
    "dubbelmoralen": "dubbelmoral",
    "dubbelmoralens": "dubbelmoral",
    "dubbelmorals": "dubbelmoral",
    "dubbelmorden": "dubbelmord",
    "dubbelmordens": "dubbelmord",
    "dubbelmordet": "dubbelmord",
    "dubbelmordets": "dubbelmord",
    "dubbelmords": "dubbelmord",
    "dubbeln": "dubbel",
    "dubbelnamnen": "dubbelnamn",
    "dubbelnamnens": "dubbelnamn",
    "dubbelnamnet": "dubbelnamn",
    "dubbelnamnets": "dubbelnamn",
    "dubbelnamns": "dubbelnamn",
    "dubbelnaturen": "dubbelnatur",
    "dubbelnaturens": "dubbelnatur",
    "dubbelnaturer": "dubbelnatur",
    "dubbelnaturerna": "dubbelnatur",
    "dubbelnaturernas": "dubbelnatur",
    "dubbelnaturers": "dubbelnatur",
    "dubbelnaturs": "dubbelnatur",
    "dubbelnelsons": "dubbelnelson",
    "dubbelns": "dubbel",
    "dubbelnöten": "dubbelnöt",
    "dubbelnötens": "dubbelnöt",
    "dubbelnöts": "dubbelnöt",
    "dubbelnötter": "dubbelnöt",
    "dubbelnötterna": "dubbelnöt",
    "dubbelnötternas": "dubbelnöt",
    "dubbelnötters": "dubbelnöt",
    "dubbelpipiga": "dubbelpipig",
    "dubbelpipigare": "dubbelpipig",
    "dubbelpipigares": "dubbelpipig",
    "dubbelpipigas": "dubbelpipig",
    "dubbelpipigast": "dubbelpipig",
    "dubbelpipigaste": "dubbelpipig",
    "dubbelpipigastes": "dubbelpipig",
    "dubbelpipigasts": "dubbelpipig",
    "dubbelpipige": "dubbelpipig",
    "dubbelpipiges": "dubbelpipig",
    "dubbelpipigs": "dubbelpipig",
    "dubbelpipigt": "dubbelpipig",
    "dubbelpipigts": "dubbelpipig",
    "dubbelrevolutionen": "dubbelrevolution",
    "dubbelrevolutionens": "dubbelrevolution",
    "dubbelrevolutioner": "dubbelrevolution",
    "dubbelrevolutionerna": "dubbelrevolution",
    "dubbelrevolutionernas": "dubbelrevolution",
    "dubbelrevolutioners": "dubbelrevolution",
    "dubbelrevolutions": "dubbelrevolution",
    "dubbelrollen": "dubbelroll",
    "dubbelrollens": "dubbelroll",
    "dubbelroller": "dubbelroll",
    "dubbelrollerna": "dubbelroll",
    "dubbelrollernas": "dubbelroll",
    "dubbelrollers": "dubbelroll",
    "dubbelrolls": "dubbelroll",
    "dubbelrummen": "dubbelrum",
    "dubbelrummens": "dubbelrum",
    "dubbelrummet": "dubbelrum",
    "dubbelrummets": "dubbelrum",
    "dubbelrums": "dubbelrum",
    "dubbelrören": "dubbelrör",
    "dubbelrörens": "dubbelrör",
    "dubbelröret": "dubbelrör",
    "dubbelrörets": "dubbelrör",
    "dubbelrörs": "dubbelrör",
    "dubbels": "dubbel",
    "dubbelsalter": "dubbelsalt",
    "dubbelsalterna": "dubbelsalt",
    "dubbelsalternas": "dubbelsalt",
    "dubbelsalters": "dubbelsalt",
    "dubbelsaltet": "dubbelsalt",
    "dubbelsaltets": "dubbelsalt",
    "dubbelsalts": "dubbelsalt",
    "dubbelseendes": "dubbelseende",
    "dubbelseendet": "dubbelseende",
    "dubbelseendets": "dubbelseende",
    "dubbelsidiga": "dubbelsidig",
    "dubbelsidigare": "dubbelsidig",
    "dubbelsidigares": "dubbelsidig",
    "dubbelsidigas": "dubbelsidig",
    "dubbelsidigast": "dubbelsidig",
    "dubbelsidigaste": "dubbelsidig",
    "dubbelsidigastes": "dubbelsidig",
    "dubbelsidigasts": "dubbelsidig",
    "dubbelsidige": "dubbelsidig",
    "dubbelsidiges": "dubbelsidig",
    "dubbelsidigs": "dubbelsidig",
    "dubbelsidigt": "dubbelsidig",
    "dubbelsidigts": "dubbelsidig",
    "dubbelspelen": "dubbelspel",
    "dubbelspelens": "dubbelspel",
    "dubbelspelet": "dubbelspel",
    "dubbelspelets": "dubbelspel",
    "dubbelspels": "dubbelspel",
    "dubbelstjärnan": "dubbelstjärna",
    "dubbelstjärnans": "dubbelstjärna",
    "dubbelstjärnas": "dubbelstjärna",
    "dubbelstjärne": "dubbelstjärna",
    "dubbelstjärnor": "dubbelstjärna",
    "dubbelstjärnorna": "dubbelstjärna",
    "dubbelstjärnornas": "dubbelstjärna",
    "dubbelstjärnors": "dubbelstjärna",
    "dubbelstjärnsystemen": "dubbelstjärnsystem",
    "dubbelstjärnsystemens": "dubbelstjärnsystem",
    "dubbelstjärnsystemet": "dubbelstjärnsystem",
    "dubbelstjärnsystemets": "dubbelstjärnsystem",
    "dubbelstjärnsystems": "dubbelstjärnsystem",
    "dubbelsträngade": "dubbelsträngad",
    "dubbelsträngades": "dubbelsträngad",
    "dubbelsträngads": "dubbelsträngad",
    "dubbelsträngat": "dubbelsträngad",
    "dubbelsträngats": "dubbelsträngad",
    "dubbelsäkringar": "dubbelsäkring",
    "dubbelsäkringarna": "dubbelsäkring",
    "dubbelsäkringarnas": "dubbelsäkring",
    "dubbelsäkringars": "dubbelsäkring",
    "dubbelsäkringen": "dubbelsäkring",
    "dubbelsäkringens": "dubbelsäkring",
    "dubbelsäkrings": "dubbelsäkring",
    "dubbelsängar": "dubbelsäng",
    "dubbelsängarna": "dubbelsäng",
    "dubbelsängarnas": "dubbelsäng",
    "dubbelsängars": "dubbelsäng",
    "dubbelsängen": "dubbelsäng",
    "dubbelsängens": "dubbelsäng",
    "dubbelsängs": "dubbelsäng",
    "dubbelt": "dubbel",
    "dubbeltim": "dubbeltimme",
    "dubbeltimman": "dubbeltimma",
    "dubbeltimmans": "dubbeltimma",
    "dubbeltimmar": "dubbeltimme",
    "dubbeltimmarna": "dubbeltimme",
    "dubbeltimmarnas": "dubbeltimme",
    "dubbeltimmars": "dubbeltimme",
    "dubbeltimmas": "dubbeltimma",
    "dubbeltimmen": "dubbeltimme",
    "dubbeltimmens": "dubbeltimme",
    "dubbeltimmes": "dubbeltimme",
    "dubbeltims": "dubbeltimme",
    "dubbelträffar": "dubbelträff",
    "dubbelträffarna": "dubbelträff",
    "dubbelträffarnas": "dubbelträff",
    "dubbelträffars": "dubbelträff",
    "dubbelträffen": "dubbelträff",
    "dubbelträffens": "dubbelträff",
    "dubbelträffs": "dubbelträff",
    "dubbeltrådiga": "dubbeltrådig",
    "dubbeltrådigare": "dubbeltrådig",
    "dubbeltrådigares": "dubbeltrådig",
    "dubbeltrådigas": "dubbeltrådig",
    "dubbeltrådigast": "dubbeltrådig",
    "dubbeltrådigaste": "dubbeltrådig",
    "dubbeltrådigastes": "dubbeltrådig",
    "dubbeltrådigasts": "dubbeltrådig",
    "dubbeltrådige": "dubbeltrådig",
    "dubbeltrådiges": "dubbeltrådig",
    "dubbeltrådigs": "dubbeltrådig",
    "dubbeltrådigt": "dubbeltrådig",
    "dubbeltrådigts": "dubbeltrådig",
    "dubbelts": "dubbel",
    "dubbeltydiga": "dubbeltydig",
    "dubbeltydigare": "dubbeltydig",
    "dubbeltydigares": "dubbeltydig",
    "dubbeltydigas": "dubbeltydig",
    "dubbeltydigast": "dubbeltydig",
    "dubbeltydigaste": "dubbeltydig",
    "dubbeltydigastes": "dubbeltydig",
    "dubbeltydigasts": "dubbeltydig",
    "dubbeltydige": "dubbeltydig",
    "dubbeltydiges": "dubbeltydig",
    "dubbeltydigheten": "dubbeltydighet",
    "dubbeltydighetens": "dubbeltydighet",
    "dubbeltydighets": "dubbeltydighet",
    "dubbeltydigs": "dubbeltydig",
    "dubbeltydigt": "dubbeltydig",
    "dubbeltydigts": "dubbeltydig",
    "dubben": "dubb",
    "dubbens": "dubb",
    "dubbla": "dubbel",
    "dubblad": "dubbla",
    "dubblade": "dubbla",
    "dubblades": "dubbla",
    "dubblads": "dubbla",
    "dubblande": "dubbla",
    "dubblanden": "dubblande",
    "dubblandena": "dubblande",
    "dubblandenas": "dubblande",
    "dubblandens": "dubblande",
    "dubblandes": "dubblande",
    "dubblandet": "dubblande",
    "dubblandets": "dubblande",
    "dubblar": "dubblare",
    "dubblare": "dubbel",
    "dubblaren": "dubblare",
    "dubblarens": "dubblare",
    "dubblares": "dubblare",
    "dubblarna": "dubblare",
    "dubblarnas": "dubblare",
    "dubblars": "dubbel",
    "dubblas": "dubbla",
    "dubblast": "dubbel",
    "dubblaste": "dubbel",
    "dubblastes": "dubbel",
    "dubblasts": "dubbel",
    "dubblat": "dubbla",
    "dubblats": "dubbla",
    "dubble": "dubbel",
    "dubblerad": "dubblera",
    "dubblerade": "dubblera",
    "dubblerades": "dubblera",
    "dubblerads": "dubblera",
    "dubblerande": "dubblera",
    "dubbleranden": "dubblerande",
    "dubblerandena": "dubblerande",
    "dubblerandenas": "dubblerande",
    "dubblerandens": "dubblerande",
    "dubblerandes": "dubblerande",
    "dubblerandet": "dubblerande",
    "dubblerandets": "dubblerande",
    "dubblerar": "dubblera",
    "dubbleras": "dubblera",
    "dubblerat": "dubblera",
    "dubblerats": "dubblera",
    "dubblerbara": "dubblerbar",
    "dubblerbarare": "dubblerbar",
    "dubblerbarares": "dubblerbar",
    "dubblerbaras": "dubblerbar",
    "dubblerbarast": "dubblerbar",
    "dubblerbaraste": "dubblerbar",
    "dubblerbarastes": "dubblerbar",
    "dubblerbarasts": "dubblerbar",
    "dubblerbare": "dubblerbar",
    "dubblerbares": "dubblerbar",
    "dubblerbarheten": "dubblerbarhet",
    "dubblerbarhetens": "dubblerbarhet",
    "dubblerbarhets": "dubblerbarhet",
    "dubblerbars": "dubblerbar",
    "dubblerbart": "dubblerbar",
    "dubblerbarts": "dubblerbar",
    "dubbleringar": "dubblering",
    "dubbleringarna": "dubblering",
    "dubbleringarnas": "dubblering",
    "dubbleringars": "dubblering",
    "dubbleringen": "dubblering",
    "dubbleringens": "dubblering",
    "dubblerings": "dubblering",
    "dubbles": "dubbel",
    "dubbletten": "dubblett",
    "dubblettens": "dubblett",
    "dubbletter": "dubblett",
    "dubbletterna": "dubblett",
    "dubbletternas": "dubblett",
    "dubbletters": "dubblett",
    "dubbletts": "dubblett",
    "dubbléer": "dubblé",
    "dubbléerna": "dubblé",
    "dubbléernas": "dubblé",
    "dubbléers": "dubblé",
    "dubblén": "dubblé",
    "dubbléns": "dubblé",
    "dubblés": "dubblé",
    "dubbs": "dubb",
    "dubie": "dubier",
    "dubierna": "dubier",
    "dubiernas": "dubier",
    "dubiers": "dubier",
    "dubiösa": "dubiös",
    "dubiösare": "dubiös",
    "dubiösares": "dubiös",
    "dubiösas": "dubiös",
    "dubiösast": "dubiös",
    "dubiösaste": "dubiös",
    "dubiösastes": "dubiös",
    "dubiösasts": "dubiös",
    "dubiöse": "dubiös",
    "dubiöses": "dubiös",
    "dubiöst": "dubiös",
    "dubiösts": "dubiös",
    "dubletten": "dublett",
    "dublettens": "dublett",
    "dubletter": "dublett",
    "dubletterna": "dublett",
    "dubletternas": "dublett",
    "dubletters": "dublett",
    "dubletts": "dublett",
    "dubrodern": "dubror",
    "dubroderns": "dubror",
    "dubrorn": "dubror",
    "dubrorns": "dubror",
    "dubrors": "dubror",
    "dubröder": "dubror",
    "dubröderna": "dubror",
    "dubrödernas": "dubror",
    "dubröders": "dubror",
    "duchatelen": "duchatel",
    "duchatelens": "duchatel",
    "duchateler": "duchatel",
    "duchatelerna": "duchatel",
    "duchatelernas": "duchatel",
    "duchatelers": "duchatel",
    "duchatels": "duchatel",
    "duchessen": "duchesse",
    "duchessens": "duchesse",
    "duchesses": "duchesse",
    "duck": "ducka",
    "duckade": "ducka",
    "duckades": "ducka",
    "duckande": "ducka",
    "duckanden": "duckande",
    "duckandena": "duckande",
    "duckandenas": "duckande",
    "duckandens": "duckande",
    "duckandes": "duckande",
    "duckandet": "duckande",
    "duckandets": "duckande",
    "duckar": "ducka",
    "duckas": "ducka",
    "duckat": "ducka",
    "duckats": "ducka",
    "duellanten": "duellant",
    "duellantens": "duellant",
    "duellanter": "duellant",
    "duellanterna": "duellant",
    "duellanternas": "duellant",
    "duellanters": "duellant",
    "duellants": "duellant",
    "duellen": "duell",
    "duellens": "duell",
    "dueller": "duell",
    "duellerade": "duellera",
    "duellerades": "duellera",
    "duellerande": "duellera",
    "duelleranden": "duellerande",
    "duellerandena": "duellerande",
    "duellerandenas": "duellerande",
    "duellerandens": "duellerande",
    "duellerandes": "duellerande",
    "duellerandet": "duellerande",
    "duellerandets": "duellerande",
    "duellerar": "duellera",
    "duelleras": "duellera",
    "duellerat": "duellera",
    "duellerats": "duellera",
    "duelleringar": "duellering",
    "duelleringarna": "duellering",
    "duelleringarnas": "duellering",
    "duelleringars": "duellering",
    "duelleringen": "duellering",
    "duelleringens": "duellering",
    "duellerings": "duellering",
    "duellerna": "duell",
    "duellernas": "duell",
    "duellers": "duell",
    "duells": "duell",
    "duenn": "duenna",
    "duennan": "duenna",
    "duennans": "duenna",
    "duennas": "duenna",
    "duenne": "duenna",
    "duennor": "duenna",
    "duennorna": "duenna",
    "duennornas": "duenna",
    "duennors": "duenna",
    "duenns": "duenna",
    "duetten": "duett",
    "duettens": "duett",
    "duetter": "duett",
    "duetterna": "duett",
    "duetternas": "duett",
    "duetters": "duett",
    "duetts": "duett",
    "duffeln": "duffel",
    "duffelns": "duffel",
    "duffels": "duffel",
    "dufflar": "duffel",
    "dufflarna": "duffel",
    "dufflarnas": "duffel",
    "dufflars": "duffel",
    "dug": "duga",
    "dugade": "duga",
    "dugande": "duga",
    "duganden": "dugande",
    "dugandena": "dugande",
    "dugandenas": "dugande",
    "dugandens": "dugande",
    "dugandes": "dugande",
    "dugandet": "dugande",
    "dugandets": "dugande",
    "duge": "duga",
    "duger": "duga",
    "dugg": "dugga",
    "duggade": "dugga",
    "duggades": "dugga",
    "duggande": "dugga",
    "dugganden": "duggande",
    "duggandena": "duggande",
    "duggandenas": "duggande",
    "duggandens": "duggande",
    "duggandes": "duggande",
    "duggandet": "duggande",
    "duggandets": "duggande",
    "duggar": "dugga",
    "duggas": "dugga",
    "duggat": "dugga",
    "duggats": "dugga",
    "duggregnade": "duggregna",
    "duggregnades": "duggregna",
    "duggregnande": "duggregna",
    "duggregnanden": "duggregnande",
    "duggregnandena": "duggregnande",
    "duggregnandenas": "duggregnande",
    "duggregnandens": "duggregnande",
    "duggregnandes": "duggregnande",
    "duggregnandet": "duggregnande",
    "duggregnandets": "duggregnande",
    "duggregnar": "duggregna",
    "duggregnas": "duggregna",
    "duggregnat": "duggregna",
    "duggregnats": "duggregna",
    "duggregnen": "duggregn",
    "duggregnens": "duggregn",
    "duggregnet": "duggregn",
    "duggregnets": "duggregn",
    "duggregns": "duggregn",
    "dugit": "duga",
    "dugliga": "duglig",
    "dugligare": "duglig",
    "dugligares": "duglig",
    "dugligas": "duglig",
    "dugligast": "duglig",
    "dugligaste": "duglig",
    "dugligastes": "duglig",
    "dugligasts": "duglig",
    "duglige": "duglig",
    "dugliges": "duglig",
    "dugligheten": "duglighet",
    "duglighetens": "duglighet",
    "dugligheter": "duglighet",
    "dugligheterna": "duglighet",
    "dugligheternas": "duglighet",
    "dugligheters": "duglighet",
    "duglighets": "duglighet",
    "dugligs": "duglig",
    "dugligt": "duglig",
    "dugligts": "duglig",
    "dugt": "duga",
    "duk": "duka",
    "dukad": "duka",
    "dukade": "duka",
    "dukades": "duka",
    "dukads": "duka",
    "dukagångar": "dukagång",
    "dukagångarna": "dukagång",
    "dukagångarnas": "dukagång",
    "dukagångars": "dukagång",
    "dukagången": "dukagång",
    "dukagångens": "dukagång",
    "dukagångs": "dukagång",
    "dukande": "duka",
    "dukanden": "dukande",
    "dukandena": "dukande",
    "dukandenas": "dukande",
    "dukandens": "dukande",
    "dukandes": "dukande",
    "dukandet": "dukande",
    "dukandets": "dukande",
    "dukar": "duka",
    "dukarna": "duk",
    "dukarnas": "duk",
    "dukars": "duk",
    "dukas": "duka",
    "dukat": "duka",
    "dukaten": "dukat",
    "dukatens": "dukat",
    "dukater": "dukat",
    "dukaterna": "dukat",
    "dukaternas": "dukat",
    "dukaters": "dukat",
    "dukats": "dukat",
    "duken": "duk",
    "dukens": "duk",
    "dukningar": "dukning",
    "dukningarna": "dukning",
    "dukningarnas": "dukning",
    "dukningars": "dukning",
    "dukningen": "dukning",
    "dukningens": "dukning",
    "duknings": "dukning",
    "duks": "duk",
    "dukten": "dukt",
    "duktens": "dukt",
    "dukter": "dukt",
    "dukterna": "dukt",
    "dukternas": "dukt",
    "dukters": "dukt",
    "duktiga": "duktig",
    "duktigare": "duktig",
    "duktigares": "duktig",
    "duktigas": "duktig",
    "duktigast": "duktig",
    "duktigaste": "duktig",
    "duktigastes": "duktig",
    "duktigasts": "duktig",
    "duktige": "duktig",
    "duktiges": "duktig",
    "duktigheten": "duktighet",
    "duktighetens": "duktighet",
    "duktighets": "duktighet",
    "duktigs": "duktig",
    "duktigt": "duktig",
    "duktigts": "duktig",
    "dukts": "dukt",
    "dulcianen": "dulcian",
    "dulcianens": "dulcian",
    "dulcianer": "dulcian",
    "dulcianerna": "dulcian",
    "dulcianernas": "dulcian",
    "dulcianers": "dulcian",
    "dulcians": "dulcian",
    "dumbommar": "dumbom",
    "dumbommarna": "dumbom",
    "dumbommarnas": "dumbom",
    "dumbommars": "dumbom",
    "dumbommen": "dumbom",
    "dumbommens": "dumbom",
    "dumboms": "dumbom",
    "dumdristiga": "dumdristig",
    "dumdristigare": "dumdristig",
    "dumdristigares": "dumdristig",
    "dumdristigas": "dumdristig",
    "dumdristigast": "dumdristig",
    "dumdristigaste": "dumdristig",
    "dumdristigastes": "dumdristig",
    "dumdristigasts": "dumdristig",
    "dumdristige": "dumdristig",
    "dumdristiges": "dumdristig",
    "dumdristigheten": "dumdristighet",
    "dumdristighetens": "dumdristighet",
    "dumdristighets": "dumdristighet",
    "dumdristigs": "dumdristig",
    "dumdristigt": "dumdristig",
    "dumdristigts": "dumdristig",
    "dumdryga": "dumdryg",
    "dumdrygare": "dumdryg",
    "dumdrygares": "dumdryg",
    "dumdrygas": "dumdryg",
    "dumdrygast": "dumdryg",
    "dumdrygaste": "dumdryg",
    "dumdrygastes": "dumdryg",
    "dumdrygasts": "dumdryg",
    "dumdryge": "dumdryg",
    "dumdryges": "dumdryg",
    "dumdrygheten": "dumdryghet",
    "dumdryghetens": "dumdryghet",
    "dumdryghets": "dumdryghet",
    "dumdrygs": "dumdryg",
    "dumdrygt": "dumdryg",
    "dumdrygts": "dumdryg",
    "dumdumkul": "dumdumkula",
    "dumdumkulan": "dumdumkula",
    "dumdumkulans": "dumdumkula",
    "dumdumkulas": "dumdumkula",
    "dumdumkule": "dumdumkula",
    "dumdumkulor": "dumdumkula",
    "dumdumkulorna": "dumdumkula",
    "dumdumkulornas": "dumdumkula",
    "dumdumkulors": "dumdumkula",
    "dumdumkuls": "dumdumkula",
    "dumheten": "dumhet",
    "dumhetens": "dumhet",
    "dumheter": "dumhet",
    "dumheterna": "dumhet",
    "dumheternas": "dumhet",
    "dumheters": "dumhet",
    "dumhets": "dumhet",
    "dumhuvuden": "dumhuvud",
    "dumhuvudena": "dumhuvud",
    "dumhuvudenas": "dumhuvud",
    "dumhuvudens": "dumhuvud",
    "dumhuvudet": "dumhuvud",
    "dumhuvudets": "dumhuvud",
    "dumhuvuds": "dumhuvud",
    "dumma": "dum",
    "dummar": "dummer",
    "dummare": "dum",
    "dummares": "dum",
    "dummarna": "dummer",
    "dummarnas": "dummer",
    "dummars": "dummer",
    "dummas": "dum",
    "dummast": "dum",
    "dummaste": "dum",
    "dummastes": "dum",
    "dummasts": "dum",
    "dumme": "dum",
    "dummerjönsar": "dummerjöns",
    "dummerjönsarna": "dummerjöns",
    "dummerjönsarnas": "dummerjöns",
    "dummerjönsars": "dummerjöns",
    "dummerjönsen": "dummerjöns",
    "dummerjönsens": "dummerjöns",
    "dummern": "dummer",
    "dummerns": "dummer",
    "dummers": "dummer",
    "dummes": "dum",
    "dummier": "dummy",
    "dummierna": "dummy",
    "dummiernas": "dummy",
    "dummiers": "dummy",
    "dummies": "dummy",
    "dummiesarna": "dummy",
    "dummiesarnas": "dummy",
    "dummingar": "dumming",
    "dummingarna": "dumming",
    "dummingarnas": "dumming",
    "dummingars": "dumming",
    "dummingen": "dumming",
    "dummingens": "dumming",
    "dummings": "dumming",
    "dummyer": "dummy",
    "dummyerna": "dummy",
    "dummyernas": "dummy",
    "dummyers": "dummy",
    "dummyn": "dummy",
    "dummyns": "dummy",
    "dummys": "dummy",
    "dummysar": "dummy",
    "dummysarna": "dummy",
    "dummysarnas": "dummy",
    "dummysars": "dummy",
    "dump": "dumpa",
    "dumpad": "dumpa",
    "dumpade": "dumpa",
    "dumpades": "dumpa",
    "dumpads": "dumpa",
    "dumpande": "dumpa",
    "dumpanden": "dumpande",
    "dumpandena": "dumpande",
    "dumpandenas": "dumpande",
    "dumpandens": "dumpande",
    "dumpandes": "dumpande",
    "dumpandet": "dumpande",
    "dumpandets": "dumpande",
    "dumpar": "dumpa",
    "dumpas": "dumpa",
    "dumpat": "dumpa",
    "dumpats": "dumpa",
    "dumpe": "dimpa",
    "dumpern": "dumper",
    "dumperns": "dumper",
    "dumpers": "dumper",
    "dumpersarna": "dumper",
    "dumpersarnas": "dumper",
    "dumpersen": "dumper",
    "dumpersens": "dumper",
    "dumpes": "dimpa",
    "dumpit": "dimpa",
    "dumpits": "dimpa",
    "dumpningar": "dumpning",
    "dumpningarna": "dumpning",
    "dumpningarnas": "dumpning",
    "dumpningars": "dumpning",
    "dumpningen": "dumpning",
    "dumpningens": "dumpning",
    "dumpnings": "dumpning",
    "dumprar": "dumper",
    "dumprarna": "dumper",
    "dumprarnas": "dumper",
    "dumprars": "dumper",
    "dumrar": "dummer",
    "dumrarna": "dummer",
    "dumrarnas": "dummer",
    "dumrars": "dummer",
    "dums": "dum",
    "dumskall": "dumskalle",
    "dumskallar": "dumskalle",
    "dumskallarna": "dumskalle",
    "dumskallarnas": "dumskalle",
    "dumskallars": "dumskalle",
    "dumskallemajoriteten": "dumskallemajoritet",
    "dumskallemajoritetens": "dumskallemajoritet",
    "dumskallemajoriteter": "dumskallemajoritet",
    "dumskallemajoriteterna": "dumskallemajoritet",
    "dumskallemajoriteternas": "dumskallemajoritet",
    "dumskallemajoriteters": "dumskallemajoritet",
    "dumskallemajoritets": "dumskallemajoritet",
    "dumskallen": "dumskalle",
    "dumskallens": "dumskalle",
    "dumskalles": "dumskalle",
    "dumskalls": "dumskalle",
    "dumsnutar": "dumsnut",
    "dumsnutarna": "dumsnut",
    "dumsnutarnas": "dumsnut",
    "dumsnutars": "dumsnut",
    "dumsnuten": "dumsnut",
    "dumsnutens": "dumsnut",
    "dumsnuts": "dumsnut",
    "dumstrutar": "dumstrut",
    "dumstrutarna": "dumstrut",
    "dumstrutarnas": "dumstrut",
    "dumstrutars": "dumstrut",
    "dumstruten": "dumstrut",
    "dumstrutens": "dumstrut",
    "dumstruts": "dumstrut",
    "dumt": "dum",
    "dumts": "dum",
    "dunade": "duna",
    "dunades": "duna",
    "dunande": "duna",
    "dunanden": "dunande",
    "dunandena": "dunande",
    "dunandenas": "dunande",
    "dunandens": "dunande",
    "dunandes": "dunande",
    "dunandet": "dunande",
    "dunandets": "dunande",
    "dunar": "duna",
    "dunas": "duna",
    "dunat": "duna",
    "dunats": "duna",
    "dunbollar": "dunboll",
    "dunbollarna": "dunboll",
    "dunbollarnas": "dunboll",
    "dunbollars": "dunboll",
    "dunbollen": "dunboll",
    "dunbollens": "dunboll",
    "dunbolls": "dunboll",
    "dunder": "dundra",
    "dundergudar": "dundergud",
    "dundergudarna": "dundergud",
    "dundergudarnas": "dundergud",
    "dundergudars": "dundergud",
    "dunderguden": "dundergud",
    "dundergudens": "dundergud",
    "dunderguds": "dundergud",
    "dunderhonungen": "dunderhonung",
    "dunderhonungens": "dunderhonung",
    "dunderhonungs": "dunderhonung",
    "dunders": "dunder",
    "dundrade": "dundra",
    "dundrades": "dundra",
    "dundrande": "dundra",
    "dundranden": "dundrande",
    "dundrandena": "dundrande",
    "dundrandenas": "dundrande",
    "dundrandens": "dundrande",
    "dundrandes": "dundrande",
    "dundrandet": "dundrande",
    "dundrandets": "dundrande",
    "dundrar": "dundra",
    "dundras": "dundra",
    "dundrat": "dundra",
    "dundrats": "dundra",
    "dundren": "dunder",
    "dundrens": "dunder",
    "dundret": "dunder",
    "dundrets": "dunder",
    "dunen": "dun",
    "dunens": "dun",
    "dunet": "dun",
    "dunets": "dun",
    "dung": "dunge",
    "dungar": "dunge",
    "dungarna": "dunge",
    "dungarnas": "dunge",
    "dungars": "dunge",
    "dungen": "dunge",
    "dungens": "dunge",
    "dunges": "dunge",
    "dungs": "dunge",
    "duniga": "dunig",
    "dunigare": "dunig",
    "dunigares": "dunig",
    "dunigas": "dunig",
    "dunigast": "dunig",
    "dunigaste": "dunig",
    "dunigastes": "dunig",
    "dunigasts": "dunig",
    "dunige": "dunig",
    "duniges": "dunig",
    "dunigs": "dunig",
    "dunigt": "dunig",
    "dunigts": "dunig",
    "dunk": "dunka",
    "dunkad": "dunka",
    "dunkade": "dunka",
    "dunkades": "dunka",
    "dunkads": "dunka",
    "dunkande": "dunka",
    "dunkanden": "dunkande",
    "dunkandena": "dunkande",
    "dunkandenas": "dunkande",
    "dunkandens": "dunkande",
    "dunkandes": "dunkande",
    "dunkandet": "dunkande",
    "dunkandets": "dunkande",
    "dunkar": "dunka",
    "dunkarna": "dunk",
    "dunkarnas": "dunk",
    "dunkars": "dunk",
    "dunkas": "dunka",
    "dunkat": "dunka",
    "dunkats": "dunka",
    "dunkelblåa": "dunkelblå",
    "dunkelblåare": "dunkelblå",
    "dunkelblåares": "dunkelblå",
    "dunkelblåas": "dunkelblå",
    "dunkelblåast": "dunkelblå",
    "dunkelblåaste": "dunkelblå",
    "dunkelblåastes": "dunkelblå",
    "dunkelblåasts": "dunkelblå",
    "dunkelblåe": "dunkelblå",
    "dunkelblåes": "dunkelblå",
    "dunkelblås": "dunkelblå",
    "dunkelblått": "dunkelblå",
    "dunkelblåtts": "dunkelblå",
    "dunkelheten": "dunkelhet",
    "dunkelhetens": "dunkelhet",
    "dunkelheter": "dunkelhet",
    "dunkelheterna": "dunkelhet",
    "dunkelheternas": "dunkelhet",
    "dunkelheters": "dunkelhet",
    "dunkelhets": "dunkelhet",
    "dunkels": "dunkel",
    "dunkelt": "dunkel",
    "dunkelts": "dunkel",
    "dunken": "dunk",
    "dunkens": "dunk",
    "dunket": "dunk",
    "dunkets": "dunk",
    "dunkla": "dunkel",
    "dunklare": "dunkel",
    "dunklares": "dunkel",
    "dunklas": "dunkel",
    "dunklast": "dunkel",
    "dunklaste": "dunkel",
    "dunklastes": "dunkel",
    "dunklasts": "dunkel",
    "dunkle": "dunkel",
    "dunkles": "dunkel",
    "dunklet": "dunkel",
    "dunklets": "dunkel",
    "dunks": "dunk",
    "dunlätta": "dunlätt",
    "dunlättare": "dunlätt",
    "dunlättares": "dunlätt",
    "dunlättas": "dunlätt",
    "dunlättast": "dunlätt",
    "dunlättaste": "dunlätt",
    "dunlättastes": "dunlätt",
    "dunlättasts": "dunlätt",
    "dunlätte": "dunlätt",
    "dunlättes": "dunlätt",
    "dunlätts": "dunlätt",
    "duns": "dunsa",
    "dunsade": "dunsa",
    "dunsades": "dunsa",
    "dunsande": "dunsa",
    "dunsanden": "dunsande",
    "dunsandena": "dunsande",
    "dunsandenas": "dunsande",
    "dunsandens": "dunsande",
    "dunsandes": "dunsande",
    "dunsandet": "dunsande",
    "dunsandets": "dunsande",
    "dunsar": "dunsa",
    "dunsarna": "duns",
    "dunsarnas": "duns",
    "dunsars": "duns",
    "dunsas": "dunsa",
    "dunsat": "dunsa",
    "dunsats": "dunsa",
    "dunsen": "duns",
    "dunsens": "duns",
    "dunstad": "dunsta",
    "dunstade": "dunsta",
    "dunstades": "dunsta",
    "dunstads": "dunsta",
    "dunstande": "dunsta",
    "dunstanden": "dunstande",
    "dunstandena": "dunstande",
    "dunstandenas": "dunstande",
    "dunstandens": "dunstande",
    "dunstandes": "dunstande",
    "dunstandet": "dunstande",
    "dunstandets": "dunstande",
    "dunstar": "dunsta",
    "dunstas": "dunsta",
    "dunstat": "dunsta",
    "dunstats": "dunsta",
    "dunsten": "dunst",
    "dunstens": "dunst",
    "dunster": "dunst",
    "dunsterna": "dunst",
    "dunsternas": "dunst",
    "dunsters": "dunst",
    "dunstiga": "dunstig",
    "dunstigare": "dunstig",
    "dunstigares": "dunstig",
    "dunstigas": "dunstig",
    "dunstigast": "dunstig",
    "dunstigaste": "dunstig",
    "dunstigastes": "dunstig",
    "dunstigasts": "dunstig",
    "dunstige": "dunstig",
    "dunstiges": "dunstig",
    "dunstigheten": "dunstighet",
    "dunstighetens": "dunstighet",
    "dunstighets": "dunstighet",
    "dunstigs": "dunstig",
    "dunstigt": "dunstig",
    "dunstigts": "dunstig",
    "dunsts": "dunst",
    "dunungar": "dununge",
    "dunungarna": "dununge",
    "dunungarnas": "dununge",
    "dunungars": "dununge",
    "dunungen": "dununge",
    "dunungens": "dununge",
    "dununges": "dununge",
    "duodecimalsystemen": "duodecimalsystem",
    "duodecimalsystemens": "duodecimalsystem",
    "duodecimalsystemet": "duodecimalsystem",
    "duodecimalsystemets": "duodecimalsystem",
    "duodecimalsystems": "duodecimalsystem",
    "duodesen": "duodes",
    "duodesens": "duodes",
    "duodeser": "duodes",
    "duodeserna": "duodes",
    "duodesernas": "duodes",
    "duodesers": "duodes",
    "duon": "duo",
    "duons": "duo",
    "duor": "duo",
    "duorna": "duo",
    "duornas": "duo",
    "duors": "duo",
    "duos": "duo",
    "duosen": "duo",
    "duosens": "duo",
    "duperad": "dupera",
    "duperade": "dupera",
    "duperades": "dupera",
    "duperads": "dupera",
    "duperande": "dupera",
    "duperanden": "duperande",
    "duperandena": "duperande",
    "duperandenas": "duperande",
    "duperandens": "duperande",
    "duperandes": "duperande",
    "duperandet": "duperande",
    "duperandets": "duperande",
    "duperar": "dupera",
    "duperas": "dupera",
    "duperat": "dupera",
    "duperats": "dupera",
    "duperbara": "duperbar",
    "duperbarare": "duperbar",
    "duperbarares": "duperbar",
    "duperbaras": "duperbar",
    "duperbarast": "duperbar",
    "duperbaraste": "duperbar",
    "duperbarastes": "duperbar",
    "duperbarasts": "duperbar",
    "duperbare": "duperbar",
    "duperbares": "duperbar",
    "duperbarheten": "duperbarhet",
    "duperbarhetens": "duperbarhet",
    "duperbarhets": "duperbarhet",
    "duperbars": "duperbar",
    "duperbart": "duperbar",
    "duperbarts": "duperbar",
    "duperingar": "dupering",
    "duperingarna": "dupering",
    "duperingarnas": "dupering",
    "duperingars": "dupering",
    "duperingen": "dupering",
    "duperingens": "dupering",
    "duperings": "dupering",
    "dupletten": "duplett",
    "duplettens": "duplett",
    "dupletter": "duplett",
    "dupletterna": "duplett",
    "dupletternas": "duplett",
    "dupletters": "duplett",
    "dupletts": "duplett",
    "duplexfärgen": "duplexfärg",
    "duplexfärgens": "duplexfärg",
    "duplexfärger": "duplexfärg",
    "duplexfärgerna": "duplexfärg",
    "duplexfärgernas": "duplexfärg",
    "duplexfärgers": "duplexfärg",
    "duplexfärgs": "duplexfärg",
    "duplicerad": "duplicera",
    "duplicerade": "duplicera",
    "duplicerades": "duplicera",
    "duplicerads": "duplicera",
    "duplicerande": "duplicera",
    "dupliceranden": "duplicerande",
    "duplicerandena": "duplicerande",
    "duplicerandenas": "duplicerande",
    "duplicerandens": "duplicerande",
    "duplicerandes": "duplicerande",
    "duplicerandet": "duplicerande",
    "duplicerandets": "duplicerande",
    "duplicerar": "duplicera",
    "dupliceras": "duplicera",
    "duplicerat": "duplicera",
    "duplicerats": "duplicera",
    "duplicerbara": "duplicerbar",
    "duplicerbarare": "duplicerbar",
    "duplicerbarares": "duplicerbar",
    "duplicerbaras": "duplicerbar",
    "duplicerbarast": "duplicerbar",
    "duplicerbaraste": "duplicerbar",
    "duplicerbarastes": "duplicerbar",
    "duplicerbarasts": "duplicerbar",
    "duplicerbare": "duplicerbar",
    "duplicerbares": "duplicerbar",
    "duplicerbarheten": "duplicerbarhet",
    "duplicerbarhetens": "duplicerbarhet",
    "duplicerbarhets": "duplicerbarhet",
    "duplicerbars": "duplicerbar",
    "duplicerbart": "duplicerbar",
    "duplicerbarts": "duplicerbar",
    "dupliceringar": "duplicering",
    "dupliceringarna": "duplicering",
    "dupliceringarnas": "duplicering",
    "dupliceringars": "duplicering",
    "dupliceringen": "duplicering",
    "dupliceringens": "duplicering",
    "duplicerings": "duplicering",
    "duplikaten": "duplikat",
    "duplikatens": "duplikat",
    "duplikatet": "duplikat",
    "duplikatets": "duplikat",
    "duplikatorer": "duplikator",
    "duplikatorerna": "duplikator",
    "duplikatorernas": "duplikator",
    "duplikatorers": "duplikator",
    "duplikatorn": "duplikator",
    "duplikatorns": "duplikator",
    "duplikators": "duplikator",
    "duplikats": "duplikat",
    "dupliken": "duplik",
    "duplikens": "duplik",
    "dupliker": "duplik",
    "duplikerna": "duplik",
    "duplikernas": "duplik",
    "duplikers": "duplik",
    "dupliks": "duplik",
    "durabela": "durabel",
    "durabelare": "durabel",
    "durabelares": "durabel",
    "durabelas": "durabel",
    "durabelast": "durabel",
    "durabelaste": "durabel",
    "durabelastes": "durabel",
    "durabelasts": "durabel",
    "durabele": "durabel",
    "durabeles": "durabel",
    "durabels": "durabel",
    "durabelt": "durabel",
    "durabelts": "durabel",
    "duralexglasen": "duralexglas",
    "duralexglasens": "duralexglas",
    "duralexglaset": "duralexglas",
    "duralexglasets": "duralexglas",
    "duraluminiet": "duraluminium",
    "duraluminiets": "duraluminium",
    "duraluminiumet": "duraluminium",
    "duraluminiumets": "duraluminium",
    "duraluminiums": "duraluminium",
    "durativa": "durativ",
    "durativare": "durativ",
    "durativares": "durativ",
    "durativas": "durativ",
    "durativast": "durativ",
    "durativaste": "durativ",
    "durativastes": "durativ",
    "durativasts": "durativ",
    "durative": "durativ",
    "duratives": "durativ",
    "durativs": "durativ",
    "durativt": "durativ",
    "durativts": "durativ",
    "dureformen": "dureform",
    "dureformens": "dureform",
    "dureformer": "dureform",
    "dureformerna": "dureform",
    "dureformernas": "dureform",
    "dureformers": "dureform",
    "dureforms": "dureform",
    "duren": "dur",
    "durens": "dur",
    "durkade": "durka",
    "durkades": "durka",
    "durkande": "durka",
    "durkanden": "durkande",
    "durkandena": "durkande",
    "durkandenas": "durkande",
    "durkandens": "durkande",
    "durkandes": "durkande",
    "durkandet": "durkande",
    "durkandets": "durkande",
    "durkar": "durka",
    "durkarna": "durk",
    "durkarnas": "durk",
    "durkars": "durk",
    "durkas": "durka",
    "durkat": "durka",
    "durkats": "durka",
    "durkdrivens": "durkdriven",
    "durkdrivet": "durkdriven",
    "durkdrivets": "durkdriven",
    "durkdrivna": "durkdriven",
    "durkdrivnare": "durkdriven",
    "durkdrivnares": "durkdriven",
    "durkdrivnas": "durkdriven",
    "durkdrivnast": "durkdriven",
    "durkdrivnaste": "durkdriven",
    "durkdrivnastes": "durkdriven",
    "durkdrivnasts": "durkdriven",
    "durkdrivne": "durkdriven",
    "durkdrivnes": "durkdriven",
    "durken": "durk",
    "durkens": "durk",
    "durkmönsterna": "durkmönster",
    "durkmönsternas": "durkmönster",
    "durkmönsters": "durkmönster",
    "durkmönstren": "durkmönster",
    "durkmönstrens": "durkmönster",
    "durkmönstret": "durkmönster",
    "durkmönstrets": "durkmönster",
    "durks": "durk",
    "durkslagen": "durkslag",
    "durkslagens": "durkslag",
    "durkslaget": "durkslag",
    "durkslagets": "durkslag",
    "durkslags": "durkslag",
    "duroplasten": "duroplast",
    "duroplastens": "duroplast",
    "duroplaster": "duroplast",
    "duroplasterna": "duroplast",
    "duroplasternas": "duroplast",
    "duroplasters": "duroplast",
    "duroplasts": "duroplast",
    "durran": "durra",
    "durrans": "durra",
    "durras": "durra",
    "durrat": "durra",
    "durrats": "durra",
    "durs": "dur",
    "durumvetes": "durumvete",
    "durumvetet": "durumvete",
    "durumvetets": "durumvete",
    "dusch": "duscha",
    "duschad": "duscha",
    "duschade": "duscha",
    "duschades": "duscha",
    "duschads": "duscha",
    "duschande": "duscha",
    "duschanden": "duschande",
    "duschandena": "duschande",
    "duschandenas": "duschande",
    "duschandens": "duschande",
    "duschandes": "duschande",
    "duschandet": "duschande",
    "duschandets": "duschande",
    "duschar": "duscha",
    "duscharna": "dusch",
    "duscharnas": "dusch",
    "duschars": "dusch",
    "duschas": "duscha",
    "duschat": "duscha",
    "duschats": "duscha",
    "duschdraperier": "duschdraperi",
    "duschdraperierna": "duschdraperi",
    "duschdraperiernas": "duschdraperi",
    "duschdraperiers": "duschdraperi",
    "duschdraperiet": "duschdraperi",
    "duschdraperiets": "duschdraperi",
    "duschdraperis": "duschdraperi",
    "duschdraperit": "duschdraperi",
    "duschdraperits": "duschdraperi",
    "duschen": "dusch",
    "duschens": "dusch",
    "duschhanddukar": "duschhandduk",
    "duschhanddukarna": "duschhandduk",
    "duschhanddukarnas": "duschhandduk",
    "duschhanddukars": "duschhandduk",
    "duschhandduken": "duschhandduk",
    "duschhanddukens": "duschhandduk",
    "duschhandduks": "duschhandduk",
    "duschhandtagen": "duschhandtag",
    "duschhandtagens": "duschhandtag",
    "duschhandtaget": "duschhandtag",
    "duschhandtagets": "duschhandtag",
    "duschhandtags": "duschhandtag",
    "duschkrämen": "duschkräm",
    "duschkrämens": "duschkräm",
    "duschkrämer": "duschkräm",
    "duschkrämerna": "duschkräm",
    "duschkrämernas": "duschkräm",
    "duschkrämers": "duschkräm",
    "duschkräms": "duschkräm",
    "duschs": "dusch",
    "duschväggar": "duschvägg",
    "duschväggarna": "duschvägg",
    "duschväggarnas": "duschvägg",
    "duschväggars": "duschvägg",
    "duschväggen": "duschvägg",
    "duschväggens": "duschvägg",
    "duschväggs": "duschvägg",
    "dusen": "dus",
    "dusens": "dus",
    "duser": "dus",
    "duserna": "dus",
    "dusernas": "dus",
    "dusers": "dus",
    "duskade": "duska",
    "duskades": "duska",
    "duskande": "duska",
    "duskanden": "duskande",
    "duskandena": "duskande",
    "duskandenas": "duskande",
    "duskandens": "duskande",
    "duskandes": "duskande",
    "duskandet": "duskande",
    "duskandets": "duskande",
    "duskar": "duska",
    "duskas": "duska",
    "duskat": "duska",
    "duskats": "duska",
    "dusket": "dusk",
    "duskets": "dusk",
    "dusks": "dusk",
    "duskålar": "duskål",
    "duskålarna": "duskål",
    "duskålarnas": "duskål",
    "duskålars": "duskål",
    "duskålen": "duskål",
    "duskålens": "duskål",
    "duskåls": "duskål",
    "dussinen": "dussin",
    "dussinens": "dussin",
    "dussinet": "dussin",
    "dussinets": "dussin",
    "dussinmänniskan": "dussinmänniska",
    "dussinmänniskans": "dussinmänniska",
    "dussinmänniskas": "dussinmänniska",
    "dussinmännisko": "dussinmänniska",
    "dussinmänniskor": "dussinmänniska",
    "dussinmänniskorna": "dussinmänniska",
    "dussinmänniskornas": "dussinmänniska",
    "dussinmänniskors": "dussinmänniska",
    "dussinromanen": "dussinroman",
    "dussinromanens": "dussinroman",
    "dussinromaner": "dussinroman",
    "dussinromanerna": "dussinroman",
    "dussinromanernas": "dussinroman",
    "dussinromaners": "dussinroman",
    "dussinromans": "dussinroman",
    "dussins": "dussin",
    "dussintalen": "dussintal",
    "dussintalens": "dussintal",
    "dussintalet": "dussintal",
    "dussintalets": "dussintal",
    "dussintals": "dussintal",
    "dussinvar": "dussinvara",
    "dussinvaran": "dussinvara",
    "dussinvarans": "dussinvara",
    "dussinvaras": "dussinvara",
    "dussinvare": "dussinvara",
    "dussinvaror": "dussinvara",
    "dussinvarorna": "dussinvara",
    "dussinvarornas": "dussinvara",
    "dussinvarors": "dussinvara",
    "dussinvars": "dussinvara",
    "dusten": "dust",
    "dustens": "dust",
    "duster": "dust",
    "dusterna": "dust",
    "dusternas": "dust",
    "dusters": "dust",
    "dusts": "dust",
    "dusören": "dusör",
    "dusörens": "dusör",
    "dusörer": "dusör",
    "dusörerna": "dusör",
    "dusörernas": "dusör",
    "dusörers": "dusör",
    "dusörs": "dusör",
    "duv": "duva",
    "duvade": "duva",
    "duvades": "duva",
    "duvan": "duva",
    "duvande": "duva",
    "duvanden": "duvande",
    "duvandena": "duvande",
    "duvandenas": "duvande",
    "duvandens": "duvande",
    "duvandes": "duvande",
    "duvandet": "duvande",
    "duvandets": "duvande",
    "duvans": "duva",
    "duvar": "duva",
    "duvas": "duva",
    "duvat": "duva",
    "duvats": "duva",
    "duvblåa": "duvblå",
    "duvblåare": "duvblå",
    "duvblåares": "duvblå",
    "duvblåas": "duvblå",
    "duvblåast": "duvblå",
    "duvblåaste": "duvblå",
    "duvblåastes": "duvblå",
    "duvblåasts": "duvblå",
    "duvblåe": "duvblå",
    "duvblåes": "duvblå",
    "duvblås": "duvblå",
    "duvblått": "duvblå",
    "duvblåtts": "duvblå",
    "duve": "duva",
    "duvenheten": "duvenhet",
    "duvenhetens": "duvenhet",
    "duvenhets": "duvenhet",
    "duvens": "duven",
    "duvet": "duven",
    "duvets": "duven",
    "duvfågeln": "duvfågel",
    "duvfågelns": "duvfågel",
    "duvfågels": "duvfågel",
    "duvfåglar": "duvfågel",
    "duvfåglarna": "duvfågel",
    "duvfåglarnas": "duvfågel",
    "duvfåglars": "duvfågel",
    "duvhökar": "duvhök",
    "duvhökarna": "duvhök",
    "duvhökarnas": "duvhök",
    "duvhökars": "duvhök",
    "duvhöken": "duvhök",
    "duvhökens": "duvhök",
    "duvhöks": "duvhök",
    "duvjäveln": "duvjävel",
    "duvjävelns": "duvjävel",
    "duvjävels": "duvjävel",
    "duvjävlar": "duvjävel",
    "duvjävlarna": "duvjävel",
    "duvjävlarnas": "duvjävel",
    "duvjävlars": "duvjävel",
    "duvkull": "duvkulla",
    "duvkullan": "duvkulla",
    "duvkullans": "duvkulla",
    "duvkullas": "duvkulla",
    "duvkulle": "duvkulla",
    "duvkullor": "duvkulla",
    "duvkullorna": "duvkulla",
    "duvkullornas": "duvkulla",
    "duvkullors": "duvkulla",
    "duvkulls": "duvkulla",
    "duvna": "duven",
    "duvnade": "duvna",
    "duvnades": "duvna",
    "duvnande": "duvna",
    "duvnanden": "duvnande",
    "duvnandena": "duvnande",
    "duvnandenas": "duvnande",
    "duvnandens": "duvnande",
    "duvnandes": "duvnande",
    "duvnandet": "duvnande",
    "duvnandets": "duvnande",
    "duvnar": "duvna",
    "duvnare": "duven",
    "duvnares": "duven",
    "duvnas": "duvna",
    "duvnast": "duven",
    "duvnaste": "duven",
    "duvnastes": "duven",
    "duvnasts": "duven",
    "duvnat": "duvna",
    "duvnats": "duvna",
    "duvne": "duven",
    "duvnes": "duven",
    "duvningar": "duvning",
    "duvningarna": "duvning",
    "duvningarnas": "duvning",
    "duvningars": "duvning",
    "duvningen": "duvning",
    "duvningens": "duvning",
    "duvnings": "duvning",
    "duvor": "duva",
    "duvorna": "duva",
    "duvornas": "duva",
    "duvors": "duva",
    "duvpolitiken": "duvpolitik",
    "duvpolitikens": "duvpolitik",
    "duvpolitiks": "duvpolitik",
    "duvs": "duva",
    "duvslagen": "duvslag",
    "duvslagens": "duvslag",
    "duvslaget": "duvslag",
    "duvslagets": "duvslag",
    "duvslags": "duvslag",
    "duvungar": "duvunge",
    "duvungarna": "duvunge",
    "duvungarnas": "duvunge",
    "duvungars": "duvunge",
    "duvungen": "duvunge",
    "duvungens": "duvunge",
    "duvunges": "duvunge",
    "dvalan": "dvala",
    "dvalans": "dvala",
    "dvalas": "dvala",
    "dvaldes": "dväljas",
    "dvalts": "dväljas",
    "dvd-filmen": "dvd-film",
    "dvd-filmer": "dvd-film",
    "dvd-filmernas": "dvd-film",
    "dvd-films": "dvd-film",
    "dvd-rommen": "dvd-rom",
    "dvd-rommens": "dvd-rom",
    "dvd-rommet": "dvd-rom",
    "dvd-rommets": "dvd-rom",
    "dvd:ar": "dvd",
    "dvd:arnas": "dvd",
    "dvd:er": "dvd",
    "dvd:ernas": "dvd",
    "dvd:n": "dvd",
    "dvdarna": "dvd",
    "dvdars": "dvd",
    "dvderna": "dvd",
    "dvders": "dvd",
    "dvdn": "dvd",
    "dväljdes": "dväljas",
    "dväljes": "dväljas",
    "dväljs": "dväljas",
    "dvälts": "dväljas",
    "dvärgalåten": "dvärgalåt",
    "dvärgalåtens": "dvärgalåt",
    "dvärgalåts": "dvärgalåt",
    "dvärgar": "dvärg",
    "dvärgarna": "dvärg",
    "dvärgarnas": "dvärg",
    "dvärgars": "dvärg",
    "dvärgbjörkar": "dvärgbjörk",
    "dvärgbjörkarna": "dvärgbjörk",
    "dvärgbjörkarnas": "dvärgbjörk",
    "dvärgbjörkars": "dvärgbjörk",
    "dvärgbjörken": "dvärgbjörk",
    "dvärgbjörkens": "dvärgbjörk",
    "dvärgbjörks": "dvärgbjörk",
    "dvärgbrytar": "dvärgbrytare",
    "dvärgbrytaren": "dvärgbrytare",
    "dvärgbrytarens": "dvärgbrytare",
    "dvärgbrytares": "dvärgbrytare",
    "dvärgbrytarna": "dvärgbrytare",
    "dvärgbrytarnas": "dvärgbrytare",
    "dvärgbusk": "dvärgbuske",
    "dvärgbuskar": "dvärgbuske",
    "dvärgbuskarna": "dvärgbuske",
    "dvärgbuskarnas": "dvärgbuske",
    "dvärgbuskars": "dvärgbuske",
    "dvärgbusken": "dvärgbuske",
    "dvärgbuskens": "dvärgbuske",
    "dvärgbuskes": "dvärgbuske",
    "dvärgen": "dvärg",
    "dvärgens": "dvärg",
    "dvärggalaxen": "dvärggalax",
    "dvärggalaxens": "dvärggalax",
    "dvärggalaxer": "dvärggalax",
    "dvärggalaxerna": "dvärggalax",
    "dvärggalaxernas": "dvärggalax",
    "dvärggalaxers": "dvärggalax",
    "dvärghamstern": "dvärghamster",
    "dvärghamsterns": "dvärghamster",
    "dvärghamsters": "dvärghamster",
    "dvärghamstrar": "dvärghamster",
    "dvärghamstrarna": "dvärghamster",
    "dvärghamstrarnas": "dvärghamster",
    "dvärghamstrars": "dvärghamster",
    "dvärghundar": "dvärghund",
    "dvärghundarna": "dvärghund",
    "dvärghundarnas": "dvärghund",
    "dvärghundars": "dvärghund",
    "dvärghunden": "dvärghund",
    "dvärghundens": "dvärghund",
    "dvärghunds": "dvärghund",
    "dvärgs": "dvärg",
    "dvärgtallar": "dvärgtall",
    "dvärgtallarna": "dvärgtall",
    "dvärgtallarnas": "dvärgtall",
    "dvärgtallars": "dvärgtall",
    "dvärgtallen": "dvärgtall",
    "dvärgtallens": "dvärgtall",
    "dvärgtalls": "dvärgtall",
    "dybladen": "dyblad",
    "dybladens": "dyblad",
    "dybladet": "dyblad",
    "dybladets": "dyblad",
    "dyblads": "dyblad",
    "dyblöta": "dyblöt",
    "dyblötare": "dyblöt",
    "dyblötares": "dyblöt",
    "dyblötas": "dyblöt",
    "dyblötast": "dyblöt",
    "dyblötaste": "dyblöt",
    "dyblötastes": "dyblöt",
    "dyblötasts": "dyblöt",
    "dyblöte": "dyblöt",
    "dyblötes": "dyblöt",
    "dyblötheten": "dyblöthet",
    "dyblöthetens": "dyblöthet",
    "dyblöthets": "dyblöthet",
    "dyblöts": "dyblöt",
    "dyblött": "dyblöt",
    "dyblötts": "dyblöt",
    "dyborr": "dyborre",
    "dyborrar": "dyborre",
    "dyborrarna": "dyborre",
    "dyborrarnas": "dyborre",
    "dyborrars": "dyborre",
    "dyborren": "dyborre",
    "dyborrens": "dyborre",
    "dyborres": "dyborre",
    "dyborrs": "dyborre",
    "dyckertar": "dyckert",
    "dyckertarna": "dyckert",
    "dyckertarnas": "dyckert",
    "dyckertars": "dyckert",
    "dyckerten": "dyckert",
    "dyckertens": "dyckert",
    "dyckerts": "dyckert",
    "dygde": "dygd",
    "dygdemönsterna": "dygdemönster",
    "dygdemönsternas": "dygdemönster",
    "dygdemönsters": "dygdemönster",
    "dygdemönstren": "dygdemönster",
    "dygdemönstrens": "dygdemönster",
    "dygdemönstret": "dygdemönster",
    "dygdemönstrets": "dygdemönster",
    "dygden": "dygd",
    "dygdens": "dygd",
    "dygder": "dygd",
    "dygderna": "dygd",
    "dygdernas": "dygd",
    "dygders": "dygd",
    "dygdiga": "dygdig",
    "dygdigare": "dygdig",
    "dygdigares": "dygdig",
    "dygdigas": "dygdig",
    "dygdigast": "dygdig",
    "dygdigaste": "dygdig",
    "dygdigastes": "dygdig",
    "dygdigasts": "dygdig",
    "dygdige": "dygdig",
    "dygdiges": "dygdig",
    "dygdigheten": "dygdighet",
    "dygdighetens": "dygdighet",
    "dygdighets": "dygdighet",
    "dygdigs": "dygdig",
    "dygdigt": "dygdig",
    "dygdigts": "dygdig",
    "dygds": "dygd",
    "dygnen": "dygn",
    "dygnens": "dygn",
    "dygnet": "dygn",
    "dygnetruntöppens": "dygnetruntöppen",
    "dygnetruntöppet": "dygnetruntöppen",
    "dygnetruntöppets": "dygnetruntöppen",
    "dygnetruntöppna": "dygnetruntöppen",
    "dygnetruntöppnare": "dygnetruntöppen",
    "dygnetruntöppnares": "dygnetruntöppen",
    "dygnetruntöppnas": "dygnetruntöppen",
    "dygnetruntöppnast": "dygnetruntöppen",
    "dygnetruntöppnaste": "dygnetruntöppen",
    "dygnetruntöppnastes": "dygnetruntöppen",
    "dygnetruntöppnasts": "dygnetruntöppen",
    "dygnetruntöppne": "dygnetruntöppen",
    "dygnetruntöppnes": "dygnetruntöppen",
    "dygnets": "dygn",
    "dygns": "dygn",
    "dygnsgamla": "dygnsgammal",
    "dygnsgamlas": "dygnsgammal",
    "dygnsgamle": "dygnsgammal",
    "dygnsgamles": "dygnsgammal",
    "dygnsgammals": "dygnsgammal",
    "dygnsgammalt": "dygnsgammal",
    "dygnsgammalts": "dygnsgammal",
    "dygnsringar": "dygnsring",
    "dygnsringarna": "dygnsring",
    "dygnsringarnas": "dygnsring",
    "dygnsringars": "dygnsring",
    "dygnsringen": "dygnsring",
    "dygnsringens": "dygnsring",
    "dygnsrings": "dygnsring",
    "dygnsrytmen": "dygnsrytm",
    "dygnsrytmens": "dygnsrytm",
    "dygnsrytmer": "dygnsrytm",
    "dygnsrytmerna": "dygnsrytm",
    "dygnsrytmernas": "dygnsrytm",
    "dygnsrytmers": "dygnsrytm",
    "dygnsrytms": "dygnsrytm",
    "dygnsvilla": "dygnsvill",
    "dygnsvillare": "dygnsvill",
    "dygnsvillares": "dygnsvill",
    "dygnsvillas": "dygnsvill",
    "dygnsvillast": "dygnsvill",
    "dygnsvillaste": "dygnsvill",
    "dygnsvillastes": "dygnsvill",
    "dygnsvillasts": "dygnsvill",
    "dygnsville": "dygnsvill",
    "dygnsvilles": "dygnsvill",
    "dygnsvillheten": "dygnsvillhet",
    "dygnsvillhetens": "dygnsvillhet",
    "dygnsvillhets": "dygnsvillhet",
    "dygnsvills": "dygnsvill",
    "dyiga": "dyig",
    "dyigare": "dyig",
    "dyigares": "dyig",
    "dyigas": "dyig",
    "dyigast": "dyig",
    "dyigaste": "dyig",
    "dyigastes": "dyig",
    "dyigasts": "dyig",
    "dyige": "dyig",
    "dyiges": "dyig",
    "dyigheten": "dyighet",
    "dyighetens": "dyighet",
    "dyighets": "dyighet",
    "dyigs": "dyig",
    "dyigt": "dyig",
    "dyigts": "dyig",
    "dyk": "dyka",
    "dykande": "dyka",
    "dykanden": "dykande",
    "dykandena": "dykande",
    "dykandenas": "dykande",
    "dykandens": "dykande",
    "dykandes": "dykande",
    "dykandet": "dykande",
    "dykandets": "dykande",
    "dykands": "dykand",
    "dykar": "dykare",
    "dykarbagg": "dykarbagge",
    "dykarbaggar": "dykarbagge",
    "dykarbaggarna": "dykarbagge",
    "dykarbaggarnas": "dykarbagge",
    "dykarbaggars": "dykarbagge",
    "dykarbaggen": "dykarbagge",
    "dykarbaggens": "dykarbagge",
    "dykarbagges": "dykarbagge",
    "dykarbaggs": "dykarbagge",
    "dykardräkten": "dykardräkt",
    "dykardräktens": "dykardräkt",
    "dykardräkter": "dykardräkt",
    "dykardräkterna": "dykardräkt",
    "dykardräkternas": "dykardräkt",
    "dykardräkters": "dykardräkt",
    "dykardräkts": "dykardräkt",
    "dykaren": "dykare",
    "dykarens": "dykare",
    "dykares": "dykare",
    "dykarklock": "dykarklocka",
    "dykarklockan": "dykarklocka",
    "dykarklockans": "dykarklocka",
    "dykarklockas": "dykarklocka",
    "dykarklocke": "dykarklocka",
    "dykarklockor": "dykarklocka",
    "dykarklockorna": "dykarklocka",
    "dykarklockornas": "dykarklocka",
    "dykarklockors": "dykarklocka",
    "dykarklocks": "dykarklocka",
    "dykarna": "dykare",
    "dykarnas": "dykare",
    "dykarsjukan": "dykarsjuka",
    "dykarsjukans": "dykarsjuka",
    "dykarsjukas": "dykarsjuka",
    "dykarsjuke": "dykarsjuka",
    "dykarsjuks": "dykarsjuka",
    "dykarutrustningar": "dykarutrustning",
    "dykarutrustningarna": "dykarutrustning",
    "dykarutrustningarnas": "dykarutrustning",
    "dykarutrustningars": "dykarutrustning",
    "dykarutrustningen": "dykarutrustning",
    "dykarutrustningens": "dykarutrustning",
    "dykarutrustnings": "dykarutrustning",
    "dykas": "dyka",
    "dykdalben": "dykdalb",
    "dykdalbens": "dykdalb",
    "dykdalber": "dykdalb",
    "dykdalberna": "dykdalb",
    "dykdalbernas": "dykdalb",
    "dykdalbers": "dykdalb",
    "dykdalbs": "dykdalb",
    "dyke": "dyka",
    "dyker": "dyka",
    "dykeriet": "dykeri",
    "dykeriets": "dykeri",
    "dykeris": "dykeri",
    "dykerit": "dykeri",
    "dykerits": "dykeri",
    "dykes": "dyka",
    "dykningar": "dykning",
    "dykningarna": "dykning",
    "dykningarnas": "dykning",
    "dykningars": "dykning",
    "dykningen": "dykning",
    "dykningens": "dykning",
    "dyknings": "dykning",
    "dyks": "dyka",
    "dykt": "dyka",
    "dykte": "dyka",
    "dyktes": "dyka",
    "dykts": "dyka",
    "dykänder": "dykand",
    "dykänderna": "dykand",
    "dykändernas": "dykand",
    "dykänders": "dykand",
    "dylidan": "dylik",
    "dylidana": "dylik",
    "dylidanas": "dylik",
    "dylidans": "dylik",
    "dylidant": "dylik",
    "dylidants": "dylik",
    "dylika": "dylik",
    "dylikas": "dylik",
    "dyliks": "dylik",
    "dylikt": "dylik",
    "dylikts": "dylik",
    "dymlingar": "dymling",
    "dymlingarna": "dymling",
    "dymlingarnas": "dymling",
    "dymlingars": "dymling",
    "dymlingen": "dymling",
    "dymlingens": "dymling",
    "dymlings": "dymling",
    "dymmelonsdagar": "dymmelonsdag",
    "dymmelonsdagarna": "dymmelonsdag",
    "dymmelonsdagarnas": "dymmelonsdag",
    "dymmelonsdagars": "dymmelonsdag",
    "dymmelonsdagen": "dymmelonsdag",
    "dymmelonsdagens": "dymmelonsdag",
    "dymmelonsdags": "dymmelonsdag",
    "dymmelveck": "dymmelvecka",
    "dymmelveckan": "dymmelvecka",
    "dymmelveckans": "dymmelvecka",
    "dymmelveckas": "dymmelvecka",
    "dymmelvecke": "dymmelvecka",
    "dymmelvecko": "dymmelvecka",
    "dymmelveckor": "dymmelvecka",
    "dymmelveckorna": "dymmelvecka",
    "dymmelveckornas": "dymmelvecka",
    "dymmelveckors": "dymmelvecka",
    "dymmelvecks": "dymmelvecka",
    "dyn": "dyna",
    "dynamiken": "dynamik",
    "dynamikens": "dynamik",
    "dynamiks": "dynamik",
    "dynamiska": "dynamisk",
    "dynamiskare": "dynamisk",
    "dynamiskares": "dynamisk",
    "dynamiskas": "dynamisk",
    "dynamiskast": "dynamisk",
    "dynamiskaste": "dynamisk",
    "dynamiskastes": "dynamisk",
    "dynamiskasts": "dynamisk",
    "dynamiske": "dynamisk",
    "dynamiskes": "dynamisk",
    "dynamisks": "dynamisk",
    "dynamiskt": "dynamisk",
    "dynamiskts": "dynamisk",
    "dynamismen": "dynamism",
    "dynamismens": "dynamism",
    "dynamismer": "dynamism",
    "dynamismerna": "dynamism",
    "dynamismernas": "dynamism",
    "dynamismers": "dynamism",
    "dynamisms": "dynamism",
    "dynamistiska": "dynamistisk",
    "dynamistiskas": "dynamistisk",
    "dynamistiske": "dynamistisk",
    "dynamistiskes": "dynamistisk",
    "dynamistisks": "dynamistisk",
    "dynamistiskt": "dynamistisk",
    "dynamistiskts": "dynamistisk",
    "dynamitarden": "dynamitard",
    "dynamitardens": "dynamitard",
    "dynamitarder": "dynamitard",
    "dynamitarderna": "dynamitard",
    "dynamitardernas": "dynamitard",
    "dynamitarders": "dynamitard",
    "dynamitards": "dynamitard",
    "dynamiten": "dynamit",
    "dynamitens": "dynamit",
    "dynamitgubb": "dynamitgubbe",
    "dynamitgubbar": "dynamitgubbe",
    "dynamitgubbarna": "dynamitgubbe",
    "dynamitgubbarnas": "dynamitgubbe",
    "dynamitgubbars": "dynamitgubbe",
    "dynamitgubben": "dynamitgubbe",
    "dynamitgubbens": "dynamitgubbe",
    "dynamitgubbes": "dynamitgubbe",
    "dynamitgubbs": "dynamitgubbe",
    "dynamits": "dynamit",
    "dynamometern": "dynamometer",
    "dynamometerns": "dynamometer",
    "dynamometers": "dynamometer",
    "dynamometrar": "dynamometer",
    "dynamometrarna": "dynamometer",
    "dynamometrarnas": "dynamometer",
    "dynamometrars": "dynamometer",
    "dynamon": "dynamo",
    "dynamons": "dynamo",
    "dynamor": "dynamo",
    "dynamorna": "dynamo",
    "dynamornas": "dynamo",
    "dynamors": "dynamo",
    "dynamos": "dynamo",
    "dynan": "dyna",
    "dynans": "dyna",
    "dynas": "dyna",
    "dynastien": "dynasti",
    "dynastiens": "dynasti",
    "dynastier": "dynasti",
    "dynastierna": "dynasti",
    "dynastiernas": "dynasti",
    "dynastiers": "dynasti",
    "dynastin": "dynasti",
    "dynastins": "dynasti",
    "dynastis": "dynasti",
    "dynastiska": "dynastisk",
    "dynastiskare": "dynastisk",
    "dynastiskares": "dynastisk",
    "dynastiskas": "dynastisk",
    "dynastiskast": "dynastisk",
    "dynastiskaste": "dynastisk",
    "dynastiskastes": "dynastisk",
    "dynastiskasts": "dynastisk",
    "dynastiske": "dynastisk",
    "dynastiskes": "dynastisk",
    "dynastisks": "dynastisk",
    "dynastiskt": "dynastisk",
    "dynastiskts": "dynastisk",
    "dyne": "dyna",
    "dynen": "dyn",
    "dynens": "dyn",
    "dyner": "dyn",
    "dynerna": "dyn",
    "dynernas": "dyn",
    "dyners": "dyn",
    "dynet": "dyn",
    "dynets": "dyn",
    "dyngan": "dynga",
    "dyngans": "dynga",
    "dyngas": "dynga",
    "dyngbagg": "dyngbagge",
    "dyngbaggar": "dyngbagge",
    "dyngbaggarna": "dyngbagge",
    "dyngbaggarnas": "dyngbagge",
    "dyngbaggars": "dyngbagge",
    "dyngbaggen": "dyngbagge",
    "dyngbaggens": "dyngbagge",
    "dyngbagges": "dyngbagge",
    "dyngbaggs": "dyngbagge",
    "dyngraka": "dyngrak",
    "dyngrakare": "dyngrak",
    "dyngrakares": "dyngrak",
    "dyngrakas": "dyngrak",
    "dyngrakast": "dyngrak",
    "dyngrakaste": "dyngrak",
    "dyngrakastes": "dyngrak",
    "dyngrakasts": "dyngrak",
    "dyngrake": "dyngrak",
    "dyngrakes": "dyngrak",
    "dyngraks": "dyngrak",
    "dyngrakt": "dyngrak",
    "dyngrakts": "dyngrak",
    "dyngsura": "dyngsur",
    "dyngsurare": "dyngsur",
    "dyngsurares": "dyngsur",
    "dyngsuras": "dyngsur",
    "dyngsurast": "dyngsur",
    "dyngsuraste": "dyngsur",
    "dyngsurastes": "dyngsur",
    "dyngsurasts": "dyngsur",
    "dyngsure": "dyngsur",
    "dyngsures": "dyngsur",
    "dyngsurheten": "dyngsurhet",
    "dyngsurhetens": "dyngsurhet",
    "dyngsurhets": "dyngsurhet",
    "dyngsurs": "dyngsur",
    "dyngsurt": "dyngsur",
    "dyngsurts": "dyngsur",
    "dyningar": "dyning",
    "dyningarna": "dyning",
    "dyningarnas": "dyning",
    "dyningars": "dyning",
    "dyningen": "dyning",
    "dyningens": "dyning",
    "dynings": "dyning",
    "dynlandskapen": "dynlandskap",
    "dynlandskapens": "dynlandskap",
    "dynlandskapet": "dynlandskap",
    "dynlandskapets": "dynlandskap",
    "dynlandskaps": "dynlandskap",
    "dynor": "dyna",
    "dynorna": "dyna",
    "dynornas": "dyna",
    "dynors": "dyna",
    "dyns": "dyna",
    "dynten": "dynt",
    "dyntens": "dynt",
    "dyntet": "dynt",
    "dyntets": "dynt",
    "dynts": "dynt",
    "dyra": "dyr",
    "dyrare": "dyr",
    "dyrares": "dyr",
    "dyras": "dyr",
    "dyrast": "dyr",
    "dyraste": "dyr",
    "dyrastes": "dyr",
    "dyrasts": "dyr",
    "dyrbara": "dyrbar",
    "dyrbarare": "dyrbar",
    "dyrbarares": "dyrbar",
    "dyrbaras": "dyrbar",
    "dyrbarast": "dyrbar",
    "dyrbaraste": "dyrbar",
    "dyrbarastes": "dyrbar",
    "dyrbarasts": "dyrbar",
    "dyrbare": "dyrbar",
    "dyrbares": "dyrbar",
    "dyrbarheten": "dyrbarhet",
    "dyrbarhetens": "dyrbarhet",
    "dyrbarheter": "dyrbarhet",
    "dyrbarheterna": "dyrbarhet",
    "dyrbarheternas": "dyrbarhet",
    "dyrbarheters": "dyrbarhet",
    "dyrbarhets": "dyrbarhet",
    "dyrbars": "dyrbar",
    "dyrbart": "dyrbar",
    "dyrbarts": "dyrbar",
    "dyre": "dyr",
    "dyres": "dyr",
    "dyrgripar": "dyrgrip",
    "dyrgriparna": "dyrgrip",
    "dyrgriparnas": "dyrgrip",
    "dyrgripars": "dyrgrip",
    "dyrgripen": "dyrgrip",
    "dyrgripens": "dyrgrip",
    "dyrgrips": "dyrgrip",
    "dyrheten": "dyrhet",
    "dyrhetens": "dyrhet",
    "dyrhets": "dyrhet",
    "dyrk": "dyrka",
    "dyrkad": "dyrka",
    "dyrkade": "dyrka",
    "dyrkades": "dyrka",
    "dyrkads": "dyrka",
    "dyrkande": "dyrka",
    "dyrkanden": "dyrkande",
    "dyrkandena": "dyrkande",
    "dyrkandenas": "dyrkande",
    "dyrkandens": "dyrkande",
    "dyrkandes": "dyrkande",
    "dyrkandet": "dyrkande",
    "dyrkandets": "dyrkande",
    "dyrkans": "dyrkan",
    "dyrkansvärda": "dyrkansvärd",
    "dyrkansvärdare": "dyrkansvärd",
    "dyrkansvärdares": "dyrkansvärd",
    "dyrkansvärdas": "dyrkansvärd",
    "dyrkansvärdast": "dyrkansvärd",
    "dyrkansvärdaste": "dyrkansvärd",
    "dyrkansvärdastes": "dyrkansvärd",
    "dyrkansvärdasts": "dyrkansvärd",
    "dyrkansvärde": "dyrkansvärd",
    "dyrkansvärdes": "dyrkansvärd",
    "dyrkansvärdheten": "dyrkansvärdhet",
    "dyrkansvärdhetens": "dyrkansvärdhet",
    "dyrkansvärdhets": "dyrkansvärdhet",
    "dyrkansvärds": "dyrkansvärd",
    "dyrkansvärt": "dyrkansvärd",
    "dyrkansvärts": "dyrkansvärd",
    "dyrkar": "dyrkare",
    "dyrkaren": "dyrkare",
    "dyrkarens": "dyrkare",
    "dyrkares": "dyrkare",
    "dyrkarna": "dyrkare",
    "dyrkarnas": "dyrkare",
    "dyrkars": "dyrk",
    "dyrkas": "dyrka",
    "dyrkat": "dyrka",
    "dyrkats": "dyrka",
    "dyrken": "dyrk",
    "dyrkens": "dyrk",
    "dyrkfria": "dyrkfri",
    "dyrkfriare": "dyrkfri",
    "dyrkfriares": "dyrkfri",
    "dyrkfrias": "dyrkfri",
    "dyrkfriast": "dyrkfri",
    "dyrkfriaste": "dyrkfri",
    "dyrkfriastes": "dyrkfri",
    "dyrkfriasts": "dyrkfri",
    "dyrkfrie": "dyrkfri",
    "dyrkfries": "dyrkfri",
    "dyrkfris": "dyrkfri",
    "dyrkfritt": "dyrkfri",
    "dyrkfritts": "dyrkfri",
    "dyrks": "dyrk",
    "dyrköpta": "dyrköpt",
    "dyrköptare": "dyrköpt",
    "dyrköptares": "dyrköpt",
    "dyrköptas": "dyrköpt",
    "dyrköptast": "dyrköpt",
    "dyrköptaste": "dyrköpt",
    "dyrköptastes": "dyrköpt",
    "dyrköptasts": "dyrköpt",
    "dyrköpte": "dyrköpt",
    "dyrköptes": "dyrköpt",
    "dyrköptheten": "dyrköpthet",
    "dyrköpthetens": "dyrköpthet",
    "dyrköpthets": "dyrköpthet",
    "dyrköpts": "dyrköpt",
    "dyrorten": "dyrort",
    "dyrortens": "dyrort",
    "dyrorter": "dyrort",
    "dyrorterna": "dyrort",
    "dyrorternas": "dyrort",
    "dyrorters": "dyrort",
    "dyrorts": "dyrort",
    "dyrortsgruppen": "dyrortsgrupp",
    "dyrortsgruppens": "dyrortsgrupp",
    "dyrortsgrupper": "dyrortsgrupp",
    "dyrortsgrupperingar": "dyrortsgruppering",
    "dyrortsgrupperingarna": "dyrortsgruppering",
    "dyrortsgrupperingarnas": "dyrortsgruppering",
    "dyrortsgrupperingars": "dyrortsgruppering",
    "dyrortsgrupperingen": "dyrortsgruppering",
    "dyrortsgrupperingens": "dyrortsgruppering",
    "dyrortsgrupperings": "dyrortsgruppering",
    "dyrortsgrupperna": "dyrortsgrupp",
    "dyrortsgruppernas": "dyrortsgrupp",
    "dyrortsgruppers": "dyrortsgrupp",
    "dyrortsgrupps": "dyrortsgrupp",
    "dyrs": "dyr",
    "dyrt": "dyr",
    "dyrtiden": "dyrtid",
    "dyrtidens": "dyrtid",
    "dyrtider": "dyrtid",
    "dyrtiderna": "dyrtid",
    "dyrtidernas": "dyrtid",
    "dyrtiders": "dyrtid",
    "dyrtids": "dyrtid",
    "dyrts": "dyr",
    "dys": "dysa",
    "dysan": "dysa",
    "dysans": "dysa",
    "dysas": "dysa",
    "dysch": "dyscha",
    "dyschan": "dyscha",
    "dyschans": "dyscha",
    "dyschas": "dyscha",
    "dyschatellen": "dyschatell",
    "dyschatellens": "dyschatell",
    "dyschateller": "dyschatell",
    "dyschatellerna": "dyschatell",
    "dyschatellernas": "dyschatell",
    "dyschatellers": "dyschatell",
    "dyschatells": "dyschatell",
    "dysche": "dyscha",
    "dyschor": "dyscha",
    "dyschorna": "dyscha",
    "dyschornas": "dyscha",
    "dyschors": "dyscha",
    "dyse": "dysa",
    "dysen": "dys",
    "dysens": "dys",
    "dysenterien": "dysenteri",
    "dysenteriens": "dysenteri",
    "dysenterier": "dysenteri",
    "dysenterierna": "dysenteri",
    "dysenteriernas": "dysenteri",
    "dysenteriers": "dysenteri",
    "dysenterin": "dysenteri",
    "dysenterins": "dysenteri",
    "dysenteris": "dysenteri",
    "dyser": "dys",
    "dyserna": "dys",
    "dysernas": "dys",
    "dysers": "dys",
    "dysforien": "dysfori",
    "dysforiens": "dysfori",
    "dysforier": "dysfori",
    "dysforierna": "dysfori",
    "dysforiernas": "dysfori",
    "dysforiers": "dysfori",
    "dysforin": "dysfori",
    "dysforins": "dysfori",
    "dysforis": "dysfori",
    "dysfunktionella": "dysfunktionell",
    "dysfunktionellare": "dysfunktionell",
    "dysfunktionellares": "dysfunktionell",
    "dysfunktionellas": "dysfunktionell",
    "dysfunktionellast": "dysfunktionell",
    "dysfunktionellaste": "dysfunktionell",
    "dysfunktionellastes": "dysfunktionell",
    "dysfunktionellasts": "dysfunktionell",
    "dysfunktionelle": "dysfunktionell",
    "dysfunktionelles": "dysfunktionell",
    "dysfunktionells": "dysfunktionell",
    "dysfunktionellt": "dysfunktionell",
    "dysfunktionellts": "dysfunktionell",
    "dyslektikern": "dyslektiker",
    "dyslektikerna": "dyslektiker",
    "dyslektikernas": "dyslektiker",
    "dyslektikerns": "dyslektiker",
    "dyslektikers": "dyslektiker",
    "dyslektiska": "dyslektisk",
    "dyslektiskas": "dyslektisk",
    "dyslektiske": "dyslektisk",
    "dyslektiskes": "dyslektisk",
    "dyslektisks": "dyslektisk",
    "dyslektiskt": "dyslektisk",
    "dyslektiskts": "dyslektisk",
    "dyslexien": "dyslexi",
    "dyslexiens": "dyslexi",
    "dyslexier": "dyslexi",
    "dyslexierna": "dyslexi",
    "dyslexiernas": "dyslexi",
    "dyslexiers": "dyslexi",
    "dyslexin": "dyslexi",
    "dyslexins": "dyslexi",
    "dyslexis": "dyslexi",
    "dysor": "dysa",
    "dysorna": "dysa",
    "dysornas": "dysa",
    "dysors": "dysa",
    "dyspepsien": "dyspepsi",
    "dyspepsiens": "dyspepsi",
    "dyspepsier": "dyspepsi",
    "dyspepsierna": "dyspepsi",
    "dyspepsiernas": "dyspepsi",
    "dyspepsiers": "dyspepsi",
    "dyspepsin": "dyspepsi",
    "dyspepsins": "dyspepsi",
    "dyspepsis": "dyspepsi",
    "dysprosiet": "dysprosium",
    "dysprosiets": "dysprosium",
    "dysprosiumet": "dysprosium",
    "dysprosiumets": "dysprosium",
    "dysprosiums": "dysprosium",
    "dysterheten": "dysterhet",
    "dysterhetens": "dysterhet",
    "dysterheter": "dysterhet",
    "dysterheterna": "dysterhet",
    "dysterheternas": "dysterhet",
    "dysterheters": "dysterhet",
    "dysterhets": "dysterhet",
    "dysterkvistar": "dysterkvist",
    "dysterkvistarna": "dysterkvist",
    "dysterkvistarnas": "dysterkvist",
    "dysterkvistars": "dysterkvist",
    "dysterkvisten": "dysterkvist",
    "dysterkvistens": "dysterkvist",
    "dysterkvists": "dysterkvist",
    "dysters": "dyster",
    "dystert": "dyster",
    "dysterts": "dyster",
    "dystopien": "dystopi",
    "dystopiens": "dystopi",
    "dystopier": "dystopi",
    "dystopierna": "dystopi",
    "dystopiernas": "dystopi",
    "dystopiers": "dystopi",
    "dystopin": "dystopi",
    "dystopins": "dystopi",
    "dystopis": "dystopi",
    "dystra": "dyster",
    "dystrare": "dyster",
    "dystrares": "dyster",
    "dystras": "dyster",
    "dystrast": "dyster",
    "dystraste": "dyster",
    "dystrastes": "dyster",
    "dystrasts": "dyster",
    "dystre": "dyster",
    "dystres": "dyster",
    "dystrofa": "dystrof",
    "dystrofare": "dystrof",
    "dystrofares": "dystrof",
    "dystrofas": "dystrof",
    "dystrofast": "dystrof",
    "dystrofaste": "dystrof",
    "dystrofastes": "dystrof",
    "dystrofasts": "dystrof",
    "dystrofe": "dystrof",
    "dystrofes": "dystrof",
    "dystrofien": "dystrofi",
    "dystrofiens": "dystrofi",
    "dystrofier": "dystrofi",
    "dystrofierna": "dystrofi",
    "dystrofiernas": "dystrofi",
    "dystrofiers": "dystrofi",
    "dystrofin": "dystrofi",
    "dystrofins": "dystrofi",
    "dystrofis": "dystrofi",
    "dystrofs": "dystrof",
    "dystroft": "dystrof",
    "dystrofts": "dystrof",
    "dyvelsträcken": "dyvelsträck",
    "dyvelsträckens": "dyvelsträck",
    "dyvelsträcks": "dyvelsträck",
    "dyvik": "dyvika",
    "dyvikan": "dyvika",
    "dyvikans": "dyvika",
    "dyvikar": "dyvikare",
    "dyvikaren": "dyvikare",
    "dyvikarens": "dyvikare",
    "dyvikares": "dyvikare",
    "dyvikarna": "dyvikare",
    "dyvikarnas": "dyvikare",
    "dyvikars": "dyvik",
    "dyvikas": "dyvika",
    "dyvike": "dyvika",
    "dyviken": "dyvik",
    "dyvikens": "dyvik",
    "dyvikor": "dyvika",
    "dyvikorna": "dyvika",
    "dyvikornas": "dyvika",
    "dyvikors": "dyvika",
    "dyviks": "dyvika",
    "dyvåta": "dyvåt",
    "dyvåtare": "dyvåt",
    "dyvåtares": "dyvåt",
    "dyvåtas": "dyvåt",
    "dyvåtast": "dyvåt",
    "dyvåtaste": "dyvåt",
    "dyvåtastes": "dyvåt",
    "dyvåtasts": "dyvåt",
    "dyvåte": "dyvåt",
    "dyvåtes": "dyvåt",
    "dyvåts": "dyvåt",
    "dyvått": "dyvåt",
    "dyvåtts": "dyvåt",
    "däck": "däcka",
    "däckad": "däcka",
    "däckade": "däckad",
    "däckades": "däckad",
    "däckads": "däckad",
    "däckande": "däcka",
    "däckanden": "däckande",
    "däckandena": "däckande",
    "däckandenas": "däckande",
    "däckandens": "däckande",
    "däckandes": "däckande",
    "däckandet": "däckande",
    "däckandets": "däckande",
    "däckar": "däcka",
    "däckas": "däcka",
    "däckat": "däckad",
    "däckats": "däckad",
    "däckavtagningen": "däckavtagning",
    "däckavtagningens": "däckavtagning",
    "däckavtagnings": "däckavtagning",
    "däckbytarhelgen": "däckbytarhelg",
    "däckbytarhelgens": "däckbytarhelg",
    "däckbytarhelger": "däckbytarhelg",
    "däckbytarhelgerna": "däckbytarhelg",
    "däckbytarhelgernas": "däckbytarhelg",
    "däckbytarhelgers": "däckbytarhelg",
    "däckbytarhelgs": "däckbytarhelg",
    "däckbyten": "däckbyte",
    "däckbytena": "däckbyte",
    "däckbytenas": "däckbyte",
    "däckbytens": "däckbyte",
    "däckbytes": "däckbyte",
    "däckbytet": "däckbyte",
    "däckbytets": "däckbyte",
    "däckdimensionen": "däckdimension",
    "däckdimensionens": "däckdimension",
    "däckdimensioner": "däckdimension",
    "däckdimensionerna": "däckdimension",
    "däckdimensionernas": "däckdimension",
    "däckdimensioners": "däckdimension",
    "däckdimensions": "däckdimension",
    "däckeln": "däckel",
    "däckelns": "däckel",
    "däckels": "däckel",
    "däcken": "däck",
    "däckens": "däck",
    "däckern": "däcker",
    "däckerna": "däcker",
    "däckernas": "däcker",
    "däckerns": "däcker",
    "däckers": "däcker",
    "däcket": "däck",
    "däckets": "däck",
    "däckglansen": "däckglans",
    "däckglansens": "däckglans",
    "däckhållar": "däckhållare",
    "däckhållaren": "däckhållare",
    "däckhållarens": "däckhållare",
    "däckhållares": "däckhållare",
    "däckhållarna": "däckhållare",
    "däckhållarnas": "däckhållare",
    "däckjärnen": "däckjärn",
    "däckjärnens": "däckjärn",
    "däckjärnet": "däckjärn",
    "däckjärnets": "däckjärn",
    "däckjärns": "däckjärn",
    "däcklar": "däckel",
    "däcklarna": "däckel",
    "däcklarnas": "däckel",
    "däcklars": "däckel",
    "däckmärkningar": "däckmärkning",
    "däckmärkningarna": "däckmärkning",
    "däckmärkningarnas": "däckmärkning",
    "däckmärkningars": "däckmärkning",
    "däckmärkningen": "däckmärkning",
    "däckmärkningens": "däckmärkning",
    "däckmärknings": "däckmärkning",
    "däckmärkningsklämman": "däckmärkningsklämma",
    "däckmärkningsklämmans": "däckmärkningsklämma",
    "däckmärkningsklämmas": "däckmärkningsklämma",
    "däckmärkningsklämme": "däckmärkningsklämma",
    "däckmärkningsklämmor": "däckmärkningsklämma",
    "däckmärkningsklämmorna": "däckmärkningsklämma",
    "däckmärkningsklämmornas": "däckmärkningsklämma",
    "däckmärkningsklämmors": "däckmärkningsklämma",
    "däckpås": "däckpåse",
    "däckpåsar": "däckpåse",
    "däckpåsarna": "däckpåse",
    "däckpåsarnas": "däckpåse",
    "däckpåsars": "däckpåse",
    "däckpåsen": "däckpåse",
    "däckpåsens": "däckpåse",
    "däckpåses": "däckpåse",
    "däckren": "däcker",
    "däckrens": "däcker",
    "däckret": "däcker",
    "däckrets": "däcker",
    "däcks": "däck",
    "däckslasten": "däckslast",
    "däckslastens": "däckslast",
    "däckslaster": "däckslast",
    "däckslasterna": "däckslast",
    "däckslasternas": "däckslast",
    "däckslasters": "däckslast",
    "däckslasts": "däckslast",
    "däcksmanskapen": "däcksmanskap",
    "däcksmanskapens": "däcksmanskap",
    "däcksmanskapet": "däcksmanskap",
    "däcksmanskapets": "däcksmanskap",
    "däcksmanskaps": "däcksmanskap",
    "däckspassagerar": "däckspassagerare",
    "däckspassageraren": "däckspassagerare",
    "däckspassagerarens": "däckspassagerare",
    "däckspassagerares": "däckspassagerare",
    "däckspassagerarna": "däckspassagerare",
    "däckspassagerarnas": "däckspassagerare",
    "däcksplank": "däcksplanka",
    "däcksplankan": "däcksplanka",
    "däcksplankans": "däcksplanka",
    "däcksplankas": "däcksplanka",
    "däcksplanke": "däcksplanka",
    "däcksplankor": "däcksplanka",
    "däcksplankorna": "däcksplanka",
    "däcksplankornas": "däcksplanka",
    "däcksplankors": "däcksplanka",
    "däcksplanks": "däcksplanka",
    "däckventilen": "däckventil",
    "däckventilens": "däckventil",
    "däckventiler": "däckventil",
    "däckventilerna": "däckventil",
    "däckventilernas": "däckventil",
    "däckventilers": "däckventil",
    "däckventils": "däckventil",
    "däckverkstaden": "däckverkstad",
    "däckverkstadens": "däckverkstad",
    "däckverkstads": "däckverkstad",
    "däckverkstan": "däckverkstad",
    "däckverkstans": "däckverkstad",
    "däckverkstäder": "däckverkstad",
    "däckverkstäderna": "däckverkstad",
    "däckverkstädernas": "däckverkstad",
    "däckverkstäders": "däckverkstad",
    "dägg": "dägga",
    "däggad": "dägga",
    "däggade": "dägga",
    "däggades": "dägga",
    "däggads": "dägga",
    "däggande": "dägga",
    "dägganden": "däggande",
    "däggandena": "däggande",
    "däggandenas": "däggande",
    "däggandens": "däggande",
    "däggandes": "däggande",
    "däggandet": "däggande",
    "däggandets": "däggande",
    "däggar": "dägga",
    "däggas": "dägga",
    "däggat": "dägga",
    "däggats": "dägga",
    "däggdjuren": "däggdjur",
    "däggdjurens": "däggdjur",
    "däggdjuret": "däggdjur",
    "däggdjurets": "däggdjur",
    "däggdjurs": "däggdjur",
    "däggdjursgruppen": "däggdjursgrupp",
    "däggdjursgruppens": "däggdjursgrupp",
    "däggdjursgrupper": "däggdjursgrupp",
    "däggdjursgrupperna": "däggdjursgrupp",
    "däggdjursgruppernas": "däggdjursgrupp",
    "däggdjursgruppers": "däggdjursgrupp",
    "däggdjursgrupps": "däggdjursgrupp",
    "däggdjurstanden": "däggdjurstand",
    "däggdjurstandens": "däggdjurstand",
    "däggdjurstands": "däggdjurstand",
    "däggdjurstypen": "däggdjurstyp",
    "däggdjurstypens": "däggdjurstyp",
    "däggdjurstyper": "däggdjurstyp",
    "däggdjurstyperna": "däggdjurstyp",
    "däggdjurstypernas": "däggdjurstyp",
    "däggdjurstypers": "däggdjurstyp",
    "däggdjurstyps": "däggdjurstyp",
    "däggdjurständer": "däggdjurstand",
    "däggdjurständerna": "däggdjurstand",
    "däggdjurständernas": "däggdjurstand",
    "däggdjurständers": "däggdjurstand",
    "däggdjursungar": "däggdjursunge",
    "däggdjursungarna": "däggdjursunge",
    "däggdjursungarnas": "däggdjursunge",
    "däggdjursungars": "däggdjursunge",
    "däggdjursungen": "däggdjursunge",
    "däggdjursungens": "däggdjursunge",
    "däggdjursunges": "däggdjursunge",
    "dälden": "däld",
    "däldens": "däld",
    "dälder": "däld",
    "dälderna": "däld",
    "däldernas": "däld",
    "dälders": "däld",
    "dälds": "däld",
    "däm": "dämma",
    "dämd": "dämma",
    "dämda": "dämma",
    "dämdas": "dämma",
    "dämde": "dämma",
    "dämdes": "dämma",
    "dämds": "dämma",
    "dämmande": "dämma",
    "dämmanden": "dämmande",
    "dämmandena": "dämmande",
    "dämmandenas": "dämmande",
    "dämmandens": "dämmande",
    "dämmandes": "dämmande",
    "dämmandet": "dämmande",
    "dämmandets": "dämmande",
    "dämmar": "dämmare",
    "dämmaren": "dämmare",
    "dämmarens": "dämmare",
    "dämmares": "dämmare",
    "dämmarna": "dämmare",
    "dämmarnas": "dämmare",
    "dämmas": "dämma",
    "dämmen": "dämme",
    "dämmena": "dämme",
    "dämmenas": "dämme",
    "dämmens": "dämme",
    "dämmer": "dämma",
    "dämmes": "dämme",
    "dämmet": "dämme",
    "dämmets": "dämme",
    "dämningar": "dämning",
    "dämningarna": "dämning",
    "dämningarnas": "dämning",
    "dämningars": "dämning",
    "dämningen": "dämning",
    "dämningens": "dämning",
    "dämnings": "dämning",
    "dämp": "dämpa",
    "dämpad": "dämpa",
    "dämpade": "dämpad",
    "dämpades": "dämpad",
    "dämpads": "dämpad",
    "dämpande": "dämpa",
    "dämpanden": "dämpande",
    "dämpandena": "dämpande",
    "dämpandenas": "dämpande",
    "dämpandens": "dämpande",
    "dämpandes": "dämpande",
    "dämpandet": "dämpande",
    "dämpandets": "dämpande",
    "dämpar": "dämpare",
    "dämparen": "dämpare",
    "dämparens": "dämpare",
    "dämpares": "dämpare",
    "dämparna": "dämpare",
    "dämparnas": "dämpare",
    "dämpas": "dämpa",
    "dämpat": "dämpad",
    "dämpats": "dämpad",
    "dämpboxar": "dämpbox",
    "dämpboxarna": "dämpbox",
    "dämpboxarnas": "dämpbox",
    "dämpboxars": "dämpbox",
    "dämpboxen": "dämpbox",
    "dämpboxens": "dämpbox",
    "dämpningar": "dämpning",
    "dämpningarna": "dämpning",
    "dämpningarnas": "dämpning",
    "dämpningars": "dämpning",
    "dämpningen": "dämpning",
    "dämpningens": "dämpning",
    "dämpnings": "dämpning",
    "däms": "dämma",
    "dämt": "dämma",
    "dämts": "dämma",
    "däng": "dänga",
    "dängande": "dänga",
    "dänganden": "dängande",
    "dängandena": "dängande",
    "dängandenas": "dängande",
    "dängandens": "dängande",
    "dängandes": "dängande",
    "dängandet": "dängande",
    "dängandets": "dängande",
    "dängas": "dänga",
    "dängd": "dänga",
    "dängda": "dänga",
    "dängdas": "dänga",
    "dängde": "dänga",
    "dängdes": "dänga",
    "dängds": "dänga",
    "dänger": "dänga",
    "dänges": "dänga",
    "dänget": "däng",
    "dängets": "däng",
    "dängs": "dänga",
    "dängt": "dänga",
    "dängts": "dänga",
    "dänk": "dänka",
    "dänkande": "dänka",
    "dänkanden": "dänkande",
    "dänkandena": "dänkande",
    "dänkandenas": "dänkande",
    "dänkandens": "dänkande",
    "dänkandes": "dänkande",
    "dänkandet": "dänkande",
    "dänkandets": "dänkande",
    "dänkas": "dänka",
    "dänker": "dänka",
    "dänkes": "dänka",
    "dänks": "dänka",
    "dänkt": "dänka",
    "dänkta": "dänka",
    "dänktas": "dänka",
    "dänkte": "dänka",
    "dänktes": "dänka",
    "dänkts": "dänka",
    "dästa": "däst",
    "dästare": "däst",
    "dästares": "däst",
    "dästas": "däst",
    "dästast": "däst",
    "dästaste": "däst",
    "dästastes": "däst",
    "dästasts": "däst",
    "däste": "däst",
    "dästes": "däst",
    "dästheten": "dästhet",
    "dästhetens": "dästhet",
    "dästhets": "dästhet",
    "dästs": "däst",
    "dävenheten": "dävenhet",
    "dävenhetens": "dävenhet",
    "dävenhets": "dävenhet",
    "dävens": "däven",
    "dävertar": "dävert",
    "dävertarna": "dävert",
    "dävertarnas": "dävert",
    "dävertars": "dävert",
    "däverten": "dävert",
    "dävertens": "dävert",
    "däverts": "dävert",
    "dävet": "däven",
    "dävets": "däven",
    "dävn": "dävna",
    "dävna": "däven",
    "dävnad": "dävna",
    "dävnade": "dävna",
    "dävnades": "dävna",
    "dävnads": "dävna",
    "dävnande": "dävna",
    "dävnanden": "dävnande",
    "dävnandena": "dävnande",
    "dävnandenas": "dävnande",
    "dävnandens": "dävnande",
    "dävnandes": "dävnande",
    "dävnandet": "dävnande",
    "dävnandets": "dävnande",
    "dävnar": "dävna",
    "dävnare": "däven",
    "dävnares": "däven",
    "dävnas": "dävna",
    "dävnast": "däven",
    "dävnaste": "däven",
    "dävnastes": "däven",
    "dävnasts": "däven",
    "dävnat": "dävna",
    "dävnats": "dävna",
    "dävne": "däven",
    "dävnes": "däven",
    "däxeln": "däxel",
    "däxelns": "däxel",
    "däxels": "däxel",
    "däxlar": "däxel",
    "däxlarna": "däxel",
    "däxlarnas": "däxel",
    "däxlars": "däxel",
    "dåden": "dåd",
    "dådens": "dåd",
    "dådet": "dåd",
    "dådets": "dåd",
    "dådkraften": "dådkraft",
    "dådkraftens": "dådkraft",
    "dådkrafts": "dådkraft",
    "dådrafröen": "dådrafrö",
    "dådrafröens": "dådrafrö",
    "dådrafröer": "dådrafrö",
    "dådrafröerna": "dådrafrö",
    "dådrafröernas": "dådrafrö",
    "dådrafröers": "dådrafrö",
    "dådrafröet": "dådrafrö",
    "dådrafröets": "dådrafrö",
    "dådrafrön": "dådrafrö",
    "dådrafröna": "dådrafrö",
    "dådrafrönas": "dådrafrö",
    "dådrafröns": "dådrafrö",
    "dådrafrös": "dådrafrö",
    "dådrafröt": "dådrafrö",
    "dådrafröts": "dådrafrö",
    "dådran": "dådra",
    "dådrans": "dådra",
    "dådras": "dådra",
    "dådre": "dådra",
    "dådror": "dådra",
    "dådrorna": "dådra",
    "dådrornas": "dådra",
    "dådrors": "dådra",
    "dåds": "dåd",
    "dåliga": "dålig",
    "dåligare": "dålig",
    "dåligares": "dålig",
    "dåligas": "dålig",
    "dåligast": "dålig",
    "dåligaste": "dålig",
    "dåligastes": "dålig",
    "dåligasts": "dålig",
    "dålige": "dålig",
    "dåliges": "dålig",
    "dåligheten": "dålighet",
    "dålighetens": "dålighet",
    "dåligheter": "dålighet",
    "dåligheterna": "dåligheter",
    "dåligheternas": "dåligheter",
    "dåligheters": "dåligheter",
    "dålighets": "dåligheter",
    "dåligs": "dålig",
    "dåligt": "dålig",
    "dåligts": "dålig",
    "dån": "dåna",
    "dånad": "dåna",
    "dånade": "dåna",
    "dånades": "dåna",
    "dånads": "dåna",
    "dånande": "dåna",
    "dånanden": "dånande",
    "dånandena": "dånande",
    "dånandenas": "dånande",
    "dånandens": "dånande",
    "dånandes": "dånande",
    "dånandet": "dånande",
    "dånandets": "dånande",
    "dånar": "dåna",
    "dånas": "dåna",
    "dånat": "dåna",
    "dånats": "dåna",
    "dånen": "dån",
    "dånens": "dån",
    "dånet": "dån",
    "dånets": "dån",
    "dåns": "dån",
    "dår": "dåre",
    "dårad": "dåra",
    "dårade": "dåra",
    "dårades": "dåra",
    "dårads": "dåra",
    "dåraktiga": "dåraktig",
    "dåraktigare": "dåraktig",
    "dåraktigares": "dåraktig",
    "dåraktigas": "dåraktig",
    "dåraktigast": "dåraktig",
    "dåraktigaste": "dåraktig",
    "dåraktigastes": "dåraktig",
    "dåraktigasts": "dåraktig",
    "dåraktige": "dåraktig",
    "dåraktiges": "dåraktig",
    "dåraktigheten": "dåraktighet",
    "dåraktighetens": "dåraktighet",
    "dåraktigheter": "dåraktighet",
    "dåraktigheterna": "dåraktighet",
    "dåraktigheternas": "dåraktighet",
    "dåraktigheters": "dåraktighet",
    "dåraktighets": "dåraktighet",
    "dåraktigs": "dåraktig",
    "dåraktigt": "dåraktig",
    "dåraktigts": "dåraktig",
    "dårande": "dåra",
    "dåranden": "dårande",
    "dårandena": "dårande",
    "dårandenas": "dårande",
    "dårandens": "dårande",
    "dårandes": "dårande",
    "dårandet": "dårande",
    "dårandets": "dårande",
    "dårar": "dåre",
    "dårarna": "dåre",
    "dårarnas": "dåre",
    "dårars": "dåre",
    "dåras": "dåra",
    "dårat": "dåra",
    "dårats": "dåra",
    "dåren": "dåre",
    "dårens": "dåre",
    "dåres": "dåre",
    "dårfinkar": "dårfink",
    "dårfinkarna": "dårfink",
    "dårfinkarnas": "dårfink",
    "dårfinkars": "dårfink",
    "dårfinken": "dårfink",
    "dårfinkens": "dårfink",
    "dårfinks": "dårfink",
    "dårhusen": "dårhus",
    "dårhusens": "dårhus",
    "dårhuset": "dårhus",
    "dårhusets": "dårhus",
    "dårhusmässiga": "dårhusmässig",
    "dårhusmässigare": "dårhusmässig",
    "dårhusmässigares": "dårhusmässig",
    "dårhusmässigas": "dårhusmässig",
    "dårhusmässigast": "dårhusmässig",
    "dårhusmässigaste": "dårhusmässig",
    "dårhusmässigastes": "dårhusmässig",
    "dårhusmässigasts": "dårhusmässig",
    "dårhusmässige": "dårhusmässig",
    "dårhusmässiges": "dårhusmässig",
    "dårhusmässigs": "dårhusmässig",
    "dårhusmässigt": "dårhusmässig",
    "dårhusmässigts": "dårhusmässig",
    "dårs": "dåre",
    "dårskapen": "dårskap",
    "dårskapens": "dårskap",
    "dårskaper": "dårskap",
    "dårskaperna": "dårskap",
    "dårskapernas": "dårskap",
    "dårskapers": "dårskap",
    "dårskaps": "dårskap",
    "dås": "dåsa",
    "dåsade": "dåsa",
    "dåsades": "dåsa",
    "dåsande": "dåsa",
    "dåsanden": "dåsande",
    "dåsandena": "dåsande",
    "dåsandenas": "dåsande",
    "dåsandens": "dåsande",
    "dåsandes": "dåsande",
    "dåsandet": "dåsande",
    "dåsandets": "dåsande",
    "dåsar": "dåsa",
    "dåsas": "dåsa",
    "dåsat": "dåsa",
    "dåsats": "dåsa",
    "dåset": "dås",
    "dåsets": "dås",
    "dåsiga": "dåsig",
    "dåsigare": "dåsig",
    "dåsigares": "dåsig",
    "dåsigas": "dåsig",
    "dåsigast": "dåsig",
    "dåsigaste": "dåsig",
    "dåsigastes": "dåsig",
    "dåsigasts": "dåsig",
    "dåsige": "dåsig",
    "dåsiges": "dåsig",
    "dåsigheten": "dåsighet",
    "dåsighetens": "dåsighet",
    "dåsigheter": "dåsighet",
    "dåsigheterna": "dåsighet",
    "dåsigheternas": "dåsighet",
    "dåsigheters": "dåsighet",
    "dåsighets": "dåsighet",
    "dåsigs": "dåsig",
    "dåsigt": "dåsig",
    "dåsigts": "dåsig",
    "dåtiden": "dåtid",
    "dåtidens": "dåtid",
    "dåtids": "dåtid",
    "détenten": "détente",
    "détentens": "détente",
    "détentes": "détente",
    "döbattangen": "döbattang",
    "döbattangens": "döbattang",
    "döbattanger": "döbattang",
    "döbattangerna": "döbattang",
    "döbattangernas": "döbattang",
    "döbattangers": "döbattang",
    "döbattangs": "döbattang",
    "döbleka": "döblek",
    "döblekare": "döblek",
    "döblekares": "döblek",
    "döblekas": "döblek",
    "döblekast": "döblek",
    "döblekaste": "döblek",
    "döblekastes": "döblek",
    "döblekasts": "döblek",
    "döbleke": "döblek",
    "döblekes": "döblek",
    "döblekheten": "döblekhet",
    "döblekhetens": "döblekhet",
    "döblekhets": "döblekhet",
    "döbleks": "döblek",
    "döblekt": "döblek",
    "döblekts": "döblek",
    "död": "döda",
    "döda": "död",
    "dödad": "döda",
    "dödade": "döda",
    "dödades": "döda",
    "dödads": "döda",
    "dödande": "döda",
    "dödandes": "dödande",
    "dödandet": "dödande",
    "dödandets": "dödande",
    "dödar": "döda",
    "dödare": "död",
    "dödares": "död",
    "dödarna": "död",
    "dödarnas": "död",
    "dödars": "död",
    "dödas": "döda",
    "dödast": "död",
    "dödaste": "död",
    "dödastes": "död",
    "dödasts": "död",
    "dödat": "döda",
    "dödats": "döda",
    "dödbakade": "dödbakad",
    "dödbakades": "dödbakad",
    "dödbakads": "dödbakad",
    "dödbakat": "dödbakad",
    "dödbakats": "dödbakad",
    "dödbrända": "dödbränd",
    "dödbrändare": "dödbränd",
    "dödbrändares": "dödbränd",
    "dödbrändas": "dödbränd",
    "dödbrändast": "dödbränd",
    "dödbrändaste": "dödbränd",
    "dödbrändastes": "dödbränd",
    "dödbrändasts": "dödbränd",
    "dödbrände": "dödbränd",
    "dödbrändes": "dödbränd",
    "dödbränds": "dödbränd",
    "dödbränt": "dödbränd",
    "dödbränts": "dödbränd",
    "döddansar": "döddansare",
    "döddansaren": "döddansare",
    "döddansarens": "döddansare",
    "döddansares": "döddansare",
    "döddansarna": "döddansare",
    "döddansarnas": "döddansare",
    "döde": "död",
    "döden": "död",
    "dödens": "död",
    "dödes": "död",
    "dödfulla": "dödfull",
    "dödfullare": "dödfull",
    "dödfullares": "dödfull",
    "dödfullas": "dödfull",
    "dödfullast": "dödfull",
    "dödfullaste": "dödfull",
    "dödfullastes": "dödfull",
    "dödfullasts": "dödfull",
    "dödfulle": "dödfull",
    "dödfulles": "dödfull",
    "dödfulls": "dödfull",
    "dödfullt": "dödfull",
    "dödfullts": "dödfull",
    "dödfödda": "dödfödd",
    "dödföddare": "dödfödd",
    "dödföddares": "dödfödd",
    "dödföddas": "dödfödd",
    "dödföddast": "dödfödd",
    "dödföddaste": "dödfödd",
    "dödföddastes": "dödfödd",
    "dödföddasts": "dödfödd",
    "dödfödde": "dödfödd",
    "dödföddes": "dödfödd",
    "dödfödds": "dödfödd",
    "dödförklarad": "dödförklara",
    "dödförklarade": "dödförklara",
    "dödförklarades": "dödförklara",
    "dödförklarads": "dödförklara",
    "dödförklarande": "dödförklara",
    "dödförklaranden": "dödförklarande",
    "dödförklarandena": "dödförklarande",
    "dödförklarandenas": "dödförklarande",
    "dödförklarandens": "dödförklarande",
    "dödförklarandes": "dödförklarande",
    "dödförklarandet": "dödförklarande",
    "dödförklarandets": "dödförklarande",
    "dödförklarar": "dödförklara",
    "dödförklaras": "dödförklara",
    "dödförklarat": "dödförklara",
    "dödförklarats": "dödförklara",
    "dödfött": "dödfödd",
    "dödfötts": "dödfödd",
    "dödgrävar": "dödgrävare",
    "dödgrävaren": "dödgrävare",
    "dödgrävarens": "dödgrävare",
    "dödgrävares": "dödgrävare",
    "dödgrävarna": "dödgrävare",
    "dödgrävarnas": "dödgrävare",
    "dödheten": "dödhet",
    "dödhetens": "dödhet",
    "dödhets": "dödhet",
    "dödingar": "döding",
    "dödingarna": "döding",
    "dödingarnas": "döding",
    "dödingars": "döding",
    "dödingen": "döding",
    "dödingens": "döding",
    "dödings": "döding",
    "dödisen": "dödis",
    "dödisens": "dödis",
    "dödköttet": "dödkött",
    "dödköttets": "dödkött",
    "dödkötts": "dödkött",
    "dödliga": "dödlig",
    "dödligare": "dödlig",
    "dödligares": "dödlig",
    "dödligas": "dödlig",
    "dödligast": "dödlig",
    "dödligaste": "dödlig",
    "dödligastes": "dödlig",
    "dödligasts": "dödlig",
    "dödlige": "dödlig",
    "dödliges": "dödlig",
    "dödligheten": "dödlighet",
    "dödlighetens": "dödlighet",
    "dödligheter": "dödlighet",
    "dödligheterna": "dödlighet",
    "dödligheternas": "dödlighet",
    "dödligheters": "dödlighet",
    "dödlighets": "dödlighet",
    "dödligs": "dödlig",
    "dödligt": "dödlig",
    "dödligts": "dödlig",
    "dödlägen": "dödläge",
    "dödlägena": "dödläge",
    "dödlägenas": "dödläge",
    "dödlägens": "dödläge",
    "dödläges": "dödläge",
    "dödläget": "dödläge",
    "dödlägets": "dödläge",
    "dödmansgreppen": "dödmansgrepp",
    "dödmansgreppens": "dödmansgrepp",
    "dödmansgreppet": "dödmansgrepp",
    "dödmansgreppets": "dödmansgrepp",
    "dödmansgrepps": "dödmansgrepp",
    "dödperioden": "dödperiod",
    "dödperiodens": "dödperiod",
    "dödperioder": "dödperiod",
    "dödperioderna": "dödperiod",
    "dödperiodernas": "dödperiod",
    "dödperioders": "dödperiod",
    "dödperiods": "dödperiod",
    "döds": "död",
    "dödsannonsen": "dödsannons",
    "dödsannonsens": "dödsannons",
    "dödsannonser": "dödsannons",
    "dödsannonserna": "dödsannons",
    "dödsannonsernas": "dödsannons",
    "dödsannonsers": "dödsannons",
    "dödsattesten": "dödsattest",
    "dödsattestens": "dödsattest",
    "dödsattester": "dödsattest",
    "dödsattesterna": "dödsattest",
    "dödsattesternas": "dödsattest",
    "dödsattesters": "dödsattest",
    "dödsattests": "dödsattest",
    "dödsbakterien": "dödsbakterie",
    "dödsbakteriens": "dödsbakterie",
    "dödsbakterier": "dödsbakterie",
    "dödsbakterierna": "dödsbakterie",
    "dödsbakteriernas": "dödsbakterie",
    "dödsbakteriers": "dödsbakterie",
    "dödsbakteries": "dödsbakterie",
    "dödsbevisen": "dödsbevis",
    "dödsbevisens": "dödsbevis",
    "dödsbeviset": "dödsbevis",
    "dödsbevisets": "dödsbevis",
    "dödsbleka": "dödsblek",
    "dödsblekare": "dödsblek",
    "dödsblekares": "dödsblek",
    "dödsblekas": "dödsblek",
    "dödsblekast": "dödsblek",
    "dödsblekaste": "dödsblek",
    "dödsblekastes": "dödsblek",
    "dödsblekasts": "dödsblek",
    "dödsbleke": "dödsblek",
    "dödsblekes": "dödsblek",
    "dödsblekheten": "dödsblekhet",
    "dödsblekhetens": "dödsblekhet",
    "dödsblekhets": "dödsblekhet",
    "dödsbleks": "dödsblek",
    "dödsblekt": "dödsblek",
    "dödsblekts": "dödsblek",
    "dödsboen": "dödsbo",
    "dödsboens": "dödsbo",
    "dödsboet": "dödsbo",
    "dödsboets": "dödsbo",
    "dödsbon": "dödsbo",
    "dödsbona": "dödsbo",
    "dödsbonas": "dödsbo",
    "dödsbons": "dödsbo",
    "dödsbos": "dödsbo",
    "dödsbot": "dödsbo",
    "dödsbots": "dödsbo",
    "dödsbuden": "dödsbud",
    "dödsbudens": "dödsbud",
    "dödsbudet": "dödsbud",
    "dödsbudets": "dödsbud",
    "dödsbuds": "dödsbud",
    "dödsbäddar": "dödsbädd",
    "dödsbäddarna": "dödsbädd",
    "dödsbäddarnas": "dödsbädd",
    "dödsbäddars": "dödsbädd",
    "dödsbädden": "dödsbädd",
    "dödsbäddens": "dödsbädd",
    "dödsbädds": "dödsbädd",
    "dödsdansen": "dödsdans",
    "dödsdansens": "dödsdans",
    "dödsdanser": "dödsdans",
    "dödsdanserna": "dödsdans",
    "dödsdansernas": "dödsdans",
    "dödsdansers": "dödsdans",
    "dödsdomar": "dödsdom",
    "dödsdomarna": "dödsdom",
    "dödsdomarnas": "dödsdom",
    "dödsdomars": "dödsdom",
    "dödsdomen": "dödsdom",
    "dödsdomens": "dödsdom",
    "dödsdoms": "dödsdom",
    "dödsdömda": "dödsdömd",
    "dödsdömdare": "dödsdömd",
    "dödsdömdares": "dödsdömd",
    "dödsdömdas": "dödsdömd",
    "dödsdömdast": "dödsdömd",
    "dödsdömdaste": "dödsdömd",
    "dödsdömdastes": "dödsdömd",
    "dödsdömdasts": "dödsdömd",
    "dödsdömde": "dödsdömd",
    "dödsdömdes": "dödsdömd",
    "dödsdömds": "dödsdömd",
    "dödsdömt": "dödsdömd",
    "dödsdömts": "dödsdömd",
    "dödsfallen": "dödsfall",
    "dödsfallens": "dödsfall",
    "dödsfallet": "dödsfall",
    "dödsfallets": "dödsfall",
    "dödsfalls": "dödsfall",
    "dödsfar": "dödsfara",
    "dödsfaran": "dödsfara",
    "dödsfarans": "dödsfara",
    "dödsfaras": "dödsfara",
    "dödsfare": "dödsfara",
    "dödsfaro": "dödsfara",
    "dödsfaror": "dödsfara",
    "dödsfarorna": "dödsfara",
    "dödsfarornas": "dödsfara",
    "dödsfarors": "dödsfara",
    "dödsfars": "dödsfara",
    "dödsfasen": "dödsfas",
    "dödsfasens": "dödsfas",
    "dödsfaser": "dödsfas",
    "dödsfaserna": "dödsfas",
    "dödsfasernas": "dödsfas",
    "dödsfasers": "dödsfas",
    "dödsfienden": "dödsfiende",
    "dödsfiendens": "dödsfiende",
    "dödsfiender": "dödsfiende",
    "dödsfienderna": "dödsfiende",
    "dödsfiendernas": "dödsfiende",
    "dödsfienders": "dödsfiende",
    "dödsfiendes": "dödsfiende",
    "dödsfäll": "dödsfälla",
    "dödsfällan": "dödsfälla",
    "dödsfällans": "dödsfälla",
    "dödsfällas": "dödsfälla",
    "dödsfälle": "dödsfälla",
    "dödsfällor": "dödsfälla",
    "dödsfällorna": "dödsfälla",
    "dödsfällornas": "dödsfälla",
    "dödsfällors": "dödsfälla",
    "dödsfälls": "dödsfälla",
    "dödsföraktet": "dödsförakt",
    "dödsföraktets": "dödsförakt",
    "dödsförakts": "dödsförakt",
    "dödsförbannade": "dödsförbannad",
    "dödsförbannades": "dödsförbannad",
    "dödsförbannads": "dödsförbannad",
    "dödsförbannat": "dödsförbannad",
    "dödsförbannats": "dödsförbannad",
    "dödsförskräckta": "dödsförskräckt",
    "dödsförskräcktare": "dödsförskräckt",
    "dödsförskräcktares": "dödsförskräckt",
    "dödsförskräcktas": "dödsförskräckt",
    "dödsförskräcktast": "dödsförskräckt",
    "dödsförskräcktaste": "dödsförskräckt",
    "dödsförskräcktastes": "dödsförskräckt",
    "dödsförskräcktasts": "dödsförskräckt",
    "dödsförskräckte": "dödsförskräckt",
    "dödsförskräcktes": "dödsförskräckt",
    "dödsförskräckts": "dödsförskräckt",
    "dödshjälpen": "dödshjälp",
    "dödshjälpens": "dödshjälp",
    "dödshjälps": "dödshjälp",
    "dödshjälpsdebatten": "dödshjälpsdebatt",
    "dödshjälpsdebattens": "dödshjälpsdebatt",
    "dödshjälpsdebatter": "dödshjälpsdebatt",
    "dödshjälpsdebatterna": "dödshjälpsdebatt",
    "dödshjälpsdebatternas": "dödshjälpsdebatt",
    "dödshjälpsdebatters": "dödshjälpsdebatt",
    "dödshjälpsdebatts": "dödshjälpsdebatt",
    "dödshoten": "dödshot",
    "dödshotens": "dödshot",
    "dödshotet": "dödshot",
    "dödshotets": "dödshot",
    "dödshots": "dödshot",
    "dödsjön": "dödsjö",
    "dödsjöns": "dödsjö",
    "dödsjös": "dödsjö",
    "dödskallar": "dödskalle",
    "dödskallarna": "dödskalle",
    "dödskallarnas": "dödskalle",
    "dödskallars": "dödskalle",
    "dödskallefjärilar": "dödskallefjäril",
    "dödskallefjärilarna": "dödskallefjäril",
    "dödskallefjärilarnas": "dödskallefjäril",
    "dödskallefjärilars": "dödskallefjäril",
    "dödskallefjärilen": "dödskallefjäril",
    "dödskallefjärilens": "dödskallefjäril",
    "dödskallefjäriln": "dödskallefjäril",
    "dödskallefjärilns": "dödskallefjäril",
    "dödskallefjärils": "dödskallefjäril",
    "dödskallen": "dödskalle",
    "dödskallens": "dödskalle",
    "dödskalles": "dödskalle",
    "dödskampen": "dödskamp",
    "dödskampens": "dödskamp",
    "dödskamper": "dödskamp",
    "dödskamperna": "dödskamp",
    "dödskampernas": "dödskamp",
    "dödskampers": "dödskamp",
    "dödskamps": "dödskamp",
    "dödskliniken": "dödsklinik",
    "dödsklinikens": "dödsklinik",
    "dödskliniker": "dödsklinik",
    "dödsklinikerna": "dödsklinik",
    "dödsklinikernas": "dödsklinik",
    "dödsklinikers": "dödsklinik",
    "dödskliniks": "dödsklinik",
    "dödskraschen": "dödskrasch",
    "dödskraschens": "dödskrasch",
    "dödskrascher": "dödskrasch",
    "dödskrascherna": "dödskrasch",
    "dödskraschernas": "dödskrasch",
    "dödskraschers": "dödskrasch",
    "dödskraschs": "dödskrasch",
    "dödslistan": "dödslista",
    "dödslistans": "dödslista",
    "dödslistas": "dödslista",
    "dödsliste": "dödslista",
    "dödslistor": "dödslista",
    "dödslistorna": "dödslista",
    "dödslistornas": "dödslista",
    "dödslistors": "dödslista",
    "dödslängtans": "dödslängtan",
    "dödsmasken": "dödsmask",
    "dödsmaskens": "dödsmask",
    "dödsmasker": "dödsmask",
    "dödsmaskerna": "dödsmask",
    "dödsmaskernas": "dödsmask",
    "dödsmaskers": "dödsmask",
    "dödsmasks": "dödsmask",
    "dödsmetalen": "dödsmetal",
    "dödsmetalens": "dödsmetal",
    "dödsmetallen": "dödsmetall",
    "dödsmetallens": "dödsmetall",
    "dödsmetalls": "dödsmetall",
    "dödsmetals": "dödsmetal",
    "dödsmärkta": "dödsmärkt",
    "dödsmärktare": "dödsmärkt",
    "dödsmärktares": "dödsmärkt",
    "dödsmärktas": "dödsmärkt",
    "dödsmärktast": "dödsmärkt",
    "dödsmärktaste": "dödsmärkt",
    "dödsmärktastes": "dödsmärkt",
    "dödsmärktasts": "dödsmärkt",
    "dödsmärkte": "dödsmärkt",
    "dödsmärktes": "dödsmärkt",
    "dödsmärkts": "dödsmärkt",
    "dödsoffers": "dödsoffer",
    "dödsoffren": "dödsoffer",
    "dödsoffrens": "dödsoffer",
    "dödsoffret": "dödsoffer",
    "dödsoffrets": "dödsoffer",
    "dödsolyck": "dödsolycka",
    "dödsolyckan": "dödsolycka",
    "dödsolyckans": "dödsolycka",
    "dödsolyckas": "dödsolycka",
    "dödsolycke": "dödsolycka",
    "dödsolyckor": "dödsolycka",
    "dödsolyckorna": "dödsolycka",
    "dödsolyckornas": "dödsolycka",
    "dödsolyckors": "dödsolycka",
    "dödsolycks": "dödsolycka",
    "dödsorsaken": "dödsorsak",
    "dödsorsakens": "dödsorsak",
    "dödsorsaker": "dödsorsak",
    "dödsorsakerna": "dödsorsak",
    "dödsorsakernas": "dödsorsak",
    "dödsorsakers": "dödsorsak",
    "dödsorsaks": "dödsorsak",
    "dödsorsaksregisterna": "dödsorsaksregister",
    "dödsorsaksregisternas": "dödsorsaksregister",
    "dödsorsaksregisters": "dödsorsaksregister",
    "dödsorsaksregistren": "dödsorsaksregister",
    "dödsorsaksregistrens": "dödsorsaksregister",
    "dödsorsaksregistret": "dödsorsaksregister",
    "dödsorsaksregistrets": "dödsorsaksregister",
    "dödspatrullen": "dödspatrull",
    "dödspatrullens": "dödspatrull",
    "dödspatruller": "dödspatrull",
    "dödspatrullerna": "dödspatrull",
    "dödspatrullernas": "dödspatrull",
    "dödspatrullers": "dödspatrull",
    "dödspatrulls": "dödspatrull",
    "dödsriken": "dödsrike",
    "dödsrikena": "dödsrike",
    "dödsrikenas": "dödsrike",
    "dödsrikens": "dödsrike",
    "dödsrikes": "dödsrike",
    "dödsriket": "dödsrike",
    "dödsrikets": "dödsrike",
    "dödsrun": "dödsruna",
    "dödsrunan": "dödsruna",
    "dödsrunans": "dödsruna",
    "dödsrunas": "dödsruna",
    "dödsrune": "dödsruna",
    "dödsrunor": "dödsruna",
    "dödsrunorna": "dödsruna",
    "dödsrunornas": "dödsruna",
    "dödsrunors": "dödsruna",
    "dödsruns": "dödsruna",
    "dödsryckningarna": "dödsryckningar",
    "dödsryckningarnas": "dödsryckningar",
    "dödsryckningars": "dödsryckningar",
    "dödsrycknings": "dödsryckningar",
    "dödssiffer": "dödssiffra",
    "dödssiffran": "dödssiffra",
    "dödssiffrans": "dödssiffra",
    "dödssiffras": "dödssiffra",
    "dödssiffre": "dödssiffra",
    "dödssiffror": "dödssiffra",
    "dödssiffrorna": "dödssiffra",
    "dödssiffrornas": "dödssiffra",
    "dödssiffrors": "dödssiffra",
    "dödssjuka": "dödssjuk",
    "dödssjukare": "dödssjuk",
    "dödssjukares": "dödssjuk",
    "dödssjukas": "dödssjuk",
    "dödssjukast": "dödssjuk",
    "dödssjukaste": "dödssjuk",
    "dödssjukastes": "dödssjuk",
    "dödssjukasts": "dödssjuk",
    "dödssjuke": "dödssjuk",
    "dödssjukes": "dödssjuk",
    "dödssjukheten": "dödssjukhet",
    "dödssjukhetens": "dödssjukhet",
    "dödssjukhets": "dödssjukhet",
    "dödssjuks": "dödssjuk",
    "dödssjukt": "dödssjuk",
    "dödssjukts": "dödssjuk",
    "dödsskjutningar": "dödsskjutning",
    "dödsskjutningarna": "dödsskjutning",
    "dödsskjutningarnas": "dödsskjutning",
    "dödsskjutningars": "dödsskjutning",
    "dödsskjutningen": "dödsskjutning",
    "dödsskjutningens": "dödsskjutning",
    "dödsskjutnings": "dödsskjutning",
    "dödsskotten": "dödsskott",
    "dödsskottens": "dödsskott",
    "dödsskottet": "dödsskott",
    "dödsskottets": "dödsskott",
    "dödsskotts": "dödsskott",
    "dödsskuggan": "dödsskugga",
    "dödsskuggans": "dödsskugga",
    "dödsskuggas": "dödsskugga",
    "dödsstelheten": "dödsstelhet",
    "dödsstelhetens": "dödsstelhet",
    "dödsstelheter": "dödsstelhet",
    "dödsstelheterna": "dödsstelhet",
    "dödsstelheternas": "dödsstelhet",
    "dödsstelheters": "dödsstelhet",
    "dödsstelhets": "dödsstelhet",
    "dödsstjärnan": "dödsstjärna",
    "dödsstjärnans": "dödsstjärna",
    "dödsstjärnas": "dödsstjärna",
    "dödsstjärne": "dödsstjärna",
    "dödsstjärnor": "dödsstjärna",
    "dödsstjärnorna": "dödsstjärna",
    "dödsstjärnornas": "dödsstjärna",
    "dödsstjärnors": "dödsstjärna",
    "dödsstraffen": "dödsstraff",
    "dödsstraffens": "dödsstraff",
    "dödsstraffet": "dödsstraff",
    "dödsstraffets": "dödsstraff",
    "dödsstraffs": "dödsstraff",
    "dödsstötar": "dödsstöt",
    "dödsstötarna": "dödsstöt",
    "dödsstötarnas": "dödsstöt",
    "dödsstötars": "dödsstöt",
    "dödsstöten": "dödsstöt",
    "dödsstötens": "dödsstöt",
    "dödsstöts": "dödsstöt",
    "dödssynden": "dödssynd",
    "dödssyndens": "dödssynd",
    "dödssynder": "dödssynd",
    "dödssynderna": "dödssynd",
    "dödssyndernas": "dödssynd",
    "dödssynders": "dödssynd",
    "dödssynds": "dödssynd",
    "dödstalen": "dödstal",
    "dödstalens": "dödstal",
    "dödstalet": "dödstal",
    "dödstalets": "dödstal",
    "dödstals": "dödstal",
    "dödstråkiga": "dödstråkig",
    "dödstråkigare": "dödstråkig",
    "dödstråkigares": "dödstråkig",
    "dödstråkigas": "dödstråkig",
    "dödstråkigast": "dödstråkig",
    "dödstråkigaste": "dödstråkig",
    "dödstråkigastes": "dödstråkig",
    "dödstråkigasts": "dödstråkig",
    "dödstråkige": "dödstråkig",
    "dödstråkiges": "dödstråkig",
    "dödstråkigheten": "dödstråkighet",
    "dödstråkighetens": "dödstråkighet",
    "dödstråkighets": "dödstråkighet",
    "dödstråkigs": "dödstråkig",
    "dödstråkigt": "dödstråkig",
    "dödstråkigts": "dödstråkig",
    "dödströtta": "dödstrött",
    "dödströttare": "dödstrött",
    "dödströttares": "dödstrött",
    "dödströttas": "dödstrött",
    "dödströttast": "dödstrött",
    "dödströttaste": "dödstrött",
    "dödströttastes": "dödstrött",
    "dödströttasts": "dödstrött",
    "dödströtte": "dödstrött",
    "dödströttes": "dödstrött",
    "dödströttheten": "dödströtthet",
    "dödströtthetens": "dödströtthet",
    "dödströtthets": "dödströtthet",
    "dödströtts": "dödstrött",
    "dödstysta": "dödstyst",
    "dödstystare": "dödstyst",
    "dödstystares": "dödstyst",
    "dödstystas": "dödstyst",
    "dödstystast": "dödstyst",
    "dödstystaste": "dödstyst",
    "dödstystastes": "dödstyst",
    "dödstystasts": "dödstyst",
    "dödstyste": "dödstyst",
    "dödstystes": "dödstyst",
    "dödstysts": "dödstyst",
    "dödsuren": "dödsur",
    "dödsurens": "dödsur",
    "dödsuret": "dödsur",
    "dödsurets": "dödsur",
    "dödsurs": "dödsur",
    "dödsvånd": "dödsvånda",
    "dödsvåndan": "dödsvånda",
    "dödsvåndans": "dödsvånda",
    "dödsvåndas": "dödsvånda",
    "dödsvånde": "dödsvånda",
    "dödsvåndor": "dödsvånda",
    "dödsvåndorna": "dödsvånda",
    "dödsvåndornas": "dödsvånda",
    "dödsvåndors": "dödsvånda",
    "dödsvånds": "dödsvånda",
    "dödsångesten": "dödsångest",
    "dödsångestens": "dödsångest",
    "dödsångests": "dödsångest",
    "dödtiden": "dödtid",
    "dödtidens": "dödtid",
    "dödtids": "dödtid",
    "dödvattens": "dödvatten",
    "dödvattnet": "dödvatten",
    "dödvattnets": "dödvatten",
    "dödvikten": "dödvikt",
    "dödviktens": "dödvikt",
    "dödvikts": "dödvikt",
    "döende": "dö",
    "döenden": "döende",
    "döendena": "döende",
    "döendenas": "döende",
    "döendens": "döende",
    "döendes": "döende",
    "döendet": "döende",
    "döendets": "döende",
    "döfulla": "döfull",
    "döfullare": "döfull",
    "döfullares": "döfull",
    "döfullas": "döfull",
    "döfullast": "döfull",
    "döfullaste": "döfull",
    "döfullastes": "döfull",
    "döfullasts": "döfull",
    "döfulle": "döfull",
    "döfulles": "döfull",
    "döfulls": "döfull",
    "döfullt": "döfull",
    "döfullts": "döfull",
    "döförbannade": "döförbannad",
    "döförbannades": "döförbannad",
    "döförbannads": "döförbannad",
    "döförbannat": "döförbannad",
    "döförbannats": "döförbannad",
    "döförskräckta": "döförskräckt",
    "döförskräcktare": "döförskräckt",
    "döförskräcktares": "döförskräckt",
    "döförskräcktas": "döförskräckt",
    "döförskräcktast": "döförskräckt",
    "döförskräcktaste": "döförskräckt",
    "döförskräcktastes": "döförskräckt",
    "döförskräcktasts": "döförskräckt",
    "döförskräckte": "döförskräckt",
    "döförskräcktes": "döförskräckt",
    "döförskräckts": "döförskräckt",
    "dög": "duga",
    "döge": "duga",
    "döglingar": "dögling",
    "döglingarna": "dögling",
    "döglingarnas": "dögling",
    "döglingars": "dögling",
    "döglingen": "dögling",
    "döglingens": "dögling",
    "döglings": "dögling",
    "döingar": "döing",
    "döingarna": "döing",
    "döingarnas": "döing",
    "döingars": "döing",
    "döingen": "döing",
    "döingens": "döing",
    "döings": "döing",
    "dök": "dyka",
    "döke": "dyka",
    "dökes": "dyka",
    "döks": "dyka",
    "dölj": "dölja",
    "döljande": "dölja",
    "döljanden": "döljande",
    "döljandena": "döljande",
    "döljandenas": "döljande",
    "döljandens": "döljande",
    "döljandes": "döljande",
    "döljandet": "döljande",
    "döljandets": "döljande",
    "döljas": "dölja",
    "döljer": "dölja",
    "döljes": "dölja",
    "döljs": "dölja",
    "döm": "döma",
    "dömande": "döma",
    "dömanden": "dömande",
    "dömandena": "dömande",
    "dömandenas": "dömande",
    "dömandens": "dömande",
    "dömandes": "dömande",
    "dömandet": "dömande",
    "dömandets": "dömande",
    "dömas": "döma",
    "dömd": "döma",
    "dömda": "döma",
    "dömdas": "döma",
    "dömde": "döma",
    "dömdes": "döma",
    "dömds": "döma",
    "dömer": "döma",
    "döms": "döma",
    "dömt": "döma",
    "dömts": "döma",
    "dönade": "döna",
    "dönades": "döna",
    "dönande": "döna",
    "dönanden": "dönande",
    "dönandena": "dönande",
    "dönandenas": "dönande",
    "dönandens": "dönande",
    "dönandes": "dönande",
    "dönandet": "dönande",
    "dönandets": "dönande",
    "dönar": "döna",
    "dönas": "döna",
    "dönat": "döna",
    "dönats": "döna",
    "dönet": "dön",
    "dönets": "dön",
    "döns": "dön",
    "döp": "döpa",
    "döpande": "döpa",
    "döpanden": "döpande",
    "döpandena": "döpande",
    "döpandenas": "döpande",
    "döpandens": "döpande",
    "döpandes": "döpande",
    "döpandet": "döpande",
    "döpandets": "döpande",
    "döpas": "döpa",
    "döpelsen": "döpelse",
    "döpelsens": "döpelse",
    "döpelses": "döpelse",
    "döper": "döpa",
    "döpes": "döpa",
    "döps": "döpa",
    "döpt": "döpa",
    "döpta": "döpa",
    "döptas": "döpa",
    "döpte": "döpa",
    "döptes": "döpa",
    "döpts": "döpa",
    "dör": "dö",
    "dörj": "dörja",
    "dörjad": "dörja",
    "dörjade": "dörja",
    "dörjades": "dörja",
    "dörjads": "dörja",
    "dörjande": "dörja",
    "dörjanden": "dörjande",
    "dörjandena": "dörjande",
    "dörjandenas": "dörjande",
    "dörjandens": "dörjande",
    "dörjandes": "dörjande",
    "dörjandet": "dörjande",
    "dörjandets": "dörjande",
    "dörjar": "dörja",
    "dörjarna": "dörj",
    "dörjarnas": "dörj",
    "dörjars": "dörj",
    "dörjas": "dörja",
    "dörjat": "dörja",
    "dörjats": "dörja",
    "dörjen": "dörj",
    "dörjens": "dörj",
    "dörjs": "dörj",
    "dörrar": "dörr",
    "dörrarna": "dörr",
    "dörrarnas": "dörr",
    "dörrars": "dörr",
    "dörrbladen": "dörrblad",
    "dörrbladens": "dörrblad",
    "dörrbladet": "dörrblad",
    "dörrbladets": "dörrblad",
    "dörrblads": "dörrblad",
    "dörren": "dörr",
    "dörrens": "dörr",
    "dörrfärgen": "dörrfärg",
    "dörrfärgens": "dörrfärg",
    "dörrfärger": "dörrfärg",
    "dörrfärgerna": "dörrfärg",
    "dörrfärgernas": "dörrfärg",
    "dörrfärgers": "dörrfärg",
    "dörrfärgs": "dörrfärg",
    "dörrförhängen": "dörrförhänge",
    "dörrförhängena": "dörrförhänge",
    "dörrförhängenas": "dörrförhänge",
    "dörrförhängens": "dörrförhänge",
    "dörrförhänges": "dörrförhänge",
    "dörrförhänget": "dörrförhänge",
    "dörrförhängets": "dörrförhänge",
    "dörrförsäljar": "dörrförsäljare",
    "dörrförsäljaren": "dörrförsäljare",
    "dörrförsäljarens": "dörrförsäljare",
    "dörrförsäljares": "dörrförsäljare",
    "dörrförsäljarna": "dörrförsäljare",
    "dörrförsäljarnas": "dörrförsäljare",
    "dörrhandtagen": "dörrhandtag",
    "dörrhandtagens": "dörrhandtag",
    "dörrhandtaget": "dörrhandtag",
    "dörrhandtagets": "dörrhandtag",
    "dörrhandtags": "dörrhandtag",
    "dörrkarmar": "dörrkarm",
    "dörrkarmarna": "dörrkarm",
    "dörrkarmarnas": "dörrkarm",
    "dörrkarmars": "dörrkarm",
    "dörrkarmen": "dörrkarm",
    "dörrkarmens": "dörrkarm",
    "dörrkarms": "dörrkarm",
    "dörrkedjan": "dörrkedja",
    "dörrkedjans": "dörrkedja",
    "dörrkedjas": "dörrkedja",
    "dörrkedje": "dörrkedja",
    "dörrkedjor": "dörrkedja",
    "dörrkedjorna": "dörrkedja",
    "dörrkedjornas": "dörrkedja",
    "dörrkedjors": "dörrkedja",
    "dörrklock": "dörrklocka",
    "dörrklockan": "dörrklocka",
    "dörrklockans": "dörrklocka",
    "dörrklockas": "dörrklocka",
    "dörrklocke": "dörrklocka",
    "dörrklockor": "dörrklocka",
    "dörrklockorna": "dörrklocka",
    "dörrklockornas": "dörrklocka",
    "dörrklockors": "dörrklocka",
    "dörrklocks": "dörrklocka",
    "dörrknackar": "dörrknackare",
    "dörrknackaren": "dörrknackare",
    "dörrknackarens": "dörrknackare",
    "dörrknackares": "dörrknackare",
    "dörrknackarna": "dörrknackare",
    "dörrknackarnas": "dörrknackare",
    "dörrknackningen": "dörrknackning",
    "dörrknackningens": "dörrknackning",
    "dörrknacknings": "dörrknackning",
    "dörrknackningskampanjen": "dörrknackningskampanj",
    "dörrknackningskampanjens": "dörrknackningskampanj",
    "dörrknackningskampanjer": "dörrknackningskampanj",
    "dörrknackningskampanjerna": "dörrknackningskampanj",
    "dörrknackningskampanjernas": "dörrknackningskampanj",
    "dörrknackningskampanjers": "dörrknackningskampanj",
    "dörrknackningskampanjs": "dörrknackningskampanj",
    "dörrkransar": "dörrkrans",
    "dörrkransarna": "dörrkrans",
    "dörrkransarnas": "dörrkrans",
    "dörrkransars": "dörrkrans",
    "dörrkransen": "dörrkrans",
    "dörrkransens": "dörrkrans",
    "dörrmatt": "dörrmatta",
    "dörrmattan": "dörrmatta",
    "dörrmattans": "dörrmatta",
    "dörrmattas": "dörrmatta",
    "dörrmatte": "dörrmatta",
    "dörrmattor": "dörrmatta",
    "dörrmattorna": "dörrmatta",
    "dörrmattornas": "dörrmatta",
    "dörrmattors": "dörrmatta",
    "dörrmatts": "dörrmatta",
    "dörrposten": "dörrpost",
    "dörrpostens": "dörrpost",
    "dörrposter": "dörrpost",
    "dörrposterna": "dörrpost",
    "dörrposternas": "dörrpost",
    "dörrposters": "dörrpost",
    "dörrposts": "dörrpost",
    "dörrs": "dörr",
    "dörrspegeln": "dörrspegel",
    "dörrspegelns": "dörrspegel",
    "dörrspegels": "dörrspegel",
    "dörrspeglar": "dörrspegel",
    "dörrspeglarna": "dörrspegel",
    "dörrspeglarnas": "dörrspegel",
    "dörrspeglars": "dörrspegel",
    "dörrstolp": "dörrstolpe",
    "dörrstolpar": "dörrstolpe",
    "dörrstolparna": "dörrstolpe",
    "dörrstolparnas": "dörrstolpe",
    "dörrstolpars": "dörrstolpe",
    "dörrstolpen": "dörrstolpe",
    "dörrstolpens": "dörrstolpe",
    "dörrstolpes": "dörrstolpe",
    "dörrstolps": "dörrstolpe",
    "dörrstängar": "dörrstängare",
    "dörrstängaren": "dörrstängare",
    "dörrstängarens": "dörrstängare",
    "dörrstängares": "dörrstängare",
    "dörrstängarna": "dörrstängare",
    "dörrstängarnas": "dörrstängare",
    "dörrvakten": "dörrvakt",
    "dörrvaktens": "dörrvakt",
    "dörrvakter": "dörrvakt",
    "dörrvakterna": "dörrvakt",
    "dörrvakternas": "dörrvakt",
    "dörrvakters": "dörrvakt",
    "dörrvakts": "dörrvakt",
    "dörröppnar": "dörröppnare",
    "dörröppnaren": "dörröppnare",
    "dörröppnarens": "dörröppnare",
    "dörröppnares": "dörröppnare",
    "dörröppnarna": "dörröppnare",
    "dörröppnarnas": "dörröppnare",
    "dörröppningar": "dörröppning",
    "dörröppningarna": "dörröppning",
    "dörröppningarnas": "dörröppning",
    "dörröppningars": "dörröppning",
    "dörröppningen": "dörröppning",
    "dörröppningens": "dörröppning",
    "dörröppnings": "dörröppning",
    "dös": "dö",
    "dösar": "dös",
    "dösarna": "dös",
    "dösarnas": "dös",
    "dösars": "dös",
    "dösen": "dös",
    "dösens": "dös",
    "dösjuka": "dösjuk",
    "dösjukare": "dösjuk",
    "dösjukares": "dösjuk",
    "dösjukas": "dösjuk",
    "dösjukast": "dösjuk",
    "dösjukaste": "dösjuk",
    "dösjukastes": "dösjuk",
    "dösjukasts": "dösjuk",
    "dösjuke": "dösjuk",
    "dösjukes": "dösjuk",
    "dösjuks": "dösjuk",
    "dösjukt": "dösjuk",
    "dösjukts": "dösjuk",
    "döskraja": "döskraj",
    "döskrajare": "döskraj",
    "döskrajares": "döskraj",
    "döskrajas": "döskraj",
    "döskrajast": "döskraj",
    "döskrajaste": "döskraj",
    "döskrajastes": "döskraj",
    "döskrajasts": "döskraj",
    "döskraje": "döskraj",
    "döskrajes": "döskraj",
    "döskrajs": "döskraj",
    "döskrajt": "döskraj",
    "döskrajts": "döskraj",
    "dötråkiga": "dötråkig",
    "dötråkigare": "dötråkig",
    "dötråkigares": "dötråkig",
    "dötråkigas": "dötråkig",
    "dötråkigast": "dötråkig",
    "dötråkigaste": "dötråkig",
    "dötråkigastes": "dötråkig",
    "dötråkigasts": "dötråkig",
    "dötråkige": "dötråkig",
    "dötråkiges": "dötråkig",
    "dötråkigs": "dötråkig",
    "dötråkigt": "dötråkig",
    "dötråkigts": "dötråkig",
    "dötrötta": "dötrött",
    "dötröttare": "dötrött",
    "dötröttares": "dötrött",
    "dötröttas": "dötrött",
    "dötröttast": "dötrött",
    "dötröttaste": "dötrött",
    "dötröttastes": "dötrött",
    "dötröttasts": "dötrött",
    "dötrötte": "dötrött",
    "dötröttes": "dötrött",
    "dötrötts": "dötrött",
    "dött": "död",
    "döttrar": "dotter",
    "döttrarna": "dotter",
    "döttrarnas": "dotter",
    "döttrars": "dotter",
    "dötts": "död",
    "dötysta": "dötyst",
    "dötystare": "dötyst",
    "dötystares": "dötyst",
    "dötystas": "dötyst",
    "dötystast": "dötyst",
    "dötystaste": "dötyst",
    "dötystastes": "dötyst",
    "dötystasts": "dötyst",
    "dötyste": "dötyst",
    "dötystes": "dötyst",
    "dötysts": "dötyst",
    "döv": "döva",
    "döva": "döv",
    "dövad": "döva",
    "dövade": "döva",
    "dövades": "döva",
    "dövads": "döva",
    "dövande": "döva",
    "dövanden": "dövande",
    "dövandena": "dövande",
    "dövandenas": "dövande",
    "dövandens": "dövande",
    "dövandes": "dövande",
    "dövandet": "dövande",
    "dövandets": "dövande",
    "dövar": "döva",
    "dövare": "döv",
    "dövares": "döv",
    "dövas": "döva",
    "dövast": "döv",
    "dövaste": "döv",
    "dövastes": "döv",
    "dövasts": "döv",
    "dövat": "döva",
    "dövats": "döva",
    "dövblinda": "dövblind",
    "dövblindare": "dövblind",
    "dövblindares": "dövblind",
    "dövblindas": "dövblind",
    "dövblindast": "dövblind",
    "dövblindaste": "dövblind",
    "dövblindastes": "dövblind",
    "dövblindasts": "dövblind",
    "dövblinde": "dövblind",
    "dövblindes": "dövblind",
    "dövblindheten": "dövblindhet",
    "dövblindhetens": "dövblindhet",
    "dövblindhets": "dövblindhet",
    "dövblinds": "dövblind",
    "dövblint": "dövblind",
    "dövblints": "dövblind",
    "döve": "döv",
    "döves": "döv",
    "dövheten": "dövhet",
    "dövhetens": "dövhet",
    "dövheter": "dövhet",
    "dövheterna": "dövhet",
    "dövheternas": "dövhet",
    "dövheters": "dövhet",
    "dövhets": "dövhet",
    "dövs": "döv",
    "dövstumheten": "dövstumhet",
    "dövstumhetens": "dövstumhet",
    "dövstumhets": "dövstumhet",
    "dövstumma": "dövstum",
    "dövstummare": "dövstum",
    "dövstummares": "dövstum",
    "dövstummas": "dövstum",
    "dövstummast": "dövstum",
    "dövstummaste": "dövstum",
    "dövstummastes": "dövstum",
    "dövstummasts": "dövstum",
    "dövstumme": "dövstum",
    "dövstummes": "dövstum",
    "dövstums": "dövstum",
    "dövstumt": "dövstum",
    "dövstumts": "dövstum",
    "dövt": "döv",
    "dövts": "döv",
    "e-boken": "e-bok",
    "e-bokens": "e-bok",
    "e-bokläsar": "e-bokläsare",
    "e-bokläsaren": "e-bokläsare",
    "e-bokläsarens": "e-bokläsare",
    "e-bokläsares": "e-bokläsare",
    "e-bokläsarna": "e-bokläsare",
    "e-bokläsarnas": "e-bokläsare",
    "e-boks": "e-bok",
    "e-breven": "e-brev",
    "e-brevens": "e-brev",
    "e-brevet": "e-brev",
    "e-brevets": "e-brev",
    "e-brevs": "e-brev",
    "e-böcker": "e-bok",
    "e-böckerna": "e-bok",
    "e-böckernas": "e-bok",
    "e-böckers": "e-bok",
    "e-et": "e",
    "e-ets": "e",
    "e-mail": "e-maila",
    "e-mailad": "e-maila",
    "e-mailade": "e-maila",
    "e-mailades": "e-maila",
    "e-mailads": "e-maila",
    "e-mailande": "e-maila",
    "e-mailanden": "e-mailande",
    "e-mailandena": "e-mailande",
    "e-mailandenas": "e-mailande",
    "e-mailandens": "e-mailande",
    "e-mailandes": "e-mailande",
    "e-mailandet": "e-mailande",
    "e-mailandets": "e-mailande",
    "e-mailar": "e-maila",
    "e-mailas": "e-maila",
    "e-mailat": "e-maila",
    "e-mailats": "e-maila",
    "e-mailen": "e-mail",
    "e-mailens": "e-mail",
    "e-mailet": "e-mail",
    "e-mailets": "e-mail",
    "e-mails": "e-mail",
    "e-n": "e",
    "e-na": "e",
    "e-nas": "e",
    "e-ns": "e",
    "e-postad": "e-posta",
    "e-postade": "e-posta",
    "e-postades": "e-posta",
    "e-postads": "e-posta",
    "e-postande": "e-posta",
    "e-postanden": "e-postande",
    "e-postandena": "e-postande",
    "e-postandenas": "e-postande",
    "e-postandens": "e-postande",
    "e-postandes": "e-postande",
    "e-postandet": "e-postande",
    "e-postandets": "e-postande",
    "e-postar": "e-postare",
    "e-postaren": "e-postare",
    "e-postarens": "e-postare",
    "e-postares": "e-postare",
    "e-postarna": "e-postare",
    "e-postarnas": "e-postare",
    "e-postars": "e-post",
    "e-postas": "e-posta",
    "e-postat": "e-posta",
    "e-postats": "e-posta",
    "e-postbreven": "e-postbrev",
    "e-postbrevens": "e-postbrev",
    "e-postbrevet": "e-postbrev",
    "e-postbrevets": "e-postbrev",
    "e-postbrevs": "e-postbrev",
    "e-posten": "e-post",
    "e-postens": "e-post",
    "e-poster": "e-post",
    "e-posterna": "e-post",
    "e-posternas": "e-post",
    "e-posters": "e-post",
    "e-postmeddelanden": "e-postmeddelande",
    "e-postmeddelandena": "e-postmeddelande",
    "e-postmeddelandenas": "e-postmeddelande",
    "e-postmeddelandens": "e-postmeddelande",
    "e-postmeddelandes": "e-postmeddelande",
    "e-postmeddelandet": "e-postmeddelande",
    "e-postmeddelandets": "e-postmeddelande",
    "e-posts": "e-post",
    "e-t": "e",
    "e-tidningar": "e-tidning",
    "e-tidningarna": "e-tidning",
    "e-tidningarnas": "e-tidning",
    "e-tidningars": "e-tidning",
    "e-tidningen": "e-tidning",
    "e-tidningens": "e-tidning",
    "e-tidnings": "e-tidning",
    "e-tidskriften": "e-tidskrift",
    "e-tidskriftens": "e-tidskrift",
    "e-tidskrifter": "e-tidskrift",
    "e-tidskrifterna": "e-tidskrift",
    "e-tidskrifternas": "e-tidskrift",
    "e-tidskrifters": "e-tidskrift",
    "e-tidskrifts": "e-tidskrift",
    "e-ts": "e",
    "e-vetenskapen": "e-vetenskap",
    "e-vetenskapens": "e-vetenskap",
    "e-vetenskaper": "e-vetenskap",
    "e-vetenskaperna": "e-vetenskap",
    "e-vetenskapernas": "e-vetenskap",
    "e-vetenskapers": "e-vetenskap",
    "e-vetenskaps": "e-vetenskap",
    "e:et": "e",
    "e:ets": "e",
    "e:n": "e",
    "e:na": "e",
    "e:nas": "e",
    "e:ns": "e",
    "e:s": "e",
    "e:t": "e",
    "e:ts": "e",
    "eau-de-colognen": "eau-de-cologne",
    "eau-de-colognens": "eau-de-cologne",
    "eau-de-colognes": "eau-de-cologne",
    "eau-de-toiletten": "eau-de-toilette",
    "eau-de-toilettens": "eau-de-toilette",
    "eau-de-toilettes": "eau-de-toilette",
    "eau-de-vien": "eau-de-vie",
    "eau-de-viens": "eau-de-vie",
    "eau-de-vies": "eau-de-vie",
    "ebb": "ebba",
    "ebbade": "ebba",
    "ebbades": "ebba",
    "ebbande": "ebba",
    "ebbanden": "ebbande",
    "ebbandena": "ebbande",
    "ebbandenas": "ebbande",
    "ebbandens": "ebbande",
    "ebbandes": "ebbande",
    "ebbandet": "ebbande",
    "ebbandets": "ebbande",
    "ebbar": "ebba",
    "ebbas": "ebba",
    "ebbat": "ebba",
    "ebbats": "ebba",
    "ebben": "ebb",
    "ebbens": "ebb",
    "ebbs": "ebb",
    "ebenholtsen": "ebenholts",
    "ebenholtsens": "ebenholts",
    "ebenholtset": "ebenholts",
    "ebenholtsets": "ebenholts",
    "ebenisten": "ebenist",
    "ebenistens": "ebenist",
    "ebenister": "ebenist",
    "ebenisterna": "ebenist",
    "ebenisternas": "ebenist",
    "ebenisters": "ebenist",
    "ebenists": "ebenist",
    "eboniten": "ebonit",
    "ebonitens": "ebonit",
    "ebonits": "ebonit",
    "ebonitstavar": "ebonitstav",
    "ebonitstavarna": "ebonitstav",
    "ebonitstavarnas": "ebonitstav",
    "ebonitstavars": "ebonitstav",
    "ebonitstaven": "ebonitstav",
    "ebonitstavens": "ebonitstav",
    "ebonitstavs": "ebonitstav",
    "ebreven": "ebrev",
    "ebrevens": "ebrev",
    "ebrevet": "ebrev",
    "ebrevets": "ebrev",
    "ebrevs": "ebrev",
    "echaufferade": "echaufferad",
    "echaufferades": "echaufferad",
    "echaufferads": "echaufferad",
    "echaufferat": "echaufferad",
    "echaufferats": "echaufferad",
    "echelongen": "echelong",
    "echelongens": "echelong",
    "echelonger": "echelong",
    "echelongerna": "echelong",
    "echelongernas": "echelong",
    "echelongers": "echelong",
    "echelongs": "echelong",
    "ecklesiastika": "ecklesiastik",
    "ecklesiastikare": "ecklesiastik",
    "ecklesiastikares": "ecklesiastik",
    "ecklesiastikas": "ecklesiastik",
    "ecklesiastikast": "ecklesiastik",
    "ecklesiastikaste": "ecklesiastik",
    "ecklesiastikastes": "ecklesiastik",
    "ecklesiastikasts": "ecklesiastik",
    "ecklesiastikdepartementen": "ecklesiastikdepartement",
    "ecklesiastikdepartementens": "ecklesiastikdepartement",
    "ecklesiastikdepartementet": "ecklesiastikdepartement",
    "ecklesiastikdepartementets": "ecklesiastikdepartement",
    "ecklesiastikdepartements": "ecklesiastikdepartement",
    "ecklesiastike": "ecklesiastik",
    "ecklesiastikes": "ecklesiastik",
    "ecklesiastikministern": "ecklesiastikminister",
    "ecklesiastikministerns": "ecklesiastikminister",
    "ecklesiastikministers": "ecklesiastikminister",
    "ecklesiastikministrar": "ecklesiastikminister",
    "ecklesiastikministrarna": "ecklesiastikminister",
    "ecklesiastikministrarnas": "ecklesiastikminister",
    "ecklesiastikministrars": "ecklesiastikminister",
    "ecklesiastiks": "ecklesiastik",
    "ecklesiastikt": "ecklesiastik",
    "ecklesiastikts": "ecklesiastik",
    "ecklesiastiska": "ecklesiastisk",
    "ecklesiastiskare": "ecklesiastisk",
    "ecklesiastiskares": "ecklesiastisk",
    "ecklesiastiskas": "ecklesiastisk",
    "ecklesiastiskast": "ecklesiastisk",
    "ecklesiastiskaste": "ecklesiastisk",
    "ecklesiastiskastes": "ecklesiastisk",
    "ecklesiastiskasts": "ecklesiastisk",
    "ecklesiastiske": "ecklesiastisk",
    "ecklesiastiskes": "ecklesiastisk",
    "ecklesiastisks": "ecklesiastisk",
    "ecklesiastiskt": "ecklesiastisk",
    "ecklesiastiskts": "ecklesiastisk",
    "ecuadorianen": "ecuadorian",
    "ecuadorianens": "ecuadorian",
    "ecuadorianer": "ecuadorian",
    "ecuadorianerna": "ecuadorian",
    "ecuadorianernas": "ecuadorian",
    "ecuadorianers": "ecuadorian",
    "ecuadorians": "ecuadorian",
    "ecuadorianska": "ecuadoriansk",
    "ecuadorianskan": "ecuadorianska",
    "ecuadorianskans": "ecuadorianska",
    "ecuadorianskare": "ecuadoriansk",
    "ecuadorianskares": "ecuadoriansk",
    "ecuadorianskas": "ecuadorianska",
    "ecuadorianskast": "ecuadoriansk",
    "ecuadorianskaste": "ecuadoriansk",
    "ecuadorianskastes": "ecuadoriansk",
    "ecuadorianskasts": "ecuadoriansk",
    "ecuadorianske": "ecuadorianska",
    "ecuadorianskes": "ecuadoriansk",
    "ecuadorianskor": "ecuadorianska",
    "ecuadorianskorna": "ecuadorianska",
    "ecuadorianskornas": "ecuadorianska",
    "ecuadorianskors": "ecuadorianska",
    "ecuadoriansks": "ecuadoriansk",
    "ecuadorianskt": "ecuadoriansk",
    "ecuadorianskts": "ecuadoriansk",
    "ed": "eda",
    "edamerostar": "edamerost",
    "edamerostarna": "edamerost",
    "edamerostarnas": "edamerost",
    "edamerostars": "edamerost",
    "edamerosten": "edamerost",
    "edamerostens": "edamerost",
    "edamerosts": "edamerost",
    "edan": "eda",
    "edans": "eda",
    "edas": "eda",
    "edd": "edda",
    "eddan": "edda",
    "eddans": "edda",
    "eddas": "edda",
    "edde": "edda",
    "eddor": "edda",
    "eddorna": "edda",
    "eddornas": "edda",
    "eddors": "edda",
    "edds": "edda",
    "ede": "eda",
    "edelweissen": "edelweiss",
    "edelweissens": "edelweiss",
    "eden": "ed",
    "edens": "ed",
    "eder": "ed",
    "ederad": "edera",
    "ederade": "edera",
    "ederades": "edera",
    "ederads": "edera",
    "ederande": "edera",
    "ederanden": "ederande",
    "ederandena": "ederande",
    "ederandenas": "ederande",
    "ederandens": "ederande",
    "ederandes": "ederande",
    "ederandet": "ederande",
    "ederandets": "ederande",
    "ederar": "edera",
    "ederas": "edera",
    "ederat": "edera",
    "ederats": "edera",
    "ederbara": "ederbar",
    "ederbarare": "ederbar",
    "ederbarares": "ederbar",
    "ederbaras": "ederbar",
    "ederbarast": "ederbar",
    "ederbaraste": "ederbar",
    "ederbarastes": "ederbar",
    "ederbarasts": "ederbar",
    "ederbare": "ederbar",
    "ederbares": "ederbar",
    "ederbarheten": "ederbarhet",
    "ederbarhetens": "ederbarhet",
    "ederbarhets": "ederbarhet",
    "ederbars": "ederbar",
    "ederbart": "ederbar",
    "ederbarts": "ederbar",
    "ederingar": "edering",
    "ederingarna": "edering",
    "ederingarnas": "edering",
    "ederingars": "edering",
    "ederingen": "edering",
    "ederingens": "edering",
    "ederings": "edering",
    "ederna": "ed",
    "edernas": "ed",
    "eders": "ed",
    "edet": "ed",
    "edets": "ed",
    "edfäst": "edfästa",
    "edfästande": "edfästa",
    "edfästanden": "edfästande",
    "edfästandena": "edfästande",
    "edfästandenas": "edfästande",
    "edfästandens": "edfästande",
    "edfästandes": "edfästande",
    "edfästandet": "edfästande",
    "edfästandets": "edfästande",
    "edfästas": "edfästa",
    "edfäste": "edfästa",
    "edfäster": "edfästa",
    "edfästes": "edfästa",
    "edfästs": "edfästa",
    "edgångar": "edgång",
    "edgångarna": "edgång",
    "edgångarnas": "edgång",
    "edgångars": "edgång",
    "edgången": "edgång",
    "edgångens": "edgång",
    "edgångs": "edgång",
    "edikten": "edikt",
    "ediktens": "edikt",
    "ediktet": "edikt",
    "ediktets": "edikt",
    "edikts": "edikt",
    "edilen": "edil",
    "edilens": "edil",
    "ediler": "edil",
    "edilerna": "edil",
    "edilernas": "edil",
    "edilers": "edil",
    "edils": "edil",
    "editionen": "edition",
    "editionens": "edition",
    "editioner": "edition",
    "editionerna": "edition",
    "editionernas": "edition",
    "editioners": "edition",
    "editions": "edition",
    "edliga": "edlig",
    "edligare": "edlig",
    "edligares": "edlig",
    "edligas": "edlig",
    "edligast": "edlig",
    "edligaste": "edlig",
    "edligastes": "edlig",
    "edligasts": "edlig",
    "edlige": "edlig",
    "edliges": "edlig",
    "edligheten": "edlighet",
    "edlighetens": "edlighet",
    "edlighets": "edlighet",
    "edligs": "edlig",
    "edligt": "edlig",
    "edligts": "edlig",
    "edor": "eda",
    "edorna": "eda",
    "edornas": "eda",
    "edors": "eda",
    "eds": "eda",
    "edsansvaret": "edsansvar",
    "edsansvarets": "edsansvar",
    "edsansvars": "edsansvar",
    "edsbrotten": "edsbrott",
    "edsbrottens": "edsbrott",
    "edsbrottet": "edsbrott",
    "edsbrottets": "edsbrott",
    "edsbrotts": "edsbrott",
    "edsvurens": "edsvuren",
    "edsvuret": "edsvuren",
    "edsvurets": "edsvuren",
    "edsvurna": "edsvuren",
    "edsvurnare": "edsvuren",
    "edsvurnares": "edsvuren",
    "edsvurnas": "edsvuren",
    "edsvurnast": "edsvuren",
    "edsvurnaste": "edsvuren",
    "edsvurnastes": "edsvuren",
    "edsvurnasts": "edsvuren",
    "edsvurne": "edsvuren",
    "edsvurnes": "edsvuren",
    "edsöres": "edsöre",
    "edsöret": "edsöre",
    "edsörets": "edsöre",
    "efedrinen": "efedrin",
    "efedrinens": "efedrin",
    "efedriner": "efedrin",
    "efedrinerna": "efedrin",
    "efedrinernas": "efedrin",
    "efedriners": "efedrin",
    "efedrinet": "efedrin",
    "efedrinets": "efedrin",
    "efedrins": "efedrin",
    "efemerid": "efemerider",
    "efemeriden": "efemerid",
    "efemeridens": "efemerid",
    "efemerider": "efemerid",
    "efemeriderna": "efemerider",
    "efemeridernas": "efemerider",
    "efemeriders": "efemerider",
    "efemerids": "efemerider",
    "efemeridtiden": "efemeridtid",
    "efemeridtidens": "efemeridtid",
    "efemeridtids": "efemeridtid",
    "efemära": "efemär",
    "efemärare": "efemär",
    "efemärares": "efemär",
    "efemäras": "efemär",
    "efemärast": "efemär",
    "efemäraste": "efemär",
    "efemärastes": "efemär",
    "efemärasts": "efemär",
    "efemäre": "efemär",
    "efemäres": "efemär",
    "efemärs": "efemär",
    "efemärt": "efemär",
    "efemärts": "efemär",
    "effacerad": "effacera",
    "effacerade": "effacera",
    "effacerades": "effacera",
    "effacerads": "effacera",
    "effacerande": "effacera",
    "effaceranden": "effacerande",
    "effacerandena": "effacerande",
    "effacerandenas": "effacerande",
    "effacerandens": "effacerande",
    "effacerandes": "effacerande",
    "effacerandet": "effacerande",
    "effacerandets": "effacerande",
    "effacerar": "effacera",
    "effaceras": "effacera",
    "effacerat": "effacera",
    "effacerats": "effacera",
    "effacerbara": "effacerbar",
    "effacerbarare": "effacerbar",
    "effacerbarares": "effacerbar",
    "effacerbaras": "effacerbar",
    "effacerbarast": "effacerbar",
    "effacerbaraste": "effacerbar",
    "effacerbarastes": "effacerbar",
    "effacerbarasts": "effacerbar",
    "effacerbare": "effacerbar",
    "effacerbares": "effacerbar",
    "effacerbarheten": "effacerbarhet",
    "effacerbarhetens": "effacerbarhet",
    "effacerbarhets": "effacerbarhet",
    "effacerbars": "effacerbar",
    "effacerbart": "effacerbar",
    "effacerbarts": "effacerbar",
    "effaceringar": "effacering",
    "effaceringarna": "effacering",
    "effaceringarnas": "effacering",
    "effaceringars": "effacering",
    "effaceringen": "effacering",
    "effaceringens": "effacering",
    "effacerings": "effacering",
    "effekten": "effekt",
    "effektens": "effekt",
    "effekter": "effekt",
    "effekterna": "effekt",
    "effekternas": "effekt",
    "effekters": "effekt",
    "effektfaktorer": "effektfaktor",
    "effektfaktorerna": "effektfaktor",
    "effektfaktorernas": "effektfaktor",
    "effektfaktorers": "effektfaktor",
    "effektfaktorn": "effektfaktor",
    "effektfaktorns": "effektfaktor",
    "effektfaktors": "effektfaktor",
    "effektfrånskiljar": "effektfrånskiljare",
    "effektfrånskiljaren": "effektfrånskiljare",
    "effektfrånskiljarens": "effektfrånskiljare",
    "effektfrånskiljares": "effektfrånskiljare",
    "effektfrånskiljarna": "effektfrånskiljare",
    "effektfrånskiljarnas": "effektfrånskiljare",
    "effektfulla": "effektfull",
    "effektfullare": "effektfull",
    "effektfullares": "effektfull",
    "effektfullas": "effektfull",
    "effektfullast": "effektfull",
    "effektfullaste": "effektfull",
    "effektfullastes": "effektfull",
    "effektfullasts": "effektfull",
    "effektfulle": "effektfull",
    "effektfulles": "effektfull",
    "effektfullheten": "effektfullhet",
    "effektfullhetens": "effektfullhet",
    "effektfullhets": "effektfullhet",
    "effektfulls": "effektfull",
    "effektfullt": "effektfull",
    "effektfullts": "effektfull",
    "effektförstärkar": "effektförstärkare",
    "effektförstärkaren": "effektförstärkare",
    "effektförstärkarens": "effektförstärkare",
    "effektförstärkares": "effektförstärkare",
    "effektförstärkarna": "effektförstärkare",
    "effektförstärkarnas": "effektförstärkare",
    "effektgarnet": "effektgarn",
    "effektgarnets": "effektgarn",
    "effektgarns": "effektgarn",
    "effektiva": "effektiv",
    "effektivare": "effektiv",
    "effektivares": "effektiv",
    "effektivas": "effektiv",
    "effektivast": "effektiv",
    "effektivaste": "effektiv",
    "effektivastes": "effektiv",
    "effektivasts": "effektiv",
    "effektive": "effektiv",
    "effektiverad": "effektivera",
    "effektiverade": "effektivera",
    "effektiverades": "effektivera",
    "effektiverads": "effektivera",
    "effektiverande": "effektivera",
    "effektiveranden": "effektiverande",
    "effektiverandena": "effektiverande",
    "effektiverandenas": "effektiverande",
    "effektiverandens": "effektiverande",
    "effektiverandes": "effektiverande",
    "effektiverandet": "effektiverande",
    "effektiverandets": "effektiverande",
    "effektiverar": "effektivera",
    "effektiveras": "effektivera",
    "effektiverat": "effektivera",
    "effektiverats": "effektivera",
    "effektiverbara": "effektiverbar",
    "effektiverbarare": "effektiverbar",
    "effektiverbarares": "effektiverbar",
    "effektiverbaras": "effektiverbar",
    "effektiverbarast": "effektiverbar",
    "effektiverbaraste": "effektiverbar",
    "effektiverbarastes": "effektiverbar",
    "effektiverbarasts": "effektiverbar",
    "effektiverbare": "effektiverbar",
    "effektiverbares": "effektiverbar",
    "effektiverbarheten": "effektiverbarhet",
    "effektiverbarhetens": "effektiverbarhet",
    "effektiverbarhets": "effektiverbarhet",
    "effektiverbars": "effektiverbar",
    "effektiverbart": "effektiverbar",
    "effektiverbarts": "effektiverbar",
    "effektiveringar": "effektivering",
    "effektiveringarna": "effektivering",
    "effektiveringarnas": "effektivering",
    "effektiveringars": "effektivering",
    "effektiveringen": "effektivering",
    "effektiveringens": "effektivering",
    "effektiverings": "effektivering",
    "effektives": "effektiv",
    "effektiviserad": "effektivisera",
    "effektiviserade": "effektivisera",
    "effektiviserades": "effektivisera",
    "effektiviserads": "effektivisera",
    "effektiviserande": "effektivisera",
    "effektiviseranden": "effektiviserande",
    "effektiviserandena": "effektiviserande",
    "effektiviserandenas": "effektiviserande",
    "effektiviserandens": "effektiviserande",
    "effektiviserandes": "effektiviserande",
    "effektiviserandet": "effektiviserande",
    "effektiviserandets": "effektiviserande",
    "effektiviserar": "effektivisera",
    "effektiviseras": "effektivisera",
    "effektiviserat": "effektivisera",
    "effektiviserats": "effektivisera",
    "effektiviserbara": "effektiviserbar",
    "effektiviserbarare": "effektiviserbar",
    "effektiviserbarares": "effektiviserbar",
    "effektiviserbaras": "effektiviserbar",
    "effektiviserbarast": "effektiviserbar",
    "effektiviserbaraste": "effektiviserbar",
    "effektiviserbarastes": "effektiviserbar",
    "effektiviserbarasts": "effektiviserbar",
    "effektiviserbare": "effektiviserbar",
    "effektiviserbares": "effektiviserbar",
    "effektiviserbarheten": "effektiviserbarhet",
    "effektiviserbarhetens": "effektiviserbarhet",
    "effektiviserbarhets": "effektiviserbarhet",
    "effektiviserbars": "effektiviserbar",
    "effektiviserbart": "effektiviserbar",
    "effektiviserbarts": "effektiviserbar",
    "effektiviseringar": "effektivisering",
    "effektiviseringarna": "effektivisering",
    "effektiviseringarnas": "effektivisering",
    "effektiviseringars": "effektivisering",
    "effektiviseringen": "effektivisering",
    "effektiviseringens": "effektivisering",
    "effektiviserings": "effektivisering",
    "effektiviteten": "effektivitet",
    "effektivitetens": "effektivitet",
    "effektiviteter": "effektivitet",
    "effektiviteterna": "effektivitet",
    "effektiviteternas": "effektivitet",
    "effektiviteters": "effektivitet",
    "effektivitets": "effektivitet",
    "effektivitetsmässiga": "effektivitetsmässig",
    "effektivitetsmässigare": "effektivitetsmässig",
    "effektivitetsmässigares": "effektivitetsmässig",
    "effektivitetsmässigas": "effektivitetsmässig",
    "effektivitetsmässigast": "effektivitetsmässig",
    "effektivitetsmässigaste": "effektivitetsmässig",
    "effektivitetsmässigastes": "effektivitetsmässig",
    "effektivitetsmässigasts": "effektivitetsmässig",
    "effektivitetsmässige": "effektivitetsmässig",
    "effektivitetsmässiges": "effektivitetsmässig",
    "effektivitetsmässigs": "effektivitetsmässig",
    "effektivitetsmässigt": "effektivitetsmässig",
    "effektivitetsmässigts": "effektivitetsmässig",
    "effektivs": "effektiv",
    "effektivt": "effektiv",
    "effektivts": "effektiv",
    "effektlägen": "effektläge",
    "effektlägena": "effektläge",
    "effektlägenas": "effektläge",
    "effektlägens": "effektläge",
    "effektläges": "effektläge",
    "effektläget": "effektläge",
    "effektlägets": "effektläge",
    "effektmässiga": "effektmässig",
    "effektmässigare": "effektmässig",
    "effektmässigares": "effektmässig",
    "effektmässigas": "effektmässig",
    "effektmässigast": "effektmässig",
    "effektmässigaste": "effektmässig",
    "effektmässigastes": "effektmässig",
    "effektmässigasts": "effektmässig",
    "effektmässige": "effektmässig",
    "effektmässiges": "effektmässig",
    "effektmässigs": "effektmässig",
    "effektmässigt": "effektmässig",
    "effektmässigts": "effektmässig",
    "effekts": "effekt",
    "effektsökerier": "effektsökeri",
    "effektsökerierna": "effektsökeri",
    "effektsökeriernas": "effektsökeri",
    "effektsökeriers": "effektsökeri",
    "effektsökeriet": "effektsökeri",
    "effektsökeriets": "effektsökeri",
    "effektsökeris": "effektsökeri",
    "effektsökerit": "effektsökeri",
    "effektsökerits": "effektsökeri",
    "effektuerad": "effektuera",
    "effektuerade": "effektuera",
    "effektuerades": "effektuera",
    "effektuerads": "effektuera",
    "effektuerande": "effektuera",
    "effektueranden": "effektuerande",
    "effektuerandena": "effektuerande",
    "effektuerandenas": "effektuerande",
    "effektuerandens": "effektuerande",
    "effektuerandes": "effektuerande",
    "effektuerandet": "effektuerande",
    "effektuerandets": "effektuerande",
    "effektuerar": "effektuera",
    "effektueras": "effektuera",
    "effektuerat": "effektuera",
    "effektuerats": "effektuera",
    "effektuerbara": "effektuerbar",
    "effektuerbarare": "effektuerbar",
    "effektuerbarares": "effektuerbar",
    "effektuerbaras": "effektuerbar",
    "effektuerbarast": "effektuerbar",
    "effektuerbaraste": "effektuerbar",
    "effektuerbarastes": "effektuerbar",
    "effektuerbarasts": "effektuerbar",
    "effektuerbare": "effektuerbar",
    "effektuerbares": "effektuerbar",
    "effektuerbarheten": "effektuerbarhet",
    "effektuerbarhetens": "effektuerbarhet",
    "effektuerbarhets": "effektuerbarhet",
    "effektuerbars": "effektuerbar",
    "effektuerbart": "effektuerbar",
    "effektuerbarts": "effektuerbar",
    "effektueringar": "effektuering",
    "effektueringarna": "effektuering",
    "effektueringarnas": "effektuering",
    "effektueringars": "effektuering",
    "effektueringen": "effektuering",
    "effektueringens": "effektuering",
    "effektuerings": "effektuering",
    "effektökningar": "effektökning",
    "effektökningarna": "effektökning",
    "effektökningarnas": "effektökning",
    "effektökningars": "effektökning",
    "effektökningen": "effektökning",
    "effektökningens": "effektökning",
    "effektöknings": "effektökning",
    "effeminerade": "effeminerad",
    "effeminerades": "effeminerad",
    "effeminerads": "effeminerad",
    "effeminerat": "effeminerad",
    "effeminerats": "effeminerad",
    "eforen": "efor",
    "eforens": "efor",
    "eforer": "eforus",
    "eforerna": "eforus",
    "eforernas": "eforus",
    "eforers": "eforus",
    "efors": "efor",
    "efteraccepten": "efteraccept",
    "efteracceptens": "efteraccept",
    "efteracceptet": "efteraccept",
    "efteracceptets": "efteraccept",
    "efteraccepts": "efteraccept",
    "efterap": "efterapa",
    "efterapad": "efterapa",
    "efterapade": "efterapa",
    "efterapades": "efterapa",
    "efterapads": "efterapa",
    "efterapande": "efterapa",
    "efterapanden": "efterapande",
    "efterapandena": "efterapande",
    "efterapandenas": "efterapande",
    "efterapandens": "efterapande",
    "efterapandes": "efterapande",
    "efterapandet": "efterapande",
    "efterapandets": "efterapande",
    "efterapar": "efterapa",
    "efterapas": "efterapa",
    "efterapat": "efterapa",
    "efterapats": "efterapa",
    "efterarbeten": "efterarbete",
    "efterarbetena": "efterarbete",
    "efterarbetenas": "efterarbete",
    "efterarbetens": "efterarbete",
    "efterarbetes": "efterarbete",
    "efterarbetet": "efterarbete",
    "efterarbetets": "efterarbete",
    "efterarbets": "efterarbete",
    "efterbehandlad": "efterbehandla",
    "efterbehandlade": "efterbehandla",
    "efterbehandlades": "efterbehandla",
    "efterbehandlads": "efterbehandla",
    "efterbehandlande": "efterbehandla",
    "efterbehandlanden": "efterbehandlande",
    "efterbehandlandena": "efterbehandlande",
    "efterbehandlandenas": "efterbehandlande",
    "efterbehandlandens": "efterbehandlande",
    "efterbehandlandes": "efterbehandlande",
    "efterbehandlandet": "efterbehandlande",
    "efterbehandlandets": "efterbehandlande",
    "efterbehandlar": "efterbehandla",
    "efterbehandlas": "efterbehandla",
    "efterbehandlat": "efterbehandla",
    "efterbehandlats": "efterbehandla",
    "efterbesiktningar": "efterbesiktning",
    "efterbesiktningarna": "efterbesiktning",
    "efterbesiktningarnas": "efterbesiktning",
    "efterbesiktningars": "efterbesiktning",
    "efterbesiktningen": "efterbesiktning",
    "efterbesiktningens": "efterbesiktning",
    "efterbesiktnings": "efterbesiktning",
    "efterbeskattningar": "efterbeskattning",
    "efterbeskattningarna": "efterbeskattning",
    "efterbeskattningarnas": "efterbeskattning",
    "efterbeskattningars": "efterbeskattning",
    "efterbeskattningen": "efterbeskattning",
    "efterbeskattningens": "efterbeskattning",
    "efterbeskattnings": "efterbeskattning",
    "efterbeställningar": "efterbeställning",
    "efterbeställningarna": "efterbeställning",
    "efterbeställningarnas": "efterbeställning",
    "efterbeställningars": "efterbeställning",
    "efterbeställningen": "efterbeställning",
    "efterbeställningens": "efterbeställning",
    "efterbeställnings": "efterbeställning",
    "efterbevakningar": "efterbevakning",
    "efterbevakningarna": "efterbevakning",
    "efterbevakningarnas": "efterbevakning",
    "efterbevakningars": "efterbevakning",
    "efterbevakningen": "efterbevakning",
    "efterbevakningens": "efterbevakning",
    "efterbevaknings": "efterbevakning",
    "efterbild": "efterbilda",
    "efterbildad": "efterbilda",
    "efterbildade": "efterbilda",
    "efterbildades": "efterbilda",
    "efterbildads": "efterbilda",
    "efterbildande": "efterbilda",
    "efterbildanden": "efterbildande",
    "efterbildandena": "efterbildande",
    "efterbildandenas": "efterbildande",
    "efterbildandens": "efterbildande",
    "efterbildandes": "efterbildande",
    "efterbildandet": "efterbildande",
    "efterbildandets": "efterbildande",
    "efterbildar": "efterbilda",
    "efterbildas": "efterbilda",
    "efterbildat": "efterbilda",
    "efterbildats": "efterbilda",
    "efterbilden": "efterbild",
    "efterbildens": "efterbild",
    "efterbilder": "efterbild",
    "efterbilderna": "efterbild",
    "efterbildernas": "efterbild",
    "efterbilders": "efterbild",
    "efterbildningar": "efterbildning",
    "efterbildningarna": "efterbildning",
    "efterbildningarnas": "efterbildning",
    "efterbildningars": "efterbildning",
    "efterbildningen": "efterbildning",
    "efterbildningens": "efterbildning",
    "efterbildnings": "efterbildning",
    "efterbilds": "efterbild",
    "efterblivenheten": "efterblivenhet",
    "efterblivenhetens": "efterblivenhet",
    "efterblivenhets": "efterblivenhet",
    "efterblivens": "efterbliven",
    "efterblivet": "efterbliven",
    "efterblivets": "efterbliven",
    "efterblivna": "efterbliven",
    "efterblivnare": "efterbliven",
    "efterblivnares": "efterbliven",
    "efterblivnas": "efterbliven",
    "efterblivnast": "efterbliven",
    "efterblivnaste": "efterbliven",
    "efterblivnastes": "efterbliven",
    "efterblivnasts": "efterbliven",
    "efterblivne": "efterbliven",
    "efterblivnes": "efterbliven",
    "efterblomningar": "efterblomning",
    "efterblomningarna": "efterblomning",
    "efterblomningarnas": "efterblomning",
    "efterblomningars": "efterblomning",
    "efterblomningen": "efterblomning",
    "efterblomningens": "efterblomning",
    "efterblomnings": "efterblomning",
    "efterblomstringar": "efterblomstring",
    "efterblomstringarna": "efterblomstring",
    "efterblomstringarnas": "efterblomstring",
    "efterblomstringars": "efterblomstring",
    "efterblomstringen": "efterblomstring",
    "efterblomstringens": "efterblomstring",
    "efterblomstrings": "efterblomstring",
    "efterblödningar": "efterblödning",
    "efterblödningarna": "efterblödning",
    "efterblödningarnas": "efterblödning",
    "efterblödningars": "efterblödning",
    "efterblödningen": "efterblödning",
    "efterblödningens": "efterblödning",
    "efterblödnings": "efterblödning",
    "efterbrännar": "efterbrännare",
    "efterbrännaren": "efterbrännare",
    "efterbrännarens": "efterbrännare",
    "efterbrännares": "efterbrännare",
    "efterbrännarna": "efterbrännare",
    "efterbrännarnas": "efterbrännare",
    "efterbrännkammar": "efterbrännkammare",
    "efterbrännkammaren": "efterbrännkammare",
    "efterbrännkammarens": "efterbrännkammare",
    "efterbrännkammares": "efterbrännkammare",
    "efterbrännkamrar": "efterbrännkammare",
    "efterbrännkamrarna": "efterbrännkammare",
    "efterbrännkamrarnas": "efterbrännkammare",
    "efterbrännkamrars": "efterbrännkammare",
    "efterbörden": "efterbörd",
    "efterbördens": "efterbörd",
    "efterbörder": "efterbörd",
    "efterbörderna": "efterbörd",
    "efterbördernas": "efterbörd",
    "efterbörders": "efterbörd",
    "efterbörds": "efterbörd",
    "efterbörsen": "efterbörs",
    "efterbörsens": "efterbörs",
    "efterbörser": "efterbörs",
    "efterbörserna": "efterbörs",
    "efterbörsernas": "efterbörs",
    "efterbörsers": "efterbörs",
    "efterdaterad": "efterdatera",
    "efterdaterade": "efterdatera",
    "efterdaterades": "efterdatera",
    "efterdaterads": "efterdatera",
    "efterdaterande": "efterdatera",
    "efterdateranden": "efterdaterande",
    "efterdaterandena": "efterdaterande",
    "efterdaterandenas": "efterdaterande",
    "efterdaterandens": "efterdaterande",
    "efterdaterandes": "efterdaterande",
    "efterdaterandet": "efterdaterande",
    "efterdaterandets": "efterdaterande",
    "efterdaterar": "efterdatera",
    "efterdateras": "efterdatera",
    "efterdaterat": "efterdatera",
    "efterdaterats": "efterdatera",
    "efterdaterbara": "efterdaterbar",
    "efterdaterbarare": "efterdaterbar",
    "efterdaterbarares": "efterdaterbar",
    "efterdaterbaras": "efterdaterbar",
    "efterdaterbarast": "efterdaterbar",
    "efterdaterbaraste": "efterdaterbar",
    "efterdaterbarastes": "efterdaterbar",
    "efterdaterbarasts": "efterdaterbar",
    "efterdaterbare": "efterdaterbar",
    "efterdaterbares": "efterdaterbar",
    "efterdaterbarheten": "efterdaterbarhet",
    "efterdaterbarhetens": "efterdaterbarhet",
    "efterdaterbarhets": "efterdaterbarhet",
    "efterdaterbars": "efterdaterbar",
    "efterdaterbart": "efterdaterbar",
    "efterdaterbarts": "efterdaterbar",
    "efterdateringar": "efterdatering",
    "efterdateringarna": "efterdatering",
    "efterdateringarnas": "efterdatering",
    "efterdateringars": "efterdatering",
    "efterdateringen": "efterdatering",
    "efterdateringens": "efterdatering",
    "efterdaterings": "efterdatering",
    "efterdebiterad": "efterdebitera",
    "efterdebiterade": "efterdebitera",
    "efterdebiterades": "efterdebitera",
    "efterdebiterads": "efterdebitera",
    "efterdebiterande": "efterdebitera",
    "efterdebiteranden": "efterdebiterande",
    "efterdebiterandena": "efterdebiterande",
    "efterdebiterandenas": "efterdebiterande",
    "efterdebiterandens": "efterdebiterande",
    "efterdebiterandes": "efterdebiterande",
    "efterdebiterandet": "efterdebiterande",
    "efterdebiterandets": "efterdebiterande",
    "efterdebiterar": "efterdebitera",
    "efterdebiteras": "efterdebitera",
    "efterdebiterat": "efterdebitera",
    "efterdebiterats": "efterdebitera",
    "efterdebiterbara": "efterdebiterbar",
    "efterdebiterbarare": "efterdebiterbar",
    "efterdebiterbarares": "efterdebiterbar",
    "efterdebiterbaras": "efterdebiterbar",
    "efterdebiterbarast": "efterdebiterbar",
    "efterdebiterbaraste": "efterdebiterbar",
    "efterdebiterbarastes": "efterdebiterbar",
    "efterdebiterbarasts": "efterdebiterbar",
    "efterdebiterbare": "efterdebiterbar",
    "efterdebiterbares": "efterdebiterbar",
    "efterdebiterbarheten": "efterdebiterbarhet",
    "efterdebiterbarhetens": "efterdebiterbarhet",
    "efterdebiterbarhets": "efterdebiterbarhet",
    "efterdebiterbars": "efterdebiterbar",
    "efterdebiterbart": "efterdebiterbar",
    "efterdebiterbarts": "efterdebiterbar",
    "efterdebiteringar": "efterdebitering",
    "efterdebiteringarna": "efterdebitering",
    "efterdebiteringarnas": "efterdebitering",
    "efterdebiteringars": "efterdebitering",
    "efterdebiteringen": "efterdebitering",
    "efterdebiteringens": "efterdebitering",
    "efterdebiterings": "efterdebitering",
    "efterdyningar": "efterdyning",
    "efterdyningarna": "efterdyning",
    "efterdyningarnas": "efterdyning",
    "efterdyningars": "efterdyning",
    "efterdyningen": "efterdyning",
    "efterdyningens": "efterdyning",
    "efterdynings": "efterdyning",
    "efterdömen": "efterdöme",
    "efterdömena": "efterdöme",
    "efterdömenas": "efterdöme",
    "efterdömens": "efterdöme",
    "efterdömes": "efterdöme",
    "efterdömet": "efterdöme",
    "efterdömets": "efterdöme",
    "efterdömliga": "efterdömlig",
    "efterdömligare": "efterdömlig",
    "efterdömligares": "efterdömlig",
    "efterdömligas": "efterdömlig",
    "efterdömligast": "efterdömlig",
    "efterdömligaste": "efterdömlig",
    "efterdömligastes": "efterdömlig",
    "efterdömligasts": "efterdömlig",
    "efterdömlige": "efterdömlig",
    "efterdömliges": "efterdömlig",
    "efterdömligheten": "efterdömlighet",
    "efterdömlighetens": "efterdömlighet",
    "efterdömlighets": "efterdömlighet",
    "efterdömligs": "efterdömlig",
    "efterdömligt": "efterdömlig",
    "efterdömligts": "efterdömlig",
    "efterfesten": "efterfest",
    "efterfestens": "efterfest",
    "efterfester": "efterfest",
    "efterfesterna": "efterfest",
    "efterfesternas": "efterfest",
    "efterfesters": "efterfest",
    "efterfests": "efterfest",
    "efterforsk": "efterforska",
    "efterforskad": "efterforska",
    "efterforskade": "efterforska",
    "efterforskades": "efterforska",
    "efterforskads": "efterforska",
    "efterforskande": "efterforska",
    "efterforskanden": "efterforskande",
    "efterforskandena": "efterforskande",
    "efterforskandenas": "efterforskande",
    "efterforskandens": "efterforskande",
    "efterforskandes": "efterforskande",
    "efterforskandet": "efterforskande",
    "efterforskandets": "efterforskande",
    "efterforskar": "efterforska",
    "efterforskas": "efterforska",
    "efterforskat": "efterforska",
    "efterforskats": "efterforska",
    "efterforskningar": "efterforskning",
    "efterforskningarna": "efterforskning",
    "efterforskningarnas": "efterforskning",
    "efterforskningars": "efterforskning",
    "efterforskningen": "efterforskning",
    "efterforskningens": "efterforskning",
    "efterforsknings": "efterforskning",
    "efterfråg": "efterfråga",
    "efterfrågad": "efterfråga",
    "efterfrågade": "efterfrågad",
    "efterfrågades": "efterfrågad",
    "efterfrågads": "efterfrågad",
    "efterfrågande": "efterfråga",
    "efterfråganden": "efterfrågande",
    "efterfrågandena": "efterfrågande",
    "efterfrågandenas": "efterfrågande",
    "efterfrågandens": "efterfrågande",
    "efterfrågandes": "efterfrågande",
    "efterfrågandet": "efterfrågande",
    "efterfrågandets": "efterfrågande",
    "efterfrågans": "efterfrågan",
    "efterfrågar": "efterfråga",
    "efterfrågas": "efterfråga",
    "efterfrågat": "efterfrågad",
    "efterfrågats": "efterfrågad",
    "efterfrågningar": "efterfrågning",
    "efterfrågningarna": "efterfrågning",
    "efterfrågningarnas": "efterfrågning",
    "efterfrågningars": "efterfrågning",
    "efterfrågningen": "efterfrågning",
    "efterfrågningens": "efterfrågning",
    "efterfrågnings": "efterfrågning",
    "efterfölj": "efterfölja",
    "efterföljande": "efterfölja",
    "efterföljanden": "efterföljande",
    "efterföljandena": "efterföljande",
    "efterföljandenas": "efterföljande",
    "efterföljandens": "efterföljande",
    "efterföljandes": "efterföljande",
    "efterföljandet": "efterföljande",
    "efterföljandets": "efterföljande",
    "efterföljansvärda": "efterföljansvärd",
    "efterföljansvärdare": "efterföljansvärd",
    "efterföljansvärdares": "efterföljansvärd",
    "efterföljansvärdas": "efterföljansvärd",
    "efterföljansvärdast": "efterföljansvärd",
    "efterföljansvärdaste": "efterföljansvärd",
    "efterföljansvärdastes": "efterföljansvärd",
    "efterföljansvärdasts": "efterföljansvärd",
    "efterföljansvärde": "efterföljansvärd",
    "efterföljansvärdes": "efterföljansvärd",
    "efterföljansvärds": "efterföljansvärd",
    "efterföljansvärt": "efterföljansvärd",
    "efterföljansvärts": "efterföljansvärd",
    "efterföljar": "efterföljare",
    "efterföljaren": "efterföljare",
    "efterföljarens": "efterföljare",
    "efterföljares": "efterföljare",
    "efterföljarna": "efterföljare",
    "efterföljarnas": "efterföljare",
    "efterföljas": "efterfölja",
    "efterföljd": "efterfölja",
    "efterföljda": "efterfölja",
    "efterföljdas": "efterfölja",
    "efterföljde": "efterfölja",
    "efterföljden": "efterföljd",
    "efterföljdens": "efterföljd",
    "efterföljdes": "efterfölja",
    "efterföljds": "efterföljd",
    "efterföljelsen": "efterföljelse",
    "efterföljelsens": "efterföljelse",
    "efterföljelser": "efterföljelse",
    "efterföljelserna": "efterföljelse",
    "efterföljelsernas": "efterföljelse",
    "efterföljelsers": "efterföljelse",
    "efterföljelses": "efterföljelse",
    "efterföljer": "efterfölja",
    "efterföljes": "efterfölja",
    "efterföljs": "efterfölja",
    "efterföljt": "efterfölja",
    "efterföljts": "efterfölja",
    "eftergav": "efterge",
    "eftergavs": "efterge",
    "eftergeende": "efterge",
    "eftergeendes": "efterge",
    "efterger": "efterge",
    "efterges": "efterge",
    "eftergett": "efterge",
    "eftergetts": "efterge",
    "eftergiften": "eftergift",
    "eftergiftens": "eftergift",
    "eftergifter": "eftergift",
    "eftergifterna": "eftergift",
    "eftergifternas": "eftergift",
    "eftergifters": "eftergift",
    "eftergifts": "eftergift",
    "eftergiv": "efterge",
    "eftergiva": "efterge",
    "eftergivande": "efterge",
    "eftergivanden": "eftergivande",
    "eftergivandena": "eftergivande",
    "eftergivandenas": "eftergivande",
    "eftergivandens": "eftergivande",
    "eftergivandes": "eftergivande",
    "eftergivandet": "eftergivande",
    "eftergivandets": "eftergivande",
    "eftergivas": "efterge",
    "eftergive": "efterge",
    "eftergiven": "efterge",
    "eftergivenheten": "eftergivenhet",
    "eftergivenhetens": "eftergivenhet",
    "eftergivenheter": "eftergivenhet",
    "eftergivenheterna": "eftergivenhet",
    "eftergivenheternas": "eftergivenhet",
    "eftergivenheters": "eftergivenhet",
    "eftergivenhets": "eftergivenhet",
    "eftergivens": "eftergiven",
    "eftergiver": "efterge",
    "eftergives": "efterge",
    "eftergivet": "eftergiven",
    "eftergivets": "eftergiven",
    "eftergivit": "efterge",
    "eftergivits": "efterge",
    "eftergivliga": "eftergivlig",
    "eftergivligare": "eftergivlig",
    "eftergivligares": "eftergivlig",
    "eftergivligas": "eftergivlig",
    "eftergivligast": "eftergivlig",
    "eftergivligaste": "eftergivlig",
    "eftergivligastes": "eftergivlig",
    "eftergivligasts": "eftergivlig",
    "eftergivlige": "eftergivlig",
    "eftergivliges": "eftergivlig",
    "eftergivligheten": "eftergivlighet",
    "eftergivlighetens": "eftergivlighet",
    "eftergivlighets": "eftergivlighet",
    "eftergivligs": "eftergivlig",
    "eftergivligt": "eftergivlig",
    "eftergivligts": "eftergivlig",
    "eftergivna": "eftergiven",
    "eftergivnare": "eftergiven",
    "eftergivnares": "eftergiven",
    "eftergivnas": "eftergiven",
    "eftergivnast": "eftergiven",
    "eftergivnaste": "eftergiven",
    "eftergivnastes": "eftergiven",
    "eftergivnasts": "eftergiven",
    "eftergivne": "eftergiven",
    "eftergivnes": "eftergiven",
    "eftergivs": "efterge",
    "eftergjord": "eftergöra",
    "eftergjorda": "eftergöra",
    "eftergjordare": "eftergjord",
    "eftergjordares": "eftergjord",
    "eftergjordas": "eftergöra",
    "eftergjordast": "eftergjord",
    "eftergjordaste": "eftergjord",
    "eftergjordastes": "eftergjord",
    "eftergjordasts": "eftergjord",
    "eftergjorde": "eftergöra",
    "eftergjordes": "eftergöra",
    "eftergjords": "eftergöra",
    "eftergjort": "eftergöra",
    "eftergjorts": "eftergöra",
    "efterglansen": "efterglans",
    "efterglansens": "efterglans",
    "eftergranskningar": "eftergranskning",
    "eftergranskningarna": "eftergranskning",
    "eftergranskningarnas": "eftergranskning",
    "eftergranskningars": "eftergranskning",
    "eftergranskningen": "eftergranskning",
    "eftergranskningens": "eftergranskning",
    "eftergransknings": "eftergranskning",
    "eftergymnasiala": "eftergymnasial",
    "eftergymnasialare": "eftergymnasial",
    "eftergymnasialares": "eftergymnasial",
    "eftergymnasialas": "eftergymnasial",
    "eftergymnasialast": "eftergymnasial",
    "eftergymnasialaste": "eftergymnasial",
    "eftergymnasialastes": "eftergymnasial",
    "eftergymnasialasts": "eftergymnasial",
    "eftergymnasiale": "eftergymnasial",
    "eftergymnasiales": "eftergymnasial",
    "eftergymnasials": "eftergymnasial",
    "eftergymnasialt": "eftergymnasial",
    "eftergymnasialts": "eftergymnasial",
    "eftergåve": "efterge",
    "eftergåves": "efterge",
    "eftergör": "eftergöra",
    "eftergörande": "eftergöra",
    "eftergöranden": "eftergörande",
    "eftergörandena": "eftergörande",
    "eftergörandenas": "eftergörande",
    "eftergörandens": "eftergörande",
    "eftergörandes": "eftergörande",
    "eftergörandet": "eftergörande",
    "eftergörandets": "eftergörande",
    "eftergöras": "eftergöra",
    "eftergöres": "eftergöra",
    "eftergörs": "eftergöra",
    "efterhanden": "efterhand",
    "efterhandens": "efterhand",
    "efterhands": "efterhand",
    "efterhandskonstruktionen": "efterhandskonstruktion",
    "efterhandskonstruktionens": "efterhandskonstruktion",
    "efterhandskonstruktioner": "efterhandskonstruktion",
    "efterhandskonstruktionerna": "efterhandskonstruktion",
    "efterhandskonstruktionernas": "efterhandskonstruktion",
    "efterhandskonstruktioners": "efterhandskonstruktion",
    "efterhandskonstruktions": "efterhandskonstruktion",
    "efterhängsenheten": "efterhängsenhet",
    "efterhängsenhetens": "efterhängsenhet",
    "efterhängsenhets": "efterhängsenhet",
    "efterhängsens": "efterhängsen",
    "efterhängset": "efterhängsen",
    "efterhängsets": "efterhängsen",
    "efterhängsna": "efterhängsen",
    "efterhängsnare": "efterhängsen",
    "efterhängsnares": "efterhängsen",
    "efterhängsnas": "efterhängsen",
    "efterhängsnast": "efterhängsen",
    "efterhängsnaste": "efterhängsen",
    "efterhängsnastes": "efterhängsen",
    "efterhängsnasts": "efterhängsen",
    "efterhängsne": "efterhängsen",
    "efterhängsnes": "efterhängsen",
    "efterhärm": "efterhärma",
    "efterhärmad": "efterhärma",
    "efterhärmade": "efterhärma",
    "efterhärmades": "efterhärma",
    "efterhärmads": "efterhärma",
    "efterhärmande": "efterhärma",
    "efterhärmanden": "efterhärmande",
    "efterhärmandena": "efterhärmande",
    "efterhärmandenas": "efterhärmande",
    "efterhärmandens": "efterhärmande",
    "efterhärmandes": "efterhärmande",
    "efterhärmandet": "efterhärmande",
    "efterhärmandets": "efterhärmande",
    "efterhärmar": "efterhärma",
    "efterhärmas": "efterhärma",
    "efterhärmat": "efterhärma",
    "efterhärmats": "efterhärma",
    "efterhärmningar": "efterhärmning",
    "efterhärmningarna": "efterhärmning",
    "efterhärmningarnas": "efterhärmning",
    "efterhärmningars": "efterhärmning",
    "efterhärmningen": "efterhärmning",
    "efterhärmningens": "efterhärmning",
    "efterhärmnings": "efterhärmning",
    "efterhåll": "efterhålla",
    "efterhållande": "efterhålla",
    "efterhållanden": "efterhållande",
    "efterhållandena": "efterhållande",
    "efterhållandenas": "efterhållande",
    "efterhållandens": "efterhållande",
    "efterhållandes": "efterhållande",
    "efterhållandet": "efterhållande",
    "efterhållandets": "efterhållande",
    "efterhållas": "efterhålla",
    "efterhålle": "efterhålla",
    "efterhållen": "efterhålla",
    "efterhållens": "efterhålla",
    "efterhåller": "efterhålla",
    "efterhålles": "efterhålla",
    "efterhållet": "efterhålla",
    "efterhållets": "efterhålla",
    "efterhållit": "efterhålla",
    "efterhållits": "efterhålla",
    "efterhållna": "efterhålla",
    "efterhållnas": "efterhålla",
    "efterhållne": "efterhålla",
    "efterhållnes": "efterhålla",
    "efterhålls": "efterhålla",
    "efterhöll": "efterhålla",
    "efterhölle": "efterhålla",
    "efterhölles": "efterhålla",
    "efterhölls": "efterhålla",
    "efterhör": "efterhöra",
    "efterhörande": "efterhöra",
    "efterhöranden": "efterhörande",
    "efterhörandena": "efterhörande",
    "efterhörandenas": "efterhörande",
    "efterhörandens": "efterhörande",
    "efterhörandes": "efterhörande",
    "efterhörandet": "efterhörande",
    "efterhörandets": "efterhörande",
    "efterhöras": "efterhöra",
    "efterhörd": "efterhöra",
    "efterhörda": "efterhöra",
    "efterhördas": "efterhöra",
    "efterhörde": "efterhöra",
    "efterhördes": "efterhöra",
    "efterhörds": "efterhöra",
    "efterhöres": "efterhöra",
    "efterhörs": "efterhöra",
    "efterhört": "efterhöra",
    "efterhörts": "efterhöra",
    "efterhöstar": "efterhöst",
    "efterhöstarna": "efterhöst",
    "efterhöstarnas": "efterhöst",
    "efterhöstars": "efterhöst",
    "efterhösten": "efterhöst",
    "efterhöstens": "efterhöst",
    "efterhösts": "efterhöst",
    "efterjäsningar": "efterjäsning",
    "efterjäsningarna": "efterjäsning",
    "efterjäsningarnas": "efterjäsning",
    "efterjäsningars": "efterjäsning",
    "efterjäsningen": "efterjäsning",
    "efterjäsningens": "efterjäsning",
    "efterjäsnings": "efterjäsning",
    "efterklangen": "efterklang",
    "efterklangens": "efterklang",
    "efterklanger": "efterklang",
    "efterklangerna": "efterklang",
    "efterklangernas": "efterklang",
    "efterklangers": "efterklang",
    "efterklangs": "efterklang",
    "efterkloka": "efterklok",
    "efterklokare": "efterklok",
    "efterklokares": "efterklok",
    "efterklokas": "efterklok",
    "efterklokast": "efterklok",
    "efterklokaste": "efterklok",
    "efterklokastes": "efterklok",
    "efterklokasts": "efterklok",
    "efterkloke": "efterklok",
    "efterklokes": "efterklok",
    "efterklokheten": "efterklokhet",
    "efterklokhetens": "efterklokhet",
    "efterklokhets": "efterklokhet",
    "efterkloks": "efterklok",
    "efterklokt": "efterklok",
    "efterklokts": "efterklok",
    "efterkokningar": "efterkokning",
    "efterkokningarna": "efterkokning",
    "efterkokningarnas": "efterkokning",
    "efterkokningars": "efterkokning",
    "efterkokningen": "efterkokning",
    "efterkokningens": "efterkokning",
    "efterkoknings": "efterkokning",
    "efterkom": "efterkomma",
    "efterkomet": "efterkomma",
    "efterkomets": "efterkomma",
    "efterkommande": "efterkomma",
    "efterkommanden": "efterkommande",
    "efterkommandena": "efterkommande",
    "efterkommandenas": "efterkommande",
    "efterkommandens": "efterkommande",
    "efterkommandes": "efterkommande",
    "efterkommandet": "efterkommande",
    "efterkommandets": "efterkommande",
    "efterkommas": "efterkomma",
    "efterkomme": "efterkomma",
    "efterkommen": "efterkomma",
    "efterkommens": "efterkomma",
    "efterkommer": "efterkomma",
    "efterkommes": "efterkomma",
    "efterkommit": "efterkomma",
    "efterkommits": "efterkomma",
    "efterkomna": "efterkomma",
    "efterkomnas": "efterkomma",
    "efterkomne": "efterkomma",
    "efterkomnes": "efterkomma",
    "efterkoms": "efterkomma",
    "efterkonstruktionen": "efterkonstruktion",
    "efterkonstruktionens": "efterkonstruktion",
    "efterkonstruktioner": "efterkonstruktion",
    "efterkonstruktionerna": "efterkonstruktion",
    "efterkonstruktionernas": "efterkonstruktion",
    "efterkonstruktioners": "efterkonstruktion",
    "efterkonstruktions": "efterkonstruktion",
    "efterkontrollen": "efterkontroll",
    "efterkontrollens": "efterkontroll",
    "efterkontroller": "efterkontroll",
    "efterkontrollerna": "efterkontroll",
    "efterkontrollernas": "efterkontroll",
    "efterkontrollers": "efterkontroll",
    "efterkontrolls": "efterkontroll",
    "efterkraven": "efterkrav",
    "efterkravens": "efterkrav",
    "efterkravet": "efterkrav",
    "efterkravets": "efterkrav",
    "efterkravs": "efterkrav",
    "efterkrigsdecennie": "efterkrigsdecennium",
    "efterkrigsdecennier": "efterkrigsdecennium",
    "efterkrigsdecennierna": "efterkrigsdecennium",
    "efterkrigsdecenniernas": "efterkrigsdecennium",
    "efterkrigsdecenniers": "efterkrigsdecennium",
    "efterkrigsdecenniet": "efterkrigsdecennium",
    "efterkrigsdecenniets": "efterkrigsdecennium",
    "efterkrigsdecenniums": "efterkrigsdecennium",
    "efterkrigstiden": "efterkrigstid",
    "efterkrigstidens": "efterkrigstid",
    "efterkrigstider": "efterkrigstid",
    "efterkrigstiderna": "efterkrigstid",
    "efterkrigstidernas": "efterkrigstid",
    "efterkrigstiders": "efterkrigstid",
    "efterkrigstids": "efterkrigstid",
    "efterkulturen": "efterkultur",
    "efterkulturens": "efterkultur",
    "efterkulturs": "efterkultur",
    "efterkänningar": "efterkänning",
    "efterkänningarna": "efterkänning",
    "efterkänningarnas": "efterkänning",
    "efterkänningars": "efterkänning",
    "efterkänningen": "efterkänning",
    "efterkänningens": "efterkänning",
    "efterkännings": "efterkänning",
    "efterleden": "efterled",
    "efterledens": "efterled",
    "efterleder": "efterled",
    "efterlederna": "efterled",
    "efterledernas": "efterled",
    "efterleders": "efterled",
    "efterledet": "efterled",
    "efterledets": "efterled",
    "efterleds": "efterled",
    "efterlev": "efterleva",
    "efterlevande": "efterleva",
    "efterlevanden": "efterlevande",
    "efterlevandena": "efterlevande",
    "efterlevandenas": "efterlevande",
    "efterlevandens": "efterlevande",
    "efterlevandes": "efterlevande",
    "efterlevandet": "efterlevande",
    "efterlevandets": "efterlevande",
    "efterlevas": "efterleva",
    "efterlevat": "efterleva",
    "efterlevats": "efterleva",
    "efterlevd": "efterleva",
    "efterlevda": "efterleva",
    "efterlevdas": "efterleva",
    "efterlevde": "efterleva",
    "efterlevdes": "efterleva",
    "efterlevds": "efterleva",
    "efterlever": "efterleva",
    "efterleverskan": "efterleverska",
    "efterleverskans": "efterleverska",
    "efterleverskas": "efterleverska",
    "efterleverske": "efterleverska",
    "efterleverskor": "efterleverska",
    "efterleverskorna": "efterleverska",
    "efterleverskornas": "efterleverska",
    "efterleverskors": "efterleverska",
    "efterleves": "efterleva",
    "efterlevnaden": "efterlevnad",
    "efterlevnadens": "efterlevnad",
    "efterlevnader": "efterlevnad",
    "efterlevnaderna": "efterlevnad",
    "efterlevnadernas": "efterlevnad",
    "efterlevnaders": "efterlevnad",
    "efterlevnads": "efterlevnad",
    "efterlevs": "efterleva",
    "efterlevt": "efterleva",
    "efterlevts": "efterleva",
    "efterlikn": "efterlikna",
    "efterliknad": "efterlikna",
    "efterliknade": "efterlikna",
    "efterliknades": "efterlikna",
    "efterliknads": "efterlikna",
    "efterliknande": "efterlikna",
    "efterliknanden": "efterliknande",
    "efterliknandena": "efterliknande",
    "efterliknandenas": "efterliknande",
    "efterliknandens": "efterliknande",
    "efterliknandes": "efterliknande",
    "efterliknandet": "efterliknande",
    "efterliknandets": "efterliknande",
    "efterliknar": "efterlikna",
    "efterliknas": "efterlikna",
    "efterliknat": "efterlikna",
    "efterliknats": "efterlikna",
    "efterlys": "efterlysa",
    "efterlysande": "efterlysa",
    "efterlysanden": "efterlysande",
    "efterlysandena": "efterlysande",
    "efterlysandenas": "efterlysande",
    "efterlysandens": "efterlysande",
    "efterlysandes": "efterlysande",
    "efterlysandet": "efterlysande",
    "efterlysandets": "efterlysande",
    "efterlysas": "efterlysa",
    "efterlyser": "efterlysa",
    "efterlyses": "efterlysa",
    "efterlysningar": "efterlysning",
    "efterlysningarna": "efterlysning",
    "efterlysningarnas": "efterlysning",
    "efterlysningars": "efterlysning",
    "efterlysningen": "efterlysning",
    "efterlysningens": "efterlysning",
    "efterlysnings": "efterlysning",
    "efterlyst": "efterlysa",
    "efterlysta": "efterlysa",
    "efterlystas": "efterlysa",
    "efterlyste": "efterlysa",
    "efterlystes": "efterlysa",
    "efterlysts": "efterlysa",
    "efterlämn": "efterlämna",
    "efterlämnad": "efterlämna",
    "efterlämnade": "efterlämna",
    "efterlämnades": "efterlämna",
    "efterlämnads": "efterlämna",
    "efterlämnande": "efterlämna",
    "efterlämnanden": "efterlämnande",
    "efterlämnandena": "efterlämnande",
    "efterlämnandenas": "efterlämnande",
    "efterlämnandens": "efterlämnande",
    "efterlämnandes": "efterlämnande",
    "efterlämnandet": "efterlämnande",
    "efterlämnandets": "efterlämnande",
    "efterlämnar": "efterlämna",
    "efterlämnas": "efterlämna",
    "efterlämnat": "efterlämna",
    "efterlämnats": "efterlämna",
    "efterlängtade": "efterlängtad",
    "efterlängtades": "efterlängtad",
    "efterlängtads": "efterlängtad",
    "efterlängtat": "efterlängtad",
    "efterlängtats": "efterlängtad",
    "efterlät": "efterlåta",
    "efterläts": "efterlåta",
    "efterlåt": "efterlåta",
    "efterlåtande": "efterlåta",
    "efterlåtanden": "efterlåtande",
    "efterlåtandena": "efterlåtande",
    "efterlåtandenas": "efterlåtande",
    "efterlåtandens": "efterlåtande",
    "efterlåtandes": "efterlåtande",
    "efterlåtandet": "efterlåtande",
    "efterlåtandets": "efterlåtande",
    "efterlåtas": "efterlåta",
    "efterlåte": "efterlåta",
    "efterlåten": "efterlåta",
    "efterlåtenheten": "efterlåtenhet",
    "efterlåtenhetens": "efterlåtenhet",
    "efterlåtenhets": "efterlåtenhet",
    "efterlåtens": "efterlåten",
    "efterlåter": "efterlåta",
    "efterlåtes": "efterlåta",
    "efterlåtet": "efterlåten",
    "efterlåtets": "efterlåten",
    "efterlåtit": "efterlåta",
    "efterlåtits": "efterlåta",
    "efterlåtna": "efterlåten",
    "efterlåtnare": "efterlåten",
    "efterlåtnares": "efterlåten",
    "efterlåtnas": "efterlåten",
    "efterlåtnast": "efterlåten",
    "efterlåtnaste": "efterlåten",
    "efterlåtnastes": "efterlåten",
    "efterlåtnasts": "efterlåten",
    "efterlåtne": "efterlåten",
    "efterlåtnes": "efterlåten",
    "efterlåts": "efterlåta",
    "eftermassagen": "eftermassage",
    "eftermassagens": "eftermassage",
    "eftermassages": "eftermassage",
    "eftermiddagar": "eftermiddag",
    "eftermiddagarna": "eftermiddag",
    "eftermiddagarnas": "eftermiddag",
    "eftermiddagars": "eftermiddag",
    "eftermiddagen": "eftermiddag",
    "eftermiddagens": "eftermiddag",
    "eftermiddags": "eftermiddag",
    "eftermiddagsjobben": "eftermiddagsjobb",
    "eftermiddagsjobbens": "eftermiddagsjobb",
    "eftermiddagsjobbet": "eftermiddagsjobb",
    "eftermiddagsjobbets": "eftermiddagsjobb",
    "eftermiddagsjobbs": "eftermiddagsjobb",
    "eftermiddagslurar": "eftermiddagslur",
    "eftermiddagslurarna": "eftermiddagslur",
    "eftermiddagslurarnas": "eftermiddagslur",
    "eftermiddagslurars": "eftermiddagslur",
    "eftermiddagsluren": "eftermiddagslur",
    "eftermiddagslurens": "eftermiddagslur",
    "eftermiddagslurs": "eftermiddagslur",
    "eftermiddagsrusningar": "eftermiddagsrusning",
    "eftermiddagsrusningarna": "eftermiddagsrusning",
    "eftermiddagsrusningarnas": "eftermiddagsrusning",
    "eftermiddagsrusningars": "eftermiddagsrusning",
    "eftermiddagsrusningen": "eftermiddagsrusning",
    "eftermiddagsrusningens": "eftermiddagsrusning",
    "eftermiddagsrusnings": "eftermiddagsrusning",
    "eftermiddagstim": "eftermiddagstimme",
    "eftermiddagstimmar": "eftermiddagstimme",
    "eftermiddagstimmarna": "eftermiddagstimme",
    "eftermiddagstimmarnas": "eftermiddagstimme",
    "eftermiddagstimmars": "eftermiddagstimme",
    "eftermiddagstimmen": "eftermiddagstimme",
    "eftermiddagstimmens": "eftermiddagstimme",
    "eftermiddagstimmes": "eftermiddagstimme",
    "eftermiddagstims": "eftermiddagstimme",
    "eftermognad": "eftermogna",
    "eftermognade": "eftermogna",
    "eftermognades": "eftermogna",
    "eftermognads": "eftermogna",
    "eftermognande": "eftermogna",
    "eftermognanden": "eftermognande",
    "eftermognandena": "eftermognande",
    "eftermognandenas": "eftermognande",
    "eftermognandens": "eftermognande",
    "eftermognandes": "eftermognande",
    "eftermognandet": "eftermognande",
    "eftermognandets": "eftermognande",
    "eftermognar": "eftermogna",
    "eftermognas": "eftermogna",
    "eftermognat": "eftermogna",
    "eftermognats": "eftermogna",
    "eftermälen": "eftermäle",
    "eftermälena": "eftermäle",
    "eftermälenas": "eftermäle",
    "eftermälens": "eftermäle",
    "eftermäles": "eftermäle",
    "eftermälet": "eftermäle",
    "eftermälets": "eftermäle",
    "efternamnen": "efternamn",
    "efternamnens": "efternamn",
    "efternamnet": "efternamn",
    "efternamnets": "efternamn",
    "efternamns": "efternamn",
    "efternatten": "efternatt",
    "efternattens": "efternatt",
    "efternatts": "efternatt",
    "efterorden": "efterord",
    "efterordens": "efterord",
    "efterordet": "efterord",
    "efterordets": "efterord",
    "efterords": "efterord",
    "efterplocket": "efterplock",
    "efterplockets": "efterplock",
    "efterplocks": "efterplock",
    "efterprövningar": "efterprövning",
    "efterprövningarna": "efterprövning",
    "efterprövningarnas": "efterprövning",
    "efterprövningars": "efterprövning",
    "efterprövningen": "efterprövning",
    "efterprövningens": "efterprövning",
    "efterprövnings": "efterprövning",
    "efterputsen": "efterputs",
    "efterputsens": "efterputs",
    "efterrationaliserad": "efterrationalisera",
    "efterrationaliserade": "efterrationalisera",
    "efterrationaliserades": "efterrationalisera",
    "efterrationaliserads": "efterrationalisera",
    "efterrationaliserande": "efterrationalisera",
    "efterrationaliseranden": "efterrationaliserande",
    "efterrationaliserandena": "efterrationaliserande",
    "efterrationaliserandenas": "efterrationaliserande",
    "efterrationaliserandens": "efterrationaliserande",
    "efterrationaliserandes": "efterrationaliserande",
    "efterrationaliserandet": "efterrationaliserande",
    "efterrationaliserandets": "efterrationaliserande",
    "efterrationaliserar": "efterrationalisera",
    "efterrationaliseras": "efterrationalisera",
    "efterrationaliserat": "efterrationalisera",
    "efterrationaliserats": "efterrationalisera",
    "efterrationaliserbara": "efterrationaliserbar",
    "efterrationaliserbarare": "efterrationaliserbar",
    "efterrationaliserbarares": "efterrationaliserbar",
    "efterrationaliserbaras": "efterrationaliserbar",
    "efterrationaliserbarast": "efterrationaliserbar",
    "efterrationaliserbaraste": "efterrationaliserbar",
    "efterrationaliserbarastes": "efterrationaliserbar",
    "efterrationaliserbarasts": "efterrationaliserbar",
    "efterrationaliserbare": "efterrationaliserbar",
    "efterrationaliserbares": "efterrationaliserbar",
    "efterrationaliserbarheten": "efterrationaliserbarhet",
    "efterrationaliserbarhetens": "efterrationaliserbarhet",
    "efterrationaliserbarhets": "efterrationaliserbarhet",
    "efterrationaliserbars": "efterrationaliserbar",
    "efterrationaliserbart": "efterrationaliserbar",
    "efterrationaliserbarts": "efterrationaliserbar",
    "efterrationaliseringar": "efterrationalisering",
    "efterrationaliseringarna": "efterrationalisering",
    "efterrationaliseringarnas": "efterrationalisering",
    "efterrationaliseringars": "efterrationalisering",
    "efterrationaliseringen": "efterrationalisering",
    "efterrationaliseringens": "efterrationalisering",
    "efterrationaliserings": "efterrationalisering",
    "efterräkningar": "efterräkning",
    "efterräkningarna": "efterräkning",
    "efterräkningarnas": "efterräkning",
    "efterräkningars": "efterräkning",
    "efterräkningen": "efterräkning",
    "efterräkningens": "efterräkning",
    "efterräknings": "efterräkning",
    "efterrättelsen": "efterrättelse",
    "efterrättelsens": "efterrättelse",
    "efterrättelses": "efterrättelse",
    "efterrätten": "efterrätt",
    "efterrättens": "efterrätt",
    "efterrätter": "efterrätt",
    "efterrätterna": "efterrätt",
    "efterrätternas": "efterrätt",
    "efterrätters": "efterrätt",
    "efterrätts": "efterrätt",
    "efterrättssopp": "efterrättssoppa",
    "efterrättssoppan": "efterrättssoppa",
    "efterrättssoppans": "efterrättssoppa",
    "efterrättssoppas": "efterrättssoppa",
    "efterrättssoppe": "efterrättssoppa",
    "efterrättssoppor": "efterrättssoppa",
    "efterrättssopporna": "efterrättssoppa",
    "efterrättssoppornas": "efterrättssoppa",
    "efterrättssoppors": "efterrättssoppa",
    "efterrättssopps": "efterrättssoppa",
    "eftersa": "eftersäga",
    "eftersade": "eftersäga",
    "eftersades": "eftersäga",
    "eftersagd": "eftersäga",
    "eftersagda": "eftersäga",
    "eftersagdas": "eftersäga",
    "eftersagde": "eftersäga",
    "eftersagdes": "eftersäga",
    "eftersagds": "eftersäga",
    "eftersagt": "eftersäga",
    "eftersagts": "eftersäga",
    "eftersaknade": "eftersaknad",
    "eftersaknaden": "eftersaknad",
    "eftersaknadens": "eftersaknad",
    "eftersaknades": "eftersaknad",
    "eftersaknads": "eftersaknad",
    "eftersaknat": "eftersaknad",
    "eftersaknats": "eftersaknad",
    "eftersas": "eftersäga",
    "eftersatsen": "eftersats",
    "eftersatsens": "eftersats",
    "eftersatser": "eftersats",
    "eftersatserna": "eftersats",
    "eftersatsernas": "eftersats",
    "eftersatsers": "eftersats",
    "eftersatt": "eftersätta",
    "eftersatta": "eftersätta",
    "eftersattas": "eftersätta",
    "eftersatte": "eftersätta",
    "eftersattes": "eftersätta",
    "eftersatts": "eftersätta",
    "eftersedd": "efterse",
    "eftersedda": "efterse",
    "efterseddas": "efterse",
    "eftersedde": "efterse",
    "efterseddes": "efterse",
    "eftersedds": "efterse",
    "efterseende": "efterse",
    "efterseenden": "efterseende",
    "efterseendena": "efterseende",
    "efterseendenas": "efterseende",
    "efterseendens": "efterseende",
    "efterseendes": "efterseende",
    "efterseendet": "efterseende",
    "efterseendets": "efterseende",
    "efterser": "efterse",
    "efterses": "efterse",
    "eftersett": "efterse",
    "eftersetts": "efterse",
    "eftersinnade": "eftersinna",
    "eftersinnades": "eftersinna",
    "eftersinnande": "eftersinna",
    "eftersinnanden": "eftersinnande",
    "eftersinnandena": "eftersinnande",
    "eftersinnandenas": "eftersinnande",
    "eftersinnandens": "eftersinnande",
    "eftersinnandes": "eftersinnande",
    "eftersinnandet": "eftersinnande",
    "eftersinnandets": "eftersinnande",
    "eftersinnar": "eftersinna",
    "eftersinnas": "eftersinna",
    "eftersinnat": "eftersinna",
    "eftersinnats": "eftersinna",
    "eftersitsar": "eftersits",
    "eftersitsarna": "eftersits",
    "eftersitsarnas": "eftersits",
    "eftersitsars": "eftersits",
    "eftersitsen": "eftersits",
    "eftersitsens": "eftersits",
    "efterskotten": "efterskott",
    "efterskottens": "efterskott",
    "efterskottet": "efterskott",
    "efterskottets": "efterskott",
    "efterskotts": "efterskott",
    "efterskriften": "efterskrift",
    "efterskriftens": "efterskrift",
    "efterskrifter": "efterskrift",
    "efterskrifterna": "efterskrift",
    "efterskrifternas": "efterskrift",
    "efterskrifters": "efterskrift",
    "efterskrifts": "efterskrift",
    "efterskänk": "efterskänka",
    "efterskänkande": "efterskänka",
    "efterskänkanden": "efterskänkande",
    "efterskänkandena": "efterskänkande",
    "efterskänkandenas": "efterskänkande",
    "efterskänkandens": "efterskänkande",
    "efterskänkandes": "efterskänkande",
    "efterskänkandet": "efterskänkande",
    "efterskänkandets": "efterskänkande",
    "efterskänkas": "efterskänka",
    "efterskänker": "efterskänka",
    "efterskänkes": "efterskänka",
    "efterskänks": "efterskänka",
    "efterskänkt": "efterskänka",
    "efterskänkta": "efterskänka",
    "efterskänktas": "efterskänka",
    "efterskänkte": "efterskänka",
    "efterskänktes": "efterskänka",
    "efterskänkts": "efterskänka",
    "efterskörden": "efterskörd",
    "efterskördens": "efterskörd",
    "efterskörds": "efterskörd",
    "efterslagen": "efterslag",
    "efterslagens": "efterslag",
    "efterslaget": "efterslag",
    "efterslagets": "efterslag",
    "efterslags": "efterslag",
    "eftersläckningar": "eftersläckning",
    "eftersläckningarna": "eftersläckning",
    "eftersläckningarnas": "eftersläckning",
    "eftersläckningars": "eftersläckning",
    "eftersläckningen": "eftersläckning",
    "eftersläckningens": "eftersläckning",
    "eftersläcknings": "eftersläckning",
    "efterslängar": "eftersläng",
    "efterslängarna": "eftersläng",
    "efterslängarnas": "eftersläng",
    "efterslängars": "eftersläng",
    "efterslängen": "eftersläng",
    "efterslängens": "eftersläng",
    "efterslängs": "eftersläng",
    "eftersläntrar": "eftersläntrare",
    "eftersläntraren": "eftersläntrare",
    "eftersläntrarens": "eftersläntrare",
    "eftersläntrares": "eftersläntrare",
    "eftersläntrarna": "eftersläntrare",
    "eftersläntrarnas": "eftersläntrare",
    "eftersläpningar": "eftersläpning",
    "eftersläpningarna": "eftersläpning",
    "eftersläpningarnas": "eftersläpning",
    "eftersläpningars": "eftersläpning",
    "eftersläpningen": "eftersläpning",
    "eftersläpningens": "eftersläpning",
    "eftersläpnings": "eftersläpning",
    "eftersmaken": "eftersmak",
    "eftersmakens": "eftersmak",
    "eftersmaks": "eftersmak",
    "eftersnacket": "eftersnack",
    "eftersnackets": "eftersnack",
    "eftersnacks": "eftersnack",
    "eftersommaren": "eftersommar",
    "eftersommarens": "eftersommar",
    "eftersommarn": "eftersommar",
    "eftersommarns": "eftersommar",
    "eftersommars": "eftersommar",
    "eftersomrar": "eftersommar",
    "eftersomrarna": "eftersommar",
    "eftersomrarnas": "eftersommar",
    "eftersomrars": "eftersommar",
    "efterspanade": "efterspanad",
    "efterspanades": "efterspanad",
    "efterspanads": "efterspanad",
    "efterspanat": "efterspanad",
    "efterspanats": "efterspanad",
    "efterspaningar": "efterspaning",
    "efterspaningarna": "efterspaning",
    "efterspaningarnas": "efterspaning",
    "efterspaningars": "efterspaning",
    "efterspaningen": "efterspaning",
    "efterspaningens": "efterspaning",
    "efterspanings": "efterspaning",
    "efterspelen": "efterspel",
    "efterspelens": "efterspel",
    "efterspelet": "efterspel",
    "efterspelets": "efterspel",
    "efterspels": "efterspel",
    "efterstavad": "efterstava",
    "efterstavade": "efterstava",
    "efterstavades": "efterstava",
    "efterstavads": "efterstava",
    "efterstavande": "efterstava",
    "efterstavanden": "efterstavande",
    "efterstavandena": "efterstavande",
    "efterstavandenas": "efterstavande",
    "efterstavandens": "efterstavande",
    "efterstavandes": "efterstavande",
    "efterstavandet": "efterstavande",
    "efterstavandets": "efterstavande",
    "efterstavar": "efterstava",
    "efterstavas": "efterstava",
    "efterstavat": "efterstava",
    "efterstavats": "efterstava",
    "eftersträv": "eftersträva",
    "eftersträvad": "eftersträva",
    "eftersträvade": "eftersträva",
    "eftersträvades": "eftersträva",
    "eftersträvads": "eftersträva",
    "eftersträvande": "eftersträva",
    "eftersträvanden": "eftersträvande",
    "eftersträvandena": "eftersträvande",
    "eftersträvandenas": "eftersträvande",
    "eftersträvandens": "eftersträvande",
    "eftersträvandes": "eftersträvande",
    "eftersträvandet": "eftersträvande",
    "eftersträvandets": "eftersträvande",
    "eftersträvansvärda": "eftersträvansvärd",
    "eftersträvansvärdare": "eftersträvansvärd",
    "eftersträvansvärdares": "eftersträvansvärd",
    "eftersträvansvärdas": "eftersträvansvärd",
    "eftersträvansvärdast": "eftersträvansvärd",
    "eftersträvansvärdaste": "eftersträvansvärd",
    "eftersträvansvärdastes": "eftersträvansvärd",
    "eftersträvansvärdasts": "eftersträvansvärd",
    "eftersträvansvärde": "eftersträvansvärd",
    "eftersträvansvärdes": "eftersträvansvärd",
    "eftersträvansvärdheten": "eftersträvansvärdhet",
    "eftersträvansvärdhetens": "eftersträvansvärdhet",
    "eftersträvansvärdhets": "eftersträvansvärdhet",
    "eftersträvansvärds": "eftersträvansvärd",
    "eftersträvansvärt": "eftersträvansvärd",
    "eftersträvansvärts": "eftersträvansvärd",
    "eftersträvar": "eftersträva",
    "eftersträvas": "eftersträva",
    "eftersträvat": "eftersträva",
    "eftersträvats": "eftersträva",
    "efterstygnen": "efterstygn",
    "efterstygnens": "efterstygn",
    "efterstygnet": "efterstygn",
    "efterstygnets": "efterstygn",
    "efterstygns": "efterstygn",
    "efterställda": "efterställd",
    "efterställdare": "efterställd",
    "efterställdares": "efterställd",
    "efterställdas": "efterställd",
    "efterställdast": "efterställd",
    "efterställdaste": "efterställd",
    "efterställdastes": "efterställd",
    "efterställdasts": "efterställd",
    "efterställde": "efterställd",
    "efterställdes": "efterställd",
    "efterställds": "efterställd",
    "efterställt": "efterställd",
    "efterställts": "efterställd",
    "eftersynen": "eftersyn",
    "eftersynens": "eftersyn",
    "eftersynkroniserad": "eftersynkronisera",
    "eftersynkroniserade": "eftersynkronisera",
    "eftersynkroniserades": "eftersynkronisera",
    "eftersynkroniserads": "eftersynkronisera",
    "eftersynkroniserande": "eftersynkronisera",
    "eftersynkroniseranden": "eftersynkroniserande",
    "eftersynkroniserandena": "eftersynkroniserande",
    "eftersynkroniserandenas": "eftersynkroniserande",
    "eftersynkroniserandens": "eftersynkroniserande",
    "eftersynkroniserandes": "eftersynkroniserande",
    "eftersynkroniserandet": "eftersynkroniserande",
    "eftersynkroniserandets": "eftersynkroniserande",
    "eftersynkroniserar": "eftersynkronisera",
    "eftersynkroniseras": "eftersynkronisera",
    "eftersynkroniserat": "eftersynkronisera",
    "eftersynkroniserats": "eftersynkronisera",
    "eftersynkroniserbara": "eftersynkroniserbar",
    "eftersynkroniserbarare": "eftersynkroniserbar",
    "eftersynkroniserbarares": "eftersynkroniserbar",
    "eftersynkroniserbaras": "eftersynkroniserbar",
    "eftersynkroniserbarast": "eftersynkroniserbar",
    "eftersynkroniserbaraste": "eftersynkroniserbar",
    "eftersynkroniserbarastes": "eftersynkroniserbar",
    "eftersynkroniserbarasts": "eftersynkroniserbar",
    "eftersynkroniserbare": "eftersynkroniserbar",
    "eftersynkroniserbares": "eftersynkroniserbar",
    "eftersynkroniserbarheten": "eftersynkroniserbarhet",
    "eftersynkroniserbarhetens": "eftersynkroniserbarhet",
    "eftersynkroniserbarhets": "eftersynkroniserbarhet",
    "eftersynkroniserbars": "eftersynkroniserbar",
    "eftersynkroniserbart": "eftersynkroniserbar",
    "eftersynkroniserbarts": "eftersynkroniserbar",
    "eftersynkroniseringar": "eftersynkronisering",
    "eftersynkroniseringarna": "eftersynkronisering",
    "eftersynkroniseringarnas": "eftersynkronisering",
    "eftersynkroniseringars": "eftersynkronisering",
    "eftersynkroniseringen": "eftersynkronisering",
    "eftersynkroniseringens": "eftersynkronisering",
    "eftersynkroniserings": "eftersynkronisering",
    "eftersyns": "eftersyn",
    "eftersäg": "eftersäga",
    "eftersägande": "eftersäga",
    "eftersäganden": "eftersägande",
    "eftersägandena": "eftersägande",
    "eftersägandenas": "eftersägande",
    "eftersägandens": "eftersägande",
    "eftersägandes": "eftersägande",
    "eftersägandet": "eftersägande",
    "eftersägandets": "eftersägande",
    "eftersägar": "eftersägare",
    "eftersägaren": "eftersägare",
    "eftersägarens": "eftersägare",
    "eftersägares": "eftersägare",
    "eftersägarna": "eftersägare",
    "eftersägarnas": "eftersägare",
    "eftersägas": "eftersäga",
    "eftersäger": "eftersäga",
    "eftersäges": "eftersäga",
    "eftersägs": "eftersäga",
    "eftersäj": "eftersäga",
    "eftersäja": "eftersäga",
    "eftersäjande": "eftersäga",
    "eftersäjandes": "eftersäga",
    "eftersäjas": "eftersäga",
    "eftersäjer": "eftersäga",
    "eftersäjes": "eftersäga",
    "eftersäjs": "eftersäga",
    "eftersänd": "eftersända",
    "eftersändande": "eftersända",
    "eftersändanden": "eftersändande",
    "eftersändandena": "eftersändande",
    "eftersändandenas": "eftersändande",
    "eftersändandens": "eftersändande",
    "eftersändandes": "eftersändande",
    "eftersändandet": "eftersändande",
    "eftersändandets": "eftersändande",
    "eftersändas": "eftersända",
    "eftersände": "eftersända",
    "eftersänder": "eftersända",
    "eftersändes": "eftersända",
    "eftersänds": "eftersända",
    "eftersänt": "eftersända",
    "eftersänts": "eftersända",
    "eftersätt": "eftersätta",
    "eftersättande": "eftersätta",
    "eftersättanden": "eftersättande",
    "eftersättandena": "eftersättande",
    "eftersättandenas": "eftersättande",
    "eftersättandens": "eftersättande",
    "eftersättandes": "eftersättande",
    "eftersättandet": "eftersättande",
    "eftersättandets": "eftersättande",
    "eftersättas": "eftersätta",
    "eftersätter": "eftersätta",
    "eftersättes": "eftersätta",
    "eftersätts": "eftersätta",
    "eftersättsbladen": "eftersättsblad",
    "eftersättsbladens": "eftersättsblad",
    "eftersättsbladet": "eftersättsblad",
    "eftersättsbladets": "eftersättsblad",
    "eftersättsblads": "eftersättsblad",
    "eftersåg": "efterse",
    "eftersåge": "efterse",
    "eftersåges": "efterse",
    "eftersågs": "efterse",
    "eftersök": "eftersöka",
    "eftersökande": "eftersöka",
    "eftersökanden": "eftersökande",
    "eftersökandena": "eftersökande",
    "eftersökandenas": "eftersökande",
    "eftersökandens": "eftersökande",
    "eftersökandes": "eftersökande",
    "eftersökandet": "eftersökande",
    "eftersökandets": "eftersökande",
    "eftersökas": "eftersöka",
    "eftersöker": "eftersöka",
    "eftersökes": "eftersöka",
    "eftersöket": "eftersök",
    "eftersökets": "eftersök",
    "eftersöks": "eftersöka",
    "eftersökt": "eftersöka",
    "eftersökta": "eftersökt",
    "eftersöktare": "eftersökt",
    "eftersöktares": "eftersökt",
    "eftersöktas": "eftersökt",
    "eftersöktast": "eftersökt",
    "eftersöktaste": "eftersökt",
    "eftersöktastes": "eftersökt",
    "eftersöktasts": "eftersökt",
    "eftersökte": "eftersökt",
    "eftersöktes": "eftersökt",
    "eftersöktheten": "eftersökthet",
    "eftersökthetens": "eftersökthet",
    "eftersökthets": "eftersökthet",
    "eftersökts": "eftersökt",
    "eftertanken": "eftertanke",
    "eftertankens": "eftertanke",
    "eftertankes": "eftertanke",
    "eftertaxerad": "eftertaxera",
    "eftertaxerade": "eftertaxera",
    "eftertaxerades": "eftertaxera",
    "eftertaxerads": "eftertaxera",
    "eftertaxerande": "eftertaxera",
    "eftertaxeranden": "eftertaxerande",
    "eftertaxerandena": "eftertaxerande",
    "eftertaxerandenas": "eftertaxerande",
    "eftertaxerandens": "eftertaxerande",
    "eftertaxerandes": "eftertaxerande",
    "eftertaxerandet": "eftertaxerande",
    "eftertaxerandets": "eftertaxerande",
    "eftertaxerar": "eftertaxera",
    "eftertaxeras": "eftertaxera",
    "eftertaxerat": "eftertaxera",
    "eftertaxerats": "eftertaxera",
    "eftertaxerbara": "eftertaxerbar",
    "eftertaxerbarare": "eftertaxerbar",
    "eftertaxerbarares": "eftertaxerbar",
    "eftertaxerbaras": "eftertaxerbar",
    "eftertaxerbarast": "eftertaxerbar",
    "eftertaxerbaraste": "eftertaxerbar",
    "eftertaxerbarastes": "eftertaxerbar",
    "eftertaxerbarasts": "eftertaxerbar",
    "eftertaxerbare": "eftertaxerbar",
    "eftertaxerbares": "eftertaxerbar",
    "eftertaxerbarheten": "eftertaxerbarhet",
    "eftertaxerbarhetens": "eftertaxerbarhet",
    "eftertaxerbarhets": "eftertaxerbarhet",
    "eftertaxerbars": "eftertaxerbar",
    "eftertaxerbart": "eftertaxerbar",
    "eftertaxerbarts": "eftertaxerbar",
    "eftertaxeringar": "eftertaxering",
    "eftertaxeringarna": "eftertaxering",
    "eftertaxeringarnas": "eftertaxering",
    "eftertaxeringars": "eftertaxering",
    "eftertaxeringen": "eftertaxering",
    "eftertaxeringens": "eftertaxering",
    "eftertaxerings": "eftertaxering",
    "eftertextnoten": "eftertextnot",
    "eftertextnotens": "eftertextnot",
    "eftertextnoter": "eftertextnot",
    "eftertextnoterna": "eftertextnot",
    "eftertextnoternas": "eftertextnot",
    "eftertextnoters": "eftertextnot",
    "eftertextnots": "eftertextnot",
    "eftertorkningen": "eftertorkning",
    "eftertorkningens": "eftertorkning",
    "eftertorknings": "eftertorkning",
    "eftertrakt": "eftertrakta",
    "eftertraktad": "eftertrakta",
    "eftertraktade": "eftertrakta",
    "eftertraktades": "eftertrakta",
    "eftertraktads": "eftertrakta",
    "eftertraktande": "eftertrakta",
    "eftertraktanden": "eftertraktande",
    "eftertraktandena": "eftertraktande",
    "eftertraktandenas": "eftertraktande",
    "eftertraktandens": "eftertraktande",
    "eftertraktandes": "eftertraktande",
    "eftertraktandet": "eftertraktande",
    "eftertraktandets": "eftertraktande",
    "eftertraktansvärda": "eftertraktansvärd",
    "eftertraktansvärdare": "eftertraktansvärd",
    "eftertraktansvärdares": "eftertraktansvärd",
    "eftertraktansvärdas": "eftertraktansvärd",
    "eftertraktansvärdast": "eftertraktansvärd",
    "eftertraktansvärdaste": "eftertraktansvärd",
    "eftertraktansvärdastes": "eftertraktansvärd",
    "eftertraktansvärdasts": "eftertraktansvärd",
    "eftertraktansvärde": "eftertraktansvärd",
    "eftertraktansvärdes": "eftertraktansvärd",
    "eftertraktansvärdheten": "eftertraktansvärdhet",
    "eftertraktansvärdhetens": "eftertraktansvärdhet",
    "eftertraktansvärdhets": "eftertraktansvärdhet",
    "eftertraktansvärds": "eftertraktansvärd",
    "eftertraktansvärt": "eftertraktansvärd",
    "eftertraktansvärts": "eftertraktansvärd",
    "eftertraktar": "eftertrakta",
    "eftertraktas": "eftertrakta",
    "eftertraktat": "eftertrakta",
    "eftertraktats": "eftertrakta",
    "eftertravet": "eftertrav",
    "eftertravets": "eftertrav",
    "eftertravs": "eftertrav",
    "eftertruppen": "eftertrupp",
    "eftertruppens": "eftertrupp",
    "eftertrupper": "eftertrupp",
    "eftertrupperna": "eftertrupp",
    "eftertruppernas": "eftertrupp",
    "eftertruppers": "eftertrupp",
    "eftertrupps": "eftertrupp",
    "eftertrycken": "eftertryck",
    "eftertryckens": "eftertryck",
    "eftertrycket": "eftertryck",
    "eftertryckets": "eftertryck",
    "eftertryckliga": "eftertrycklig",
    "eftertryckligare": "eftertrycklig",
    "eftertryckligares": "eftertrycklig",
    "eftertryckligas": "eftertrycklig",
    "eftertryckligast": "eftertrycklig",
    "eftertryckligaste": "eftertrycklig",
    "eftertryckligastes": "eftertrycklig",
    "eftertryckligasts": "eftertrycklig",
    "eftertrycklige": "eftertrycklig",
    "eftertryckliges": "eftertrycklig",
    "eftertryckligheten": "eftertrycklighet",
    "eftertrycklighetens": "eftertrycklighet",
    "eftertrycklighets": "eftertrycklighet",
    "eftertryckligs": "eftertrycklig",
    "eftertryckligt": "eftertrycklig",
    "eftertryckligts": "eftertrycklig",
    "eftertrycks": "eftertryck",
    "efterträd": "efterträda",
    "efterträdande": "efterträda",
    "efterträdanden": "efterträdande",
    "efterträdandena": "efterträdande",
    "efterträdandenas": "efterträdande",
    "efterträdandens": "efterträdande",
    "efterträdandes": "efterträdande",
    "efterträdandet": "efterträdande",
    "efterträdandets": "efterträdande",
    "efterträdar": "efterträdare",
    "efterträdaren": "efterträdare",
    "efterträdarens": "efterträdare",
    "efterträdares": "efterträdare",
    "efterträdarkandidaten": "efterträdarkandidat",
    "efterträdarkandidatens": "efterträdarkandidat",
    "efterträdarkandidater": "efterträdarkandidat",
    "efterträdarkandidaterna": "efterträdarkandidat",
    "efterträdarkandidaternas": "efterträdarkandidat",
    "efterträdarkandidaters": "efterträdarkandidat",
    "efterträdarkandidats": "efterträdarkandidat",
    "efterträdarna": "efterträdare",
    "efterträdarnas": "efterträdare",
    "efterträdas": "efterträda",
    "efterträdd": "efterträda",
    "efterträdda": "efterträda",
    "efterträddas": "efterträda",
    "efterträdde": "efterträda",
    "efterträddes": "efterträda",
    "efterträdds": "efterträda",
    "efterträder": "efterträda",
    "efterträdes": "efterträda",
    "efterträds": "efterträda",
    "efterträtt": "efterträda",
    "efterträtts": "efterträda",
    "eftertrådd": "eftertrå",
    "eftertrådda": "eftertrå",
    "eftertråddas": "eftertrå",
    "eftertrådde": "eftertrå",
    "eftertråddes": "eftertrå",
    "eftertrådds": "eftertrå",
    "eftertrående": "eftertrå",
    "eftertråenden": "eftertrående",
    "eftertråendena": "eftertrående",
    "eftertråendenas": "eftertrående",
    "eftertråendens": "eftertrående",
    "eftertråendes": "eftertrående",
    "eftertråendet": "eftertrående",
    "eftertråendets": "eftertrående",
    "eftertrår": "eftertrå",
    "eftertrås": "eftertrå",
    "eftertrått": "eftertrå",
    "eftertråtts": "eftertrå",
    "eftertänksamheten": "eftertänksamhet",
    "eftertänksamhetens": "eftertänksamhet",
    "eftertänksamhets": "eftertänksamhet",
    "eftertänksamma": "eftertänksam",
    "eftertänksammare": "eftertänksam",
    "eftertänksammares": "eftertänksam",
    "eftertänksammas": "eftertänksam",
    "eftertänksammast": "eftertänksam",
    "eftertänksammaste": "eftertänksam",
    "eftertänksammastes": "eftertänksam",
    "eftertänksammasts": "eftertänksam",
    "eftertänksamme": "eftertänksam",
    "eftertänksammes": "eftertänksam",
    "eftertänksams": "eftertänksam",
    "eftertänksamt": "eftertänksam",
    "eftertänksamts": "eftertänksam",
    "efterundersökningar": "efterundersökning",
    "efterundersökningarna": "efterundersökning",
    "efterundersökningarnas": "efterundersökning",
    "efterundersökningars": "efterundersökning",
    "efterundersökningen": "efterundersökning",
    "efterundersökningens": "efterundersökning",
    "efterundersöknings": "efterundersökning",
    "efterutbildningar": "efterutbildning",
    "efterutbildningarna": "efterutbildning",
    "efterutbildningarnas": "efterutbildning",
    "efterutbildningars": "efterutbildning",
    "efterutbildningen": "efterutbildning",
    "efterutbildningens": "efterutbildning",
    "efterutbildnings": "efterutbildning",
    "eftervalsdebatten": "eftervalsdebatt",
    "eftervalsdebattens": "eftervalsdebatt",
    "eftervalsdebatter": "eftervalsdebatt",
    "eftervalsdebatterna": "eftervalsdebatt",
    "eftervalsdebatternas": "eftervalsdebatt",
    "eftervalsdebatters": "eftervalsdebatt",
    "eftervalsdebatts": "eftervalsdebatt",
    "efterverkans": "efterverkan",
    "efterverkningar": "efterverkning",
    "efterverkningarna": "efterverkning",
    "efterverkningarnas": "efterverkning",
    "efterverkningars": "efterverkning",
    "efterverkningen": "efterverkning",
    "efterverkningens": "efterverkning",
    "efterverknings": "efterverkning",
    "eftervintern": "eftervinter",
    "eftervinterns": "eftervinter",
    "eftervinters": "eftervinter",
    "eftervintrar": "eftervinter",
    "eftervintrarna": "eftervinter",
    "eftervintrarnas": "eftervinter",
    "eftervintrars": "eftervinter",
    "eftervisa": "eftervis",
    "eftervisare": "eftervis",
    "eftervisares": "eftervis",
    "eftervisas": "eftervis",
    "eftervisast": "eftervis",
    "eftervisaste": "eftervis",
    "eftervisastes": "eftervis",
    "eftervisasts": "eftervis",
    "eftervise": "eftervis",
    "eftervises": "eftervis",
    "eftervisheten": "eftervishet",
    "eftervishetens": "eftervishet",
    "eftervishets": "eftervishet",
    "eftervist": "eftervis",
    "eftervists": "eftervis",
    "eftervärkarna": "eftervärkar",
    "eftervärkarnas": "eftervärkar",
    "eftervärkars": "eftervärkar",
    "eftervärks": "eftervärkar",
    "eftervärlden": "eftervärld",
    "eftervärldens": "eftervärld",
    "eftervärlds": "eftervärld",
    "eftervärmen": "eftervärme",
    "eftervärmens": "eftervärme",
    "eftervärmes": "eftervärme",
    "efterväxten": "efterväxt",
    "efterväxtens": "efterväxt",
    "efterväxts": "efterväxt",
    "eftervården": "eftervård",
    "eftervårdens": "eftervård",
    "eftervårds": "eftervård",
    "egala": "egal",
    "egalare": "egal",
    "egalares": "egal",
    "egalas": "egal",
    "egalast": "egal",
    "egalaste": "egal",
    "egalastes": "egal",
    "egalasts": "egal",
    "egale": "egal",
    "egales": "egal",
    "egaliserad": "egalisera",
    "egaliserade": "egalisera",
    "egaliserades": "egalisera",
    "egaliserads": "egalisera",
    "egaliserande": "egalisera",
    "egaliseranden": "egaliserande",
    "egaliserandena": "egaliserande",
    "egaliserandenas": "egaliserande",
    "egaliserandens": "egaliserande",
    "egaliserandes": "egaliserande",
    "egaliserandet": "egaliserande",
    "egaliserandets": "egaliserande",
    "egaliserar": "egalisera",
    "egaliseras": "egalisera",
    "egaliserat": "egalisera",
    "egaliserats": "egalisera",
    "egaliserbara": "egaliserbar",
    "egaliserbarare": "egaliserbar",
    "egaliserbarares": "egaliserbar",
    "egaliserbaras": "egaliserbar",
    "egaliserbarast": "egaliserbar",
    "egaliserbaraste": "egaliserbar",
    "egaliserbarastes": "egaliserbar",
    "egaliserbarasts": "egaliserbar",
    "egaliserbare": "egaliserbar",
    "egaliserbares": "egaliserbar",
    "egaliserbarheten": "egaliserbarhet",
    "egaliserbarhetens": "egaliserbarhet",
    "egaliserbarhets": "egaliserbarhet",
    "egaliserbars": "egaliserbar",
    "egaliserbart": "egaliserbar",
    "egaliserbarts": "egaliserbar",
    "egaliseringar": "egalisering",
    "egaliseringarna": "egalisering",
    "egaliseringarnas": "egalisering",
    "egaliseringars": "egalisering",
    "egaliseringen": "egalisering",
    "egaliseringens": "egalisering",
    "egaliserings": "egalisering",
    "egaliteten": "egalitet",
    "egalitetens": "egalitet",
    "egaliteter": "egalitet",
    "egaliteterna": "egalitet",
    "egaliteternas": "egalitet",
    "egaliteters": "egalitet",
    "egalitets": "egalitet",
    "egalitära": "egalitär",
    "egalitärare": "egalitär",
    "egalitärares": "egalitär",
    "egalitäras": "egalitär",
    "egalitärast": "egalitär",
    "egalitäraste": "egalitär",
    "egalitärastes": "egalitär",
    "egalitärasts": "egalitär",
    "egalitäre": "egalitär",
    "egalitäres": "egalitär",
    "egalitärs": "egalitär",
    "egalitärt": "egalitär",
    "egalitärts": "egalitär",
    "egals": "egal",
    "egalt": "egal",
    "egalts": "egal",
    "egarden": "egard",
    "egardens": "egard",
    "egards": "egard",
    "egeiska": "egeisk",
    "egeiskare": "egeisk",
    "egeiskares": "egeisk",
    "egeiskas": "egeisk",
    "egeiskast": "egeisk",
    "egeiskaste": "egeisk",
    "egeiskastes": "egeisk",
    "egeiskasts": "egeisk",
    "egeiske": "egeisk",
    "egeiskes": "egeisk",
    "egeisks": "egeisk",
    "egeiskt": "egeisk",
    "egeiskts": "egeisk",
    "egenartade": "egenartad",
    "egenartades": "egenartad",
    "egenartads": "egenartad",
    "egenartat": "egenartad",
    "egenartats": "egenartad",
    "egenarten": "egenart",
    "egenartens": "egenart",
    "egenarts": "egenart",
    "egendomar": "egendom",
    "egendomarna": "egendom",
    "egendomarnas": "egendom",
    "egendomars": "egendom",
    "egendomen": "egendom",
    "egendomens": "egendom",
    "egendomliga": "egendomlig",
    "egendomligare": "egendomlig",
    "egendomligares": "egendomlig",
    "egendomligas": "egendomlig",
    "egendomligast": "egendomlig",
    "egendomligaste": "egendomlig",
    "egendomligastes": "egendomlig",
    "egendomligasts": "egendomlig",
    "egendomlige": "egendomlig",
    "egendomliges": "egendomlig",
    "egendomligheten": "egendomlighet",
    "egendomlighetens": "egendomlighet",
    "egendomligheter": "egendomlighet",
    "egendomligheterna": "egendomlighet",
    "egendomligheternas": "egendomlighet",
    "egendomligheters": "egendomlighet",
    "egendomlighets": "egendomlighet",
    "egendomligs": "egendomlig",
    "egendomligt": "egendomlig",
    "egendomligts": "egendomlig",
    "egendoms": "egendom",
    "egendomsaffären": "egendomsaffär",
    "egendomsaffärens": "egendomsaffär",
    "egendomsaffärer": "egendomsaffär",
    "egendomsaffärerna": "egendomsaffär",
    "egendomsaffärernas": "egendomsaffär",
    "egendomsaffärers": "egendomsaffär",
    "egendomsaffärs": "egendomsaffär",
    "egendomsbrotten": "egendomsbrott",
    "egendomsbrottens": "egendomsbrott",
    "egendomsbrottet": "egendomsbrott",
    "egendomsbrottets": "egendomsbrott",
    "egendomsbrotts": "egendomsbrott",
    "egendomsfolket": "egendomsfolk",
    "egendomsfolkets": "egendomsfolk",
    "egendomsfolks": "egendomsfolk",
    "egendomsförsäkringar": "egendomsförsäkring",
    "egendomsförsäkringarna": "egendomsförsäkring",
    "egendomsförsäkringarnas": "egendomsförsäkring",
    "egendomsförsäkringars": "egendomsförsäkring",
    "egendomsförsäkringen": "egendomsförsäkring",
    "egendomsförsäkringens": "egendomsförsäkring",
    "egendomsförsäkrings": "egendomsförsäkring",
    "egendomsförsäljningar": "egendomsförsäljning",
    "egendomsförsäljningarna": "egendomsförsäljning",
    "egendomsförsäljningarnas": "egendomsförsäljning",
    "egendomsförsäljningars": "egendomsförsäljning",
    "egendomsförsäljningen": "egendomsförsäljning",
    "egendomsförsäljningens": "egendomsförsäljning",
    "egendomsförsäljnings": "egendomsförsäljning",
    "egendomsgemenskapen": "egendomsgemenskap",
    "egendomsgemenskapens": "egendomsgemenskap",
    "egendomsgemenskaps": "egendomsgemenskap",
    "egendomslösa": "egendomslös",
    "egendomslösare": "egendomslös",
    "egendomslösares": "egendomslös",
    "egendomslösas": "egendomslös",
    "egendomslösast": "egendomslös",
    "egendomslösaste": "egendomslös",
    "egendomslösastes": "egendomslös",
    "egendomslösasts": "egendomslös",
    "egendomslöse": "egendomslös",
    "egendomslöses": "egendomslös",
    "egendomslösheten": "egendomslöshet",
    "egendomslöshetens": "egendomslöshet",
    "egendomslöshets": "egendomslöshet",
    "egendomslöst": "egendomslös",
    "egendomslösts": "egendomslös",
    "egenfrekvensen": "egenfrekvens",
    "egenfrekvensens": "egenfrekvens",
    "egenfrekvenser": "egenfrekvens",
    "egenfrekvenserna": "egenfrekvens",
    "egenfrekvensernas": "egenfrekvens",
    "egenfrekvensers": "egenfrekvens",
    "egenheten": "egenhet",
    "egenhetens": "egenhet",
    "egenheter": "egenhet",
    "egenheterna": "egenhet",
    "egenheternas": "egenhet",
    "egenheters": "egenhet",
    "egenhets": "egenhet",
    "egenhändiga": "egenhändig",
    "egenhändigare": "egenhändig",
    "egenhändigares": "egenhändig",
    "egenhändigas": "egenhändig",
    "egenhändigast": "egenhändig",
    "egenhändigaste": "egenhändig",
    "egenhändigastes": "egenhändig",
    "egenhändigasts": "egenhändig",
    "egenhändige": "egenhändig",
    "egenhändiges": "egenhändig",
    "egenhändigheten": "egenhändighet",
    "egenhändighetens": "egenhändighet",
    "egenhändighets": "egenhändighet",
    "egenhändigs": "egenhändig",
    "egenhändigt": "egenhändig",
    "egenhändigts": "egenhändig",
    "egenintressen": "egenintresse",
    "egenintressena": "egenintresse",
    "egenintressenas": "egenintresse",
    "egenintressens": "egenintresse",
    "egenintresses": "egenintresse",
    "egenintresset": "egenintresse",
    "egenintressets": "egenintresse",
    "egenkonstruerade": "egenkonstruerad",
    "egenkonstruerades": "egenkonstruerad",
    "egenkonstruerads": "egenkonstruerad",
    "egenkonstruerat": "egenkonstruerad",
    "egenkonstruerats": "egenkonstruerad",
    "egenkära": "egenkär",
    "egenkärare": "egenkär",
    "egenkärares": "egenkär",
    "egenkäras": "egenkär",
    "egenkärast": "egenkär",
    "egenkäraste": "egenkär",
    "egenkärastes": "egenkär",
    "egenkärasts": "egenkär",
    "egenkäre": "egenkär",
    "egenkäres": "egenkär",
    "egenkärlekar": "egenkärlek",
    "egenkärlekarna": "egenkärlek",
    "egenkärlekarnas": "egenkärlek",
    "egenkärlekars": "egenkärlek",
    "egenkärleken": "egenkärlek",
    "egenkärlekens": "egenkärlek",
    "egenkärleks": "egenkärlek",
    "egenkärs": "egenkär",
    "egenkärt": "egenkär",
    "egenkärts": "egenkär",
    "egenmäktiga": "egenmäktig",
    "egenmäktigare": "egenmäktig",
    "egenmäktigares": "egenmäktig",
    "egenmäktigas": "egenmäktig",
    "egenmäktigast": "egenmäktig",
    "egenmäktigaste": "egenmäktig",
    "egenmäktigastes": "egenmäktig",
    "egenmäktigasts": "egenmäktig",
    "egenmäktige": "egenmäktig",
    "egenmäktiges": "egenmäktig",
    "egenmäktigheten": "egenmäktighet",
    "egenmäktighetens": "egenmäktighet",
    "egenmäktighets": "egenmäktighet",
    "egenmäktigs": "egenmäktig",
    "egenmäktigt": "egenmäktig",
    "egenmäktigts": "egenmäktig",
    "egennamnen": "egennamn",
    "egennamnens": "egennamn",
    "egennamnet": "egennamn",
    "egennamnets": "egennamn",
    "egennamns": "egennamn",
    "egennyttan": "egennytta",
    "egennyttans": "egennytta",
    "egennyttas": "egennytta",
    "egennytte": "egennytta",
    "egennyttiga": "egennyttig",
    "egennyttigare": "egennyttig",
    "egennyttigares": "egennyttig",
    "egennyttigas": "egennyttig",
    "egennyttigast": "egennyttig",
    "egennyttigaste": "egennyttig",
    "egennyttigastes": "egennyttig",
    "egennyttigasts": "egennyttig",
    "egennyttige": "egennyttig",
    "egennyttiges": "egennyttig",
    "egennyttigheten": "egennyttighet",
    "egennyttighetens": "egennyttighet",
    "egennyttighets": "egennyttighet",
    "egennyttigs": "egennyttig",
    "egennyttigt": "egennyttig",
    "egennyttigts": "egennyttig",
    "egennytto": "egennytta",
    "egennyttor": "egennytta",
    "egennyttorna": "egennytta",
    "egennyttornas": "egennytta",
    "egennyttors": "egennytta",
    "egenodlade": "egenodlad",
    "egenodlades": "egenodlad",
    "egenodlads": "egenodlad",
    "egenodlat": "egenodlad",
    "egenodlats": "egenodlad",
    "egenrättfärdiga": "egenrättfärdig",
    "egenrättfärdigare": "egenrättfärdig",
    "egenrättfärdigares": "egenrättfärdig",
    "egenrättfärdigas": "egenrättfärdig",
    "egenrättfärdigast": "egenrättfärdig",
    "egenrättfärdigaste": "egenrättfärdig",
    "egenrättfärdigastes": "egenrättfärdig",
    "egenrättfärdigasts": "egenrättfärdig",
    "egenrättfärdige": "egenrättfärdig",
    "egenrättfärdiges": "egenrättfärdig",
    "egenrättfärdigheten": "egenrättfärdighet",
    "egenrättfärdighetens": "egenrättfärdighet",
    "egenrättfärdighets": "egenrättfärdighet",
    "egenrättfärdigs": "egenrättfärdig",
    "egenrättfärdigt": "egenrättfärdig",
    "egenrättfärdigts": "egenrättfärdig",
    "egenrådiga": "egenrådig",
    "egenrådigare": "egenrådig",
    "egenrådigares": "egenrådig",
    "egenrådigas": "egenrådig",
    "egenrådigast": "egenrådig",
    "egenrådigaste": "egenrådig",
    "egenrådigastes": "egenrådig",
    "egenrådigasts": "egenrådig",
    "egenrådige": "egenrådig",
    "egenrådiges": "egenrådig",
    "egenrådigheten": "egenrådighet",
    "egenrådighetens": "egenrådighet",
    "egenrådighets": "egenrådighet",
    "egenrådigs": "egenrådig",
    "egenrådigt": "egenrådig",
    "egenrådigts": "egenrådig",
    "egenrörelsen": "egenrörelse",
    "egenrörelsens": "egenrörelse",
    "egenrörelses": "egenrörelse",
    "egens": "egen",
    "egensinnes": "egensinne",
    "egensinnet": "egensinne",
    "egensinnets": "egensinne",
    "egensinniga": "egensinnig",
    "egensinnigare": "egensinnig",
    "egensinnigares": "egensinnig",
    "egensinnigas": "egensinnig",
    "egensinnigast": "egensinnig",
    "egensinnigaste": "egensinnig",
    "egensinnigastes": "egensinnig",
    "egensinnigasts": "egensinnig",
    "egensinnige": "egensinnig",
    "egensinniges": "egensinnig",
    "egensinnigheten": "egensinnighet",
    "egensinnighetens": "egensinnighet",
    "egensinnighets": "egensinnighet",
    "egensinnigs": "egensinnig",
    "egensinnigt": "egensinnig",
    "egensinnigts": "egensinnig",
    "egenskapen": "egenskap",
    "egenskapens": "egenskap",
    "egenskaper": "egenskap",
    "egenskaperna": "egenskap",
    "egenskapernas": "egenskap",
    "egenskapers": "egenskap",
    "egenskaps": "egenskap",
    "egenskapsgenitiven": "egenskapsgenitiv",
    "egenskapsgenitivens": "egenskapsgenitiv",
    "egenskapsgenitiver": "egenskapsgenitiv",
    "egenskapsgenitiverna": "egenskapsgenitiv",
    "egenskapsgenitivernas": "egenskapsgenitiv",
    "egenskapsgenitivers": "egenskapsgenitiv",
    "egenskapsgenitivs": "egenskapsgenitiv",
    "egenskapsorden": "egenskapsord",
    "egenskapsordens": "egenskapsord",
    "egenskapsordet": "egenskapsord",
    "egenskapsordets": "egenskapsord",
    "egenskapsords": "egenskapsord",
    "egensväng": "egensvänga",
    "egensvängande": "egensvänga",
    "egensvänganden": "egensvängande",
    "egensvängandena": "egensvängande",
    "egensvängandenas": "egensvängande",
    "egensvängandens": "egensvängande",
    "egensvängandes": "egensvängande",
    "egensvängandet": "egensvängande",
    "egensvängandets": "egensvängande",
    "egensvängde": "egensvänga",
    "egensvänger": "egensvänga",
    "egensvängningar": "egensvängning",
    "egensvängningarna": "egensvängning",
    "egensvängningarnas": "egensvängning",
    "egensvängningars": "egensvängning",
    "egensvängningen": "egensvängning",
    "egensvängningens": "egensvängning",
    "egensvängnings": "egensvängning",
    "egensvängt": "egensvänga",
    "egentillverkade": "egentillverkad",
    "egentillverkades": "egentillverkad",
    "egentillverkads": "egentillverkad",
    "egentillverkat": "egentillverkad",
    "egentillverkats": "egentillverkad",
    "egentliga": "egentlig",
    "egentligare": "egentlig",
    "egentligares": "egentlig",
    "egentligas": "egentlig",
    "egentligast": "egentlig",
    "egentligaste": "egentlig",
    "egentligastes": "egentlig",
    "egentligasts": "egentlig",
    "egentlige": "egentlig",
    "egentliges": "egentlig",
    "egentligs": "egentlig",
    "egentligt": "egentlig",
    "egentligts": "egentlig",
    "egenvarma": "egenvarm",
    "egenvarmare": "egenvarm",
    "egenvarmares": "egenvarm",
    "egenvarmas": "egenvarm",
    "egenvarmast": "egenvarm",
    "egenvarmaste": "egenvarm",
    "egenvarmastes": "egenvarm",
    "egenvarmasts": "egenvarm",
    "egenvarme": "egenvarm",
    "egenvarmes": "egenvarm",
    "egenvarms": "egenvarm",
    "egenvarmt": "egenvarm",
    "egenvarmts": "egenvarm",
    "egenvärdes": "egenvärde",
    "egenvärdet": "egenvärde",
    "egenvärdets": "egenvärde",
    "eget": "egen",
    "egets": "egen",
    "egg": "egga",
    "eggad": "egga",
    "eggade": "egga",
    "eggades": "egga",
    "eggads": "egga",
    "eggande": "egga",
    "egganden": "eggande",
    "eggandena": "eggande",
    "eggandenas": "eggande",
    "eggandens": "eggande",
    "eggandes": "eggande",
    "eggandet": "eggande",
    "eggandets": "eggande",
    "eggar": "egga",
    "eggarna": "egg",
    "eggarnas": "egg",
    "eggars": "egg",
    "eggas": "egga",
    "eggat": "egga",
    "eggats": "egga",
    "eggelsen": "eggelse",
    "eggelsens": "eggelse",
    "eggelser": "eggelse",
    "eggelserna": "eggelse",
    "eggelsernas": "eggelse",
    "eggelsers": "eggelse",
    "eggelses": "eggelse",
    "eggen": "egg",
    "eggens": "egg",
    "eggjärnen": "eggjärn",
    "eggjärnens": "eggjärn",
    "eggjärnet": "eggjärn",
    "eggjärnets": "eggjärn",
    "eggjärns": "eggjärn",
    "eggs": "egg",
    "eggvassa": "eggvass",
    "eggvassare": "eggvass",
    "eggvassares": "eggvass",
    "eggvassas": "eggvass",
    "eggvassast": "eggvass",
    "eggvassaste": "eggvass",
    "eggvassastes": "eggvass",
    "eggvassasts": "eggvass",
    "eggvasse": "eggvass",
    "eggvasses": "eggvass",
    "eggvasst": "eggvass",
    "eggvassts": "eggvass",
    "eggverktygen": "eggverktyg",
    "eggverktygens": "eggverktyg",
    "eggverktyget": "eggverktyg",
    "eggverktygets": "eggverktyg",
    "eggverktygs": "eggverktyg",
    "egiden": "egid",
    "egidens": "egid",
    "egids": "egid",
    "egna": "egen",
    "egnahemmen": "egnahem",
    "egnahemmens": "egnahem",
    "egnahemmet": "egnahem",
    "egnahemmets": "egnahem",
    "egnahems": "egnahem",
    "egnare": "egen",
    "egnares": "egen",
    "egnas": "egen",
    "egnast": "egen",
    "egnaste": "egen",
    "egnastes": "egen",
    "egnasts": "egen",
    "egne": "egen",
    "egnes": "egen",
    "egocentriciteten": "egocentricitet",
    "egocentricitetens": "egocentricitet",
    "egocentriciteter": "egocentricitet",
    "egocentriciteterna": "egocentricitet",
    "egocentriciteternas": "egocentricitet",
    "egocentriciteters": "egocentricitet",
    "egocentricitets": "egocentricitet",
    "egocentrikern": "egocentriker",
    "egocentrikerna": "egocentriker",
    "egocentrikernas": "egocentriker",
    "egocentrikerns": "egocentriker",
    "egocentrikers": "egocentriker",
    "egocentriska": "egocentrisk",
    "egocentriskare": "egocentrisk",
    "egocentriskares": "egocentrisk",
    "egocentriskas": "egocentrisk",
    "egocentriskast": "egocentrisk",
    "egocentriskaste": "egocentrisk",
    "egocentriskastes": "egocentrisk",
    "egocentriskasts": "egocentrisk",
    "egocentriske": "egocentrisk",
    "egocentriskes": "egocentrisk",
    "egocentrisks": "egocentrisk",
    "egocentriskt": "egocentrisk",
    "egocentriskts": "egocentrisk",
    "egoismen": "egoism",
    "egoismens": "egoism",
    "egoismer": "egoism",
    "egoismerna": "egoism",
    "egoismernas": "egoism",
    "egoismers": "egoism",
    "egoisms": "egoism",
    "egoisten": "egoist",
    "egoistens": "egoist",
    "egoister": "egoist",
    "egoisterna": "egoist",
    "egoisternas": "egoist",
    "egoisters": "egoist",
    "egoistiska": "egoistisk",
    "egoistiskare": "egoistisk",
    "egoistiskares": "egoistisk",
    "egoistiskas": "egoistisk",
    "egoistiskast": "egoistisk",
    "egoistiskaste": "egoistisk",
    "egoistiskastes": "egoistisk",
    "egoistiskasts": "egoistisk",
    "egoistiske": "egoistisk",
    "egoistiskes": "egoistisk",
    "egoistisks": "egoistisk",
    "egoistiskt": "egoistisk",
    "egoistiskts": "egoistisk",
    "egoists": "egoist",
    "egos": "ego",
    "egot": "ego",
    "egotismen": "egotism",
    "egotismens": "egotism",
    "egotismer": "egotism",
    "egotismerna": "egotism",
    "egotismernas": "egotism",
    "egotismers": "egotism",
    "egotisms": "egotism",
    "egotrippade": "egotrippad",
    "egotrippades": "egotrippad",
    "egotrippads": "egotrippad",
    "egotrippar": "egotripp",
    "egotripparna": "egotripp",
    "egotripparnas": "egotripp",
    "egotrippars": "egotripp",
    "egotrippat": "egotrippad",
    "egotrippats": "egotrippad",
    "egotrippen": "egotripp",
    "egotrippens": "egotripp",
    "egotripper": "egotripp",
    "egotripperna": "egotripp",
    "egotrippernas": "egotripp",
    "egotrippers": "egotripp",
    "egotripps": "egotripp",
    "egots": "ego",
    "egyptern": "egypter",
    "egypterna": "egypter",
    "egypternas": "egypter",
    "egypterns": "egypter",
    "egypters": "egypter",
    "egyptiennes": "egyptienne",
    "egyptiern": "egyptier",
    "egyptierna": "egyptier",
    "egyptiernas": "egyptier",
    "egyptierns": "egyptier",
    "egyptiers": "egyptier",
    "egyptisk": "egyptiska",
    "egyptiska": "egyptisk",
    "egyptiskan": "egyptiska",
    "egyptiskans": "egyptiska",
    "egyptiskare": "egyptisk",
    "egyptiskares": "egyptisk",
    "egyptiskas": "egyptiska",
    "egyptiskast": "egyptisk",
    "egyptiskaste": "egyptisk",
    "egyptiskastes": "egyptisk",
    "egyptiskasts": "egyptisk",
    "egyptiske": "egyptiska",
    "egyptiskes": "egyptisk",
    "egyptiskor": "egyptiska",
    "egyptiskorna": "egyptiska",
    "egyptiskornas": "egyptiska",
    "egyptiskors": "egyptiska",
    "egyptisks": "egyptisk",
    "egyptiskt": "egyptisk",
    "egyptiskts": "egyptisk",
    "egyptologen": "egyptolog",
    "egyptologens": "egyptolog",
    "egyptologer": "egyptolog",
    "egyptologerna": "egyptolog",
    "egyptologernas": "egyptolog",
    "egyptologers": "egyptolog",
    "egyptologien": "egyptologi",
    "egyptologiens": "egyptologi",
    "egyptologin": "egyptologi",
    "egyptologins": "egyptologi",
    "egyptologis": "egyptologi",
    "egyptologs": "egyptolog",
    "ehurudadan": "ehurudan",
    "ehurudadana": "ehurudan",
    "ehurudadanas": "ehurudan",
    "ehurudadans": "ehurudan",
    "ehurudadant": "ehurudan",
    "ehurudadants": "ehurudan",
    "ehurudana": "ehurudan",
    "ehurudanas": "ehurudan",
    "ehurudans": "ehurudan",
    "ehurudant": "ehurudan",
    "ehurudants": "ehurudan",
    "eidetiken": "eidetik",
    "eidetikens": "eidetik",
    "eidetiks": "eidetik",
    "eidetiska": "eidetisk",
    "eidetiskare": "eidetisk",
    "eidetiskares": "eidetisk",
    "eidetiskas": "eidetisk",
    "eidetiskast": "eidetisk",
    "eidetiskaste": "eidetisk",
    "eidetiskastes": "eidetisk",
    "eidetiskasts": "eidetisk",
    "eidetiske": "eidetisk",
    "eidetiskes": "eidetisk",
    "eidetisks": "eidetisk",
    "eidetiskt": "eidetisk",
    "eidetiskts": "eidetisk",
    "einherjarna": "einherjar",
    "einherjarnas": "einherjar",
    "einherjars": "einherjar",
    "einsteiniet": "einsteinium",
    "einsteiniets": "einsteinium",
    "einsteiniumet": "einsteinium",
    "einsteiniumets": "einsteinium",
    "einsteiniums": "einsteinium",
    "einsteinska": "einsteinsk",
    "einsteinskare": "einsteinsk",
    "einsteinskares": "einsteinsk",
    "einsteinskas": "einsteinsk",
    "einsteinskast": "einsteinsk",
    "einsteinskaste": "einsteinsk",
    "einsteinskastes": "einsteinsk",
    "einsteinskasts": "einsteinsk",
    "einsteinske": "einsteinsk",
    "einsteinskes": "einsteinsk",
    "einsteinsks": "einsteinsk",
    "einsteinskt": "einsteinsk",
    "einsteinskts": "einsteinsk",
    "ejakulaten": "ejakulat",
    "ejakulatens": "ejakulat",
    "ejakulatet": "ejakulat",
    "ejakulatets": "ejakulat",
    "ejakulationen": "ejakulation",
    "ejakulationens": "ejakulation",
    "ejakulationer": "ejakulation",
    "ejakulationerna": "ejakulation",
    "ejakulationernas": "ejakulation",
    "ejakulationers": "ejakulation",
    "ejakulations": "ejakulation",
    "ejakulats": "ejakulat",
    "ejakulerade": "ejakulera",
    "ejakulerades": "ejakulera",
    "ejakulerande": "ejakulera",
    "ejakuleranden": "ejakulerande",
    "ejakulerandena": "ejakulerande",
    "ejakulerandenas": "ejakulerande",
    "ejakulerandens": "ejakulerande",
    "ejakulerandes": "ejakulerande",
    "ejakulerandet": "ejakulerande",
    "ejakulerandets": "ejakulerande",
    "ejakulerar": "ejakulera",
    "ejakuleras": "ejakulera",
    "ejakulerat": "ejakulera",
    "ejakulerats": "ejakulera",
    "ejakuleringar": "ejakulering",
    "ejakuleringarna": "ejakulering",
    "ejakuleringarnas": "ejakulering",
    "ejakuleringars": "ejakulering",
    "ejakuleringen": "ejakulering",
    "ejakuleringens": "ejakulering",
    "ejakulerings": "ejakulering",
    "ejderdunen": "ejderdun",
    "ejderdunens": "ejderdun",
    "ejderdunet": "ejderdun",
    "ejderdunets": "ejderdun",
    "ejderduns": "ejderdun",
    "ejderhon": "ejderhona",
    "ejderhonan": "ejderhona",
    "ejderhonans": "ejderhona",
    "ejderhonas": "ejderhona",
    "ejderhone": "ejderhona",
    "ejderhonor": "ejderhona",
    "ejderhonorna": "ejderhona",
    "ejderhonornas": "ejderhona",
    "ejderhonors": "ejderhona",
    "ejderhons": "ejderhona",
    "ejdern": "ejder",
    "ejderns": "ejder",
    "ejders": "ejder",
    "ejderungar": "ejderunge",
    "ejderungarna": "ejderunge",
    "ejderungarnas": "ejderunge",
    "ejderungars": "ejderunge",
    "ejderungen": "ejderunge",
    "ejderungens": "ejderunge",
    "ejderunges": "ejderunge",
    "ejdrar": "ejder",
    "ejdrarna": "ejder",
    "ejdrarnas": "ejder",
    "ejdrars": "ejder",
    "ejektorer": "ejektor",
    "ejektorerna": "ejektor",
    "ejektorernas": "ejektor",
    "ejektorers": "ejektor",
    "ejektorn": "ejektor",
    "ejektorns": "ejektor",
    "ejektors": "ejektor",
    "ek": "eka",
    "ekad": "eka",
    "ekade": "eka",
    "ekades": "eka",
    "ekads": "eka",
    "ekan": "eka",
    "ekande": "eka",
    "ekanden": "ekande",
    "ekandena": "ekande",
    "ekandenas": "ekande",
    "ekandens": "ekande",
    "ekandes": "ekande",
    "ekandet": "ekande",
    "ekandets": "ekande",
    "ekans": "eka",
    "ekar": "eka",
    "ekarna": "ek",
    "ekarnas": "ek",
    "ekars": "ek",
    "ekartén": "ekarté",
    "ekarténs": "ekarté",
    "ekartés": "ekarté",
    "ekas": "eka",
    "ekat": "eka",
    "ekats": "eka",
    "ekback": "ekbacke",
    "ekbackar": "ekbacke",
    "ekbackarna": "ekbacke",
    "ekbackarnas": "ekbacke",
    "ekbackars": "ekbacke",
    "ekbacken": "ekbacke",
    "ekbackens": "ekbacke",
    "ekbackes": "ekbacke",
    "ekbacks": "ekbacke",
    "ekbockar": "ekbock",
    "ekbockarna": "ekbock",
    "ekbockarnas": "ekbock",
    "ekbockars": "ekbock",
    "ekbocken": "ekbock",
    "ekbockens": "ekbock",
    "ekbocks": "ekbock",
    "ekdörrar": "ekdörr",
    "ekdörrarna": "ekdörr",
    "ekdörrarnas": "ekdörr",
    "ekdörrars": "ekdörr",
    "ekdörren": "ekdörr",
    "ekdörrens": "ekdörr",
    "ekdörrs": "ekdörr",
    "eke": "eka",
    "eken": "ek",
    "ekens": "ek",
    "ekern": "eker",
    "ekerns": "eker",
    "ekers": "eker",
    "ekes": "eke",
    "eket": "eke",
    "ekets": "eke",
    "ekfaten": "ekfat",
    "ekfatens": "ekfat",
    "ekfatet": "ekfat",
    "ekfatets": "ekfat",
    "ekfats": "ekfat",
    "ekfatslagrad": "ekfatslagra",
    "ekfatslagrade": "ekfatslagra",
    "ekfatslagrades": "ekfatslagra",
    "ekfatslagrads": "ekfatslagra",
    "ekfatslagrande": "ekfatslagra",
    "ekfatslagranden": "ekfatslagrande",
    "ekfatslagrandena": "ekfatslagrande",
    "ekfatslagrandenas": "ekfatslagrande",
    "ekfatslagrandens": "ekfatslagrande",
    "ekfatslagrandes": "ekfatslagrande",
    "ekfatslagrandet": "ekfatslagrande",
    "ekfatslagrandets": "ekfatslagrande",
    "ekfatslagrar": "ekfatslagra",
    "ekfatslagras": "ekfatslagra",
    "ekfatslagrat": "ekfatslagra",
    "ekfatslagrats": "ekfatslagra",
    "ekipagen": "ekipage",
    "ekipagens": "ekipage",
    "ekipages": "ekipage",
    "ekipaget": "ekipage",
    "ekipagets": "ekipage",
    "ekiperad": "ekipera",
    "ekiperade": "ekipera",
    "ekiperades": "ekipera",
    "ekiperads": "ekipera",
    "ekiperande": "ekipera",
    "ekiperanden": "ekiperande",
    "ekiperandena": "ekiperande",
    "ekiperandenas": "ekiperande",
    "ekiperandens": "ekiperande",
    "ekiperandes": "ekiperande",
    "ekiperandet": "ekiperande",
    "ekiperandets": "ekiperande",
    "ekiperar": "ekipera",
    "ekiperas": "ekipera",
    "ekiperat": "ekipera",
    "ekiperats": "ekipera",
    "ekiperbara": "ekiperbar",
    "ekiperbarare": "ekiperbar",
    "ekiperbarares": "ekiperbar",
    "ekiperbaras": "ekiperbar",
    "ekiperbarast": "ekiperbar",
    "ekiperbaraste": "ekiperbar",
    "ekiperbarastes": "ekiperbar",
    "ekiperbarasts": "ekiperbar",
    "ekiperbare": "ekiperbar",
    "ekiperbares": "ekiperbar",
    "ekiperbarheten": "ekiperbarhet",
    "ekiperbarhetens": "ekiperbarhet",
    "ekiperbarhets": "ekiperbarhet",
    "ekiperbars": "ekiperbar",
    "ekiperbart": "ekiperbar",
    "ekiperbarts": "ekiperbar",
    "ekiperingar": "ekipering",
    "ekiperingarna": "ekipering",
    "ekiperingarnas": "ekipering",
    "ekiperingars": "ekipering",
    "ekiperingen": "ekipering",
    "ekiperingens": "ekipering",
    "ekiperings": "ekipering",
    "ekiperingsaffären": "ekiperingsaffär",
    "ekiperingsaffärens": "ekiperingsaffär",
    "ekiperingsaffärer": "ekiperingsaffär",
    "ekiperingsaffärerna": "ekiperingsaffär",
    "ekiperingsaffärernas": "ekiperingsaffär",
    "ekiperingsaffärers": "ekiperingsaffär",
    "ekiperingsaffärs": "ekiperingsaffär",
    "ekivoka": "ekivok",
    "ekivokare": "ekivok",
    "ekivokares": "ekivok",
    "ekivokas": "ekivok",
    "ekivokast": "ekivok",
    "ekivokaste": "ekivok",
    "ekivokastes": "ekivok",
    "ekivokasts": "ekivok",
    "ekivoke": "ekivok",
    "ekivokes": "ekivok",
    "ekivoks": "ekivok",
    "ekivokt": "ekivok",
    "ekivokts": "ekivok",
    "eklampsien": "eklampsi",
    "eklampsiens": "eklampsi",
    "eklampsier": "eklampsi",
    "eklampsierna": "eklampsi",
    "eklampsiernas": "eklampsi",
    "eklampsiers": "eklampsi",
    "eklampsin": "eklampsi",
    "eklampsins": "eklampsi",
    "eklampsis": "eklampsi",
    "eklatanta": "eklatant",
    "eklatantare": "eklatant",
    "eklatantares": "eklatant",
    "eklatantas": "eklatant",
    "eklatantast": "eklatant",
    "eklatantaste": "eklatant",
    "eklatantastes": "eklatant",
    "eklatantasts": "eklatant",
    "eklatante": "eklatant",
    "eklatantes": "eklatant",
    "eklatants": "eklatant",
    "eklaterad": "eklatera",
    "eklaterade": "eklatera",
    "eklaterades": "eklatera",
    "eklaterads": "eklatera",
    "eklaterande": "eklatera",
    "eklateranden": "eklaterande",
    "eklaterandena": "eklaterande",
    "eklaterandenas": "eklaterande",
    "eklaterandens": "eklaterande",
    "eklaterandes": "eklaterande",
    "eklaterandet": "eklaterande",
    "eklaterandets": "eklaterande",
    "eklaterar": "eklatera",
    "eklateras": "eklatera",
    "eklaterat": "eklatera",
    "eklaterats": "eklatera",
    "eklaterbara": "eklaterbar",
    "eklaterbarare": "eklaterbar",
    "eklaterbarares": "eklaterbar",
    "eklaterbaras": "eklaterbar",
    "eklaterbarast": "eklaterbar",
    "eklaterbaraste": "eklaterbar",
    "eklaterbarastes": "eklaterbar",
    "eklaterbarasts": "eklaterbar",
    "eklaterbare": "eklaterbar",
    "eklaterbares": "eklaterbar",
    "eklaterbarheten": "eklaterbarhet",
    "eklaterbarhetens": "eklaterbarhet",
    "eklaterbarhets": "eklaterbarhet",
    "eklaterbars": "eklaterbar",
    "eklaterbart": "eklaterbar",
    "eklaterbarts": "eklaterbar",
    "eklateringar": "eklatering",
    "eklateringarna": "eklatering",
    "eklateringarnas": "eklatering",
    "eklateringars": "eklatering",
    "eklateringen": "eklatering",
    "eklateringens": "eklatering",
    "eklaterings": "eklatering",
    "eklatta": "eklatt",
    "eklattare": "eklatt",
    "eklattares": "eklatt",
    "eklattas": "eklatt",
    "eklattast": "eklatt",
    "eklattaste": "eklatt",
    "eklattastes": "eklatt",
    "eklattasts": "eklatt",
    "eklatte": "eklatt",
    "eklattes": "eklatt",
    "eklatts": "eklatt",
    "eklekticismen": "eklekticism",
    "eklekticismens": "eklekticism",
    "eklekticismer": "eklekticism",
    "eklekticismerna": "eklekticism",
    "eklekticismernas": "eklekticism",
    "eklekticismers": "eklekticism",
    "eklekticisms": "eklekticism",
    "eklektikern": "eklektiker",
    "eklektikerna": "eklektiker",
    "eklektikernas": "eklektiker",
    "eklektikerns": "eklektiker",
    "eklektikers": "eklektiker",
    "eklektiska": "eklektisk",
    "eklektiskare": "eklektisk",
    "eklektiskares": "eklektisk",
    "eklektiskas": "eklektisk",
    "eklektiskast": "eklektisk",
    "eklektiskaste": "eklektisk",
    "eklektiskastes": "eklektisk",
    "eklektiskasts": "eklektisk",
    "eklektiske": "eklektisk",
    "eklektiskes": "eklektisk",
    "eklektisks": "eklektisk",
    "eklektiskt": "eklektisk",
    "eklektiskts": "eklektisk",
    "eklipsen": "eklips",
    "eklipsens": "eklips",
    "eklipser": "eklips",
    "eklipserna": "eklips",
    "eklipsernas": "eklips",
    "eklipsers": "eklips",
    "ekliptikan": "ekliptika",
    "ekliptikans": "ekliptika",
    "ekliptikas": "ekliptika",
    "eklogen": "eklog",
    "eklogens": "eklog",
    "ekloger": "eklog",
    "eklogerna": "eklog",
    "eklogernas": "eklog",
    "eklogers": "eklog",
    "eklogs": "eklog",
    "ekluten": "eklut",
    "eklutens": "eklut",
    "ekluts": "eklut",
    "eklärerad": "eklärera",
    "eklärerade": "eklärera",
    "eklärerades": "eklärera",
    "eklärerads": "eklärera",
    "eklärerande": "eklärera",
    "ekläreranden": "eklärerande",
    "eklärerandena": "eklärerande",
    "eklärerandenas": "eklärerande",
    "eklärerandens": "eklärerande",
    "eklärerandes": "eklärerande",
    "eklärerandet": "eklärerande",
    "eklärerandets": "eklärerande",
    "eklärerar": "eklärera",
    "ekläreras": "eklärera",
    "eklärerat": "eklärera",
    "eklärerats": "eklärera",
    "eklärerbara": "eklärerbar",
    "eklärerbarare": "eklärerbar",
    "eklärerbarares": "eklärerbar",
    "eklärerbaras": "eklärerbar",
    "eklärerbarast": "eklärerbar",
    "eklärerbaraste": "eklärerbar",
    "eklärerbarastes": "eklärerbar",
    "eklärerbarasts": "eklärerbar",
    "eklärerbare": "eklärerbar",
    "eklärerbares": "eklärerbar",
    "eklärerbarheten": "eklärerbarhet",
    "eklärerbarhetens": "eklärerbarhet",
    "eklärerbarhets": "eklärerbarhet",
    "eklärerbars": "eklärerbar",
    "eklärerbart": "eklärerbar",
    "eklärerbarts": "eklärerbar",
    "ekläreringar": "eklärering",
    "ekläreringarna": "eklärering",
    "ekläreringarnas": "eklärering",
    "ekläreringars": "eklärering",
    "ekläreringen": "eklärering",
    "ekläreringens": "eklärering",
    "eklärerings": "eklärering",
    "eklöven": "eklöv",
    "eklövens": "eklöv",
    "eklövet": "eklöv",
    "eklövets": "eklöv",
    "eklövs": "eklöv",
    "ekobrotten": "ekobrott",
    "ekobrottens": "ekobrott",
    "ekobrottet": "ekobrott",
    "ekobrottets": "ekobrott",
    "ekobrotts": "ekobrott",
    "ekollonen": "ekollon",
    "ekollonens": "ekollon",
    "ekollonet": "ekollon",
    "ekollonets": "ekollon",
    "ekollons": "ekollon",
    "ekolod": "ekoloda",
    "ekolodad": "ekoloda",
    "ekolodade": "ekoloda",
    "ekolodades": "ekoloda",
    "ekolodads": "ekoloda",
    "ekolodande": "ekoloda",
    "ekolodanden": "ekolodande",
    "ekolodandena": "ekolodande",
    "ekolodandenas": "ekolodande",
    "ekolodandens": "ekolodande",
    "ekolodandes": "ekolodande",
    "ekolodandet": "ekolodande",
    "ekolodandets": "ekolodande",
    "ekolodar": "ekoloda",
    "ekolodas": "ekoloda",
    "ekolodat": "ekoloda",
    "ekolodats": "ekoloda",
    "ekoloden": "ekolod",
    "ekolodens": "ekolod",
    "ekolodet": "ekolod",
    "ekolodets": "ekolod",
    "ekolods": "ekolod",
    "ekologen": "ekolog",
    "ekologens": "ekolog",
    "ekologer": "ekolog",
    "ekologerna": "ekolog",
    "ekologernas": "ekolog",
    "ekologers": "ekolog",
    "ekologien": "ekologi",
    "ekologiens": "ekologi",
    "ekologin": "ekologi",
    "ekologins": "ekologi",
    "ekologis": "ekologi",
    "ekologiska": "ekologisk",
    "ekologiskare": "ekologisk",
    "ekologiskares": "ekologisk",
    "ekologiskas": "ekologisk",
    "ekologiskast": "ekologisk",
    "ekologiskaste": "ekologisk",
    "ekologiskastes": "ekologisk",
    "ekologiskasts": "ekologisk",
    "ekologiske": "ekologisk",
    "ekologiskes": "ekologisk",
    "ekologisks": "ekologisk",
    "ekologiskt": "ekologisk",
    "ekologiskts": "ekologisk",
    "ekologs": "ekolog",
    "ekon": "eko",
    "ekona": "eko",
    "ekonas": "eko",
    "ekonomen": "ekonom",
    "ekonomens": "ekonom",
    "ekonomer": "ekonom",
    "ekonomerna": "ekonom",
    "ekonomernas": "ekonom",
    "ekonomers": "ekonom",
    "ekonometrien": "ekonometri",
    "ekonometriens": "ekonometri",
    "ekonometrin": "ekonometri",
    "ekonometrins": "ekonometri",
    "ekonometris": "ekonometri",
    "ekonomexamens": "ekonomexamen",
    "ekonomexamina": "ekonomexamen",
    "ekonomexaminas": "ekonomexamen",
    "ekonomiavdelningar": "ekonomiavdelning",
    "ekonomiavdelningarna": "ekonomiavdelning",
    "ekonomiavdelningarnas": "ekonomiavdelning",
    "ekonomiavdelningars": "ekonomiavdelning",
    "ekonomiavdelningen": "ekonomiavdelning",
    "ekonomiavdelningens": "ekonomiavdelning",
    "ekonomiavdelnings": "ekonomiavdelning",
    "ekonomibiträden": "ekonomibiträde",
    "ekonomibiträdena": "ekonomibiträde",
    "ekonomibiträdenas": "ekonomibiträde",
    "ekonomibiträdens": "ekonomibiträde",
    "ekonomibiträdes": "ekonomibiträde",
    "ekonomibiträdet": "ekonomibiträde",
    "ekonomibiträdets": "ekonomibiträde",
    "ekonomibreven": "ekonomibrev",
    "ekonomibrevens": "ekonomibrev",
    "ekonomibrevet": "ekonomibrev",
    "ekonomibrevets": "ekonomibrev",
    "ekonomibrevs": "ekonomibrev",
    "ekonomibyggnaden": "ekonomibyggnad",
    "ekonomibyggnadens": "ekonomibyggnad",
    "ekonomibyggnader": "ekonomibyggnad",
    "ekonomibyggnaderna": "ekonomibyggnad",
    "ekonomibyggnadernas": "ekonomibyggnad",
    "ekonomibyggnaders": "ekonomibyggnad",
    "ekonomibyggnads": "ekonomibyggnad",
    "ekonomichefen": "ekonomichef",
    "ekonomichefens": "ekonomichef",
    "ekonomichefer": "ekonomichef",
    "ekonomicheferna": "ekonomichef",
    "ekonomichefernas": "ekonomichef",
    "ekonomichefers": "ekonomichef",
    "ekonomichefs": "ekonomichef",
    "ekonomien": "ekonomi",
    "ekonomiens": "ekonomi",
    "ekonomier": "ekonomi",
    "ekonomierna": "ekonomi",
    "ekonomiernas": "ekonomi",
    "ekonomiers": "ekonomi",
    "ekonomiföreståndar": "ekonomiföreståndare",
    "ekonomiföreståndaren": "ekonomiföreståndare",
    "ekonomiföreståndarens": "ekonomiföreståndare",
    "ekonomiföreståndares": "ekonomiföreståndare",
    "ekonomiföreståndarna": "ekonomiföreståndare",
    "ekonomiföreståndarnas": "ekonomiföreståndare",
    "ekonomiförpackningar": "ekonomiförpackning",
    "ekonomiförpackningarna": "ekonomiförpackning",
    "ekonomiförpackningarnas": "ekonomiförpackning",
    "ekonomiförpackningars": "ekonomiförpackning",
    "ekonomiförpackningen": "ekonomiförpackning",
    "ekonomiförpackningens": "ekonomiförpackning",
    "ekonomiförpacknings": "ekonomiförpackning",
    "ekonomiklassen": "ekonomiklass",
    "ekonomiklassens": "ekonomiklass",
    "ekonomikrönikören": "ekonomikrönikör",
    "ekonomikrönikörens": "ekonomikrönikör",
    "ekonomikrönikörer": "ekonomikrönikör",
    "ekonomikrönikörerna": "ekonomikrönikör",
    "ekonomikrönikörernas": "ekonomikrönikör",
    "ekonomikrönikörers": "ekonomikrönikör",
    "ekonomikrönikörs": "ekonomikrönikör",
    "ekonomiläran": "ekonomilära",
    "ekonomilärans": "ekonomilära",
    "ekonomiläras": "ekonomilära",
    "ekonomiläre": "ekonomilära",
    "ekonomiläro": "ekonomilära",
    "ekonomiläror": "ekonomilära",
    "ekonomilärorna": "ekonomilära",
    "ekonomilärornas": "ekonomilära",
    "ekonomilärors": "ekonomilära",
    "ekonomin": "ekonomi",
    "ekonomins": "ekonomi",
    "ekonomipaketen": "ekonomipaket",
    "ekonomipaketens": "ekonomipaket",
    "ekonomipaketet": "ekonomipaket",
    "ekonomipaketets": "ekonomipaket",
    "ekonomipakets": "ekonomipaket",
    "ekonomipersonalen": "ekonomipersonal",
    "ekonomipersonalens": "ekonomipersonal",
    "ekonomipersonals": "ekonomipersonal",
    "ekonomirätten": "ekonomirätt",
    "ekonomirättens": "ekonomirätt",
    "ekonomirätts": "ekonomirätt",
    "ekonomis": "ekonomi",
    "ekonomiserad": "ekonomisera",
    "ekonomiserade": "ekonomisera",
    "ekonomiserades": "ekonomisera",
    "ekonomiserads": "ekonomisera",
    "ekonomiserande": "ekonomisera",
    "ekonomiseranden": "ekonomiserande",
    "ekonomiserandena": "ekonomiserande",
    "ekonomiserandenas": "ekonomiserande",
    "ekonomiserandens": "ekonomiserande",
    "ekonomiserandes": "ekonomiserande",
    "ekonomiserandet": "ekonomiserande",
    "ekonomiserandets": "ekonomiserande",
    "ekonomiserar": "ekonomisera",
    "ekonomiseras": "ekonomisera",
    "ekonomiserat": "ekonomisera",
    "ekonomiserats": "ekonomisera",
    "ekonomiserbara": "ekonomiserbar",
    "ekonomiserbarare": "ekonomiserbar",
    "ekonomiserbarares": "ekonomiserbar",
    "ekonomiserbaras": "ekonomiserbar",
    "ekonomiserbarast": "ekonomiserbar",
    "ekonomiserbaraste": "ekonomiserbar",
    "ekonomiserbarastes": "ekonomiserbar",
    "ekonomiserbarasts": "ekonomiserbar",
    "ekonomiserbare": "ekonomiserbar",
    "ekonomiserbares": "ekonomiserbar",
    "ekonomiserbarheten": "ekonomiserbarhet",
    "ekonomiserbarhetens": "ekonomiserbarhet",
    "ekonomiserbarhets": "ekonomiserbarhet",
    "ekonomiserbars": "ekonomiserbar",
    "ekonomiserbart": "ekonomiserbar",
    "ekonomiserbarts": "ekonomiserbar",
    "ekonomiseringar": "ekonomisering",
    "ekonomiseringarna": "ekonomisering",
    "ekonomiseringarnas": "ekonomisering",
    "ekonomiseringars": "ekonomisering",
    "ekonomiseringen": "ekonomisering",
    "ekonomiseringens": "ekonomisering",
    "ekonomiserings": "ekonomisering",
    "ekonomisk-politiska": "ekonomisk-politisk",
    "ekonomisk-politiskas": "ekonomisk-politisk",
    "ekonomisk-politiske": "ekonomisk-politisk",
    "ekonomisk-politiskes": "ekonomisk-politisk",
    "ekonomisk-politisks": "ekonomisk-politisk",
    "ekonomisk-politiskt": "ekonomisk-politisk",
    "ekonomisk-politiskts": "ekonomisk-politisk",
    "ekonomiska": "ekonomisk",
    "ekonomiskare": "ekonomisk",
    "ekonomiskares": "ekonomisk",
    "ekonomiskas": "ekonomisk",
    "ekonomiskast": "ekonomisk",
    "ekonomiskaste": "ekonomisk",
    "ekonomiskastes": "ekonomisk",
    "ekonomiskasts": "ekonomisk",
    "ekonomiske": "ekonomisk",
    "ekonomiskes": "ekonomisk",
    "ekonomiskpolitiska": "ekonomiskpolitisk",
    "ekonomiskpolitiskas": "ekonomiskpolitisk",
    "ekonomiskpolitiske": "ekonomiskpolitisk",
    "ekonomiskpolitiskes": "ekonomiskpolitisk",
    "ekonomiskpolitisks": "ekonomiskpolitisk",
    "ekonomiskpolitiskt": "ekonomiskpolitisk",
    "ekonomiskpolitiskts": "ekonomiskpolitisk",
    "ekonomisks": "ekonomisk",
    "ekonomiskt": "ekonomisk",
    "ekonomiskt-politiska": "ekonomiskt-politisk",
    "ekonomiskt-politiskas": "ekonomiskt-politisk",
    "ekonomiskt-politiske": "ekonomiskt-politisk",
    "ekonomiskt-politiskes": "ekonomiskt-politisk",
    "ekonomiskt-politisks": "ekonomiskt-politisk",
    "ekonomiskt-politiskt": "ekonomiskt-politisk",
    "ekonomiskt-politiskts": "ekonomiskt-politisk",
    "ekonomisktpolitiska": "ekonomisktpolitisk",
    "ekonomisktpolitiskas": "ekonomisktpolitisk",
    "ekonomisktpolitiske": "ekonomisktpolitisk",
    "ekonomisktpolitiskes": "ekonomisktpolitisk",
    "ekonomisktpolitisks": "ekonomisktpolitisk",
    "ekonomisktpolitiskt": "ekonomisktpolitisk",
    "ekonomisktpolitiskts": "ekonomisktpolitisk",
    "ekonomiskts": "ekonomisk",
    "ekonomiutbildningar": "ekonomiutbildning",
    "ekonomiutbildningarna": "ekonomiutbildning",
    "ekonomiutbildningarnas": "ekonomiutbildning",
    "ekonomiutbildningars": "ekonomiutbildning",
    "ekonomiutbildningen": "ekonomiutbildning",
    "ekonomiutbildningens": "ekonomiutbildning",
    "ekonomiutbildnings": "ekonomiutbildning",
    "ekonoms": "ekonom",
    "ekonomutbildningar": "ekonomutbildning",
    "ekonomutbildningarna": "ekonomutbildning",
    "ekonomutbildningarnas": "ekonomutbildning",
    "ekonomutbildningars": "ekonomutbildning",
    "ekonomutbildningen": "ekonomutbildning",
    "ekonomutbildningens": "ekonomutbildning",
    "ekonomutbildnings": "ekonomutbildning",
    "ekons": "eko",
    "ekoodlade": "ekoodlad",
    "ekoodlades": "ekoodlad",
    "ekoodlads": "ekoodlad",
    "ekoodlat": "ekoodlad",
    "ekoodlats": "ekoodlad",
    "ekor": "eka",
    "ekoradion": "ekoradio",
    "ekoradions": "ekoradio",
    "ekoradior": "ekoradio",
    "ekoradiorna": "ekoradio",
    "ekoradiornas": "ekoradio",
    "ekoradiors": "ekoradio",
    "ekoradios": "ekoradio",
    "ekorna": "eka",
    "ekornas": "eka",
    "ekorr": "ekorre",
    "ekorrar": "ekorre",
    "ekorrarna": "ekorre",
    "ekorrarnas": "ekorre",
    "ekorrars": "ekorre",
    "ekorrbären": "ekorrbär",
    "ekorrbärens": "ekorrbär",
    "ekorrbäret": "ekorrbär",
    "ekorrbärets": "ekorrbär",
    "ekorrbärs": "ekorrbär",
    "ekorrdjuren": "ekorrdjur",
    "ekorrdjurens": "ekorrdjur",
    "ekorrdjuret": "ekorrdjur",
    "ekorrdjurets": "ekorrdjur",
    "ekorrdjurs": "ekorrdjur",
    "ekorren": "ekorre",
    "ekorrens": "ekorre",
    "ekorres": "ekorre",
    "ekorrhjulet": "ekorrhjul",
    "ekorrhjulets": "ekorrhjul",
    "ekorrhjuls": "ekorrhjul",
    "ekorrs": "ekorre",
    "ekorröda": "ekorröd",
    "ekorrödare": "ekorröd",
    "ekorrödares": "ekorröd",
    "ekorrödas": "ekorröd",
    "ekorrödast": "ekorröd",
    "ekorrödaste": "ekorröd",
    "ekorrödastes": "ekorröd",
    "ekorrödasts": "ekorröd",
    "ekorröde": "ekorröd",
    "ekorrödes": "ekorröd",
    "ekorröds": "ekorröd",
    "ekorrött": "ekorröd",
    "ekorrötts": "ekorröd",
    "ekors": "eka",
    "ekos": "eko",
    "ekosystemen": "ekosystem",
    "ekosystemens": "ekosystem",
    "ekosystemet": "ekosystem",
    "ekosystemets": "ekosystem",
    "ekosystems": "ekosystem",
    "ekot": "eko",
    "ekots": "eko",
    "ekoturisten": "ekoturist",
    "ekoturistens": "ekoturist",
    "ekoturister": "ekoturist",
    "ekoturisterna": "ekoturist",
    "ekoturisternas": "ekoturist",
    "ekoturisters": "ekoturist",
    "ekoturists": "ekoturist",
    "ekotypen": "ekotyp",
    "ekotypens": "ekotyp",
    "ekotyper": "ekotyp",
    "ekotyperna": "ekotyp",
    "ekotypernas": "ekotyp",
    "ekotypers": "ekotyp",
    "ekotyps": "ekotyp",
    "ekox": "ekoxe",
    "ekoxar": "ekoxe",
    "ekoxarna": "ekoxe",
    "ekoxarnas": "ekoxe",
    "ekoxars": "ekoxe",
    "ekoxen": "ekoxe",
    "ekoxens": "ekoxe",
    "ekoxes": "ekoxe",
    "ekrar": "eker",
    "ekrarna": "eker",
    "ekrarnas": "eker",
    "ekrars": "eker",
    "eks": "eka",
    "eksemen": "eksem",
    "eksemens": "eksem",
    "eksemet": "eksem",
    "eksemets": "eksem",
    "eksems": "eksem",
    "ekskogar": "ekskog",
    "ekskogarna": "ekskog",
    "ekskogarnas": "ekskog",
    "ekskogars": "ekskog",
    "ekskogen": "ekskog",
    "ekskogens": "ekskog",
    "ekskogs": "ekskog",
    "ekspinnar": "ekspinnare",
    "ekspinnaren": "ekspinnare",
    "ekspinnarens": "ekspinnare",
    "ekspinnares": "ekspinnare",
    "ekspinnarna": "ekspinnare",
    "ekspinnarnas": "ekspinnare",
    "ekstockar": "ekstock",
    "ekstockarna": "ekstock",
    "ekstockarnas": "ekstock",
    "ekstockars": "ekstock",
    "ekstocken": "ekstock",
    "ekstockens": "ekstock",
    "ekstocks": "ekstock",
    "ektodermet": "ektoderm",
    "ektodermets": "ektoderm",
    "ektoderms": "ektoderm",
    "ektomien": "ektomi",
    "ektomiens": "ektomi",
    "ektomier": "ektomi",
    "ektomierna": "ektomi",
    "ektomiernas": "ektomi",
    "ektomiers": "ektomi",
    "ektomin": "ektomi",
    "ektomins": "ektomi",
    "ektomis": "ektomi",
    "ekumeniken": "ekumenik",
    "ekumenikens": "ekumenik",
    "ekumeniks": "ekumenik",
    "ekumeniska": "ekumenisk",
    "ekumeniskare": "ekumenisk",
    "ekumeniskares": "ekumenisk",
    "ekumeniskas": "ekumenisk",
    "ekumeniskast": "ekumenisk",
    "ekumeniskaste": "ekumenisk",
    "ekumeniskastes": "ekumenisk",
    "ekumeniskasts": "ekumenisk",
    "ekumeniske": "ekumenisk",
    "ekumeniskes": "ekumenisk",
    "ekumenisks": "ekumenisk",
    "ekumeniskt": "ekumenisk",
    "ekumeniskts": "ekumenisk",
    "ekumenismen": "ekumenism",
    "ekumenismens": "ekumenism",
    "ekumenismer": "ekumenism",
    "ekumenismerna": "ekumenism",
    "ekumenismernas": "ekumenism",
    "ekumenismers": "ekumenism",
    "ekumenisms": "ekumenism",
    "ekvationen": "ekvation",
    "ekvationens": "ekvation",
    "ekvationer": "ekvation",
    "ekvationerna": "ekvation",
    "ekvationernas": "ekvation",
    "ekvationers": "ekvation",
    "ekvations": "ekvation",
    "ekvatoriala": "ekvatorial",
    "ekvatorialare": "ekvatorial",
    "ekvatorialares": "ekvatorial",
    "ekvatorialas": "ekvatorial",
    "ekvatorialast": "ekvatorial",
    "ekvatorialaste": "ekvatorial",
    "ekvatorialastes": "ekvatorial",
    "ekvatorialasts": "ekvatorial",
    "ekvatorialbälten": "ekvatorialbälte",
    "ekvatorialbältena": "ekvatorialbälte",
    "ekvatorialbältenas": "ekvatorialbälte",
    "ekvatorialbältens": "ekvatorialbälte",
    "ekvatorialbältes": "ekvatorialbälte",
    "ekvatorialbältet": "ekvatorialbälte",
    "ekvatorialbältets": "ekvatorialbälte",
    "ekvatoriale": "ekvatorial",
    "ekvatoriales": "ekvatorial",
    "ekvatorialguineanen": "ekvatorialguinean",
    "ekvatorialguineanens": "ekvatorialguinean",
    "ekvatorialguineaner": "ekvatorialguinean",
    "ekvatorialguineanerna": "ekvatorialguinean",
    "ekvatorialguineanernas": "ekvatorialguinean",
    "ekvatorialguineaners": "ekvatorialguinean",
    "ekvatorialguineans": "ekvatorialguinean",
    "ekvatorialguineanska": "ekvatorialguineansk",
    "ekvatorialguineanskan": "ekvatorialguineanska",
    "ekvatorialguineanskans": "ekvatorialguineanska",
    "ekvatorialguineanskare": "ekvatorialguineansk",
    "ekvatorialguineanskares": "ekvatorialguineansk",
    "ekvatorialguineanskas": "ekvatorialguineanska",
    "ekvatorialguineanskast": "ekvatorialguineansk",
    "ekvatorialguineanskaste": "ekvatorialguineansk",
    "ekvatorialguineanskastes": "ekvatorialguineansk",
    "ekvatorialguineanskasts": "ekvatorialguineansk",
    "ekvatorialguineanske": "ekvatorialguineanska",
    "ekvatorialguineanskes": "ekvatorialguineansk",
    "ekvatorialguineanskor": "ekvatorialguineanska",
    "ekvatorialguineanskorna": "ekvatorialguineanska",
    "ekvatorialguineanskornas": "ekvatorialguineanska",
    "ekvatorialguineanskors": "ekvatorialguineanska",
    "ekvatorialguineansks": "ekvatorialguineansk",
    "ekvatorialguineanskt": "ekvatorialguineansk",
    "ekvatorialguineanskts": "ekvatorialguineansk",
    "ekvatorials": "ekvatorial",
    "ekvatorialströmmar": "ekvatorialström",
    "ekvatorialströmmarna": "ekvatorialström",
    "ekvatorialströmmarnas": "ekvatorialström",
    "ekvatorialströmmars": "ekvatorialström",
    "ekvatorialströmmen": "ekvatorialström",
    "ekvatorialströmmens": "ekvatorialström",
    "ekvatorialströms": "ekvatorialström",
    "ekvatorialt": "ekvatorial",
    "ekvatorialts": "ekvatorial",
    "ekvatorialzonen": "ekvatorialzon",
    "ekvatorialzonens": "ekvatorialzon",
    "ekvatorialzoner": "ekvatorialzon",
    "ekvatorialzonerna": "ekvatorialzon",
    "ekvatorialzonernas": "ekvatorialzon",
    "ekvatorialzoners": "ekvatorialzon",
    "ekvatorialzons": "ekvatorialzon",
    "ekvatoriella": "ekvatoriell",
    "ekvatoriellare": "ekvatoriell",
    "ekvatoriellares": "ekvatoriell",
    "ekvatoriellas": "ekvatoriell",
    "ekvatoriellast": "ekvatoriell",
    "ekvatoriellaste": "ekvatoriell",
    "ekvatoriellastes": "ekvatoriell",
    "ekvatoriellasts": "ekvatoriell",
    "ekvatorielle": "ekvatoriell",
    "ekvatorielles": "ekvatoriell",
    "ekvatoriells": "ekvatoriell",
    "ekvatoriellt": "ekvatoriell",
    "ekvatoriellts": "ekvatoriell",
    "ekvatorn": "ekvator",
    "ekvatorns": "ekvator",
    "ekvators": "ekvator",
    "ekvatorshöjden": "ekvatorshöjd",
    "ekvatorshöjdens": "ekvatorshöjd",
    "ekvatorshöjds": "ekvatorshöjd",
    "ekvatorsplanen": "ekvatorsplan",
    "ekvatorsplanens": "ekvatorsplan",
    "ekvatorsplanet": "ekvatorsplan",
    "ekvatorsplanets": "ekvatorsplan",
    "ekvatorsplans": "ekvatorsplan",
    "ekvecklar": "ekvecklare",
    "ekvecklaren": "ekvecklare",
    "ekvecklarens": "ekvecklare",
    "ekvecklares": "ekvecklare",
    "ekvecklarna": "ekvecklare",
    "ekvecklarnas": "ekvecklare",
    "ekvidistansen": "ekvidistans",
    "ekvidistansens": "ekvidistans",
    "ekvidistanta": "ekvidistant",
    "ekvidistantare": "ekvidistant",
    "ekvidistantares": "ekvidistant",
    "ekvidistantas": "ekvidistant",
    "ekvidistantast": "ekvidistant",
    "ekvidistantaste": "ekvidistant",
    "ekvidistantastes": "ekvidistant",
    "ekvidistantasts": "ekvidistant",
    "ekvidistante": "ekvidistant",
    "ekvidistantes": "ekvidistant",
    "ekvidistants": "ekvidistant",
    "ekvilibristen": "ekvilibrist",
    "ekvilibristens": "ekvilibrist",
    "ekvilibrister": "ekvilibrist",
    "ekvilibristerna": "ekvilibrist",
    "ekvilibristernas": "ekvilibrist",
    "ekvilibristers": "ekvilibrist",
    "ekvilibristiken": "ekvilibristik",
    "ekvilibristikens": "ekvilibristik",
    "ekvilibristiks": "ekvilibristik",
    "ekvilibristiska": "ekvilibristisk",
    "ekvilibristiskare": "ekvilibristisk",
    "ekvilibristiskares": "ekvilibristisk",
    "ekvilibristiskas": "ekvilibristisk",
    "ekvilibristiskast": "ekvilibristisk",
    "ekvilibristiskaste": "ekvilibristisk",
    "ekvilibristiskastes": "ekvilibristisk",
    "ekvilibristiskasts": "ekvilibristisk",
    "ekvilibristiske": "ekvilibristisk",
    "ekvilibristiskes": "ekvilibristisk",
    "ekvilibristisks": "ekvilibristisk",
    "ekvilibristiskt": "ekvilibristisk",
    "ekvilibristiskts": "ekvilibristisk",
    "ekvilibrists": "ekvilibrist",
    "ekvipotentiallinjen": "ekvipotentiallinje",
    "ekvipotentiallinjens": "ekvipotentiallinje",
    "ekvipotentiallinjer": "ekvipotentiallinje",
    "ekvipotentiallinjerna": "ekvipotentiallinje",
    "ekvipotentiallinjernas": "ekvipotentiallinje",
    "ekvipotentiallinjers": "ekvipotentiallinje",
    "ekvipotentiallinjes": "ekvipotentiallinje",
    "ekvipotentialytan": "ekvipotentialyta",
    "ekvipotentialytans": "ekvipotentialyta",
    "ekvipotentialytas": "ekvipotentialyta",
    "ekvipotentialyte": "ekvipotentialyta",
    "ekvipotentialytor": "ekvipotentialyta",
    "ekvipotentialytorna": "ekvipotentialyta",
    "ekvipotentialytornas": "ekvipotentialyta",
    "ekvipotentialytors": "ekvipotentialyta",
    "ekvivalensen": "ekvivalens",
    "ekvivalensens": "ekvivalens",
    "ekvivalenta": "ekvivalent",
    "ekvivalentare": "ekvivalent",
    "ekvivalentares": "ekvivalent",
    "ekvivalentas": "ekvivalent",
    "ekvivalentast": "ekvivalent",
    "ekvivalentaste": "ekvivalent",
    "ekvivalentastes": "ekvivalent",
    "ekvivalentasts": "ekvivalent",
    "ekvivalente": "ekvivalent",
    "ekvivalenten": "ekvivalent",
    "ekvivalentens": "ekvivalent",
    "ekvivalenter": "ekvivalent",
    "ekvivalenterna": "ekvivalent",
    "ekvivalenternas": "ekvivalent",
    "ekvivalenters": "ekvivalent",
    "ekvivalentes": "ekvivalent",
    "ekvivalents": "ekvivalent",
    "ekvivalentvikten": "ekvivalentvikt",
    "ekvivalentviktens": "ekvivalentvikt",
    "ekvivalentvikter": "ekvivalentvikt",
    "ekvivalentvikterna": "ekvivalentvikt",
    "ekvivalentvikternas": "ekvivalentvikt",
    "ekvivalentvikters": "ekvivalentvikt",
    "ekvivalentvikts": "ekvivalentvikt",
    "elaborerad": "elaborera",
    "elaborerade": "elaborera",
    "elaborerades": "elaborera",
    "elaborerads": "elaborera",
    "elaborerande": "elaborera",
    "elaboreranden": "elaborerande",
    "elaborerandena": "elaborerande",
    "elaborerandenas": "elaborerande",
    "elaborerandens": "elaborerande",
    "elaborerandes": "elaborerande",
    "elaborerandet": "elaborerande",
    "elaborerandets": "elaborerande",
    "elaborerar": "elaborera",
    "elaboreras": "elaborera",
    "elaborerat": "elaborera",
    "elaborerats": "elaborera",
    "elaborerbara": "elaborerbar",
    "elaborerbarare": "elaborerbar",
    "elaborerbarares": "elaborerbar",
    "elaborerbaras": "elaborerbar",
    "elaborerbarast": "elaborerbar",
    "elaborerbaraste": "elaborerbar",
    "elaborerbarastes": "elaborerbar",
    "elaborerbarasts": "elaborerbar",
    "elaborerbare": "elaborerbar",
    "elaborerbares": "elaborerbar",
    "elaborerbarheten": "elaborerbarhet",
    "elaborerbarhetens": "elaborerbarhet",
    "elaborerbarhets": "elaborerbarhet",
    "elaborerbars": "elaborerbar",
    "elaborerbart": "elaborerbar",
    "elaborerbarts": "elaborerbar",
    "elaboreringar": "elaborering",
    "elaboreringarna": "elaborering",
    "elaboreringarnas": "elaborering",
    "elaboreringars": "elaborering",
    "elaboreringen": "elaborering",
    "elaboreringens": "elaborering",
    "elaborerings": "elaborering",
    "elaka": "elak",
    "elakare": "elak",
    "elakares": "elak",
    "elakartade": "elakartad",
    "elakartades": "elakartad",
    "elakartads": "elakartad",
    "elakartat": "elakartad",
    "elakartats": "elakartad",
    "elakas": "elak",
    "elakast": "elak",
    "elakaste": "elak",
    "elakastes": "elak",
    "elakasts": "elak",
    "elake": "elak",
    "elakes": "elak",
    "elakheten": "elakhet",
    "elakhetens": "elakhet",
    "elakheter": "elakhet",
    "elakheterna": "elakhet",
    "elakheternas": "elakhet",
    "elakheters": "elakhet",
    "elakhets": "elakhet",
    "elakingar": "elaking",
    "elakingarna": "elaking",
    "elakingarnas": "elaking",
    "elakingars": "elaking",
    "elakingen": "elaking",
    "elakingens": "elaking",
    "elakings": "elaking",
    "elaks": "elak",
    "elakt": "elak",
    "elakts": "elak",
    "elanden": "eland",
    "elandens": "eland",
    "elander": "eland",
    "elanderna": "eland",
    "elandernas": "eland",
    "elanders": "eland",
    "elands": "eland",
    "elapparaten": "elapparat",
    "elapparatens": "elapparat",
    "elapparater": "elapparat",
    "elapparaterna": "elapparat",
    "elapparaternas": "elapparat",
    "elapparaters": "elapparat",
    "elapparats": "elapparat",
    "elasticiteten": "elasticitet",
    "elasticitetens": "elasticitet",
    "elasticiteter": "elasticitet",
    "elasticiteterna": "elasticitet",
    "elasticiteternas": "elasticitet",
    "elasticiteters": "elasticitet",
    "elasticitets": "elasticitet",
    "elasticitetsgränsen": "elasticitetsgräns",
    "elasticitetsgränsens": "elasticitetsgräns",
    "elasticitetsgränser": "elasticitetsgräns",
    "elasticitetsgränserna": "elasticitetsgräns",
    "elasticitetsgränsernas": "elasticitetsgräns",
    "elasticitetsgränsers": "elasticitetsgräns",
    "elastiserad": "elastisera",
    "elastiserade": "elastisera",
    "elastiserades": "elastisera",
    "elastiserads": "elastisera",
    "elastiserande": "elastisera",
    "elastiseranden": "elastiserande",
    "elastiserandena": "elastiserande",
    "elastiserandenas": "elastiserande",
    "elastiserandens": "elastiserande",
    "elastiserandes": "elastiserande",
    "elastiserandet": "elastiserande",
    "elastiserandets": "elastiserande",
    "elastiserar": "elastisera",
    "elastiseras": "elastisera",
    "elastiserat": "elastisera",
    "elastiserats": "elastisera",
    "elastiserbara": "elastiserbar",
    "elastiserbarare": "elastiserbar",
    "elastiserbarares": "elastiserbar",
    "elastiserbaras": "elastiserbar",
    "elastiserbarast": "elastiserbar",
    "elastiserbaraste": "elastiserbar",
    "elastiserbarastes": "elastiserbar",
    "elastiserbarasts": "elastiserbar",
    "elastiserbare": "elastiserbar",
    "elastiserbares": "elastiserbar",
    "elastiserbarheten": "elastiserbarhet",
    "elastiserbarhetens": "elastiserbarhet",
    "elastiserbarhets": "elastiserbarhet",
    "elastiserbars": "elastiserbar",
    "elastiserbart": "elastiserbar",
    "elastiserbarts": "elastiserbar",
    "elastiseringar": "elastisering",
    "elastiseringarna": "elastisering",
    "elastiseringarnas": "elastisering",
    "elastiseringars": "elastisering",
    "elastiseringen": "elastisering",
    "elastiseringens": "elastisering",
    "elastiserings": "elastisering",
    "elastiska": "elastisk",
    "elastiskare": "elastisk",
    "elastiskares": "elastisk",
    "elastiskas": "elastisk",
    "elastiskast": "elastisk",
    "elastiskaste": "elastisk",
    "elastiskastes": "elastisk",
    "elastiskasts": "elastisk",
    "elastiske": "elastisk",
    "elastiskes": "elastisk",
    "elastisks": "elastisk",
    "elastiskt": "elastisk",
    "elastiskts": "elastisk",
    "elativen": "elativ",
    "elativens": "elativ",
    "elativer": "elativ",
    "elativerna": "elativ",
    "elativernas": "elativ",
    "elativers": "elativ",
    "elativs": "elativ",
    "elavläsningar": "elavläsning",
    "elavläsningarna": "elavläsning",
    "elavläsningarnas": "elavläsning",
    "elavläsningars": "elavläsning",
    "elavläsningen": "elavläsning",
    "elavläsningens": "elavläsning",
    "elavläsnings": "elavläsning",
    "elbilar": "elbil",
    "elbilarna": "elbil",
    "elbilarnas": "elbil",
    "elbilars": "elbil",
    "elbilen": "elbil",
    "elbilens": "elbil",
    "elbils": "elbil",
    "elborst": "elborste",
    "elborstar": "elborste",
    "elborstarna": "elborste",
    "elborstarnas": "elborste",
    "elborstars": "elborste",
    "elborsten": "elborste",
    "elborstens": "elborste",
    "elborstes": "elborste",
    "elbörsen": "elbörs",
    "elbörsens": "elbörs",
    "elbörser": "elbörs",
    "elbörserna": "elbörs",
    "elbörsernas": "elbörs",
    "elbörsers": "elbörs",
    "elchocken": "elchock",
    "elchockens": "elchock",
    "elchocker": "elchock",
    "elchockerna": "elchock",
    "elchockernas": "elchock",
    "elchockers": "elchock",
    "elchocks": "elchock",
    "eld": "elda",
    "eldad": "elda",
    "eldade": "elda",
    "eldades": "elda",
    "eldads": "elda",
    "eldande": "elda",
    "eldanden": "eldande",
    "eldandena": "eldande",
    "eldandenas": "eldande",
    "eldandens": "eldande",
    "eldandes": "eldande",
    "eldandet": "eldande",
    "eldandets": "eldande",
    "eldar": "eldare",
    "eldaren": "eldare",
    "eldarens": "eldare",
    "eldares": "eldare",
    "eldarna": "eldare",
    "eldarnas": "eldare",
    "eldars": "eld",
    "eldas": "elda",
    "eldat": "elda",
    "eldats": "elda",
    "eldavstånden": "eldavstånd",
    "eldavståndens": "eldavstånd",
    "eldavståndet": "eldavstånd",
    "eldavståndets": "eldavstånd",
    "eldavstånds": "eldavstånd",
    "eldbegängelsen": "eldbegängelse",
    "eldbegängelsens": "eldbegängelse",
    "eldbegängelser": "eldbegängelse",
    "eldbegängelserna": "eldbegängelse",
    "eldbegängelsernas": "eldbegängelse",
    "eldbegängelsers": "eldbegängelse",
    "eldbegängelses": "eldbegängelse",
    "eldbranden": "eldbrand",
    "eldbrandens": "eldbrand",
    "eldbrands": "eldbrand",
    "eldbränder": "eldbrand",
    "eldbränderna": "eldbrand",
    "eldbrändernas": "eldbrand",
    "eldbränders": "eldbrand",
    "elddisciplinen": "elddisciplin",
    "elddisciplinens": "elddisciplin",
    "elddisciplins": "elddisciplin",
    "elddonen": "elddon",
    "elddonens": "elddon",
    "elddonet": "elddon",
    "elddonets": "elddon",
    "elddons": "elddon",
    "elddopen": "elddop",
    "elddopens": "elddop",
    "elddopet": "elddop",
    "elddopets": "elddop",
    "elddops": "elddop",
    "elden": "eld",
    "eldens": "eld",
    "eldfaran": "eldfara",
    "eldfarans": "eldfara",
    "eldfaras": "eldfara",
    "eldfare": "eldfara",
    "eldfarliga": "eldfarlig",
    "eldfarligare": "eldfarlig",
    "eldfarligares": "eldfarlig",
    "eldfarligas": "eldfarlig",
    "eldfarligast": "eldfarlig",
    "eldfarligaste": "eldfarlig",
    "eldfarligastes": "eldfarlig",
    "eldfarligasts": "eldfarlig",
    "eldfarlige": "eldfarlig",
    "eldfarliges": "eldfarlig",
    "eldfarligheten": "eldfarlighet",
    "eldfarlighetens": "eldfarlighet",
    "eldfarlighets": "eldfarlighet",
    "eldfarligs": "eldfarlig",
    "eldfarligt": "eldfarlig",
    "eldfarligts": "eldfarlig",
    "eldfaro": "eldfara",
    "eldfasta": "eldfast",
    "eldfastare": "eldfast",
    "eldfastares": "eldfast",
    "eldfastas": "eldfast",
    "eldfastast": "eldfast",
    "eldfastaste": "eldfast",
    "eldfastastes": "eldfast",
    "eldfastasts": "eldfast",
    "eldfaste": "eldfast",
    "eldfastes": "eldfast",
    "eldfastheten": "eldfasthet",
    "eldfasthetens": "eldfasthet",
    "eldfasthets": "eldfasthet",
    "eldfasts": "eldfast",
    "eldflug": "eldfluga",
    "eldflugan": "eldfluga",
    "eldflugans": "eldfluga",
    "eldflugas": "eldfluga",
    "eldfluge": "eldfluga",
    "eldflugor": "eldfluga",
    "eldflugorna": "eldfluga",
    "eldflugornas": "eldfluga",
    "eldflugors": "eldfluga",
    "eldflugs": "eldfluga",
    "eldfängda": "eldfängd",
    "eldfängdare": "eldfängd",
    "eldfängdares": "eldfängd",
    "eldfängdas": "eldfängd",
    "eldfängdast": "eldfängd",
    "eldfängdaste": "eldfängd",
    "eldfängdastes": "eldfängd",
    "eldfängdasts": "eldfängd",
    "eldfängde": "eldfängd",
    "eldfängdes": "eldfängd",
    "eldfängdheten": "eldfängdhet",
    "eldfängdhetens": "eldfängdhet",
    "eldfängdhets": "eldfängdhet",
    "eldfängds": "eldfängd",
    "eldfängt": "eldfängd",
    "eldfängts": "eldfängd",
    "eldgaffeln": "eldgaffel",
    "eldgaffelns": "eldgaffel",
    "eldgaffels": "eldgaffel",
    "eldgaffelsraka": "eldgaffelsrak",
    "eldgaffelsrakare": "eldgaffelsrak",
    "eldgaffelsrakares": "eldgaffelsrak",
    "eldgaffelsrakas": "eldgaffelsrak",
    "eldgaffelsrakast": "eldgaffelsrak",
    "eldgaffelsrakaste": "eldgaffelsrak",
    "eldgaffelsrakastes": "eldgaffelsrak",
    "eldgaffelsrakasts": "eldgaffelsrak",
    "eldgaffelsrake": "eldgaffelsrak",
    "eldgaffelsrakes": "eldgaffelsrak",
    "eldgaffelsraks": "eldgaffelsrak",
    "eldgaffelsrakt": "eldgaffelsrak",
    "eldgaffelsrakts": "eldgaffelsrak",
    "eldgafflar": "eldgaffel",
    "eldgafflarna": "eldgaffel",
    "eldgafflarnas": "eldgaffel",
    "eldgafflars": "eldgaffel",
    "eldgivningar": "eldgivning",
    "eldgivningarna": "eldgivning",
    "eldgivningarnas": "eldgivning",
    "eldgivningars": "eldgivning",
    "eldgivningen": "eldgivning",
    "eldgivningens": "eldgivning",
    "eldgivnings": "eldgivning",
    "eldhandvapens": "eldhandvapen",
    "eldhandvapnen": "eldhandvapen",
    "eldhandvapnens": "eldhandvapen",
    "eldhandvapnet": "eldhandvapen",
    "eldhandvapnets": "eldhandvapen",
    "eldhastigheten": "eldhastighet",
    "eldhastighetens": "eldhastighet",
    "eldhastigheter": "eldhastighet",
    "eldhastigheterna": "eldhastighet",
    "eldhastigheternas": "eldhastighet",
    "eldhastigheters": "eldhastighet",
    "eldhastighets": "eldhastighet",
    "eldhavet": "eldhav",
    "eldhavets": "eldhav",
    "eldhavs": "eldhav",
    "eldhundar": "eldhund",
    "eldhundarna": "eldhund",
    "eldhundarnas": "eldhund",
    "eldhundars": "eldhund",
    "eldhunden": "eldhund",
    "eldhundens": "eldhund",
    "eldhunds": "eldhund",
    "eldhusen": "eldhus",
    "eldhusens": "eldhus",
    "eldhuset": "eldhus",
    "eldhusets": "eldhus",
    "eldhärdar": "eldhärd",
    "eldhärdarna": "eldhärd",
    "eldhärdarnas": "eldhärd",
    "eldhärdars": "eldhärd",
    "eldhärden": "eldhärd",
    "eldhärdens": "eldhärd",
    "eldhärdiga": "eldhärdig",
    "eldhärdigare": "eldhärdig",
    "eldhärdigares": "eldhärdig",
    "eldhärdigas": "eldhärdig",
    "eldhärdigast": "eldhärdig",
    "eldhärdigaste": "eldhärdig",
    "eldhärdigastes": "eldhärdig",
    "eldhärdigasts": "eldhärdig",
    "eldhärdige": "eldhärdig",
    "eldhärdiges": "eldhärdig",
    "eldhärdigheten": "eldhärdighet",
    "eldhärdighetens": "eldhärdighet",
    "eldhärdighets": "eldhärdighet",
    "eldhärdigs": "eldhärdig",
    "eldhärdigt": "eldhärdig",
    "eldhärdigts": "eldhärdig",
    "eldhärds": "eldhärd",
    "eldhärj": "eldhärja",
    "eldhärjad": "eldhärja",
    "eldhärjade": "eldhärja",
    "eldhärjades": "eldhärja",
    "eldhärjads": "eldhärja",
    "eldhärjande": "eldhärja",
    "eldhärjanden": "eldhärjande",
    "eldhärjandena": "eldhärjande",
    "eldhärjandenas": "eldhärjande",
    "eldhärjandens": "eldhärjande",
    "eldhärjandes": "eldhärjande",
    "eldhärjandet": "eldhärjande",
    "eldhärjandets": "eldhärjande",
    "eldhärjar": "eldhärja",
    "eldhärjas": "eldhärja",
    "eldhärjat": "eldhärja",
    "eldhärjats": "eldhärja",
    "eldiga": "eldig",
    "eldigare": "eldig",
    "eldigares": "eldig",
    "eldigas": "eldig",
    "eldigast": "eldig",
    "eldigaste": "eldig",
    "eldigastes": "eldig",
    "eldigasts": "eldig",
    "eldige": "eldig",
    "eldiges": "eldig",
    "eldigheten": "eldighet",
    "eldighetens": "eldighet",
    "eldighets": "eldighet",
    "eldigs": "eldig",
    "eldigt": "eldig",
    "eldigts": "eldig",
    "eldkanalen": "eldkanal",
    "eldkanalens": "eldkanal",
    "eldkanaler": "eldkanal",
    "eldkanalerna": "eldkanal",
    "eldkanalernas": "eldkanal",
    "eldkanalers": "eldkanal",
    "eldkanals": "eldkanal",
    "eldkastar": "eldkastare",
    "eldkastaren": "eldkastare",
    "eldkastarens": "eldkastare",
    "eldkastares": "eldkastare",
    "eldkastarna": "eldkastare",
    "eldkastarnas": "eldkastare",
    "eldkommandon": "eldkommando",
    "eldkommandona": "eldkommando",
    "eldkommandonas": "eldkommando",
    "eldkommandons": "eldkommando",
    "eldkommandos": "eldkommando",
    "eldkommandot": "eldkommando",
    "eldkommandots": "eldkommando",
    "eldkraften": "eldkraft",
    "eldkraftens": "eldkraft",
    "eldkrafts": "eldkraft",
    "eldledar": "eldledare",
    "eldledaren": "eldledare",
    "eldledarens": "eldledare",
    "eldledares": "eldledare",
    "eldledarna": "eldledare",
    "eldledarnas": "eldledare",
    "eldledningar": "eldledning",
    "eldledningarna": "eldledning",
    "eldledningarnas": "eldledning",
    "eldledningars": "eldledning",
    "eldledningen": "eldledning",
    "eldledningens": "eldledning",
    "eldlednings": "eldledning",
    "eldlinjen": "eldlinje",
    "eldlinjens": "eldlinje",
    "eldlinjer": "eldlinje",
    "eldlinjerna": "eldlinje",
    "eldlinjernas": "eldlinje",
    "eldlinjers": "eldlinje",
    "eldlinjes": "eldlinje",
    "eldningar": "eldning",
    "eldningarna": "eldning",
    "eldningarnas": "eldning",
    "eldningars": "eldning",
    "eldningen": "eldning",
    "eldningens": "eldning",
    "eldnings": "eldning",
    "eldningsoljan": "eldningsolja",
    "eldningsoljans": "eldningsolja",
    "eldningsoljas": "eldningsolja",
    "eldningsolje": "eldningsolja",
    "eldningsoljor": "eldningsolja",
    "eldningsoljorna": "eldningsolja",
    "eldningsoljornas": "eldningsolja",
    "eldningsoljors": "eldningsolja",
    "eldoradon": "eldorado",
    "eldoradona": "eldorado",
    "eldoradonas": "eldorado",
    "eldoradons": "eldorado",
    "eldorados": "eldorado",
    "eldoradot": "eldorado",
    "eldoradots": "eldorado",
    "eldproven": "eldprov",
    "eldprovens": "eldprov",
    "eldprovet": "eldprov",
    "eldprovets": "eldprov",
    "eldprovs": "eldprov",
    "eldredskapen": "eldredskap",
    "eldredskapens": "eldredskap",
    "eldredskapet": "eldredskap",
    "eldredskapets": "eldredskap",
    "eldredskaps": "eldredskap",
    "eldriften": "eldrift",
    "eldriftens": "eldrift",
    "eldrifts": "eldrift",
    "eldrivens": "eldriven",
    "eldrivet": "eldriven",
    "eldrivets": "eldriven",
    "eldrivna": "eldriven",
    "eldrivnare": "eldriven",
    "eldrivnares": "eldriven",
    "eldrivnas": "eldriven",
    "eldrivnast": "eldriven",
    "eldrivnaste": "eldriven",
    "eldrivnastes": "eldriven",
    "eldrivnasts": "eldriven",
    "eldrivne": "eldriven",
    "eldrivnes": "eldriven",
    "eldröda": "eldröd",
    "eldrödare": "eldröd",
    "eldrödares": "eldröd",
    "eldrödas": "eldröd",
    "eldrödast": "eldröd",
    "eldrödaste": "eldröd",
    "eldrödastes": "eldröd",
    "eldrödasts": "eldröd",
    "eldröde": "eldröd",
    "eldrödes": "eldröd",
    "eldröds": "eldröd",
    "eldrören": "eldrör",
    "eldrörens": "eldrör",
    "eldröret": "eldrör",
    "eldrörets": "eldrör",
    "eldrörs": "eldrör",
    "eldrött": "eldröd",
    "eldrötts": "eldröd",
    "elds": "eld",
    "eldsalamandern": "eldsalamander",
    "eldsalamanderns": "eldsalamander",
    "eldsalamanders": "eldsalamander",
    "eldsalamandrar": "eldsalamander",
    "eldsalamandrarna": "eldsalamander",
    "eldsalamandrarnas": "eldsalamander",
    "eldsalamandrars": "eldsalamander",
    "eldsatsen": "eldsats",
    "eldsatsens": "eldsats",
    "eldsatser": "eldsats",
    "eldsatserna": "eldsats",
    "eldsatsernas": "eldsats",
    "eldsatsers": "eldsats",
    "eldsignalen": "eldsignal",
    "eldsignalens": "eldsignal",
    "eldsignaler": "eldsignal",
    "eldsignaleringar": "eldsignalering",
    "eldsignaleringarna": "eldsignalering",
    "eldsignaleringarnas": "eldsignalering",
    "eldsignaleringars": "eldsignalering",
    "eldsignaleringen": "eldsignalering",
    "eldsignaleringens": "eldsignalering",
    "eldsignalerings": "eldsignalering",
    "eldsignalerna": "eldsignal",
    "eldsignalernas": "eldsignal",
    "eldsignalers": "eldsignal",
    "eldsignals": "eldsignal",
    "eldsjälar": "eldsjäl",
    "eldsjälarna": "eldsjäl",
    "eldsjälarnas": "eldsjäl",
    "eldsjälars": "eldsjäl",
    "eldsjälen": "eldsjäl",
    "eldsjälens": "eldsjäl",
    "eldsjäls": "eldsjäl",
    "eldskenen": "eldsken",
    "eldskenens": "eldsken",
    "eldskenet": "eldsken",
    "eldskenets": "eldsken",
    "eldskens": "eldsken",
    "eldskriften": "eldskrift",
    "eldskriftens": "eldskrift",
    "eldskrifts": "eldskrift",
    "eldskurar": "eldskur",
    "eldskurarna": "eldskur",
    "eldskurarnas": "eldskur",
    "eldskurars": "eldskur",
    "eldskuren": "eldskur",
    "eldskurens": "eldskur",
    "eldskurs": "eldskur",
    "eldskyddet": "eldskydd",
    "eldskyddets": "eldskydd",
    "eldskydds": "eldskydd",
    "eldsljusen": "eldsljus",
    "eldsljusens": "eldsljus",
    "eldsljuset": "eldsljus",
    "eldsljusets": "eldsljus",
    "eldslukar": "eldslukare",
    "eldslukaren": "eldslukare",
    "eldslukarens": "eldslukare",
    "eldslukares": "eldslukare",
    "eldslukarna": "eldslukare",
    "eldslukarnas": "eldslukare",
    "eldsläckar": "eldsläckare",
    "eldsläckaren": "eldsläckare",
    "eldsläckarens": "eldsläckare",
    "eldsläckares": "eldsläckare",
    "eldsläckarna": "eldsläckare",
    "eldsläckarnas": "eldsläckare",
    "eldsläckningar": "eldsläckning",
    "eldsläckningarna": "eldsläckning",
    "eldsläckningarnas": "eldsläckning",
    "eldsläckningars": "eldsläckning",
    "eldsläckningen": "eldsläckning",
    "eldsläckningens": "eldsläckning",
    "eldsläcknings": "eldsläckning",
    "eldsländar": "eldsländare",
    "eldsländaren": "eldsländare",
    "eldsländarens": "eldsländare",
    "eldsländares": "eldsländare",
    "eldsländarna": "eldsländare",
    "eldsländarnas": "eldsländare",
    "eldsmärken": "eldsmärke",
    "eldsmärkena": "eldsmärke",
    "eldsmärkenas": "eldsmärke",
    "eldsmärkens": "eldsmärke",
    "eldsmärkes": "eldsmärke",
    "eldsmärket": "eldsmärke",
    "eldsmärkets": "eldsmärke",
    "eldsprut": "eldspruta",
    "eldsprutan": "eldspruta",
    "eldsprutans": "eldspruta",
    "eldsprutas": "eldspruta",
    "eldsprute": "eldspruta",
    "eldsprutor": "eldspruta",
    "eldsprutorna": "eldspruta",
    "eldsprutornas": "eldspruta",
    "eldsprutors": "eldspruta",
    "eldspruts": "eldspruta",
    "eldstaden": "eldstad",
    "eldstadens": "eldstad",
    "eldstads": "eldstad",
    "eldstoden": "eldstod",
    "eldstodens": "eldstod",
    "eldstoder": "eldstod",
    "eldstoderna": "eldstod",
    "eldstodernas": "eldstod",
    "eldstoders": "eldstod",
    "eldstods": "eldstod",
    "eldstormar": "eldstorm",
    "eldstormarna": "eldstorm",
    "eldstormarnas": "eldstorm",
    "eldstormars": "eldstorm",
    "eldstormen": "eldstorm",
    "eldstormens": "eldstorm",
    "eldstorms": "eldstorm",
    "eldstriden": "eldstrid",
    "eldstridens": "eldstrid",
    "eldstrider": "eldstrid",
    "eldstriderna": "eldstrid",
    "eldstridernas": "eldstrid",
    "eldstriders": "eldstrid",
    "eldstrids": "eldstrid",
    "eldstäder": "eldstad",
    "eldstäderna": "eldstad",
    "eldstädernas": "eldstad",
    "eldstäders": "eldstad",
    "eldställningar": "eldställning",
    "eldställningarna": "eldställning",
    "eldställningarnas": "eldställning",
    "eldställningars": "eldställning",
    "eldställningen": "eldställning",
    "eldställningens": "eldställning",
    "eldställnings": "eldställning",
    "eldstålen": "eldstål",
    "eldstålens": "eldstål",
    "eldstålet": "eldstål",
    "eldstålets": "eldstål",
    "eldståls": "eldstål",
    "eldsvådan": "eldsvåda",
    "eldsvådans": "eldsvåda",
    "eldsvådas": "eldsvåda",
    "eldsvåde": "eldsvåda",
    "eldsvådeungar": "eldsvådeunge",
    "eldsvådeungarna": "eldsvådeunge",
    "eldsvådeungarnas": "eldsvådeunge",
    "eldsvådeungars": "eldsvådeunge",
    "eldsvådeungen": "eldsvådeunge",
    "eldsvådeungens": "eldsvådeunge",
    "eldsvådeunges": "eldsvådeunge",
    "eldsvådor": "eldsvåda",
    "eldsvådorna": "eldsvåda",
    "eldsvådornas": "eldsvåda",
    "eldsvådors": "eldsvåda",
    "eldsäkerheten": "eldsäkerhet",
    "eldsäkerhetens": "eldsäkerhet",
    "eldsäkerhets": "eldsäkerhet",
    "eldsäkers": "eldsäker",
    "eldsäkert": "eldsäker",
    "eldsäkerts": "eldsäker",
    "eldsäkra": "eldsäker",
    "eldsäkrad": "eldsäkra",
    "eldsäkrade": "eldsäkra",
    "eldsäkrades": "eldsäkra",
    "eldsäkrads": "eldsäkra",
    "eldsäkrande": "eldsäkra",
    "eldsäkranden": "eldsäkrande",
    "eldsäkrandena": "eldsäkrande",
    "eldsäkrandenas": "eldsäkrande",
    "eldsäkrandens": "eldsäkrande",
    "eldsäkrandes": "eldsäkrande",
    "eldsäkrandet": "eldsäkrande",
    "eldsäkrandets": "eldsäkrande",
    "eldsäkrar": "eldsäkra",
    "eldsäkrare": "eldsäker",
    "eldsäkrares": "eldsäker",
    "eldsäkras": "eldsäkra",
    "eldsäkrast": "eldsäker",
    "eldsäkraste": "eldsäker",
    "eldsäkrastes": "eldsäker",
    "eldsäkrasts": "eldsäker",
    "eldsäkrat": "eldsäkra",
    "eldsäkrats": "eldsäkra",
    "eldsäkre": "eldsäker",
    "eldsäkres": "eldsäker",
    "eldunderstödet": "eldunderstöd",
    "eldunderstödets": "eldunderstöd",
    "eldunderstöds": "eldunderstöd",
    "eldupphören": "eldupphör",
    "eldupphörens": "eldupphör",
    "eldupphöret": "eldupphör",
    "eldupphörets": "eldupphör",
    "eldupphörordern": "eldupphörorder",
    "eldupphörorderna": "eldupphörorder",
    "eldupphörordernas": "eldupphörorder",
    "eldupphörorderns": "eldupphörorder",
    "eldupphörorders": "eldupphörorder",
    "eldupphörordrar": "eldupphörorder",
    "eldupphörordrarna": "eldupphörorder",
    "eldupphörordrarnas": "eldupphörorder",
    "eldupphörordrars": "eldupphörorder",
    "eldupphörs": "eldupphör",
    "eldvaktade": "eldvakta",
    "eldvaktades": "eldvakta",
    "eldvaktande": "eldvakta",
    "eldvaktanden": "eldvaktande",
    "eldvaktandena": "eldvaktande",
    "eldvaktandenas": "eldvaktande",
    "eldvaktandens": "eldvaktande",
    "eldvaktandes": "eldvaktande",
    "eldvaktandet": "eldvaktande",
    "eldvaktandets": "eldvaktande",
    "eldvaktar": "eldvakta",
    "eldvaktas": "eldvakta",
    "eldvaktat": "eldvakta",
    "eldvaktats": "eldvakta",
    "eldvapens": "eldvapen",
    "eldvapnen": "eldvapen",
    "eldvapnens": "eldvapen",
    "eldvapnet": "eldvapen",
    "eldvapnets": "eldvapen",
    "eldvattens": "eldvatten",
    "eldvattnet": "eldvatten",
    "eldvattnets": "eldvatten",
    "eldverkans": "eldverkan",
    "eldytan": "eldyta",
    "eldytans": "eldyta",
    "eldytas": "eldyta",
    "eldyte": "eldyta",
    "eldytor": "eldyta",
    "eldytorna": "eldyta",
    "eldytornas": "eldyta",
    "eldytors": "eldyta",
    "eldöverfallen": "eldöverfall",
    "eldöverfallens": "eldöverfall",
    "eldöverfallet": "eldöverfall",
    "eldöverfallets": "eldöverfall",
    "eldöverfalls": "eldöverfall",
    "elefantbet": "elefantbete",
    "elefantbetar": "elefantbete",
    "elefantbetarna": "elefantbete",
    "elefantbetarnas": "elefantbete",
    "elefantbetars": "elefantbete",
    "elefantbeten": "elefantbete",
    "elefantbetens": "elefantbete",
    "elefantbetes": "elefantbete",
    "elefantbets": "elefantbete",
    "elefanten": "elefant",
    "elefantens": "elefant",
    "elefanter": "elefant",
    "elefanterna": "elefant",
    "elefanternas": "elefant",
    "elefanters": "elefant",
    "elefantgräset": "elefantgräs",
    "elefantgräsets": "elefantgräs",
    "elefanthuden": "elefanthud",
    "elefanthudens": "elefanthud",
    "elefanthuds": "elefanthud",
    "elefantinhoppen": "elefantinhopp",
    "elefantinhoppens": "elefantinhopp",
    "elefantinhoppet": "elefantinhopp",
    "elefantinhoppets": "elefantinhopp",
    "elefantinhopps": "elefantinhopp",
    "elefantnäbbmusen": "elefantnäbbmus",
    "elefantnäbbmusens": "elefantnäbbmus",
    "elefantnäbbmöss": "elefantnäbbmus",
    "elefantnäbbmössen": "elefantnäbbmus",
    "elefantnäbbmössens": "elefantnäbbmus",
    "elefants": "elefant",
    "elefantsjukan": "elefantsjuka",
    "elefantsjukans": "elefantsjuka",
    "elefantsjukas": "elefantsjuka",
    "elefantsjuke": "elefantsjuka",
    "elefantsjuks": "elefantsjuka",
    "elefantsköldpadd": "elefantsköldpadda",
    "elefantsköldpaddan": "elefantsköldpadda",
    "elefantsköldpaddans": "elefantsköldpadda",
    "elefantsköldpaddas": "elefantsköldpadda",
    "elefantsköldpadde": "elefantsköldpadda",
    "elefantsköldpaddor": "elefantsköldpadda",
    "elefantsköldpaddorna": "elefantsköldpadda",
    "elefantsköldpaddornas": "elefantsköldpadda",
    "elefantsköldpaddors": "elefantsköldpadda",
    "elefantsköldpadds": "elefantsköldpadda",
    "elegansen": "elegans",
    "elegansens": "elegans",
    "eleganta": "elegant",
    "elegantare": "elegant",
    "elegantares": "elegant",
    "elegantas": "elegant",
    "elegantast": "elegant",
    "elegantaste": "elegant",
    "elegantastes": "elegant",
    "elegantasts": "elegant",
    "elegante": "elegant",
    "elegantes": "elegant",
    "elegants": "elegant",
    "elegien": "elegi",
    "elegiens": "elegi",
    "elegier": "elegi",
    "elegierna": "elegi",
    "elegiernas": "elegi",
    "elegiers": "elegi",
    "elegin": "elegi",
    "elegins": "elegi",
    "elegis": "elegi",
    "elegiska": "elegisk",
    "elegiskare": "elegisk",
    "elegiskares": "elegisk",
    "elegiskas": "elegisk",
    "elegiskast": "elegisk",
    "elegiskaste": "elegisk",
    "elegiskastes": "elegisk",
    "elegiskasts": "elegisk",
    "elegiske": "elegisk",
    "elegiskes": "elegisk",
    "elegisks": "elegisk",
    "elegiskt": "elegisk",
    "elegiskts": "elegisk",
    "elektorer": "elektor",
    "elektorerna": "elektor",
    "elektorernas": "elektor",
    "elektorers": "elektor",
    "elektorn": "elektor",
    "elektorns": "elektor",
    "elektors": "elektor",
    "elektriciteten": "elektricitet",
    "elektricitetens": "elektricitet",
    "elektriciteter": "elektricitet",
    "elektriciteterna": "elektricitet",
    "elektriciteternas": "elektricitet",
    "elektriciteters": "elektricitet",
    "elektricitets": "elektricitet",
    "elektricitetsmängden": "elektricitetsmängd",
    "elektricitetsmängdens": "elektricitetsmängd",
    "elektricitetsmängder": "elektricitetsmängd",
    "elektricitetsmängderna": "elektricitetsmängd",
    "elektricitetsmängdernas": "elektricitetsmängd",
    "elektricitetsmängders": "elektricitetsmängd",
    "elektricitetsmängds": "elektricitetsmängd",
    "elektricitetsorsakade": "elektricitetsorsakad",
    "elektricitetsorsakades": "elektricitetsorsakad",
    "elektricitetsorsakads": "elektricitetsorsakad",
    "elektricitetsorsakat": "elektricitetsorsakad",
    "elektricitetsorsakats": "elektricitetsorsakad",
    "elektricitetsverken": "elektricitetsverk",
    "elektricitetsverkens": "elektricitetsverk",
    "elektricitetsverket": "elektricitetsverk",
    "elektricitetsverkets": "elektricitetsverk",
    "elektricitetsverks": "elektricitetsverk",
    "elektrificerad": "elektrificera",
    "elektrificerade": "elektrificera",
    "elektrificerades": "elektrificera",
    "elektrificerads": "elektrificera",
    "elektrificerande": "elektrificera",
    "elektrificeranden": "elektrificerande",
    "elektrificerandena": "elektrificerande",
    "elektrificerandenas": "elektrificerande",
    "elektrificerandens": "elektrificerande",
    "elektrificerandes": "elektrificerande",
    "elektrificerandet": "elektrificerande",
    "elektrificerandets": "elektrificerande",
    "elektrificerar": "elektrificera",
    "elektrificeras": "elektrificera",
    "elektrificerat": "elektrificera",
    "elektrificerats": "elektrificera",
    "elektrificerbara": "elektrificerbar",
    "elektrificerbarare": "elektrificerbar",
    "elektrificerbarares": "elektrificerbar",
    "elektrificerbaras": "elektrificerbar",
    "elektrificerbarast": "elektrificerbar",
    "elektrificerbaraste": "elektrificerbar",
    "elektrificerbarastes": "elektrificerbar",
    "elektrificerbarasts": "elektrificerbar",
    "elektrificerbare": "elektrificerbar",
    "elektrificerbares": "elektrificerbar",
    "elektrificerbarheten": "elektrificerbarhet",
    "elektrificerbarhetens": "elektrificerbarhet",
    "elektrificerbarhets": "elektrificerbarhet",
    "elektrificerbars": "elektrificerbar",
    "elektrificerbart": "elektrificerbar",
    "elektrificerbarts": "elektrificerbar",
    "elektrificeringar": "elektrificering",
    "elektrificeringarna": "elektrificering",
    "elektrificeringarnas": "elektrificering",
    "elektrificeringars": "elektrificering",
    "elektrificeringen": "elektrificering",
    "elektrificeringens": "elektrificering",
    "elektrificerings": "elektrificering",
    "elektrifierad": "elektrifiera",
    "elektrifierade": "elektrifiera",
    "elektrifierades": "elektrifiera",
    "elektrifierads": "elektrifiera",
    "elektrifierande": "elektrifiera",
    "elektrifieranden": "elektrifierande",
    "elektrifierandena": "elektrifierande",
    "elektrifierandenas": "elektrifierande",
    "elektrifierandens": "elektrifierande",
    "elektrifierandes": "elektrifierande",
    "elektrifierandet": "elektrifierande",
    "elektrifierandets": "elektrifierande",
    "elektrifierar": "elektrifiera",
    "elektrifieras": "elektrifiera",
    "elektrifierat": "elektrifiera",
    "elektrifierats": "elektrifiera",
    "elektrifierbara": "elektrifierbar",
    "elektrifierbarare": "elektrifierbar",
    "elektrifierbarares": "elektrifierbar",
    "elektrifierbaras": "elektrifierbar",
    "elektrifierbarast": "elektrifierbar",
    "elektrifierbaraste": "elektrifierbar",
    "elektrifierbarastes": "elektrifierbar",
    "elektrifierbarasts": "elektrifierbar",
    "elektrifierbare": "elektrifierbar",
    "elektrifierbares": "elektrifierbar",
    "elektrifierbarheten": "elektrifierbarhet",
    "elektrifierbarhetens": "elektrifierbarhet",
    "elektrifierbarhets": "elektrifierbarhet",
    "elektrifierbars": "elektrifierbar",
    "elektrifierbart": "elektrifierbar",
    "elektrifierbarts": "elektrifierbar",
    "elektrifieringar": "elektrifiering",
    "elektrifieringarna": "elektrifiering",
    "elektrifieringarnas": "elektrifiering",
    "elektrifieringars": "elektrifiering",
    "elektrifieringen": "elektrifiering",
    "elektrifieringens": "elektrifiering",
    "elektrifierings": "elektrifiering",
    "elektrikermejseln": "elektrikermejsel",
    "elektrikermejselns": "elektrikermejsel",
    "elektrikermejsels": "elektrikermejsel",
    "elektrikermejselsatsen": "elektrikermejselsats",
    "elektrikermejselsatsens": "elektrikermejselsats",
    "elektrikermejselsatser": "elektrikermejselsats",
    "elektrikermejselsatserna": "elektrikermejselsats",
    "elektrikermejselsatsernas": "elektrikermejselsats",
    "elektrikermejselsatsers": "elektrikermejselsats",
    "elektrikermejslar": "elektrikermejsel",
    "elektrikermejslarna": "elektrikermejsel",
    "elektrikermejslarnas": "elektrikermejsel",
    "elektrikermejslars": "elektrikermejsel",
    "elektrikern": "elektriker",
    "elektrikerna": "elektriker",
    "elektrikernas": "elektriker",
    "elektrikerns": "elektriker",
    "elektrikers": "elektriker",
    "elektriserad": "elektrisera",
    "elektriserade": "elektrisera",
    "elektriserades": "elektrisera",
    "elektriserads": "elektrisera",
    "elektriserande": "elektrisera",
    "elektriseranden": "elektriserande",
    "elektriserandena": "elektriserande",
    "elektriserandenas": "elektriserande",
    "elektriserandens": "elektriserande",
    "elektriserandes": "elektriserande",
    "elektriserandet": "elektriserande",
    "elektriserandets": "elektriserande",
    "elektriserar": "elektrisera",
    "elektriseras": "elektrisera",
    "elektriserat": "elektrisera",
    "elektriserats": "elektrisera",
    "elektriserbara": "elektriserbar",
    "elektriserbarare": "elektriserbar",
    "elektriserbarares": "elektriserbar",
    "elektriserbaras": "elektriserbar",
    "elektriserbarast": "elektriserbar",
    "elektriserbaraste": "elektriserbar",
    "elektriserbarastes": "elektriserbar",
    "elektriserbarasts": "elektriserbar",
    "elektriserbare": "elektriserbar",
    "elektriserbares": "elektriserbar",
    "elektriserbarheten": "elektriserbarhet",
    "elektriserbarhetens": "elektriserbarhet",
    "elektriserbarhets": "elektriserbarhet",
    "elektriserbars": "elektriserbar",
    "elektriserbart": "elektriserbar",
    "elektriserbarts": "elektriserbar",
    "elektriseringar": "elektrisering",
    "elektriseringarna": "elektrisering",
    "elektriseringarnas": "elektrisering",
    "elektriseringars": "elektrisering",
    "elektriseringen": "elektrisering",
    "elektriseringens": "elektrisering",
    "elektriserings": "elektrisering",
    "elektriska": "elektrisk",
    "elektriskare": "elektrisk",
    "elektriskares": "elektrisk",
    "elektriskas": "elektrisk",
    "elektriskast": "elektrisk",
    "elektriskaste": "elektrisk",
    "elektriskastes": "elektrisk",
    "elektriskasts": "elektrisk",
    "elektriske": "elektrisk",
    "elektriskes": "elektrisk",
    "elektrisks": "elektrisk",
    "elektriskt": "elektrisk",
    "elektriskts": "elektrisk",
    "elektroakustiken": "elektroakustik",
    "elektroakustikens": "elektroakustik",
    "elektroakustiks": "elektroakustik",
    "elektrochocken": "elektrochock",
    "elektrochockens": "elektrochock",
    "elektrochocker": "elektrochock",
    "elektrochockerna": "elektrochock",
    "elektrochockernas": "elektrochock",
    "elektrochockers": "elektrochock",
    "elektrochocks": "elektrochock",
    "elektroden": "elektrod",
    "elektrodens": "elektrod",
    "elektroder": "elektrod",
    "elektroderna": "elektrod",
    "elektrodernas": "elektrod",
    "elektroders": "elektrod",
    "elektrods": "elektrod",
    "elektrodynamiken": "elektrodynamik",
    "elektrodynamikens": "elektrodynamik",
    "elektrodynamiks": "elektrodynamik",
    "elektroencefalografien": "elektroencefalografi",
    "elektroencefalografiens": "elektroencefalografi",
    "elektroencefalografier": "elektroencefalografi",
    "elektroencefalografierna": "elektroencefalografi",
    "elektroencefalografiernas": "elektroencefalografi",
    "elektroencefalografiers": "elektroencefalografi",
    "elektroencefalografin": "elektroencefalografi",
    "elektroencefalografins": "elektroencefalografi",
    "elektroencefalografis": "elektroencefalografi",
    "elektroencefalogrammen": "elektroencefalogram",
    "elektroencefalogrammens": "elektroencefalogram",
    "elektroencefalogrammet": "elektroencefalogram",
    "elektroencefalogrammets": "elektroencefalogram",
    "elektroencefalograms": "elektroencefalogram",
    "elektrofilterna": "elektrofilter",
    "elektrofilternas": "elektrofilter",
    "elektrofilters": "elektrofilter",
    "elektrofiltren": "elektrofilter",
    "elektrofiltrens": "elektrofilter",
    "elektrofiltret": "elektrofilter",
    "elektrofiltrets": "elektrofilter",
    "elektroforen": "elektrofor",
    "elektroforens": "elektrofor",
    "elektroforer": "elektrofor",
    "elektroforerna": "elektrofor",
    "elektroforernas": "elektrofor",
    "elektroforers": "elektrofor",
    "elektroforesen": "elektrofores",
    "elektroforesens": "elektrofores",
    "elektrofors": "elektrofor",
    "elektrofysiken": "elektrofysik",
    "elektrofysikens": "elektrofysik",
    "elektrofysiks": "elektrofysik",
    "elektroingenjören": "elektroingenjör",
    "elektroingenjörens": "elektroingenjör",
    "elektroingenjörer": "elektroingenjör",
    "elektroingenjörerna": "elektroingenjör",
    "elektroingenjörernas": "elektroingenjör",
    "elektroingenjörers": "elektroingenjör",
    "elektroingenjörn": "elektroingenjör",
    "elektroingenjörns": "elektroingenjör",
    "elektroingenjörs": "elektroingenjör",
    "elektrokardiografien": "elektrokardiografi",
    "elektrokardiografiens": "elektrokardiografi",
    "elektrokardiografier": "elektrokardiografi",
    "elektrokardiografierna": "elektrokardiografi",
    "elektrokardiografiernas": "elektrokardiografi",
    "elektrokardiografiers": "elektrokardiografi",
    "elektrokardiografin": "elektrokardiografi",
    "elektrokardiografins": "elektrokardiografi",
    "elektrokardiografis": "elektrokardiografi",
    "elektrokardiogrammen": "elektrokardiogram",
    "elektrokardiogrammens": "elektrokardiogram",
    "elektrokardiogrammet": "elektrokardiogram",
    "elektrokardiogrammets": "elektrokardiogram",
    "elektrokardiograms": "elektrokardiogram",
    "elektrokemien": "elektrokemi",
    "elektrokemiens": "elektrokemi",
    "elektrokemin": "elektrokemi",
    "elektrokemins": "elektrokemi",
    "elektrokemis": "elektrokemi",
    "elektrokemiska": "elektrokemisk",
    "elektrokemiskare": "elektrokemisk",
    "elektrokemiskares": "elektrokemisk",
    "elektrokemiskas": "elektrokemisk",
    "elektrokemiskast": "elektrokemisk",
    "elektrokemiskaste": "elektrokemisk",
    "elektrokemiskastes": "elektrokemisk",
    "elektrokemiskasts": "elektrokemisk",
    "elektrokemiske": "elektrokemisk",
    "elektrokemiskes": "elektrokemisk",
    "elektrokemisks": "elektrokemisk",
    "elektrokemiskt": "elektrokemisk",
    "elektrokemiskts": "elektrokemisk",
    "elektrolysen": "elektrolys",
    "elektrolysens": "elektrolys",
    "elektrolyser": "elektrolys",
    "elektrolyserna": "elektrolys",
    "elektrolysernas": "elektrolys",
    "elektrolysers": "elektrolys",
    "elektrolyten": "elektrolyt",
    "elektrolytens": "elektrolyt",
    "elektrolyter": "elektrolyt",
    "elektrolyterna": "elektrolyt",
    "elektrolyternas": "elektrolyt",
    "elektrolyters": "elektrolyt",
    "elektrolytiska": "elektrolytisk",
    "elektrolytiskare": "elektrolytisk",
    "elektrolytiskares": "elektrolytisk",
    "elektrolytiskas": "elektrolytisk",
    "elektrolytiskast": "elektrolytisk",
    "elektrolytiskaste": "elektrolytisk",
    "elektrolytiskastes": "elektrolytisk",
    "elektrolytiskasts": "elektrolytisk",
    "elektrolytiske": "elektrolytisk",
    "elektrolytiskes": "elektrolytisk",
    "elektrolytisks": "elektrolytisk",
    "elektrolytiskt": "elektrolytisk",
    "elektrolytiskts": "elektrolytisk",
    "elektrolyts": "elektrolyt",
    "elektromagneten": "elektromagnet",
    "elektromagnetens": "elektromagnet",
    "elektromagneter": "elektromagnet",
    "elektromagneterna": "elektromagnet",
    "elektromagneternas": "elektromagnet",
    "elektromagneters": "elektromagnet",
    "elektromagnetiska": "elektromagnetisk",
    "elektromagnetiskare": "elektromagnetisk",
    "elektromagnetiskares": "elektromagnetisk",
    "elektromagnetiskas": "elektromagnetisk",
    "elektromagnetiskast": "elektromagnetisk",
    "elektromagnetiskaste": "elektromagnetisk",
    "elektromagnetiskastes": "elektromagnetisk",
    "elektromagnetiskasts": "elektromagnetisk",
    "elektromagnetiske": "elektromagnetisk",
    "elektromagnetiskes": "elektromagnetisk",
    "elektromagnetisks": "elektromagnetisk",
    "elektromagnetiskt": "elektromagnetisk",
    "elektromagnetiskts": "elektromagnetisk",
    "elektromagnetismen": "elektromagnetism",
    "elektromagnetismens": "elektromagnetism",
    "elektromagnetismer": "elektromagnetism",
    "elektromagnetismerna": "elektromagnetism",
    "elektromagnetismernas": "elektromagnetism",
    "elektromagnetismers": "elektromagnetism",
    "elektromagnetisms": "elektromagnetism",
    "elektromagnets": "elektromagnet",
    "elektromekaniska": "elektromekanisk",
    "elektromekaniskare": "elektromekanisk",
    "elektromekaniskares": "elektromekanisk",
    "elektromekaniskas": "elektromekanisk",
    "elektromekaniskast": "elektromekanisk",
    "elektromekaniskaste": "elektromekanisk",
    "elektromekaniskastes": "elektromekanisk",
    "elektromekaniskasts": "elektromekanisk",
    "elektromekaniske": "elektromekanisk",
    "elektromekaniskes": "elektromekanisk",
    "elektromekanisks": "elektromekanisk",
    "elektromekaniskt": "elektromekanisk",
    "elektromekaniskts": "elektromekanisk",
    "elektrometallurgien": "elektrometallurgi",
    "elektrometallurgiens": "elektrometallurgi",
    "elektrometallurgin": "elektrometallurgi",
    "elektrometallurgins": "elektrometallurgi",
    "elektrometallurgis": "elektrometallurgi",
    "elektrometern": "elektrometer",
    "elektrometerns": "elektrometer",
    "elektrometers": "elektrometer",
    "elektrometrar": "elektrometer",
    "elektrometrarna": "elektrometer",
    "elektrometrarnas": "elektrometer",
    "elektrometrars": "elektrometer",
    "elektromotorer": "elektromotor",
    "elektromotorerna": "elektromotor",
    "elektromotorernas": "elektromotor",
    "elektromotorers": "elektromotor",
    "elektromotoriska": "elektromotorisk",
    "elektromotoriskare": "elektromotorisk",
    "elektromotoriskares": "elektromotorisk",
    "elektromotoriskas": "elektromotorisk",
    "elektromotoriskast": "elektromotorisk",
    "elektromotoriskaste": "elektromotorisk",
    "elektromotoriskastes": "elektromotorisk",
    "elektromotoriskasts": "elektromotorisk",
    "elektromotoriske": "elektromotorisk",
    "elektromotoriskes": "elektromotorisk",
    "elektromotorisks": "elektromotorisk",
    "elektromotoriskt": "elektromotorisk",
    "elektromotoriskts": "elektromotorisk",
    "elektromotorn": "elektromotor",
    "elektromotorns": "elektromotor",
    "elektromotors": "elektromotor",
    "elektronbanan": "elektronbana",
    "elektronbanans": "elektronbana",
    "elektronbanas": "elektronbana",
    "elektronbane": "elektronbana",
    "elektronbanor": "elektronbana",
    "elektronbanorna": "elektronbana",
    "elektronbanornas": "elektronbana",
    "elektronbanors": "elektronbana",
    "elektronblixtar": "elektronblixt",
    "elektronblixtarna": "elektronblixt",
    "elektronblixtarnas": "elektronblixt",
    "elektronblixtars": "elektronblixt",
    "elektronblixten": "elektronblixt",
    "elektronblixtens": "elektronblixt",
    "elektronblixts": "elektronblixt",
    "elektronegativiteten": "elektronegativitet",
    "elektronegativitetens": "elektronegativitet",
    "elektronegativiteter": "elektronegativitet",
    "elektronegativiteterna": "elektronegativitet",
    "elektronegativiteternas": "elektronegativitet",
    "elektronegativiteters": "elektronegativitet",
    "elektronegativitets": "elektronegativitet",
    "elektronen": "elektron",
    "elektronens": "elektron",
    "elektroner": "elektron",
    "elektronerna": "elektron",
    "elektronernas": "elektron",
    "elektroners": "elektron",
    "elektronet": "elektron",
    "elektronets": "elektron",
    "elektronhöljen": "elektronhölje",
    "elektronhöljena": "elektronhölje",
    "elektronhöljenas": "elektronhölje",
    "elektronhöljens": "elektronhölje",
    "elektronhöljes": "elektronhölje",
    "elektronhöljet": "elektronhölje",
    "elektronhöljets": "elektronhölje",
    "elektronhöljs": "elektronhölje",
    "elektroniken": "elektronik",
    "elektronikens": "elektronik",
    "elektronikkomponenten": "elektronikkomponent",
    "elektronikkomponentens": "elektronikkomponent",
    "elektronikkomponenter": "elektronikkomponent",
    "elektronikkomponenterna": "elektronikkomponent",
    "elektronikkomponenternas": "elektronikkomponent",
    "elektronikkomponenters": "elektronikkomponent",
    "elektronikkomponents": "elektronikkomponent",
    "elektronikmejseln": "elektronikmejsel",
    "elektronikmejselns": "elektronikmejsel",
    "elektronikmejsels": "elektronikmejsel",
    "elektronikmejslar": "elektronikmejsel",
    "elektronikmejslarna": "elektronikmejsel",
    "elektronikmejslarnas": "elektronikmejsel",
    "elektronikmejslars": "elektronikmejsel",
    "elektroniks": "elektronik",
    "elektroniska": "elektronisk",
    "elektroniskare": "elektronisk",
    "elektroniskares": "elektronisk",
    "elektroniskas": "elektronisk",
    "elektroniskast": "elektronisk",
    "elektroniskaste": "elektronisk",
    "elektroniskastes": "elektronisk",
    "elektroniskasts": "elektronisk",
    "elektroniske": "elektronisk",
    "elektroniskes": "elektronisk",
    "elektronisks": "elektronisk",
    "elektroniskt": "elektronisk",
    "elektroniskts": "elektronisk",
    "elektronkameran": "elektronkamera",
    "elektronkamerans": "elektronkamera",
    "elektronkameras": "elektronkamera",
    "elektronkameror": "elektronkamera",
    "elektronkamerorna": "elektronkamera",
    "elektronkamerornas": "elektronkamera",
    "elektronkamerors": "elektronkamera",
    "elektronmikroskopbilden": "elektronmikroskopbild",
    "elektronmikroskopbildens": "elektronmikroskopbild",
    "elektronmikroskopbilder": "elektronmikroskopbild",
    "elektronmikroskopbilderna": "elektronmikroskopbild",
    "elektronmikroskopbildernas": "elektronmikroskopbild",
    "elektronmikroskopbilders": "elektronmikroskopbild",
    "elektronmikroskopbilds": "elektronmikroskopbild",
    "elektronmikroskopen": "elektronmikroskop",
    "elektronmikroskopens": "elektronmikroskop",
    "elektronmikroskopet": "elektronmikroskop",
    "elektronmikroskopets": "elektronmikroskop",
    "elektronmikroskopien": "elektronmikroskopi",
    "elektronmikroskopiens": "elektronmikroskopi",
    "elektronmikroskopier": "elektronmikroskopi",
    "elektronmikroskopierna": "elektronmikroskopi",
    "elektronmikroskopiernas": "elektronmikroskopi",
    "elektronmikroskopiers": "elektronmikroskopi",
    "elektronmikroskopin": "elektronmikroskopi",
    "elektronmikroskopins": "elektronmikroskopi",
    "elektronmikroskopis": "elektronmikroskopi",
    "elektronmikroskops": "elektronmikroskop",
    "elektronmolnen": "elektronmoln",
    "elektronmolnens": "elektronmoln",
    "elektronmolnet": "elektronmoln",
    "elektronmolnets": "elektronmoln",
    "elektronmolns": "elektronmoln",
    "elektronparbindningar": "elektronparbindning",
    "elektronparbindningarna": "elektronparbindning",
    "elektronparbindningarnas": "elektronparbindning",
    "elektronparbindningars": "elektronparbindning",
    "elektronparbindningen": "elektronparbindning",
    "elektronparbindningens": "elektronparbindning",
    "elektronparbindnings": "elektronparbindning",
    "elektronparen": "elektronpar",
    "elektronparens": "elektronpar",
    "elektronparet": "elektronpar",
    "elektronparets": "elektronpar",
    "elektronpars": "elektronpar",
    "elektronrören": "elektronrör",
    "elektronrörens": "elektronrör",
    "elektronröret": "elektronrör",
    "elektronrörets": "elektronrör",
    "elektronrörs": "elektronrör",
    "elektronrörsdioden": "elektronrörsdiod",
    "elektronrörsdiodens": "elektronrörsdiod",
    "elektronrörsdioder": "elektronrörsdiod",
    "elektronrörsdioderna": "elektronrörsdiod",
    "elektronrörsdiodernas": "elektronrörsdiod",
    "elektronrörsdioders": "elektronrörsdiod",
    "elektronrörsdiods": "elektronrörsdiod",
    "elektrons": "elektron",
    "elektronskalen": "elektronskal",
    "elektronskalens": "elektronskal",
    "elektronskalet": "elektronskal",
    "elektronskalets": "elektronskal",
    "elektronskals": "elektronskal",
    "elektronstrål": "elektronstråle",
    "elektronstrålar": "elektronstråle",
    "elektronstrålarna": "elektronstråle",
    "elektronstrålarnas": "elektronstråle",
    "elektronstrålars": "elektronstråle",
    "elektronstrålen": "elektronstråle",
    "elektronstrålens": "elektronstråle",
    "elektronstråles": "elektronstråle",
    "elektronstråls": "elektronstråle",
    "elektronugnar": "elektronugn",
    "elektronugnarna": "elektronugn",
    "elektronugnarnas": "elektronugn",
    "elektronugnars": "elektronugn",
    "elektronugnen": "elektronugn",
    "elektronugnens": "elektronugn",
    "elektronugns": "elektronugn",
    "elektronvolten": "elektronvolt",
    "elektronvoltens": "elektronvolt",
    "elektronvolts": "elektronvolt",
    "elektroskopen": "elektroskop",
    "elektroskopens": "elektroskop",
    "elektroskopet": "elektroskop",
    "elektroskopets": "elektroskop",
    "elektroskops": "elektroskop",
    "elektrostatiken": "elektrostatik",
    "elektrostatikens": "elektrostatik",
    "elektrostatiks": "elektrostatik",
    "elektrostatiska": "elektrostatisk",
    "elektrostatiskare": "elektrostatisk",
    "elektrostatiskares": "elektrostatisk",
    "elektrostatiskas": "elektrostatisk",
    "elektrostatiskast": "elektrostatisk",
    "elektrostatiskaste": "elektrostatisk",
    "elektrostatiskastes": "elektrostatisk",
    "elektrostatiskasts": "elektrostatisk",
    "elektrostatiske": "elektrostatisk",
    "elektrostatiskes": "elektrostatisk",
    "elektrostatisks": "elektrostatisk",
    "elektrostatiskt": "elektrostatisk",
    "elektrostatiskts": "elektrostatisk",
    "elektrostriktionen": "elektrostriktion",
    "elektrostriktionens": "elektrostriktion",
    "elektrostriktioner": "elektrostriktion",
    "elektrostriktionerna": "elektrostriktion",
    "elektrostriktionernas": "elektrostriktion",
    "elektrostriktioners": "elektrostriktion",
    "elektrostriktions": "elektrostriktion",
    "elektrostålet": "elektrostål",
    "elektrostålets": "elektrostål",
    "elektroståls": "elektrostål",
    "elektrosvaga": "elektrosvag",
    "elektrosvagare": "elektrosvag",
    "elektrosvagares": "elektrosvag",
    "elektrosvagas": "elektrosvag",
    "elektrosvagast": "elektrosvag",
    "elektrosvagaste": "elektrosvag",
    "elektrosvagastes": "elektrosvag",
    "elektrosvagasts": "elektrosvag",
    "elektrosvage": "elektrosvag",
    "elektrosvages": "elektrosvag",
    "elektrosvags": "elektrosvag",
    "elektrosvagt": "elektrosvag",
    "elektrosvagts": "elektrosvag",
    "elektrotekniken": "elektroteknik",
    "elektroteknikens": "elektroteknik",
    "elektroteknikern": "elektrotekniker",
    "elektroteknikerna": "elektrotekniker",
    "elektroteknikernas": "elektrotekniker",
    "elektroteknikerns": "elektrotekniker",
    "elektroteknikers": "elektrotekniker",
    "elektrotekniks": "elektroteknik",
    "elektrotekniska": "elektroteknisk",
    "elektrotekniskare": "elektroteknisk",
    "elektrotekniskares": "elektroteknisk",
    "elektrotekniskas": "elektroteknisk",
    "elektrotekniskast": "elektroteknisk",
    "elektrotekniskaste": "elektroteknisk",
    "elektrotekniskastes": "elektroteknisk",
    "elektrotekniskasts": "elektroteknisk",
    "elektrotekniske": "elektroteknisk",
    "elektrotekniskes": "elektroteknisk",
    "elektroteknisks": "elektroteknisk",
    "elektrotekniskt": "elektroteknisk",
    "elektrotekniskts": "elektroteknisk",
    "elektroterapien": "elektroterapi",
    "elektroterapiens": "elektroterapi",
    "elektroterapin": "elektroterapi",
    "elektroterapins": "elektroterapi",
    "elektroterapis": "elektroterapi",
    "elektrotypen": "elektrotyp",
    "elektrotypens": "elektrotyp",
    "elektrotyper": "elektrotyp",
    "elektrotyperna": "elektrotyp",
    "elektrotypernas": "elektrotyp",
    "elektrotypers": "elektrotyp",
    "elektrotyps": "elektrotyp",
    "elementan": "elementa",
    "elementana": "elementa",
    "elementanas": "elementa",
    "elementans": "elementa",
    "elementaranalysen": "elementaranalys",
    "elementaranalysens": "elementaranalys",
    "elementarandar": "elementarande",
    "elementarandarna": "elementarande",
    "elementarandarnas": "elementarande",
    "elementarandars": "elementarande",
    "elementaranden": "elementarande",
    "elementarandens": "elementarande",
    "elementarandes": "elementarande",
    "elementarboken": "elementarbok",
    "elementarbokens": "elementarbok",
    "elementarboks": "elementarbok",
    "elementarböcker": "elementarbok",
    "elementarböckerna": "elementarbok",
    "elementarböckernas": "elementarbok",
    "elementarböckers": "elementarbok",
    "elementarladdningar": "elementarladdning",
    "elementarladdningarna": "elementarladdning",
    "elementarladdningarnas": "elementarladdning",
    "elementarladdningars": "elementarladdning",
    "elementarladdningen": "elementarladdning",
    "elementarladdningens": "elementarladdning",
    "elementarladdnings": "elementarladdning",
    "elementarpartikeln": "elementarpartikel",
    "elementarpartikelns": "elementarpartikel",
    "elementarpartikels": "elementarpartikel",
    "elementarpartiklar": "elementarpartikel",
    "elementarpartiklarna": "elementarpartikel",
    "elementarpartiklarnas": "elementarpartikel",
    "elementarpartiklars": "elementarpartikel",
    "elementarskolan": "elementarskola",
    "elementarskolans": "elementarskola",
    "elementarskolas": "elementarskola",
    "elementarskole": "elementarskola",
    "elementarskolor": "elementarskola",
    "elementarskolorna": "elementarskola",
    "elementarskolornas": "elementarskola",
    "elementarskolors": "elementarskola",
    "elementas": "elementa",
    "elementat": "elementa",
    "elementats": "elementa",
    "elementen": "element",
    "elementens": "element",
    "elementet": "element",
    "elementets": "element",
    "elementfärgen": "elementfärg",
    "elementfärgens": "elementfärg",
    "elementfärger": "elementfärg",
    "elementfärgerna": "elementfärg",
    "elementfärgernas": "elementfärg",
    "elementfärgers": "elementfärg",
    "elementfärgs": "elementfärg",
    "elementpenseln": "elementpensel",
    "elementpenselns": "elementpensel",
    "elementpensels": "elementpensel",
    "elementpenslar": "elementpensel",
    "elementpenslarna": "elementpensel",
    "elementpenslarnas": "elementpensel",
    "elementpenslars": "elementpensel",
    "elements": "element",
    "elementära": "elementär",
    "elementärare": "elementär",
    "elementärares": "elementär",
    "elementäras": "elementär",
    "elementärast": "elementär",
    "elementäraste": "elementär",
    "elementärastes": "elementär",
    "elementärasts": "elementär",
    "elementäre": "elementär",
    "elementäres": "elementär",
    "elementärkraften": "elementärkraft",
    "elementärkraftens": "elementärkraft",
    "elementärkrafter": "elementärkraft",
    "elementärkrafterna": "elementärkraft",
    "elementärkrafternas": "elementärkraft",
    "elementärkrafters": "elementärkraft",
    "elementärkrafts": "elementärkraft",
    "elementärs": "elementär",
    "elementärt": "elementär",
    "elementärts": "elementär",
    "elen": "el",
    "elenergien": "elenergi",
    "elenergiens": "elenergi",
    "elenergin": "elenergi",
    "elenergins": "elenergi",
    "elenergis": "elenergi",
    "elens": "el",
    "elevationen": "elevation",
    "elevationens": "elevation",
    "elevationer": "elevation",
    "elevationerna": "elevation",
    "elevationernas": "elevation",
    "elevationers": "elevation",
    "elevations": "elevation",
    "elevatorer": "elevator",
    "elevatorerna": "elevator",
    "elevatorernas": "elevator",
    "elevatorers": "elevator",
    "elevatorn": "elevator",
    "elevatorns": "elevator",
    "elevators": "elevator",
    "eleven": "elev",
    "elevens": "elev",
    "elever": "elev",
    "eleverna": "elev",
    "elevernas": "elev",
    "elevers": "elev",
    "elevfartygen": "elevfartyg",
    "elevfartygens": "elevfartyg",
    "elevfartyget": "elevfartyg",
    "elevfartygets": "elevfartyg",
    "elevfartygs": "elevfartyg",
    "elevhemmen": "elevhem",
    "elevhemmens": "elevhem",
    "elevhemmet": "elevhem",
    "elevhemmets": "elevhem",
    "elevhems": "elevhem",
    "elevråden": "elevråd",
    "elevrådens": "elevråd",
    "elevrådet": "elevråd",
    "elevrådets": "elevråd",
    "elevråds": "elevråd",
    "elevs": "elev",
    "elevunderlagen": "elevunderlag",
    "elevunderlagens": "elevunderlag",
    "elevunderlaget": "elevunderlag",
    "elevunderlagets": "elevunderlag",
    "elevunderlags": "elevunderlag",
    "elevvården": "elevvård",
    "elevvårdens": "elevvård",
    "elevvårds": "elevvård",
    "elfenbenet": "elfenben",
    "elfenbenets": "elfenben",
    "elfenbens": "elfenben",
    "elfenbensbitar": "elfenbensbit",
    "elfenbensbitarna": "elfenbensbit",
    "elfenbensbitarnas": "elfenbensbit",
    "elfenbensbitars": "elfenbensbit",
    "elfenbensbiten": "elfenbensbit",
    "elfenbensbitens": "elfenbensbit",
    "elfenbensbits": "elfenbensbit",
    "elfenbensfärgade": "elfenbensfärgad",
    "elfenbensfärgades": "elfenbensfärgad",
    "elfenbensfärgads": "elfenbensfärgad",
    "elfenbensfärgat": "elfenbensfärgad",
    "elfenbensfärgats": "elfenbensfärgad",
    "elfenbenspalmen": "elfenbenspalm",
    "elfenbenspalmens": "elfenbenspalm",
    "elfenbenspalmer": "elfenbenspalm",
    "elfenbenspalmerna": "elfenbenspalm",
    "elfenbenspalmernas": "elfenbenspalm",
    "elfenbenspalmers": "elfenbenspalm",
    "elfenbenspalms": "elfenbenspalm",
    "elfenbenspapperet": "elfenbenspapper",
    "elfenbenspapperets": "elfenbenspapper",
    "elfenbenspappers": "elfenbenspapper",
    "elfenbenspappret": "elfenbenspapper",
    "elfenbenspapprets": "elfenbenspapper",
    "elfenbenssvärtan": "elfenbenssvärta",
    "elfenbenssvärtans": "elfenbenssvärta",
    "elfenbenssvärtas": "elfenbenssvärta",
    "elfenbenstornen": "elfenbenstorn",
    "elfenbenstornens": "elfenbenstorn",
    "elfenbenstornet": "elfenbenstorn",
    "elfenbenstornets": "elfenbenstorn",
    "elfenbenstorns": "elfenbenstorn",
    "elfenbensvita": "elfenbensvit",
    "elfenbensvitare": "elfenbensvit",
    "elfenbensvitares": "elfenbensvit",
    "elfenbensvitas": "elfenbensvit",
    "elfenbensvitast": "elfenbensvit",
    "elfenbensvitaste": "elfenbensvit",
    "elfenbensvitastes": "elfenbensvit",
    "elfenbensvitasts": "elfenbensvit",
    "elfenbensvite": "elfenbensvit",
    "elfenbensvites": "elfenbensvit",
    "elfenbensvits": "elfenbensvit",
    "elfenbensvitt": "elfenbensvit",
    "elfenbensvitts": "elfenbensvit",
    "elfte": "elva",
    "elftes": "elva",
    "elförbrukningar": "elförbrukning",
    "elförbrukningarna": "elförbrukning",
    "elförbrukningarnas": "elförbrukning",
    "elförbrukningars": "elförbrukning",
    "elförbrukningen": "elförbrukning",
    "elförbrukningens": "elförbrukning",
    "elförbruknings": "elförbrukning",
    "elförsörjningar": "elförsörjning",
    "elförsörjningarna": "elförsörjning",
    "elförsörjningarnas": "elförsörjning",
    "elförsörjningars": "elförsörjning",
    "elförsörjningen": "elförsörjning",
    "elförsörjningens": "elförsörjning",
    "elförsörjnings": "elförsörjning",
    "elförzinkade": "elförzinkad",
    "elförzinkades": "elförzinkad",
    "elförzinkads": "elförzinkad",
    "elförzinkat": "elförzinkad",
    "elförzinkats": "elförzinkad",
    "elgeneratorer": "elgenerator",
    "elgeneratorerna": "elgenerator",
    "elgeneratorernas": "elgenerator",
    "elgeneratorers": "elgenerator",
    "elgeneratorn": "elgenerator",
    "elgeneratorns": "elgenerator",
    "elgenerators": "elgenerator",
    "elgitarren": "elgitarr",
    "elgitarrens": "elgitarr",
    "elgitarrer": "elgitarr",
    "elgitarrerna": "elgitarr",
    "elgitarrernas": "elgitarr",
    "elgitarrers": "elgitarr",
    "elgitarrs": "elgitarr",
    "elgräsklippar": "elgräsklippare",
    "elgräsklipparen": "elgräsklippare",
    "elgräsklipparens": "elgräsklippare",
    "elgräsklippares": "elgräsklippare",
    "elgräsklipparna": "elgräsklippare",
    "elgräsklipparnas": "elgräsklippare",
    "elhybridbilar": "elhybridbil",
    "elhybridbilarna": "elhybridbil",
    "elhybridbilarnas": "elhybridbil",
    "elhybridbilars": "elhybridbil",
    "elhybridbilen": "elhybridbil",
    "elhybridbilens": "elhybridbil",
    "elhybridbils": "elhybridbil",
    "elhybriden": "elhybrid",
    "elhybridens": "elhybrid",
    "elhybrider": "elhybrid",
    "elhybriderna": "elhybrid",
    "elhybridernas": "elhybrid",
    "elhybriders": "elhybrid",
    "elhybrids": "elhybrid",
    "elhyveln": "elhyvel",
    "elhyvelns": "elhyvel",
    "elhyvels": "elhyvel",
    "elhyvlar": "elhyvel",
    "elhyvlarna": "elhyvel",
    "elhyvlarnas": "elhyvel",
    "elhyvlars": "elhyvel",
    "eliderad": "elidera",
    "eliderade": "elidera",
    "eliderades": "elidera",
    "eliderads": "elidera",
    "eliderande": "elidera",
    "elideranden": "eliderande",
    "eliderandena": "eliderande",
    "eliderandenas": "eliderande",
    "eliderandens": "eliderande",
    "eliderandes": "eliderande",
    "eliderandet": "eliderande",
    "eliderandets": "eliderande",
    "eliderar": "elidera",
    "elideras": "elidera",
    "eliderat": "elidera",
    "eliderats": "elidera",
    "eliderbara": "eliderbar",
    "eliderbarare": "eliderbar",
    "eliderbarares": "eliderbar",
    "eliderbaras": "eliderbar",
    "eliderbarast": "eliderbar",
    "eliderbaraste": "eliderbar",
    "eliderbarastes": "eliderbar",
    "eliderbarasts": "eliderbar",
    "eliderbare": "eliderbar",
    "eliderbares": "eliderbar",
    "eliderbarheten": "eliderbarhet",
    "eliderbarhetens": "eliderbarhet",
    "eliderbarhets": "eliderbarhet",
    "eliderbars": "eliderbar",
    "eliderbart": "eliderbar",
    "eliderbarts": "eliderbar",
    "elideringar": "elidering",
    "elideringarna": "elidering",
    "elideringarnas": "elidering",
    "elideringars": "elidering",
    "elideringen": "elidering",
    "elideringens": "elidering",
    "eliderings": "elidering",
    "eliminationen": "elimination",
    "eliminationens": "elimination",
    "eliminationer": "elimination",
    "eliminationerna": "elimination",
    "eliminationernas": "elimination",
    "eliminationers": "elimination",
    "eliminations": "elimination",
    "eliminerad": "eliminera",
    "eliminerade": "eliminera",
    "eliminerades": "eliminera",
    "eliminerads": "eliminera",
    "eliminerande": "eliminera",
    "elimineranden": "eliminerande",
    "eliminerandena": "eliminerande",
    "eliminerandenas": "eliminerande",
    "eliminerandens": "eliminerande",
    "eliminerandes": "eliminerande",
    "eliminerandet": "eliminerande",
    "eliminerandets": "eliminerande",
    "eliminerar": "eliminera",
    "elimineras": "eliminera",
    "eliminerat": "eliminera",
    "eliminerats": "eliminera",
    "eliminerbara": "eliminerbar",
    "eliminerbarare": "eliminerbar",
    "eliminerbarares": "eliminerbar",
    "eliminerbaras": "eliminerbar",
    "eliminerbarast": "eliminerbar",
    "eliminerbaraste": "eliminerbar",
    "eliminerbarastes": "eliminerbar",
    "eliminerbarasts": "eliminerbar",
    "eliminerbare": "eliminerbar",
    "eliminerbares": "eliminerbar",
    "eliminerbarheten": "eliminerbarhet",
    "eliminerbarhetens": "eliminerbarhet",
    "eliminerbarhets": "eliminerbarhet",
    "eliminerbars": "eliminerbar",
    "eliminerbart": "eliminerbar",
    "eliminerbarts": "eliminerbar",
    "elimineringar": "eliminering",
    "elimineringarna": "eliminering",
    "elimineringarnas": "eliminering",
    "elimineringars": "eliminering",
    "elimineringen": "eliminering",
    "elimineringens": "eliminering",
    "eliminerings": "eliminering",
    "elisionen": "elision",
    "elisionens": "elision",
    "elisioner": "elision",
    "elisionerna": "elision",
    "elisionernas": "elision",
    "elisioners": "elision",
    "elisions": "elision",
    "eliten": "elit",
    "elitens": "elit",
    "eliter": "elit",
    "eliterna": "elit",
    "eliternas": "elit",
    "eliters": "elit",
    "elitförbanden": "elitförband",
    "elitförbandens": "elitförband",
    "elitförbandet": "elitförband",
    "elitförbandets": "elitförband",
    "elitförbands": "elitförband",
    "elitgymnastiken": "elitgymnastik",
    "elitgymnastikens": "elitgymnastik",
    "elitgymnastiks": "elitgymnastik",
    "elitidrotten": "elitidrott",
    "elitidrottens": "elitidrott",
    "elitidrotter": "elitidrott",
    "elitidrotterna": "elitidrott",
    "elitidrotternas": "elitidrott",
    "elitidrotters": "elitidrott",
    "elitidrotts": "elitidrott",
    "elitidrottsmannen": "elitidrottsman",
    "elitidrottsmannens": "elitidrottsman",
    "elitidrottsmans": "elitidrottsman",
    "elitidrottsmän": "elitidrottsman",
    "elitidrottsmännen": "elitidrottsman",
    "elitidrottsmännens": "elitidrottsman",
    "elitidrottsmäns": "elitidrottsman",
    "elitiska": "elitisk",
    "elitiskare": "elitisk",
    "elitiskares": "elitisk",
    "elitiskas": "elitisk",
    "elitiskast": "elitisk",
    "elitiskaste": "elitisk",
    "elitiskastes": "elitisk",
    "elitiskasts": "elitisk",
    "elitiske": "elitisk",
    "elitiskes": "elitisk",
    "elitisks": "elitisk",
    "elitiskt": "elitisk",
    "elitiskts": "elitisk",
    "elitismen": "elitism",
    "elitismens": "elitism",
    "elitismer": "elitism",
    "elitismerna": "elitism",
    "elitismernas": "elitism",
    "elitismers": "elitism",
    "elitisms": "elitism",
    "elitistiska": "elitistisk",
    "elitistiskare": "elitistisk",
    "elitistiskares": "elitistisk",
    "elitistiskas": "elitistisk",
    "elitistiskast": "elitistisk",
    "elitistiskaste": "elitistisk",
    "elitistiskastes": "elitistisk",
    "elitistiskasts": "elitistisk",
    "elitistiske": "elitistisk",
    "elitistiskes": "elitistisk",
    "elitistisks": "elitistisk",
    "elitistiskt": "elitistisk",
    "elitistiskts": "elitistisk",
    "elitmässiga": "elitmässig",
    "elitmässigare": "elitmässig",
    "elitmässigares": "elitmässig",
    "elitmässigas": "elitmässig",
    "elitmässigast": "elitmässig",
    "elitmässigaste": "elitmässig",
    "elitmässigastes": "elitmässig",
    "elitmässigasts": "elitmässig",
    "elitmässige": "elitmässig",
    "elitmässiges": "elitmässig",
    "elitmässigs": "elitmässig",
    "elitmässigt": "elitmässig",
    "elitmässigts": "elitmässig",
    "elits": "elit",
    "elitseriemässiga": "elitseriemässig",
    "elitseriemässigare": "elitseriemässig",
    "elitseriemässigares": "elitseriemässig",
    "elitseriemässigas": "elitseriemässig",
    "elitseriemässigast": "elitseriemässig",
    "elitseriemässigaste": "elitseriemässig",
    "elitseriemässigastes": "elitseriemässig",
    "elitseriemässigasts": "elitseriemässig",
    "elitseriemässige": "elitseriemässig",
    "elitseriemässiges": "elitseriemässig",
    "elitseriemässigs": "elitseriemässig",
    "elitseriemässigt": "elitseriemässig",
    "elitseriemässigts": "elitseriemässig",
    "elitserien": "elitserie",
    "elitseriens": "elitserie",
    "elitserier": "elitserie",
    "elitserierna": "elitserie",
    "elitseriernas": "elitserie",
    "elitseriers": "elitserie",
    "elitseries": "elitserie",
    "elitsoldaten": "elitsoldat",
    "elitsoldatens": "elitsoldat",
    "elitsoldater": "elitsoldat",
    "elitsoldaterna": "elitsoldat",
    "elitsoldaternas": "elitsoldat",
    "elitsoldaters": "elitsoldat",
    "elitsoldats": "elitsoldat",
    "elitteorien": "elitteori",
    "elitteoriens": "elitteori",
    "elitteorier": "elitteori",
    "elitteorierna": "elitteori",
    "elitteoriernas": "elitteori",
    "elitteoriers": "elitteori",
    "elitteorin": "elitteori",
    "elitteorins": "elitteori",
    "elitteoris": "elitteori",
    "elittänkandes": "elittänkande",
    "elittänkandet": "elittänkande",
    "elittänkandets": "elittänkande",
    "elixiren": "elixir",
    "elixirens": "elixir",
    "elixiret": "elixir",
    "elixirets": "elixir",
    "elixirs": "elixir",
    "elkabeln": "elkabel",
    "elkabelns": "elkabel",
    "elkabels": "elkabel",
    "elkablar": "elkabel",
    "elkablarna": "elkabel",
    "elkablarnas": "elkabel",
    "elkablars": "elkabel",
    "elkedjesågar": "elkedjesåg",
    "elkedjesågarna": "elkedjesåg",
    "elkedjesågarnas": "elkedjesåg",
    "elkedjesågars": "elkedjesåg",
    "elkedjesågen": "elkedjesåg",
    "elkedjesågens": "elkedjesåg",
    "elkedjesågs": "elkedjesåg",
    "elkonsumtionen": "elkonsumtion",
    "elkonsumtionens": "elkonsumtion",
    "elkonsumtions": "elkonsumtion",
    "elkopplingar": "elkoppling",
    "elkopplingarna": "elkoppling",
    "elkopplingarnas": "elkoppling",
    "elkopplingars": "elkoppling",
    "elkopplingen": "elkoppling",
    "elkopplingens": "elkoppling",
    "elkopplings": "elkoppling",
    "elkraften": "elkraft",
    "elkraftens": "elkraft",
    "elkrafts": "elkraft",
    "elkraftsaggregaten": "elkraftsaggregat",
    "elkraftsaggregatens": "elkraftsaggregat",
    "elkraftsaggregatet": "elkraftsaggregat",
    "elkraftsaggregatets": "elkraftsaggregat",
    "elkraftsaggregats": "elkraftsaggregat",
    "elledningar": "elledning",
    "elledningarna": "elledning",
    "elledningarnas": "elledning",
    "elledningars": "elledning",
    "elledningen": "elledning",
    "elledningens": "elledning",
    "ellednings": "elledning",
    "ellipsen": "ellips",
    "ellipsens": "ellips",
    "ellipser": "ellips",
    "ellipserna": "ellips",
    "ellipsernas": "ellips",
    "ellipsers": "ellips",
    "ellipsoiden": "ellipsoid",
    "ellipsoidens": "ellipsoid",
    "ellipsoider": "ellipsoid",
    "ellipsoiderna": "ellipsoid",
    "ellipsoidernas": "ellipsoid",
    "ellipsoiders": "ellipsoid",
    "ellipsoids": "ellipsoid",
    "elliptiska": "elliptisk",
    "elliptiskare": "elliptisk",
    "elliptiskares": "elliptisk",
    "elliptiskas": "elliptisk",
    "elliptiskast": "elliptisk",
    "elliptiskaste": "elliptisk",
    "elliptiskastes": "elliptisk",
    "elliptiskasts": "elliptisk",
    "elliptiske": "elliptisk",
    "elliptiskes": "elliptisk",
    "elliptisks": "elliptisk",
    "elliptiskt": "elliptisk",
    "elliptiskts": "elliptisk",
    "elljuset": "elljus",
    "elljusets": "elljus",
    "elljussling": "elljusslinga",
    "elljusslingan": "elljusslinga",
    "elljusslingans": "elljusslinga",
    "elljusslingas": "elljusslinga",
    "elljusslinge": "elljusslinga",
    "elljusslingor": "elljusslinga",
    "elljusslingorna": "elljusslinga",
    "elljusslingornas": "elljusslinga",
    "elljusslingors": "elljusslinga",
    "elljusslings": "elljusslinga",
    "elljusspåren": "elljusspår",
    "elljusspårens": "elljusspår",
    "elljusspåret": "elljusspår",
    "elljusspårets": "elljusspår",
    "elljusspårs": "elljusspår",
    "elloken": "ellok",
    "ellokens": "ellok",
    "elloket": "ellok",
    "ellokets": "ellok",
    "elloks": "ellok",
    "elmanövrerade": "elmanövrerad",
    "elmanövrerades": "elmanövrerad",
    "elmanövrerads": "elmanövrerad",
    "elmanövrerat": "elmanövrerad",
    "elmanövrerats": "elmanövrerad",
    "elmarknaden": "elmarknad",
    "elmarknadens": "elmarknad",
    "elmarknader": "elmarknad",
    "elmarknaderna": "elmarknad",
    "elmarknadernas": "elmarknad",
    "elmarknaders": "elmarknad",
    "elmarknads": "elmarknad",
    "elmotorer": "elmotor",
    "elmotorerna": "elmotor",
    "elmotorernas": "elmotor",
    "elmotorers": "elmotor",
    "elmotorn": "elmotor",
    "elmotorns": "elmotor",
    "elmotors": "elmotor",
    "elmselden": "elmseld",
    "elmseldens": "elmseld",
    "elmselds": "elmseld",
    "elmutterdragar": "elmutterdragare",
    "elmutterdragaren": "elmutterdragare",
    "elmutterdragarens": "elmutterdragare",
    "elmutterdragares": "elmutterdragare",
    "elmutterdragarna": "elmutterdragare",
    "elmutterdragarnas": "elmutterdragare",
    "elmätar": "elmätare",
    "elmätaren": "elmätare",
    "elmätarens": "elmätare",
    "elmätares": "elmätare",
    "elmätarna": "elmätare",
    "elmätarnas": "elmätare",
    "elnäten": "elnät",
    "elnätens": "elnät",
    "elnätet": "elnät",
    "elnätets": "elnät",
    "elnäts": "elnät",
    "elogen": "eloge",
    "elogens": "eloge",
    "eloger": "eloge",
    "elogerna": "eloge",
    "elogernas": "eloge",
    "elogers": "eloge",
    "eloges": "eloge",
    "elokvensen": "elokvens",
    "elokvensens": "elokvens",
    "elokventa": "elokvent",
    "elokventare": "elokvent",
    "elokventares": "elokvent",
    "elokventas": "elokvent",
    "elokventast": "elokvent",
    "elokventaste": "elokvent",
    "elokventastes": "elokvent",
    "elokventasts": "elokvent",
    "elokvente": "elokvent",
    "elokventes": "elokvent",
    "elokvents": "elokvent",
    "elongationen": "elongation",
    "elongationens": "elongation",
    "elongationer": "elongation",
    "elongationerna": "elongation",
    "elongationernas": "elongation",
    "elongationers": "elongation",
    "elongations": "elongation",
    "eloquentias": "eloquentia",
    "elorgeln": "elorgel",
    "elorgelns": "elorgel",
    "elorgels": "elorgel",
    "elorglar": "elorgel",
    "elorglarna": "elorgel",
    "elorglarnas": "elorgel",
    "elorglars": "elorgel",
    "eloxerad": "eloxera",
    "eloxerade": "eloxera",
    "eloxerades": "eloxera",
    "eloxerads": "eloxera",
    "eloxerande": "eloxera",
    "eloxeranden": "eloxerande",
    "eloxerandena": "eloxerande",
    "eloxerandenas": "eloxerande",
    "eloxerandens": "eloxerande",
    "eloxerandes": "eloxerande",
    "eloxerandet": "eloxerande",
    "eloxerandets": "eloxerande",
    "eloxerar": "eloxera",
    "eloxeras": "eloxera",
    "eloxerat": "eloxera",
    "eloxerats": "eloxera",
    "eloxerbara": "eloxerbar",
    "eloxerbarare": "eloxerbar",
    "eloxerbarares": "eloxerbar",
    "eloxerbaras": "eloxerbar",
    "eloxerbarast": "eloxerbar",
    "eloxerbaraste": "eloxerbar",
    "eloxerbarastes": "eloxerbar",
    "eloxerbarasts": "eloxerbar",
    "eloxerbare": "eloxerbar",
    "eloxerbares": "eloxerbar",
    "eloxerbarheten": "eloxerbarhet",
    "eloxerbarhetens": "eloxerbarhet",
    "eloxerbarhets": "eloxerbarhet",
    "eloxerbars": "eloxerbar",
    "eloxerbart": "eloxerbar",
    "eloxerbarts": "eloxerbar",
    "eloxeringar": "eloxering",
    "eloxeringarna": "eloxering",
    "eloxeringarnas": "eloxering",
    "eloxeringars": "eloxering",
    "eloxeringen": "eloxering",
    "eloxeringens": "eloxering",
    "eloxerings": "eloxering",
    "elpistolen": "elpistol",
    "elpistolens": "elpistol",
    "elpistoler": "elpistol",
    "elpistolerna": "elpistol",
    "elpistolernas": "elpistol",
    "elpistolers": "elpistol",
    "elpistols": "elpistol",
    "elplatt": "elplatta",
    "elplattan": "elplatta",
    "elplattans": "elplatta",
    "elplattas": "elplatta",
    "elplatte": "elplatta",
    "elplattor": "elplatta",
    "elplattorna": "elplatta",
    "elplattornas": "elplatta",
    "elplattors": "elplatta",
    "elplatts": "elplatta",
    "elproppar": "elpropp",
    "elpropparna": "elpropp",
    "elpropparnas": "elpropp",
    "elproppars": "elpropp",
    "elproppen": "elpropp",
    "elproppens": "elpropp",
    "elpropps": "elpropp",
    "elrits": "elritsa",
    "elritsan": "elritsa",
    "elritsans": "elritsa",
    "elritsas": "elritsa",
    "elritse": "elritsa",
    "elritsor": "elritsa",
    "elritsorna": "elritsa",
    "elritsornas": "elritsa",
    "elritsors": "elritsa",
    "els": "el",
    "elseviren": "elsevir",
    "elsevirens": "elsevir",
    "elsevirer": "elsevir",
    "elsevirerna": "elsevir",
    "elsevirernas": "elsevir",
    "elsevirers": "elsevir",
    "elsevirs": "elsevir",
    "elskrotet": "elskrot",
    "elskrotets": "elskrot",
    "elskrots": "elskrot",
    "elspisar": "elspis",
    "elspisarna": "elspis",
    "elspisarnas": "elspis",
    "elspisars": "elspis",
    "elspisen": "elspis",
    "elspisens": "elspis",
    "elstolp": "elstolpe",
    "elstolpar": "elstolpe",
    "elstolparna": "elstolpe",
    "elstolparnas": "elstolpe",
    "elstolpars": "elstolpe",
    "elstolpen": "elstolpe",
    "elstolpens": "elstolpe",
    "elstolpes": "elstolpe",
    "elstolps": "elstolpe",
    "elströmmar": "elström",
    "elströmmarna": "elström",
    "elströmmarnas": "elström",
    "elströmmars": "elström",
    "elströmmen": "elström",
    "elströmmens": "elström",
    "elströms": "elström",
    "elstängsels": "elstängsel",
    "elstängslen": "elstängsel",
    "elstängslens": "elstängsel",
    "elstängslet": "elstängsel",
    "elstängslets": "elstängsel",
    "eltejpen": "eltejp",
    "eltejpens": "eltejp",
    "eltejps": "eltejp",
    "eluderad": "eludera",
    "eluderade": "eludera",
    "eluderades": "eludera",
    "eluderads": "eludera",
    "eluderande": "eludera",
    "eluderanden": "eluderande",
    "eluderandena": "eluderande",
    "eluderandenas": "eluderande",
    "eluderandens": "eluderande",
    "eluderandes": "eluderande",
    "eluderandet": "eluderande",
    "eluderandets": "eluderande",
    "eluderar": "eludera",
    "eluderas": "eludera",
    "eluderat": "eludera",
    "eluderats": "eludera",
    "eluderbara": "eluderbar",
    "eluderbarare": "eluderbar",
    "eluderbarares": "eluderbar",
    "eluderbaras": "eluderbar",
    "eluderbarast": "eluderbar",
    "eluderbaraste": "eluderbar",
    "eluderbarastes": "eluderbar",
    "eluderbarasts": "eluderbar",
    "eluderbare": "eluderbar",
    "eluderbares": "eluderbar",
    "eluderbarheten": "eluderbarhet",
    "eluderbarhetens": "eluderbarhet",
    "eluderbarhets": "eluderbarhet",
    "eluderbars": "eluderbar",
    "eluderbart": "eluderbar",
    "eluderbarts": "eluderbar",
    "eluderingar": "eludering",
    "eluderingarna": "eludering",
    "eluderingarnas": "eludering",
    "eluderingars": "eludering",
    "eluderingen": "eludering",
    "eluderingens": "eludering",
    "eluderings": "eludering",
    "eluerad": "eluera",
    "eluerade": "eluera",
    "eluerades": "eluera",
    "eluerads": "eluera",
    "eluerande": "eluera",
    "elueranden": "eluerande",
    "eluerandena": "eluerande",
    "eluerandenas": "eluerande",
    "eluerandens": "eluerande",
    "eluerandes": "eluerande",
    "eluerandet": "eluerande",
    "eluerandets": "eluerande",
    "eluerar": "eluera",
    "elueras": "eluera",
    "eluerat": "eluera",
    "eluerats": "eluera",
    "eluerbara": "eluerbar",
    "eluerbarare": "eluerbar",
    "eluerbarares": "eluerbar",
    "eluerbaras": "eluerbar",
    "eluerbarast": "eluerbar",
    "eluerbaraste": "eluerbar",
    "eluerbarastes": "eluerbar",
    "eluerbarasts": "eluerbar",
    "eluerbare": "eluerbar",
    "eluerbares": "eluerbar",
    "eluerbarheten": "eluerbarhet",
    "eluerbarhetens": "eluerbarhet",
    "eluerbarhets": "eluerbarhet",
    "eluerbars": "eluerbar",
    "eluerbart": "eluerbar",
    "eluerbarts": "eluerbar",
    "elueringar": "eluering",
    "elueringarna": "eluering",
    "elueringarnas": "eluering",
    "elueringars": "eluering",
    "elueringen": "eluering",
    "elueringens": "eluering",
    "eluerings": "eluering",
    "elusionen": "elusion",
    "elusionens": "elusion",
    "elusioner": "elusion",
    "elusionerna": "elusion",
    "elusionernas": "elusion",
    "elusioners": "elusion",
    "elusions": "elusion",
    "eluttagen": "eluttag",
    "eluttagens": "eluttag",
    "eluttaget": "eluttag",
    "eluttagets": "eluttag",
    "eluttags": "eluttag",
    "eluviala": "eluvial",
    "eluvialare": "eluvial",
    "eluvialares": "eluvial",
    "eluvialas": "eluvial",
    "eluvialast": "eluvial",
    "eluvialaste": "eluvial",
    "eluvialastes": "eluvial",
    "eluvialasts": "eluvial",
    "eluviale": "eluvial",
    "eluviales": "eluvial",
    "eluvials": "eluvial",
    "eluvialt": "eluvial",
    "eluvialts": "eluvial",
    "eluviums": "eluvium",
    "elvadimensionella": "elvadimensionell",
    "elvadimensionellare": "elvadimensionell",
    "elvadimensionellares": "elvadimensionell",
    "elvadimensionellas": "elvadimensionell",
    "elvadimensionellast": "elvadimensionell",
    "elvadimensionellaste": "elvadimensionell",
    "elvadimensionellastes": "elvadimensionell",
    "elvadimensionellasts": "elvadimensionell",
    "elvadimensionelle": "elvadimensionell",
    "elvadimensionelles": "elvadimensionell",
    "elvadimensionells": "elvadimensionell",
    "elvadimensionellt": "elvadimensionell",
    "elvadimensionellts": "elvadimensionell",
    "elvahundratalet": "elvahundratal",
    "elvahundratalets": "elvahundratal",
    "elvahundratals": "elvahundratal",
    "elvamannalagen": "elvamannalag",
    "elvamannalagens": "elvamannalag",
    "elvamannalaget": "elvamannalag",
    "elvamannalagets": "elvamannalag",
    "elvamannalags": "elvamannalag",
    "elvan": "elva",
    "elvans": "elva",
    "elvas": "elva",
    "elvasnårets": "elvasnåret",
    "elvaåriga": "elvaårig",
    "elvaårigas": "elvaårig",
    "elvaårige": "elvaårig",
    "elvaåriges": "elvaårig",
    "elvaårigs": "elvaårig",
    "elvaårigt": "elvaårig",
    "elvaårigts": "elvaårig",
    "elvaåringar": "elvaåring",
    "elvaåringarna": "elvaåring",
    "elvaåringarnas": "elvaåring",
    "elvaåringars": "elvaåring",
    "elvaåringen": "elvaåring",
    "elvaåringens": "elvaåring",
    "elvaårings": "elvaåring",
    "elvaårsgränsen": "elvaårsgräns",
    "elvaårsgränsens": "elvaårsgräns",
    "elverken": "elverk",
    "elverkens": "elverk",
    "elverket": "elverk",
    "elverkets": "elverk",
    "elverks": "elverk",
    "elvispar": "elvisp",
    "elvisparna": "elvisp",
    "elvisparnas": "elvisp",
    "elvispars": "elvisp",
    "elvispen": "elvisp",
    "elvispens": "elvisp",
    "elvispfabriken": "elvispfabrik",
    "elvispfabrikens": "elvispfabrik",
    "elvispfabriker": "elvispfabrik",
    "elvispfabrikerna": "elvispfabrik",
    "elvispfabrikernas": "elvispfabrik",
    "elvispfabrikers": "elvispfabrik",
    "elvispfabriks": "elvispfabrik",
    "elvisps": "elvisp",
    "elvor": "elva",
    "elvorna": "elva",
    "elvornas": "elva",
    "elvors": "elva",
    "elvärmen": "elvärme",
    "elvärmens": "elvärme",
    "elvärmes": "elvärme",
    "elyseiska": "elyseisk",
    "elyseiskare": "elyseisk",
    "elyseiskares": "elyseisk",
    "elyseiskas": "elyseisk",
    "elyseiskast": "elyseisk",
    "elyseiskaste": "elyseisk",
    "elyseiskastes": "elyseisk",
    "elyseiskasts": "elyseisk",
    "elyseiske": "elyseisk",
    "elyseiskes": "elyseisk",
    "elyseisks": "elyseisk",
    "elyseiskt": "elyseisk",
    "elyseiskts": "elyseisk",
    "elzevieren": "elzevier",
    "elzevierens": "elzevier",
    "elzevierer": "elzevier",
    "elzeviererna": "elzevier",
    "elzevierernas": "elzevier",
    "elzevierers": "elzevier",
    "elzeviers": "elzevier",
    "eländen": "elände",
    "eländena": "elände",
    "eländenas": "elände",
    "eländens": "elände",
    "eländes": "elände",
    "eländesskildringar": "eländesskildring",
    "eländesskildringarna": "eländesskildring",
    "eländesskildringarnas": "eländesskildring",
    "eländesskildringars": "eländesskildring",
    "eländesskildringen": "eländesskildring",
    "eländesskildringens": "eländesskildring",
    "eländesskildrings": "eländesskildring",
    "eländet": "elände",
    "eländets": "elände",
    "eländiga": "eländig",
    "eländigare": "eländig",
    "eländigares": "eländig",
    "eländigas": "eländig",
    "eländigast": "eländig",
    "eländigaste": "eländig",
    "eländigastes": "eländig",
    "eländigasts": "eländig",
    "eländige": "eländig",
    "eländiges": "eländig",
    "eländigheten": "eländighet",
    "eländighetens": "eländighet",
    "eländighets": "eländighet",
    "eländigs": "eländig",
    "eländigt": "eländig",
    "eländigts": "eländig",
    "em": "emma",
    "emailen": "email",
    "emailens": "email",
    "emailet": "email",
    "emailets": "email",
    "emails": "email",
    "emaljen": "emalj",
    "emaljens": "emalj",
    "emaljer": "emalj",
    "emaljerad": "emaljera",
    "emaljerade": "emaljera",
    "emaljerades": "emaljera",
    "emaljerads": "emaljera",
    "emaljerande": "emaljera",
    "emaljeranden": "emaljerande",
    "emaljerandena": "emaljerande",
    "emaljerandenas": "emaljerande",
    "emaljerandens": "emaljerande",
    "emaljerandes": "emaljerande",
    "emaljerandet": "emaljerande",
    "emaljerandets": "emaljerande",
    "emaljerar": "emaljera",
    "emaljeras": "emaljera",
    "emaljerat": "emaljera",
    "emaljerats": "emaljera",
    "emaljerbara": "emaljerbar",
    "emaljerbarare": "emaljerbar",
    "emaljerbarares": "emaljerbar",
    "emaljerbaras": "emaljerbar",
    "emaljerbarast": "emaljerbar",
    "emaljerbaraste": "emaljerbar",
    "emaljerbarastes": "emaljerbar",
    "emaljerbarasts": "emaljerbar",
    "emaljerbare": "emaljerbar",
    "emaljerbares": "emaljerbar",
    "emaljerbarheten": "emaljerbarhet",
    "emaljerbarhetens": "emaljerbarhet",
    "emaljerbarhets": "emaljerbarhet",
    "emaljerbars": "emaljerbar",
    "emaljerbart": "emaljerbar",
    "emaljerbarts": "emaljerbar",
    "emaljeringar": "emaljering",
    "emaljeringarna": "emaljering",
    "emaljeringarnas": "emaljering",
    "emaljeringars": "emaljering",
    "emaljeringen": "emaljering",
    "emaljeringens": "emaljering",
    "emaljerings": "emaljering",
    "emaljerna": "emalj",
    "emaljernas": "emalj",
    "emaljers": "emalj",
    "emaljfyllningar": "emaljfyllning",
    "emaljfyllningarna": "emaljfyllning",
    "emaljfyllningarnas": "emaljfyllning",
    "emaljfyllningars": "emaljfyllning",
    "emaljfyllningen": "emaljfyllning",
    "emaljfyllningens": "emaljfyllning",
    "emaljfyllnings": "emaljfyllning",
    "emaljfärgen": "emaljfärg",
    "emaljfärgens": "emaljfärg",
    "emaljfärger": "emaljfärg",
    "emaljfärgerna": "emaljfärg",
    "emaljfärgernas": "emaljfärg",
    "emaljfärgers": "emaljfärg",
    "emaljfärgs": "emaljfärg",
    "emaljglaset": "emaljglas",
    "emaljglasets": "emaljglas",
    "emaljinläggningar": "emaljinläggning",
    "emaljinläggningarna": "emaljinläggning",
    "emaljinläggningarnas": "emaljinläggning",
    "emaljinläggningars": "emaljinläggning",
    "emaljinläggningen": "emaljinläggning",
    "emaljinläggningens": "emaljinläggning",
    "emaljinläggnings": "emaljinläggning",
    "emaljlacker": "emaljlack",
    "emaljlackerna": "emaljlack",
    "emaljlackernas": "emaljlack",
    "emaljlackers": "emaljlack",
    "emaljlacket": "emaljlack",
    "emaljlackets": "emaljlack",
    "emaljlacks": "emaljlack",
    "emaljmålningar": "emaljmålning",
    "emaljmålningarna": "emaljmålning",
    "emaljmålningarnas": "emaljmålning",
    "emaljmålningars": "emaljmålning",
    "emaljmålningen": "emaljmålning",
    "emaljmålningens": "emaljmålning",
    "emaljmålnings": "emaljmålning",
    "emaljplomben": "emaljplomb",
    "emaljplombens": "emaljplomb",
    "emaljplomber": "emaljplomb",
    "emaljplomberna": "emaljplomb",
    "emaljplombernas": "emaljplomb",
    "emaljplombers": "emaljplomb",
    "emaljplombs": "emaljplomb",
    "emaljs": "emalj",
    "emaljögas": "emaljöga",
    "emaljögat": "emaljöga",
    "emaljögats": "emaljöga",
    "emaljögon": "emaljöga",
    "emaljögonen": "emaljöga",
    "emaljögonens": "emaljöga",
    "emaljögons": "emaljöga",
    "emaljören": "emaljör",
    "emaljörens": "emaljör",
    "emaljörer": "emaljör",
    "emaljörerna": "emaljör",
    "emaljörernas": "emaljör",
    "emaljörers": "emaljör",
    "emaljörs": "emaljör",
    "emanationen": "emanation",
    "emanationens": "emanation",
    "emanationer": "emanation",
    "emanationerna": "emanation",
    "emanationernas": "emanation",
    "emanationers": "emanation",
    "emanations": "emanation",
    "emancipationen": "emancipation",
    "emancipationens": "emancipation",
    "emancipationer": "emancipation",
    "emancipationerna": "emancipation",
    "emancipationernas": "emancipation",
    "emancipationers": "emancipation",
    "emancipations": "emancipation",
    "emanciperad": "emancipera",
    "emanciperade": "emancipera",
    "emanciperades": "emancipera",
    "emanciperads": "emancipera",
    "emanciperande": "emancipera",
    "emanciperanden": "emanciperande",
    "emanciperandena": "emanciperande",
    "emanciperandenas": "emanciperande",
    "emanciperandens": "emanciperande",
    "emanciperandes": "emanciperande",
    "emanciperandet": "emanciperande",
    "emanciperandets": "emanciperande",
    "emanciperar": "emancipera",
    "emanciperas": "emancipera",
    "emanciperat": "emancipera",
    "emanciperats": "emancipera",
    "emanciperbara": "emanciperbar",
    "emanciperbarare": "emanciperbar",
    "emanciperbarares": "emanciperbar",
    "emanciperbaras": "emanciperbar",
    "emanciperbarast": "emanciperbar",
    "emanciperbaraste": "emanciperbar",
    "emanciperbarastes": "emanciperbar",
    "emanciperbarasts": "emanciperbar",
    "emanciperbare": "emanciperbar",
    "emanciperbares": "emanciperbar",
    "emanciperbarheten": "emanciperbarhet",
    "emanciperbarhetens": "emanciperbarhet",
    "emanciperbarhets": "emanciperbarhet",
    "emanciperbars": "emanciperbar",
    "emanciperbart": "emanciperbar",
    "emanciperbarts": "emanciperbar",
    "emanciperingar": "emancipering",
    "emanciperingarna": "emancipering",
    "emanciperingarnas": "emancipering",
    "emanciperingars": "emancipering",
    "emanciperingen": "emancipering",
    "emanciperingens": "emancipering",
    "emanciperings": "emancipering",
    "emanerade": "emanera",
    "emanerades": "emanera",
    "emanerande": "emanera",
    "emaneranden": "emanerande",
    "emanerandena": "emanerande",
    "emanerandenas": "emanerande",
    "emanerandens": "emanerande",
    "emanerandes": "emanerande",
    "emanerandet": "emanerande",
    "emanerandets": "emanerande",
    "emanerar": "emanera",
    "emaneras": "emanera",
    "emanerat": "emanera",
    "emanerats": "emanera",
    "emaneringar": "emanering",
    "emaneringarna": "emanering",
    "emaneringarnas": "emanering",
    "emaneringars": "emanering",
    "emaneringen": "emanering",
    "emaneringens": "emanering",
    "emanerings": "emanering",
    "emballagen": "emballage",
    "emballagens": "emballage",
    "emballages": "emballage",
    "emballaget": "emballage",
    "emballagets": "emballage",
    "emballerad": "emballera",
    "emballerade": "emballera",
    "emballerades": "emballera",
    "emballerads": "emballera",
    "emballerande": "emballera",
    "emballeranden": "emballerande",
    "emballerandena": "emballerande",
    "emballerandenas": "emballerande",
    "emballerandens": "emballerande",
    "emballerandes": "emballerande",
    "emballerandet": "emballerande",
    "emballerandets": "emballerande",
    "emballerar": "emballera",
    "emballeras": "emballera",
    "emballerat": "emballera",
    "emballerats": "emballera",
    "emballerbara": "emballerbar",
    "emballerbarare": "emballerbar",
    "emballerbarares": "emballerbar",
    "emballerbaras": "emballerbar",
    "emballerbarast": "emballerbar",
    "emballerbaraste": "emballerbar",
    "emballerbarastes": "emballerbar",
    "emballerbarasts": "emballerbar",
    "emballerbare": "emballerbar",
    "emballerbares": "emballerbar",
    "emballerbarheten": "emballerbarhet",
    "emballerbarhetens": "emballerbarhet",
    "emballerbarhets": "emballerbarhet",
    "emballerbars": "emballerbar",
    "emballerbart": "emballerbar",
    "emballerbarts": "emballerbar",
    "emballeringar": "emballering",
    "emballeringarna": "emballering",
    "emballeringarnas": "emballering",
    "emballeringars": "emballering",
    "emballeringen": "emballering",
    "emballeringens": "emballering",
    "emballerings": "emballering",
    "embargon": "embargo",
    "embargons": "embargo",
    "embargos": "embargo",
    "embargot": "embargo",
    "embargots": "embargo",
    "embarkerad": "embarkera",
    "embarkerade": "embarkera",
    "embarkerades": "embarkera",
    "embarkerads": "embarkera",
    "embarkerande": "embarkera",
    "embarkeranden": "embarkerande",
    "embarkerandena": "embarkerande",
    "embarkerandenas": "embarkerande",
    "embarkerandens": "embarkerande",
    "embarkerandes": "embarkerande",
    "embarkerandet": "embarkerande",
    "embarkerandets": "embarkerande",
    "embarkerar": "embarkera",
    "embarkeras": "embarkera",
    "embarkerat": "embarkera",
    "embarkerats": "embarkera",
    "embarkerbara": "embarkerbar",
    "embarkerbarare": "embarkerbar",
    "embarkerbarares": "embarkerbar",
    "embarkerbaras": "embarkerbar",
    "embarkerbarast": "embarkerbar",
    "embarkerbaraste": "embarkerbar",
    "embarkerbarastes": "embarkerbar",
    "embarkerbarasts": "embarkerbar",
    "embarkerbare": "embarkerbar",
    "embarkerbares": "embarkerbar",
    "embarkerbarheten": "embarkerbarhet",
    "embarkerbarhetens": "embarkerbarhet",
    "embarkerbarhets": "embarkerbarhet",
    "embarkerbars": "embarkerbar",
    "embarkerbart": "embarkerbar",
    "embarkerbarts": "embarkerbar",
    "embarkeringar": "embarkering",
    "embarkeringarna": "embarkering",
    "embarkeringarnas": "embarkering",
    "embarkeringars": "embarkering",
    "embarkeringen": "embarkering",
    "embarkeringens": "embarkering",
    "embarkerings": "embarkering",
    "embellerad": "embellera",
    "embellerade": "embellera",
    "embellerades": "embellera",
    "embellerads": "embellera",
    "embellerande": "embellera",
    "embelleranden": "embellerande",
    "embellerandena": "embellerande",
    "embellerandenas": "embellerande",
    "embellerandens": "embellerande",
    "embellerandes": "embellerande",
    "embellerandet": "embellerande",
    "embellerandets": "embellerande",
    "embellerar": "embellera",
    "embelleras": "embellera",
    "embellerat": "embellera",
    "embellerats": "embellera",
    "embellerbara": "embellerbar",
    "embellerbarare": "embellerbar",
    "embellerbarares": "embellerbar",
    "embellerbaras": "embellerbar",
    "embellerbarast": "embellerbar",
    "embellerbaraste": "embellerbar",
    "embellerbarastes": "embellerbar",
    "embellerbarasts": "embellerbar",
    "embellerbare": "embellerbar",
    "embellerbares": "embellerbar",
    "embellerbarheten": "embellerbarhet",
    "embellerbarhetens": "embellerbarhet",
    "embellerbarhets": "embellerbarhet",
    "embellerbars": "embellerbar",
    "embellerbart": "embellerbar",
    "embellerbarts": "embellerbar",
    "embelleringar": "embellering",
    "embelleringarna": "embellering",
    "embelleringarnas": "embellering",
    "embelleringars": "embellering",
    "embelleringen": "embellering",
    "embelleringens": "embellering",
    "embellerings": "embellering",
    "emblematiken": "emblematik",
    "emblematikens": "emblematik",
    "emblematiks": "emblematik",
    "emblemen": "emblem",
    "emblemens": "emblem",
    "emblemet": "emblem",
    "emblemets": "emblem",
    "emblems": "emblem",
    "embolien": "emboli",
    "emboliens": "emboli",
    "embolier": "emboli",
    "embolierna": "emboli",
    "emboliernas": "emboli",
    "emboliers": "emboli",
    "embolin": "emboli",
    "embolins": "emboli",
    "embolis": "emboli",
    "embonpointen": "embonpoint",
    "embonpointens": "embonpoint",
    "embonpoints": "embonpoint",
    "embryologen": "embryolog",
    "embryologens": "embryolog",
    "embryologer": "embryolog",
    "embryologerna": "embryolog",
    "embryologernas": "embryolog",
    "embryologers": "embryolog",
    "embryologien": "embryologi",
    "embryologiens": "embryologi",
    "embryologin": "embryologi",
    "embryologins": "embryologi",
    "embryologis": "embryologi",
    "embryologs": "embryolog",
    "embryon": "embryo",
    "embryona": "embryo",
    "embryonala": "embryonal",
    "embryonalare": "embryonal",
    "embryonalares": "embryonal",
    "embryonalas": "embryonal",
    "embryonalast": "embryonal",
    "embryonalaste": "embryonal",
    "embryonalastes": "embryonal",
    "embryonalasts": "embryonal",
    "embryonale": "embryonal",
    "embryonales": "embryonal",
    "embryonals": "embryonal",
    "embryonalt": "embryonal",
    "embryonalts": "embryonal",
    "embryonas": "embryo",
    "embryoniska": "embryonisk",
    "embryoniskare": "embryonisk",
    "embryoniskares": "embryonisk",
    "embryoniskas": "embryonisk",
    "embryoniskast": "embryonisk",
    "embryoniskaste": "embryonisk",
    "embryoniskastes": "embryonisk",
    "embryoniskasts": "embryonisk",
    "embryoniske": "embryonisk",
    "embryoniskes": "embryonisk",
    "embryonisks": "embryonisk",
    "embryoniskt": "embryonisk",
    "embryoniskts": "embryonisk",
    "embryons": "embryo",
    "embryos": "embryo",
    "embryosäckar": "embryosäck",
    "embryosäckarna": "embryosäck",
    "embryosäckarnas": "embryosäck",
    "embryosäckars": "embryosäck",
    "embryosäcken": "embryosäck",
    "embryosäckens": "embryosäck",
    "embryosäcks": "embryosäck",
    "embryot": "embryo",
    "embryots": "embryo",
    "emendationen": "emendation",
    "emendationens": "emendation",
    "emendationer": "emendation",
    "emendationerna": "emendation",
    "emendationernas": "emendation",
    "emendationers": "emendation",
    "emendations": "emendation",
    "emenderad": "emendera",
    "emenderade": "emendera",
    "emenderades": "emendera",
    "emenderads": "emendera",
    "emenderande": "emendera",
    "emenderanden": "emenderande",
    "emenderandena": "emenderande",
    "emenderandenas": "emenderande",
    "emenderandens": "emenderande",
    "emenderandes": "emenderande",
    "emenderandet": "emenderande",
    "emenderandets": "emenderande",
    "emenderar": "emendera",
    "emenderas": "emendera",
    "emenderat": "emendera",
    "emenderats": "emendera",
    "emenderbara": "emenderbar",
    "emenderbarare": "emenderbar",
    "emenderbarares": "emenderbar",
    "emenderbaras": "emenderbar",
    "emenderbarast": "emenderbar",
    "emenderbaraste": "emenderbar",
    "emenderbarastes": "emenderbar",
    "emenderbarasts": "emenderbar",
    "emenderbare": "emenderbar",
    "emenderbares": "emenderbar",
    "emenderbarheten": "emenderbarhet",
    "emenderbarhetens": "emenderbarhet",
    "emenderbarhets": "emenderbarhet",
    "emenderbars": "emenderbar",
    "emenderbart": "emenderbar",
    "emenderbarts": "emenderbar",
    "emenderingar": "emendering",
    "emenderingarna": "emendering",
    "emenderingarnas": "emendering",
    "emenderingars": "emendering",
    "emenderingen": "emendering",
    "emenderingens": "emendering",
    "emenderings": "emendering",
    "emeriti": "emeritus",
    "emeritina": "emeritus",
    "emeritinas": "emeritus",
    "emeritis": "emeritus",
    "emfasen": "emfas",
    "emfasens": "emfas",
    "emfatiska": "emfatisk",
    "emfatiskare": "emfatisk",
    "emfatiskares": "emfatisk",
    "emfatiskas": "emfatisk",
    "emfatiskast": "emfatisk",
    "emfatiskaste": "emfatisk",
    "emfatiskastes": "emfatisk",
    "emfatiskasts": "emfatisk",
    "emfatiske": "emfatisk",
    "emfatiskes": "emfatisk",
    "emfatisks": "emfatisk",
    "emfatiskt": "emfatisk",
    "emfatiskts": "emfatisk",
    "emfysemen": "emfysem",
    "emfysemens": "emfysem",
    "emfysemet": "emfysem",
    "emfysemets": "emfysem",
    "emfysems": "emfysem",
    "emigranten": "emigrant",
    "emigrantens": "emigrant",
    "emigranter": "emigrant",
    "emigranterna": "emigrant",
    "emigranternas": "emigrant",
    "emigranters": "emigrant",
    "emigrants": "emigrant",
    "emigrationen": "emigration",
    "emigrationens": "emigration",
    "emigrationer": "emigration",
    "emigrationerna": "emigration",
    "emigrationernas": "emigration",
    "emigrationers": "emigration",
    "emigrations": "emigration",
    "emigrerad": "emigrera",
    "emigrerade": "emigrera",
    "emigrerades": "emigrera",
    "emigrerads": "emigrera",
    "emigrerande": "emigrera",
    "emigreranden": "emigrerande",
    "emigrerandena": "emigrerande",
    "emigrerandenas": "emigrerande",
    "emigrerandens": "emigrerande",
    "emigrerandes": "emigrerande",
    "emigrerandet": "emigrerande",
    "emigrerandets": "emigrerande",
    "emigrerar": "emigrera",
    "emigreras": "emigrera",
    "emigrerat": "emigrera",
    "emigrerats": "emigrera",
    "emigrerbara": "emigrerbar",
    "emigrerbarare": "emigrerbar",
    "emigrerbarares": "emigrerbar",
    "emigrerbaras": "emigrerbar",
    "emigrerbarast": "emigrerbar",
    "emigrerbaraste": "emigrerbar",
    "emigrerbarastes": "emigrerbar",
    "emigrerbarasts": "emigrerbar",
    "emigrerbare": "emigrerbar",
    "emigrerbares": "emigrerbar",
    "emigrerbarheten": "emigrerbarhet",
    "emigrerbarhetens": "emigrerbarhet",
    "emigrerbarhets": "emigrerbarhet",
    "emigrerbars": "emigrerbar",
    "emigrerbart": "emigrerbar",
    "emigrerbarts": "emigrerbar",
    "emigreringar": "emigrering",
    "emigreringarna": "emigrering",
    "emigreringarnas": "emigrering",
    "emigreringars": "emigrering",
    "emigreringen": "emigrering",
    "emigreringens": "emigrering",
    "emigrerings": "emigrering",
    "eminensen": "eminens",
    "eminensens": "eminens",
    "eminenser": "eminens",
    "eminenserna": "eminens",
    "eminensernas": "eminens",
    "eminensers": "eminens",
    "eminenta": "eminent",
    "eminentare": "eminent",
    "eminentares": "eminent",
    "eminentas": "eminent",
    "eminentast": "eminent",
    "eminentaste": "eminent",
    "eminentastes": "eminent",
    "eminentasts": "eminent",
    "eminente": "eminent",
    "eminentes": "eminent",
    "eminentheten": "eminenthet",
    "eminenthetens": "eminenthet",
    "eminenthets": "eminenthet",
    "eminents": "eminent",
    "emiratiern": "emiratier",
    "emiratierna": "emiratier",
    "emiratiernas": "emiratier",
    "emiratierns": "emiratier",
    "emiratiers": "emiratier",
    "emiratiska": "emiratisk",
    "emiratiskan": "emiratiska",
    "emiratiskans": "emiratiska",
    "emiratiskare": "emiratisk",
    "emiratiskares": "emiratisk",
    "emiratiskas": "emiratiska",
    "emiratiskast": "emiratisk",
    "emiratiskaste": "emiratisk",
    "emiratiskastes": "emiratisk",
    "emiratiskasts": "emiratisk",
    "emiratiske": "emiratiska",
    "emiratiskes": "emiratisk",
    "emiratiskor": "emiratiska",
    "emiratiskorna": "emiratiska",
    "emiratiskornas": "emiratiska",
    "emiratiskors": "emiratiska",
    "emiratisks": "emiratisk",
    "emiratiskt": "emiratisk",
    "emiratiskts": "emiratisk",
    "emiren": "emir",
    "emirens": "emir",
    "emirer": "emir",
    "emirerna": "emir",
    "emirernas": "emir",
    "emirers": "emir",
    "emirs": "emir",
    "emissarien": "emissarie",
    "emissariens": "emissarie",
    "emissarier": "emissarie",
    "emissarierna": "emissarie",
    "emissariernas": "emissarie",
    "emissariers": "emissarie",
    "emissaries": "emissarie",
    "emissionen": "emission",
    "emissionens": "emission",
    "emissioner": "emission",
    "emissionerna": "emission",
    "emissionernas": "emission",
    "emissioners": "emission",
    "emissions": "emission",
    "emitterad": "emittera",
    "emitterade": "emittera",
    "emitterades": "emittera",
    "emitterads": "emittera",
    "emitterande": "emittera",
    "emitteranden": "emitterande",
    "emitterandena": "emitterande",
    "emitterandenas": "emitterande",
    "emitterandens": "emitterande",
    "emitterandes": "emitterande",
    "emitterandet": "emitterande",
    "emitterandets": "emitterande",
    "emitterar": "emittera",
    "emitteras": "emittera",
    "emitterat": "emittera",
    "emitterats": "emittera",
    "emitterbara": "emitterbar",
    "emitterbarare": "emitterbar",
    "emitterbarares": "emitterbar",
    "emitterbaras": "emitterbar",
    "emitterbarast": "emitterbar",
    "emitterbaraste": "emitterbar",
    "emitterbarastes": "emitterbar",
    "emitterbarasts": "emitterbar",
    "emitterbare": "emitterbar",
    "emitterbares": "emitterbar",
    "emitterbarheten": "emitterbarhet",
    "emitterbarhetens": "emitterbarhet",
    "emitterbarhets": "emitterbarhet",
    "emitterbars": "emitterbar",
    "emitterbart": "emitterbar",
    "emitterbarts": "emitterbar",
    "emitteringar": "emittering",
    "emitteringarna": "emittering",
    "emitteringarnas": "emittering",
    "emitteringars": "emittering",
    "emitteringen": "emittering",
    "emitteringens": "emittering",
    "emitterings": "emittering",
    "emittern": "emitter",
    "emitterns": "emitter",
    "emitters": "emitter",
    "emittrar": "emitter",
    "emittrarna": "emitter",
    "emittrarnas": "emitter",
    "emittrars": "emitter",
    "emman": "emma",
    "emmans": "emma",
    "emmas": "emma",
    "emme": "emma",
    "emmentalern": "emmentaler",
    "emmentalerns": "emmentaler",
    "emmentalers": "emmentaler",
    "emmern": "emmer",
    "emmerns": "emmer",
    "emmers": "emmer",
    "emmor": "emma",
    "emmorna": "emma",
    "emmornas": "emma",
    "emmors": "emma",
    "emollitionen": "emollition",
    "emollitionens": "emollition",
    "emollitioner": "emollition",
    "emollitionerna": "emollition",
    "emollitionernas": "emollition",
    "emollitioners": "emollition",
    "emollitions": "emollition",
    "emotionella": "emotionell",
    "emotionellare": "emotionell",
    "emotionellares": "emotionell",
    "emotionellas": "emotionell",
    "emotionellast": "emotionell",
    "emotionellaste": "emotionell",
    "emotionellastes": "emotionell",
    "emotionellasts": "emotionell",
    "emotionelle": "emotionell",
    "emotionelles": "emotionell",
    "emotionells": "emotionell",
    "emotionellt": "emotionell",
    "emotionellts": "emotionell",
    "emotionen": "emotion",
    "emotionens": "emotion",
    "emotioner": "emotion",
    "emotionerna": "emotion",
    "emotionernas": "emotion",
    "emotioners": "emotion",
    "emotions": "emotion",
    "emotiva": "emotiv",
    "emotivare": "emotiv",
    "emotivares": "emotiv",
    "emotivas": "emotiv",
    "emotivast": "emotiv",
    "emotivaste": "emotiv",
    "emotivastes": "emotiv",
    "emotivasts": "emotiv",
    "emotive": "emotiv",
    "emotives": "emotiv",
    "emotivs": "emotiv",
    "emotivt": "emotiv",
    "emotivts": "emotiv",
    "emotsedd": "emotse",
    "emotsedda": "emotse",
    "emotseddas": "emotse",
    "emotsedde": "emotse",
    "emotseddes": "emotse",
    "emotsedds": "emotse",
    "emotseende": "emotse",
    "emotseenden": "emotseende",
    "emotseendena": "emotseende",
    "emotseendenas": "emotseende",
    "emotseendens": "emotseende",
    "emotseendes": "emotseende",
    "emotseendet": "emotseende",
    "emotseendets": "emotseende",
    "emotser": "emotse",
    "emotses": "emotse",
    "emotsett": "emotse",
    "emotsetts": "emotse",
    "emotstod": "emotstå",
    "emotstode": "emotstå",
    "emotstodes": "emotstå",
    "emotstods": "emotstå",
    "emotstående": "emotstå",
    "emotståenden": "emotstående",
    "emotståendena": "emotstående",
    "emotståendenas": "emotstående",
    "emotståendens": "emotstående",
    "emotståendes": "emotstående",
    "emotståendet": "emotstående",
    "emotståendets": "emotstående",
    "emotstånden": "emotstå",
    "emotståndens": "emotstå",
    "emotståndet": "emotstå",
    "emotståndets": "emotstå",
    "emotståndna": "emotstå",
    "emotståndnas": "emotstå",
    "emotståndne": "emotstå",
    "emotståndnes": "emotstå",
    "emotstår": "emotstå",
    "emotstås": "emotstå",
    "emotstått": "emotstå",
    "emotståtts": "emotstå",
    "emotsåg": "emotse",
    "emotsåge": "emotse",
    "emotsåges": "emotse",
    "emotsågs": "emotse",
    "emottag": "emotta",
    "emottaga": "emotta",
    "emottagande": "emotta",
    "emottaganden": "emottagande",
    "emottagandena": "emottagande",
    "emottagandenas": "emottagande",
    "emottagandens": "emottagande",
    "emottagandes": "emottagande",
    "emottagandet": "emottagande",
    "emottagandets": "emottagande",
    "emottagas": "emotta",
    "emottage": "emotta",
    "emottagen": "emotta",
    "emottagens": "emotta",
    "emottager": "emotta",
    "emottages": "emotta",
    "emottaget": "emotta",
    "emottagets": "emotta",
    "emottagit": "emotta",
    "emottagits": "emotta",
    "emottagna": "emotta",
    "emottagnas": "emotta",
    "emottagne": "emotta",
    "emottagnes": "emotta",
    "emottags": "emotta",
    "emottar": "emotta",
    "emottas": "emotta",
    "emottog": "emotta",
    "emottoge": "emotta",
    "emottoges": "emotta",
    "emottogs": "emotta",
    "empatibefriade": "empatibefriad",
    "empatibefriades": "empatibefriad",
    "empatibefriads": "empatibefriad",
    "empatibefriat": "empatibefriad",
    "empatibefriats": "empatibefriad",
    "empatien": "empati",
    "empatiens": "empati",
    "empatin": "empati",
    "empatins": "empati",
    "empatis": "empati",
    "empatiska": "empatisk",
    "empatiskas": "empatisk",
    "empatiske": "empatisk",
    "empatiskes": "empatisk",
    "empatisks": "empatisk",
    "empatiskt": "empatisk",
    "empatiskts": "empatisk",
    "empiren": "empire",
    "empirens": "empire",
    "empires": "empire",
    "empirestilar": "empirestil",
    "empirestilarna": "empirestil",
    "empirestilarnas": "empirestil",
    "empirestilars": "empirestil",
    "empirestilen": "empirestil",
    "empirestilens": "empirestil",
    "empirestils": "empirestil",
    "empirien": "empiri",
    "empiriens": "empiri",
    "empirikern": "empiriker",
    "empirikerna": "empiriker",
    "empirikernas": "empiriker",
    "empirikerns": "empiriker",
    "empirikers": "empiriker",
    "empirin": "empiri",
    "empirins": "empiri",
    "empiris": "empiri",
    "empiriska": "empirisk",
    "empiriskare": "empirisk",
    "empiriskares": "empirisk",
    "empiriskas": "empirisk",
    "empiriskast": "empirisk",
    "empiriskaste": "empirisk",
    "empiriskastes": "empirisk",
    "empiriskasts": "empirisk",
    "empiriske": "empirisk",
    "empiriskes": "empirisk",
    "empirisks": "empirisk",
    "empiriskt": "empirisk",
    "empiriskts": "empirisk",
    "empirismen": "empirism",
    "empirismens": "empirism",
    "empirismer": "empirism",
    "empirismerna": "empirism",
    "empirismernas": "empirism",
    "empirismers": "empirism",
    "empirisms": "empirism",
    "empiristen": "empirist",
    "empiristens": "empirist",
    "empirister": "empirist",
    "empiristerna": "empirist",
    "empiristernas": "empirist",
    "empiristers": "empirist",
    "empiristiska": "empiristisk",
    "empiristiskas": "empiristisk",
    "empiristiske": "empiristisk",
    "empiristiskes": "empiristisk",
    "empiristisks": "empiristisk",
    "empiristiskt": "empiristisk",
    "empiristiskts": "empiristisk",
    "empirists": "empirist",
    "empirs": "empir",
    "empyemen": "empyem",
    "empyemens": "empyem",
    "empyemet": "empyem",
    "empyemets": "empyem",
    "empyems": "empyem",
    "ems": "emma",
    "emsersaltet": "emsersalt",
    "emsersaltets": "emsersalt",
    "emsersalts": "emsersalt",
    "emservattens": "emservatten",
    "emservattnet": "emservatten",
    "emservattnets": "emservatten",
    "emuer": "emu",
    "emuerna": "emu",
    "emuernas": "emu",
    "emuers": "emu",
    "emulgerad": "emulgera",
    "emulgerade": "emulgera",
    "emulgerades": "emulgera",
    "emulgerads": "emulgera",
    "emulgerande": "emulgera",
    "emulgeranden": "emulgerande",
    "emulgerandena": "emulgerande",
    "emulgerandenas": "emulgerande",
    "emulgerandens": "emulgerande",
    "emulgerandes": "emulgerande",
    "emulgerandet": "emulgerande",
    "emulgerandets": "emulgerande",
    "emulgerar": "emulgera",
    "emulgeras": "emulgera",
    "emulgerat": "emulgera",
    "emulgerats": "emulgera",
    "emulgerbara": "emulgerbar",
    "emulgerbarare": "emulgerbar",
    "emulgerbarares": "emulgerbar",
    "emulgerbaras": "emulgerbar",
    "emulgerbarast": "emulgerbar",
    "emulgerbaraste": "emulgerbar",
    "emulgerbarastes": "emulgerbar",
    "emulgerbarasts": "emulgerbar",
    "emulgerbare": "emulgerbar",
    "emulgerbares": "emulgerbar",
    "emulgerbarheten": "emulgerbarhet",
    "emulgerbarhetens": "emulgerbarhet",
    "emulgerbarhets": "emulgerbarhet",
    "emulgerbars": "emulgerbar",
    "emulgerbart": "emulgerbar",
    "emulgerbarts": "emulgerbar",
    "emulgeringar": "emulgering",
    "emulgeringarna": "emulgering",
    "emulgeringarnas": "emulgering",
    "emulgeringars": "emulgering",
    "emulgeringen": "emulgering",
    "emulgeringens": "emulgering",
    "emulgerings": "emulgering",
    "emulsionen": "emulsion",
    "emulsionens": "emulsion",
    "emulsioner": "emulsion",
    "emulsionerna": "emulsion",
    "emulsionernas": "emulsion",
    "emulsioners": "emulsion",
    "emulsions": "emulsion",
    "emulsionsfärgen": "emulsionsfärg",
    "emulsionsfärgens": "emulsionsfärg",
    "emulsionsfärger": "emulsionsfärg",
    "emulsionsfärgerna": "emulsionsfärg",
    "emulsionsfärgernas": "emulsionsfärg",
    "emulsionsfärgers": "emulsionsfärg",
    "emulsionsfärgs": "emulsionsfärg",
    "emulsionssprängämnen": "emulsionssprängämne",
    "emulsionssprängämnena": "emulsionssprängämne",
    "emulsionssprängämnenas": "emulsionssprängämne",
    "emulsionssprängämnens": "emulsionssprängämne",
    "emulsionssprängämnes": "emulsionssprängämne",
    "emulsionssprängämnet": "emulsionssprängämne",
    "emulsionssprängämnets": "emulsionssprängämne",
    "emun": "emu",
    "emuns": "emu",
    "emus": "emu",
    "en": "man",
    "ena": "en",
    "enad": "ena",
    "enade": "ena",
    "enades": "enas",
    "enads": "ena",
    "enaktar": "enaktare",
    "enaktaren": "enaktare",
    "enaktarens": "enaktare",
    "enaktares": "enaktare",
    "enaktarna": "enaktare",
    "enaktarnas": "enaktare",
    "enande": "ena",
    "enanden": "enande",
    "enandena": "enande",
    "enandenas": "enande",
    "enandens": "enande",
    "enandes": "enande",
    "enandet": "enande",
    "enandets": "enande",
    "enar": "ena",
    "enarmade": "enarmad",
    "enarmades": "enarmad",
    "enarmads": "enarmad",
    "enarmat": "enarmad",
    "enarmats": "enarmad",
    "enarmiga": "enarmig",
    "enarmigare": "enarmig",
    "enarmigares": "enarmig",
    "enarmigas": "enarmig",
    "enarmigast": "enarmig",
    "enarmigaste": "enarmig",
    "enarmigastes": "enarmig",
    "enarmigasts": "enarmig",
    "enarmige": "enarmig",
    "enarmiges": "enarmig",
    "enarmigs": "enarmig",
    "enarmigt": "enarmig",
    "enarmigts": "enarmig",
    "enarna": "en",
    "enarnas": "en",
    "enars": "en",
    "enas": "ena",
    "enat": "ena",
    "enats": "enas",
    "enaxlade": "enaxlad",
    "enaxlades": "enaxlad",
    "enaxlads": "enaxlad",
    "enaxlat": "enaxlad",
    "enaxlats": "enaxlad",
    "enaxliga": "enaxlig",
    "enaxligare": "enaxlig",
    "enaxligares": "enaxlig",
    "enaxligas": "enaxlig",
    "enaxligast": "enaxlig",
    "enaxligaste": "enaxlig",
    "enaxligastes": "enaxlig",
    "enaxligasts": "enaxlig",
    "enaxlige": "enaxlig",
    "enaxliges": "enaxlig",
    "enaxligheten": "enaxlighet",
    "enaxlighetens": "enaxlighet",
    "enaxlighets": "enaxlighet",
    "enaxligs": "enaxlig",
    "enaxligt": "enaxlig",
    "enaxligts": "enaxlig",
    "enback": "enbacke",
    "enbackar": "enbacke",
    "enbackarna": "enbacke",
    "enbackarnas": "enbacke",
    "enbackars": "enbacke",
    "enbacken": "enbacke",
    "enbackens": "enbacke",
    "enbackes": "enbacke",
    "enbacks": "enbacke",
    "enbasiska": "enbasisk",
    "enbasiskare": "enbasisk",
    "enbasiskares": "enbasisk",
    "enbasiskas": "enbasisk",
    "enbasiskast": "enbasisk",
    "enbasiskaste": "enbasisk",
    "enbasiskastes": "enbasisk",
    "enbasiskasts": "enbasisk",
    "enbasiske": "enbasisk",
    "enbasiskes": "enbasisk",
    "enbasisks": "enbasisk",
    "enbasiskt": "enbasisk",
    "enbasiskts": "enbasisk",
    "enbenta": "enbent",
    "enbentare": "enbent",
    "enbentares": "enbent",
    "enbentas": "enbent",
    "enbentast": "enbent",
    "enbentaste": "enbent",
    "enbentastes": "enbent",
    "enbentasts": "enbent",
    "enbente": "enbent",
    "enbentes": "enbent",
    "enbentheten": "enbenthet",
    "enbenthetens": "enbenthet",
    "enbenthets": "enbenthet",
    "enbents": "enbent",
    "enbeten": "enbet",
    "enbetens": "enbet",
    "enbetet": "enbet",
    "enbetets": "enbet",
    "enbets": "enbet",
    "enbusk": "enbuske",
    "enbuskar": "enbuske",
    "enbuskarna": "enbuske",
    "enbuskarnas": "enbuske",
    "enbuskars": "enbuske",
    "enbusken": "enbuske",
    "enbuskens": "enbuske",
    "enbuskes": "enbuske",
    "enbyggar": "enbyggare",
    "enbyggaren": "enbyggare",
    "enbyggarens": "enbyggare",
    "enbyggares": "enbyggare",
    "enbyggarna": "enbyggare",
    "enbyggarnas": "enbyggare",
    "enbäddsrummen": "enbäddsrum",
    "enbäddsrummens": "enbäddsrum",
    "enbäddsrummet": "enbäddsrum",
    "enbäddsrummets": "enbäddsrum",
    "enbäddsrums": "enbäddsrum",
    "enbären": "enbär",
    "enbärens": "enbär",
    "enbäret": "enbär",
    "enbärets": "enbär",
    "enbärs": "enbär",
    "encefaliten": "encefalit",
    "encefalitens": "encefalit",
    "encefaliter": "encefalit",
    "encefaliterna": "encefalit",
    "encefaliternas": "encefalit",
    "encefaliters": "encefalit",
    "encefalits": "encefalit",
    "encefalografien": "encefalografi",
    "encefalografiens": "encefalografi",
    "encefalografier": "encefalografi",
    "encefalografierna": "encefalografi",
    "encefalografiernas": "encefalografi",
    "encefalografiers": "encefalografi",
    "encefalografin": "encefalografi",
    "encefalografins": "encefalografi",
    "encefalografis": "encefalografi",
    "encelliga": "encellig",
    "encelligare": "encellig",
    "encelligares": "encellig",
    "encelligas": "encellig",
    "encelligast": "encellig",
    "encelligaste": "encellig",
    "encelligastes": "encellig",
    "encelligasts": "encellig",
    "encellige": "encellig",
    "encelliges": "encellig",
    "encelligheten": "encellighet",
    "encellighetens": "encellighet",
    "encellighets": "encellighet",
    "encelligs": "encellig",
    "encelligt": "encellig",
    "encelligts": "encellig",
    "encyklik": "encyklika",
    "encyklikan": "encyklika",
    "encyklikans": "encyklika",
    "encyklikas": "encyklika",
    "encyklike": "encyklika",
    "encyklikor": "encyklika",
    "encyklikorna": "encyklika",
    "encyklikornas": "encyklika",
    "encyklikors": "encyklika",
    "encykliks": "encyklika",
    "encyklopedien": "encyklopedi",
    "encyklopediens": "encyklopedi",
    "encyklopedier": "encyklopedi",
    "encyklopedierna": "encyklopedi",
    "encyklopediernas": "encyklopedi",
    "encyklopediers": "encyklopedi",
    "encyklopedin": "encyklopedi",
    "encyklopedins": "encyklopedi",
    "encyklopedis": "encyklopedi",
    "encyklopediska": "encyklopedisk",
    "encyklopediskare": "encyklopedisk",
    "encyklopediskares": "encyklopedisk",
    "encyklopediskas": "encyklopedisk",
    "encyklopediskast": "encyklopedisk",
    "encyklopediskaste": "encyklopedisk",
    "encyklopediskastes": "encyklopedisk",
    "encyklopediskasts": "encyklopedisk",
    "encyklopediske": "encyklopedisk",
    "encyklopediskes": "encyklopedisk",
    "encyklopedisks": "encyklopedisk",
    "encyklopediskt": "encyklopedisk",
    "encyklopediskts": "encyklopedisk",
    "endagsbesöken": "endagsbesök",
    "endagsbesökens": "endagsbesök",
    "endagsbesöket": "endagsbesök",
    "endagsbesökets": "endagsbesök",
    "endagsbesöks": "endagsbesök",
    "endas": "enda",
    "ende": "enda",
    "endemien": "endemi",
    "endemiens": "endemi",
    "endemier": "endemi",
    "endemierna": "endemi",
    "endemiernas": "endemi",
    "endemiers": "endemi",
    "endemin": "endemi",
    "endemins": "endemi",
    "endemis": "endemi",
    "endemiska": "endemisk",
    "endemiskare": "endemisk",
    "endemiskares": "endemisk",
    "endemiskas": "endemisk",
    "endemiskast": "endemisk",
    "endemiskaste": "endemisk",
    "endemiskastes": "endemisk",
    "endemiskasts": "endemisk",
    "endemiske": "endemisk",
    "endemiskes": "endemisk",
    "endemisks": "endemisk",
    "endemiskt": "endemisk",
    "endemiskts": "endemisk",
    "enderas": "endera",
    "endes": "enda",
    "endimensionella": "endimensionell",
    "endimensionellare": "endimensionell",
    "endimensionellares": "endimensionell",
    "endimensionellas": "endimensionell",
    "endimensionellast": "endimensionell",
    "endimensionellaste": "endimensionell",
    "endimensionellastes": "endimensionell",
    "endimensionellasts": "endimensionell",
    "endimensionelle": "endimensionell",
    "endimensionelles": "endimensionell",
    "endimensionells": "endimensionell",
    "endimensionellt": "endimensionell",
    "endimensionellts": "endimensionell",
    "endiven": "endiv",
    "endivens": "endiv",
    "endiver": "endiv",
    "endiverna": "endiv",
    "endivernas": "endiv",
    "endivers": "endiv",
    "endivs": "endiv",
    "endogena": "endogen",
    "endogenare": "endogen",
    "endogenares": "endogen",
    "endogenas": "endogen",
    "endogenast": "endogen",
    "endogenaste": "endogen",
    "endogenastes": "endogen",
    "endogenasts": "endogen",
    "endogene": "endogen",
    "endogenes": "endogen",
    "endogens": "endogen",
    "endogent": "endogen",
    "endogents": "endogen",
    "endokrina": "endokrin",
    "endokrinare": "endokrin",
    "endokrinares": "endokrin",
    "endokrinas": "endokrin",
    "endokrinast": "endokrin",
    "endokrinaste": "endokrin",
    "endokrinastes": "endokrin",
    "endokrinasts": "endokrin",
    "endokrine": "endokrin",
    "endokrines": "endokrin",
    "endokrinologen": "endokrinolog",
    "endokrinologens": "endokrinolog",
    "endokrinologer": "endokrinolog",
    "endokrinologerna": "endokrinolog",
    "endokrinologernas": "endokrinolog",
    "endokrinologers": "endokrinolog",
    "endokrinologien": "endokrinologi",
    "endokrinologiens": "endokrinologi",
    "endokrinologin": "endokrinologi",
    "endokrinologins": "endokrinologi",
    "endokrinologis": "endokrinologi",
    "endokrinologs": "endokrinolog",
    "endokrins": "endokrin",
    "endokrint": "endokrin",
    "endokrints": "endokrin",
    "endonymen": "endonym",
    "endonymens": "endonym",
    "endonymer": "endonym",
    "endonymerna": "endonym",
    "endonymernas": "endonym",
    "endonymers": "endonym",
    "endonyms": "endonym",
    "endorfiner": "endorfin",
    "endorfinerna": "endorfin",
    "endorfinernas": "endorfin",
    "endorfiners": "endorfin",
    "endorfinet": "endorfin",
    "endorfinets": "endorfin",
    "endorfins": "endorfin",
    "endossaten": "endossat",
    "endossatens": "endossat",
    "endossater": "endossat",
    "endossaterna": "endossat",
    "endossaternas": "endossat",
    "endossaters": "endossat",
    "endossats": "endossat",
    "endossemangen": "endossemang",
    "endossemangens": "endossemang",
    "endossemanget": "endossemang",
    "endossemangets": "endossemang",
    "endossemangs": "endossemang",
    "endossementen": "endossement",
    "endossementens": "endossement",
    "endossementet": "endossement",
    "endossementets": "endossement",
    "endossements": "endossement",
    "endossenten": "endossent",
    "endossentens": "endossent",
    "endossenter": "endossent",
    "endossenterna": "endossent",
    "endossenternas": "endossent",
    "endossenters": "endossent",
    "endossents": "endossent",
    "endosserad": "endossera",
    "endosserade": "endossera",
    "endosserades": "endossera",
    "endosserads": "endossera",
    "endosserande": "endossera",
    "endosseranden": "endosserande",
    "endosserandena": "endosserande",
    "endosserandenas": "endosserande",
    "endosserandens": "endosserande",
    "endosserandes": "endosserande",
    "endosserandet": "endosserande",
    "endosserandets": "endosserande",
    "endosserar": "endossera",
    "endosseras": "endossera",
    "endosserat": "endossera",
    "endosserats": "endossera",
    "endosserbara": "endosserbar",
    "endosserbarare": "endosserbar",
    "endosserbarares": "endosserbar",
    "endosserbaras": "endosserbar",
    "endosserbarast": "endosserbar",
    "endosserbaraste": "endosserbar",
    "endosserbarastes": "endosserbar",
    "endosserbarasts": "endosserbar",
    "endosserbare": "endosserbar",
    "endosserbares": "endosserbar",
    "endosserbarheten": "endosserbarhet",
    "endosserbarhetens": "endosserbarhet",
    "endosserbarhets": "endosserbarhet",
    "endosserbars": "endosserbar",
    "endosserbart": "endosserbar",
    "endosserbarts": "endosserbar",
    "endosseringar": "endossering",
    "endosseringarna": "endossering",
    "endosseringarnas": "endossering",
    "endosseringars": "endossering",
    "endosseringen": "endossering",
    "endosseringens": "endossering",
    "endosserings": "endossering",
    "endotermiska": "endotermisk",
    "endotermiskare": "endotermisk",
    "endotermiskares": "endotermisk",
    "endotermiskas": "endotermisk",
    "endotermiskast": "endotermisk",
    "endotermiskaste": "endotermisk",
    "endotermiskastes": "endotermisk",
    "endotermiskasts": "endotermisk",
    "endotermiske": "endotermisk",
    "endotermiskes": "endotermisk",
    "endotermisks": "endotermisk",
    "endotermiskt": "endotermisk",
    "endotermiskts": "endotermisk",
    "endräkten": "endräkt",
    "endräktens": "endräkt",
    "endräkts": "endräkt",
    "ene": "ena",
    "enen": "en",
    "enens": "en",
    "energialternativen": "energialternativ",
    "energialternativens": "energialternativ",
    "energialternativet": "energialternativ",
    "energialternativets": "energialternativ",
    "energialternativs": "energialternativ",
    "energibehoven": "energibehov",
    "energibehovens": "energibehov",
    "energibehovet": "energibehov",
    "energibehovets": "energibehov",
    "energibehovs": "energibehov",
    "energidepartementen": "energidepartement",
    "energidepartementens": "energidepartement",
    "energidepartementet": "energidepartement",
    "energidepartementets": "energidepartement",
    "energidepartements": "energidepartement",
    "energidrycken": "energidryck",
    "energidryckens": "energidryck",
    "energidrycker": "energidryck",
    "energidryckerna": "energidryck",
    "energidryckernas": "energidryck",
    "energidryckers": "energidryck",
    "energidrycks": "energidryck",
    "energien": "energi",
    "energiens": "energi",
    "energier": "energi",
    "energierna": "energi",
    "energiernas": "energi",
    "energiers": "energi",
    "energiformen": "energiform",
    "energiformens": "energiform",
    "energiformer": "energiform",
    "energiformerna": "energiform",
    "energiformernas": "energiform",
    "energiformers": "energiform",
    "energiforms": "energiform",
    "energiförlusten": "energiförlust",
    "energiförlustens": "energiförlust",
    "energiförluster": "energiförlust",
    "energiförlusterna": "energiförlust",
    "energiförlusternas": "energiförlust",
    "energiförlusters": "energiförlust",
    "energiförlusts": "energiförlust",
    "energiförsörjningar": "energiförsörjning",
    "energiförsörjningarna": "energiförsörjning",
    "energiförsörjningarnas": "energiförsörjning",
    "energiförsörjningars": "energiförsörjning",
    "energiförsörjningen": "energiförsörjning",
    "energiförsörjningens": "energiförsörjning",
    "energiförsörjnings": "energiförsörjning",
    "energiinnehållen": "energiinnehåll",
    "energiinnehållens": "energiinnehåll",
    "energiinnehållet": "energiinnehåll",
    "energiinnehållets": "energiinnehåll",
    "energiinnehålls": "energiinnehåll",
    "energiintagen": "energiintag",
    "energiintagens": "energiintag",
    "energiintaget": "energiintag",
    "energiintagets": "energiintag",
    "energiintags": "energiintag",
    "energiknipp": "energiknippe",
    "energiknippen": "energiknippe",
    "energiknippena": "energiknippe",
    "energiknippenas": "energiknippe",
    "energiknippens": "energiknippe",
    "energiknippes": "energiknippe",
    "energiknippet": "energiknippe",
    "energiknippets": "energiknippe",
    "energiknipps": "energiknippe",
    "energikoncentrationen": "energikoncentration",
    "energikoncentrationens": "energikoncentration",
    "energikoncentrationer": "energikoncentration",
    "energikoncentrationerna": "energikoncentration",
    "energikoncentrationernas": "energikoncentration",
    "energikoncentrationers": "energikoncentration",
    "energikoncentrations": "energikoncentration",
    "energikäll": "energikälla",
    "energikällan": "energikälla",
    "energikällans": "energikälla",
    "energikällas": "energikälla",
    "energikälle": "energikälla",
    "energikällor": "energikälla",
    "energikällorna": "energikälla",
    "energikällornas": "energikälla",
    "energikällors": "energikälla",
    "energikälls": "energikälla",
    "energimarknaden": "energimarknad",
    "energimarknadens": "energimarknad",
    "energimarknader": "energimarknad",
    "energimarknaderna": "energimarknad",
    "energimarknadernas": "energimarknad",
    "energimarknaders": "energimarknad",
    "energimarknads": "energimarknad",
    "energimixen": "energimix",
    "energimixens": "energimix",
    "energimixer": "energimix",
    "energimixerna": "energimix",
    "energimixernas": "energimix",
    "energimixers": "energimix",
    "energimängden": "energimängd",
    "energimängdens": "energimängd",
    "energimängder": "energimängd",
    "energimängderna": "energimängd",
    "energimängdernas": "energimängd",
    "energimängders": "energimängd",
    "energimängds": "energimängd",
    "energimässiga": "energimässig",
    "energimässigare": "energimässig",
    "energimässigares": "energimässig",
    "energimässigas": "energimässig",
    "energimässigast": "energimässig",
    "energimässigaste": "energimässig",
    "energimässigastes": "energimässig",
    "energimässigasts": "energimässig",
    "energimässige": "energimässig",
    "energimässiges": "energimässig",
    "energimässigs": "energimässig",
    "energimässigt": "energimässig",
    "energimässigts": "energimässig",
    "energin": "energi",
    "energins": "energi",
    "energiomställningar": "energiomställning",
    "energiomställningarna": "energiomställning",
    "energiomställningarnas": "energiomställning",
    "energiomställningars": "energiomställning",
    "energiomställningen": "energiomställning",
    "energiomställningens": "energiomställning",
    "energiomställnings": "energiomställning",
    "energiomsättningar": "energiomsättning",
    "energiomsättningarna": "energiomsättning",
    "energiomsättningarnas": "energiomsättning",
    "energiomsättningars": "energiomsättning",
    "energiomsättningen": "energiomsättning",
    "energiomsättningens": "energiomsättning",
    "energiomsättnings": "energiomsättning",
    "energiomvandlingar": "energiomvandling",
    "energiomvandlingarna": "energiomvandling",
    "energiomvandlingarnas": "energiomvandling",
    "energiomvandlingars": "energiomvandling",
    "energiomvandlingen": "energiomvandling",
    "energiomvandlingens": "energiomvandling",
    "energiomvandlings": "energiomvandling",
    "energiomvandlingscentra": "energiomvandlingscentrum",
    "energiomvandlingscentrana": "energiomvandlingscentrum",
    "energiomvandlingscentranas": "energiomvandlingscentrum",
    "energiomvandlingscentras": "energiomvandlingscentrum",
    "energiomvandlingscentrer": "energiomvandlingscentrum",
    "energiomvandlingscentrerna": "energiomvandlingscentrum",
    "energiomvandlingscentrernas": "energiomvandlingscentrum",
    "energiomvandlingscentrers": "energiomvandlingscentrum",
    "energiomvandlingscentret": "energiomvandlingscentrum",
    "energiomvandlingscentrets": "energiomvandlingscentrum",
    "energiomvandlingscentrumen": "energiomvandlingscentrum",
    "energiomvandlingscentrumens": "energiomvandlingscentrum",
    "energiomvandlingscentrumet": "energiomvandlingscentrum",
    "energiomvandlingscentrumets": "energiomvandlingscentrum",
    "energiomvandlingscentrums": "energiomvandlingscentrum",
    "energipolitiken": "energipolitik",
    "energipolitikens": "energipolitik",
    "energipolitiker": "energipolitik",
    "energipolitikerna": "energipolitik",
    "energipolitikernas": "energipolitik",
    "energipolitikers": "energipolitik",
    "energipolitiks": "energipolitik",
    "energipolitiska": "energipolitisk",
    "energipolitiskas": "energipolitisk",
    "energipolitiske": "energipolitisk",
    "energipolitiskes": "energipolitisk",
    "energipolitisks": "energipolitisk",
    "energipolitiskt": "energipolitisk",
    "energipolitiskts": "energipolitisk",
    "energiprincipen": "energiprincip",
    "energiprincipens": "energiprincip",
    "energiprincips": "energiprincip",
    "energirika": "energirik",
    "energirikare": "energirik",
    "energirikares": "energirik",
    "energirikas": "energirik",
    "energirikast": "energirik",
    "energirikaste": "energirik",
    "energirikastes": "energirik",
    "energirikasts": "energirik",
    "energirike": "energirik",
    "energirikes": "energirik",
    "energirikheten": "energirikhet",
    "energirikhetens": "energirikhet",
    "energirikhets": "energirikhet",
    "energiriks": "energirik",
    "energirikt": "energirik",
    "energirikts": "energirik",
    "energis": "energi",
    "energiska": "energisk",
    "energiskare": "energisk",
    "energiskares": "energisk",
    "energiskas": "energisk",
    "energiskast": "energisk",
    "energiskaste": "energisk",
    "energiskastes": "energisk",
    "energiskasts": "energisk",
    "energiskatten": "energiskatt",
    "energiskattens": "energiskatt",
    "energiskatter": "energiskatt",
    "energiskatterna": "energiskatt",
    "energiskatternas": "energiskatt",
    "energiskatters": "energiskatt",
    "energiskatts": "energiskatt",
    "energiske": "energisk",
    "energiskes": "energisk",
    "energiskogar": "energiskog",
    "energiskogarna": "energiskog",
    "energiskogarnas": "energiskog",
    "energiskogars": "energiskog",
    "energiskogen": "energiskog",
    "energiskogens": "energiskog",
    "energiskogs": "energiskog",
    "energisks": "energisk",
    "energiskt": "energisk",
    "energiskts": "energisk",
    "energisystemen": "energisystem",
    "energisystemens": "energisystem",
    "energisystemet": "energisystem",
    "energisystemets": "energisystem",
    "energisystems": "energisystem",
    "energiteorien": "energiteori",
    "energiteoriens": "energiteori",
    "energiteorier": "energiteori",
    "energiteorierna": "energiteori",
    "energiteoriernas": "energiteori",
    "energiteoriers": "energiteori",
    "energiteorin": "energiteori",
    "energiteorins": "energiteori",
    "energiteoris": "energiteori",
    "energitillstånden": "energitillstånd",
    "energitillståndens": "energitillstånd",
    "energitillståndet": "energitillstånd",
    "energitillståndets": "energitillstånd",
    "energitillstånds": "energitillstånd",
    "energiuppgörelsen": "energiuppgörelse",
    "energiuppgörelsens": "energiuppgörelse",
    "energiuppgörelser": "energiuppgörelse",
    "energiuppgörelserna": "energiuppgörelse",
    "energiuppgörelsernas": "energiuppgörelse",
    "energiuppgörelsers": "energiuppgörelse",
    "energiuppgörelses": "energiuppgörelse",
    "energiutstrålningar": "energiutstrålning",
    "energiutstrålningarna": "energiutstrålning",
    "energiutstrålningarnas": "energiutstrålning",
    "energiutstrålningars": "energiutstrålning",
    "energiutstrålningen": "energiutstrålning",
    "energiutstrålningens": "energiutstrålning",
    "energiutstrålnings": "energiutstrålning",
    "energiutvecklingar": "energiutveckling",
    "energiutvecklingarna": "energiutveckling",
    "energiutvecklingarnas": "energiutveckling",
    "energiutvecklingars": "energiutveckling",
    "energiutvecklingen": "energiutveckling",
    "energiutvecklingens": "energiutveckling",
    "energiutvecklings": "energiutveckling",
    "energiverken": "energiverk",
    "energiverkens": "energiverk",
    "energiverket": "energiverk",
    "energiverkets": "energiverk",
    "energiverks": "energiverk",
    "energivinsten": "energivinst",
    "energivinstens": "energivinst",
    "energivinster": "energivinst",
    "energivinsterna": "energivinst",
    "energivinsternas": "energivinst",
    "energivinsters": "energivinst",
    "energivinsts": "energivinst",
    "enerverad": "enervera",
    "enerverade": "enervera",
    "enerverades": "enervera",
    "enerverads": "enervera",
    "enerverande": "enervera",
    "enerveranden": "enerverande",
    "enerverandena": "enerverande",
    "enerverandenas": "enerverande",
    "enerverandens": "enerverande",
    "enerverandes": "enerverande",
    "enerverandet": "enerverande",
    "enerverandets": "enerverande",
    "enerverar": "enervera",
    "enerveras": "enervera",
    "enerverat": "enervera",
    "enerverats": "enervera",
    "enerverbara": "enerverbar",
    "enerverbarare": "enerverbar",
    "enerverbarares": "enerverbar",
    "enerverbaras": "enerverbar",
    "enerverbarast": "enerverbar",
    "enerverbaraste": "enerverbar",
    "enerverbarastes": "enerverbar",
    "enerverbarasts": "enerverbar",
    "enerverbare": "enerverbar",
    "enerverbares": "enerverbar",
    "enerverbarheten": "enerverbarhet",
    "enerverbarhetens": "enerverbarhet",
    "enerverbarhets": "enerverbarhet",
    "enerverbars": "enerverbar",
    "enerverbart": "enerverbar",
    "enerverbarts": "enerverbar",
    "enerveringar": "enervering",
    "enerveringarna": "enervering",
    "enerveringarnas": "enervering",
    "enerveringars": "enervering",
    "enerveringen": "enervering",
    "enerveringens": "enervering",
    "enerverings": "enervering",
    "enes": "ene",
    "enet": "ene",
    "enets": "ene",
    "enfalden": "enfald",
    "enfaldens": "enfald",
    "enfaldiga": "enfaldig",
    "enfaldigare": "enfaldig",
    "enfaldigares": "enfaldig",
    "enfaldigas": "enfaldig",
    "enfaldigast": "enfaldig",
    "enfaldigaste": "enfaldig",
    "enfaldigastes": "enfaldig",
    "enfaldigasts": "enfaldig",
    "enfaldige": "enfaldig",
    "enfaldiges": "enfaldig",
    "enfaldigheten": "enfaldighet",
    "enfaldighetens": "enfaldighet",
    "enfaldighets": "enfaldighet",
    "enfaldigs": "enfaldig",
    "enfaldigt": "enfaldig",
    "enfaldigts": "enfaldig",
    "enfalds": "enfald",
    "enfamiljshusen": "enfamiljshus",
    "enfamiljshusens": "enfamiljshus",
    "enfamiljshuset": "enfamiljshus",
    "enfamiljshusets": "enfamiljshus",
    "enfasiga": "enfasig",
    "enfasigare": "enfasig",
    "enfasigares": "enfasig",
    "enfasigas": "enfasig",
    "enfasigast": "enfasig",
    "enfasigaste": "enfasig",
    "enfasigastes": "enfasig",
    "enfasigasts": "enfasig",
    "enfasige": "enfasig",
    "enfasiges": "enfasig",
    "enfasigs": "enfasig",
    "enfasigt": "enfasig",
    "enfasigts": "enfasig",
    "enformiga": "enformig",
    "enformigare": "enformig",
    "enformigares": "enformig",
    "enformigas": "enformig",
    "enformigast": "enformig",
    "enformigaste": "enformig",
    "enformigastes": "enformig",
    "enformigasts": "enformig",
    "enformige": "enformig",
    "enformiges": "enformig",
    "enformigheten": "enformighet",
    "enformighetens": "enformighet",
    "enformighets": "enformighet",
    "enformigs": "enformig",
    "enformigt": "enformig",
    "enformigts": "enformig",
    "enfotade": "enfotad",
    "enfotades": "enfotad",
    "enfotads": "enfotad",
    "enfotat": "enfotad",
    "enfotats": "enfotad",
    "enfrågepartier": "enfrågeparti",
    "enfrågepartierna": "enfrågeparti",
    "enfrågepartiernas": "enfrågeparti",
    "enfrågepartiers": "enfrågeparti",
    "enfrågepartiet": "enfrågeparti",
    "enfrågepartiets": "enfrågeparti",
    "enfrågepartis": "enfrågeparti",
    "enfrågepartit": "enfrågeparti",
    "enfrågepartits": "enfrågeparti",
    "enfärgade": "enfärgad",
    "enfärgades": "enfärgad",
    "enfärgads": "enfärgad",
    "enfärgat": "enfärgad",
    "enfärgats": "enfärgad",
    "enfödda": "enfödd",
    "enföddare": "enfödd",
    "enföddares": "enfödd",
    "enföddas": "enfödd",
    "enföddast": "enfödd",
    "enföddaste": "enfödd",
    "enföddastes": "enfödd",
    "enföddasts": "enfödd",
    "enfödde": "enfödd",
    "enföddes": "enfödd",
    "enfödds": "enfödd",
    "enföräldersfamiljen": "enföräldersfamilj",
    "enföräldersfamiljens": "enföräldersfamilj",
    "enföräldersfamiljer": "enföräldersfamilj",
    "enföräldersfamiljerna": "enföräldersfamilj",
    "enföräldersfamiljernas": "enföräldersfamilj",
    "enföräldersfamiljers": "enföräldersfamilj",
    "enföräldersfamiljs": "enföräldersfamilj",
    "enfött": "enfödd",
    "enfötts": "enfödd",
    "engagemangen": "engagemang",
    "engagemangens": "engagemang",
    "engagemanget": "engagemang",
    "engagemangets": "engagemang",
    "engagemangs": "engagemang",
    "engagerad": "engagera",
    "engagerade": "engagerad",
    "engagerades": "engagerad",
    "engagerads": "engagerad",
    "engagerande": "engagera",
    "engageranden": "engagerande",
    "engagerandena": "engagerande",
    "engagerandenas": "engagerande",
    "engagerandens": "engagerande",
    "engagerandes": "engagerande",
    "engagerandet": "engagerande",
    "engagerandets": "engagerande",
    "engagerar": "engagera",
    "engageras": "engagera",
    "engagerat": "engagerad",
    "engagerats": "engagerad",
    "engagerbara": "engagerbar",
    "engagerbarare": "engagerbar",
    "engagerbarares": "engagerbar",
    "engagerbaras": "engagerbar",
    "engagerbarast": "engagerbar",
    "engagerbaraste": "engagerbar",
    "engagerbarastes": "engagerbar",
    "engagerbarasts": "engagerbar",
    "engagerbare": "engagerbar",
    "engagerbares": "engagerbar",
    "engagerbarheten": "engagerbarhet",
    "engagerbarhetens": "engagerbarhet",
    "engagerbarhets": "engagerbarhet",
    "engagerbars": "engagerbar",
    "engagerbart": "engagerbar",
    "engagerbarts": "engagerbar",
    "engageringar": "engagering",
    "engageringarna": "engagering",
    "engageringarnas": "engagering",
    "engageringars": "engagering",
    "engageringen": "engagering",
    "engageringens": "engagering",
    "engagerings": "engagering",
    "engelsk": "engelska",
    "engelska": "engelsk",
    "engelskakursen": "engelskakurs",
    "engelskakursens": "engelskakurs",
    "engelskakurser": "engelskakurs",
    "engelskakurserna": "engelskakurs",
    "engelskakursernas": "engelskakurs",
    "engelskakursers": "engelskakurs",
    "engelskalektionen": "engelskalektion",
    "engelskalektionens": "engelskalektion",
    "engelskalektioner": "engelskalektion",
    "engelskalektionerna": "engelskalektion",
    "engelskalektionernas": "engelskalektion",
    "engelskalektioners": "engelskalektion",
    "engelskalektions": "engelskalektion",
    "engelskalärar": "engelskalärare",
    "engelskaläraren": "engelskalärare",
    "engelskalärarens": "engelskalärare",
    "engelskalärares": "engelskalärare",
    "engelskalärarna": "engelskalärare",
    "engelskalärarnas": "engelskalärare",
    "engelskan": "engelska",
    "engelskans": "engelska",
    "engelskare": "engelsk",
    "engelskares": "engelsk",
    "engelskas": "engelska",
    "engelskast": "engelsk",
    "engelskaste": "engelsk",
    "engelskastes": "engelsk",
    "engelskasts": "engelsk",
    "engelskaundervisningen": "engelskaundervisning",
    "engelskaundervisningens": "engelskaundervisning",
    "engelskaundervisnings": "engelskaundervisning",
    "engelske": "engelska",
    "engelskes": "engelsk",
    "engelskkursen": "engelskkurs",
    "engelskkursens": "engelskkurs",
    "engelskkurser": "engelskkurs",
    "engelskkurserna": "engelskkurs",
    "engelskkursernas": "engelskkurs",
    "engelskkursers": "engelskkurs",
    "engelsklektionen": "engelsklektion",
    "engelsklektionens": "engelsklektion",
    "engelsklektioner": "engelsklektion",
    "engelsklektionerna": "engelsklektion",
    "engelsklektionernas": "engelsklektion",
    "engelsklektioners": "engelsklektion",
    "engelsklektions": "engelsklektion",
    "engelsklärar": "engelsklärare",
    "engelskläraren": "engelsklärare",
    "engelsklärarens": "engelsklärare",
    "engelsklärares": "engelsklärare",
    "engelsklärarna": "engelsklärare",
    "engelsklärarnas": "engelsklärare",
    "engelskor": "engelska",
    "engelskorna": "engelska",
    "engelskornas": "engelska",
    "engelskors": "engelska",
    "engelsks": "engelsk",
    "engelskspråkiga": "engelskspråkig",
    "engelskspråkigas": "engelskspråkig",
    "engelskspråkige": "engelskspråkig",
    "engelskspråkiges": "engelskspråkig",
    "engelskspråkigheten": "engelskspråkighet",
    "engelskspråkighetens": "engelskspråkighet",
    "engelskspråkighets": "engelskspråkighet",
    "engelskspråkigs": "engelskspråkig",
    "engelskspråkigt": "engelskspråkig",
    "engelskspråkigts": "engelskspråkig",
    "engelskt": "engelsk",
    "engelskts": "engelsk",
    "engelskundervisningen": "engelskundervisning",
    "engelskundervisningens": "engelskundervisning",
    "engelskundervisnings": "engelskundervisning",
    "engelsmannen": "engelsman",
    "engelsmannens": "engelsman",
    "engelsmans": "engelsman",
    "engelsmän": "engelsman",
    "engelsmännen": "engelsman",
    "engelsmännens": "engelsman",
    "engelsmäns": "engelsman",
    "engiftes": "engifte",
    "engiftet": "engifte",
    "engiftets": "engifte",
    "englergraden": "englergrad",
    "englergradens": "englergrad",
    "englergrader": "englergrad",
    "englergraderna": "englergrad",
    "englergradernas": "englergrad",
    "englergraders": "englergrad",
    "englergrads": "englergrad",
    "engrammen": "engram",
    "engrammens": "engram",
    "engrammet": "engram",
    "engrammets": "engram",
    "engrams": "engram",
    "engrossisten": "engrossist",
    "engrossistens": "engrossist",
    "engrossister": "engrossist",
    "engrossisterna": "engrossist",
    "engrossisternas": "engrossist",
    "engrossisters": "engrossist",
    "engrossists": "engrossist",
    "engångsartikeln": "engångsartikel",
    "engångsartikelns": "engångsartikel",
    "engångsartikels": "engångsartikel",
    "engångsartiklar": "engångsartikel",
    "engångsartiklarna": "engångsartikel",
    "engångsartiklarnas": "engångsartikel",
    "engångsartiklars": "engångsartikel",
    "engångsdosen": "engångsdos",
    "engångsdosens": "engångsdos",
    "engångsdoser": "engångsdos",
    "engångsdoserna": "engångsdos",
    "engångsdosernas": "engångsdos",
    "engångsdosers": "engångsdos",
    "engångsflask": "engångsflaska",
    "engångsflaskan": "engångsflaska",
    "engångsflaskans": "engångsflaska",
    "engångsflaskas": "engångsflaska",
    "engångsflaske": "engångsflaska",
    "engångsflaskor": "engångsflaska",
    "engångsflaskorna": "engångsflaska",
    "engångsflaskornas": "engångsflaska",
    "engångsflaskors": "engångsflaska",
    "engångsföreteelsen": "engångsföreteelse",
    "engångsföreteelsens": "engångsföreteelse",
    "engångsföreteelser": "engångsföreteelse",
    "engångsföreteelserna": "engångsföreteelse",
    "engångsföreteelsernas": "engångsföreteelse",
    "engångsföreteelsers": "engångsföreteelse",
    "engångsföreteelses": "engångsföreteelse",
    "engångshanddukar": "engångshandduk",
    "engångshanddukarna": "engångshandduk",
    "engångshanddukarnas": "engångshandduk",
    "engångshanddukars": "engångshandduk",
    "engångshandduken": "engångshandduk",
    "engångshanddukens": "engångshandduk",
    "engångshandduks": "engångshandduk",
    "engångskaraktären": "engångskaraktär",
    "engångskaraktärens": "engångskaraktär",
    "engångskaraktärs": "engångskaraktär",
    "engångskostnaden": "engångskostnad",
    "engångskostnadens": "engångskostnad",
    "engångskostnader": "engångskostnad",
    "engångskostnaderna": "engångskostnad",
    "engångskostnadernas": "engångskostnad",
    "engångskostnaders": "engångskostnad",
    "engångskostnads": "engångskostnad",
    "engångsliggen": "engångsligg",
    "engångsliggens": "engångsligg",
    "engångsligget": "engångsligg",
    "engångsliggets": "engångsligg",
    "engångsliggs": "engångsligg",
    "engångsnaturen": "engångsnatur",
    "engångsnaturens": "engångsnatur",
    "engångsnaturs": "engångsnatur",
    "engångsnäsdukar": "engångsnäsduk",
    "engångsnäsdukarna": "engångsnäsduk",
    "engångsnäsdukarnas": "engångsnäsduk",
    "engångsnäsdukars": "engångsnäsduk",
    "engångsnäsduken": "engångsnäsduk",
    "engångsnäsdukens": "engångsnäsduk",
    "engångsnäsduks": "engångsnäsduk",
    "engångsservetten": "engångsservett",
    "engångsservettens": "engångsservett",
    "engångsservetter": "engångsservett",
    "engångsservetterna": "engångsservett",
    "engångsservetternas": "engångsservett",
    "engångsservetters": "engångsservett",
    "engångsservetts": "engångsservett",
    "engångsskatten": "engångsskatt",
    "engångsskattens": "engångsskatt",
    "engångsskatter": "engångsskatt",
    "engångsskatterna": "engångsskatt",
    "engångsskatternas": "engångsskatt",
    "engångsskatters": "engångsskatt",
    "engångsskatts": "engångsskatt",
    "engångstallrikar": "engångstallrik",
    "engångstallrikarna": "engångstallrik",
    "engångstallrikarnas": "engångstallrik",
    "engångstallrikars": "engångstallrik",
    "engångstallriken": "engångstallrik",
    "engångstallrikens": "engångstallrik",
    "engångstallriks": "engångstallrik",
    "engångsvärden": "engångsvärde",
    "engångsvärdena": "engångsvärde",
    "engångsvärdenas": "engångsvärde",
    "engångsvärdens": "engångsvärde",
    "engångsvärdes": "engångsvärde",
    "engångsvärdet": "engångsvärde",
    "engångsvärdets": "engångsvärde",
    "enharmoniska": "enharmonisk",
    "enharmoniskare": "enharmonisk",
    "enharmoniskares": "enharmonisk",
    "enharmoniskas": "enharmonisk",
    "enharmoniskast": "enharmonisk",
    "enharmoniskaste": "enharmonisk",
    "enharmoniskastes": "enharmonisk",
    "enharmoniskasts": "enharmonisk",
    "enharmoniske": "enharmonisk",
    "enharmoniskes": "enharmonisk",
    "enharmonisks": "enharmonisk",
    "enharmoniskt": "enharmonisk",
    "enharmoniskts": "enharmonisk",
    "enheten": "enhet",
    "enhetens": "enhet",
    "enheter": "enhet",
    "enheterna": "enhet",
    "enheternas": "enhet",
    "enheters": "enhet",
    "enhetliga": "enhetlig",
    "enhetligare": "enhetlig",
    "enhetligares": "enhetlig",
    "enhetligas": "enhetlig",
    "enhetligast": "enhetlig",
    "enhetligaste": "enhetlig",
    "enhetligastes": "enhetlig",
    "enhetligasts": "enhetlig",
    "enhetlige": "enhetlig",
    "enhetliges": "enhetlig",
    "enhetligheten": "enhetlighet",
    "enhetlighetens": "enhetlighet",
    "enhetlighets": "enhetlighet",
    "enhetligs": "enhetlig",
    "enhetligt": "enhetlig",
    "enhetligts": "enhetlig",
    "enhets": "enhet",
    "enhetscirkeln": "enhetscirkel",
    "enhetscirkelns": "enhetscirkel",
    "enhetscirkels": "enhetscirkel",
    "enhetscirklar": "enhetscirkel",
    "enhetscirklarna": "enhetscirkel",
    "enhetscirklarnas": "enhetscirkel",
    "enhetscirklars": "enhetscirkel",
    "enhetsflygplanen": "enhetsflygplan",
    "enhetsflygplanens": "enhetsflygplan",
    "enhetsflygplanet": "enhetsflygplan",
    "enhetsflygplanets": "enhetsflygplan",
    "enhetsflygplans": "enhetsflygplan",
    "enhetsfronten": "enhetsfront",
    "enhetsfrontens": "enhetsfront",
    "enhetsfronter": "enhetsfront",
    "enhetsfronterna": "enhetsfront",
    "enhetsfronternas": "enhetsfront",
    "enhetsfronters": "enhetsfront",
    "enhetsfronts": "enhetsfront",
    "enhetsladdningar": "enhetsladdning",
    "enhetsladdningarna": "enhetsladdning",
    "enhetsladdningarnas": "enhetsladdning",
    "enhetsladdningars": "enhetsladdning",
    "enhetsladdningen": "enhetsladdning",
    "enhetsladdningens": "enhetsladdning",
    "enhetsladdnings": "enhetsladdning",
    "enhetslasten": "enhetslast",
    "enhetslastens": "enhetslast",
    "enhetslaster": "enhetslast",
    "enhetslasterna": "enhetslast",
    "enhetslasternas": "enhetslast",
    "enhetslasters": "enhetslast",
    "enhetslasts": "enhetslast",
    "enhetsmåtten": "enhetsmått",
    "enhetsmåttens": "enhetsmått",
    "enhetsmåttet": "enhetsmått",
    "enhetsmåttets": "enhetsmått",
    "enhetsmåtts": "enhetsmått",
    "enhetspartier": "enhetsparti",
    "enhetspartierna": "enhetsparti",
    "enhetspartiernas": "enhetsparti",
    "enhetspartiers": "enhetsparti",
    "enhetspartiet": "enhetsparti",
    "enhetspartiets": "enhetsparti",
    "enhetspartis": "enhetsparti",
    "enhetspartit": "enhetsparti",
    "enhetspartits": "enhetsparti",
    "enhetspatronen": "enhetspatron",
    "enhetspatronens": "enhetspatron",
    "enhetspatroner": "enhetspatron",
    "enhetspatronerna": "enhetspatron",
    "enhetspatronernas": "enhetspatron",
    "enhetspatroners": "enhetspatron",
    "enhetspatrons": "enhetspatron",
    "enhetsporton": "enhetsporto",
    "enhetsportona": "enhetsporto",
    "enhetsportonas": "enhetsporto",
    "enhetsportons": "enhetsporto",
    "enhetsportos": "enhetsporto",
    "enhetsportot": "enhetsporto",
    "enhetsportots": "enhetsporto",
    "enhetsprisen": "enhetspris",
    "enhetsprisens": "enhetspris",
    "enhetspriser": "enhetspris",
    "enhetspriserna": "enhetspris",
    "enhetsprisernas": "enhetspris",
    "enhetsprisers": "enhetspris",
    "enhetspriset": "enhetspris",
    "enhetsprisets": "enhetspris",
    "enhetsskolan": "enhetsskola",
    "enhetsskolans": "enhetsskola",
    "enhetsskolas": "enhetsskola",
    "enhetsvektorer": "enhetsvektor",
    "enhetsvektorerna": "enhetsvektor",
    "enhetsvektorernas": "enhetsvektor",
    "enhetsvektorers": "enhetsvektor",
    "enhetsvektorn": "enhetsvektor",
    "enhetsvektorns": "enhetsvektor",
    "enhetsvektors": "enhetsvektor",
    "enhjuliga": "enhjulig",
    "enhjuligare": "enhjulig",
    "enhjuligares": "enhjulig",
    "enhjuligas": "enhjulig",
    "enhjuligast": "enhjulig",
    "enhjuligaste": "enhjulig",
    "enhjuligastes": "enhjulig",
    "enhjuligasts": "enhjulig",
    "enhjulige": "enhjulig",
    "enhjuliges": "enhjulig",
    "enhjuligheten": "enhjulighet",
    "enhjulighetens": "enhjulighet",
    "enhjulighets": "enhjulighet",
    "enhjuligs": "enhjulig",
    "enhjuligt": "enhjulig",
    "enhjuligts": "enhjulig",
    "enhjulingar": "enhjuling",
    "enhjulingarna": "enhjuling",
    "enhjulingarnas": "enhjuling",
    "enhjulingars": "enhjuling",
    "enhjulingen": "enhjuling",
    "enhjulingens": "enhjuling",
    "enhjulings": "enhjuling",
    "enhjärtbladiga": "enhjärtbladig",
    "enhjärtbladigare": "enhjärtbladig",
    "enhjärtbladigares": "enhjärtbladig",
    "enhjärtbladigas": "enhjärtbladig",
    "enhjärtbladigast": "enhjärtbladig",
    "enhjärtbladigaste": "enhjärtbladig",
    "enhjärtbladigastes": "enhjärtbladig",
    "enhjärtbladigasts": "enhjärtbladig",
    "enhjärtbladige": "enhjärtbladig",
    "enhjärtbladiges": "enhjärtbladig",
    "enhjärtbladigs": "enhjärtbladig",
    "enhjärtbladigt": "enhjärtbladig",
    "enhjärtbladigts": "enhjärtbladig",
    "enhälliga": "enhällig",
    "enhälligare": "enhällig",
    "enhälligares": "enhällig",
    "enhälligas": "enhällig",
    "enhälligast": "enhällig",
    "enhälligaste": "enhällig",
    "enhälligastes": "enhällig",
    "enhälligasts": "enhällig",
    "enhällige": "enhällig",
    "enhälliges": "enhällig",
    "enhälligheten": "enhällighet",
    "enhällighetens": "enhällighet",
    "enhällighets": "enhällighet",
    "enhälligs": "enhällig",
    "enhälligt": "enhällig",
    "enhälligts": "enhällig",
    "enhörningar": "enhörning",
    "enhörningarna": "enhörning",
    "enhörningarnas": "enhörning",
    "enhörningars": "enhörning",
    "enhörningen": "enhörning",
    "enhörningens": "enhörning",
    "enhörnings": "enhörning",
    "eniga": "enig",
    "enigare": "enig",
    "enigares": "enig",
    "enigas": "enig",
    "enigast": "enig",
    "enigaste": "enig",
    "enigastes": "enig",
    "enigasts": "enig",
    "enige": "enig",
    "eniges": "enig",
    "enigheten": "enighet",
    "enighetens": "enighet",
    "enigheter": "enighet",
    "enigheterna": "enighet",
    "enigheternas": "enighet",
    "enigheters": "enighet",
    "enighets": "enighet",
    "enigmatiska": "enigmatisk",
    "enigmatiskare": "enigmatisk",
    "enigmatiskares": "enigmatisk",
    "enigmatiskas": "enigmatisk",
    "enigmatiskast": "enigmatisk",
    "enigmatiskaste": "enigmatisk",
    "enigmatiskastes": "enigmatisk",
    "enigmatiskasts": "enigmatisk",
    "enigmatiske": "enigmatisk",
    "enigmatiskes": "enigmatisk",
    "enigmatisks": "enigmatisk",
    "enigmatiskt": "enigmatisk",
    "enigmatiskts": "enigmatisk",
    "enigs": "enig",
    "enigt": "enig",
    "enigts": "enig",
    "enjambemangen": "enjambemang",
    "enjambemangens": "enjambemang",
    "enjambemanget": "enjambemang",
    "enjambemangets": "enjambemang",
    "enjambemangs": "enjambemang",
    "enkammarsystemen": "enkammarsystem",
    "enkammarsystemens": "enkammarsystem",
    "enkammarsystemet": "enkammarsystem",
    "enkammarsystemets": "enkammarsystem",
    "enkammarsystems": "enkammarsystem",
    "enkel": "enkla",
    "enkelbeckasinen": "enkelbeckasin",
    "enkelbeckasinens": "enkelbeckasin",
    "enkelbeckasiner": "enkelbeckasin",
    "enkelbeckasinerna": "enkelbeckasin",
    "enkelbeckasinernas": "enkelbeckasin",
    "enkelbeckasiners": "enkelbeckasin",
    "enkelbeckasins": "enkelbeckasin",
    "enkelbiffar": "enkelbiff",
    "enkelbiffarna": "enkelbiff",
    "enkelbiffarnas": "enkelbiff",
    "enkelbiffars": "enkelbiff",
    "enkelbiffen": "enkelbiff",
    "enkelbiffens": "enkelbiff",
    "enkelbiffs": "enkelbiff",
    "enkelbiljetten": "enkelbiljett",
    "enkelbiljettens": "enkelbiljett",
    "enkelbiljetter": "enkelbiljett",
    "enkelbiljetterna": "enkelbiljett",
    "enkelbiljetternas": "enkelbiljett",
    "enkelbiljetters": "enkelbiljett",
    "enkelbiljetts": "enkelbiljett",
    "enkelbredden": "enkelbredd",
    "enkelbreddens": "enkelbredd",
    "enkelbredder": "enkelbredd",
    "enkelbredderna": "enkelbredd",
    "enkelbreddernas": "enkelbredd",
    "enkelbredders": "enkelbredd",
    "enkelbredds": "enkelbredd",
    "enkelheten": "enkelhet",
    "enkelhetens": "enkelhet",
    "enkelheter": "enkelhet",
    "enkelheterna": "enkelhet",
    "enkelheternas": "enkelhet",
    "enkelheters": "enkelhet",
    "enkelhets": "enkelhet",
    "enkelkikar": "enkelkikare",
    "enkelkikaren": "enkelkikare",
    "enkelkikarens": "enkelkikare",
    "enkelkikares": "enkelkikare",
    "enkelkikarna": "enkelkikare",
    "enkelkikarnas": "enkelkikare",
    "enkelknäppningar": "enkelknäppning",
    "enkelknäppningarna": "enkelknäppning",
    "enkelknäppningarnas": "enkelknäppning",
    "enkelknäppningars": "enkelknäppning",
    "enkelknäppningen": "enkelknäppning",
    "enkelknäppningens": "enkelknäppning",
    "enkelknäppnings": "enkelknäppning",
    "enkelknäppta": "enkelknäppt",
    "enkelknäpptare": "enkelknäppt",
    "enkelknäpptares": "enkelknäppt",
    "enkelknäpptas": "enkelknäppt",
    "enkelknäpptast": "enkelknäppt",
    "enkelknäpptaste": "enkelknäppt",
    "enkelknäpptastes": "enkelknäppt",
    "enkelknäpptasts": "enkelknäppt",
    "enkelknäppte": "enkelknäppt",
    "enkelknäpptes": "enkelknäppt",
    "enkelknäppts": "enkelknäppt",
    "enkelkvartetten": "enkelkvartett",
    "enkelkvartettens": "enkelkvartett",
    "enkelkvartetter": "enkelkvartett",
    "enkelkvartetterna": "enkelkvartett",
    "enkelkvartetternas": "enkelkvartett",
    "enkelkvartetters": "enkelkvartett",
    "enkelkvartetts": "enkelkvartett",
    "enkelladdar": "enkelladdare",
    "enkelladdaren": "enkelladdare",
    "enkelladdarens": "enkelladdare",
    "enkelladdares": "enkelladdare",
    "enkelladdarna": "enkelladdare",
    "enkelladdarnas": "enkelladdare",
    "enkelnerviga": "enkelnervig",
    "enkelnervigare": "enkelnervig",
    "enkelnervigares": "enkelnervig",
    "enkelnervigas": "enkelnervig",
    "enkelnervigast": "enkelnervig",
    "enkelnervigaste": "enkelnervig",
    "enkelnervigastes": "enkelnervig",
    "enkelnervigasts": "enkelnervig",
    "enkelnervige": "enkelnervig",
    "enkelnerviges": "enkelnervig",
    "enkelnervigs": "enkelnervig",
    "enkelnervigt": "enkelnervig",
    "enkelnervigts": "enkelnervig",
    "enkelpipiga": "enkelpipig",
    "enkelpipigare": "enkelpipig",
    "enkelpipigares": "enkelpipig",
    "enkelpipigas": "enkelpipig",
    "enkelpipigast": "enkelpipig",
    "enkelpipigaste": "enkelpipig",
    "enkelpipigastes": "enkelpipig",
    "enkelpipigasts": "enkelpipig",
    "enkelpipige": "enkelpipig",
    "enkelpipiges": "enkelpipig",
    "enkelpipigs": "enkelpipig",
    "enkelpipigt": "enkelpipig",
    "enkelpipigts": "enkelpipig",
    "enkelraden": "enkelrad",
    "enkelradens": "enkelrad",
    "enkelrader": "enkelrad",
    "enkelraderna": "enkelrad",
    "enkelradernas": "enkelrad",
    "enkelraders": "enkelrad",
    "enkelrads": "enkelrad",
    "enkelrenade": "enkelrenad",
    "enkelrenades": "enkelrenad",
    "enkelrenads": "enkelrenad",
    "enkelrenat": "enkelrenad",
    "enkelrenats": "enkelrenad",
    "enkelrikt": "enkelrikta",
    "enkelriktad": "enkelrikta",
    "enkelriktade": "enkelriktad",
    "enkelriktades": "enkelriktad",
    "enkelriktads": "enkelriktad",
    "enkelriktande": "enkelrikta",
    "enkelriktanden": "enkelriktande",
    "enkelriktandena": "enkelriktande",
    "enkelriktandenas": "enkelriktande",
    "enkelriktandens": "enkelriktande",
    "enkelriktandes": "enkelriktande",
    "enkelriktandet": "enkelriktande",
    "enkelriktandets": "enkelriktande",
    "enkelriktar": "enkelrikta",
    "enkelriktas": "enkelrikta",
    "enkelriktat": "enkelriktad",
    "enkelriktats": "enkelriktad",
    "enkelrummen": "enkelrum",
    "enkelrummens": "enkelrum",
    "enkelrummet": "enkelrum",
    "enkelrummets": "enkelrum",
    "enkelrums": "enkelrum",
    "enkels": "enkel",
    "enkelskrev": "enkelskriva",
    "enkelskrevs": "enkelskriva",
    "enkelskriv": "enkelskriva",
    "enkelskrivande": "enkelskriva",
    "enkelskrivanden": "enkelskrivande",
    "enkelskrivandena": "enkelskrivande",
    "enkelskrivandenas": "enkelskrivande",
    "enkelskrivandens": "enkelskrivande",
    "enkelskrivandes": "enkelskrivande",
    "enkelskrivandet": "enkelskrivande",
    "enkelskrivandets": "enkelskrivande",
    "enkelskrivas": "enkelskriva",
    "enkelskrive": "enkelskriva",
    "enkelskriven": "enkelskriva",
    "enkelskrivens": "enkelskriva",
    "enkelskriver": "enkelskriva",
    "enkelskrives": "enkelskriva",
    "enkelskrivet": "enkelskriva",
    "enkelskrivets": "enkelskriva",
    "enkelskrivit": "enkelskriva",
    "enkelskrivits": "enkelskriva",
    "enkelskrivna": "enkelskriva",
    "enkelskrivnas": "enkelskriva",
    "enkelskrivne": "enkelskriva",
    "enkelskrivnes": "enkelskriva",
    "enkelskrivs": "enkelskriva",
    "enkelspelen": "enkelspel",
    "enkelspelens": "enkelspel",
    "enkelspelet": "enkelspel",
    "enkelspelets": "enkelspel",
    "enkelspels": "enkelspel",
    "enkelspåriga": "enkelspårig",
    "enkelspårigare": "enkelspårig",
    "enkelspårigares": "enkelspårig",
    "enkelspårigas": "enkelspårig",
    "enkelspårigast": "enkelspårig",
    "enkelspårigaste": "enkelspårig",
    "enkelspårigastes": "enkelspårig",
    "enkelspårigasts": "enkelspårig",
    "enkelspårige": "enkelspårig",
    "enkelspåriges": "enkelspårig",
    "enkelspårigheten": "enkelspårighet",
    "enkelspårighetens": "enkelspårighet",
    "enkelspårighets": "enkelspårighet",
    "enkelspårigs": "enkelspårig",
    "enkelspårigt": "enkelspårig",
    "enkelspårigts": "enkelspårig",
    "enkelstjärnan": "enkelstjärna",
    "enkelstjärnans": "enkelstjärna",
    "enkelstjärnas": "enkelstjärna",
    "enkelstjärne": "enkelstjärna",
    "enkelstjärnor": "enkelstjärna",
    "enkelstjärnorna": "enkelstjärna",
    "enkelstjärnornas": "enkelstjärna",
    "enkelstjärnors": "enkelstjärna",
    "enkelsträngade": "enkelsträngad",
    "enkelsträngades": "enkelsträngad",
    "enkelsträngads": "enkelsträngad",
    "enkelsträngat": "enkelsträngad",
    "enkelsträngats": "enkelsträngad",
    "enkelsängar": "enkelsäng",
    "enkelsängarna": "enkelsäng",
    "enkelsängarnas": "enkelsäng",
    "enkelsängars": "enkelsäng",
    "enkelsängen": "enkelsäng",
    "enkelsängens": "enkelsäng",
    "enkelsängs": "enkelsäng",
    "enkelt": "enkel",
    "enkelteckn": "enkelteckna",
    "enkeltecknad": "enkelteckna",
    "enkeltecknade": "enkelteckna",
    "enkeltecknades": "enkelteckna",
    "enkeltecknads": "enkelteckna",
    "enkeltecknande": "enkelteckna",
    "enkeltecknanden": "enkeltecknande",
    "enkeltecknandena": "enkeltecknande",
    "enkeltecknandenas": "enkeltecknande",
    "enkeltecknandens": "enkeltecknande",
    "enkeltecknandes": "enkeltecknande",
    "enkeltecknandet": "enkeltecknande",
    "enkeltecknandets": "enkeltecknande",
    "enkeltecknar": "enkelteckna",
    "enkeltecknas": "enkelteckna",
    "enkeltecknat": "enkelteckna",
    "enkeltecknats": "enkelteckna",
    "enkeltim": "enkeltimme",
    "enkeltimman": "enkeltimma",
    "enkeltimmans": "enkeltimma",
    "enkeltimmar": "enkeltimme",
    "enkeltimmarna": "enkeltimme",
    "enkeltimmarnas": "enkeltimme",
    "enkeltimmars": "enkeltimme",
    "enkeltimmas": "enkeltimma",
    "enkeltimmen": "enkeltimme",
    "enkeltimmens": "enkeltimme",
    "enkeltimmes": "enkeltimme",
    "enkeltims": "enkeltimme",
    "enkelts": "enkel",
    "enkla": "enkel",
    "enklad": "enkla",
    "enklade": "enkla",
    "enklades": "enkla",
    "enklads": "enkla",
    "enklande": "enkla",
    "enklanden": "enklande",
    "enklandena": "enklande",
    "enklandenas": "enklande",
    "enklandens": "enklande",
    "enklandes": "enklande",
    "enklandet": "enklande",
    "enklandets": "enklande",
    "enklangen": "enklang",
    "enklangens": "enklang",
    "enklangs": "enklang",
    "enklar": "enkla",
    "enklare": "enkel",
    "enklares": "enkel",
    "enklas": "enkla",
    "enklast": "enkel",
    "enklaste": "enkel",
    "enklastes": "enkel",
    "enklasts": "enkel",
    "enklat": "enkla",
    "enklats": "enkla",
    "enklaven": "enklav",
    "enklavens": "enklav",
    "enklaver": "enklav",
    "enklaverna": "enklav",
    "enklavernas": "enklav",
    "enklavers": "enklav",
    "enklavs": "enklav",
    "enkle": "enkel",
    "enkles": "enkel",
    "enklitiska": "enklitisk",
    "enklitiskare": "enklitisk",
    "enklitiskares": "enklitisk",
    "enklitiskas": "enklitisk",
    "enklitiskast": "enklitisk",
    "enklitiskaste": "enklitisk",
    "enklitiskastes": "enklitisk",
    "enklitiskasts": "enklitisk",
    "enklitiske": "enklitisk",
    "enklitiskes": "enklitisk",
    "enklitisks": "enklitisk",
    "enklitiskt": "enklitisk",
    "enklitiskts": "enklitisk",
    "enkomponentskitten": "enkomponentskitt",
    "enkomponentskittens": "enkomponentskitt",
    "enkomponentskittet": "enkomponentskitt",
    "enkomponentskittets": "enkomponentskitt",
    "enkomponentskitts": "enkomponentskitt",
    "enkornet": "enkorn",
    "enkornets": "enkorn",
    "enkorns": "enkorn",
    "enkron": "enkrona",
    "enkronan": "enkrona",
    "enkronans": "enkrona",
    "enkronas": "enkrona",
    "enkrone": "enkrona",
    "enkronor": "enkrona",
    "enkronorna": "enkrona",
    "enkronornas": "enkrona",
    "enkronors": "enkrona",
    "enkrons": "enkrona",
    "enkäten": "enkät",
    "enkätens": "enkät",
    "enkäter": "enkät",
    "enkäterna": "enkät",
    "enkäternas": "enkät",
    "enkäters": "enkät",
    "enkäts": "enkät",
    "enkätsvaren": "enkätsvar",
    "enkätsvarens": "enkätsvar",
    "enkätsvaret": "enkätsvar",
    "enkätsvarets": "enkätsvar",
    "enkätsvars": "enkätsvar",
    "enkönsregeln": "enkönsregel",
    "enkönsregelns": "enkönsregel",
    "enkönsregels": "enkönsregel",
    "enkönsregler": "enkönsregel",
    "enkönsreglerna": "enkönsregel",
    "enkönsreglernas": "enkönsregel",
    "enkönsreglers": "enkönsregel",
    "enleverad": "enlevera",
    "enleverade": "enlevera",
    "enleverades": "enlevera",
    "enleverads": "enlevera",
    "enleverande": "enlevera",
    "enleveranden": "enleverande",
    "enleverandena": "enleverande",
    "enleverandenas": "enleverande",
    "enleverandens": "enleverande",
    "enleverandes": "enleverande",
    "enleverandet": "enleverande",
    "enleverandets": "enleverande",
    "enleverar": "enlevera",
    "enleveras": "enlevera",
    "enleverat": "enlevera",
    "enleverats": "enlevera",
    "enleverbara": "enleverbar",
    "enleverbarare": "enleverbar",
    "enleverbarares": "enleverbar",
    "enleverbaras": "enleverbar",
    "enleverbarast": "enleverbar",
    "enleverbaraste": "enleverbar",
    "enleverbarastes": "enleverbar",
    "enleverbarasts": "enleverbar",
    "enleverbare": "enleverbar",
    "enleverbares": "enleverbar",
    "enleverbarheten": "enleverbarhet",
    "enleverbarhetens": "enleverbarhet",
    "enleverbarhets": "enleverbarhet",
    "enleverbars": "enleverbar",
    "enleverbart": "enleverbar",
    "enleverbarts": "enleverbar",
    "enleveringar": "enlevering",
    "enleveringarna": "enlevering",
    "enleveringarnas": "enlevering",
    "enleveringars": "enlevering",
    "enleveringen": "enlevering",
    "enleveringens": "enlevering",
    "enleverings": "enlevering",
    "enmansföreställningar": "enmansföreställning",
    "enmansföreställningarna": "enmansföreställning",
    "enmansföreställningarnas": "enmansföreställning",
    "enmansföreställningars": "enmansföreställning",
    "enmansföreställningen": "enmansföreställning",
    "enmansföreställningens": "enmansföreställning",
    "enmansföreställnings": "enmansföreställning",
    "enmansgravar": "enmansgrav",
    "enmansgravarna": "enmansgrav",
    "enmansgravarnas": "enmansgrav",
    "enmansgravars": "enmansgrav",
    "enmansgraven": "enmansgrav",
    "enmansgravens": "enmansgrav",
    "enmansgravs": "enmansgrav",
    "enmanslivbåtar": "enmanslivbåt",
    "enmanslivbåtarna": "enmanslivbåt",
    "enmanslivbåtarnas": "enmanslivbåt",
    "enmanslivbåtars": "enmanslivbåt",
    "enmanslivbåten": "enmanslivbåt",
    "enmanslivbåtens": "enmanslivbåt",
    "enmanslivbåts": "enmanslivbåt",
    "enmanspubliken": "enmanspublik",
    "enmanspublikens": "enmanspublik",
    "enmanspubliker": "enmanspublik",
    "enmanspublikerna": "enmanspublik",
    "enmanspublikernas": "enmanspublik",
    "enmanspublikers": "enmanspublik",
    "enmanspubliks": "enmanspublik",
    "enmansshowen": "enmansshow",
    "enmansshowens": "enmansshow",
    "enmansshower": "enmansshow",
    "enmansshowerna": "enmansshow",
    "enmansshowernas": "enmansshow",
    "enmansshowers": "enmansshow",
    "enmansshows": "enmansshow",
    "enmansteatern": "enmansteater",
    "enmansteaterns": "enmansteater",
    "enmansteaters": "enmansteater",
    "enmansvalkretsar": "enmansvalkrets",
    "enmansvalkretsarna": "enmansvalkrets",
    "enmansvalkretsarnas": "enmansvalkrets",
    "enmansvalkretsars": "enmansvalkrets",
    "enmansvalkretsen": "enmansvalkrets",
    "enmansvalkretsens": "enmansvalkrets",
    "enorma": "enorm",
    "enormare": "enorm",
    "enormares": "enorm",
    "enormas": "enorm",
    "enormast": "enorm",
    "enormaste": "enorm",
    "enormastes": "enorm",
    "enormasts": "enorm",
    "enorme": "enorm",
    "enormes": "enorm",
    "enormheten": "enormhet",
    "enormhetens": "enormhet",
    "enormhets": "enormhet",
    "enorms": "enorm",
    "enormt": "enorm",
    "enormts": "enorm",
    "enpartistaten": "enpartistat",
    "enpartistatens": "enpartistat",
    "enpartistater": "enpartistat",
    "enpartistaterna": "enpartistat",
    "enpartistaternas": "enpartistat",
    "enpartistaters": "enpartistat",
    "enpartistats": "enpartistat",
    "enpersonsfamiljen": "enpersonsfamilj",
    "enpersonsfamiljens": "enpersonsfamilj",
    "enpersonsfamiljer": "enpersonsfamilj",
    "enpersonsfamiljerna": "enpersonsfamilj",
    "enpersonsfamiljernas": "enpersonsfamilj",
    "enpersonsfamiljers": "enpersonsfamilj",
    "enpersonsfamiljs": "enpersonsfamilj",
    "enplanshusen": "enplanshus",
    "enplanshusens": "enplanshus",
    "enplanshuset": "enplanshus",
    "enplanshusets": "enplanshus",
    "enplansvillan": "enplansvilla",
    "enplansvillans": "enplansvilla",
    "enplansvillas": "enplansvilla",
    "enplansville": "enplansvilla",
    "enplansvillor": "enplansvilla",
    "enplansvillorna": "enplansvilla",
    "enplansvillornas": "enplansvilla",
    "enplansvillors": "enplansvilla",
    "enpoliga": "enpolig",
    "enpoligare": "enpolig",
    "enpoligares": "enpolig",
    "enpoligas": "enpolig",
    "enpoligast": "enpolig",
    "enpoligaste": "enpolig",
    "enpoligastes": "enpolig",
    "enpoligasts": "enpolig",
    "enpolige": "enpolig",
    "enpoliges": "enpolig",
    "enpoligheten": "enpolighet",
    "enpolighetens": "enpolighet",
    "enpolighets": "enpolighet",
    "enpoligs": "enpolig",
    "enpoligt": "enpolig",
    "enpoligts": "enpolig",
    "enpuckliga": "enpucklig",
    "enpuckligare": "enpucklig",
    "enpuckligares": "enpucklig",
    "enpuckligas": "enpucklig",
    "enpuckligast": "enpucklig",
    "enpuckligaste": "enpucklig",
    "enpuckligastes": "enpucklig",
    "enpuckligasts": "enpucklig",
    "enpucklige": "enpucklig",
    "enpuckliges": "enpucklig",
    "enpuckligheten": "enpucklighet",
    "enpucklighetens": "enpucklighet",
    "enpucklighets": "enpucklighet",
    "enpuckligs": "enpucklig",
    "enpuckligt": "enpucklig",
    "enpuckligts": "enpucklig",
    "enrisen": "enris",
    "enrisens": "enris",
    "enriset": "enris",
    "enrisets": "enris",
    "enrisrökta": "enrisrökt",
    "enrisröktare": "enrisrökt",
    "enrisröktares": "enrisrökt",
    "enrisröktas": "enrisrökt",
    "enrisröktast": "enrisrökt",
    "enrisröktaste": "enrisrökt",
    "enrisröktastes": "enrisrökt",
    "enrisröktasts": "enrisrökt",
    "enrisrökte": "enrisrökt",
    "enrisröktes": "enrisrökt",
    "enrisrökts": "enrisrökt",
    "enrollerad": "enrollera",
    "enrollerade": "enrollera",
    "enrollerades": "enrollera",
    "enrollerads": "enrollera",
    "enrollerande": "enrollera",
    "enrolleranden": "enrollerande",
    "enrollerandena": "enrollerande",
    "enrollerandenas": "enrollerande",
    "enrollerandens": "enrollerande",
    "enrollerandes": "enrollerande",
    "enrollerandet": "enrollerande",
    "enrollerandets": "enrollerande",
    "enrollerar": "enrollera",
    "enrolleras": "enrollera",
    "enrollerat": "enrollera",
    "enrollerats": "enrollera",
    "enrollerbara": "enrollerbar",
    "enrollerbarare": "enrollerbar",
    "enrollerbarares": "enrollerbar",
    "enrollerbaras": "enrollerbar",
    "enrollerbarast": "enrollerbar",
    "enrollerbaraste": "enrollerbar",
    "enrollerbarastes": "enrollerbar",
    "enrollerbarasts": "enrollerbar",
    "enrollerbare": "enrollerbar",
    "enrollerbares": "enrollerbar",
    "enrollerbarheten": "enrollerbarhet",
    "enrollerbarhetens": "enrollerbarhet",
    "enrollerbarhets": "enrollerbarhet",
    "enrollerbars": "enrollerbar",
    "enrollerbart": "enrollerbar",
    "enrollerbarts": "enrollerbar",
    "enrolleringar": "enrollering",
    "enrolleringarna": "enrollering",
    "enrolleringarnas": "enrollering",
    "enrolleringars": "enrollering",
    "enrolleringen": "enrollering",
    "enrolleringens": "enrollering",
    "enrollerings": "enrollering",
    "enrummar": "enrummare",
    "enrummaren": "enrummare",
    "enrummarens": "enrummare",
    "enrummares": "enrummare",
    "enrummarna": "enrummare",
    "enrummarnas": "enrummare",
    "enrumslägenheten": "enrumslägenhet",
    "enrumslägenhetens": "enrumslägenhet",
    "enrumslägenheter": "enrumslägenhet",
    "enrumslägenheterna": "enrumslägenhet",
    "enrumslägenheternas": "enrumslägenhet",
    "enrumslägenheters": "enrumslägenhet",
    "enrumslägenhets": "enrumslägenhet",
    "enrådiga": "enrådig",
    "enrådigare": "enrådig",
    "enrådigares": "enrådig",
    "enrådigas": "enrådig",
    "enrådigast": "enrådig",
    "enrådigaste": "enrådig",
    "enrådigastes": "enrådig",
    "enrådigasts": "enrådig",
    "enrådige": "enrådig",
    "enrådiges": "enrådig",
    "enrådigs": "enrådig",
    "enrådigt": "enrådig",
    "enrådigts": "enrådig",
    "ens": "man",
    "ensad": "ensa",
    "ensade": "ensa",
    "ensades": "ensa",
    "ensads": "ensa",
    "ensaken": "ensak",
    "ensakens": "ensak",
    "ensaker": "ensak",
    "ensakerna": "ensak",
    "ensakernas": "ensak",
    "ensakers": "ensak",
    "ensaks": "ensak",
    "ensamflygningar": "ensamflygning",
    "ensamflygningarna": "ensamflygning",
    "ensamflygningarnas": "ensamflygning",
    "ensamflygningars": "ensamflygning",
    "ensamflygningen": "ensamflygning",
    "ensamflygningens": "ensamflygning",
    "ensamflygnings": "ensamflygning",
    "ensamföräldern": "ensamförälder",
    "ensamförälderns": "ensamförälder",
    "ensamförälders": "ensamförälder",
    "ensamföräldrar": "ensamförälder",
    "ensamföräldrarna": "ensamförälder",
    "ensamföräldrarnas": "ensamförälder",
    "ensamföräldrars": "ensamförälder",
    "ensamgårdar": "ensamgård",
    "ensamgårdarna": "ensamgård",
    "ensamgårdarnas": "ensamgård",
    "ensamgårdars": "ensamgård",
    "ensamgården": "ensamgård",
    "ensamgårdens": "ensamgård",
    "ensamgårds": "ensamgård",
    "ensamheten": "ensamhet",
    "ensamhetens": "ensamhet",
    "ensamheter": "ensamhet",
    "ensamheterna": "ensamhet",
    "ensamheternas": "ensamhet",
    "ensamheters": "ensamhet",
    "ensamhets": "ensamhet",
    "ensamhushållen": "ensamhushåll",
    "ensamhushållens": "ensamhushåll",
    "ensamhushållet": "ensamhushåll",
    "ensamhushållets": "ensamhushåll",
    "ensamhushålls": "ensamhushåll",
    "ensamma": "ensam",
    "ensammare": "ensam",
    "ensammares": "ensam",
    "ensammas": "ensam",
    "ensammast": "ensam",
    "ensammaste": "ensam",
    "ensammastes": "ensam",
    "ensammasts": "ensam",
    "ensamme": "ensam",
    "ensammes": "ensam",
    "ensamrätten": "ensamrätt",
    "ensamrättens": "ensamrätt",
    "ensamrätter": "ensamrätt",
    "ensamrätterna": "ensamrätt",
    "ensamrätternas": "ensamrätt",
    "ensamrätters": "ensamrätt",
    "ensamrätts": "ensamrätt",
    "ensams": "ensam",
    "ensamseglar": "ensamseglare",
    "ensamseglaren": "ensamseglare",
    "ensamseglarens": "ensamseglare",
    "ensamseglares": "ensamseglare",
    "ensamseglarna": "ensamseglare",
    "ensamseglarnas": "ensamseglare",
    "ensamt": "ensam",
    "ensamts": "ensam",
    "ensande": "ensa",
    "ensanden": "ensande",
    "ensandena": "ensande",
    "ensandenas": "ensande",
    "ensandens": "ensande",
    "ensandes": "ensande",
    "ensandet": "ensande",
    "ensandets": "ensande",
    "ensar": "ensa",
    "ensartade": "ensartad",
    "ensartades": "ensartad",
    "ensartads": "ensartad",
    "ensartat": "ensartad",
    "ensartats": "ensartad",
    "ensas": "ensa",
    "ensat": "ensa",
    "ensats": "ensa",
    "ensemblen": "ensemble",
    "ensemblens": "ensemble",
    "ensembler": "ensemble",
    "ensemblerna": "ensemble",
    "ensemblernas": "ensemble",
    "ensemblers": "ensemble",
    "ensembles": "ensemble",
    "ensfyrar": "ensfyr",
    "ensfyrarna": "ensfyr",
    "ensfyrarnas": "ensfyr",
    "ensfyrars": "ensfyr",
    "ensfyren": "ensfyr",
    "ensfyrens": "ensfyr",
    "ensfyrs": "ensfyr",
    "ensidiga": "ensidig",
    "ensidigare": "ensidig",
    "ensidigares": "ensidig",
    "ensidigas": "ensidig",
    "ensidigast": "ensidig",
    "ensidigaste": "ensidig",
    "ensidigastes": "ensidig",
    "ensidigasts": "ensidig",
    "ensidige": "ensidig",
    "ensidiges": "ensidig",
    "ensidigheten": "ensidighet",
    "ensidighetens": "ensidighet",
    "ensidighets": "ensidighet",
    "ensidigs": "ensidig",
    "ensidigt": "ensidig",
    "ensidigts": "ensidig",
    "ensilages": "ensilage",
    "ensilaget": "ensilage",
    "ensilagets": "ensilage",
    "ensilerad": "ensilera",
    "ensilerade": "ensilera",
    "ensilerades": "ensilera",
    "ensilerads": "ensilera",
    "ensilerande": "ensilera",
    "ensileranden": "ensilerande",
    "ensilerandena": "ensilerande",
    "ensilerandenas": "ensilerande",
    "ensilerandens": "ensilerande",
    "ensilerandes": "ensilerande",
    "ensilerandet": "ensilerande",
    "ensilerandets": "ensilerande",
    "ensilerar": "ensilera",
    "ensileras": "ensilera",
    "ensilerat": "ensilera",
    "ensilerats": "ensilera",
    "ensilerbara": "ensilerbar",
    "ensilerbarare": "ensilerbar",
    "ensilerbarares": "ensilerbar",
    "ensilerbaras": "ensilerbar",
    "ensilerbarast": "ensilerbar",
    "ensilerbaraste": "ensilerbar",
    "ensilerbarastes": "ensilerbar",
    "ensilerbarasts": "ensilerbar",
    "ensilerbare": "ensilerbar",
    "ensilerbares": "ensilerbar",
    "ensilerbarheten": "ensilerbarhet",
    "ensilerbarhetens": "ensilerbarhet",
    "ensilerbarhets": "ensilerbarhet",
    "ensilerbars": "ensilerbar",
    "ensilerbart": "ensilerbar",
    "ensilerbarts": "ensilerbar",
    "ensileringar": "ensilering",
    "ensileringarna": "ensilering",
    "ensileringarnas": "ensilering",
    "ensileringars": "ensilering",
    "ensileringen": "ensilering",
    "ensileringens": "ensilering",
    "ensilerings": "ensilering",
    "ensittar": "ensittare",
    "ensittaren": "ensittare",
    "ensittarens": "ensittare",
    "ensittares": "ensittare",
    "ensittarna": "ensittare",
    "ensittarnas": "ensittare",
    "enskiftes": "enskifte",
    "enskiftet": "enskifte",
    "enskiftets": "enskifte",
    "enskilda": "enskild",
    "enskildare": "enskild",
    "enskildares": "enskild",
    "enskildas": "enskild",
    "enskildast": "enskild",
    "enskildaste": "enskild",
    "enskildastes": "enskild",
    "enskildasts": "enskild",
    "enskilde": "enskild",
    "enskildes": "enskild",
    "enskildheten": "enskildhet",
    "enskildhetens": "enskildhet",
    "enskildheter": "enskildhet",
    "enskildheterna": "enskildhet",
    "enskildheternas": "enskildhet",
    "enskildheters": "enskildhet",
    "enskildhets": "enskildhet",
    "enskilds": "enskild",
    "enskilt": "enskild",
    "enskilts": "enskild",
    "ensliga": "enslig",
    "ensligare": "enslig",
    "ensligares": "enslig",
    "ensligas": "enslig",
    "ensligast": "enslig",
    "ensligaste": "enslig",
    "ensligastes": "enslig",
    "ensligasts": "enslig",
    "enslige": "enslig",
    "ensliges": "enslig",
    "ensligheten": "enslighet",
    "enslighetens": "enslighet",
    "enslighets": "enslighet",
    "ensligs": "enslig",
    "ensligt": "enslig",
    "ensligts": "enslig",
    "enslingar": "ensling",
    "enslingarna": "ensling",
    "enslingarnas": "ensling",
    "enslingars": "ensling",
    "enslingen": "ensling",
    "enslingens": "ensling",
    "enslings": "ensling",
    "enslinjen": "enslinje",
    "enslinjens": "enslinje",
    "enslinjer": "enslinje",
    "enslinjerna": "enslinje",
    "enslinjernas": "enslinje",
    "enslinjers": "enslinje",
    "enslinjes": "enslinje",
    "enspannet": "enspann",
    "enspannets": "enspann",
    "enspanns": "enspann",
    "enspråkiga": "enspråkig",
    "enspråkigare": "enspråkig",
    "enspråkigares": "enspråkig",
    "enspråkigas": "enspråkig",
    "enspråkigast": "enspråkig",
    "enspråkigaste": "enspråkig",
    "enspråkigastes": "enspråkig",
    "enspråkigasts": "enspråkig",
    "enspråkige": "enspråkig",
    "enspråkiges": "enspråkig",
    "enspråkigheten": "enspråkighet",
    "enspråkighetens": "enspråkighet",
    "enspråkighets": "enspråkighet",
    "enspråkigs": "enspråkig",
    "enspråkigt": "enspråkig",
    "enspråkigts": "enspråkig",
    "enstaviga": "enstavig",
    "enstavigare": "enstavig",
    "enstavigares": "enstavig",
    "enstavigas": "enstavig",
    "enstavigast": "enstavig",
    "enstavigaste": "enstavig",
    "enstavigastes": "enstavig",
    "enstavigasts": "enstavig",
    "enstavige": "enstavig",
    "enstaviges": "enstavig",
    "enstavigheten": "enstavighet",
    "enstavighetens": "enstavighet",
    "enstavighets": "enstavighet",
    "enstavighetsaccenten": "enstavighetsaccent",
    "enstavighetsaccentens": "enstavighetsaccent",
    "enstavighetsaccents": "enstavighetsaccent",
    "enstavigs": "enstavig",
    "enstavigt": "enstavig",
    "enstavigts": "enstavig",
    "enstegstätade": "enstegstätad",
    "enstegstätades": "enstegstätad",
    "enstegstätads": "enstegstätad",
    "enstegstätat": "enstegstätad",
    "enstegstätats": "enstegstätad",
    "enstensmurar": "enstensmur",
    "enstensmurarna": "enstensmur",
    "enstensmurarnas": "enstensmur",
    "enstensmurars": "enstensmur",
    "enstensmuren": "enstensmur",
    "enstensmurens": "enstensmur",
    "enstensmurs": "enstensmur",
    "enstjärniga": "enstjärnig",
    "enstjärnigare": "enstjärnig",
    "enstjärnigares": "enstjärnig",
    "enstjärnigas": "enstjärnig",
    "enstjärnigast": "enstjärnig",
    "enstjärnigaste": "enstjärnig",
    "enstjärnigastes": "enstjärnig",
    "enstjärnigasts": "enstjärnig",
    "enstjärnige": "enstjärnig",
    "enstjärniges": "enstjärnig",
    "enstjärnigs": "enstjärnig",
    "enstjärnigt": "enstjärnig",
    "enstjärnigts": "enstjärnig",
    "enstämmiga": "enstämmig",
    "enstämmigare": "enstämmig",
    "enstämmigares": "enstämmig",
    "enstämmigas": "enstämmig",
    "enstämmigast": "enstämmig",
    "enstämmigaste": "enstämmig",
    "enstämmigastes": "enstämmig",
    "enstämmigasts": "enstämmig",
    "enstämmige": "enstämmig",
    "enstämmiges": "enstämmig",
    "enstämmigheten": "enstämmighet",
    "enstämmighetens": "enstämmighet",
    "enstämmighets": "enstämmighet",
    "enstämmigs": "enstämmig",
    "enstämmigt": "enstämmig",
    "enstämmigts": "enstämmig",
    "enständiga": "enständig",
    "enständigare": "enständig",
    "enständigares": "enständig",
    "enständigas": "enständig",
    "enständigast": "enständig",
    "enständigaste": "enständig",
    "enständigastes": "enständig",
    "enständigasts": "enständig",
    "enständige": "enständig",
    "enständiges": "enständig",
    "enständigs": "enständig",
    "enständigt": "enständig",
    "enständigts": "enständig",
    "enstöriga": "enstörig",
    "enstörigare": "enstörig",
    "enstörigares": "enstörig",
    "enstörigas": "enstörig",
    "enstörigast": "enstörig",
    "enstörigaste": "enstörig",
    "enstörigastes": "enstörig",
    "enstörigasts": "enstörig",
    "enstörige": "enstörig",
    "enstöriges": "enstörig",
    "enstörigheten": "enstörighet",
    "enstörighetens": "enstörighet",
    "enstörighets": "enstörighet",
    "enstörigs": "enstörig",
    "enstörigt": "enstörig",
    "enstörigts": "enstörig",
    "enstöringar": "enstöring",
    "enstöringarna": "enstöring",
    "enstöringarnas": "enstöring",
    "enstöringars": "enstöring",
    "enstöringen": "enstöring",
    "enstöringens": "enstöring",
    "enstörings": "enstöring",
    "entalen": "ental",
    "entalens": "ental",
    "entalet": "ental",
    "entalets": "ental",
    "entalpien": "entalpi",
    "entalpiens": "entalpi",
    "entalpin": "entalpi",
    "entalpins": "entalpi",
    "entalpis": "entalpi",
    "entals": "ental",
    "ententen": "entente",
    "ententens": "entente",
    "ententer": "entente",
    "ententerna": "entente",
    "ententernas": "entente",
    "ententers": "entente",
    "ententes": "entente",
    "entents": "entent",
    "entertainern": "entertainer",
    "entertainerna": "entertainer",
    "entertainernas": "entertainer",
    "entertainerns": "entertainer",
    "entertainers": "entertainer",
    "entertainersarna": "entertainer",
    "entertainersarnas": "entertainer",
    "entertainersen": "entertainer",
    "entertainersens": "entertainer",
    "entit": "entita",
    "entitan": "entita",
    "entitans": "entita",
    "entitas": "entita",
    "entite": "entita",
    "entiteten": "entitet",
    "entitetens": "entitet",
    "entiteter": "entitet",
    "entiteterna": "entitet",
    "entiteternas": "entitet",
    "entiteters": "entitet",
    "entitets": "entitet",
    "entitor": "entita",
    "entitorna": "entita",
    "entitornas": "entita",
    "entitors": "entita",
    "entits": "entita",
    "entledig": "entlediga",
    "entledigad": "entlediga",
    "entledigade": "entlediga",
    "entledigades": "entlediga",
    "entledigads": "entlediga",
    "entledigande": "entlediga",
    "entlediganden": "entledigande",
    "entledigandena": "entledigande",
    "entledigandenas": "entledigande",
    "entledigandens": "entledigande",
    "entledigandes": "entledigande",
    "entledigandet": "entledigande",
    "entledigandets": "entledigande",
    "entledigar": "entlediga",
    "entledigas": "entlediga",
    "entledigat": "entlediga",
    "entledigats": "entlediga",
    "entomologen": "entomolog",
    "entomologens": "entomolog",
    "entomologer": "entomolog",
    "entomologerna": "entomolog",
    "entomologernas": "entomolog",
    "entomologers": "entomolog",
    "entomologien": "entomologi",
    "entomologiens": "entomologi",
    "entomologin": "entomologi",
    "entomologins": "entomologi",
    "entomologis": "entomologi",
    "entomologiska": "entomologisk",
    "entomologiskare": "entomologisk",
    "entomologiskares": "entomologisk",
    "entomologiskas": "entomologisk",
    "entomologiskast": "entomologisk",
    "entomologiskaste": "entomologisk",
    "entomologiskastes": "entomologisk",
    "entomologiskasts": "entomologisk",
    "entomologiske": "entomologisk",
    "entomologiskes": "entomologisk",
    "entomologisks": "entomologisk",
    "entomologiskt": "entomologisk",
    "entomologiskts": "entomologisk",
    "entomologs": "entomolog",
    "entoniga": "entonig",
    "entonigare": "entonig",
    "entonigares": "entonig",
    "entonigas": "entonig",
    "entonigast": "entonig",
    "entonigaste": "entonig",
    "entonigastes": "entonig",
    "entonigasts": "entonig",
    "entonige": "entonig",
    "entoniges": "entonig",
    "entonigheten": "entonighet",
    "entonighetens": "entonighet",
    "entonighets": "entonighet",
    "entonigs": "entonig",
    "entonigt": "entonig",
    "entonigts": "entonig",
    "entrecoten": "entrecote",
    "entrecotens": "entrecote",
    "entrecoter": "entrecote",
    "entrecoterna": "entrecote",
    "entrecoternas": "entrecote",
    "entrecoters": "entrecote",
    "entrecotes": "entrecote",
    "entrecôten": "entrecôte",
    "entrecôtens": "entrecôte",
    "entrecôter": "entrecôte",
    "entrecôterna": "entrecôte",
    "entrecôternas": "entrecôte",
    "entrecôters": "entrecôte",
    "entrecôtes": "entrecôte",
    "entreprenaden": "entreprenad",
    "entreprenadens": "entreprenad",
    "entreprenader": "entreprenad",
    "entreprenaderna": "entreprenad",
    "entreprenadernas": "entreprenad",
    "entreprenaders": "entreprenad",
    "entreprenads": "entreprenad",
    "entreprenören": "entreprenör",
    "entreprenörens": "entreprenör",
    "entreprenörer": "entreprenör",
    "entreprenörerna": "entreprenör",
    "entreprenörernas": "entreprenör",
    "entreprenörers": "entreprenör",
    "entreprenörs": "entreprenör",
    "entreprenörskapen": "entreprenörskap",
    "entreprenörskapens": "entreprenörskap",
    "entreprenörskapet": "entreprenörskap",
    "entreprenörskapets": "entreprenörskap",
    "entreprenörskaps": "entreprenörskap",
    "entresolen": "entresol",
    "entresolens": "entresol",
    "entresoler": "entresol",
    "entresolerna": "entresol",
    "entresolernas": "entresol",
    "entresolers": "entresol",
    "entresollen": "entresoll",
    "entresollens": "entresoll",
    "entresoller": "entresoll",
    "entresollerna": "entresoll",
    "entresollernas": "entresoll",
    "entresollers": "entresoll",
    "entresolls": "entresoll",
    "entresols": "entresol",
    "entropien": "entropi",
    "entropiens": "entropi",
    "entropin": "entropi",
    "entropins": "entropi",
    "entropis": "entropi",
    "enträgenheten": "enträgenhet",
    "enträgenhetens": "enträgenhet",
    "enträgenhets": "enträgenhet",
    "enträgens": "enträgen",
    "enträget": "enträgen",
    "enträgets": "enträgen",
    "enträgna": "enträgen",
    "enträgnare": "enträgen",
    "enträgnares": "enträgen",
    "enträgnas": "enträgen",
    "enträgnast": "enträgen",
    "enträgnaste": "enträgen",
    "enträgnastes": "enträgen",
    "enträgnasts": "enträgen",
    "enträgne": "enträgen",
    "enträgnes": "enträgen",
    "entrédörrar": "entrédörr",
    "entrédörrarna": "entrédörr",
    "entrédörrarnas": "entrédörr",
    "entrédörrars": "entrédörr",
    "entrédörren": "entrédörr",
    "entrédörrens": "entrédörr",
    "entrédörrs": "entrédörr",
    "entréer": "entré",
    "entréerna": "entré",
    "entréernas": "entré",
    "entréers": "entré",
    "entrén": "entré",
    "entréns": "entré",
    "entrés": "entré",
    "entumsspikar": "entumsspik",
    "entumsspikarna": "entumsspik",
    "entumsspikarnas": "entumsspik",
    "entumsspikars": "entumsspik",
    "entumsspiken": "entumsspik",
    "entumsspikens": "entumsspik",
    "entumsspiks": "entumsspik",
    "entusiasmen": "entusiasm",
    "entusiasmens": "entusiasm",
    "entusiasmerad": "entusiasmera",
    "entusiasmerade": "entusiasmera",
    "entusiasmerades": "entusiasmera",
    "entusiasmerads": "entusiasmera",
    "entusiasmerande": "entusiasmera",
    "entusiasmeranden": "entusiasmerande",
    "entusiasmerandena": "entusiasmerande",
    "entusiasmerandenas": "entusiasmerande",
    "entusiasmerandens": "entusiasmerande",
    "entusiasmerandes": "entusiasmerande",
    "entusiasmerandet": "entusiasmerande",
    "entusiasmerandets": "entusiasmerande",
    "entusiasmerar": "entusiasmera",
    "entusiasmeras": "entusiasmera",
    "entusiasmerat": "entusiasmera",
    "entusiasmerats": "entusiasmera",
    "entusiasmerbara": "entusiasmerbar",
    "entusiasmerbarare": "entusiasmerbar",
    "entusiasmerbarares": "entusiasmerbar",
    "entusiasmerbaras": "entusiasmerbar",
    "entusiasmerbarast": "entusiasmerbar",
    "entusiasmerbaraste": "entusiasmerbar",
    "entusiasmerbarastes": "entusiasmerbar",
    "entusiasmerbarasts": "entusiasmerbar",
    "entusiasmerbare": "entusiasmerbar",
    "entusiasmerbares": "entusiasmerbar",
    "entusiasmerbarheten": "entusiasmerbarhet",
    "entusiasmerbarhetens": "entusiasmerbarhet",
    "entusiasmerbarhets": "entusiasmerbarhet",
    "entusiasmerbars": "entusiasmerbar",
    "entusiasmerbart": "entusiasmerbar",
    "entusiasmerbarts": "entusiasmerbar",
    "entusiasmeringar": "entusiasmering",
    "entusiasmeringarna": "entusiasmering",
    "entusiasmeringarnas": "entusiasmering",
    "entusiasmeringars": "entusiasmering",
    "entusiasmeringen": "entusiasmering",
    "entusiasmeringens": "entusiasmering",
    "entusiasmerings": "entusiasmering",
    "entusiasms": "entusiasm",
    "entusiasten": "entusiast",
    "entusiastens": "entusiast",
    "entusiaster": "entusiast",
    "entusiasterna": "entusiast",
    "entusiasternas": "entusiast",
    "entusiasters": "entusiast",
    "entusiastiska": "entusiastisk",
    "entusiastiskare": "entusiastisk",
    "entusiastiskares": "entusiastisk",
    "entusiastiskas": "entusiastisk",
    "entusiastiskast": "entusiastisk",
    "entusiastiskaste": "entusiastisk",
    "entusiastiskastes": "entusiastisk",
    "entusiastiskasts": "entusiastisk",
    "entusiastiske": "entusiastisk",
    "entusiastiskes": "entusiastisk",
    "entusiastisks": "entusiastisk",
    "entusiastiskt": "entusiastisk",
    "entusiastiskts": "entusiastisk",
    "entusiasts": "entusiast",
    "entusiastsajten": "entusiastsajt",
    "entusiastsajtens": "entusiastsajt",
    "entusiastsajter": "entusiastsajt",
    "entusiastsajterna": "entusiastsajt",
    "entusiastsajternas": "entusiastsajt",
    "entusiastsajters": "entusiastsajt",
    "entusiastsajts": "entusiastsajt",
    "entydiga": "entydig",
    "entydigare": "entydig",
    "entydigares": "entydig",
    "entydigas": "entydig",
    "entydigast": "entydig",
    "entydigaste": "entydig",
    "entydigastes": "entydig",
    "entydigasts": "entydig",
    "entydige": "entydig",
    "entydiges": "entydig",
    "entydigheten": "entydighet",
    "entydighetens": "entydighet",
    "entydigheter": "entydighet",
    "entydigheterna": "entydighet",
    "entydigheternas": "entydighet",
    "entydigheters": "entydighet",
    "entydighets": "entydighet",
    "entydigs": "entydig",
    "entydigt": "entydig",
    "entydigts": "entydig",
    "entypsbåtar": "entypsbåt",
    "entypsbåtarna": "entypsbåt",
    "entypsbåtarnas": "entypsbåt",
    "entypsbåtars": "entypsbåt",
    "entypsbåten": "entypsbåt",
    "entypsbåtens": "entypsbåt",
    "entypsbåts": "entypsbåt",
    "enumerationen": "enumeration",
    "enumerationens": "enumeration",
    "enumerationer": "enumeration",
    "enumerationerna": "enumeration",
    "enumerationernas": "enumeration",
    "enumerationers": "enumeration",
    "enumerations": "enumeration",
    "envars": "envar",
    "envetenheten": "envetenhet",
    "envetenhetens": "envetenhet",
    "envetenhets": "envetenhet",
    "envetens": "enveten",
    "envetet": "enveten",
    "envetets": "enveten",
    "envetna": "enveten",
    "envetnare": "enveten",
    "envetnares": "enveten",
    "envetnas": "enveten",
    "envetnast": "enveten",
    "envetnaste": "enveten",
    "envetnastes": "enveten",
    "envetnasts": "enveten",
    "envetne": "enveten",
    "envetnes": "enveten",
    "envigar": "envig",
    "envigarna": "envig",
    "envigarnas": "envig",
    "envigars": "envig",
    "envigen": "envig",
    "envigens": "envig",
    "enviger": "envig",
    "envigerna": "envig",
    "envigernas": "envig",
    "envigers": "envig",
    "enviget": "envig",
    "envigets": "envig",
    "envigs": "envig",
    "environgen": "environg",
    "environgens": "environg",
    "environger": "environg",
    "environgerna": "environg",
    "environgernas": "environg",
    "environgers": "environg",
    "environgs": "environg",
    "envisa": "envis",
    "envisades": "envisas",
    "envisare": "envis",
    "envisares": "envis",
    "envisas": "envis",
    "envisast": "envis",
    "envisaste": "envis",
    "envisastes": "envis",
    "envisasts": "envis",
    "envisats": "envisas",
    "envise": "envis",
    "envises": "envis",
    "envisheten": "envishet",
    "envishetens": "envishet",
    "envishets": "envishet",
    "envist": "envis",
    "envists": "envis",
    "envoyéen": "envoyé",
    "envoyéens": "envoyé",
    "envoyéer": "envoyé",
    "envoyéerna": "envoyé",
    "envoyéernas": "envoyé",
    "envoyéers": "envoyé",
    "envoyén": "envoyé",
    "envoyéns": "envoyé",
    "envoyés": "envoyé",
    "envägskommunikationen": "envägskommunikation",
    "envägskommunikationens": "envägskommunikation",
    "envägskommunikationer": "envägskommunikation",
    "envägskommunikationerna": "envägskommunikation",
    "envägskommunikationernas": "envägskommunikation",
    "envägskommunikationers": "envägskommunikation",
    "envägskommunikations": "envägskommunikation",
    "enväldes": "envälde",
    "enväldet": "envälde",
    "enväldets": "envälde",
    "enväldiga": "enväldig",
    "enväldigare": "enväldig",
    "enväldigares": "enväldig",
    "enväldigas": "enväldig",
    "enväldigast": "enväldig",
    "enväldigaste": "enväldig",
    "enväldigastes": "enväldig",
    "enväldigasts": "enväldig",
    "enväldige": "enväldig",
    "enväldiges": "enväldig",
    "enväldigheten": "enväldighet",
    "enväldighetens": "enväldighet",
    "enväldighets": "enväldighet",
    "enväldigs": "enväldig",
    "enväldigt": "enväldig",
    "enväldigts": "enväldig",
    "envärda": "envärd",
    "envärdare": "envärd",
    "envärdares": "envärd",
    "envärdas": "envärd",
    "envärdast": "envärd",
    "envärdaste": "envärd",
    "envärdastes": "envärd",
    "envärdasts": "envärd",
    "envärde": "envärd",
    "envärdes": "envärd",
    "envärds": "envärd",
    "envärt": "envärd",
    "envärts": "envärd",
    "envåldshärskar": "envåldshärskare",
    "envåldshärskaren": "envåldshärskare",
    "envåldshärskarens": "envåldshärskare",
    "envåldshärskares": "envåldshärskare",
    "envåldshärskarna": "envåldshärskare",
    "envåldshärskarnas": "envåldshärskare",
    "envåningshusen": "envåningshus",
    "envåningshusens": "envåningshus",
    "envåningshuset": "envåningshus",
    "envåningshusets": "envåningshus",
    "enzymen": "enzym",
    "enzymens": "enzym",
    "enzymer": "enzym",
    "enzymerna": "enzym",
    "enzymernas": "enzym",
    "enzymers": "enzym",
    "enzymet": "enzym",
    "enzymets": "enzym",
    "enzyms": "enzym",
    "enzymsystemen": "enzymsystem",
    "enzymsystemens": "enzymsystem",
    "enzymsystemet": "enzymsystem",
    "enzymsystemets": "enzymsystem",
    "enzymsystems": "enzymsystem",
    "enzymtvättmedels": "enzymtvättmedel",
    "enzymtvättmedlen": "enzymtvättmedel",
    "enzymtvättmedlens": "enzymtvättmedel",
    "enzymtvättmedlet": "enzymtvättmedel",
    "enzymtvättmedlets": "enzymtvättmedel",
    "enäggstvillingar": "enäggstvilling",
    "enäggstvillingarna": "enäggstvilling",
    "enäggstvillingarnas": "enäggstvilling",
    "enäggstvillingars": "enäggstvilling",
    "enäggstvillingen": "enäggstvilling",
    "enäggstvillingens": "enäggstvilling",
    "enäggstvillings": "enäggstvilling",
    "enögda": "enögd",
    "enögdare": "enögd",
    "enögdares": "enögd",
    "enögdas": "enögd",
    "enögdast": "enögd",
    "enögdaste": "enögd",
    "enögdastes": "enögd",
    "enögdasts": "enögd",
    "enögde": "enögd",
    "enögdes": "enögd",
    "enögdheten": "enögdhet",
    "enögdhetens": "enögdhet",
    "enögdheter": "enögdhet",
    "enögdheterna": "enögdhet",
    "enögdheternas": "enögdhet",
    "enögdheters": "enögdhet",
    "enögdhets": "enögdhet",
    "enögds": "enögd",
    "enögt": "enögd",
    "enögts": "enögd",
    "eocens": "eocen",
    "eolern": "eoler",
    "eolerna": "eoler",
    "eolernas": "eoler",
    "eolerns": "eoler",
    "eolers": "eoler",
    "eoliern": "eolier",
    "eolierna": "eolier",
    "eoliernas": "eolier",
    "eolierns": "eolier",
    "eoliers": "eolier",
    "eoliska": "eolisk",
    "eoliskare": "eolisk",
    "eoliskares": "eolisk",
    "eoliskas": "eolisk",
    "eoliskast": "eolisk",
    "eoliskaste": "eolisk",
    "eoliskastes": "eolisk",
    "eoliskasts": "eolisk",
    "eoliske": "eolisk",
    "eoliskes": "eolisk",
    "eolisks": "eolisk",
    "eoliskt": "eolisk",
    "eoliskts": "eolisk",
    "eolsharp": "eolsharpa",
    "eolsharpan": "eolsharpa",
    "eolsharpans": "eolsharpa",
    "eolsharpas": "eolsharpa",
    "eolsharpe": "eolsharpa",
    "eolsharpor": "eolsharpa",
    "eolsharporna": "eolsharpa",
    "eolsharpornas": "eolsharpa",
    "eolsharpors": "eolsharpa",
    "eolsharps": "eolsharpa",
    "eonen": "eon",
    "eonens": "eon",
    "eoner": "eon",
    "eonerna": "eon",
    "eonernas": "eon",
    "eoners": "eon",
    "eons": "eon",
    "eosinen": "eosin",
    "eosinens": "eosin",
    "eosiner": "eosin",
    "eosinerna": "eosin",
    "eosinernas": "eosin",
    "eosiners": "eosin",
    "eosinet": "eosin",
    "eosinets": "eosin",
    "eosins": "eosin",
    "epatraktorer": "epatraktor",
    "epatraktorerna": "epatraktor",
    "epatraktorernas": "epatraktor",
    "epatraktorers": "epatraktor",
    "epatraktorn": "epatraktor",
    "epatraktorns": "epatraktor",
    "epatraktors": "epatraktor",
    "epicentra": "epicentrum",
    "epicentrana": "epicentrum",
    "epicentranas": "epicentrum",
    "epicentras": "epicentrum",
    "epicentrer": "epicentrum",
    "epicentrerna": "epicentrum",
    "epicentrernas": "epicentrum",
    "epicentrers": "epicentrum",
    "epicentret": "epicentrum",
    "epicentrets": "epicentrum",
    "epicentrumen": "epicentrum",
    "epicentrumens": "epicentrum",
    "epicentrumet": "epicentrum",
    "epicentrumets": "epicentrum",
    "epicentrums": "epicentrum",
    "epidemien": "epidemi",
    "epidemiens": "epidemi",
    "epidemier": "epidemi",
    "epidemierna": "epidemi",
    "epidemiernas": "epidemi",
    "epidemiers": "epidemi",
    "epidemin": "epidemi",
    "epidemins": "epidemi",
    "epidemiologien": "epidemiologi",
    "epidemiologiens": "epidemiologi",
    "epidemiologin": "epidemiologi",
    "epidemiologins": "epidemiologi",
    "epidemiologis": "epidemiologi",
    "epidemiologiska": "epidemiologisk",
    "epidemiologiskas": "epidemiologisk",
    "epidemiologiske": "epidemiologisk",
    "epidemiologiskes": "epidemiologisk",
    "epidemiologisks": "epidemiologisk",
    "epidemiologiskt": "epidemiologisk",
    "epidemiologiskts": "epidemiologisk",
    "epidemis": "epidemi",
    "epidemiska": "epidemisk",
    "epidemiskare": "epidemisk",
    "epidemiskares": "epidemisk",
    "epidemiskas": "epidemisk",
    "epidemiskast": "epidemisk",
    "epidemiskaste": "epidemisk",
    "epidemiskastes": "epidemisk",
    "epidemiskasts": "epidemisk",
    "epidemiske": "epidemisk",
    "epidemiskes": "epidemisk",
    "epidemisks": "epidemisk",
    "epidemiskt": "epidemisk",
    "epidemiskts": "epidemisk",
    "epiduralblockaden": "epiduralblockad",
    "epiduralblockadens": "epiduralblockad",
    "epiduralblockader": "epiduralblockad",
    "epiduralblockaderna": "epiduralblockad",
    "epiduralblockadernas": "epiduralblockad",
    "epiduralblockaders": "epiduralblockad",
    "epiduralblockads": "epiduralblockad",
    "epifysen": "epifys",
    "epifysens": "epifys",
    "epifyser": "epifys",
    "epifyserna": "epifys",
    "epifysernas": "epifys",
    "epifysers": "epifys",
    "epifyten": "epifyt",
    "epifytens": "epifyt",
    "epifyter": "epifyt",
    "epifyterna": "epifyt",
    "epifyternas": "epifyt",
    "epifyters": "epifyt",
    "epifyts": "epifyt",
    "epigonen": "epigon",
    "epigonens": "epigon",
    "epigoner": "epigon",
    "epigoneriet": "epigoneri",
    "epigoneriets": "epigoneri",
    "epigoneris": "epigoneri",
    "epigonerit": "epigoneri",
    "epigonerits": "epigoneri",
    "epigonerna": "epigon",
    "epigonernas": "epigon",
    "epigoners": "epigon",
    "epigons": "epigon",
    "epigrafiken": "epigrafik",
    "epigrafikens": "epigrafik",
    "epigrafiks": "epigrafik",
    "epigrammatiska": "epigrammatisk",
    "epigrammatiskare": "epigrammatisk",
    "epigrammatiskares": "epigrammatisk",
    "epigrammatiskas": "epigrammatisk",
    "epigrammatiskast": "epigrammatisk",
    "epigrammatiskaste": "epigrammatisk",
    "epigrammatiskastes": "epigrammatisk",
    "epigrammatiskasts": "epigrammatisk",
    "epigrammatiske": "epigrammatisk",
    "epigrammatiskes": "epigrammatisk",
    "epigrammatisks": "epigrammatisk",
    "epigrammatiskt": "epigrammatisk",
    "epigrammatiskts": "epigrammatisk",
    "epigrammen": "epigram",
    "epigrammens": "epigram",
    "epigrammet": "epigram",
    "epigrammets": "epigram",
    "epigrams": "epigram",
    "epiken": "epik",
    "epikens": "epik",
    "epikern": "epiker",
    "epikerna": "epiker",
    "epikernas": "epiker",
    "epikerns": "epiker",
    "epikers": "epiker",
    "epiks": "epik",
    "epikureiska": "epikureisk",
    "epikureiskare": "epikureisk",
    "epikureiskares": "epikureisk",
    "epikureiskas": "epikureisk",
    "epikureiskast": "epikureisk",
    "epikureiskaste": "epikureisk",
    "epikureiskastes": "epikureisk",
    "epikureiskasts": "epikureisk",
    "epikureiske": "epikureisk",
    "epikureiskes": "epikureisk",
    "epikureisks": "epikureisk",
    "epikureiskt": "epikureisk",
    "epikureiskts": "epikureisk",
    "epikurismen": "epikurism",
    "epikurismens": "epikurism",
    "epikurismer": "epikurism",
    "epikurismerna": "epikurism",
    "epikurismernas": "epikurism",
    "epikurismers": "epikurism",
    "epikurisms": "epikurism",
    "epikuréen": "epikuré",
    "epikuréens": "epikuré",
    "epikuréer": "epikuré",
    "epikuréerna": "epikuré",
    "epikuréernas": "epikuré",
    "epikuréers": "epikuré",
    "epikurén": "epikuré",
    "epikuréns": "epikuré",
    "epikurés": "epikuré",
    "epilepsien": "epilepsi",
    "epilepsiens": "epilepsi",
    "epilepsier": "epilepsi",
    "epilepsierna": "epilepsi",
    "epilepsiernas": "epilepsi",
    "epilepsiers": "epilepsi",
    "epilepsin": "epilepsi",
    "epilepsins": "epilepsi",
    "epilepsis": "epilepsi",
    "epileptikern": "epileptiker",
    "epileptikerna": "epileptiker",
    "epileptikernas": "epileptiker",
    "epileptikerns": "epileptiker",
    "epileptikers": "epileptiker",
    "epilerad": "epilera",
    "epilerade": "epilera",
    "epilerades": "epilera",
    "epilerads": "epilera",
    "epilerande": "epilera",
    "epileranden": "epilerande",
    "epilerandena": "epilerande",
    "epilerandenas": "epilerande",
    "epilerandens": "epilerande",
    "epilerandes": "epilerande",
    "epilerandet": "epilerande",
    "epilerandets": "epilerande",
    "epilerar": "epilera",
    "epileras": "epilera",
    "epilerat": "epilera",
    "epilerats": "epilera",
    "epilerbara": "epilerbar",
    "epilerbarare": "epilerbar",
    "epilerbarares": "epilerbar",
    "epilerbaras": "epilerbar",
    "epilerbarast": "epilerbar",
    "epilerbaraste": "epilerbar",
    "epilerbarastes": "epilerbar",
    "epilerbarasts": "epilerbar",
    "epilerbare": "epilerbar",
    "epilerbares": "epilerbar",
    "epilerbarheten": "epilerbarhet",
    "epilerbarhetens": "epilerbarhet",
    "epilerbarhets": "epilerbarhet",
    "epilerbars": "epilerbar",
    "epilerbart": "epilerbar",
    "epilerbarts": "epilerbar",
    "epileringar": "epilering",
    "epileringarna": "epilering",
    "epileringarnas": "epilering",
    "epileringars": "epilering",
    "epileringen": "epilering",
    "epileringens": "epilering",
    "epilerings": "epilering",
    "epilogen": "epilog",
    "epilogens": "epilog",
    "epiloger": "epilog",
    "epilogerna": "epilog",
    "epilogernas": "epilog",
    "epilogers": "epilog",
    "epilogs": "epilog",
    "epinefrinen": "epinefrin",
    "epinefrinens": "epinefrin",
    "epinefriner": "epinefrin",
    "epinefrinerna": "epinefrin",
    "epinefrinernas": "epinefrin",
    "epinefriners": "epinefrin",
    "epinefrinet": "epinefrin",
    "epinefrinets": "epinefrin",
    "epinefrins": "epinefrin",
    "episka": "episk",
    "episkare": "episk",
    "episkares": "episk",
    "episkas": "episk",
    "episkast": "episk",
    "episkaste": "episk",
    "episkastes": "episk",
    "episkasts": "episk",
    "episke": "episk",
    "episkes": "episk",
    "episkopala": "episkopal",
    "episkopalare": "episkopal",
    "episkopalares": "episkopal",
    "episkopalas": "episkopal",
    "episkopalast": "episkopal",
    "episkopalaste": "episkopal",
    "episkopalastes": "episkopal",
    "episkopalasts": "episkopal",
    "episkopale": "episkopal",
    "episkopales": "episkopal",
    "episkopalkyrkan": "episkopalkyrka",
    "episkopalkyrkans": "episkopalkyrka",
    "episkopalkyrkas": "episkopalkyrka",
    "episkopals": "episkopal",
    "episkopalt": "episkopal",
    "episkopalts": "episkopal",
    "episkopaten": "episkopat",
    "episkopatens": "episkopat",
    "episkopatet": "episkopat",
    "episkopatets": "episkopat",
    "episkopats": "episkopat",
    "episkopen": "episkop",
    "episkopens": "episkop",
    "episkopet": "episkop",
    "episkopets": "episkop",
    "episkops": "episkop",
    "episks": "episk",
    "episkt": "episk",
    "episkts": "episk",
    "episoden": "episod",
    "episodens": "episod",
    "episoder": "episod",
    "episoderna": "episod",
    "episodernas": "episod",
    "episoders": "episod",
    "episodiska": "episodisk",
    "episodiskare": "episodisk",
    "episodiskares": "episodisk",
    "episodiskas": "episodisk",
    "episodiskast": "episodisk",
    "episodiskaste": "episodisk",
    "episodiskastes": "episodisk",
    "episodiskasts": "episodisk",
    "episodiske": "episodisk",
    "episodiskes": "episodisk",
    "episodisks": "episodisk",
    "episodiskt": "episodisk",
    "episodiskts": "episodisk",
    "episods": "episod",
    "episteln": "epistel",
    "epistelns": "epistel",
    "epistels": "epistel",
    "epistemologien": "epistemologi",
    "epistemologiens": "epistemologi",
    "epistemologin": "epistemologi",
    "epistemologins": "epistemologi",
    "epistemologis": "epistemologi",
    "epistlar": "epistel",
    "epistlarna": "epistel",
    "epistlarnas": "epistel",
    "epistlars": "epistel",
    "epistolära": "epistolär",
    "epistolärare": "epistolär",
    "epistolärares": "epistolär",
    "epistoläras": "epistolär",
    "epistolärast": "epistolär",
    "epistoläraste": "epistolär",
    "epistolärastes": "epistolär",
    "epistolärasts": "epistolär",
    "epistoläre": "epistolär",
    "epistoläres": "epistolär",
    "epistolärs": "epistolär",
    "epistolärt": "epistolär",
    "epistolärts": "epistolär",
    "epistylen": "epistyl",
    "epistylens": "epistyl",
    "epistyler": "epistyl",
    "epistylerna": "epistyl",
    "epistylernas": "epistyl",
    "epistylers": "epistyl",
    "epistyls": "epistyl",
    "epitafer": "epitaf",
    "epitaferna": "epitaf",
    "epitafernas": "epitaf",
    "epitafers": "epitaf",
    "epitafet": "epitaf",
    "epitafets": "epitaf",
    "epitafie": "epitafium",
    "epitafier": "epitafium",
    "epitafierna": "epitafium",
    "epitafiernas": "epitafium",
    "epitafiers": "epitafium",
    "epitafiet": "epitafium",
    "epitafiets": "epitafium",
    "epitafiums": "epitafium",
    "epitafs": "epitaf",
    "epitelcellen": "epitelcell",
    "epitelcellens": "epitelcell",
    "epitelceller": "epitelcell",
    "epitelcellerna": "epitelcell",
    "epitelcellernas": "epitelcell",
    "epitelcellers": "epitelcell",
    "epitelcells": "epitelcell",
    "epitelen": "epitel",
    "epitelens": "epitel",
    "epitelet": "epitel",
    "epitelets": "epitel",
    "epitels": "epitel",
    "epiteten": "epitet",
    "epitetens": "epitet",
    "epitetet": "epitet",
    "epitetets": "epitet",
    "epitets": "epitet",
    "epizoiska": "epizoisk",
    "epizoiskare": "epizoisk",
    "epizoiskares": "epizoisk",
    "epizoiskas": "epizoisk",
    "epizoiskast": "epizoisk",
    "epizoiskaste": "epizoisk",
    "epizoiskastes": "epizoisk",
    "epizoiskasts": "epizoisk",
    "epizoiske": "epizoisk",
    "epizoiskes": "epizoisk",
    "epizoisks": "epizoisk",
    "epizoiskt": "epizoisk",
    "epizoiskts": "epizoisk",
    "epizootien": "epizooti",
    "epizootiens": "epizooti",
    "epizootier": "epizooti",
    "epizootierna": "epizooti",
    "epizootiernas": "epizooti",
    "epizootiers": "epizooti",
    "epizootin": "epizooti",
    "epizootins": "epizooti",
    "epizootis": "epizooti",
    "epoken": "epok",
    "epokens": "epok",
    "epoker": "epok",
    "epokerna": "epok",
    "epokernas": "epok",
    "epokers": "epok",
    "epoks": "epok",
    "eposen": "epos",
    "eposens": "epos",
    "eposet": "epos",
    "eposets": "epos",
    "epostad": "eposta",
    "epostade": "eposta",
    "epostades": "eposta",
    "epostads": "eposta",
    "epostande": "eposta",
    "epostanden": "epostande",
    "epostandena": "epostande",
    "epostandenas": "epostande",
    "epostandens": "epostande",
    "epostandes": "epostande",
    "epostandet": "epostande",
    "epostandets": "epostande",
    "epostar": "epostare",
    "epostaren": "epostare",
    "epostarens": "epostare",
    "epostares": "epostare",
    "epostarna": "epostare",
    "epostarnas": "epostare",
    "epostars": "epost",
    "epostas": "eposta",
    "epostat": "eposta",
    "epostats": "eposta",
    "epostbreven": "epostbrev",
    "epostbrevens": "epostbrev",
    "epostbrevet": "epostbrev",
    "epostbrevets": "epostbrev",
    "epostbrevs": "epostbrev",
    "eposten": "epost",
    "epostens": "epost",
    "eposter": "epost",
    "eposterna": "epost",
    "eposternas": "epost",
    "eposters": "epost",
    "epostmeddelanden": "epostmeddelande",
    "epostmeddelandena": "epostmeddelande",
    "epostmeddelandenas": "epostmeddelande",
    "epostmeddelandens": "epostmeddelande",
    "epostmeddelandes": "epostmeddelande",
    "epostmeddelandet": "epostmeddelande",
    "epostmeddelandets": "epostmeddelande",
    "eposts": "epost",
    "epoxin": "epoxi",
    "epoxins": "epoxi",
    "epoxis": "epoxi",
    "epoxylimmen": "epoxylim",
    "epoxylimmens": "epoxylim",
    "epoxylimmer": "epoxylim",
    "epoxylimmerna": "epoxylim",
    "epoxylimmernas": "epoxylim",
    "epoxylimmers": "epoxylim",
    "epoxylimmet": "epoxylim",
    "epoxylimmets": "epoxylim",
    "epoxylims": "epoxylim",
    "epsilonen": "epsilon",
    "epsilonens": "epsilon",
    "epsilonet": "epsilon",
    "epsilonets": "epsilon",
    "epsilons": "epsilon",
    "epåletten": "epålett",
    "epålettens": "epålett",
    "epåletter": "epålett",
    "epåletterna": "epålett",
    "epåletternas": "epålett",
    "epåletters": "epålett",
    "epåletts": "epålett",
    "er": "Ni",
    "era": "ni",
    "eran": "Ni",
    "erans": "era",
    "eras": "era",
    "erat": "Ni",
    "erbarmliga": "erbarmlig",
    "erbarmligare": "erbarmlig",
    "erbarmligares": "erbarmlig",
    "erbarmligas": "erbarmlig",
    "erbarmligast": "erbarmlig",
    "erbarmligaste": "erbarmlig",
    "erbarmligastes": "erbarmlig",
    "erbarmligasts": "erbarmlig",
    "erbarmlige": "erbarmlig",
    "erbarmliges": "erbarmlig",
    "erbarmligheten": "erbarmlighet",
    "erbarmlighetens": "erbarmlighet",
    "erbarmligheter": "erbarmlighet",
    "erbarmligheterna": "erbarmlighet",
    "erbarmligheternas": "erbarmlighet",
    "erbarmligheters": "erbarmlighet",
    "erbarmlighets": "erbarmlighet",
    "erbarmligs": "erbarmlig",
    "erbarmligt": "erbarmlig",
    "erbarmligts": "erbarmlig",
    "erbiet": "erbium",
    "erbiets": "erbium",
    "erbiumet": "erbium",
    "erbiumets": "erbium",
    "erbiums": "erbium",
    "erbjud": "erbjuda",
    "erbjudande": "erbjuda",
    "erbjudanden": "erbjudande",
    "erbjudandena": "erbjudande",
    "erbjudandenas": "erbjudande",
    "erbjudandens": "erbjudande",
    "erbjudandes": "erbjudande",
    "erbjudandet": "erbjudande",
    "erbjudandets": "erbjudande",
    "erbjudans": "erbjudan",
    "erbjudas": "erbjuda",
    "erbjude": "erbjuda",
    "erbjuden": "erbjuda",
    "erbjudens": "erbjuda",
    "erbjuder": "erbjuda",
    "erbjudes": "erbjuda",
    "erbjudet": "erbjuda",
    "erbjudets": "erbjuda",
    "erbjudit": "erbjuda",
    "erbjudits": "erbjuda",
    "erbjudna": "erbjuda",
    "erbjudnas": "erbjuda",
    "erbjudne": "erbjuda",
    "erbjudnes": "erbjuda",
    "erbjuds": "erbjuda",
    "erbjöd": "erbjuda",
    "erbjöde": "erbjuda",
    "erbjödes": "erbjuda",
    "erbjöds": "erbjuda",
    "ere": "era",
    "erektionen": "erektion",
    "erektionens": "erektion",
    "erektioner": "erektion",
    "erektionerna": "erektion",
    "erektionernas": "erektion",
    "erektioners": "erektion",
    "erektions": "erektion",
    "eremitagen": "eremitage",
    "eremitagens": "eremitage",
    "eremitages": "eremitage",
    "eremitaget": "eremitage",
    "eremitagets": "eremitage",
    "eremiten": "eremit",
    "eremitens": "eremit",
    "eremiter": "eremit",
    "eremiterna": "eremit",
    "eremiternas": "eremit",
    "eremiters": "eremit",
    "eremitiska": "eremitisk",
    "eremitiskare": "eremitisk",
    "eremitiskares": "eremitisk",
    "eremitiskas": "eremitisk",
    "eremitiskast": "eremitisk",
    "eremitiskaste": "eremitisk",
    "eremitiskastes": "eremitisk",
    "eremitiskasts": "eremitisk",
    "eremitiske": "eremitisk",
    "eremitiskes": "eremitisk",
    "eremitisks": "eremitisk",
    "eremitiskt": "eremitisk",
    "eremitiskts": "eremitisk",
    "eremitkräft": "eremitkräfta",
    "eremitkräftan": "eremitkräfta",
    "eremitkräftans": "eremitkräfta",
    "eremitkräftas": "eremitkräfta",
    "eremitkräfte": "eremitkräfta",
    "eremitkräftor": "eremitkräfta",
    "eremitkräftorna": "eremitkräfta",
    "eremitkräftornas": "eremitkräfta",
    "eremitkräftors": "eremitkräfta",
    "eremitkräfts": "eremitkräfta",
    "eremits": "eremit",
    "erfar": "erfara",
    "erfarande": "erfara",
    "erfaranden": "erfarande",
    "erfarandena": "erfarande",
    "erfarandenas": "erfarande",
    "erfarandens": "erfarande",
    "erfarandes": "erfarande",
    "erfarandet": "erfarande",
    "erfarandets": "erfarande",
    "erfaras": "erfara",
    "erfare": "erfara",
    "erfarenheten": "erfarenhet",
    "erfarenhetens": "erfarenhet",
    "erfarenheter": "erfarenhet",
    "erfarenheterna": "erfarenhet",
    "erfarenheternas": "erfarenhet",
    "erfarenheters": "erfarenhet",
    "erfarenhets": "erfarenhet",
    "erfarenhetsmässiga": "erfarenhetsmässig",
    "erfarenhetsmässigare": "erfarenhetsmässig",
    "erfarenhetsmässigares": "erfarenhetsmässig",
    "erfarenhetsmässigas": "erfarenhetsmässig",
    "erfarenhetsmässigast": "erfarenhetsmässig",
    "erfarenhetsmässigaste": "erfarenhetsmässig",
    "erfarenhetsmässigastes": "erfarenhetsmässig",
    "erfarenhetsmässigasts": "erfarenhetsmässig",
    "erfarenhetsmässige": "erfarenhetsmässig",
    "erfarenhetsmässiges": "erfarenhetsmässig",
    "erfarenhetsmässigheten": "erfarenhetsmässighet",
    "erfarenhetsmässighetens": "erfarenhetsmässighet",
    "erfarenhetsmässighets": "erfarenhetsmässighet",
    "erfarenhetsmässigs": "erfarenhetsmässig",
    "erfarenhetsmässigt": "erfarenhetsmässig",
    "erfarenhetsmässigts": "erfarenhetsmässig",
    "erfarenhetsvärldar": "erfarenhetsvärld",
    "erfarenhetsvärldarna": "erfarenhetsvärld",
    "erfarenhetsvärldarnas": "erfarenhetsvärld",
    "erfarenhetsvärldars": "erfarenhetsvärld",
    "erfarenhetsvärlden": "erfarenhetsvärld",
    "erfarenhetsvärldens": "erfarenhetsvärld",
    "erfarenhetsvärlds": "erfarenhetsvärld",
    "erfarens": "erfaren",
    "erfares": "erfara",
    "erfaret": "erfaren",
    "erfarets": "erfaren",
    "erfarit": "erfara",
    "erfarits": "erfara",
    "erfarna": "erfaren",
    "erfarnare": "erfaren",
    "erfarnares": "erfaren",
    "erfarnas": "erfaren",
    "erfarnast": "erfaren",
    "erfarnaste": "erfaren",
    "erfarnastes": "erfaren",
    "erfarnasts": "erfaren",
    "erfarne": "erfaren",
    "erfarnes": "erfaren",
    "erfars": "erfara",
    "erfor": "erfara",
    "erforderliga": "erforderlig",
    "erforderligare": "erforderlig",
    "erforderligares": "erforderlig",
    "erforderligas": "erforderlig",
    "erforderligast": "erforderlig",
    "erforderligaste": "erforderlig",
    "erforderligastes": "erforderlig",
    "erforderligasts": "erforderlig",
    "erforderlige": "erforderlig",
    "erforderliges": "erforderlig",
    "erforderligheten": "erforderlighet",
    "erforderlighetens": "erforderlighet",
    "erforderlighets": "erforderlighet",
    "erforderligs": "erforderlig",
    "erforderligt": "erforderlig",
    "erforderligts": "erforderlig",
    "erfordrad": "erfordra",
    "erfordrade": "erfordra",
    "erfordrades": "erfordra",
    "erfordrads": "erfordra",
    "erfordrande": "erfordra",
    "erfordranden": "erfordrande",
    "erfordrandena": "erfordrande",
    "erfordrandenas": "erfordrande",
    "erfordrandens": "erfordrande",
    "erfordrandes": "erfordrande",
    "erfordrandet": "erfordrande",
    "erfordrandets": "erfordrande",
    "erfordrar": "erfordra",
    "erfordras": "erfordra",
    "erfordrat": "erfordra",
    "erfordrats": "erfordra",
    "erfore": "erfara",
    "erfores": "erfara",
    "erfors": "erfara",
    "ergativa": "ergativ",
    "ergativare": "ergativ",
    "ergativares": "ergativ",
    "ergativas": "ergativ",
    "ergativast": "ergativ",
    "ergativaste": "ergativ",
    "ergativastes": "ergativ",
    "ergativasts": "ergativ",
    "ergative": "ergativ",
    "ergativen": "ergativ",
    "ergativens": "ergativ",
    "ergativer": "ergativ",
    "ergativerna": "ergativ",
    "ergativernas": "ergativ",
    "ergativers": "ergativ",
    "ergatives": "ergativ",
    "ergativs": "ergativ",
    "ergativsubjekten": "ergativsubjekt",
    "ergativsubjektens": "ergativsubjekt",
    "ergativsubjektet": "ergativsubjekt",
    "ergativsubjektets": "ergativsubjekt",
    "ergativsubjekts": "ergativsubjekt",
    "ergativt": "ergativ",
    "ergativts": "ergativ",
    "ergometern": "ergometer",
    "ergometerns": "ergometer",
    "ergometers": "ergometer",
    "ergometrar": "ergometer",
    "ergometrarna": "ergometer",
    "ergometrarnas": "ergometer",
    "ergometrars": "ergometer",
    "ergonomen": "ergonom",
    "ergonomens": "ergonom",
    "ergonomer": "ergonom",
    "ergonomerna": "ergonom",
    "ergonomernas": "ergonom",
    "ergonomers": "ergonom",
    "ergonometriska": "ergonometrisk",
    "ergonometriskare": "ergonometrisk",
    "ergonometriskares": "ergonometrisk",
    "ergonometriskas": "ergonometrisk",
    "ergonometriskast": "ergonometrisk",
    "ergonometriskaste": "ergonometrisk",
    "ergonometriskastes": "ergonometrisk",
    "ergonometriskasts": "ergonometrisk",
    "ergonometriske": "ergonometrisk",
    "ergonometriskes": "ergonometrisk",
    "ergonometrisks": "ergonometrisk",
    "ergonometriskt": "ergonometrisk",
    "ergonometriskts": "ergonometrisk",
    "ergonomien": "ergonomi",
    "ergonomiens": "ergonomi",
    "ergonomin": "ergonomi",
    "ergonomins": "ergonomi",
    "ergonomis": "ergonomi",
    "ergonomiska": "ergonomisk",
    "ergonomiskare": "ergonomisk",
    "ergonomiskares": "ergonomisk",
    "ergonomiskas": "ergonomisk",
    "ergonomiskast": "ergonomisk",
    "ergonomiskaste": "ergonomisk",
    "ergonomiskastes": "ergonomisk",
    "ergonomiskasts": "ergonomisk",
    "ergonomiske": "ergonomisk",
    "ergonomiskes": "ergonomisk",
    "ergonomisks": "ergonomisk",
    "ergonomiskt": "ergonomisk",
    "ergonomiskts": "ergonomisk",
    "ergonoms": "ergonom",
    "erhåll": "erhålla",
    "erhållande": "erhålla",
    "erhållanden": "erhållande",
    "erhållandena": "erhållande",
    "erhållandenas": "erhållande",
    "erhållandens": "erhållande",
    "erhållandes": "erhållande",
    "erhållandet": "erhållande",
    "erhållandets": "erhållande",
    "erhållas": "erhålla",
    "erhålle": "erhålla",
    "erhållen": "erhålla",
    "erhållens": "erhålla",
    "erhåller": "erhålla",
    "erhålles": "erhålla",
    "erhållet": "erhålla",
    "erhållets": "erhålla",
    "erhållit": "erhålla",
    "erhållits": "erhålla",
    "erhållna": "erhålla",
    "erhållnas": "erhålla",
    "erhållne": "erhålla",
    "erhållnes": "erhålla",
    "erhålls": "erhålla",
    "erhöll": "erhålla",
    "erhölle": "erhålla",
    "erhölles": "erhålla",
    "erhölls": "erhålla",
    "erigerad": "erigera",
    "erigerade": "erigera",
    "erigerades": "erigera",
    "erigerads": "erigera",
    "erigerande": "erigera",
    "erigeranden": "erigerande",
    "erigerandena": "erigerande",
    "erigerandenas": "erigerande",
    "erigerandens": "erigerande",
    "erigerandes": "erigerande",
    "erigerandet": "erigerande",
    "erigerandets": "erigerande",
    "erigerar": "erigera",
    "erigeras": "erigera",
    "erigerat": "erigera",
    "erigerats": "erigera",
    "erigerbara": "erigerbar",
    "erigerbarare": "erigerbar",
    "erigerbarares": "erigerbar",
    "erigerbaras": "erigerbar",
    "erigerbarast": "erigerbar",
    "erigerbaraste": "erigerbar",
    "erigerbarastes": "erigerbar",
    "erigerbarasts": "erigerbar",
    "erigerbare": "erigerbar",
    "erigerbares": "erigerbar",
    "erigerbarheten": "erigerbarhet",
    "erigerbarhetens": "erigerbarhet",
    "erigerbarhets": "erigerbarhet",
    "erigerbars": "erigerbar",
    "erigerbart": "erigerbar",
    "erigerbarts": "erigerbar",
    "erigeringar": "erigering",
    "erigeringarna": "erigering",
    "erigeringarnas": "erigering",
    "erigeringars": "erigering",
    "erigeringen": "erigering",
    "erigeringens": "erigering",
    "erigerings": "erigering",
    "eriksgat": "eriksgata",
    "eriksgatan": "eriksgata",
    "eriksgatans": "eriksgata",
    "eriksgatas": "eriksgata",
    "eriksgate": "eriksgata",
    "eriksgator": "eriksgata",
    "eriksgatorna": "eriksgata",
    "eriksgatornas": "eriksgata",
    "eriksgators": "eriksgata",
    "eriksgats": "eriksgata",
    "erinnyen": "erinnye",
    "erinnyens": "erinnye",
    "erinnyer": "erinnye",
    "erinnyerna": "erinnye",
    "erinnyernas": "erinnye",
    "erinnyers": "erinnye",
    "erinnyes": "erinnye",
    "erinrade": "erinra",
    "erinrades": "erinra",
    "erinrande": "erinra",
    "erinranden": "erinrande",
    "erinrandena": "erinrande",
    "erinrandenas": "erinrande",
    "erinrandens": "erinrande",
    "erinrandes": "erinrande",
    "erinrandet": "erinrande",
    "erinrandets": "erinrande",
    "erinrans": "erinran",
    "erinrar": "erinra",
    "erinras": "erinra",
    "erinrat": "erinra",
    "erinrats": "erinra",
    "erinringar": "erinring",
    "erinringarna": "erinring",
    "erinringarnas": "erinring",
    "erinringars": "erinring",
    "erinringen": "erinring",
    "erinringens": "erinring",
    "erinrings": "erinring",
    "erisäpples": "erisäpple",
    "erisäpplet": "erisäpple",
    "erisäpplets": "erisäpple",
    "eritreanen": "eritrean",
    "eritreanens": "eritrean",
    "eritreaner": "eritrean",
    "eritreanerna": "eritrean",
    "eritreanernas": "eritrean",
    "eritreaners": "eritrean",
    "eritreans": "eritrean",
    "eritreansk": "eritreanska",
    "eritreanska": "eritreansk",
    "eritreanskan": "eritreanska",
    "eritreanskans": "eritreanska",
    "eritreanskare": "eritreansk",
    "eritreanskares": "eritreansk",
    "eritreanskas": "eritreanska",
    "eritreanskast": "eritreansk",
    "eritreanskaste": "eritreansk",
    "eritreanskastes": "eritreansk",
    "eritreanskasts": "eritreansk",
    "eritreanske": "eritreanska",
    "eritreanskes": "eritreansk",
    "eritreanskor": "eritreanska",
    "eritreanskorna": "eritreanska",
    "eritreanskornas": "eritreanska",
    "eritreanskors": "eritreanska",
    "eritreansks": "eritreansk",
    "eritreanskt": "eritreansk",
    "eritreanskts": "eritreansk",
    "erkänd": "erkänna",
    "erkända": "erkänna",
    "erkändare": "erkänd",
    "erkändares": "erkänd",
    "erkändas": "erkänna",
    "erkändast": "erkänd",
    "erkändaste": "erkänd",
    "erkändastes": "erkänd",
    "erkändasts": "erkänd",
    "erkände": "erkänna",
    "erkändes": "erkänna",
    "erkändheten": "erkändhet",
    "erkändhetens": "erkändhet",
    "erkändhets": "erkändhet",
    "erkänds": "erkänna",
    "erkänn": "erkänna",
    "erkännande": "erkänna",
    "erkännanden": "erkännande",
    "erkännandena": "erkännande",
    "erkännandenas": "erkännande",
    "erkännandens": "erkännande",
    "erkännandes": "erkännande",
    "erkännandet": "erkännande",
    "erkännandets": "erkännande",
    "erkännas": "erkänna",
    "erkänner": "erkänna",
    "erkännes": "erkänna",
    "erkänns": "erkänna",
    "erkännsamheten": "erkännsamhet",
    "erkännsamhetens": "erkännsamhet",
    "erkännsamhets": "erkännsamhet",
    "erkännsamma": "erkännsam",
    "erkännsammare": "erkännsam",
    "erkännsammares": "erkännsam",
    "erkännsammas": "erkännsam",
    "erkännsammast": "erkännsam",
    "erkännsammaste": "erkännsam",
    "erkännsammastes": "erkännsam",
    "erkännsammasts": "erkännsam",
    "erkännsamme": "erkännsam",
    "erkännsammes": "erkännsam",
    "erkännsams": "erkännsam",
    "erkännsamt": "erkännsam",
    "erkännsamts": "erkännsam",
    "erkänslan": "erkänsla",
    "erkänslans": "erkänsla",
    "erkänslas": "erkänsla",
    "erkänsle": "erkänsla",
    "erkänslo": "erkänsla",
    "erkänt": "erkänna",
    "erkänts": "erkänna",
    "erla": "erlägga",
    "erlade": "erlägga",
    "erlades": "erlägga",
    "erlagd": "erlägga",
    "erlagda": "erlägga",
    "erlagdas": "erlägga",
    "erlagde": "erlägga",
    "erlagdes": "erlägga",
    "erlagds": "erlägga",
    "erlagt": "erlägga",
    "erlagts": "erlägga",
    "erlas": "erlägga",
    "erlägg": "erlägga",
    "erläggande": "erlägga",
    "erlägganden": "erläggande",
    "erläggandena": "erläggande",
    "erläggandenas": "erläggande",
    "erläggandens": "erläggande",
    "erläggandes": "erläggande",
    "erläggandet": "erläggande",
    "erläggandets": "erläggande",
    "erläggas": "erlägga",
    "erlägger": "erlägga",
    "erlägges": "erlägga",
    "erläggs": "erlägga",
    "ernådd": "ernå",
    "ernådda": "ernå",
    "ernåddas": "ernå",
    "ernådde": "ernå",
    "ernåddes": "ernå",
    "ernådds": "ernå",
    "ernående": "ernå",
    "ernåenden": "ernående",
    "ernåendena": "ernående",
    "ernåendenas": "ernående",
    "ernåendens": "ernående",
    "ernåendes": "ernående",
    "ernåendet": "ernående",
    "ernåendets": "ernående",
    "ernår": "ernå",
    "ernås": "ernå",
    "ernått": "ernå",
    "ernåtts": "ernå",
    "eroderad": "erodera",
    "eroderade": "erodera",
    "eroderades": "erodera",
    "eroderads": "erodera",
    "eroderande": "erodera",
    "eroderanden": "eroderande",
    "eroderandena": "eroderande",
    "eroderandenas": "eroderande",
    "eroderandens": "eroderande",
    "eroderandes": "eroderande",
    "eroderandet": "eroderande",
    "eroderandets": "eroderande",
    "eroderar": "erodera",
    "eroderas": "erodera",
    "eroderat": "erodera",
    "eroderats": "erodera",
    "eroderbara": "eroderbar",
    "eroderbarare": "eroderbar",
    "eroderbarares": "eroderbar",
    "eroderbaras": "eroderbar",
    "eroderbarast": "eroderbar",
    "eroderbaraste": "eroderbar",
    "eroderbarastes": "eroderbar",
    "eroderbarasts": "eroderbar",
    "eroderbare": "eroderbar",
    "eroderbares": "eroderbar",
    "eroderbarheten": "eroderbarhet",
    "eroderbarhetens": "eroderbarhet",
    "eroderbarhets": "eroderbarhet",
    "eroderbars": "eroderbar",
    "eroderbart": "eroderbar",
    "eroderbarts": "eroderbar",
    "eroderingar": "erodering",
    "eroderingarna": "erodering",
    "eroderingarnas": "erodering",
    "eroderingars": "erodering",
    "eroderingen": "erodering",
    "eroderingens": "erodering",
    "eroderings": "erodering",
    "erogena": "erogen",
    "erogenare": "erogen",
    "erogenares": "erogen",
    "erogenas": "erogen",
    "erogenast": "erogen",
    "erogenaste": "erogen",
    "erogenastes": "erogen",
    "erogenasts": "erogen",
    "erogene": "erogen",
    "erogenes": "erogen",
    "erogens": "erogen",
    "erogent": "erogen",
    "erogents": "erogen",
    "eror": "era",
    "erorna": "era",
    "erornas": "era",
    "erors": "era",
    "erosionen": "erosion",
    "erosionens": "erosion",
    "erosioner": "erosion",
    "erosionerna": "erosion",
    "erosionernas": "erosion",
    "erosioners": "erosion",
    "erosions": "erosion",
    "erosionsskadan": "erosionsskada",
    "erosionsskadans": "erosionsskada",
    "erosionsskadas": "erosionsskada",
    "erosionsskade": "erosionsskada",
    "erosionsskador": "erosionsskada",
    "erosionsskadorna": "erosionsskada",
    "erosionsskadornas": "erosionsskada",
    "erosionsskadors": "erosionsskada",
    "erosionsstranden": "erosionsstrand",
    "erosionsstrandens": "erosionsstrand",
    "erosionsstrands": "erosionsstrand",
    "erosionsstränder": "erosionsstrand",
    "erosionsstränderna": "erosionsstrand",
    "erosionssträndernas": "erosionsstrand",
    "erosionsstränders": "erosionsstrand",
    "erotiken": "erotik",
    "erotikens": "erotik",
    "erotikern": "erotiker",
    "erotikerna": "erotiker",
    "erotikernas": "erotiker",
    "erotikerns": "erotiker",
    "erotikers": "erotiker",
    "erotiks": "erotik",
    "erotiska": "erotisk",
    "erotiskare": "erotisk",
    "erotiskares": "erotisk",
    "erotiskas": "erotisk",
    "erotiskast": "erotisk",
    "erotiskaste": "erotisk",
    "erotiskastes": "erotisk",
    "erotiskasts": "erotisk",
    "erotiske": "erotisk",
    "erotiskes": "erotisk",
    "erotisks": "erotisk",
    "erotiskt": "erotisk",
    "erotiskts": "erotisk",
    "erotogena": "erotogen",
    "erotogenare": "erotogen",
    "erotogenares": "erotogen",
    "erotogenas": "erotogen",
    "erotogenast": "erotogen",
    "erotogenaste": "erotogen",
    "erotogenastes": "erotogen",
    "erotogenasts": "erotogen",
    "erotogene": "erotogen",
    "erotogenes": "erotogen",
    "erotogens": "erotogen",
    "erotogent": "erotogen",
    "erotogents": "erotogen",
    "erotomana": "erotoman",
    "erotomanare": "erotoman",
    "erotomanares": "erotoman",
    "erotomanas": "erotoman",
    "erotomanast": "erotoman",
    "erotomanaste": "erotoman",
    "erotomanastes": "erotoman",
    "erotomanasts": "erotoman",
    "erotomane": "erotoman",
    "erotomanen": "erotoman",
    "erotomanens": "erotoman",
    "erotomaner": "erotoman",
    "erotomanerna": "erotoman",
    "erotomanernas": "erotoman",
    "erotomaners": "erotoman",
    "erotomanes": "erotoman",
    "erotomanien": "erotomani",
    "erotomaniens": "erotomani",
    "erotomanin": "erotomani",
    "erotomanins": "erotomani",
    "erotomanis": "erotomani",
    "erotomans": "erotoman",
    "erotomant": "erotoman",
    "erotomants": "erotoman",
    "erratan": "errata",
    "erratana": "errata",
    "erratanas": "errata",
    "erratans": "errata",
    "erratas": "errata",
    "erratiska": "erratisk",
    "erratiskare": "erratisk",
    "erratiskares": "erratisk",
    "erratiskas": "erratisk",
    "erratiskast": "erratisk",
    "erratiskaste": "erratisk",
    "erratiskastes": "erratisk",
    "erratiskasts": "erratisk",
    "erratiske": "erratisk",
    "erratiskes": "erratisk",
    "erratisks": "erratisk",
    "erratiskt": "erratisk",
    "erratiskts": "erratisk",
    "ers": "era",
    "ersatt": "ersätta",
    "ersatta": "ersätta",
    "ersattas": "ersätta",
    "ersatte": "ersätta",
    "ersattes": "ersätta",
    "ersatts": "ersätta",
    "ersmäss": "ersmässa",
    "ersmässan": "ersmässa",
    "ersmässans": "ersmässa",
    "ersmässas": "ersmässa",
    "ersmässe": "ersmässa",
    "ersmässor": "ersmässa",
    "ersmässorna": "ersmässa",
    "ersmässornas": "ersmässa",
    "ersmässors": "ersmässa",
    "ersätt": "ersätta",
    "ersättande": "ersätta",
    "ersättanden": "ersättande",
    "ersättandena": "ersättande",
    "ersättandenas": "ersättande",
    "ersättandens": "ersättande",
    "ersättandes": "ersättande",
    "ersättandet": "ersättande",
    "ersättandets": "ersättande",
    "ersättar": "ersättare",
    "ersättaren": "ersättare",
    "ersättarens": "ersättare",
    "ersättares": "ersättare",
    "ersättarna": "ersättare",
    "ersättarnas": "ersättare",
    "ersättas": "ersätta",
    "ersätter": "ersätta",
    "ersättes": "ersätta",
    "ersättliga": "ersättlig",
    "ersättligare": "ersättlig",
    "ersättligares": "ersättlig",
    "ersättligas": "ersättlig",
    "ersättligast": "ersättlig",
    "ersättligaste": "ersättlig",
    "ersättligastes": "ersättlig",
    "ersättligasts": "ersättlig",
    "ersättlige": "ersättlig",
    "ersättliges": "ersättlig",
    "ersättligheten": "ersättlighet",
    "ersättlighetens": "ersättlighet",
    "ersättlighets": "ersättlighet",
    "ersättligs": "ersättlig",
    "ersättligt": "ersättlig",
    "ersättligts": "ersättlig",
    "ersättningar": "ersättning",
    "ersättningarna": "ersättning",
    "ersättningarnas": "ersättning",
    "ersättningars": "ersättning",
    "ersättningen": "ersättning",
    "ersättningens": "ersättning",
    "ersättnings": "ersättning",
    "ersättningsbussar": "ersättningsbuss",
    "ersättningsbussarna": "ersättningsbuss",
    "ersättningsbussarnas": "ersättningsbuss",
    "ersättningsbussars": "ersättningsbuss",
    "ersättningsbussen": "ersättningsbuss",
    "ersättningsbussens": "ersättningsbuss",
    "ersättningsnivåer": "ersättningsnivå",
    "ersättningsnivåerna": "ersättningsnivå",
    "ersättningsnivåernas": "ersättningsnivå",
    "ersättningsnivåers": "ersättningsnivå",
    "ersättningsnivån": "ersättningsnivå",
    "ersättningsnivåns": "ersättningsnivå",
    "ersättningsnivås": "ersättningsnivå",
    "ersätts": "ersätta",
    "ert": "Ni",
    "ertapp": "ertappa",
    "ertappad": "ertappa",
    "ertappade": "ertappa",
    "ertappades": "ertappa",
    "ertappads": "ertappa",
    "ertappande": "ertappa",
    "ertappanden": "ertappande",
    "ertappandena": "ertappande",
    "ertappandenas": "ertappande",
    "ertappandens": "ertappande",
    "ertappandes": "ertappande",
    "ertappandet": "ertappande",
    "ertappandets": "ertappande",
    "ertappar": "ertappa",
    "ertappas": "ertappa",
    "ertappat": "ertappa",
    "ertappats": "ertappa",
    "eruptionen": "eruption",
    "eruptionens": "eruption",
    "eruptioner": "eruption",
    "eruptionerna": "eruption",
    "eruptionernas": "eruption",
    "eruptioners": "eruption",
    "eruptions": "eruption",
    "eruptiva": "eruptiv",
    "eruptivare": "eruptiv",
    "eruptivares": "eruptiv",
    "eruptivas": "eruptiv",
    "eruptivast": "eruptiv",
    "eruptivaste": "eruptiv",
    "eruptivastes": "eruptiv",
    "eruptivasts": "eruptiv",
    "eruptivbergarten": "eruptivbergart",
    "eruptivbergartens": "eruptivbergart",
    "eruptivbergarter": "eruptivbergart",
    "eruptivbergarterna": "eruptivbergart",
    "eruptivbergarternas": "eruptivbergart",
    "eruptivbergarters": "eruptivbergart",
    "eruptivbergarts": "eruptivbergart",
    "eruptive": "eruptiv",
    "eruptives": "eruptiv",
    "eruptivs": "eruptiv",
    "eruptivt": "eruptiv",
    "eruptivts": "eruptiv",
    "erytropoitinen": "erytropoitin",
    "erytropoitinens": "erytropoitin",
    "erytropoitiner": "erytropoitin",
    "erytropoitinerna": "erytropoitin",
    "erytropoitinernas": "erytropoitin",
    "erytropoitiners": "erytropoitin",
    "erytropoitinet": "erytropoitin",
    "erytropoitinets": "erytropoitin",
    "erytropoitins": "erytropoitin",
    "erövrad": "erövra",
    "erövrade": "erövra",
    "erövrades": "erövra",
    "erövrads": "erövra",
    "erövrande": "erövra",
    "erövranden": "erövrande",
    "erövrandena": "erövrande",
    "erövrandenas": "erövrande",
    "erövrandens": "erövrande",
    "erövrandes": "erövrande",
    "erövrandet": "erövrande",
    "erövrandets": "erövrande",
    "erövrar": "erövrare",
    "erövraren": "erövrare",
    "erövrarens": "erövrare",
    "erövrares": "erövrare",
    "erövrarna": "erövrare",
    "erövrarnas": "erövrare",
    "erövras": "erövra",
    "erövrat": "erövra",
    "erövrats": "erövra",
    "erövringar": "erövring",
    "erövringarna": "erövring",
    "erövringarnas": "erövring",
    "erövringars": "erövring",
    "erövringen": "erövring",
    "erövringens": "erövring",
    "erövrings": "erövring",
    "erövringstågen": "erövringståg",
    "erövringstågens": "erövringståg",
    "erövringståget": "erövringståg",
    "erövringstågets": "erövringståg",
    "erövringstågs": "erövringståg",
    "escudon": "escudo",
    "escudons": "escudo",
    "escudos": "escudo",
    "escudosarna": "escudo",
    "escudosarnas": "escudo",
    "escudosen": "escudo",
    "escudosens": "escudo",
    "eselhuvuden": "eselhuvud",
    "eselhuvudena": "eselhuvud",
    "eselhuvudenas": "eselhuvud",
    "eselhuvudens": "eselhuvud",
    "eselhuvudet": "eselhuvud",
    "eselhuvudets": "eselhuvud",
    "eselhuvuds": "eselhuvud",
    "eskadern": "eskader",
    "eskaderns": "eskader",
    "eskaders": "eskader",
    "eskadrar": "eskader",
    "eskadrarna": "eskader",
    "eskadrarnas": "eskader",
    "eskadrars": "eskader",
    "eskalationen": "eskalation",
    "eskalationens": "eskalation",
    "eskalationer": "eskalation",
    "eskalationerna": "eskalation",
    "eskalationernas": "eskalation",
    "eskalationers": "eskalation",
    "eskalations": "eskalation",
    "eskalerad": "eskalera",
    "eskalerade": "eskalera",
    "eskalerades": "eskalera",
    "eskalerads": "eskalera",
    "eskalerande": "eskalera",
    "eskaleranden": "eskalerande",
    "eskalerandena": "eskalerande",
    "eskalerandenas": "eskalerande",
    "eskalerandens": "eskalerande",
    "eskalerandes": "eskalerande",
    "eskalerandet": "eskalerande",
    "eskalerandets": "eskalerande",
    "eskalerar": "eskalera",
    "eskaleras": "eskalera",
    "eskalerat": "eskalera",
    "eskalerats": "eskalera",
    "eskalerbara": "eskalerbar",
    "eskalerbarare": "eskalerbar",
    "eskalerbarares": "eskalerbar",
    "eskalerbaras": "eskalerbar",
    "eskalerbarast": "eskalerbar",
    "eskalerbaraste": "eskalerbar",
    "eskalerbarastes": "eskalerbar",
    "eskalerbarasts": "eskalerbar",
    "eskalerbare": "eskalerbar",
    "eskalerbares": "eskalerbar",
    "eskalerbarheten": "eskalerbarhet",
    "eskalerbarhetens": "eskalerbarhet",
    "eskalerbarhets": "eskalerbarhet",
    "eskalerbars": "eskalerbar",
    "eskalerbart": "eskalerbar",
    "eskalerbarts": "eskalerbar",
    "eskaleringar": "eskalering",
    "eskaleringarna": "eskalering",
    "eskaleringarnas": "eskalering",
    "eskaleringars": "eskalering",
    "eskaleringen": "eskalering",
    "eskaleringens": "eskalering",
    "eskalerings": "eskalering",
    "eskapaden": "eskapad",
    "eskapadens": "eskapad",
    "eskapader": "eskapad",
    "eskapaderna": "eskapad",
    "eskapadernas": "eskapad",
    "eskapaders": "eskapad",
    "eskapads": "eskapad",
    "eskapismen": "eskapism",
    "eskapismens": "eskapism",
    "eskapismer": "eskapism",
    "eskapismerna": "eskapism",
    "eskapismernas": "eskapism",
    "eskapismers": "eskapism",
    "eskapisms": "eskapism",
    "eskapistiska": "eskapistisk",
    "eskapistiskas": "eskapistisk",
    "eskapistiske": "eskapistisk",
    "eskapistiskes": "eskapistisk",
    "eskapistisks": "eskapistisk",
    "eskapistiskt": "eskapistisk",
    "eskapistiskts": "eskapistisk",
    "eskarpen": "eskarp",
    "eskarpens": "eskarp",
    "eskarper": "eskarp",
    "eskarperna": "eskarp",
    "eskarpernas": "eskarp",
    "eskarpers": "eskarp",
    "eskarps": "eskarp",
    "eskatologien": "eskatologi",
    "eskatologiens": "eskatologi",
    "eskatologin": "eskatologi",
    "eskatologins": "eskatologi",
    "eskatologis": "eskatologi",
    "eskatologiska": "eskatologisk",
    "eskatologiskare": "eskatologisk",
    "eskatologiskares": "eskatologisk",
    "eskatologiskas": "eskatologisk",
    "eskatologiskast": "eskatologisk",
    "eskatologiskaste": "eskatologisk",
    "eskatologiskastes": "eskatologisk",
    "eskatologiskasts": "eskatologisk",
    "eskatologiske": "eskatologisk",
    "eskatologiskes": "eskatologisk",
    "eskatologisks": "eskatologisk",
    "eskatologiskt": "eskatologisk",
    "eskatologiskts": "eskatologisk",
    "eskimåer": "eskimå",
    "eskimåerna": "eskimå",
    "eskimåernas": "eskimå",
    "eskimåers": "eskimå",
    "eskimåhundar": "eskimåhund",
    "eskimåhundarna": "eskimåhund",
    "eskimåhundarnas": "eskimåhund",
    "eskimåhundars": "eskimåhund",
    "eskimåhunden": "eskimåhund",
    "eskimåhundens": "eskimåhund",
    "eskimåhunds": "eskimåhund",
    "eskimåisk": "eskimåiska",
    "eskimåiskan": "eskimåiska",
    "eskimåiskans": "eskimåiska",
    "eskimåiskas": "eskimåiska",
    "eskimån": "eskimå",
    "eskimåns": "eskimå",
    "eskimås": "eskimå",
    "eskorten": "eskort",
    "eskortens": "eskort",
    "eskorter": "eskort",
    "eskorterad": "eskortera",
    "eskorterade": "eskortera",
    "eskorterades": "eskortera",
    "eskorterads": "eskortera",
    "eskorterande": "eskortera",
    "eskorteranden": "eskorterande",
    "eskorterandena": "eskorterande",
    "eskorterandenas": "eskorterande",
    "eskorterandens": "eskorterande",
    "eskorterandes": "eskorterande",
    "eskorterandet": "eskorterande",
    "eskorterandets": "eskorterande",
    "eskorterar": "eskortera",
    "eskorteras": "eskortera",
    "eskorterat": "eskortera",
    "eskorterats": "eskortera",
    "eskorterbara": "eskorterbar",
    "eskorterbarare": "eskorterbar",
    "eskorterbarares": "eskorterbar",
    "eskorterbaras": "eskorterbar",
    "eskorterbarast": "eskorterbar",
    "eskorterbaraste": "eskorterbar",
    "eskorterbarastes": "eskorterbar",
    "eskorterbarasts": "eskorterbar",
    "eskorterbare": "eskorterbar",
    "eskorterbares": "eskorterbar",
    "eskorterbarheten": "eskorterbarhet",
    "eskorterbarhetens": "eskorterbarhet",
    "eskorterbarhets": "eskorterbarhet",
    "eskorterbars": "eskorterbar",
    "eskorterbart": "eskorterbar",
    "eskorterbarts": "eskorterbar",
    "eskorteringar": "eskortering",
    "eskorteringarna": "eskortering",
    "eskorteringarnas": "eskortering",
    "eskorteringars": "eskortering",
    "eskorteringen": "eskortering",
    "eskorteringens": "eskortering",
    "eskorterings": "eskortering",
    "eskorterna": "eskort",
    "eskorternas": "eskort",
    "eskorters": "eskort",
    "eskortkvinnan": "eskortkvinna",
    "eskortkvinnans": "eskortkvinna",
    "eskortkvinnas": "eskortkvinna",
    "eskortkvinne": "eskortkvinna",
    "eskortkvinno": "eskortkvinna",
    "eskortkvinnor": "eskortkvinna",
    "eskortkvinnorna": "eskortkvinna",
    "eskortkvinnornas": "eskortkvinna",
    "eskortkvinnors": "eskortkvinna",
    "eskorts": "eskort",
    "eskulapen": "eskulap",
    "eskulapens": "eskulap",
    "eskulaper": "eskulap",
    "eskulaperna": "eskulap",
    "eskulapernas": "eskulap",
    "eskulapers": "eskulap",
    "eskulaps": "eskulap",
    "esoteriska": "esoterisk",
    "esoteriskare": "esoterisk",
    "esoteriskares": "esoterisk",
    "esoteriskas": "esoterisk",
    "esoteriskast": "esoterisk",
    "esoteriskaste": "esoterisk",
    "esoteriskastes": "esoterisk",
    "esoteriskasts": "esoterisk",
    "esoteriske": "esoterisk",
    "esoteriskes": "esoterisk",
    "esoterisks": "esoterisk",
    "esoteriskt": "esoterisk",
    "esoteriskts": "esoterisk",
    "espadrillen": "espadrill",
    "espadrillens": "espadrill",
    "espadriller": "espadrill",
    "espadrillerna": "espadrill",
    "espadrillernas": "espadrill",
    "espadrillers": "espadrill",
    "espadrills": "espadrill",
    "espagnoletten": "espagnolett",
    "espagnolettens": "espagnolett",
    "espagnoletter": "espagnolett",
    "espagnoletterna": "espagnolett",
    "espagnoletternas": "espagnolett",
    "espagnoletters": "espagnolett",
    "espagnoletts": "espagnolett",
    "espartogräset": "espartogräs",
    "espartogräsets": "espartogräs",
    "esparton": "esparto",
    "espartons": "esparto",
    "espartos": "esparto",
    "esperantisten": "esperantist",
    "esperantistens": "esperantist",
    "esperantister": "esperantist",
    "esperantisterna": "esperantist",
    "esperantisternas": "esperantist",
    "esperantisters": "esperantist",
    "esperantists": "esperantist",
    "esperantos": "esperanto",
    "esplanaden": "esplanad",
    "esplanadens": "esplanad",
    "esplanader": "esplanad",
    "esplanaderna": "esplanad",
    "esplanadernas": "esplanad",
    "esplanaders": "esplanad",
    "esplanads": "esplanad",
    "espressobryggar": "espressobryggare",
    "espressobryggaren": "espressobryggare",
    "espressobryggarens": "espressobryggare",
    "espressobryggares": "espressobryggare",
    "espressobryggarna": "espressobryggare",
    "espressobryggarnas": "espressobryggare",
    "espresson": "espresso",
    "espressons": "espresso",
    "espressos": "espresso",
    "esprien": "espri",
    "espriens": "espri",
    "esprier": "espri",
    "esprierna": "espri",
    "espriernas": "espri",
    "espriers": "espri",
    "esprin": "espri",
    "esprins": "espri",
    "espris": "espri",
    "espriten": "esprit",
    "espritens": "esprit",
    "espriter": "esprit",
    "espriterna": "esprit",
    "espriternas": "esprit",
    "espriters": "esprit",
    "esprits": "esprit",
    "essayen": "essay",
    "essayens": "essay",
    "essayer": "essay",
    "essayerna": "essay",
    "essayernas": "essay",
    "essayers": "essay",
    "essayisten": "essayist",
    "essayistens": "essayist",
    "essayister": "essayist",
    "essayisterna": "essayist",
    "essayisternas": "essayist",
    "essayisters": "essayist",
    "essayistiken": "essayistik",
    "essayistikens": "essayistik",
    "essayistiker": "essayistik",
    "essayistikerna": "essayistik",
    "essayistikernas": "essayistik",
    "essayistikers": "essayistik",
    "essayistiks": "essayistik",
    "essayistiska": "essayistisk",
    "essayistiskare": "essayistisk",
    "essayistiskares": "essayistisk",
    "essayistiskas": "essayistisk",
    "essayistiskast": "essayistisk",
    "essayistiskaste": "essayistisk",
    "essayistiskastes": "essayistisk",
    "essayistiskasts": "essayistisk",
    "essayistiske": "essayistisk",
    "essayistiskes": "essayistisk",
    "essayistisks": "essayistisk",
    "essayistiskt": "essayistisk",
    "essayistiskts": "essayistisk",
    "essayists": "essayist",
    "essayn": "essay",
    "essayns": "essay",
    "essays": "essay",
    "essaysamlingar": "essaysamling",
    "essaysamlingarna": "essaysamling",
    "essaysamlingarnas": "essaysamling",
    "essaysamlingars": "essaysamling",
    "essaysamlingen": "essaysamling",
    "essaysamlingens": "essaysamling",
    "essaysamlings": "essaysamling",
    "essen": "ess",
    "essens": "ess",
    "essensen": "essens",
    "essensens": "essens",
    "essenser": "essens",
    "essenserna": "essens",
    "essensernas": "essens",
    "essensers": "essens",
    "essentiella": "essentiell",
    "essentiellare": "essentiell",
    "essentiellares": "essentiell",
    "essentiellas": "essentiell",
    "essentiellast": "essentiell",
    "essentiellaste": "essentiell",
    "essentiellastes": "essentiell",
    "essentiellasts": "essentiell",
    "essentielle": "essentiell",
    "essentielles": "essentiell",
    "essentiells": "essentiell",
    "essentiellt": "essentiell",
    "essentiellts": "essentiell",
    "esset": "ess",
    "essets": "ess",
    "essiven": "essiv",
    "essivens": "essiv",
    "essiver": "essiv",
    "essiverna": "essiv",
    "essivernas": "essiv",
    "essivers": "essiv",
    "essivs": "essiv",
    "essäboken": "essäbok",
    "essäbokens": "essäbok",
    "essäboks": "essäbok",
    "essäböcker": "essäbok",
    "essäböckerna": "essäbok",
    "essäböckernas": "essäbok",
    "essäböckers": "essäbok",
    "essäer": "essä",
    "essäerna": "essä",
    "essäernas": "essä",
    "essäers": "essä",
    "essäfrågan": "essäfråga",
    "essäfrågans": "essäfråga",
    "essäfrågas": "essäfråga",
    "essäfråge": "essäfråga",
    "essäfrågor": "essäfråga",
    "essäfrågorna": "essäfråga",
    "essäfrågornas": "essäfråga",
    "essäfrågors": "essäfråga",
    "essäisten": "essäist",
    "essäistens": "essäist",
    "essäister": "essäist",
    "essäisterna": "essäist",
    "essäisternas": "essäist",
    "essäisters": "essäist",
    "essäistiken": "essäistik",
    "essäistikens": "essäistik",
    "essäistiks": "essäistik",
    "essäistiska": "essäistisk",
    "essäistiskare": "essäistisk",
    "essäistiskares": "essäistisk",
    "essäistiskas": "essäistisk",
    "essäistiskast": "essäistisk",
    "essäistiskaste": "essäistisk",
    "essäistiskastes": "essäistisk",
    "essäistiskasts": "essäistisk",
    "essäistiske": "essäistisk",
    "essäistiskes": "essäistisk",
    "essäistisks": "essäistisk",
    "essäistiskt": "essäistisk",
    "essäistiskts": "essäistisk",
    "essäists": "essäist",
    "essän": "essä",
    "essäns": "essä",
    "essäs": "essä",
    "essäsamlingar": "essäsamling",
    "essäsamlingarna": "essäsamling",
    "essäsamlingarnas": "essäsamling",
    "essäsamlingars": "essäsamling",
    "essäsamlingen": "essäsamling",
    "essäsamlingens": "essäsamling",
    "essäsamlings": "essäsamling",
    "essäuppgiften": "essäuppgift",
    "essäuppgiftens": "essäuppgift",
    "essäuppgifter": "essäuppgift",
    "essäuppgifterna": "essäuppgift",
    "essäuppgifternas": "essäuppgift",
    "essäuppgifters": "essäuppgift",
    "essäuppgifts": "essäuppgift",
    "esten": "est",
    "estens": "est",
    "ester": "est",
    "estern": "ester",
    "esterna": "est",
    "esternas": "est",
    "esterns": "ester",
    "esterplasten": "esterplast",
    "esterplastens": "esterplast",
    "esterplaster": "esterplast",
    "esterplasterna": "esterplast",
    "esterplasternas": "esterplast",
    "esterplasters": "esterplast",
    "esterplasts": "esterplast",
    "esters": "ester",
    "esteten": "estet",
    "estetens": "estet",
    "esteter": "estet",
    "esteterna": "estet",
    "esteternas": "estet",
    "esteters": "estet",
    "esteticerad": "esteticera",
    "esteticerade": "esteticera",
    "esteticerades": "esteticera",
    "esteticerads": "esteticera",
    "esteticerande": "esteticera",
    "esteticeranden": "esteticerande",
    "esteticerandena": "esteticerande",
    "esteticerandenas": "esteticerande",
    "esteticerandens": "esteticerande",
    "esteticerandes": "esteticerande",
    "esteticerandet": "esteticerande",
    "esteticerandets": "esteticerande",
    "esteticerar": "esteticera",
    "esteticeras": "esteticera",
    "esteticerat": "esteticera",
    "esteticerats": "esteticera",
    "esteticerbara": "esteticerbar",
    "esteticerbarare": "esteticerbar",
    "esteticerbarares": "esteticerbar",
    "esteticerbaras": "esteticerbar",
    "esteticerbarast": "esteticerbar",
    "esteticerbaraste": "esteticerbar",
    "esteticerbarastes": "esteticerbar",
    "esteticerbarasts": "esteticerbar",
    "esteticerbare": "esteticerbar",
    "esteticerbares": "esteticerbar",
    "esteticerbarheten": "esteticerbarhet",
    "esteticerbarhetens": "esteticerbarhet",
    "esteticerbarhets": "esteticerbarhet",
    "esteticerbars": "esteticerbar",
    "esteticerbart": "esteticerbar",
    "esteticerbarts": "esteticerbar",
    "esteticeringar": "esteticering",
    "esteticeringarna": "esteticering",
    "esteticeringarnas": "esteticering",
    "esteticeringars": "esteticering",
    "esteticeringen": "esteticering",
    "esteticeringens": "esteticering",
    "esteticerings": "esteticering",
    "esteticismen": "esteticism",
    "esteticismens": "esteticism",
    "esteticismer": "esteticism",
    "esteticismerna": "esteticism",
    "esteticismernas": "esteticism",
    "esteticismers": "esteticism",
    "esteticisms": "esteticism",
    "estetiken": "estetik",
    "estetikens": "estetik",
    "estetikern": "estetiker",
    "estetikerna": "estetiker",
    "estetikernas": "estetiker",
    "estetikerns": "estetiker",
    "estetikers": "estetiker",
    "estetiks": "estetik",
    "estetiserad": "estetisera",
    "estetiserade": "estetisera",
    "estetiserades": "estetisera",
    "estetiserads": "estetisera",
    "estetiserande": "estetisera",
    "estetiseranden": "estetiserande",
    "estetiserandena": "estetiserande",
    "estetiserandenas": "estetiserande",
    "estetiserandens": "estetiserande",
    "estetiserandes": "estetiserande",
    "estetiserandet": "estetiserande",
    "estetiserandets": "estetiserande",
    "estetiserar": "estetisera",
    "estetiseras": "estetisera",
    "estetiserat": "estetisera",
    "estetiserats": "estetisera",
    "estetiserbara": "estetiserbar",
    "estetiserbarare": "estetiserbar",
    "estetiserbarares": "estetiserbar",
    "estetiserbaras": "estetiserbar",
    "estetiserbarast": "estetiserbar",
    "estetiserbaraste": "estetiserbar",
    "estetiserbarastes": "estetiserbar",
    "estetiserbarasts": "estetiserbar",
    "estetiserbare": "estetiserbar",
    "estetiserbares": "estetiserbar",
    "estetiserbarheten": "estetiserbarhet",
    "estetiserbarhetens": "estetiserbarhet",
    "estetiserbarhets": "estetiserbarhet",
    "estetiserbars": "estetiserbar",
    "estetiserbart": "estetiserbar",
    "estetiserbarts": "estetiserbar",
    "estetiseringar": "estetisering",
    "estetiseringarna": "estetisering",
    "estetiseringarnas": "estetisering",
    "estetiseringars": "estetisering",
    "estetiseringen": "estetisering",
    "estetiseringens": "estetisering",
    "estetiserings": "estetisering",
    "estetiska": "estetisk",
    "estetiskare": "estetisk",
    "estetiskares": "estetisk",
    "estetiskas": "estetisk",
    "estetiskast": "estetisk",
    "estetiskaste": "estetisk",
    "estetiskastes": "estetisk",
    "estetiskasts": "estetisk",
    "estetiske": "estetisk",
    "estetiskes": "estetisk",
    "estetisks": "estetisk",
    "estetiskt": "estetisk",
    "estetiskts": "estetisk",
    "estets": "estet",
    "estimerad": "estimera",
    "estimerade": "estimera",
    "estimerades": "estimera",
    "estimerads": "estimera",
    "estimerande": "estimera",
    "estimeranden": "estimerande",
    "estimerandena": "estimerande",
    "estimerandenas": "estimerande",
    "estimerandens": "estimerande",
    "estimerandes": "estimerande",
    "estimerandet": "estimerande",
    "estimerandets": "estimerande",
    "estimerar": "estimera",
    "estimeras": "estimera",
    "estimerat": "estimera",
    "estimerats": "estimera",
    "estimerbara": "estimerbar",
    "estimerbarare": "estimerbar",
    "estimerbarares": "estimerbar",
    "estimerbaras": "estimerbar",
    "estimerbarast": "estimerbar",
    "estimerbaraste": "estimerbar",
    "estimerbarastes": "estimerbar",
    "estimerbarasts": "estimerbar",
    "estimerbare": "estimerbar",
    "estimerbares": "estimerbar",
    "estimerbarheten": "estimerbarhet",
    "estimerbarhetens": "estimerbarhet",
    "estimerbarhets": "estimerbarhet",
    "estimerbars": "estimerbar",
    "estimerbart": "estimerbar",
    "estimerbarts": "estimerbar",
    "estimeringar": "estimering",
    "estimeringarna": "estimering",
    "estimeringarnas": "estimering",
    "estimeringars": "estimering",
    "estimeringen": "estimering",
    "estimeringens": "estimering",
    "estimerings": "estimering",
    "estländar": "estländare",
    "estländaren": "estländare",
    "estländarens": "estländare",
    "estländares": "estländare",
    "estländarna": "estländare",
    "estländarnas": "estländare",
    "estländska": "estländsk",
    "estländskan": "estländska",
    "estländskans": "estländska",
    "estländskare": "estländsk",
    "estländskares": "estländsk",
    "estländskas": "estländska",
    "estländskast": "estländsk",
    "estländskaste": "estländsk",
    "estländskastes": "estländsk",
    "estländskasts": "estländsk",
    "estländske": "estländska",
    "estländskes": "estländsk",
    "estländskor": "estländska",
    "estländskorna": "estländska",
    "estländskornas": "estländska",
    "estländskors": "estländska",
    "estländsks": "estländsk",
    "estländskt": "estländsk",
    "estländskts": "estländsk",
    "estnisk": "estniska",
    "estniska": "estnisk",
    "estniskan": "estniska",
    "estniskans": "estniska",
    "estniskare": "estnisk",
    "estniskares": "estnisk",
    "estniskas": "estniska",
    "estniskast": "estnisk",
    "estniskaste": "estnisk",
    "estniskastes": "estnisk",
    "estniskasts": "estnisk",
    "estniske": "estniska",
    "estniskes": "estnisk",
    "estniskor": "estniska",
    "estniskorna": "estniska",
    "estniskornas": "estniska",
    "estniskors": "estniska",
    "estnisks": "estnisk",
    "estniskt": "estnisk",
    "estniskts": "estnisk",
    "estradartisten": "estradartist",
    "estradartistens": "estradartist",
    "estradartister": "estradartist",
    "estradartisterna": "estradartist",
    "estradartisternas": "estradartist",
    "estradartisters": "estradartist",
    "estradartists": "estradartist",
    "estraddebatten": "estraddebatt",
    "estraddebattens": "estraddebatt",
    "estraddebatter": "estraddebatt",
    "estraddebatterna": "estraddebatt",
    "estraddebatternas": "estraddebatt",
    "estraddebatters": "estraddebatt",
    "estraddebatts": "estraddebatt",
    "estraden": "estrad",
    "estradens": "estrad",
    "estrader": "estrad",
    "estraderna": "estrad",
    "estradernas": "estrad",
    "estraders": "estrad",
    "estrads": "estrad",
    "estradsamtalen": "estradsamtal",
    "estradsamtalens": "estradsamtal",
    "estradsamtalet": "estradsamtal",
    "estradsamtalets": "estradsamtal",
    "estradsamtals": "estradsamtal",
    "estradören": "estradör",
    "estradörens": "estradör",
    "estradörer": "estradör",
    "estradörerna": "estradör",
    "estradörernas": "estradör",
    "estradörers": "estradör",
    "estradörs": "estradör",
    "estrar": "ester",
    "estrarna": "ester",
    "estrarnas": "ester",
    "estrars": "ester",
    "ests": "est",
    "etablerad": "etablera",
    "etablerade": "etablerad",
    "etablerades": "etablerad",
    "etablerads": "etablerad",
    "etablerande": "etablera",
    "etableranden": "etablerande",
    "etablerandena": "etablerande",
    "etablerandenas": "etablerande",
    "etablerandens": "etablerande",
    "etablerandes": "etablerande",
    "etablerandet": "etablerande",
    "etablerandets": "etablerande",
    "etablerar": "etablera",
    "etableras": "etablera",
    "etablerat": "etablerad",
    "etablerats": "etablerad",
    "etablerbara": "etablerbar",
    "etablerbarare": "etablerbar",
    "etablerbarares": "etablerbar",
    "etablerbaras": "etablerbar",
    "etablerbarast": "etablerbar",
    "etablerbaraste": "etablerbar",
    "etablerbarastes": "etablerbar",
    "etablerbarasts": "etablerbar",
    "etablerbare": "etablerbar",
    "etablerbares": "etablerbar",
    "etablerbarheten": "etablerbarhet",
    "etablerbarhetens": "etablerbarhet",
    "etablerbarhets": "etablerbarhet",
    "etablerbars": "etablerbar",
    "etablerbart": "etablerbar",
    "etablerbarts": "etablerbar",
    "etableringar": "etablering",
    "etableringarna": "etablering",
    "etableringarnas": "etablering",
    "etableringars": "etablering",
    "etableringen": "etablering",
    "etableringens": "etablering",
    "etablerings": "etablering",
    "etablissemangen": "etablissemang",
    "etablissemangens": "etablissemang",
    "etablissemanget": "etablissemang",
    "etablissemangets": "etablissemang",
    "etablissemangs": "etablissemang",
    "etablissemangsföreträdar": "etablissemangsföreträdare",
    "etablissemangsföreträdaren": "etablissemangsföreträdare",
    "etablissemangsföreträdarens": "etablissemangsföreträdare",
    "etablissemangsföreträdares": "etablissemangsföreträdare",
    "etablissemangsföreträdarna": "etablissemangsföreträdare",
    "etablissemangsföreträdarnas": "etablissemangsföreträdare",
    "etablissementen": "etablissement",
    "etablissementens": "etablissement",
    "etablissementet": "etablissement",
    "etablissementets": "etablissement",
    "etablissements": "etablissement",
    "etagen": "etage",
    "etagens": "etage",
    "etager": "etage",
    "etagerna": "etage",
    "etagernas": "etage",
    "etagers": "etage",
    "etages": "etage",
    "etaget": "etage",
    "etagets": "etage",
    "etagevåningar": "etagevåning",
    "etagevåningarna": "etagevåning",
    "etagevåningarnas": "etagevåning",
    "etagevåningars": "etagevåning",
    "etagevåningen": "etagevåning",
    "etagevåningens": "etagevåning",
    "etagevånings": "etagevåning",
    "etagären": "etagär",
    "etagärens": "etagär",
    "etagärer": "etagär",
    "etagärerna": "etagär",
    "etagärernas": "etagär",
    "etagärers": "etagär",
    "etagärs": "etagär",
    "etalongen": "etalong",
    "etalongens": "etalong",
    "etalonger": "etalong",
    "etalongerna": "etalong",
    "etalongernas": "etalong",
    "etalongers": "etalong",
    "etalongs": "etalong",
    "etan": "eta",
    "etana": "eta",
    "etanas": "eta",
    "etanen": "etan",
    "etanens": "etan",
    "etaner": "etan",
    "etanerna": "etan",
    "etanernas": "etan",
    "etaners": "etan",
    "etanet": "etan",
    "etanets": "etan",
    "etanoldrivens": "etanoldriven",
    "etanoldrivet": "etanoldriven",
    "etanoldrivets": "etanoldriven",
    "etanoldrivna": "etanoldriven",
    "etanoldrivnas": "etanoldriven",
    "etanoldrivne": "etanoldriven",
    "etanoldrivnes": "etanoldriven",
    "etanolen": "etanol",
    "etanolens": "etanol",
    "etanols": "etanol",
    "etans": "etan",
    "etappen": "etapp",
    "etappens": "etapp",
    "etapper": "etapp",
    "etapperna": "etapp",
    "etappernas": "etapp",
    "etappers": "etapp",
    "etapplinjen": "etapplinje",
    "etapplinjens": "etapplinje",
    "etapplinjer": "etapplinje",
    "etapplinjerna": "etapplinje",
    "etapplinjernas": "etapplinje",
    "etapplinjers": "etapplinje",
    "etapplinjes": "etapplinje",
    "etapps": "etapp",
    "etappväsendet": "etappväsen",
    "etappväsendets": "etappväsen",
    "etappväsenet": "etappväsen",
    "etappväsenets": "etappväsen",
    "etappväsens": "etappväsen",
    "etas": "eta",
    "etat": "eta",
    "etats": "eta",
    "etenen": "eten",
    "etenens": "eten",
    "etenet": "eten",
    "etenets": "eten",
    "etenplasten": "etenplast",
    "etenplastens": "etenplast",
    "etenplasts": "etenplast",
    "etens": "eten",
    "eterflask": "eterflaska",
    "eterflaskan": "eterflaska",
    "eterflaskans": "eterflaska",
    "eterflaskas": "eterflaska",
    "eterflaske": "eterflaska",
    "eterflaskor": "eterflaska",
    "eterflaskorna": "eterflaska",
    "eterflaskornas": "eterflaska",
    "eterflaskors": "eterflaska",
    "eterisationen": "eterisation",
    "eterisationens": "eterisation",
    "eterisationer": "eterisation",
    "eterisationerna": "eterisation",
    "eterisationernas": "eterisation",
    "eterisationers": "eterisation",
    "eterisations": "eterisation",
    "eteriserad": "eterisera",
    "eteriserade": "eterisera",
    "eteriserades": "eterisera",
    "eteriserads": "eterisera",
    "eteriserande": "eterisera",
    "eteriseranden": "eteriserande",
    "eteriserandena": "eteriserande",
    "eteriserandenas": "eteriserande",
    "eteriserandens": "eteriserande",
    "eteriserandes": "eteriserande",
    "eteriserandet": "eteriserande",
    "eteriserandets": "eteriserande",
    "eteriserar": "eterisera",
    "eteriseras": "eterisera",
    "eteriserat": "eterisera",
    "eteriserats": "eterisera",
    "eteriserbara": "eteriserbar",
    "eteriserbarare": "eteriserbar",
    "eteriserbarares": "eteriserbar",
    "eteriserbaras": "eteriserbar",
    "eteriserbarast": "eteriserbar",
    "eteriserbaraste": "eteriserbar",
    "eteriserbarastes": "eteriserbar",
    "eteriserbarasts": "eteriserbar",
    "eteriserbare": "eteriserbar",
    "eteriserbares": "eteriserbar",
    "eteriserbarheten": "eteriserbarhet",
    "eteriserbarhetens": "eteriserbarhet",
    "eteriserbarhets": "eteriserbarhet",
    "eteriserbars": "eteriserbar",
    "eteriserbart": "eteriserbar",
    "eteriserbarts": "eteriserbar",
    "eteriseringar": "eterisering",
    "eteriseringarna": "eterisering",
    "eteriseringarnas": "eterisering",
    "eteriseringars": "eterisering",
    "eteriseringen": "eterisering",
    "eteriseringens": "eterisering",
    "eteriserings": "eterisering",
    "eteriska": "eterisk",
    "eteriskare": "eterisk",
    "eteriskares": "eterisk",
    "eteriskas": "eterisk",
    "eteriskast": "eterisk",
    "eteriskaste": "eterisk",
    "eteriskastes": "eterisk",
    "eteriskasts": "eterisk",
    "eteriske": "eterisk",
    "eteriskes": "eterisk",
    "eterisks": "eterisk",
    "eteriskt": "eterisk",
    "eteriskts": "eterisk",
    "etermedia": "etermedium",
    "etermediana": "etermedium",
    "etermedianas": "etermedium",
    "etermedias": "etermedium",
    "etermedie": "etermedium",
    "etermediemonopolen": "etermediemonopol",
    "etermediemonopolens": "etermediemonopol",
    "etermediemonopolet": "etermediemonopol",
    "etermediemonopolets": "etermediemonopol",
    "etermediemonopols": "etermediemonopol",
    "etermedier": "etermedium",
    "etermedierna": "etermedium",
    "etermediernas": "etermedium",
    "etermediers": "etermedium",
    "etermediet": "etermedium",
    "etermediets": "etermedium",
    "etermediums": "etermedium",
    "etern": "eter",
    "eternellen": "eternell",
    "eternellens": "eternell",
    "eterneller": "eternell",
    "eternellerna": "eternell",
    "eternellernas": "eternell",
    "eternellers": "eternell",
    "eternells": "eternell",
    "eterns": "eter",
    "eters": "eter",
    "etiken": "etik",
    "etikens": "etik",
    "etikern": "etiker",
    "etikerna": "etiker",
    "etikernas": "etiker",
    "etikerns": "etiker",
    "etikers": "etiker",
    "etiketten": "etikett",
    "etikettens": "etikett",
    "etiketter": "etikett",
    "etiketterad": "etikettera",
    "etiketterade": "etikettera",
    "etiketterades": "etikettera",
    "etiketterads": "etikettera",
    "etiketterande": "etikettera",
    "etiketteranden": "etiketterande",
    "etiketterandena": "etiketterande",
    "etiketterandenas": "etiketterande",
    "etiketterandens": "etiketterande",
    "etiketterandes": "etiketterande",
    "etiketterandet": "etiketterande",
    "etiketterandets": "etiketterande",
    "etiketterar": "etikettera",
    "etiketteras": "etikettera",
    "etiketterat": "etikettera",
    "etiketterats": "etikettera",
    "etiketterbara": "etiketterbar",
    "etiketterbarare": "etiketterbar",
    "etiketterbarares": "etiketterbar",
    "etiketterbaras": "etiketterbar",
    "etiketterbarast": "etiketterbar",
    "etiketterbaraste": "etiketterbar",
    "etiketterbarastes": "etiketterbar",
    "etiketterbarasts": "etiketterbar",
    "etiketterbare": "etiketterbar",
    "etiketterbares": "etiketterbar",
    "etiketterbarheten": "etiketterbarhet",
    "etiketterbarhetens": "etiketterbarhet",
    "etiketterbarhets": "etiketterbarhet",
    "etiketterbars": "etiketterbar",
    "etiketterbart": "etiketterbar",
    "etiketterbarts": "etiketterbar",
    "etiketteringar": "etikettering",
    "etiketteringarna": "etikettering",
    "etiketteringarnas": "etikettering",
    "etiketteringars": "etikettering",
    "etiketteringen": "etikettering",
    "etiketteringens": "etikettering",
    "etiketterings": "etikettering",
    "etiketterna": "etikett",
    "etiketternas": "etikett",
    "etiketters": "etikett",
    "etikettråden": "etikettråd",
    "etikettrådens": "etikettråd",
    "etikettrådet": "etikettråd",
    "etikettrådets": "etikettråd",
    "etikettråds": "etikettråd",
    "etiketts": "etikett",
    "etikettsmässiga": "etikettsmässig",
    "etikettsmässigare": "etikettsmässig",
    "etikettsmässigares": "etikettsmässig",
    "etikettsmässigas": "etikettsmässig",
    "etikettsmässigast": "etikettsmässig",
    "etikettsmässigaste": "etikettsmässig",
    "etikettsmässigastes": "etikettsmässig",
    "etikettsmässigasts": "etikettsmässig",
    "etikettsmässige": "etikettsmässig",
    "etikettsmässiges": "etikettsmässig",
    "etikettsmässigs": "etikettsmässig",
    "etikettsmässigt": "etikettsmässig",
    "etikettsmässigts": "etikettsmässig",
    "etiks": "etik",
    "etioleringar": "etiolering",
    "etioleringarna": "etiolering",
    "etioleringarnas": "etiolering",
    "etioleringars": "etiolering",
    "etioleringen": "etiolering",
    "etioleringens": "etiolering",
    "etiolerings": "etiolering",
    "etiologien": "etiologi",
    "etiologiens": "etiologi",
    "etiologin": "etiologi",
    "etiologins": "etiologi",
    "etiologis": "etiologi",
    "etiologiska": "etiologisk",
    "etiologiskare": "etiologisk",
    "etiologiskares": "etiologisk",
    "etiologiskas": "etiologisk",
    "etiologiskast": "etiologisk",
    "etiologiskaste": "etiologisk",
    "etiologiskastes": "etiologisk",
    "etiologiskasts": "etiologisk",
    "etiologiske": "etiologisk",
    "etiologiskes": "etiologisk",
    "etiologisks": "etiologisk",
    "etiologiskt": "etiologisk",
    "etiologiskts": "etiologisk",
    "etiopen": "etiop",
    "etiopens": "etiop",
    "etioper": "etiop",
    "etioperna": "etiop",
    "etiopernas": "etiop",
    "etiopers": "etiop",
    "etiopiern": "etiopier",
    "etiopierna": "etiopier",
    "etiopiernas": "etiopier",
    "etiopierns": "etiopier",
    "etiopiers": "etiopier",
    "etiopisk": "etiopiska",
    "etiopiska": "etiopisk",
    "etiopiskan": "etiopiska",
    "etiopiskans": "etiopiska",
    "etiopiskare": "etiopisk",
    "etiopiskares": "etiopisk",
    "etiopiskas": "etiopiska",
    "etiopiskast": "etiopisk",
    "etiopiskaste": "etiopisk",
    "etiopiskastes": "etiopisk",
    "etiopiskasts": "etiopisk",
    "etiopiske": "etiopiska",
    "etiopiskes": "etiopisk",
    "etiopiskor": "etiopiska",
    "etiopiskorna": "etiopiska",
    "etiopiskornas": "etiopiska",
    "etiopiskors": "etiopiska",
    "etiopisks": "etiopisk",
    "etiopiskt": "etiopisk",
    "etiopiskts": "etiopisk",
    "etiops": "etiop",
    "etiska": "etisk",
    "etiskare": "etisk",
    "etiskares": "etisk",
    "etiskas": "etisk",
    "etiskast": "etisk",
    "etiskaste": "etisk",
    "etiskastes": "etisk",
    "etiskasts": "etisk",
    "etiske": "etisk",
    "etiskes": "etisk",
    "etisks": "etisk",
    "etiskt": "etisk",
    "etiskts": "etisk",
    "etniciteten": "etnicitet",
    "etnicitetens": "etnicitet",
    "etniciteter": "etnicitet",
    "etniciteterna": "etnicitet",
    "etniciteternas": "etnicitet",
    "etniciteters": "etnicitet",
    "etnicitets": "etnicitet",
    "etniska": "etnisk",
    "etniskare": "etnisk",
    "etniskares": "etnisk",
    "etniskas": "etnisk",
    "etniskast": "etnisk",
    "etniskaste": "etnisk",
    "etniskastes": "etnisk",
    "etniskasts": "etnisk",
    "etniske": "etnisk",
    "etniskes": "etnisk",
    "etnisks": "etnisk",
    "etniskt": "etnisk",
    "etniskts": "etnisk",
    "etnocentriska": "etnocentrisk",
    "etnocentriskare": "etnocentrisk",
    "etnocentriskares": "etnocentrisk",
    "etnocentriskas": "etnocentrisk",
    "etnocentriskast": "etnocentrisk",
    "etnocentriskaste": "etnocentrisk",
    "etnocentriskastes": "etnocentrisk",
    "etnocentriskasts": "etnocentrisk",
    "etnocentriske": "etnocentrisk",
    "etnocentriskes": "etnocentrisk",
    "etnocentrisks": "etnocentrisk",
    "etnocentriskt": "etnocentrisk",
    "etnocentriskts": "etnocentrisk",
    "etnocentrismen": "etnocentrism",
    "etnocentrismens": "etnocentrism",
    "etnocentrismer": "etnocentrism",
    "etnocentrismerna": "etnocentrism",
    "etnocentrismernas": "etnocentrism",
    "etnocentrismers": "etnocentrism",
    "etnocentrisms": "etnocentrism",
    "etnografen": "etnograf",
    "etnografens": "etnograf",
    "etnografer": "etnograf",
    "etnograferna": "etnograf",
    "etnografernas": "etnograf",
    "etnografers": "etnograf",
    "etnografien": "etnografi",
    "etnografiens": "etnografi",
    "etnografin": "etnografi",
    "etnografins": "etnografi",
    "etnografis": "etnografi",
    "etnografiska": "etnografisk",
    "etnografiskare": "etnografisk",
    "etnografiskares": "etnografisk",
    "etnografiskas": "etnografisk",
    "etnografiskast": "etnografisk",
    "etnografiskaste": "etnografisk",
    "etnografiskastes": "etnografisk",
    "etnografiskasts": "etnografisk",
    "etnografiske": "etnografisk",
    "etnografiskes": "etnografisk",
    "etnografisks": "etnografisk",
    "etnografiskt": "etnografisk",
    "etnografiskts": "etnografisk",
    "etnografs": "etnograf",
    "etnologen": "etnolog",
    "etnologens": "etnolog",
    "etnologer": "etnolog",
    "etnologerna": "etnolog",
    "etnologernas": "etnolog",
    "etnologers": "etnolog",
    "etnologien": "etnologi",
    "etnologiens": "etnologi",
    "etnologin": "etnologi",
    "etnologins": "etnologi",
    "etnologis": "etnologi",
    "etnologiska": "etnologisk",
    "etnologiskare": "etnologisk",
    "etnologiskares": "etnologisk",
    "etnologiskas": "etnologisk",
    "etnologiskast": "etnologisk",
    "etnologiskaste": "etnologisk",
    "etnologiskastes": "etnologisk",
    "etnologiskasts": "etnologisk",
    "etnologiske": "etnologisk",
    "etnologiskes": "etnologisk",
    "etnologisks": "etnologisk",
    "etnologiskt": "etnologisk",
    "etnologiskts": "etnologisk",
    "etnologs": "etnolog",
    "etologen": "etolog",
    "etologens": "etolog",
    "etologer": "etolog",
    "etologerna": "etolog",
    "etologernas": "etolog",
    "etologers": "etolog",
    "etologien": "etologi",
    "etologiens": "etologi",
    "etologin": "etologi",
    "etologins": "etologi",
    "etologis": "etologi",
    "etologiska": "etologisk",
    "etologiskare": "etologisk",
    "etologiskares": "etologisk",
    "etologiskas": "etologisk",
    "etologiskast": "etologisk",
    "etologiskaste": "etologisk",
    "etologiskastes": "etologisk",
    "etologiskasts": "etologisk",
    "etologiske": "etologisk",
    "etologiskes": "etologisk",
    "etologisks": "etologisk",
    "etologiskt": "etologisk",
    "etologiskts": "etologisk",
    "etologs": "etolog",
    "etrar": "eter",
    "etrarna": "eter",
    "etrarnas": "eter",
    "etrars": "eter",
    "etrusken": "etrusk",
    "etruskens": "etrusk",
    "etrusker": "etrusk",
    "etruskern": "etrusker",
    "etruskerna": "etrusker",
    "etruskernas": "etrusker",
    "etruskerns": "etrusker",
    "etruskers": "etrusker",
    "etruskisk": "etruskiska",
    "etruskiska": "etruskisk",
    "etruskiskan": "etruskiska",
    "etruskiskans": "etruskiska",
    "etruskiskare": "etruskisk",
    "etruskiskares": "etruskisk",
    "etruskiskas": "etruskiska",
    "etruskiskast": "etruskisk",
    "etruskiskaste": "etruskisk",
    "etruskiskastes": "etruskisk",
    "etruskiskasts": "etruskisk",
    "etruskiske": "etruskiska",
    "etruskiskes": "etruskisk",
    "etruskiskor": "etruskiska",
    "etruskiskorna": "etruskiska",
    "etruskiskornas": "etruskiska",
    "etruskiskors": "etruskiska",
    "etruskisks": "etruskisk",
    "etruskiskt": "etruskisk",
    "etruskiskts": "etruskisk",
    "etruskologien": "etruskologi",
    "etruskologiens": "etruskologi",
    "etruskologin": "etruskologi",
    "etruskologins": "etruskologi",
    "etruskologis": "etruskologi",
    "etrusks": "etrusk",
    "ets": "etsa",
    "etsad": "etsa",
    "etsade": "etsa",
    "etsades": "etsa",
    "etsads": "etsa",
    "etsande": "etsa",
    "etsanden": "etsande",
    "etsandena": "etsande",
    "etsandenas": "etsande",
    "etsandens": "etsande",
    "etsandes": "etsande",
    "etsandet": "etsande",
    "etsandets": "etsande",
    "etsar": "etsa",
    "etsas": "etsa",
    "etsat": "etsa",
    "etsats": "etsa",
    "etsmedels": "etsmedel",
    "etsmedlen": "etsmedel",
    "etsmedlens": "etsmedel",
    "etsmedlet": "etsmedel",
    "etsmedlets": "etsmedel",
    "etsningar": "etsning",
    "etsningarna": "etsning",
    "etsningarnas": "etsning",
    "etsningars": "etsning",
    "etsningen": "etsning",
    "etsningens": "etsning",
    "etsnings": "etsning",
    "ett": "en",
    "ettan": "etta",
    "ettans": "etta",
    "ettas": "etta",
    "ettdera": "endera",
    "ettderas": "endera",
    "ettermyr": "ettermyra",
    "ettermyran": "ettermyra",
    "ettermyrans": "ettermyra",
    "ettermyras": "ettermyra",
    "ettermyre": "ettermyra",
    "ettermyror": "ettermyra",
    "ettermyrorna": "ettermyra",
    "ettermyrornas": "ettermyra",
    "ettermyrors": "ettermyra",
    "ettermyrs": "ettermyra",
    "etters": "etter",
    "ettor": "etta",
    "ettorna": "etta",
    "ettornas": "etta",
    "ettors": "etta",
    "ettret": "etter",
    "ettrets": "etter",
    "ettriga": "ettrig",
    "ettrigare": "ettrig",
    "ettrigares": "ettrig",
    "ettrigas": "ettrig",
    "ettrigast": "ettrig",
    "ettrigaste": "ettrig",
    "ettrigastes": "ettrig",
    "ettrigasts": "ettrig",
    "ettrige": "ettrig",
    "ettriges": "ettrig",
    "ettrigheten": "ettrighet",
    "ettrighetens": "ettrighet",
    "ettrighets": "ettrighet",
    "ettrigs": "ettrig",
    "ettrigt": "ettrig",
    "ettrigts": "ettrig",
    "ettrumslägenheten": "ettrumslägenhet",
    "ettrumslägenhetens": "ettrumslägenhet",
    "ettrumslägenheter": "ettrumslägenhet",
    "ettrumslägenheterna": "ettrumslägenhet",
    "ettrumslägenheternas": "ettrumslägenhet",
    "ettrumslägenheters": "ettrumslägenhet",
    "ettrumslägenhets": "ettrumslägenhet",
    "etts": "en",
    "ettsnårets": "ettsnåret",
    "ettstrukens": "ettstruken",
    "ettstruket": "ettstruken",
    "ettstrukets": "ettstruken",
    "ettstrukna": "ettstruken",
    "ettstruknare": "ettstruken",
    "ettstruknares": "ettstruken",
    "ettstruknas": "ettstruken",
    "ettstruknast": "ettstruken",
    "ettstruknaste": "ettstruken",
    "ettstruknastes": "ettstruken",
    "ettstruknasts": "ettstruken",
    "ettstrukne": "ettstruken",
    "ettstruknes": "ettstruken",
    "ettåriga": "ettårig",
    "ettårigas": "ettårig",
    "ettårige": "ettårig",
    "ettåriges": "ettårig",
    "ettårigs": "ettårig",
    "ettårigt": "ettårig",
    "ettårigts": "ettårig",
    "ettåringar": "ettåring",
    "ettåringarna": "ettåring",
    "ettåringarnas": "ettåring",
    "ettåringars": "ettåring",
    "ettåringen": "ettåring",
    "ettåringens": "ettåring",
    "ettårings": "ettåring",
    "ettöringar": "ettöring",
    "ettöringarna": "ettöring",
    "ettöringarnas": "ettöring",
    "ettöringars": "ettöring",
    "ettöringen": "ettöring",
    "ettöringens": "ettöring",
    "ettörings": "ettöring",
    "etuien": "etui",
    "etuiens": "etui",
    "etuier": "etui",
    "etuierna": "etui",
    "etuiernas": "etui",
    "etuiers": "etui",
    "etuiet": "etui",
    "etuiets": "etui",
    "etuin": "etui",
    "etuina": "etui",
    "etuinas": "etui",
    "etuins": "etui",
    "etuis": "etui",
    "etuit": "etui",
    "etuits": "etui",
    "etyden": "etyd",
    "etydens": "etyd",
    "etyder": "etyd",
    "etyderna": "etyd",
    "etydernas": "etyd",
    "etyders": "etyd",
    "etyds": "etyd",
    "etylalkoholen": "etylalkohol",
    "etylalkoholens": "etylalkohol",
    "etylalkohols": "etylalkohol",
    "etylen": "etyl",
    "etylenen": "etylen",
    "etylenens": "etylen",
    "etylenet": "etylen",
    "etylenets": "etylen",
    "etylens": "etylen",
    "etyls": "etyl",
    "etymologen": "etymolog",
    "etymologens": "etymolog",
    "etymologer": "etymolog",
    "etymologerna": "etymolog",
    "etymologernas": "etymolog",
    "etymologers": "etymolog",
    "etymologien": "etymologi",
    "etymologiens": "etymologi",
    "etymologier": "etymologi",
    "etymologierna": "etymologi",
    "etymologiernas": "etymologi",
    "etymologiers": "etymologi",
    "etymologin": "etymologi",
    "etymologins": "etymologi",
    "etymologis": "etymologi",
    "etymologiserad": "etymologisera",
    "etymologiserade": "etymologisera",
    "etymologiserades": "etymologisera",
    "etymologiserads": "etymologisera",
    "etymologiserande": "etymologisera",
    "etymologiseranden": "etymologiserande",
    "etymologiserandena": "etymologiserande",
    "etymologiserandenas": "etymologiserande",
    "etymologiserandens": "etymologiserande",
    "etymologiserandes": "etymologiserande",
    "etymologiserandet": "etymologiserande",
    "etymologiserandets": "etymologiserande",
    "etymologiserar": "etymologisera",
    "etymologiseras": "etymologisera",
    "etymologiserat": "etymologisera",
    "etymologiserats": "etymologisera",
    "etymologiserbara": "etymologiserbar",
    "etymologiserbarare": "etymologiserbar",
    "etymologiserbarares": "etymologiserbar",
    "etymologiserbaras": "etymologiserbar",
    "etymologiserbarast": "etymologiserbar",
    "etymologiserbaraste": "etymologiserbar",
    "etymologiserbarastes": "etymologiserbar",
    "etymologiserbarasts": "etymologiserbar",
    "etymologiserbare": "etymologiserbar",
    "etymologiserbares": "etymologiserbar",
    "etymologiserbarheten": "etymologiserbarhet",
    "etymologiserbarhetens": "etymologiserbarhet",
    "etymologiserbarhets": "etymologiserbarhet",
    "etymologiserbars": "etymologiserbar",
    "etymologiserbart": "etymologiserbar",
    "etymologiserbarts": "etymologiserbar",
    "etymologiseringar": "etymologisering",
    "etymologiseringarna": "etymologisering",
    "etymologiseringarnas": "etymologisering",
    "etymologiseringars": "etymologisering",
    "etymologiseringen": "etymologisering",
    "etymologiseringens": "etymologisering",
    "etymologiserings": "etymologisering",
    "etymologiska": "etymologisk",
    "etymologiskare": "etymologisk",
    "etymologiskares": "etymologisk",
    "etymologiskas": "etymologisk",
    "etymologiskast": "etymologisk",
    "etymologiskaste": "etymologisk",
    "etymologiskastes": "etymologisk",
    "etymologiskasts": "etymologisk",
    "etymologiske": "etymologisk",
    "etymologiskes": "etymologisk",
    "etymologisks": "etymologisk",
    "etymologiskt": "etymologisk",
    "etymologiskts": "etymologisk",
    "etymologs": "etymolog",
    "etynet": "etyn",
    "etynets": "etyn",
    "etyns": "etyn",
    "eudemonismen": "eudemonism",
    "eudemonismens": "eudemonism",
    "eudemonismer": "eudemonism",
    "eudemonismerna": "eudemonism",
    "eudemonismernas": "eudemonism",
    "eudemonismers": "eudemonism",
    "eudemonisms": "eudemonism",
    "eufemismen": "eufemism",
    "eufemismens": "eufemism",
    "eufemismer": "eufemism",
    "eufemismerna": "eufemism",
    "eufemismernas": "eufemism",
    "eufemismers": "eufemism",
    "eufemisms": "eufemism",
    "eufemistiska": "eufemistisk",
    "eufemistiskas": "eufemistisk",
    "eufemistiske": "eufemistisk",
    "eufemistiskes": "eufemistisk",
    "eufemistisks": "eufemistisk",
    "eufemistiskt": "eufemistisk",
    "eufemistiskts": "eufemistisk",
    "eufonien": "eufoni",
    "eufoniens": "eufoni",
    "eufonier": "eufoni",
    "eufonierna": "eufoni",
    "eufoniernas": "eufoni",
    "eufoniers": "eufoni",
    "eufonin": "eufoni",
    "eufonins": "eufoni",
    "eufonis": "eufoni",
    "euforbi": "euforbia",
    "euforbian": "euforbia",
    "euforbians": "euforbia",
    "euforbias": "euforbia",
    "euforbie": "euforbia",
    "euforbior": "euforbia",
    "euforbiorna": "euforbia",
    "euforbiornas": "euforbia",
    "euforbiors": "euforbia",
    "euforbis": "euforbia",
    "euforien": "eufori",
    "euforiens": "eufori",
    "euforier": "eufori",
    "euforierna": "eufori",
    "euforiernas": "eufori",
    "euforiers": "eufori",
    "euforin": "eufori",
    "euforins": "eufori",
    "euforis": "eufori",
    "euforiska": "euforisk",
    "euforiskare": "euforisk",
    "euforiskares": "euforisk",
    "euforiskas": "euforisk",
    "euforiskast": "euforisk",
    "euforiskaste": "euforisk",
    "euforiskastes": "euforisk",
    "euforiskasts": "euforisk",
    "euforiske": "euforisk",
    "euforiskes": "euforisk",
    "euforisks": "euforisk",
    "euforiskt": "euforisk",
    "euforiskts": "euforisk",
    "eugeniken": "eugenik",
    "eugenikens": "eugenik",
    "eugeniks": "eugenik",
    "eukalyptusen": "eukalyptus",
    "eukalyptusens": "eukalyptus",
    "eukalyptusoljan": "eukalyptusolja",
    "eukalyptusoljans": "eukalyptusolja",
    "eukalyptusoljas": "eukalyptusolja",
    "eukalyptusolje": "eukalyptusolja",
    "euklidiska": "euklidisk",
    "euklidiskare": "euklidisk",
    "euklidiskares": "euklidisk",
    "euklidiskas": "euklidisk",
    "euklidiskast": "euklidisk",
    "euklidiskaste": "euklidisk",
    "euklidiskastes": "euklidisk",
    "euklidiskasts": "euklidisk",
    "euklidiske": "euklidisk",
    "euklidiskes": "euklidisk",
    "euklidisks": "euklidisk",
    "euklidiskt": "euklidisk",
    "euklidiskts": "euklidisk",
    "eumeniden": "eumenid",
    "eumenidens": "eumenid",
    "eumenider": "eumenid",
    "eumeniderna": "eumenid",
    "eumenidernas": "eumenid",
    "eumeniders": "eumenid",
    "eumenids": "eumenid",
    "eunucken": "eunuck",
    "eunuckens": "eunuck",
    "eunucker": "eunuck",
    "eunuckerna": "eunuck",
    "eunuckernas": "eunuck",
    "eunuckers": "eunuck",
    "eunucks": "eunuck",
    "eurasiern": "eurasier",
    "eurasierna": "eurasier",
    "eurasiernas": "eurasier",
    "eurasierns": "eurasier",
    "eurasiers": "eurasier",
    "eurasiska": "eurasisk",
    "eurasiskan": "eurasiska",
    "eurasiskans": "eurasiska",
    "eurasiskare": "eurasisk",
    "eurasiskares": "eurasisk",
    "eurasiskas": "eurasiska",
    "eurasiskast": "eurasisk",
    "eurasiskaste": "eurasisk",
    "eurasiskastes": "eurasisk",
    "eurasiskasts": "eurasisk",
    "eurasiske": "eurasiska",
    "eurasiskes": "eurasisk",
    "eurasiskor": "eurasiska",
    "eurasiskorna": "eurasiska",
    "eurasiskornas": "eurasiska",
    "eurasiskors": "eurasiska",
    "eurasisks": "eurasisk",
    "eurasiskt": "eurasisk",
    "eurasiskts": "eurasisk",
    "eurodollarn": "eurodollar",
    "eurodollarna": "eurodollar",
    "eurodollarnas": "eurodollar",
    "eurodollarns": "eurodollar",
    "eurodollars": "eurodollar",
    "euroislams": "euroislam",
    "eurokommunismen": "eurokommunism",
    "eurokommunismens": "eurokommunism",
    "eurokommunismer": "eurokommunism",
    "eurokommunismerna": "eurokommunism",
    "eurokommunismernas": "eurokommunism",
    "eurokommunismers": "eurokommunism",
    "eurokommunisms": "eurokommunism",
    "eurokommunistiska": "eurokommunistisk",
    "eurokommunistiskas": "eurokommunistisk",
    "eurokommunistiske": "eurokommunistisk",
    "eurokommunistiskes": "eurokommunistisk",
    "eurokommunistisks": "eurokommunistisk",
    "eurokommunistiskt": "eurokommunistisk",
    "eurokommunistiskts": "eurokommunistisk",
    "eurokrisen": "eurokris",
    "eurokrisens": "eurokris",
    "eurokriser": "eurokris",
    "eurokriserna": "eurokris",
    "eurokrisernas": "eurokris",
    "eurokrisers": "eurokris",
    "euron": "euro",
    "eurona": "euro",
    "euronas": "euro",
    "eurons": "euro",
    "europamästar": "europamästare",
    "europamästaren": "europamästare",
    "europamästarens": "europamästare",
    "europamästares": "europamästare",
    "europamästarna": "europamästare",
    "europamästarnas": "europamästare",
    "europamästerskapen": "europamästerskap",
    "europamästerskapens": "europamästerskap",
    "europamästerskapet": "europamästerskap",
    "europamästerskapets": "europamästerskap",
    "europamästerskaps": "europamästerskap",
    "europavägar": "europaväg",
    "europavägarna": "europaväg",
    "europavägarnas": "europaväg",
    "europavägars": "europaväg",
    "europavägen": "europaväg",
    "europavägens": "europaväg",
    "europavägs": "europaväg",
    "europeiserad": "europeisera",
    "europeiserade": "europeisera",
    "europeiserades": "europeisera",
    "europeiserads": "europeisera",
    "europeiserande": "europeisera",
    "europeiseranden": "europeiserande",
    "europeiserandena": "europeiserande",
    "europeiserandenas": "europeiserande",
    "europeiserandens": "europeiserande",
    "europeiserandes": "europeiserande",
    "europeiserandet": "europeiserande",
    "europeiserandets": "europeiserande",
    "europeiserar": "europeisera",
    "europeiseras": "europeisera",
    "europeiserat": "europeisera",
    "europeiserats": "europeisera",
    "europeiserbara": "europeiserbar",
    "europeiserbarare": "europeiserbar",
    "europeiserbarares": "europeiserbar",
    "europeiserbaras": "europeiserbar",
    "europeiserbarast": "europeiserbar",
    "europeiserbaraste": "europeiserbar",
    "europeiserbarastes": "europeiserbar",
    "europeiserbarasts": "europeiserbar",
    "europeiserbare": "europeiserbar",
    "europeiserbares": "europeiserbar",
    "europeiserbarheten": "europeiserbarhet",
    "europeiserbarhetens": "europeiserbarhet",
    "europeiserbarhets": "europeiserbarhet",
    "europeiserbars": "europeiserbar",
    "europeiserbart": "europeiserbar",
    "europeiserbarts": "europeiserbar",
    "europeiseringar": "europeisering",
    "europeiseringarna": "europeisering",
    "europeiseringarnas": "europeisering",
    "europeiseringars": "europeisering",
    "europeiseringen": "europeisering",
    "europeiseringens": "europeisering",
    "europeiserings": "europeisering",
    "europeiska": "europeisk",
    "europeiskan": "europeiska",
    "europeiskans": "europeiska",
    "europeiskare": "europeisk",
    "europeiskares": "europeisk",
    "europeiskas": "europeiska",
    "europeiskast": "europeisk",
    "europeiskaste": "europeisk",
    "europeiskastes": "europeisk",
    "europeiskasts": "europeisk",
    "europeiske": "europeiska",
    "europeiskes": "europeisk",
    "europeiskor": "europeiska",
    "europeiskorna": "europeiska",
    "europeiskornas": "europeiska",
    "europeiskors": "europeiska",
    "europeisks": "europeisk",
    "europeiskt": "europeisk",
    "europeiskts": "europeisk",
    "europida": "europid",
    "europidare": "europid",
    "europidares": "europid",
    "europidas": "europid",
    "europidast": "europid",
    "europidaste": "europid",
    "europidastes": "europid",
    "europidasts": "europid",
    "europide": "europid",
    "europiden": "europid",
    "europidens": "europid",
    "europider": "europid",
    "europiderna": "europid",
    "europidernas": "europid",
    "europiders": "europid",
    "europides": "europid",
    "europids": "europid",
    "europiums": "europium",
    "européen": "europé",
    "européens": "europé",
    "européer": "europé",
    "européerna": "europé",
    "européernas": "europé",
    "européers": "europé",
    "europén": "europé",
    "européns": "europé",
    "europés": "europé",
    "euros": "euro",
    "eurovalutan": "eurovaluta",
    "eurovalutans": "eurovaluta",
    "eurovalutas": "eurovaluta",
    "eurovisionen": "eurovision",
    "eurovisionens": "eurovision",
    "eurovisioner": "eurovision",
    "eurovisionerna": "eurovision",
    "eurovisionernas": "eurovision",
    "eurovisioners": "eurovision",
    "eurovisions": "eurovision",
    "eurytmien": "eurytmi",
    "eurytmiens": "eurytmi",
    "eurytmier": "eurytmi",
    "eurytmierna": "eurytmi",
    "eurytmiernas": "eurytmi",
    "eurytmiers": "eurytmi",
    "eurytmin": "eurytmi",
    "eurytmins": "eurytmi",
    "eurytmis": "eurytmi",
    "eutanasien": "eutanasi",
    "eutanasiens": "eutanasi",
    "eutanasin": "eutanasi",
    "eutanasins": "eutanasi",
    "eutanasis": "eutanasi",
    "eutrofa": "eutrof",
    "eutrofare": "eutrof",
    "eutrofares": "eutrof",
    "eutrofas": "eutrof",
    "eutrofast": "eutrof",
    "eutrofaste": "eutrof",
    "eutrofastes": "eutrof",
    "eutrofasts": "eutrof",
    "eutrofe": "eutrof",
    "eutrofes": "eutrof",
    "eutrofs": "eutrof",
    "eutroft": "eutrof",
    "eutrofts": "eutrof",
    "ev": "eva",
    "evakostymen": "evakostym",
    "evakostymens": "evakostym",
    "evakostymer": "evakostym",
    "evakostymerna": "evakostym",
    "evakostymernas": "evakostym",
    "evakostymers": "evakostym",
    "evakostyms": "evakostym",
    "evakuerad": "evakuera",
    "evakuerade": "evakuera",
    "evakuerades": "evakuera",
    "evakuerads": "evakuera",
    "evakuerande": "evakuera",
    "evakueranden": "evakuerande",
    "evakuerandena": "evakuerande",
    "evakuerandenas": "evakuerande",
    "evakuerandens": "evakuerande",
    "evakuerandes": "evakuerande",
    "evakuerandet": "evakuerande",
    "evakuerandets": "evakuerande",
    "evakuerar": "evakuera",
    "evakueras": "evakuera",
    "evakuerat": "evakuera",
    "evakuerats": "evakuera",
    "evakuerbara": "evakuerbar",
    "evakuerbarare": "evakuerbar",
    "evakuerbarares": "evakuerbar",
    "evakuerbaras": "evakuerbar",
    "evakuerbarast": "evakuerbar",
    "evakuerbaraste": "evakuerbar",
    "evakuerbarastes": "evakuerbar",
    "evakuerbarasts": "evakuerbar",
    "evakuerbare": "evakuerbar",
    "evakuerbares": "evakuerbar",
    "evakuerbarheten": "evakuerbarhet",
    "evakuerbarhetens": "evakuerbarhet",
    "evakuerbarhets": "evakuerbarhet",
    "evakuerbars": "evakuerbar",
    "evakuerbart": "evakuerbar",
    "evakuerbarts": "evakuerbar",
    "evakueringar": "evakuering",
    "evakueringarna": "evakuering",
    "evakueringarnas": "evakuering",
    "evakueringars": "evakuering",
    "evakueringen": "evakuering",
    "evakueringens": "evakuering",
    "evakuerings": "evakuering",
    "evaluerad": "evaluera",
    "evaluerade": "evaluera",
    "evaluerades": "evaluera",
    "evaluerads": "evaluera",
    "evaluerande": "evaluera",
    "evalueranden": "evaluerande",
    "evaluerandena": "evaluerande",
    "evaluerandenas": "evaluerande",
    "evaluerandens": "evaluerande",
    "evaluerandes": "evaluerande",
    "evaluerandet": "evaluerande",
    "evaluerandets": "evaluerande",
    "evaluerar": "evaluera",
    "evalueras": "evaluera",
    "evaluerat": "evaluera",
    "evaluerats": "evaluera",
    "evaluerbara": "evaluerbar",
    "evaluerbarare": "evaluerbar",
    "evaluerbarares": "evaluerbar",
    "evaluerbaras": "evaluerbar",
    "evaluerbarast": "evaluerbar",
    "evaluerbaraste": "evaluerbar",
    "evaluerbarastes": "evaluerbar",
    "evaluerbarasts": "evaluerbar",
    "evaluerbare": "evaluerbar",
    "evaluerbares": "evaluerbar",
    "evaluerbarheten": "evaluerbarhet",
    "evaluerbarhetens": "evaluerbarhet",
    "evaluerbarhets": "evaluerbarhet",
    "evaluerbars": "evaluerbar",
    "evaluerbart": "evaluerbar",
    "evaluerbarts": "evaluerbar",
    "evalueringar": "evaluering",
    "evalueringarna": "evaluering",
    "evalueringarnas": "evaluering",
    "evalueringars": "evaluering",
    "evalueringen": "evaluering",
    "evalueringens": "evaluering",
    "evaluerings": "evaluering",
    "evalverad": "evalvera",
    "evalverade": "evalvera",
    "evalverades": "evalvera",
    "evalverads": "evalvera",
    "evalverande": "evalvera",
    "evalveranden": "evalverande",
    "evalverandena": "evalverande",
    "evalverandenas": "evalverande",
    "evalverandens": "evalverande",
    "evalverandes": "evalverande",
    "evalverandet": "evalverande",
    "evalverandets": "evalverande",
    "evalverar": "evalvera",
    "evalveras": "evalvera",
    "evalverat": "evalvera",
    "evalverats": "evalvera",
    "evalverbara": "evalverbar",
    "evalverbarare": "evalverbar",
    "evalverbarares": "evalverbar",
    "evalverbaras": "evalverbar",
    "evalverbarast": "evalverbar",
    "evalverbaraste": "evalverbar",
    "evalverbarastes": "evalverbar",
    "evalverbarasts": "evalverbar",
    "evalverbare": "evalverbar",
    "evalverbares": "evalverbar",
    "evalverbarheten": "evalverbarhet",
    "evalverbarhetens": "evalverbarhet",
    "evalverbarhets": "evalverbarhet",
    "evalverbars": "evalverbar",
    "evalverbart": "evalverbar",
    "evalverbarts": "evalverbar",
    "evalveringar": "evalvering",
    "evalveringarna": "evalvering",
    "evalveringarnas": "evalvering",
    "evalveringars": "evalvering",
    "evalveringen": "evalvering",
    "evalveringens": "evalvering",
    "evalverings": "evalvering",
    "evan": "eva",
    "evangelie": "evangelium",
    "evangelieboken": "evangeliebok",
    "evangeliebokens": "evangeliebok",
    "evangelieboks": "evangeliebok",
    "evangelieböcker": "evangeliebok",
    "evangelieböckerna": "evangeliebok",
    "evangelieböckernas": "evangeliebok",
    "evangelieböckers": "evangeliebok",
    "evangelier": "evangelium",
    "evangelierna": "evangelium",
    "evangeliernas": "evangelium",
    "evangeliers": "evangelium",
    "evangeliet": "evangelium",
    "evangeliets": "evangelium",
    "evangelisationen": "evangelisation",
    "evangelisationens": "evangelisation",
    "evangelisationer": "evangelisation",
    "evangelisationerna": "evangelisation",
    "evangelisationernas": "evangelisation",
    "evangelisationers": "evangelisation",
    "evangelisations": "evangelisation",
    "evangeliserade": "evangelisera",
    "evangeliserades": "evangelisera",
    "evangeliserande": "evangelisera",
    "evangeliseranden": "evangeliserande",
    "evangeliserandena": "evangeliserande",
    "evangeliserandenas": "evangeliserande",
    "evangeliserandens": "evangeliserande",
    "evangeliserandes": "evangeliserande",
    "evangeliserandet": "evangeliserande",
    "evangeliserandets": "evangeliserande",
    "evangeliserar": "evangelisera",
    "evangeliseras": "evangelisera",
    "evangeliserat": "evangelisera",
    "evangeliserats": "evangelisera",
    "evangeliseringar": "evangelisering",
    "evangeliseringarna": "evangelisering",
    "evangeliseringarnas": "evangelisering",
    "evangeliseringars": "evangelisering",
    "evangeliseringen": "evangelisering",
    "evangeliseringens": "evangelisering",
    "evangeliserings": "evangelisering",
    "evangeliska": "evangelisk",
    "evangeliskare": "evangelisk",
    "evangeliskares": "evangelisk",
    "evangeliskas": "evangelisk",
    "evangeliskast": "evangelisk",
    "evangeliskaste": "evangelisk",
    "evangeliskastes": "evangelisk",
    "evangeliskasts": "evangelisk",
    "evangeliske": "evangelisk",
    "evangeliskes": "evangelisk",
    "evangelisks": "evangelisk",
    "evangeliskt": "evangelisk",
    "evangeliskts": "evangelisk",
    "evangelisten": "evangelist",
    "evangelistens": "evangelist",
    "evangelister": "evangelist",
    "evangelisterna": "evangelist",
    "evangelisternas": "evangelist",
    "evangelisters": "evangelist",
    "evangelists": "evangelist",
    "evangeliums": "evangelium",
    "evans": "eva",
    "evaporationen": "evaporation",
    "evaporationens": "evaporation",
    "evaporationer": "evaporation",
    "evaporationerna": "evaporation",
    "evaporationernas": "evaporation",
    "evaporationers": "evaporation",
    "evaporations": "evaporation",
    "evaporerad": "evaporera",
    "evaporerade": "evaporera",
    "evaporerades": "evaporera",
    "evaporerads": "evaporera",
    "evaporerande": "evaporera",
    "evaporeranden": "evaporerande",
    "evaporerandena": "evaporerande",
    "evaporerandenas": "evaporerande",
    "evaporerandens": "evaporerande",
    "evaporerandes": "evaporerande",
    "evaporerandet": "evaporerande",
    "evaporerandets": "evaporerande",
    "evaporerar": "evaporera",
    "evaporeras": "evaporera",
    "evaporerat": "evaporera",
    "evaporerats": "evaporera",
    "evaporerbara": "evaporerbar",
    "evaporerbarare": "evaporerbar",
    "evaporerbarares": "evaporerbar",
    "evaporerbaras": "evaporerbar",
    "evaporerbarast": "evaporerbar",
    "evaporerbaraste": "evaporerbar",
    "evaporerbarastes": "evaporerbar",
    "evaporerbarasts": "evaporerbar",
    "evaporerbare": "evaporerbar",
    "evaporerbares": "evaporerbar",
    "evaporerbarheten": "evaporerbarhet",
    "evaporerbarhetens": "evaporerbarhet",
    "evaporerbarhets": "evaporerbarhet",
    "evaporerbars": "evaporerbar",
    "evaporerbart": "evaporerbar",
    "evaporerbarts": "evaporerbar",
    "evaporeringar": "evaporering",
    "evaporeringarna": "evaporering",
    "evaporeringarnas": "evaporering",
    "evaporeringars": "evaporering",
    "evaporeringen": "evaporering",
    "evaporeringens": "evaporering",
    "evaporerings": "evaporering",
    "evas": "eva",
    "eve": "eva",
    "evems": "evem",
    "evenemangen": "evenemang",
    "evenemangens": "evenemang",
    "evenemanget": "evenemang",
    "evenemangets": "evenemang",
    "evenemangs": "evenemang",
    "eventualiteten": "eventualitet",
    "eventualitetens": "eventualitet",
    "eventualiteter": "eventualitet",
    "eventualiteterna": "eventualitet",
    "eventualiteternas": "eventualitet",
    "eventualiteters": "eventualitet",
    "eventualitets": "eventualitet",
    "eventuella": "eventuell",
    "eventuellas": "eventuell",
    "eventuelle": "eventuell",
    "eventuelles": "eventuell",
    "eventuells": "eventuell",
    "eventuellt": "eventuell",
    "eventuellts": "eventuell",
    "evergreenen": "evergreen",
    "evergreenens": "evergreen",
    "evergreens": "evergreen",
    "evergreensarna": "evergreen",
    "evergreensarnas": "evergreen",
    "evergreensen": "evergreen",
    "evergreensens": "evergreen",
    "evertebraten": "evertebrat",
    "evertebratens": "evertebrat",
    "evertebrater": "evertebrat",
    "evertebraterna": "evertebrat",
    "evertebraternas": "evertebrat",
    "evertebraters": "evertebrat",
    "evertebrats": "evertebrat",
    "evidensen": "evidens",
    "evidensens": "evidens",
    "evidenta": "evident",
    "evidentare": "evident",
    "evidentares": "evident",
    "evidentas": "evident",
    "evidentast": "evident",
    "evidentaste": "evident",
    "evidentastes": "evident",
    "evidentasts": "evident",
    "evidente": "evident",
    "evidentes": "evident",
    "evidents": "evident",
    "eviga": "evig",
    "evigare": "evig",
    "evigares": "evig",
    "evigas": "evig",
    "evigast": "evig",
    "evigaste": "evig",
    "evigastes": "evig",
    "evigasts": "evig",
    "evige": "evig",
    "eviges": "evig",
    "evigheten": "evighet",
    "evighetens": "evighet",
    "evigheter": "evighet",
    "evigheterna": "evighet",
    "evigheternas": "evighet",
    "evigheters": "evighet",
    "evighets": "evighet",
    "evighetsblom": "evighetsblomma",
    "evighetsblomman": "evighetsblomma",
    "evighetsblommans": "evighetsblomma",
    "evighetsblommas": "evighetsblomma",
    "evighetsblomme": "evighetsblomma",
    "evighetsblommor": "evighetsblomma",
    "evighetsblommorna": "evighetsblomma",
    "evighetsblommornas": "evighetsblomma",
    "evighetsblommors": "evighetsblomma",
    "evighetsbloms": "evighetsblomma",
    "evighetsfilterna": "evighetsfilter",
    "evighetsfilternas": "evighetsfilter",
    "evighetsfilters": "evighetsfilter",
    "evighetsfiltren": "evighetsfilter",
    "evighetsfiltrens": "evighetsfilter",
    "evighetsfiltret": "evighetsfilter",
    "evighetsfiltrets": "evighetsfilter",
    "evighetskalendern": "evighetskalender",
    "evighetskalenderns": "evighetskalender",
    "evighetskalenders": "evighetskalender",
    "evighetskalendrar": "evighetskalender",
    "evighetskalendrarna": "evighetskalender",
    "evighetskalendrarnas": "evighetskalender",
    "evighetskalendrars": "evighetskalender",
    "evighetsmaskinen": "evighetsmaskin",
    "evighetsmaskinens": "evighetsmaskin",
    "evighetsmaskiner": "evighetsmaskin",
    "evighetsmaskinerna": "evighetsmaskin",
    "evighetsmaskinernas": "evighetsmaskin",
    "evighetsmaskiners": "evighetsmaskin",
    "evighetsmaskins": "evighetsmaskin",
    "evigs": "evig",
    "evigt": "evig",
    "evigts": "evig",
    "evinnerliga": "evinnerlig",
    "evinnerligare": "evinnerlig",
    "evinnerligares": "evinnerlig",
    "evinnerligas": "evinnerlig",
    "evinnerligast": "evinnerlig",
    "evinnerligaste": "evinnerlig",
    "evinnerligastes": "evinnerlig",
    "evinnerligasts": "evinnerlig",
    "evinnerlige": "evinnerlig",
    "evinnerliges": "evinnerlig",
    "evinnerligheten": "evinnerlighet",
    "evinnerlighetens": "evinnerlighet",
    "evinnerlighets": "evinnerlighet",
    "evinnerligs": "evinnerlig",
    "evinnerligt": "evinnerlig",
    "evinnerligts": "evinnerlig",
    "evolutionen": "evolution",
    "evolutionens": "evolution",
    "evolutioner": "evolution",
    "evolutionerna": "evolution",
    "evolutionernas": "evolution",
    "evolutioners": "evolution",
    "evolutionismen": "evolutionism",
    "evolutionismens": "evolutionism",
    "evolutionismer": "evolutionism",
    "evolutionismerna": "evolutionism",
    "evolutionismernas": "evolutionism",
    "evolutionismers": "evolutionism",
    "evolutionisms": "evolutionism",
    "evolutionisten": "evolutionist",
    "evolutionistens": "evolutionist",
    "evolutionister": "evolutionist",
    "evolutionisterna": "evolutionist",
    "evolutionisternas": "evolutionist",
    "evolutionisters": "evolutionist",
    "evolutionistiska": "evolutionistisk",
    "evolutionistiskas": "evolutionistisk",
    "evolutionistiske": "evolutionistisk",
    "evolutionistiskes": "evolutionistisk",
    "evolutionistisks": "evolutionistisk",
    "evolutionistiskt": "evolutionistisk",
    "evolutionistiskts": "evolutionistisk",
    "evolutionists": "evolutionist",
    "evolutions": "evolution",
    "evolutionsbiologen": "evolutionsbiolog",
    "evolutionsbiologens": "evolutionsbiolog",
    "evolutionsbiologer": "evolutionsbiolog",
    "evolutionsbiologerna": "evolutionsbiolog",
    "evolutionsbiologernas": "evolutionsbiolog",
    "evolutionsbiologers": "evolutionsbiolog",
    "evolutionsbiologs": "evolutionsbiolog",
    "evolutionsforskningar": "evolutionsforskning",
    "evolutionsforskningarna": "evolutionsforskning",
    "evolutionsforskningarnas": "evolutionsforskning",
    "evolutionsforskningars": "evolutionsforskning",
    "evolutionsforskningen": "evolutionsforskning",
    "evolutionsforskningens": "evolutionsforskning",
    "evolutionsforsknings": "evolutionsforskning",
    "evolutionsmekanismen": "evolutionsmekanism",
    "evolutionsmekanismens": "evolutionsmekanism",
    "evolutionsmekanismer": "evolutionsmekanism",
    "evolutionsmekanismerna": "evolutionsmekanism",
    "evolutionsmekanismernas": "evolutionsmekanism",
    "evolutionsmekanismers": "evolutionsmekanism",
    "evolutionsmekanisms": "evolutionsmekanism",
    "evolutionsmässiga": "evolutionsmässig",
    "evolutionsmässigare": "evolutionsmässig",
    "evolutionsmässigares": "evolutionsmässig",
    "evolutionsmässigas": "evolutionsmässig",
    "evolutionsmässigast": "evolutionsmässig",
    "evolutionsmässigaste": "evolutionsmässig",
    "evolutionsmässigastes": "evolutionsmässig",
    "evolutionsmässigasts": "evolutionsmässig",
    "evolutionsmässige": "evolutionsmässig",
    "evolutionsmässiges": "evolutionsmässig",
    "evolutionsmässigheten": "evolutionsmässighet",
    "evolutionsmässighetens": "evolutionsmässighet",
    "evolutionsmässighets": "evolutionsmässighet",
    "evolutionsmässigs": "evolutionsmässig",
    "evolutionsmässigt": "evolutionsmässig",
    "evolutionsmässigts": "evolutionsmässig",
    "evolutionsteorien": "evolutionsteori",
    "evolutionsteoriens": "evolutionsteori",
    "evolutionsteorier": "evolutionsteori",
    "evolutionsteorierna": "evolutionsteori",
    "evolutionsteoriernas": "evolutionsteori",
    "evolutionsteoriers": "evolutionsteori",
    "evolutionsteorin": "evolutionsteori",
    "evolutionsteorins": "evolutionsteori",
    "evolutionsteoris": "evolutionsteori",
    "evolutionära": "evolutionär",
    "evolutionärare": "evolutionär",
    "evolutionärares": "evolutionär",
    "evolutionäras": "evolutionär",
    "evolutionärast": "evolutionär",
    "evolutionäraste": "evolutionär",
    "evolutionärastes": "evolutionär",
    "evolutionärasts": "evolutionär",
    "evolutionäre": "evolutionär",
    "evolutionäres": "evolutionär",
    "evolutionärs": "evolutionär",
    "evolutionärt": "evolutionär",
    "evolutionärts": "evolutionär",
    "evor": "eva",
    "evornas": "eva",
    "evs": "eva",
    "evärdliga": "evärdlig",
    "evärdligare": "evärdlig",
    "evärdligares": "evärdlig",
    "evärdligas": "evärdlig",
    "evärdligast": "evärdlig",
    "evärdligaste": "evärdlig",
    "evärdligastes": "evärdlig",
    "evärdligasts": "evärdlig",
    "evärdlige": "evärdlig",
    "evärdliges": "evärdlig",
    "evärdligheten": "evärdlighet",
    "evärdlighetens": "evärdlighet",
    "evärdlighets": "evärdlighet",
    "evärdligs": "evärdlig",
    "evärdligt": "evärdlig",
    "evärdligts": "evärdlig",
    "exabyten": "exabyte",
    "exabytena": "exabyte",
    "exabytenas": "exabyte",
    "exabytens": "exabyte",
    "exabytes": "exabyte",
    "exakta": "exakt",
    "exaktare": "exakt",
    "exaktares": "exakt",
    "exaktas": "exakt",
    "exaktast": "exakt",
    "exaktaste": "exakt",
    "exaktastes": "exakt",
    "exaktasts": "exakt",
    "exakte": "exakt",
    "exaktes": "exakt",
    "exaktheten": "exakthet",
    "exakthetens": "exakthet",
    "exaktheter": "exakthet",
    "exaktheterna": "exakthet",
    "exaktheternas": "exakthet",
    "exaktheters": "exakthet",
    "exakthets": "exakthet",
    "exakts": "exakt",
    "exaltationen": "exaltation",
    "exaltationens": "exaltation",
    "exaltationer": "exaltation",
    "exaltationerna": "exaltation",
    "exaltationernas": "exaltation",
    "exaltationers": "exaltation",
    "exaltations": "exaltation",
    "exalterade": "exalterad",
    "exalterades": "exalterad",
    "exalterads": "exalterad",
    "exalterat": "exalterad",
    "exalterats": "exalterad",
    "examens": "examen",
    "examensarbeten": "examensarbete",
    "examensarbetena": "examensarbete",
    "examensarbetenas": "examensarbete",
    "examensarbetens": "examensarbete",
    "examensarbetes": "examensarbete",
    "examensarbetet": "examensarbete",
    "examensarbetets": "examensarbete",
    "examensarbets": "examensarbete",
    "examensfrågan": "examensfråga",
    "examensfrågans": "examensfråga",
    "examensfrågas": "examensfråga",
    "examensfråge": "examensfråga",
    "examensfrågor": "examensfråga",
    "examensfrågorna": "examensfråga",
    "examensfrågornas": "examensfråga",
    "examensfrågors": "examensfråga",
    "examensuppgiften": "examensuppgift",
    "examensuppgiftens": "examensuppgift",
    "examensuppgifter": "examensuppgift",
    "examensuppgifterna": "examensuppgift",
    "examensuppgifternas": "examensuppgift",
    "examensuppgifters": "examensuppgift",
    "examensuppgifts": "examensuppgift",
    "examina": "examen",
    "examinanden": "examinand",
    "examinandens": "examinand",
    "examinander": "examinand",
    "examinanderna": "examinand",
    "examinandernas": "examinand",
    "examinanders": "examinand",
    "examinands": "examinand",
    "examinas": "examen",
    "examinationen": "examination",
    "examinationens": "examination",
    "examinationer": "examination",
    "examinationerna": "examination",
    "examinationernas": "examination",
    "examinationers": "examination",
    "examinations": "examination",
    "examinatorer": "examinator",
    "examinatorerna": "examinator",
    "examinatorernas": "examinator",
    "examinatorers": "examinator",
    "examinatorier": "examinatorium",
    "examinatorierna": "examinatorium",
    "examinatoriernas": "examinatorium",
    "examinatoriers": "examinatorium",
    "examinatoriet": "examinatorium",
    "examinatoriets": "examinatorium",
    "examinatoriumet": "examinatorium",
    "examinatoriumets": "examinatorium",
    "examinatoriums": "examinatorium",
    "examinatorn": "examinator",
    "examinatorns": "examinator",
    "examinators": "examinator",
    "examinerad": "examinera",
    "examinerade": "examinera",
    "examinerades": "examinera",
    "examinerads": "examinera",
    "examinerande": "examinera",
    "examineranden": "examinerande",
    "examinerandena": "examinerande",
    "examinerandenas": "examinerande",
    "examinerandens": "examinerande",
    "examinerandes": "examinerande",
    "examinerandet": "examinerande",
    "examinerandets": "examinerande",
    "examinerar": "examinera",
    "examineras": "examinera",
    "examinerat": "examinera",
    "examinerats": "examinera",
    "examinerbara": "examinerbar",
    "examinerbarare": "examinerbar",
    "examinerbarares": "examinerbar",
    "examinerbaras": "examinerbar",
    "examinerbarast": "examinerbar",
    "examinerbaraste": "examinerbar",
    "examinerbarastes": "examinerbar",
    "examinerbarasts": "examinerbar",
    "examinerbare": "examinerbar",
    "examinerbares": "examinerbar",
    "examinerbarheten": "examinerbarhet",
    "examinerbarhetens": "examinerbarhet",
    "examinerbarhets": "examinerbarhet",
    "examinerbars": "examinerbar",
    "examinerbart": "examinerbar",
    "examinerbarts": "examinerbar",
    "examineringar": "examinering",
    "examineringarna": "examinering",
    "examineringarnas": "examinering",
    "examineringars": "examinering",
    "examineringen": "examinering",
    "examineringens": "examinering",
    "examinerings": "examinering",
    "exantemen": "exantem",
    "exantemens": "exantem",
    "exantemet": "exantem",
    "exantemets": "exantem",
    "exantems": "exantem",
    "excellensen": "excellens",
    "excellensens": "excellens",
    "excellenser": "excellens",
    "excellenserna": "excellens",
    "excellensernas": "excellens",
    "excellensers": "excellens",
    "excellenta": "excellent",
    "excellentare": "excellent",
    "excellentares": "excellent",
    "excellentas": "excellent",
    "excellentast": "excellent",
    "excellentaste": "excellent",
    "excellentastes": "excellent",
    "excellentasts": "excellent",
    "excellente": "excellent",
    "excellentes": "excellent",
    "excellents": "excellent",
    "excellerade": "excellera",
    "excellerades": "excellera",
    "excellerande": "excellera",
    "excelleranden": "excellerande",
    "excellerandena": "excellerande",
    "excellerandenas": "excellerande",
    "excellerandens": "excellerande",
    "excellerandes": "excellerande",
    "excellerandet": "excellerande",
    "excellerandets": "excellerande",
    "excellerar": "excellera",
    "excelleras": "excellera",
    "excellerat": "excellera",
    "excellerats": "excellera",
    "excelleringar": "excellering",
    "excelleringarna": "excellering",
    "excelleringarnas": "excellering",
    "excelleringars": "excellering",
    "excelleringen": "excellering",
    "excelleringens": "excellering",
    "excellerings": "excellering",
    "excentern": "excenter",
    "excenterns": "excenter",
    "excenters": "excenter",
    "excentrar": "excenter",
    "excentrarna": "excenter",
    "excentrarnas": "excenter",
    "excentrars": "excenter",
    "excentriciteten": "excentricitet",
    "excentricitetens": "excentricitet",
    "excentriciteter": "excentricitet",
    "excentriciteterna": "excentricitet",
    "excentriciteternas": "excentricitet",
    "excentriciteters": "excentricitet",
    "excentricitets": "excentricitet",
    "excentrikern": "excentriker",
    "excentrikerna": "excentriker",
    "excentrikernas": "excentriker",
    "excentrikerns": "excentriker",
    "excentrikers": "excentriker",
    "excentriska": "excentrisk",
    "excentriskare": "excentrisk",
    "excentriskares": "excentrisk",
    "excentriskas": "excentrisk",
    "excentriskast": "excentrisk",
    "excentriskaste": "excentrisk",
    "excentriskastes": "excentrisk",
    "excentriskasts": "excentrisk",
    "excentriske": "excentrisk",
    "excentriskes": "excentrisk",
    "excentrisks": "excentrisk",
    "excentriskt": "excentrisk",
    "excentriskts": "excentrisk",
    "exceptionella": "exceptionell",
    "exceptionellare": "exceptionell",
    "exceptionellares": "exceptionell",
    "exceptionellas": "exceptionell",
    "exceptionellast": "exceptionell",
    "exceptionellaste": "exceptionell",
    "exceptionellastes": "exceptionell",
    "exceptionellasts": "exceptionell",
    "exceptionelle": "exceptionell",
    "exceptionelles": "exceptionell",
    "exceptionells": "exceptionell",
    "exceptionellt": "exceptionell",
    "exceptionellts": "exceptionell",
    "excerperad": "excerpera",
    "excerperade": "excerpera",
    "excerperades": "excerpera",
    "excerperads": "excerpera",
    "excerperande": "excerpera",
    "excerperanden": "excerperande",
    "excerperandena": "excerperande",
    "excerperandenas": "excerperande",
    "excerperandens": "excerperande",
    "excerperandes": "excerperande",
    "excerperandet": "excerperande",
    "excerperandets": "excerperande",
    "excerperar": "excerpera",
    "excerperas": "excerpera",
    "excerperat": "excerpera",
    "excerperats": "excerpera",
    "excerperbara": "excerperbar",
    "excerperbarare": "excerperbar",
    "excerperbarares": "excerperbar",
    "excerperbaras": "excerperbar",
    "excerperbarast": "excerperbar",
    "excerperbaraste": "excerperbar",
    "excerperbarastes": "excerperbar",
    "excerperbarasts": "excerperbar",
    "excerperbare": "excerperbar",
    "excerperbares": "excerperbar",
    "excerperbarheten": "excerperbarhet",
    "excerperbarhetens": "excerperbarhet",
    "excerperbarhets": "excerperbarhet",
    "excerperbars": "excerperbar",
    "excerperbart": "excerperbar",
    "excerperbarts": "excerperbar",
    "excerperingar": "excerpering",
    "excerperingarna": "excerpering",
    "excerperingarnas": "excerpering",
    "excerperingars": "excerpering",
    "excerperingen": "excerpering",
    "excerperingens": "excerpering",
    "excerperings": "excerpering",
    "excerpisten": "excerpist",
    "excerpistens": "excerpist",
    "excerpister": "excerpist",
    "excerpisterna": "excerpist",
    "excerpisternas": "excerpist",
    "excerpisters": "excerpist",
    "excerpists": "excerpist",
    "excerpten": "excerpt",
    "excerptens": "excerpt",
    "excerpter": "excerpt",
    "excerpterna": "excerpt",
    "excerpternas": "excerpt",
    "excerpters": "excerpt",
    "excerpts": "excerpt",
    "excessen": "excess",
    "excessens": "excess",
    "excesser": "excess",
    "excesserna": "excess",
    "excessernas": "excess",
    "excessers": "excess",
    "excisionen": "excision",
    "excisionens": "excision",
    "excisioner": "excision",
    "excisionerna": "excision",
    "excisionernas": "excision",
    "excisioners": "excision",
    "excisions": "excision",
    "excitationen": "excitation",
    "excitationens": "excitation",
    "excitationer": "excitation",
    "excitationerna": "excitation",
    "excitationernas": "excitation",
    "excitationers": "excitation",
    "excitations": "excitation",
    "exciterad": "excitera",
    "exciterade": "excitera",
    "exciterades": "excitera",
    "exciterads": "excitera",
    "exciterande": "excitera",
    "exciteranden": "exciterande",
    "exciterandena": "exciterande",
    "exciterandenas": "exciterande",
    "exciterandens": "exciterande",
    "exciterandes": "exciterande",
    "exciterandet": "exciterande",
    "exciterandets": "exciterande",
    "exciterar": "excitera",
    "exciteras": "excitera",
    "exciterat": "excitera",
    "exciterats": "excitera",
    "exciterbara": "exciterbar",
    "exciterbarare": "exciterbar",
    "exciterbarares": "exciterbar",
    "exciterbaras": "exciterbar",
    "exciterbarast": "exciterbar",
    "exciterbaraste": "exciterbar",
    "exciterbarastes": "exciterbar",
    "exciterbarasts": "exciterbar",
    "exciterbare": "exciterbar",
    "exciterbares": "exciterbar",
    "exciterbarheten": "exciterbarhet",
    "exciterbarhetens": "exciterbarhet",
    "exciterbarhets": "exciterbarhet",
    "exciterbars": "exciterbar",
    "exciterbart": "exciterbar",
    "exciterbarts": "exciterbar",
    "exciteringar": "excitering",
    "exciteringarna": "excitering",
    "exciteringarnas": "excitering",
    "exciteringars": "excitering",
    "exciteringen": "excitering",
    "exciteringens": "excitering",
    "exciterings": "excitering",
    "exegesen": "exeges",
    "exegesens": "exeges",
    "exegeten": "exeget",
    "exegetens": "exeget",
    "exegeter": "exeget",
    "exegeterna": "exeget",
    "exegeternas": "exeget",
    "exegeters": "exeget",
    "exegetiken": "exegetik",
    "exegetikens": "exegetik",
    "exegetiks": "exegetik",
    "exegets": "exeget",
    "exekutionen": "exekution",
    "exekutionens": "exekution",
    "exekutioner": "exekution",
    "exekutionerna": "exekution",
    "exekutionernas": "exekution",
    "exekutioners": "exekution",
    "exekutions": "exekution",
    "exekutiva": "exekutiv",
    "exekutivare": "exekutiv",
    "exekutivares": "exekutiv",
    "exekutivas": "exekutiv",
    "exekutivast": "exekutiv",
    "exekutivaste": "exekutiv",
    "exekutivastes": "exekutiv",
    "exekutivasts": "exekutiv",
    "exekutive": "exekutiv",
    "exekutiven": "exekutiv",
    "exekutivens": "exekutiv",
    "exekutiver": "exekutiv",
    "exekutiverna": "exekutiv",
    "exekutivernas": "exekutiv",
    "exekutivers": "exekutiv",
    "exekutives": "exekutiv",
    "exekutivs": "exekutiv",
    "exekutivt": "exekutiv",
    "exekutivts": "exekutiv",
    "exekutorer": "exekutor",
    "exekutorerna": "exekutor",
    "exekutorernas": "exekutor",
    "exekutorers": "exekutor",
    "exekutoriska": "exekutorisk",
    "exekutoriskare": "exekutorisk",
    "exekutoriskares": "exekutorisk",
    "exekutoriskas": "exekutorisk",
    "exekutoriskast": "exekutorisk",
    "exekutoriskaste": "exekutorisk",
    "exekutoriskastes": "exekutorisk",
    "exekutoriskasts": "exekutorisk",
    "exekutoriske": "exekutorisk",
    "exekutoriskes": "exekutorisk",
    "exekutorisks": "exekutorisk",
    "exekutoriskt": "exekutorisk",
    "exekutoriskts": "exekutorisk",
    "exekutorn": "exekutor",
    "exekutorns": "exekutor",
    "exekutors": "exekutor",
    "exekutören": "exekutör",
    "exekutörens": "exekutör",
    "exekutörer": "exekutör",
    "exekutörerna": "exekutör",
    "exekutörernas": "exekutör",
    "exekutörers": "exekutör",
    "exekutörs": "exekutör",
    "exekverad": "exekvera",
    "exekverade": "exekvera",
    "exekverades": "exekvera",
    "exekverads": "exekvera",
    "exekverande": "exekvera",
    "exekveranden": "exekverande",
    "exekverandena": "exekverande",
    "exekverandenas": "exekverande",
    "exekverandens": "exekverande",
    "exekverandes": "exekverande",
    "exekverandet": "exekverande",
    "exekverandets": "exekverande",
    "exekverar": "exekvera",
    "exekveras": "exekvera",
    "exekverat": "exekvera",
    "exekverats": "exekvera",
    "exekverbara": "exekverbar",
    "exekverbarare": "exekverbar",
    "exekverbarares": "exekverbar",
    "exekverbaras": "exekverbar",
    "exekverbarast": "exekverbar",
    "exekverbaraste": "exekverbar",
    "exekverbarastes": "exekverbar",
    "exekverbarasts": "exekverbar",
    "exekverbare": "exekverbar",
    "exekverbares": "exekverbar",
    "exekverbarheten": "exekverbarhet",
    "exekverbarhetens": "exekverbarhet",
    "exekverbarhets": "exekverbarhet",
    "exekverbars": "exekverbar",
    "exekverbart": "exekverbar",
    "exekverbarts": "exekverbar",
    "exekveringar": "exekvering",
    "exekveringarna": "exekvering",
    "exekveringarnas": "exekvering",
    "exekveringars": "exekvering",
    "exekveringen": "exekvering",
    "exekveringens": "exekvering",
    "exekverings": "exekvering",
    "exempellösa": "exempellös",
    "exempellösare": "exempellös",
    "exempellösares": "exempellös",
    "exempellösas": "exempellös",
    "exempellösast": "exempellös",
    "exempellösaste": "exempellös",
    "exempellösastes": "exempellös",
    "exempellösasts": "exempellös",
    "exempellöse": "exempellös",
    "exempellöses": "exempellös",
    "exempellösheten": "exempellöshet",
    "exempellöshetens": "exempellöshet",
    "exempellösheter": "exempellöshet",
    "exempellösheterna": "exempellöshet",
    "exempellösheternas": "exempellöshet",
    "exempellösheters": "exempellöshet",
    "exempellöshets": "exempellöshet",
    "exempellöst": "exempellös",
    "exempellösts": "exempellös",
    "exempels": "exempel",
    "exempelsamlingar": "exempelsamling",
    "exempelsamlingarna": "exempelsamling",
    "exempelsamlingarnas": "exempelsamling",
    "exempelsamlingars": "exempelsamling",
    "exempelsamlingen": "exempelsamling",
    "exempelsamlingens": "exempelsamling",
    "exempelsamlings": "exempelsamling",
    "exemplaren": "exemplar",
    "exemplarens": "exemplar",
    "exemplaret": "exemplar",
    "exemplarets": "exemplar",
    "exemplariska": "exemplarisk",
    "exemplariskare": "exemplarisk",
    "exemplariskares": "exemplarisk",
    "exemplariskas": "exemplarisk",
    "exemplariskast": "exemplarisk",
    "exemplariskaste": "exemplarisk",
    "exemplariskastes": "exemplarisk",
    "exemplariskasts": "exemplarisk",
    "exemplariske": "exemplarisk",
    "exemplariskes": "exemplarisk",
    "exemplarisks": "exemplarisk",
    "exemplariskt": "exemplarisk",
    "exemplariskts": "exemplarisk",
    "exemplars": "exemplar",
    "exemplen": "exempel",
    "exemplens": "exempel",
    "exemplet": "exempel",
    "exemplets": "exempel",
    "exemplifierad": "exemplifiera",
    "exemplifierade": "exemplifiera",
    "exemplifierades": "exemplifiera",
    "exemplifierads": "exemplifiera",
    "exemplifierande": "exemplifiera",
    "exemplifieranden": "exemplifierande",
    "exemplifierandena": "exemplifierande",
    "exemplifierandenas": "exemplifierande",
    "exemplifierandens": "exemplifierande",
    "exemplifierandes": "exemplifierande",
    "exemplifierandet": "exemplifierande",
    "exemplifierandets": "exemplifierande",
    "exemplifierar": "exemplifiera",
    "exemplifieras": "exemplifiera",
    "exemplifierat": "exemplifiera",
    "exemplifierats": "exemplifiera",
    "exemplifierbara": "exemplifierbar",
    "exemplifierbarare": "exemplifierbar",
    "exemplifierbarares": "exemplifierbar",
    "exemplifierbaras": "exemplifierbar",
    "exemplifierbarast": "exemplifierbar",
    "exemplifierbaraste": "exemplifierbar",
    "exemplifierbarastes": "exemplifierbar",
    "exemplifierbarasts": "exemplifierbar",
    "exemplifierbare": "exemplifierbar",
    "exemplifierbares": "exemplifierbar",
    "exemplifierbarheten": "exemplifierbarhet",
    "exemplifierbarhetens": "exemplifierbarhet",
    "exemplifierbarhets": "exemplifierbarhet",
    "exemplifierbars": "exemplifierbar",
    "exemplifierbart": "exemplifierbar",
    "exemplifierbarts": "exemplifierbar",
    "exemplifieringar": "exemplifiering",
    "exemplifieringarna": "exemplifiering",
    "exemplifieringarnas": "exemplifiering",
    "exemplifieringars": "exemplifiering",
    "exemplifieringen": "exemplifiering",
    "exemplifieringens": "exemplifiering",
    "exemplifierings": "exemplifiering",
    "exemplifikationen": "exemplifikation",
    "exemplifikationens": "exemplifikation",
    "exemplifikationer": "exemplifikation",
    "exemplifikationerna": "exemplifikation",
    "exemplifikationernas": "exemplifikation",
    "exemplifikationers": "exemplifikation",
    "exemplifikations": "exemplifikation",
    "exen": "ex",
    "exens": "ex",
    "exercerad": "exercera",
    "exercerade": "exercera",
    "exercerades": "exercera",
    "exercerads": "exercera",
    "exercerande": "exercera",
    "exerceranden": "exercerande",
    "exercerandena": "exercerande",
    "exercerandenas": "exercerande",
    "exercerandens": "exercerande",
    "exercerandes": "exercerande",
    "exercerandet": "exercerande",
    "exercerandets": "exercerande",
    "exercerar": "exercera",
    "exerceras": "exercera",
    "exercerat": "exercera",
    "exercerats": "exercera",
    "exercerbara": "exercerbar",
    "exercerbarare": "exercerbar",
    "exercerbarares": "exercerbar",
    "exercerbaras": "exercerbar",
    "exercerbarast": "exercerbar",
    "exercerbaraste": "exercerbar",
    "exercerbarastes": "exercerbar",
    "exercerbarasts": "exercerbar",
    "exercerbare": "exercerbar",
    "exercerbares": "exercerbar",
    "exercerbarheten": "exercerbarhet",
    "exercerbarhetens": "exercerbarhet",
    "exercerbarhets": "exercerbarhet",
    "exercerbars": "exercerbar",
    "exercerbart": "exercerbar",
    "exercerbarts": "exercerbar",
    "exerceringar": "exercering",
    "exerceringarna": "exercering",
    "exerceringarnas": "exercering",
    "exerceringars": "exercering",
    "exerceringen": "exercering",
    "exerceringens": "exercering",
    "exercerings": "exercering",
    "exercisen": "exercis",
    "exercisens": "exercis",
    "exerciser": "exercis",
    "exerciserna": "exercis",
    "exercisernas": "exercis",
    "exercisers": "exercis",
    "exet": "ex",
    "exets": "ex",
    "exfruar": "exfru",
    "exfruarna": "exfru",
    "exfruarnas": "exfru",
    "exfruars": "exfru",
    "exfrun": "exfru",
    "exfruns": "exfru",
    "exfrus": "exfru",
    "exhalterade": "exhalterad",
    "exhalterades": "exhalterad",
    "exhalterads": "exhalterad",
    "exhalterat": "exhalterad",
    "exhalterats": "exhalterad",
    "exhibitionismen": "exhibitionism",
    "exhibitionismens": "exhibitionism",
    "exhibitionismer": "exhibitionism",
    "exhibitionismerna": "exhibitionism",
    "exhibitionismernas": "exhibitionism",
    "exhibitionismers": "exhibitionism",
    "exhibitionisms": "exhibitionism",
    "exhibitionisten": "exhibitionist",
    "exhibitionistens": "exhibitionist",
    "exhibitionister": "exhibitionist",
    "exhibitionisterna": "exhibitionist",
    "exhibitionisternas": "exhibitionist",
    "exhibitionisters": "exhibitionist",
    "exhibitionistiska": "exhibitionistisk",
    "exhibitionistiskas": "exhibitionistisk",
    "exhibitionistiske": "exhibitionistisk",
    "exhibitionistiskes": "exhibitionistisk",
    "exhibitionistisks": "exhibitionistisk",
    "exhibitionistiskt": "exhibitionistisk",
    "exhibitionistiskts": "exhibitionistisk",
    "exhibitionists": "exhibitionist",
    "exhustrun": "exhustru",
    "exhustruns": "exhustru",
    "exhustrur": "exhustru",
    "exhustrurna": "exhustru",
    "exhustrurnas": "exhustru",
    "exhustrurs": "exhustru",
    "exhustrus": "exhustru",
    "exigibels": "exigibel",
    "exigibelt": "exigibel",
    "exigibelts": "exigibel",
    "exigibla": "exigibel",
    "exigiblare": "exigibel",
    "exigiblares": "exigibel",
    "exigiblas": "exigibel",
    "exigiblast": "exigibel",
    "exigiblaste": "exigibel",
    "exigiblastes": "exigibel",
    "exigiblasts": "exigibel",
    "exigible": "exigibel",
    "exigibles": "exigibel",
    "exilen": "exil",
    "exilens": "exil",
    "exils": "exil",
    "existensberättigandes": "existensberättigande",
    "existensberättigandet": "existensberättigande",
    "existensberättigandets": "existensberättigande",
    "existensen": "existens",
    "existensens": "existens",
    "existenser": "existens",
    "existenserna": "existens",
    "existensernas": "existens",
    "existensers": "existens",
    "existensminima": "existensminimum",
    "existensminimana": "existensminimum",
    "existensminimanas": "existensminimum",
    "existensminimas": "existensminimum",
    "existensminimet": "existensminimum",
    "existensminimets": "existensminimum",
    "existensminimumen": "existensminimum",
    "existensminimumens": "existensminimum",
    "existensminimumet": "existensminimum",
    "existensminimumets": "existensminimum",
    "existensminimums": "existensminimum",
    "existentialismen": "existentialism",
    "existentialismens": "existentialism",
    "existentialismer": "existentialism",
    "existentialismerna": "existentialism",
    "existentialismernas": "existentialism",
    "existentialismers": "existentialism",
    "existentialisms": "existentialism",
    "existentialistiska": "existentialistisk",
    "existentialistiskas": "existentialistisk",
    "existentialistiske": "existentialistisk",
    "existentialistiskes": "existentialistisk",
    "existentialistisks": "existentialistisk",
    "existentialistiskt": "existentialistisk",
    "existentialistiskts": "existentialistisk",
    "existentiella": "existentiell",
    "existentiellare": "existentiell",
    "existentiellares": "existentiell",
    "existentiellas": "existentiell",
    "existentiellast": "existentiell",
    "existentiellaste": "existentiell",
    "existentiellastes": "existentiell",
    "existentiellasts": "existentiell",
    "existentielle": "existentiell",
    "existentielles": "existentiell",
    "existentiells": "existentiell",
    "existentiellt": "existentiell",
    "existentiellts": "existentiell",
    "existerade": "existera",
    "existerades": "existera",
    "existerande": "existera",
    "existeranden": "existerande",
    "existerandena": "existerande",
    "existerandenas": "existerande",
    "existerandens": "existerande",
    "existerandes": "existerande",
    "existerandet": "existerande",
    "existerandets": "existerande",
    "existerar": "existera",
    "existeras": "existera",
    "existerat": "existera",
    "existerats": "existera",
    "exklamationen": "exklamation",
    "exklamationens": "exklamation",
    "exklamationer": "exklamation",
    "exklamationerna": "exklamation",
    "exklamationernas": "exklamation",
    "exklamationers": "exklamation",
    "exklamations": "exklamation",
    "exklamatoriska": "exklamatorisk",
    "exklamatoriskare": "exklamatorisk",
    "exklamatoriskares": "exklamatorisk",
    "exklamatoriskas": "exklamatorisk",
    "exklamatoriskast": "exklamatorisk",
    "exklamatoriskaste": "exklamatorisk",
    "exklamatoriskastes": "exklamatorisk",
    "exklamatoriskasts": "exklamatorisk",
    "exklamatoriske": "exklamatorisk",
    "exklamatoriskes": "exklamatorisk",
    "exklamatorisks": "exklamatorisk",
    "exklamatoriskt": "exklamatorisk",
    "exklamatoriskts": "exklamatorisk",
    "exkluderad": "exkludera",
    "exkluderade": "exkludera",
    "exkluderades": "exkludera",
    "exkluderads": "exkludera",
    "exkluderande": "exkludera",
    "exkluderanden": "exkluderande",
    "exkluderandena": "exkluderande",
    "exkluderandenas": "exkluderande",
    "exkluderandens": "exkluderande",
    "exkluderandes": "exkluderande",
    "exkluderandet": "exkluderande",
    "exkluderandets": "exkluderande",
    "exkluderar": "exkludera",
    "exkluderas": "exkludera",
    "exkluderat": "exkludera",
    "exkluderats": "exkludera",
    "exkluderbara": "exkluderbar",
    "exkluderbarare": "exkluderbar",
    "exkluderbarares": "exkluderbar",
    "exkluderbaras": "exkluderbar",
    "exkluderbarast": "exkluderbar",
    "exkluderbaraste": "exkluderbar",
    "exkluderbarastes": "exkluderbar",
    "exkluderbarasts": "exkluderbar",
    "exkluderbare": "exkluderbar",
    "exkluderbares": "exkluderbar",
    "exkluderbarheten": "exkluderbarhet",
    "exkluderbarhetens": "exkluderbarhet",
    "exkluderbarhets": "exkluderbarhet",
    "exkluderbars": "exkluderbar",
    "exkluderbart": "exkluderbar",
    "exkluderbarts": "exkluderbar",
    "exkluderingar": "exkludering",
    "exkluderingarna": "exkludering",
    "exkluderingarnas": "exkludering",
    "exkluderingars": "exkludering",
    "exkluderingen": "exkludering",
    "exkluderingens": "exkludering",
    "exkluderings": "exkludering",
    "exklusiva": "exklusiv",
    "exklusivare": "exklusiv",
    "exklusivares": "exklusiv",
    "exklusivas": "exklusiv",
    "exklusivast": "exklusiv",
    "exklusivaste": "exklusiv",
    "exklusivastes": "exklusiv",
    "exklusivasts": "exklusiv",
    "exklusive": "exklusiv",
    "exklusives": "exklusiv",
    "exklusiviteten": "exklusivitet",
    "exklusivitetens": "exklusivitet",
    "exklusiviteter": "exklusivitet",
    "exklusiviteterna": "exklusivitet",
    "exklusiviteternas": "exklusivitet",
    "exklusiviteters": "exklusivitet",
    "exklusivitets": "exklusivitet",
    "exklusivs": "exklusiv",
    "exklusivt": "exklusiv",
    "exklusivts": "exklusiv",
    "exkommunicerad": "exkommunicera",
    "exkommunicerade": "exkommunicera",
    "exkommunicerades": "exkommunicera",
    "exkommunicerads": "exkommunicera",
    "exkommunicerande": "exkommunicera",
    "exkommuniceranden": "exkommunicerande",
    "exkommunicerandena": "exkommunicerande",
    "exkommunicerandenas": "exkommunicerande",
    "exkommunicerandens": "exkommunicerande",
    "exkommunicerandes": "exkommunicerande",
    "exkommunicerandet": "exkommunicerande",
    "exkommunicerandets": "exkommunicerande",
    "exkommunicerar": "exkommunicera",
    "exkommuniceras": "exkommunicera",
    "exkommunicerat": "exkommunicera",
    "exkommunicerats": "exkommunicera",
    "exkommunicerbara": "exkommunicerbar",
    "exkommunicerbarare": "exkommunicerbar",
    "exkommunicerbarares": "exkommunicerbar",
    "exkommunicerbaras": "exkommunicerbar",
    "exkommunicerbarast": "exkommunicerbar",
    "exkommunicerbaraste": "exkommunicerbar",
    "exkommunicerbarastes": "exkommunicerbar",
    "exkommunicerbarasts": "exkommunicerbar",
    "exkommunicerbare": "exkommunicerbar",
    "exkommunicerbares": "exkommunicerbar",
    "exkommunicerbarheten": "exkommunicerbarhet",
    "exkommunicerbarhetens": "exkommunicerbarhet",
    "exkommunicerbarhets": "exkommunicerbarhet",
    "exkommunicerbars": "exkommunicerbar",
    "exkommunicerbart": "exkommunicerbar",
    "exkommunicerbarts": "exkommunicerbar",
    "exkommuniceringar": "exkommunicering",
    "exkommuniceringarna": "exkommunicering",
    "exkommuniceringarnas": "exkommunicering",
    "exkommuniceringars": "exkommunicering",
    "exkommuniceringen": "exkommunicering",
    "exkommuniceringens": "exkommunicering",
    "exkommunicerings": "exkommunicering",
    "exkommunikationen": "exkommunikation",
    "exkommunikationens": "exkommunikation",
    "exkommunikationer": "exkommunikation",
    "exkommunikationerna": "exkommunikation",
    "exkommunikationernas": "exkommunikation",
    "exkommunikationers": "exkommunikation",
    "exkommunikations": "exkommunikation",
    "exkrementala": "exkremental",
    "exkrementalare": "exkremental",
    "exkrementalares": "exkremental",
    "exkrementalas": "exkremental",
    "exkrementalast": "exkremental",
    "exkrementalaste": "exkremental",
    "exkrementalastes": "exkremental",
    "exkrementalasts": "exkremental",
    "exkrementale": "exkremental",
    "exkrementales": "exkremental",
    "exkrementals": "exkremental",
    "exkrementalt": "exkremental",
    "exkrementalts": "exkremental",
    "exkrementer": "exkrement",
    "exkrementerna": "exkrement",
    "exkrementernas": "exkrement",
    "exkrementers": "exkrement",
    "exkrementet": "exkrement",
    "exkrementets": "exkrement",
    "exkrements": "exkrement",
    "exkreten": "exkret",
    "exkretens": "exkret",
    "exkretet": "exkret",
    "exkretets": "exkret",
    "exkretionen": "exkretion",
    "exkretionens": "exkretion",
    "exkretioner": "exkretion",
    "exkretionerna": "exkretion",
    "exkretionernas": "exkretion",
    "exkretioners": "exkretion",
    "exkretions": "exkretion",
    "exkrets": "exkret",
    "exkungar": "exkung",
    "exkungarna": "exkung",
    "exkungarnas": "exkung",
    "exkungars": "exkung",
    "exkungen": "exkung",
    "exkungens": "exkung",
    "exkungs": "exkung",
    "exkursen": "exkurs",
    "exkursens": "exkurs",
    "exkurser": "exkurs",
    "exkurserna": "exkurs",
    "exkursernas": "exkurs",
    "exkursers": "exkurs",
    "exkursionen": "exkursion",
    "exkursionens": "exkursion",
    "exkursioner": "exkursion",
    "exkursionerna": "exkursion",
    "exkursionernas": "exkursion",
    "exkursioners": "exkursion",
    "exkursions": "exkursion",
    "exlibrisen": "exlibris",
    "exlibrisens": "exlibris",
    "exlibriset": "exlibris",
    "exlibrisets": "exlibris",
    "exogena": "exogen",
    "exogenare": "exogen",
    "exogenares": "exogen",
    "exogenas": "exogen",
    "exogenast": "exogen",
    "exogenaste": "exogen",
    "exogenastes": "exogen",
    "exogenasts": "exogen",
    "exogene": "exogen",
    "exogenes": "exogen",
    "exogens": "exogen",
    "exogent": "exogen",
    "exogents": "exogen",
    "exonymen": "exonym",
    "exonymens": "exonym",
    "exonymer": "exonym",
    "exonymerna": "exonym",
    "exonymernas": "exonym",
    "exonymers": "exonym",
    "exonyms": "exonym",
    "exoplaneten": "exoplanet",
    "exoplanetens": "exoplanet",
    "exoplaneter": "exoplanet",
    "exoplaneterna": "exoplanet",
    "exoplaneternas": "exoplanet",
    "exoplaneters": "exoplanet",
    "exoplanets": "exoplanet",
    "exorcismen": "exorcism",
    "exorcismens": "exorcism",
    "exorcismer": "exorcism",
    "exorcismerna": "exorcism",
    "exorcismernas": "exorcism",
    "exorcismers": "exorcism",
    "exorcisms": "exorcism",
    "exorcisten": "exorcist",
    "exorcistens": "exorcist",
    "exorcister": "exorcist",
    "exorcisterna": "exorcist",
    "exorcisternas": "exorcist",
    "exorcisters": "exorcist",
    "exorcistiska": "exorcistisk",
    "exorcistiskas": "exorcistisk",
    "exorcistiske": "exorcistisk",
    "exorcistiskes": "exorcistisk",
    "exorcistisks": "exorcistisk",
    "exorcistiskt": "exorcistisk",
    "exorcistiskts": "exorcistisk",
    "exorcists": "exorcist",
    "exoteriska": "exoterisk",
    "exoteriskare": "exoterisk",
    "exoteriskares": "exoterisk",
    "exoteriskas": "exoterisk",
    "exoteriskast": "exoterisk",
    "exoteriskaste": "exoterisk",
    "exoteriskastes": "exoterisk",
    "exoteriskasts": "exoterisk",
    "exoteriske": "exoterisk",
    "exoteriskes": "exoterisk",
    "exoterisks": "exoterisk",
    "exoteriskt": "exoterisk",
    "exoteriskts": "exoterisk",
    "exotermiska": "exotermisk",
    "exotermiskare": "exotermisk",
    "exotermiskares": "exotermisk",
    "exotermiskas": "exotermisk",
    "exotermiskast": "exotermisk",
    "exotermiskaste": "exotermisk",
    "exotermiskastes": "exotermisk",
    "exotermiskasts": "exotermisk",
    "exotermiske": "exotermisk",
    "exotermiskes": "exotermisk",
    "exotermisks": "exotermisk",
    "exotermiskt": "exotermisk",
    "exotermiskts": "exotermisk",
    "exotiska": "exotisk",
    "exotiskare": "exotisk",
    "exotiskares": "exotisk",
    "exotiskas": "exotisk",
    "exotiskast": "exotisk",
    "exotiskaste": "exotisk",
    "exotiskastes": "exotisk",
    "exotiskasts": "exotisk",
    "exotiske": "exotisk",
    "exotiskes": "exotisk",
    "exotisks": "exotisk",
    "exotiskt": "exotisk",
    "exotiskts": "exotisk",
    "exotismen": "exotism",
    "exotismens": "exotism",
    "exotismer": "exotism",
    "exotismerna": "exotism",
    "exotismernas": "exotism",
    "exotismers": "exotism",
    "exotisms": "exotism",
    "exotistiska": "exotistisk",
    "exotistiskas": "exotistisk",
    "exotistiske": "exotistisk",
    "exotistiskes": "exotistisk",
    "exotistisks": "exotistisk",
    "exotistiskt": "exotistisk",
    "exotistiskts": "exotistisk",
    "expanderad": "expandera",
    "expanderade": "expandera",
    "expanderades": "expandera",
    "expanderads": "expandera",
    "expanderande": "expandera",
    "expanderanden": "expanderande",
    "expanderandena": "expanderande",
    "expanderandenas": "expanderande",
    "expanderandens": "expanderande",
    "expanderandes": "expanderande",
    "expanderandet": "expanderande",
    "expanderandets": "expanderande",
    "expanderar": "expandera",
    "expanderas": "expandera",
    "expanderat": "expandera",
    "expanderats": "expandera",
    "expanderbara": "expanderbar",
    "expanderbarare": "expanderbar",
    "expanderbarares": "expanderbar",
    "expanderbaras": "expanderbar",
    "expanderbarast": "expanderbar",
    "expanderbaraste": "expanderbar",
    "expanderbarastes": "expanderbar",
    "expanderbarasts": "expanderbar",
    "expanderbare": "expanderbar",
    "expanderbares": "expanderbar",
    "expanderbarheten": "expanderbarhet",
    "expanderbarhetens": "expanderbarhet",
    "expanderbarhets": "expanderbarhet",
    "expanderbars": "expanderbar",
    "expanderbart": "expanderbar",
    "expanderbarts": "expanderbar",
    "expanderingar": "expandering",
    "expanderingarna": "expandering",
    "expanderingarnas": "expandering",
    "expanderingars": "expandering",
    "expanderingen": "expandering",
    "expanderingens": "expandering",
    "expanderings": "expandering",
    "expansibels": "expansibel",
    "expansibelt": "expansibel",
    "expansibelts": "expansibel",
    "expansibla": "expansibel",
    "expansiblare": "expansibel",
    "expansiblares": "expansibel",
    "expansiblas": "expansibel",
    "expansiblast": "expansibel",
    "expansiblaste": "expansibel",
    "expansiblastes": "expansibel",
    "expansiblasts": "expansibel",
    "expansible": "expansibel",
    "expansibles": "expansibel",
    "expansionen": "expansion",
    "expansionens": "expansion",
    "expansioner": "expansion",
    "expansionerna": "expansion",
    "expansionernas": "expansion",
    "expansioners": "expansion",
    "expansionismen": "expansionism",
    "expansionismens": "expansionism",
    "expansionismer": "expansionism",
    "expansionismerna": "expansionism",
    "expansionismernas": "expansionism",
    "expansionismers": "expansionism",
    "expansionisms": "expansionism",
    "expansionistiska": "expansionistisk",
    "expansionistiskas": "expansionistisk",
    "expansionistiske": "expansionistisk",
    "expansionistiskes": "expansionistisk",
    "expansionistisks": "expansionistisk",
    "expansionistiskt": "expansionistisk",
    "expansionistiskts": "expansionistisk",
    "expansions": "expansion",
    "expansionskärlen": "expansionskärl",
    "expansionskärlens": "expansionskärl",
    "expansionskärlet": "expansionskärl",
    "expansionskärlets": "expansionskärl",
    "expansionskärls": "expansionskärl",
    "expansiva": "expansiv",
    "expansivare": "expansiv",
    "expansivares": "expansiv",
    "expansivas": "expansiv",
    "expansivast": "expansiv",
    "expansivaste": "expansiv",
    "expansivastes": "expansiv",
    "expansivasts": "expansiv",
    "expansive": "expansiv",
    "expansives": "expansiv",
    "expansivs": "expansiv",
    "expansivt": "expansiv",
    "expansivts": "expansiv",
    "expatrierad": "expatriera",
    "expatrierade": "expatriera",
    "expatrierades": "expatriera",
    "expatrierads": "expatriera",
    "expatrierande": "expatriera",
    "expatrieranden": "expatrierande",
    "expatrierandena": "expatrierande",
    "expatrierandenas": "expatrierande",
    "expatrierandens": "expatrierande",
    "expatrierandes": "expatrierande",
    "expatrierandet": "expatrierande",
    "expatrierandets": "expatrierande",
    "expatrierar": "expatriera",
    "expatrieras": "expatriera",
    "expatrierat": "expatriera",
    "expatrierats": "expatriera",
    "expatrierbara": "expatrierbar",
    "expatrierbarare": "expatrierbar",
    "expatrierbarares": "expatrierbar",
    "expatrierbaras": "expatrierbar",
    "expatrierbarast": "expatrierbar",
    "expatrierbaraste": "expatrierbar",
    "expatrierbarastes": "expatrierbar",
    "expatrierbarasts": "expatrierbar",
    "expatrierbare": "expatrierbar",
    "expatrierbares": "expatrierbar",
    "expatrierbarheten": "expatrierbarhet",
    "expatrierbarhetens": "expatrierbarhet",
    "expatrierbarhets": "expatrierbarhet",
    "expatrierbars": "expatrierbar",
    "expatrierbart": "expatrierbar",
    "expatrierbarts": "expatrierbar",
    "expatrieringar": "expatriering",
    "expatrieringarna": "expatriering",
    "expatrieringarnas": "expatriering",
    "expatrieringars": "expatriering",
    "expatrieringen": "expatriering",
    "expatrieringens": "expatriering",
    "expatrierings": "expatriering",
    "expedierad": "expediera",
    "expedierade": "expediera",
    "expedierades": "expediera",
    "expedierads": "expediera",
    "expedierande": "expediera",
    "expedieranden": "expedierande",
    "expedierandena": "expedierande",
    "expedierandenas": "expedierande",
    "expedierandens": "expedierande",
    "expedierandes": "expedierande",
    "expedierandet": "expedierande",
    "expedierandets": "expedierande",
    "expedierar": "expediera",
    "expedieras": "expediera",
    "expedierat": "expediera",
    "expedierats": "expediera",
    "expedierbara": "expedierbar",
    "expedierbarare": "expedierbar",
    "expedierbarares": "expedierbar",
    "expedierbaras": "expedierbar",
    "expedierbarast": "expedierbar",
    "expedierbaraste": "expedierbar",
    "expedierbarastes": "expedierbar",
    "expedierbarasts": "expedierbar",
    "expedierbare": "expedierbar",
    "expedierbares": "expedierbar",
    "expedierbarheten": "expedierbarhet",
    "expedierbarhetens": "expedierbarhet",
    "expedierbarhets": "expedierbarhet",
    "expedierbars": "expedierbar",
    "expedierbart": "expedierbar",
    "expedierbarts": "expedierbar",
    "expedieringar": "expediering",
    "expedieringarna": "expediering",
    "expedieringarnas": "expediering",
    "expedieringars": "expediering",
    "expedieringen": "expediering",
    "expedieringens": "expediering",
    "expedierings": "expediering",
    "expedita": "expedit",
    "expeditare": "expedit",
    "expeditares": "expedit",
    "expeditas": "expedit",
    "expeditast": "expedit",
    "expeditaste": "expedit",
    "expeditastes": "expedit",
    "expeditasts": "expedit",
    "expedite": "expedit",
    "expediten": "expedit",
    "expeditens": "expedit",
    "expediter": "expedit",
    "expediterna": "expedit",
    "expediternas": "expedit",
    "expediters": "expedit",
    "expedites": "expedit",
    "expeditionen": "expedition",
    "expeditionens": "expedition",
    "expeditioner": "expedition",
    "expeditionerna": "expedition",
    "expeditionernas": "expedition",
    "expeditioners": "expedition",
    "expeditions": "expedition",
    "expeditionskåren": "expeditionskår",
    "expeditionskårens": "expeditionskår",
    "expeditionskårer": "expeditionskår",
    "expeditionskårerna": "expeditionskår",
    "expeditionskårernas": "expeditionskår",
    "expeditionskårers": "expeditionskår",
    "expeditionskårs": "expeditionskår",
    "expeditionsledar": "expeditionsledare",
    "expeditionsledaren": "expeditionsledare",
    "expeditionsledarens": "expeditionsledare",
    "expeditionsledares": "expeditionsledare",
    "expeditionsledarna": "expeditionsledare",
    "expeditionsledarnas": "expeditionsledare",
    "expeditionsministären": "expeditionsministär",
    "expeditionsministärens": "expeditionsministär",
    "expeditionsministärer": "expeditionsministär",
    "expeditionsministärerna": "expeditionsministär",
    "expeditionsministärernas": "expeditionsministär",
    "expeditionsministärers": "expeditionsministär",
    "expeditionsministärs": "expeditionsministär",
    "expeditionsregeringar": "expeditionsregering",
    "expeditionsregeringarna": "expeditionsregering",
    "expeditionsregeringarnas": "expeditionsregering",
    "expeditionsregeringars": "expeditionsregering",
    "expeditionsregeringen": "expeditionsregering",
    "expeditionsregeringens": "expeditionsregering",
    "expeditionsregerings": "expeditionsregering",
    "expeditionsvakten": "expeditionsvakt",
    "expeditionsvaktens": "expeditionsvakt",
    "expeditionsvakter": "expeditionsvakt",
    "expeditionsvakterna": "expeditionsvakt",
    "expeditionsvakternas": "expeditionsvakt",
    "expeditionsvakters": "expeditionsvakt",
    "expeditionsvakts": "expeditionsvakt",
    "expedits": "expedit",
    "expeditören": "expeditör",
    "expeditörens": "expeditör",
    "expeditörer": "expeditör",
    "expeditörerna": "expeditör",
    "expeditörernas": "expeditör",
    "expeditörers": "expeditör",
    "expeditörs": "expeditör",
    "expektorationen": "expektoration",
    "expektorationens": "expektoration",
    "expektorationer": "expektoration",
    "expektorationerna": "expektoration",
    "expektorationernas": "expektoration",
    "expektorationers": "expektoration",
    "expektorations": "expektoration",
    "expektorerad": "expektorera",
    "expektorerade": "expektorera",
    "expektorerades": "expektorera",
    "expektorerads": "expektorera",
    "expektorerande": "expektorera",
    "expektoreranden": "expektorerande",
    "expektorerandena": "expektorerande",
    "expektorerandenas": "expektorerande",
    "expektorerandens": "expektorerande",
    "expektorerandes": "expektorerande",
    "expektorerandet": "expektorerande",
    "expektorerandets": "expektorerande",
    "expektorerar": "expektorera",
    "expektoreras": "expektorera",
    "expektorerat": "expektorera",
    "expektorerats": "expektorera",
    "expektorerbara": "expektorerbar",
    "expektorerbarare": "expektorerbar",
    "expektorerbarares": "expektorerbar",
    "expektorerbaras": "expektorerbar",
    "expektorerbarast": "expektorerbar",
    "expektorerbaraste": "expektorerbar",
    "expektorerbarastes": "expektorerbar",
    "expektorerbarasts": "expektorerbar",
    "expektorerbare": "expektorerbar",
    "expektorerbares": "expektorerbar",
    "expektorerbarheten": "expektorerbarhet",
    "expektorerbarhetens": "expektorerbarhet",
    "expektorerbarhets": "expektorerbarhet",
    "expektorerbars": "expektorerbar",
    "expektorerbart": "expektorerbar",
    "expektorerbarts": "expektorerbar",
    "expektoreringar": "expektorering",
    "expektoreringarna": "expektorering",
    "expektoreringarnas": "expektorering",
    "expektoreringars": "expektorering",
    "expektoreringen": "expektorering",
    "expektoreringens": "expektorering",
    "expektorerings": "expektorering",
    "expens": "expenser",
    "expenserna": "expenser",
    "expensernas": "expenser",
    "expensers": "expenser",
    "experimentalfysikern": "experimentalfysiker",
    "experimentalfysikerna": "experimentalfysiker",
    "experimentalfysikernas": "experimentalfysiker",
    "experimentalfysikerns": "experimentalfysiker",
    "experimentalfysikers": "experimentalfysiker",
    "experimentalkirurgien": "experimentalkirurgi",
    "experimentalkirurgiens": "experimentalkirurgi",
    "experimentalkirurgin": "experimentalkirurgi",
    "experimentalkirurgins": "experimentalkirurgi",
    "experimentalkirurgis": "experimentalkirurgi",
    "experimentatorer": "experimentator",
    "experimentatorerna": "experimentator",
    "experimentatorernas": "experimentator",
    "experimentatorers": "experimentator",
    "experimentatorn": "experimentator",
    "experimentatorns": "experimentator",
    "experimentators": "experimentator",
    "experimentella": "experimentell",
    "experimentellare": "experimentell",
    "experimentellares": "experimentell",
    "experimentellas": "experimentell",
    "experimentellast": "experimentell",
    "experimentellaste": "experimentell",
    "experimentellastes": "experimentell",
    "experimentellasts": "experimentell",
    "experimentelle": "experimentell",
    "experimentelles": "experimentell",
    "experimentells": "experimentell",
    "experimentellt": "experimentell",
    "experimentellts": "experimentell",
    "experimenten": "experiment",
    "experimentens": "experiment",
    "experimenterade": "experimentera",
    "experimenterades": "experimentera",
    "experimenterande": "experimentera",
    "experimenteranden": "experimenterande",
    "experimenterandena": "experimenterande",
    "experimenterandenas": "experimenterande",
    "experimenterandens": "experimenterande",
    "experimenterandes": "experimenterande",
    "experimenterandet": "experimenterande",
    "experimenterandets": "experimenterande",
    "experimenterar": "experimentera",
    "experimenteras": "experimentera",
    "experimenterat": "experimentera",
    "experimenterats": "experimentera",
    "experimenteringar": "experimentering",
    "experimenteringarna": "experimentering",
    "experimenteringarnas": "experimentering",
    "experimenteringars": "experimentering",
    "experimenteringen": "experimentering",
    "experimenteringens": "experimentering",
    "experimenterings": "experimentering",
    "experimentet": "experiment",
    "experimentets": "experiment",
    "experimentgymnasie": "experimentgymnasium",
    "experimentgymnasier": "experimentgymnasium",
    "experimentgymnasierna": "experimentgymnasium",
    "experimentgymnasiernas": "experimentgymnasium",
    "experimentgymnasiers": "experimentgymnasium",
    "experimentgymnasiet": "experimentgymnasium",
    "experimentgymnasiets": "experimentgymnasium",
    "experimentgymnasiums": "experimentgymnasium",
    "experimentlust": "experimentlusta",
    "experimentlustan": "experimentlusta",
    "experimentlustans": "experimentlusta",
    "experimentlustas": "experimentlusta",
    "experimentluste": "experimentlusta",
    "experimentlustor": "experimentlusta",
    "experimentlustorna": "experimentlusta",
    "experimentlustornas": "experimentlusta",
    "experimentlustors": "experimentlusta",
    "experiments": "experiment",
    "experimentstationen": "experimentstation",
    "experimentstationens": "experimentstation",
    "experimentstationer": "experimentstation",
    "experimentstationerna": "experimentstation",
    "experimentstationernas": "experimentstation",
    "experimentstationers": "experimentstation",
    "experimentstations": "experimentstation",
    "experten": "expert",
    "expertens": "expert",
    "experter": "expert",
    "experterna": "expert",
    "experternas": "expert",
    "experters": "expert",
    "expertgruppen": "expertgrupp",
    "expertgruppens": "expertgrupp",
    "expertgrupper": "expertgrupp",
    "expertgrupperna": "expertgrupp",
    "expertgruppernas": "expertgrupp",
    "expertgruppers": "expertgrupp",
    "expertgrupps": "expertgrupp",
    "expertisen": "expertis",
    "expertisens": "expertis",
    "expertkommittéer": "expertkommitté",
    "expertkommittéerna": "expertkommitté",
    "expertkommittéernas": "expertkommitté",
    "expertkommittéers": "expertkommitté",
    "expertkommittén": "expertkommitté",
    "expertkommitténs": "expertkommitté",
    "expertkommittés": "expertkommitté",
    "expertkretsar": "expertkrets",
    "expertkretsarna": "expertkrets",
    "expertkretsarnas": "expertkrets",
    "expertkretsars": "expertkrets",
    "expertkretsen": "expertkrets",
    "expertkretsens": "expertkrets",
    "experts": "expert",
    "expertspråken": "expertspråk",
    "expertspråkens": "expertspråk",
    "expertspråket": "expertspråk",
    "expertspråkets": "expertspråk",
    "expertspråks": "expertspråk",
    "expertutlåtanden": "expertutlåtande",
    "expertutlåtandena": "expertutlåtande",
    "expertutlåtandenas": "expertutlåtande",
    "expertutlåtandens": "expertutlåtande",
    "expertutlåtandes": "expertutlåtande",
    "expertutlåtandet": "expertutlåtande",
    "expertutlåtandets": "expertutlåtande",
    "explanativa": "explanativ",
    "explanativare": "explanativ",
    "explanativares": "explanativ",
    "explanativas": "explanativ",
    "explanativast": "explanativ",
    "explanativaste": "explanativ",
    "explanativastes": "explanativ",
    "explanativasts": "explanativ",
    "explanative": "explanativ",
    "explanatives": "explanativ",
    "explanativs": "explanativ",
    "explanativt": "explanativ",
    "explanativts": "explanativ",
    "explicerad": "explicera",
    "explicerade": "explicera",
    "explicerades": "explicera",
    "explicerads": "explicera",
    "explicerande": "explicera",
    "expliceranden": "explicerande",
    "explicerandena": "explicerande",
    "explicerandenas": "explicerande",
    "explicerandens": "explicerande",
    "explicerandes": "explicerande",
    "explicerandet": "explicerande",
    "explicerandets": "explicerande",
    "explicerar": "explicera",
    "expliceras": "explicera",
    "explicerat": "explicera",
    "explicerats": "explicera",
    "explicerbara": "explicerbar",
    "explicerbarare": "explicerbar",
    "explicerbarares": "explicerbar",
    "explicerbaras": "explicerbar",
    "explicerbarast": "explicerbar",
    "explicerbaraste": "explicerbar",
    "explicerbarastes": "explicerbar",
    "explicerbarasts": "explicerbar",
    "explicerbare": "explicerbar",
    "explicerbares": "explicerbar",
    "explicerbarheten": "explicerbarhet",
    "explicerbarhetens": "explicerbarhet",
    "explicerbarhets": "explicerbarhet",
    "explicerbars": "explicerbar",
    "explicerbart": "explicerbar",
    "explicerbarts": "explicerbar",
    "expliceringar": "explicering",
    "expliceringarna": "explicering",
    "expliceringarnas": "explicering",
    "expliceringars": "explicering",
    "expliceringen": "explicering",
    "expliceringens": "explicering",
    "explicerings": "explicering",
    "explicita": "explicit",
    "explicitare": "explicit",
    "explicitares": "explicit",
    "explicitas": "explicit",
    "explicitast": "explicit",
    "explicitaste": "explicit",
    "explicitastes": "explicit",
    "explicitasts": "explicit",
    "explicite": "explicit",
    "explicites": "explicit",
    "explicitheten": "explicithet",
    "explicithetens": "explicithet",
    "explicithets": "explicithet",
    "explicits": "explicit",
    "explikationen": "explikation",
    "explikationens": "explikation",
    "explikationer": "explikation",
    "explikationerna": "explikation",
    "explikationernas": "explikation",
    "explikationers": "explikation",
    "explikations": "explikation",
    "exploaterad": "exploatera",
    "exploaterade": "exploatera",
    "exploaterades": "exploatera",
    "exploaterads": "exploatera",
    "exploaterande": "exploatera",
    "exploateranden": "exploaterande",
    "exploaterandena": "exploaterande",
    "exploaterandenas": "exploaterande",
    "exploaterandens": "exploaterande",
    "exploaterandes": "exploaterande",
    "exploaterandet": "exploaterande",
    "exploaterandets": "exploaterande",
    "exploaterar": "exploatera",
    "exploateras": "exploatera",
    "exploaterat": "exploatera",
    "exploaterats": "exploatera",
    "exploaterbara": "exploaterbar",
    "exploaterbarare": "exploaterbar",
    "exploaterbarares": "exploaterbar",
    "exploaterbaras": "exploaterbar",
    "exploaterbarast": "exploaterbar",
    "exploaterbaraste": "exploaterbar",
    "exploaterbarastes": "exploaterbar",
    "exploaterbarasts": "exploaterbar",
    "exploaterbare": "exploaterbar",
    "exploaterbares": "exploaterbar",
    "exploaterbarheten": "exploaterbarhet",
    "exploaterbarhetens": "exploaterbarhet",
    "exploaterbarhets": "exploaterbarhet",
    "exploaterbars": "exploaterbar",
    "exploaterbart": "exploaterbar",
    "exploaterbarts": "exploaterbar",
    "exploateringar": "exploatering",
    "exploateringarna": "exploatering",
    "exploateringarnas": "exploatering",
    "exploateringars": "exploatering",
    "exploateringen": "exploatering",
    "exploateringens": "exploatering",
    "exploaterings": "exploatering",
    "exploateringsytan": "exploateringsyta",
    "exploateringsytans": "exploateringsyta",
    "exploateringsytas": "exploateringsyta",
    "exploateringsyte": "exploateringsyta",
    "exploateringsytor": "exploateringsyta",
    "exploateringsytorna": "exploateringsyta",
    "exploateringsytornas": "exploateringsyta",
    "exploateringsytors": "exploateringsyta",
    "exploatören": "exploatör",
    "exploatörens": "exploatör",
    "exploatörer": "exploatör",
    "exploatörerna": "exploatör",
    "exploatörernas": "exploatör",
    "exploatörers": "exploatör",
    "exploatörs": "exploatör",
    "exploderad": "explodera",
    "exploderade": "explodera",
    "exploderades": "explodera",
    "exploderads": "explodera",
    "exploderande": "explodera",
    "exploderanden": "exploderande",
    "exploderandena": "exploderande",
    "exploderandenas": "exploderande",
    "exploderandens": "exploderande",
    "exploderandes": "exploderande",
    "exploderandet": "exploderande",
    "exploderandets": "exploderande",
    "exploderar": "explodera",
    "exploderas": "explodera",
    "exploderat": "explodera",
    "exploderats": "explodera",
    "exploderbara": "exploderbar",
    "exploderbarare": "exploderbar",
    "exploderbarares": "exploderbar",
    "exploderbaras": "exploderbar",
    "exploderbarast": "exploderbar",
    "exploderbaraste": "exploderbar",
    "exploderbarastes": "exploderbar",
    "exploderbarasts": "exploderbar",
    "exploderbare": "exploderbar",
    "exploderbares": "exploderbar",
    "exploderbarheten": "exploderbarhet",
    "exploderbarhetens": "exploderbarhet",
    "exploderbarhets": "exploderbarhet",
    "exploderbars": "exploderbar",
    "exploderbart": "exploderbar",
    "exploderbarts": "exploderbar",
    "exploderingar": "explodering",
    "exploderingarna": "explodering",
    "exploderingarnas": "explodering",
    "exploderingars": "explodering",
    "exploderingen": "explodering",
    "exploderingens": "explodering",
    "exploderings": "explodering",
    "explosionen": "explosion",
    "explosionens": "explosion",
    "explosioner": "explosion",
    "explosionerna": "explosion",
    "explosionernas": "explosion",
    "explosioners": "explosion",
    "explosions": "explosion",
    "explosionsartade": "explosionsartad",
    "explosionsartades": "explosionsartad",
    "explosionsartads": "explosionsartad",
    "explosionsartat": "explosionsartad",
    "explosionsartats": "explosionsartad",
    "explosionsförloppen": "explosionsförlopp",
    "explosionsförloppens": "explosionsförlopp",
    "explosionsförloppet": "explosionsförlopp",
    "explosionsförloppets": "explosionsförlopp",
    "explosionsförlopps": "explosionsförlopp",
    "explosionshärdar": "explosionshärd",
    "explosionshärdarna": "explosionshärd",
    "explosionshärdarnas": "explosionshärd",
    "explosionshärdars": "explosionshärd",
    "explosionshärden": "explosionshärd",
    "explosionshärdens": "explosionshärd",
    "explosionshärds": "explosionshärd",
    "explosionsmotorer": "explosionsmotor",
    "explosionsmotorerna": "explosionsmotor",
    "explosionsmotorernas": "explosionsmotor",
    "explosionsmotorers": "explosionsmotor",
    "explosionsmotorn": "explosionsmotor",
    "explosionsmotorns": "explosionsmotor",
    "explosionsmotors": "explosionsmotor",
    "explosionsområden": "explosionsområde",
    "explosionsområdena": "explosionsområde",
    "explosionsområdenas": "explosionsområde",
    "explosionsområdens": "explosionsområde",
    "explosionsområdes": "explosionsområde",
    "explosionsområdet": "explosionsområde",
    "explosionsområdets": "explosionsområde",
    "explosionsrisken": "explosionsrisk",
    "explosionsriskens": "explosionsrisk",
    "explosionsrisker": "explosionsrisk",
    "explosionsriskerna": "explosionsrisk",
    "explosionsriskernas": "explosionsrisk",
    "explosionsriskers": "explosionsrisk",
    "explosionsrisks": "explosionsrisk",
    "explosionssätten": "explosionssätt",
    "explosionssättens": "explosionssätt",
    "explosionssättet": "explosionssätt",
    "explosionssättets": "explosionssätt",
    "explosionssätts": "explosionssätt",
    "explosionsögonblicken": "explosionsögonblick",
    "explosionsögonblickens": "explosionsögonblick",
    "explosionsögonblicket": "explosionsögonblick",
    "explosionsögonblickets": "explosionsögonblick",
    "explosionsögonblicks": "explosionsögonblick",
    "explosiv": "explosiva",
    "explosiva": "explosiv",
    "explosivan": "explosiva",
    "explosivans": "explosiva",
    "explosivare": "explosiv",
    "explosivares": "explosiv",
    "explosivas": "explosiva",
    "explosivast": "explosiv",
    "explosivaste": "explosiv",
    "explosivastes": "explosiv",
    "explosivasts": "explosiv",
    "explosive": "explosiva",
    "explosives": "explosiv",
    "explosivor": "explosiva",
    "explosivorna": "explosiva",
    "explosivornas": "explosiva",
    "explosivors": "explosiva",
    "explosivs": "explosiva",
    "explosivt": "explosiv",
    "explosivts": "explosiv",
    "expon": "expo",
    "exponenten": "exponent",
    "exponentens": "exponent",
    "exponenter": "exponent",
    "exponenterna": "exponent",
    "exponenternas": "exponent",
    "exponenters": "exponent",
    "exponentialfunktionen": "exponentialfunktion",
    "exponentialfunktionens": "exponentialfunktion",
    "exponentialfunktioner": "exponentialfunktion",
    "exponentialfunktionerna": "exponentialfunktion",
    "exponentialfunktionernas": "exponentialfunktion",
    "exponentialfunktioners": "exponentialfunktion",
    "exponentialfunktions": "exponentialfunktion",
    "exponentiella": "exponentiell",
    "exponentiellare": "exponentiell",
    "exponentiellares": "exponentiell",
    "exponentiellas": "exponentiell",
    "exponentiellast": "exponentiell",
    "exponentiellaste": "exponentiell",
    "exponentiellastes": "exponentiell",
    "exponentiellasts": "exponentiell",
    "exponentielle": "exponentiell",
    "exponentielles": "exponentiell",
    "exponentiells": "exponentiell",
    "exponentiellt": "exponentiell",
    "exponentiellts": "exponentiell",
    "exponents": "exponent",
    "exponerad": "exponera",
    "exponerade": "exponera",
    "exponerades": "exponera",
    "exponerads": "exponera",
    "exponerande": "exponera",
    "exponeranden": "exponerande",
    "exponerandena": "exponerande",
    "exponerandenas": "exponerande",
    "exponerandens": "exponerande",
    "exponerandes": "exponerande",
    "exponerandet": "exponerande",
    "exponerandets": "exponerande",
    "exponerar": "exponera",
    "exponeras": "exponera",
    "exponerat": "exponera",
    "exponerats": "exponera",
    "exponerbara": "exponerbar",
    "exponerbarare": "exponerbar",
    "exponerbarares": "exponerbar",
    "exponerbaras": "exponerbar",
    "exponerbarast": "exponerbar",
    "exponerbaraste": "exponerbar",
    "exponerbarastes": "exponerbar",
    "exponerbarasts": "exponerbar",
    "exponerbare": "exponerbar",
    "exponerbares": "exponerbar",
    "exponerbarheten": "exponerbarhet",
    "exponerbarhetens": "exponerbarhet",
    "exponerbarhets": "exponerbarhet",
    "exponerbars": "exponerbar",
    "exponerbart": "exponerbar",
    "exponerbarts": "exponerbar",
    "exponeringar": "exponering",
    "exponeringarna": "exponering",
    "exponeringarnas": "exponering",
    "exponeringars": "exponering",
    "exponeringen": "exponering",
    "exponeringens": "exponering",
    "exponerings": "exponering",
    "exponeringsmätar": "exponeringsmätare",
    "exponeringsmätaren": "exponeringsmätare",
    "exponeringsmätarens": "exponeringsmätare",
    "exponeringsmätares": "exponeringsmätare",
    "exponeringsmätarna": "exponeringsmätare",
    "exponeringsmätarnas": "exponeringsmätare",
    "expons": "expo",
    "expor": "expo",
    "exporna": "expo",
    "expornas": "expo",
    "expors": "expo",
    "exportberoenden": "exportberoende",
    "exportberoendena": "exportberoende",
    "exportberoendenas": "exportberoende",
    "exportberoendens": "exportberoende",
    "exportberoendes": "exportberoende",
    "exportberoendet": "exportberoende",
    "exportberoendets": "exportberoende",
    "exportbolagen": "exportbolag",
    "exportbolagens": "exportbolag",
    "exportbolaget": "exportbolag",
    "exportbolagets": "exportbolag",
    "exportbolags": "exportbolag",
    "exporten": "export",
    "exportens": "export",
    "exporter": "export",
    "exporterad": "exportera",
    "exporterade": "exportera",
    "exporterades": "exportera",
    "exporterads": "exportera",
    "exporterande": "exportera",
    "exporteranden": "exporterande",
    "exporterandena": "exporterande",
    "exporterandenas": "exporterande",
    "exporterandens": "exporterande",
    "exporterandes": "exporterande",
    "exporterandet": "exporterande",
    "exporterandets": "exporterande",
    "exporterar": "exportera",
    "exporteras": "exportera",
    "exporterat": "exportera",
    "exporterats": "exportera",
    "exporterbara": "exporterbar",
    "exporterbarare": "exporterbar",
    "exporterbarares": "exporterbar",
    "exporterbaras": "exporterbar",
    "exporterbarast": "exporterbar",
    "exporterbaraste": "exporterbar",
    "exporterbarastes": "exporterbar",
    "exporterbarasts": "exporterbar",
    "exporterbare": "exporterbar",
    "exporterbares": "exporterbar",
    "exporterbarheten": "exporterbarhet",
    "exporterbarhetens": "exporterbarhet",
    "exporterbarhets": "exporterbarhet",
    "exporterbars": "exporterbar",
    "exporterbart": "exporterbar",
    "exporterbarts": "exporterbar",
    "exporteringar": "exportering",
    "exporteringarna": "exportering",
    "exporteringarnas": "exportering",
    "exporteringars": "exportering",
    "exporteringen": "exportering",
    "exporteringens": "exportering",
    "exporterings": "exportering",
    "exporterna": "export",
    "exporternas": "export",
    "exporters": "export",
    "exportinkomsten": "exportinkomst",
    "exportinkomstens": "exportinkomst",
    "exportinkomster": "exportinkomst",
    "exportinkomsterna": "exportinkomst",
    "exportinkomsternas": "exportinkomst",
    "exportinkomsters": "exportinkomst",
    "exportinkomsts": "exportinkomst",
    "exportmarknaden": "exportmarknad",
    "exportmarknadens": "exportmarknad",
    "exportmarknader": "exportmarknad",
    "exportmarknaderna": "exportmarknad",
    "exportmarknadernas": "exportmarknad",
    "exportmarknaders": "exportmarknad",
    "exportmarknads": "exportmarknad",
    "exports": "export",
    "exportspriten": "exportsprit",
    "exportspritens": "exportsprit",
    "exportsprits": "exportsprit",
    "exportölet": "exportöl",
    "exportölets": "exportöl",
    "exportöls": "exportöl",
    "exportören": "exportör",
    "exportörens": "exportör",
    "exportörer": "exportör",
    "exportörerna": "exportör",
    "exportörernas": "exportör",
    "exportörers": "exportör",
    "exportörs": "exportör",
    "expos": "expo",
    "expositionen": "exposition",
    "expositionens": "exposition",
    "expositioner": "exposition",
    "expositionerna": "exposition",
    "expositionernas": "exposition",
    "expositioners": "exposition",
    "expositions": "exposition",
    "exposéer": "exposé",
    "exposéerna": "exposé",
    "exposéernas": "exposé",
    "exposéers": "exposé",
    "exposén": "exposé",
    "exposéns": "exposé",
    "exposés": "exposé",
    "expresidenten": "expresident",
    "expresidentens": "expresident",
    "expresidenter": "expresident",
    "expresidenterna": "expresident",
    "expresidenternas": "expresident",
    "expresidenters": "expresident",
    "expresidents": "expresident",
    "expressbreven": "expressbrev",
    "expressbrevens": "expressbrev",
    "expressbrevet": "expressbrev",
    "expressbrevets": "expressbrev",
    "expressbrevs": "expressbrev",
    "expressbyråer": "expressbyrå",
    "expressbyråerna": "expressbyrå",
    "expressbyråernas": "expressbyrå",
    "expressbyråers": "expressbyrå",
    "expressbyrån": "expressbyrå",
    "expressbyråns": "expressbyrå",
    "expressbyrås": "expressbyrå",
    "expressen": "express",
    "expressens": "express",
    "expresser": "express",
    "expresserna": "express",
    "expressernas": "express",
    "expressers": "express",
    "expressförsändelsen": "expressförsändelse",
    "expressförsändelsens": "expressförsändelse",
    "expressförsändelser": "expressförsändelse",
    "expressförsändelserna": "expressförsändelse",
    "expressförsändelsernas": "expressförsändelse",
    "expressförsändelsers": "expressförsändelse",
    "expressförsändelses": "expressförsändelse",
    "expressionismen": "expressionism",
    "expressionismens": "expressionism",
    "expressionismer": "expressionism",
    "expressionismerna": "expressionism",
    "expressionismernas": "expressionism",
    "expressionismers": "expressionism",
    "expressionisms": "expressionism",
    "expressionisten": "expressionist",
    "expressionistens": "expressionist",
    "expressionister": "expressionist",
    "expressionisterna": "expressionist",
    "expressionisternas": "expressionist",
    "expressionisters": "expressionist",
    "expressionistiska": "expressionistisk",
    "expressionistiskas": "expressionistisk",
    "expressionistiske": "expressionistisk",
    "expressionistiskes": "expressionistisk",
    "expressionistisks": "expressionistisk",
    "expressionistiskt": "expressionistisk",
    "expressionistiskts": "expressionistisk",
    "expressionists": "expressionist",
    "expressiva": "expressiv",
    "expressivare": "expressiv",
    "expressivares": "expressiv",
    "expressivas": "expressiv",
    "expressivast": "expressiv",
    "expressivaste": "expressiv",
    "expressivastes": "expressiv",
    "expressivasts": "expressiv",
    "expressive": "expressiv",
    "expressives": "expressiv",
    "expressiviteten": "expressivitet",
    "expressivitetens": "expressivitet",
    "expressiviteter": "expressivitet",
    "expressiviteterna": "expressivitet",
    "expressiviteternas": "expressivitet",
    "expressiviteters": "expressivitet",
    "expressivitets": "expressivitet",
    "expressivs": "expressiv",
    "expressivt": "expressiv",
    "expressivts": "expressiv",
    "expropriationen": "expropriation",
    "expropriationens": "expropriation",
    "expropriationer": "expropriation",
    "expropriationerna": "expropriation",
    "expropriationernas": "expropriation",
    "expropriationers": "expropriation",
    "expropriations": "expropriation",
    "exproprierad": "expropriera",
    "exproprierade": "expropriera",
    "exproprierades": "expropriera",
    "exproprierads": "expropriera",
    "exproprierande": "expropriera",
    "exproprieranden": "exproprierande",
    "exproprierandena": "exproprierande",
    "exproprierandenas": "exproprierande",
    "exproprierandens": "exproprierande",
    "exproprierandes": "exproprierande",
    "exproprierandet": "exproprierande",
    "exproprierandets": "exproprierande",
    "exproprierar": "expropriera",
    "exproprieras": "expropriera",
    "exproprierat": "expropriera",
    "exproprierats": "expropriera",
    "exproprierbara": "exproprierbar",
    "exproprierbarare": "exproprierbar",
    "exproprierbarares": "exproprierbar",
    "exproprierbaras": "exproprierbar",
    "exproprierbarast": "exproprierbar",
    "exproprierbaraste": "exproprierbar",
    "exproprierbarastes": "exproprierbar",
    "exproprierbarasts": "exproprierbar",
    "exproprierbare": "exproprierbar",
    "exproprierbares": "exproprierbar",
    "exproprierbarheten": "exproprierbarhet",
    "exproprierbarhetens": "exproprierbarhet",
    "exproprierbarhets": "exproprierbarhet",
    "exproprierbars": "exproprierbar",
    "exproprierbart": "exproprierbar",
    "exproprierbarts": "exproprierbar",
    "exproprieringar": "expropriering",
    "exproprieringarna": "expropriering",
    "exproprieringarnas": "expropriering",
    "exproprieringars": "expropriering",
    "exproprieringen": "expropriering",
    "exproprieringens": "expropriering",
    "exproprierings": "expropriering",
    "exsickaten": "exsickat",
    "exsickatens": "exsickat",
    "exsickatet": "exsickat",
    "exsickatets": "exsickat",
    "exsickatorer": "exsickator",
    "exsickatorerna": "exsickator",
    "exsickatorernas": "exsickator",
    "exsickatorers": "exsickator",
    "exsickatorn": "exsickator",
    "exsickatorns": "exsickator",
    "exsickators": "exsickator",
    "exsickats": "exsickat",
    "exspektansen": "exspektans",
    "exspektansens": "exspektans",
    "exspirationen": "exspiration",
    "exspirationens": "exspiration",
    "exspirationer": "exspiration",
    "exspirationerna": "exspiration",
    "exspirationernas": "exspiration",
    "exspirationers": "exspiration",
    "exspirations": "exspiration",
    "exstirperad": "exstirpera",
    "exstirperade": "exstirpera",
    "exstirperades": "exstirpera",
    "exstirperads": "exstirpera",
    "exstirperande": "exstirpera",
    "exstirperanden": "exstirperande",
    "exstirperandena": "exstirperande",
    "exstirperandenas": "exstirperande",
    "exstirperandens": "exstirperande",
    "exstirperandes": "exstirperande",
    "exstirperandet": "exstirperande",
    "exstirperandets": "exstirperande",
    "exstirperar": "exstirpera",
    "exstirperas": "exstirpera",
    "exstirperat": "exstirpera",
    "exstirperats": "exstirpera",
    "exstirperbara": "exstirperbar",
    "exstirperbarare": "exstirperbar",
    "exstirperbarares": "exstirperbar",
    "exstirperbaras": "exstirperbar",
    "exstirperbarast": "exstirperbar",
    "exstirperbaraste": "exstirperbar",
    "exstirperbarastes": "exstirperbar",
    "exstirperbarasts": "exstirperbar",
    "exstirperbare": "exstirperbar",
    "exstirperbares": "exstirperbar",
    "exstirperbarheten": "exstirperbarhet",
    "exstirperbarhetens": "exstirperbarhet",
    "exstirperbarhets": "exstirperbarhet",
    "exstirperbars": "exstirperbar",
    "exstirperbart": "exstirperbar",
    "exstirperbarts": "exstirperbar",
    "exstirperingar": "exstirpering",
    "exstirperingarna": "exstirpering",
    "exstirperingarnas": "exstirpering",
    "exstirperingars": "exstirpering",
    "exstirperingen": "exstirpering",
    "exstirperingens": "exstirpering",
    "exstirperings": "exstirpering",
    "exsudaten": "exsudat",
    "exsudatens": "exsudat",
    "exsudatet": "exsudat",
    "exsudatets": "exsudat",
    "exsudats": "exsudat",
    "extasen": "extas",
    "extasens": "extas",
    "extatiska": "extatisk",
    "extatiskare": "extatisk",
    "extatiskares": "extatisk",
    "extatiskas": "extatisk",
    "extatiskast": "extatisk",
    "extatiskaste": "extatisk",
    "extatiskastes": "extatisk",
    "extatiskasts": "extatisk",
    "extatiske": "extatisk",
    "extatiskes": "extatisk",
    "extatisks": "extatisk",
    "extatiskt": "extatisk",
    "extatiskts": "extatisk",
    "extemporerad": "extemporera",
    "extemporerade": "extemporera",
    "extemporerades": "extemporera",
    "extemporerads": "extemporera",
    "extemporerande": "extemporera",
    "extemporeranden": "extemporerande",
    "extemporerandena": "extemporerande",
    "extemporerandenas": "extemporerande",
    "extemporerandens": "extemporerande",
    "extemporerandes": "extemporerande",
    "extemporerandet": "extemporerande",
    "extemporerandets": "extemporerande",
    "extemporerar": "extemporera",
    "extemporeras": "extemporera",
    "extemporerat": "extemporera",
    "extemporerats": "extemporera",
    "extemporerbara": "extemporerbar",
    "extemporerbarare": "extemporerbar",
    "extemporerbarares": "extemporerbar",
    "extemporerbaras": "extemporerbar",
    "extemporerbarast": "extemporerbar",
    "extemporerbaraste": "extemporerbar",
    "extemporerbarastes": "extemporerbar",
    "extemporerbarasts": "extemporerbar",
    "extemporerbare": "extemporerbar",
    "extemporerbares": "extemporerbar",
    "extemporerbarheten": "extemporerbarhet",
    "extemporerbarhetens": "extemporerbarhet",
    "extemporerbarhets": "extemporerbarhet",
    "extemporerbars": "extemporerbar",
    "extemporerbart": "extemporerbar",
    "extemporerbarts": "extemporerbar",
    "extemporeringar": "extemporering",
    "extemporeringarna": "extemporering",
    "extemporeringarnas": "extemporering",
    "extemporeringars": "extemporering",
    "extemporeringen": "extemporering",
    "extemporeringens": "extemporering",
    "extemporerings": "extemporering",
    "extensionen": "extension",
    "extensionens": "extension",
    "extensioner": "extension",
    "extensionerna": "extension",
    "extensionernas": "extension",
    "extensioners": "extension",
    "extensions": "extension",
    "extensiva": "extensiv",
    "extensivare": "extensiv",
    "extensivares": "extensiv",
    "extensivas": "extensiv",
    "extensivast": "extensiv",
    "extensivaste": "extensiv",
    "extensivastes": "extensiv",
    "extensivasts": "extensiv",
    "extensive": "extensiv",
    "extensives": "extensiv",
    "extensivs": "extensiv",
    "extensivt": "extensiv",
    "extensivts": "extensiv",
    "exteriöra": "exteriör",
    "exteriöras": "exteriör",
    "exteriörbedömningar": "exteriörbedömning",
    "exteriörbedömningarna": "exteriörbedömning",
    "exteriörbedömningarnas": "exteriörbedömning",
    "exteriörbedömningars": "exteriörbedömning",
    "exteriörbedömningen": "exteriörbedömning",
    "exteriörbedömningens": "exteriörbedömning",
    "exteriörbedömnings": "exteriörbedömning",
    "exteriöre": "exteriör",
    "exteriören": "exteriör",
    "exteriörens": "exteriör",
    "exteriörer": "exteriör",
    "exteriörerna": "exteriör",
    "exteriörernas": "exteriör",
    "exteriörers": "exteriör",
    "exteriöres": "exteriör",
    "exteriörs": "exteriör",
    "exteriört": "exteriör",
    "exteriörts": "exteriör",
    "externa": "extern",
    "externare": "extern",
    "externares": "extern",
    "externas": "extern",
    "externast": "extern",
    "externaste": "extern",
    "externastes": "extern",
    "externasts": "extern",
    "externaten": "externat",
    "externatens": "externat",
    "externatet": "externat",
    "externatets": "externat",
    "externats": "externat",
    "externe": "extern",
    "externen": "extern",
    "externens": "extern",
    "externer": "extern",
    "externerna": "extern",
    "externernas": "extern",
    "externers": "extern",
    "externes": "extern",
    "externs": "extern",
    "externt": "extern",
    "externts": "extern",
    "exterritorialrätten": "exterritorialrätt",
    "exterritorialrättens": "exterritorialrätt",
    "exterritorialrätts": "exterritorialrätt",
    "exterritoriella": "exterritoriell",
    "exterritoriellare": "exterritoriell",
    "exterritoriellares": "exterritoriell",
    "exterritoriellas": "exterritoriell",
    "exterritoriellast": "exterritoriell",
    "exterritoriellaste": "exterritoriell",
    "exterritoriellastes": "exterritoriell",
    "exterritoriellasts": "exterritoriell",
    "exterritorielle": "exterritoriell",
    "exterritorielles": "exterritoriell",
    "exterritoriells": "exterritoriell",
    "exterritoriellt": "exterritoriell",
    "exterritoriellts": "exterritoriell",
    "extraarbeten": "extraarbete",
    "extraarbetena": "extraarbete",
    "extraarbetenas": "extraarbete",
    "extraarbetens": "extraarbete",
    "extraarbetes": "extraarbete",
    "extraarbetet": "extraarbete",
    "extraarbetets": "extraarbete",
    "extraarbets": "extraarbete",
    "extrafiltar": "extrafilt",
    "extrafiltarna": "extrafilt",
    "extrafiltarnas": "extrafilt",
    "extrafiltars": "extrafilt",
    "extrafilten": "extrafilt",
    "extrafiltens": "extrafilt",
    "extrafilts": "extrafilt",
    "extraherad": "extrahera",
    "extraherade": "extrahera",
    "extraherades": "extrahera",
    "extraherads": "extrahera",
    "extraherande": "extrahera",
    "extraheranden": "extraherande",
    "extraherandena": "extraherande",
    "extraherandenas": "extraherande",
    "extraherandens": "extraherande",
    "extraherandes": "extraherande",
    "extraherandet": "extraherande",
    "extraherandets": "extraherande",
    "extraherar": "extrahera",
    "extraheras": "extrahera",
    "extraherat": "extrahera",
    "extraherats": "extrahera",
    "extraherbara": "extraherbar",
    "extraherbarare": "extraherbar",
    "extraherbarares": "extraherbar",
    "extraherbaras": "extraherbar",
    "extraherbarast": "extraherbar",
    "extraherbaraste": "extraherbar",
    "extraherbarastes": "extraherbar",
    "extraherbarasts": "extraherbar",
    "extraherbare": "extraherbar",
    "extraherbares": "extraherbar",
    "extraherbarheten": "extraherbarhet",
    "extraherbarhetens": "extraherbarhet",
    "extraherbarhets": "extraherbarhet",
    "extraherbars": "extraherbar",
    "extraherbart": "extraherbar",
    "extraherbarts": "extraherbar",
    "extraheringar": "extrahering",
    "extraheringarna": "extrahering",
    "extraheringarnas": "extrahering",
    "extraheringars": "extrahering",
    "extraheringen": "extrahering",
    "extraheringens": "extrahering",
    "extraherings": "extrahering",
    "extrainkallade": "extrainkallad",
    "extrainkallades": "extrainkallad",
    "extrainkallads": "extrainkallad",
    "extrainkallat": "extrainkallad",
    "extrainkallats": "extrainkallad",
    "extrainkomsten": "extrainkomst",
    "extrainkomstens": "extrainkomst",
    "extrainkomster": "extrainkomst",
    "extrainkomsterna": "extrainkomst",
    "extrainkomsternas": "extrainkomst",
    "extrainkomsters": "extrainkomst",
    "extrainkomsts": "extrainkomst",
    "extrajudiciella": "extrajudiciell",
    "extrajudiciellare": "extrajudiciell",
    "extrajudiciellares": "extrajudiciell",
    "extrajudiciellas": "extrajudiciell",
    "extrajudiciellast": "extrajudiciell",
    "extrajudiciellaste": "extrajudiciell",
    "extrajudiciellastes": "extrajudiciell",
    "extrajudiciellasts": "extrajudiciell",
    "extrajudicielle": "extrajudiciell",
    "extrajudicielles": "extrajudiciell",
    "extrajudiciells": "extrajudiciell",
    "extrajudiciellt": "extrajudiciell",
    "extrajudiciellts": "extrajudiciell",
    "extraknäck": "extraknäcka",
    "extraknäckande": "extraknäcka",
    "extraknäckanden": "extraknäckande",
    "extraknäckandena": "extraknäckande",
    "extraknäckandenas": "extraknäckande",
    "extraknäckandens": "extraknäckande",
    "extraknäckandes": "extraknäckande",
    "extraknäckandet": "extraknäckande",
    "extraknäckandets": "extraknäckande",
    "extraknäckas": "extraknäcka",
    "extraknäcken": "extraknäck",
    "extraknäckens": "extraknäck",
    "extraknäcker": "extraknäcka",
    "extraknäckes": "extraknäcka",
    "extraknäcket": "extraknäck",
    "extraknäckets": "extraknäck",
    "extraknäcks": "extraknäcka",
    "extraknäckt": "extraknäcka",
    "extraknäckte": "extraknäcka",
    "extraknäcktes": "extraknäcka",
    "extraknäckts": "extraknäcka",
    "extrakontanta": "extrakontant",
    "extrakontantare": "extrakontant",
    "extrakontantares": "extrakontant",
    "extrakontantas": "extrakontant",
    "extrakontantast": "extrakontant",
    "extrakontantaste": "extrakontant",
    "extrakontantastes": "extrakontant",
    "extrakontantasts": "extrakontant",
    "extrakontante": "extrakontant",
    "extrakontantes": "extrakontant",
    "extrakontants": "extrakontant",
    "extrakten": "extrakt",
    "extraktens": "extrakt",
    "extrakter": "extrakt",
    "extrakterna": "extrakt",
    "extrakternas": "extrakt",
    "extrakters": "extrakt",
    "extraktet": "extrakt",
    "extraktets": "extrakt",
    "extraktionen": "extraktion",
    "extraktionens": "extraktion",
    "extraktioner": "extraktion",
    "extraktionerna": "extraktion",
    "extraktionernas": "extraktion",
    "extraktioners": "extraktion",
    "extraktions": "extraktion",
    "extraktivämnen": "extraktivämne",
    "extraktivämnena": "extraktivämne",
    "extraktivämnenas": "extraktivämne",
    "extraktivämnens": "extraktivämne",
    "extraktivämnes": "extraktivämne",
    "extraktivämnet": "extraktivämne",
    "extraktivämnets": "extraktivämne",
    "extraktorer": "extraktor",
    "extraktorerna": "extraktor",
    "extraktorernas": "extraktor",
    "extraktorers": "extraktor",
    "extraktorn": "extraktor",
    "extraktorns": "extraktor",
    "extraktors": "extraktor",
    "extrakts": "extrakt",
    "extralamp": "extralampa",
    "extralampan": "extralampa",
    "extralampans": "extralampa",
    "extralampas": "extralampa",
    "extralampe": "extralampa",
    "extralampor": "extralampa",
    "extralamporna": "extralampa",
    "extralampornas": "extralampa",
    "extralampors": "extralampa",
    "extralamps": "extralampa",
    "extraljusen": "extraljus",
    "extraljusens": "extraljus",
    "extraljuset": "extraljus",
    "extraljusets": "extraljus",
    "extramurala": "extramural",
    "extramuralare": "extramural",
    "extramuralares": "extramural",
    "extramuralas": "extramural",
    "extramuralast": "extramural",
    "extramuralaste": "extramural",
    "extramuralastes": "extramural",
    "extramuralasts": "extramural",
    "extramurale": "extramural",
    "extramurales": "extramural",
    "extramurals": "extramural",
    "extramuralt": "extramural",
    "extramuralts": "extramural",
    "extraordinarien": "extraordinarie",
    "extraordinariens": "extraordinarie",
    "extraordinarier": "extraordinarie",
    "extraordinarierna": "extraordinarie",
    "extraordinariernas": "extraordinarie",
    "extraordinariers": "extraordinarie",
    "extraordinaries": "extraordinarie",
    "extraordinära": "extraordinär",
    "extraordinärare": "extraordinär",
    "extraordinärares": "extraordinär",
    "extraordinäras": "extraordinär",
    "extraordinärast": "extraordinär",
    "extraordinäraste": "extraordinär",
    "extraordinärastes": "extraordinär",
    "extraordinärasts": "extraordinär",
    "extraordinäre": "extraordinär",
    "extraordinäres": "extraordinär",
    "extraordinärs": "extraordinär",
    "extraordinärt": "extraordinär",
    "extraordinärts": "extraordinär",
    "extrapolationen": "extrapolation",
    "extrapolationens": "extrapolation",
    "extrapolationer": "extrapolation",
    "extrapolationerna": "extrapolation",
    "extrapolationernas": "extrapolation",
    "extrapolationers": "extrapolation",
    "extrapolations": "extrapolation",
    "extrapolerad": "extrapolera",
    "extrapolerade": "extrapolera",
    "extrapolerades": "extrapolera",
    "extrapolerads": "extrapolera",
    "extrapolerande": "extrapolera",
    "extrapoleranden": "extrapolerande",
    "extrapolerandena": "extrapolerande",
    "extrapolerandenas": "extrapolerande",
    "extrapolerandens": "extrapolerande",
    "extrapolerandes": "extrapolerande",
    "extrapolerandet": "extrapolerande",
    "extrapolerandets": "extrapolerande",
    "extrapolerar": "extrapolera",
    "extrapoleras": "extrapolera",
    "extrapolerat": "extrapolera",
    "extrapolerats": "extrapolera",
    "extrapolerbara": "extrapolerbar",
    "extrapolerbarare": "extrapolerbar",
    "extrapolerbarares": "extrapolerbar",
    "extrapolerbaras": "extrapolerbar",
    "extrapolerbarast": "extrapolerbar",
    "extrapolerbaraste": "extrapolerbar",
    "extrapolerbarastes": "extrapolerbar",
    "extrapolerbarasts": "extrapolerbar",
    "extrapolerbare": "extrapolerbar",
    "extrapolerbares": "extrapolerbar",
    "extrapolerbarheten": "extrapolerbarhet",
    "extrapolerbarhetens": "extrapolerbarhet",
    "extrapolerbarhets": "extrapolerbarhet",
    "extrapolerbars": "extrapolerbar",
    "extrapolerbart": "extrapolerbar",
    "extrapolerbarts": "extrapolerbar",
    "extrapoleringar": "extrapolering",
    "extrapoleringarna": "extrapolering",
    "extrapoleringarnas": "extrapolering",
    "extrapoleringars": "extrapolering",
    "extrapoleringen": "extrapolering",
    "extrapoleringens": "extrapolering",
    "extrapolerings": "extrapolering",
    "extraprisen": "extrapris",
    "extraprisens": "extrapris",
    "extrapriser": "extrapris",
    "extrapriserna": "extrapris",
    "extraprisernas": "extrapris",
    "extraprisers": "extrapris",
    "extrapriset": "extrapris",
    "extraprisets": "extrapris",
    "extraransonen": "extraranson",
    "extraransonens": "extraranson",
    "extraransoner": "extraranson",
    "extraransonerna": "extraranson",
    "extraransonernas": "extraranson",
    "extraransoners": "extraranson",
    "extraransons": "extraranson",
    "extrasolar": "extrasol",
    "extrasolarna": "extrasol",
    "extrasolarnas": "extrasol",
    "extrasolars": "extrasol",
    "extrasolen": "extrasol",
    "extrasolens": "extrasol",
    "extrasols": "extrasol",
    "extraupplagan": "extraupplaga",
    "extraupplagans": "extraupplaga",
    "extraupplagas": "extraupplaga",
    "extraupplage": "extraupplaga",
    "extraupplagor": "extraupplaga",
    "extraupplagorna": "extraupplaga",
    "extraupplagornas": "extraupplaga",
    "extraupplagors": "extraupplaga",
    "extrauterina": "extrauterin",
    "extrauterinare": "extrauterin",
    "extrauterinares": "extrauterin",
    "extrauterinas": "extrauterin",
    "extrauterinast": "extrauterin",
    "extrauterinaste": "extrauterin",
    "extrauterinastes": "extrauterin",
    "extrauterinasts": "extrauterin",
    "extrauterine": "extrauterin",
    "extrauterines": "extrauterin",
    "extrauterins": "extrauterin",
    "extrauterint": "extrauterin",
    "extrauterints": "extrauterin",
    "extravagansen": "extravagans",
    "extravagansens": "extravagans",
    "extravaganser": "extravagans",
    "extravaganserna": "extravagans",
    "extravagansernas": "extravagans",
    "extravagansers": "extravagans",
    "extravaganta": "extravagant",
    "extravagantare": "extravagant",
    "extravagantares": "extravagant",
    "extravagantas": "extravagant",
    "extravagantast": "extravagant",
    "extravagantaste": "extravagant",
    "extravagantastes": "extravagant",
    "extravagantasts": "extravagant",
    "extravagante": "extravagant",
    "extravagantes": "extravagant",
    "extravagants": "extravagant",
    "extrema": "extrem",
    "extremare": "extrem",
    "extremares": "extrem",
    "extremas": "extrem",
    "extremast": "extrem",
    "extremaste": "extrem",
    "extremastes": "extrem",
    "extremasts": "extrem",
    "extreme": "extrem",
    "extremen": "extrem",
    "extremens": "extrem",
    "extremer": "extrem",
    "extremerna": "extrem",
    "extremernas": "extrem",
    "extremers": "extrem",
    "extremes": "extrem",
    "extremfallen": "extremfall",
    "extremfallens": "extremfall",
    "extremfallet": "extremfall",
    "extremfallets": "extremfall",
    "extremfalls": "extremfall",
    "extremismen": "extremism",
    "extremismens": "extremism",
    "extremismer": "extremism",
    "extremismerna": "extremism",
    "extremismernas": "extremism",
    "extremismers": "extremism",
    "extremisms": "extremism",
    "extremisten": "extremist",
    "extremistens": "extremist",
    "extremister": "extremist",
    "extremisterna": "extremist",
    "extremisternas": "extremist",
    "extremisters": "extremist",
    "extremistiska": "extremistisk",
    "extremistiskas": "extremistisk",
    "extremistiske": "extremistisk",
    "extremistiskes": "extremistisk",
    "extremistisks": "extremistisk",
    "extremistiskt": "extremistisk",
    "extremistiskts": "extremistisk",
    "extremists": "extremist",
    "extremiteten": "extremitet",
    "extremitetens": "extremitet",
    "extremiteter": "extremitet",
    "extremiteterna": "extremitet",
    "extremiteternas": "extremitet",
    "extremiteters": "extremitet",
    "extremitets": "extremitet",
    "extremkyl": "extremkyla",
    "extremkylande": "extremkyla",
    "extremkylandes": "extremkyla",
    "extremkylas": "extremkyla",
    "extremkyld": "extremkyla",
    "extremkylda": "extremkyla",
    "extremkyldas": "extremkyla",
    "extremkylde": "extremkyla",
    "extremkyldes": "extremkyla",
    "extremkylds": "extremkyla",
    "extremkyler": "extremkyla",
    "extremkyles": "extremkyla",
    "extremkyls": "extremkyla",
    "extremkylt": "extremkyla",
    "extremkylts": "extremkyla",
    "extremnationalisten": "extremnationalist",
    "extremnationalistens": "extremnationalist",
    "extremnationalister": "extremnationalist",
    "extremnationalisterna": "extremnationalist",
    "extremnationalisternas": "extremnationalist",
    "extremnationalisters": "extremnationalist",
    "extremnationalists": "extremnationalist",
    "extrems": "extrem",
    "extremt": "extrem",
    "extremts": "extrem",
    "extremväderna": "extremväder",
    "extremvädernas": "extremväder",
    "extremväders": "extremväder",
    "extremvädren": "extremväder",
    "extremvädrens": "extremväder",
    "extremvädret": "extremväder",
    "extremvädrets": "extremväder",
    "extrinsiska": "extrinsisk",
    "extrinsiskas": "extrinsisk",
    "extrinsiske": "extrinsisk",
    "extrinsiskes": "extrinsisk",
    "extrinsisks": "extrinsisk",
    "extrinsiskt": "extrinsisk",
    "extrinsiskts": "extrinsisk",
    "extroverta": "extrovert",
    "extrovertare": "extrovert",
    "extrovertares": "extrovert",
    "extrovertas": "extrovert",
    "extrovertast": "extrovert",
    "extrovertaste": "extrovert",
    "extrovertastes": "extrovert",
    "extrovertasts": "extrovert",
    "extroverte": "extrovert",
    "extrovertes": "extrovert",
    "extrovertheten": "extroverthet",
    "extroverthetens": "extroverthet",
    "extroverthets": "extroverthet",
    "extroverts": "extrovert",
    "eye-linern": "eye-liner",
    "eye-linerns": "eye-liner",
    "eye-liners": "eye-liner",
    "eye-linersarna": "eye-liner",
    "eye-linersarnas": "eye-liner",
    "eye-linersen": "eye-liner",
    "eye-linersens": "eye-liner",
    "eyelinern": "eyeliner",
    "eyelinerns": "eyeliner",
    "eyeliners": "eyeliner",
    "eyelinersarna": "eyeliner",
    "eyelinersarnas": "eyeliner",
    "eyelinersen": "eyeliner",
    "eyelinersens": "eyeliner",
    "f-en": "f",
    "f-ens": "f",
    "f-et": "f",
    "f-ets": "f",
    "f-s": "f",
    "f:en": "f",
    "f:ens": "f",
    "f:et": "f",
    "f:ets": "f",
    "f:s": "f",
    "fabelaktiga": "fabelaktig",
    "fabelaktigare": "fabelaktig",
    "fabelaktigares": "fabelaktig",
    "fabelaktigas": "fabelaktig",
    "fabelaktigast": "fabelaktig",
    "fabelaktigaste": "fabelaktig",
    "fabelaktigastes": "fabelaktig",
    "fabelaktigasts": "fabelaktig",
    "fabelaktige": "fabelaktig",
    "fabelaktiges": "fabelaktig",
    "fabelaktigheten": "fabelaktighet",
    "fabelaktighetens": "fabelaktighet",
    "fabelaktighets": "fabelaktighet",
    "fabelaktigs": "fabelaktig",
    "fabelaktigt": "fabelaktig",
    "fabelaktigts": "fabelaktig",
    "fabeldjuren": "fabeldjur",
    "fabeldjurens": "fabeldjur",
    "fabeldjuret": "fabeldjur",
    "fabeldjurets": "fabeldjur",
    "fabeldjurs": "fabeldjur",
    "fabeln": "fabel",
    "fabelns": "fabel",
    "fabels": "fabel",
    "fablade": "fabla",
    "fablades": "fabla",
    "fablande": "fabla",
    "fablanden": "fablande",
    "fablandena": "fablande",
    "fablandenas": "fablande",
    "fablandens": "fablande",
    "fablandes": "fablande",
    "fablandet": "fablande",
    "fablandets": "fablande",
    "fablar": "fabla",
    "fablas": "fabla",
    "fablat": "fabla",
    "fablats": "fabla",
    "fabler": "fabel",
    "fablerna": "fabel",
    "fablernas": "fabel",
    "fablers": "fabel",
    "fabricerad": "fabricera",
    "fabricerade": "fabricera",
    "fabricerades": "fabricera",
    "fabricerads": "fabricera",
    "fabricerande": "fabricera",
    "fabriceranden": "fabricerande",
    "fabricerandena": "fabricerande",
    "fabricerandenas": "fabricerande",
    "fabricerandens": "fabricerande",
    "fabricerandes": "fabricerande",
    "fabricerandet": "fabricerande",
    "fabricerandets": "fabricerande",
    "fabricerar": "fabricera",
    "fabriceras": "fabricera",
    "fabricerat": "fabricera",
    "fabricerats": "fabricera",
    "fabricerbara": "fabricerbar",
    "fabricerbarare": "fabricerbar",
    "fabricerbarares": "fabricerbar",
    "fabricerbaras": "fabricerbar",
    "fabricerbarast": "fabricerbar",
    "fabricerbaraste": "fabricerbar",
    "fabricerbarastes": "fabricerbar",
    "fabricerbarasts": "fabricerbar",
    "fabricerbare": "fabricerbar",
    "fabricerbares": "fabricerbar",
    "fabricerbarheten": "fabricerbarhet",
    "fabricerbarhetens": "fabricerbarhet",
    "fabricerbarhets": "fabricerbarhet",
    "fabricerbars": "fabricerbar",
    "fabricerbart": "fabricerbar",
    "fabricerbarts": "fabricerbar",
    "fabriceringar": "fabricering",
    "fabriceringarna": "fabricering",
    "fabriceringarnas": "fabricering",
    "fabriceringars": "fabricering",
    "fabriceringen": "fabricering",
    "fabriceringens": "fabricering",
    "fabricerings": "fabricering",
    "fabrikanten": "fabrikant",
    "fabrikantens": "fabrikant",
    "fabrikanter": "fabrikant",
    "fabrikanterna": "fabrikant",
    "fabrikanternas": "fabrikant",
    "fabrikanters": "fabrikant",
    "fabrikants": "fabrikant",
    "fabrikaten": "fabrikat",
    "fabrikatens": "fabrikat",
    "fabrikatet": "fabrikat",
    "fabrikatets": "fabrikat",
    "fabrikationen": "fabrikation",
    "fabrikationens": "fabrikation",
    "fabrikationer": "fabrikation",
    "fabrikationerna": "fabrikation",
    "fabrikationernas": "fabrikation",
    "fabrikationers": "fabrikation",
    "fabrikations": "fabrikation",
    "fabrikats": "fabrikat",
    "fabriken": "fabrik",
    "fabrikens": "fabrik",
    "fabriker": "fabrik",
    "fabrikerna": "fabrik",
    "fabrikernas": "fabrik",
    "fabrikers": "fabrik",
    "fabriks": "fabrik",
    "fabriksarbetar": "fabriksarbetare",
    "fabriksarbetaren": "fabriksarbetare",
    "fabriksarbetarens": "fabriksarbetare",
    "fabriksarbetares": "fabriksarbetare",
    "fabriksarbetarna": "fabriksarbetare",
    "fabriksarbetarnas": "fabriksarbetare",
    "fabriksbyggnaden": "fabriksbyggnad",
    "fabriksbyggnadens": "fabriksbyggnad",
    "fabriksbyggnader": "fabriksbyggnad",
    "fabriksbyggnaderna": "fabriksbyggnad",
    "fabriksbyggnadernas": "fabriksbyggnad",
    "fabriksbyggnaders": "fabriksbyggnad",
    "fabriksbyggnads": "fabriksbyggnad",
    "fabriksmässiga": "fabriksmässig",
    "fabriksmässigare": "fabriksmässig",
    "fabriksmässigares": "fabriksmässig",
    "fabriksmässigas": "fabriksmässig",
    "fabriksmässigast": "fabriksmässig",
    "fabriksmässigaste": "fabriksmässig",
    "fabriksmässigastes": "fabriksmässig",
    "fabriksmässigasts": "fabriksmässig",
    "fabriksmässige": "fabriksmässig",
    "fabriksmässiges": "fabriksmässig",
    "fabriksmässigheten": "fabriksmässighet",
    "fabriksmässighetens": "fabriksmässighet",
    "fabriksmässighets": "fabriksmässighet",
    "fabriksmässigs": "fabriksmässig",
    "fabriksmässigt": "fabriksmässig",
    "fabriksmässigts": "fabriksmässig",
    "fabriksnya": "fabriksny",
    "fabriksnyare": "fabriksny",
    "fabriksnyares": "fabriksny",
    "fabriksnyas": "fabriksny",
    "fabriksnyast": "fabriksny",
    "fabriksnyaste": "fabriksny",
    "fabriksnyastes": "fabriksny",
    "fabriksnyasts": "fabriksny",
    "fabriksnye": "fabriksny",
    "fabriksnyes": "fabriksny",
    "fabriksnys": "fabriksny",
    "fabriksnytt": "fabriksny",
    "fabriksnytts": "fabriksny",
    "fabriksområden": "fabriksområde",
    "fabriksområdena": "fabriksområde",
    "fabriksområdenas": "fabriksområde",
    "fabriksområdens": "fabriksområde",
    "fabriksområdes": "fabriksområde",
    "fabriksområdet": "fabriksområde",
    "fabriksområdets": "fabriksområde",
    "fabriksportar": "fabriksport",
    "fabriksportarna": "fabriksport",
    "fabriksportarnas": "fabriksport",
    "fabriksportars": "fabriksport",
    "fabriksporten": "fabriksport",
    "fabriksportens": "fabriksport",
    "fabriksports": "fabriksport",
    "fabriksprisen": "fabrikspris",
    "fabriksprisens": "fabrikspris",
    "fabrikspriser": "fabrikspris",
    "fabrikspriserna": "fabrikspris",
    "fabriksprisernas": "fabrikspris",
    "fabriksprisers": "fabrikspris",
    "fabrikspriset": "fabrikspris",
    "fabriksprisets": "fabrikspris",
    "fabriksskorstenar": "fabriksskorsten",
    "fabriksskorstenarna": "fabriksskorsten",
    "fabriksskorstenarnas": "fabriksskorsten",
    "fabriksskorstenars": "fabriksskorsten",
    "fabriksskorstenen": "fabriksskorsten",
    "fabriksskorstenens": "fabriksskorsten",
    "fabriksskorstens": "fabriksskorsten",
    "fabrikstomten": "fabrikstomt",
    "fabrikstomtens": "fabrikstomt",
    "fabrikstomter": "fabrikstomt",
    "fabrikstomterna": "fabrikstomt",
    "fabrikstomternas": "fabrikstomt",
    "fabrikstomters": "fabrikstomt",
    "fabrikstomts": "fabrikstomt",
    "fabrikören": "fabrikör",
    "fabrikörens": "fabrikör",
    "fabrikörer": "fabrikör",
    "fabrikörerna": "fabrikör",
    "fabrikörernas": "fabrikör",
    "fabrikörers": "fabrikör",
    "fabrikörn": "fabrikör",
    "fabrikörns": "fabrikör",
    "fabrikörs": "fabrikör",
    "fabulerad": "fabulera",
    "fabulerade": "fabulera",
    "fabulerades": "fabulera",
    "fabulerads": "fabulera",
    "fabulerande": "fabulera",
    "fabuleranden": "fabulerande",
    "fabulerandena": "fabulerande",
    "fabulerandenas": "fabulerande",
    "fabulerandens": "fabulerande",
    "fabulerandes": "fabulerande",
    "fabulerandet": "fabulerande",
    "fabulerandets": "fabulerande",
    "fabulerar": "fabulera",
    "fabuleras": "fabulera",
    "fabulerat": "fabulera",
    "fabulerats": "fabulera",
    "fabulerbara": "fabulerbar",
    "fabulerbarare": "fabulerbar",
    "fabulerbarares": "fabulerbar",
    "fabulerbaras": "fabulerbar",
    "fabulerbarast": "fabulerbar",
    "fabulerbaraste": "fabulerbar",
    "fabulerbarastes": "fabulerbar",
    "fabulerbarasts": "fabulerbar",
    "fabulerbare": "fabulerbar",
    "fabulerbares": "fabulerbar",
    "fabulerbarheten": "fabulerbarhet",
    "fabulerbarhetens": "fabulerbarhet",
    "fabulerbarhets": "fabulerbarhet",
    "fabulerbars": "fabulerbar",
    "fabulerbart": "fabulerbar",
    "fabulerbarts": "fabulerbar",
    "fabuleringar": "fabulering",
    "fabuleringarna": "fabulering",
    "fabuleringarnas": "fabulering",
    "fabuleringars": "fabulering",
    "fabuleringen": "fabulering",
    "fabuleringens": "fabulering",
    "fabulerings": "fabulering",
    "fabulösa": "fabulös",
    "fabulösare": "fabulös",
    "fabulösares": "fabulös",
    "fabulösas": "fabulös",
    "fabulösast": "fabulös",
    "fabulösaste": "fabulös",
    "fabulösastes": "fabulös",
    "fabulösasts": "fabulös",
    "fabulöse": "fabulös",
    "fabulöses": "fabulös",
    "fabulöst": "fabulös",
    "fabulösts": "fabulös",
    "facebookad": "facebooka",
    "facebookade": "facebooka",
    "facebookades": "facebooka",
    "facebookads": "facebooka",
    "facebookande": "facebooka",
    "facebookanden": "facebookande",
    "facebookandena": "facebookande",
    "facebookandenas": "facebookande",
    "facebookandens": "facebookande",
    "facebookandes": "facebookande",
    "facebookandet": "facebookande",
    "facebookandets": "facebookande",
    "facebookar": "facebooka",
    "facebookas": "facebooka",
    "facebookat": "facebooka",
    "facebookats": "facebooka",
    "facebookbildens": "facebookbild",
    "facebookbildernas": "facebookbild",
    "facebookbilders": "facebookbild",
    "facebookgruppens": "facebookgrupp",
    "facebookgruppernas": "facebookgrupp",
    "facebookgruppers": "facebookgrupp",
    "facetten": "facett",
    "facettens": "facett",
    "facetter": "facett",
    "facetterad": "facettera",
    "facetterade": "facetterad",
    "facetterades": "facetterad",
    "facetterads": "facetterad",
    "facetterande": "facettera",
    "facetteranden": "facetterande",
    "facetterandena": "facetterande",
    "facetterandenas": "facetterande",
    "facetterandens": "facetterande",
    "facetterandes": "facetterande",
    "facetterandet": "facetterande",
    "facetterandets": "facetterande",
    "facetterar": "facettera",
    "facetteras": "facettera",
    "facetterat": "facetterad",
    "facetterats": "facetterad",
    "facetterbara": "facetterbar",
    "facetterbarare": "facetterbar",
    "facetterbarares": "facetterbar",
    "facetterbaras": "facetterbar",
    "facetterbarast": "facetterbar",
    "facetterbaraste": "facetterbar",
    "facetterbarastes": "facetterbar",
    "facetterbarasts": "facetterbar",
    "facetterbare": "facetterbar",
    "facetterbares": "facetterbar",
    "facetterbarheten": "facetterbarhet",
    "facetterbarhetens": "facetterbarhet",
    "facetterbarhets": "facetterbarhet",
    "facetterbars": "facetterbar",
    "facetterbart": "facetterbar",
    "facetterbarts": "facetterbar",
    "facetteringar": "facettering",
    "facetteringarna": "facettering",
    "facetteringarnas": "facettering",
    "facetteringars": "facettering",
    "facetteringen": "facettering",
    "facetteringens": "facettering",
    "facetterings": "facettering",
    "facetterna": "facett",
    "facetternas": "facett",
    "facetters": "facett",
    "facetts": "facett",
    "facettögas": "facettöga",
    "facettögat": "facettöga",
    "facettögats": "facettöga",
    "facettögon": "facettöga",
    "facettögonen": "facettöga",
    "facettögonens": "facettöga",
    "facettögons": "facettöga",
    "facila": "facil",
    "facilare": "facil",
    "facilares": "facil",
    "facilas": "facil",
    "facilast": "facil",
    "facilaste": "facil",
    "facilastes": "facil",
    "facilasts": "facil",
    "facile": "facil",
    "faciles": "facil",
    "faciliteten": "facilitet",
    "facilitetens": "facilitet",
    "faciliteter": "facilitet",
    "faciliteterna": "facilitet",
    "faciliteternas": "facilitet",
    "faciliteters": "facilitet",
    "facilitets": "facilitet",
    "facils": "facil",
    "facilt": "facil",
    "facilts": "facil",
    "facits": "facit",
    "fackel": "fackla",
    "fackelblomsterna": "fackelblomster",
    "fackelblomsternas": "fackelblomster",
    "fackelblomsters": "fackelblomster",
    "fackelblomstren": "fackelblomster",
    "fackelblomstrens": "fackelblomster",
    "fackelblomstret": "fackelblomster",
    "fackelblomstrets": "fackelblomster",
    "fackeltågen": "fackeltåg",
    "fackeltågens": "fackeltåg",
    "fackeltåget": "fackeltåg",
    "fackeltågets": "fackeltåg",
    "fackeltågs": "fackeltåg",
    "facken": "fack",
    "fackens": "fack",
    "facket": "fack",
    "fackets": "fack",
    "fackförbunden": "fackförbund",
    "fackförbundens": "fackförbund",
    "fackförbundet": "fackförbund",
    "fackförbundets": "fackförbund",
    "fackförbunds": "fackförbund",
    "fackföreningar": "fackförening",
    "fackföreningarna": "fackförening",
    "fackföreningarnas": "fackförening",
    "fackföreningars": "fackförening",
    "fackföreningen": "fackförening",
    "fackföreningens": "fackförening",
    "fackförenings": "fackförening",
    "fackföreningsrörelsen": "fackföreningsrörelse",
    "fackföreningsrörelsens": "fackföreningsrörelse",
    "fackföreningsrörelser": "fackföreningsrörelse",
    "fackföreningsrörelserna": "fackföreningsrörelse",
    "fackföreningsrörelsernas": "fackföreningsrörelse",
    "fackföreningsrörelsers": "fackföreningsrörelse",
    "fackföreningsrörelses": "fackföreningsrörelse",
    "fackhögskolan": "fackhögskola",
    "fackhögskolans": "fackhögskola",
    "fackhögskolas": "fackhögskola",
    "fackhögskole": "fackhögskola",
    "fackhögskolor": "fackhögskola",
    "fackhögskolorna": "fackhögskola",
    "fackhögskolornas": "fackhögskola",
    "fackhögskolors": "fackhögskola",
    "fackidioten": "fackidiot",
    "fackidiotens": "fackidiot",
    "fackidioter": "fackidiot",
    "fackidioterna": "fackidiot",
    "fackidioternas": "fackidiot",
    "fackidioters": "fackidiot",
    "fackidiots": "fackidiot",
    "fackkunniga": "fackkunnig",
    "fackkunnigare": "fackkunnig",
    "fackkunnigares": "fackkunnig",
    "fackkunnigas": "fackkunnig",
    "fackkunnigast": "fackkunnig",
    "fackkunnigaste": "fackkunnig",
    "fackkunnigastes": "fackkunnig",
    "fackkunnigasts": "fackkunnig",
    "fackkunnige": "fackkunnig",
    "fackkunniges": "fackkunnig",
    "fackkunnigheten": "fackkunnighet",
    "fackkunnighetens": "fackkunnighet",
    "fackkunnighets": "fackkunnighet",
    "fackkunnigs": "fackkunnig",
    "fackkunnigt": "fackkunnig",
    "fackkunnigts": "fackkunnig",
    "fackkunskapen": "fackkunskap",
    "fackkunskapens": "fackkunskap",
    "fackkunskaper": "fackkunskap",
    "fackkunskaperna": "fackkunskap",
    "fackkunskapernas": "fackkunskap",
    "fackkunskapers": "fackkunskap",
    "fackkunskaps": "fackkunskap",
    "facklan": "fackla",
    "facklans": "fackla",
    "facklas": "fackla",
    "fackle": "fackla",
    "facklig-politiska": "facklig-politisk",
    "facklig-politiskas": "facklig-politisk",
    "facklig-politiske": "facklig-politisk",
    "facklig-politiskes": "facklig-politisk",
    "facklig-politisks": "facklig-politisk",
    "facklig-politiskt": "facklig-politisk",
    "facklig-politiskts": "facklig-politisk",
    "fackliga": "facklig",
    "fackligare": "facklig",
    "fackligares": "facklig",
    "fackligas": "facklig",
    "fackligast": "facklig",
    "fackligaste": "facklig",
    "fackligastes": "facklig",
    "fackligasts": "facklig",
    "facklige": "facklig",
    "fackliges": "facklig",
    "fackligheten": "facklighet",
    "facklighetens": "facklighet",
    "facklighets": "facklighet",
    "fackligpolitiska": "fackligpolitisk",
    "fackligpolitiskas": "fackligpolitisk",
    "fackligpolitiske": "fackligpolitisk",
    "fackligpolitiskes": "fackligpolitisk",
    "fackligpolitisks": "fackligpolitisk",
    "fackligpolitiskt": "fackligpolitisk",
    "fackligpolitiskts": "fackligpolitisk",
    "fackligs": "facklig",
    "fackligt": "facklig",
    "fackligt-politiska": "fackligt-politisk",
    "fackligt-politiskas": "fackligt-politisk",
    "fackligt-politiske": "fackligt-politisk",
    "fackligt-politiskes": "fackligt-politisk",
    "fackligt-politisks": "fackligt-politisk",
    "fackligt-politiskt": "fackligt-politisk",
    "fackligt-politiskts": "fackligt-politisk",
    "fackligtpolitiska": "fackligtpolitisk",
    "fackligtpolitiskas": "fackligtpolitisk",
    "fackligtpolitiske": "fackligtpolitisk",
    "fackligtpolitiskes": "fackligtpolitisk",
    "fackligtpolitisks": "fackligtpolitisk",
    "fackligtpolitiskt": "fackligtpolitisk",
    "fackligtpolitiskts": "fackligtpolitisk",
    "fackligts": "facklig",
    "facklitteraturen": "facklitteratur",
    "facklitteraturens": "facklitteratur",
    "facklitteraturs": "facklitteratur",
    "facklor": "fackla",
    "facklorna": "fackla",
    "facklornas": "fackla",
    "facklors": "fackla",
    "fackmannamässiga": "fackmannamässig",
    "fackmannamässigare": "fackmannamässig",
    "fackmannamässigares": "fackmannamässig",
    "fackmannamässigas": "fackmannamässig",
    "fackmannamässigast": "fackmannamässig",
    "fackmannamässigaste": "fackmannamässig",
    "fackmannamässigastes": "fackmannamässig",
    "fackmannamässigasts": "fackmannamässig",
    "fackmannamässige": "fackmannamässig",
    "fackmannamässiges": "fackmannamässig",
    "fackmannamässigs": "fackmannamässig",
    "fackmannamässigt": "fackmannamässig",
    "fackmannamässigts": "fackmannamässig",
    "fackmannen": "fackman",
    "fackmannens": "fackman",
    "fackmans": "fackman",
    "fackministern": "fackminister",
    "fackministerns": "fackminister",
    "fackministers": "fackminister",
    "fackministrar": "fackminister",
    "fackministrarna": "fackminister",
    "fackministrarnas": "fackminister",
    "fackministrars": "fackminister",
    "fackmän": "fackman",
    "fackmännen": "fackman",
    "fackmännens": "fackman",
    "fackmäns": "fackman",
    "fackmässiga": "fackmässig",
    "fackmässigare": "fackmässig",
    "fackmässigares": "fackmässig",
    "fackmässigas": "fackmässig",
    "fackmässigast": "fackmässig",
    "fackmässigaste": "fackmässig",
    "fackmässigastes": "fackmässig",
    "fackmässigasts": "fackmässig",
    "fackmässige": "fackmässig",
    "fackmässiges": "fackmässig",
    "fackmässigheten": "fackmässighet",
    "fackmässighetens": "fackmässighet",
    "fackmässighets": "fackmässighet",
    "fackmässigs": "fackmässig",
    "fackmässigt": "fackmässig",
    "fackmässigts": "fackmässig",
    "fackordboken": "fackordbok",
    "fackordbokens": "fackordbok",
    "fackordboks": "fackordbok",
    "fackordböcker": "fackordbok",
    "fackordböckerna": "fackordbok",
    "fackordböckernas": "fackordbok",
    "fackordböckers": "fackordbok",
    "fackorganen": "fackorgan",
    "fackorganens": "fackorgan",
    "fackorganet": "fackorgan",
    "fackorganets": "fackorgan",
    "fackorgans": "fackorgan",
    "fackpressen": "fackpress",
    "fackpressens": "fackpress",
    "fackprosan": "fackprosa",
    "fackprosans": "fackprosa",
    "fackprosas": "fackprosa",
    "facks": "fack",
    "fackskolan": "fackskola",
    "fackskolans": "fackskola",
    "fackskolas": "fackskola",
    "fackskole": "fackskola",
    "fackskolor": "fackskola",
    "fackskolorna": "fackskola",
    "fackskolornas": "fackskola",
    "fackskolors": "fackskola",
    "fackspråken": "fackspråk",
    "fackspråkens": "fackspråk",
    "fackspråket": "fackspråk",
    "fackspråkets": "fackspråk",
    "fackspråks": "fackspråk",
    "facktermen": "fackterm",
    "facktermens": "fackterm",
    "facktermer": "fackterm",
    "facktermerna": "fackterm",
    "facktermernas": "fackterm",
    "facktermers": "fackterm",
    "fackterms": "fackterm",
    "facktidskriften": "facktidskrift",
    "facktidskriftens": "facktidskrift",
    "facktidskrifter": "facktidskrift",
    "facktidskrifterna": "facktidskrift",
    "facktidskrifternas": "facktidskrift",
    "facktidskrifters": "facktidskrift",
    "facktidskrifts": "facktidskrift",
    "fackutskottsprincipen": "fackutskottsprincip",
    "fackutskottsprincipens": "fackutskottsprincip",
    "fackutskottsprinciper": "fackutskottsprincip",
    "fackutskottsprinciperna": "fackutskottsprincip",
    "fackutskottsprincipernas": "fackutskottsprincip",
    "fackutskottsprincipers": "fackutskottsprincip",
    "fackutskottsprincips": "fackutskottsprincip",
    "fackverken": "fackverk",
    "fackverkens": "fackverk",
    "fackverket": "fackverk",
    "fackverkets": "fackverk",
    "fackverks": "fackverk",
    "factoringen": "factoring",
    "factoringens": "factoring",
    "factorings": "factoring",
    "fadda": "fadd",
    "faddare": "fadd",
    "faddares": "fadd",
    "faddas": "fadd",
    "faddast": "fadd",
    "faddaste": "fadd",
    "faddastes": "fadd",
    "faddasts": "fadd",
    "fadde": "fadd",
    "fadderbarnen": "fadderbarn",
    "fadderbarnens": "fadderbarn",
    "fadderbarnet": "fadderbarn",
    "fadderbarnets": "fadderbarn",
    "fadderbarns": "fadderbarn",
    "faddergalan": "faddergala",
    "faddergalans": "faddergala",
    "faddergalas": "faddergala",
    "faddergale": "faddergala",
    "faddergalor": "faddergala",
    "faddergalorna": "faddergala",
    "faddergalornas": "faddergala",
    "faddergalors": "faddergala",
    "faddergåvan": "faddergåva",
    "faddergåvans": "faddergåva",
    "faddergåvas": "faddergåva",
    "faddergåve": "faddergåva",
    "faddergåvo": "faddergåva",
    "faddergåvor": "faddergåva",
    "faddergåvorna": "faddergåva",
    "faddergåvornas": "faddergåva",
    "faddergåvors": "faddergåva",
    "faddern": "fadder",
    "fadderns": "fadder",
    "fadders": "fadder",
    "faddes": "fadd",
    "faddheten": "faddhet",
    "faddhetens": "faddhet",
    "faddhets": "faddhet",
    "faddrar": "fadder",
    "faddrarna": "fadder",
    "faddrarnas": "fadder",
    "faddrars": "fadder",
    "fadds": "fadd",
    "fader": "far",
    "faderliga": "faderlig",
    "faderligare": "faderlig",
    "faderligares": "faderlig",
    "faderligas": "faderlig",
    "faderligast": "faderlig",
    "faderligaste": "faderlig",
    "faderligastes": "faderlig",
    "faderligasts": "faderlig",
    "faderlige": "faderlig",
    "faderliges": "faderlig",
    "faderligheten": "faderlighet",
    "faderlighetens": "faderlighet",
    "faderlighets": "faderlighet",
    "faderligs": "faderlig",
    "faderligt": "faderlig",
    "faderligts": "faderlig",
    "fadermorden": "fadermord",
    "fadermordens": "fadermord",
    "fadermordet": "fadermord",
    "fadermordets": "fadermord",
    "fadermords": "fadermord",
    "fadermördar": "fadermördare",
    "fadermördaren": "fadermördare",
    "fadermördarens": "fadermördare",
    "fadermördares": "fadermördare",
    "fadermördarna": "fadermördare",
    "fadermördarnas": "fadermördare",
    "fadern": "far",
    "faderns": "far",
    "faders": "far",
    "fadersarven": "fadersarv",
    "fadersarvens": "fadersarv",
    "fadersarvet": "fadersarv",
    "fadersarvets": "fadersarv",
    "fadersarvs": "fadersarv",
    "fadersfiguren": "fadersfigur",
    "fadersfigurens": "fadersfigur",
    "fadersfigurer": "fadersfigur",
    "fadersfigurerna": "fadersfigur",
    "fadersfigurernas": "fadersfigur",
    "fadersfigurers": "fadersfigur",
    "fadersfigurs": "fadersfigur",
    "fadersgestalten": "fadersgestalt",
    "fadersgestaltens": "fadersgestalt",
    "fadersgestalter": "fadersgestalt",
    "fadersgestalterna": "fadersgestalt",
    "fadersgestalternas": "fadersgestalt",
    "fadersgestalters": "fadersgestalt",
    "fadersgestalts": "fadersgestalt",
    "fadershjärt": "fadershjärta",
    "fadershjärtan": "fadershjärta",
    "fadershjärtana": "fadershjärta",
    "fadershjärtanas": "fadershjärta",
    "fadershjärtans": "fadershjärta",
    "fadershjärtas": "fadershjärta",
    "fadershjärtat": "fadershjärta",
    "fadershjärtats": "fadershjärta",
    "fadershjärts": "fadershjärta",
    "fadershusen": "fadershus",
    "fadershusens": "fadershus",
    "fadershuset": "fadershus",
    "fadershusets": "fadershus",
    "faderskapet": "faderskap",
    "faderskapets": "faderskap",
    "faderskaps": "faderskap",
    "faderskomplexen": "faderskomplex",
    "faderskomplexens": "faderskomplex",
    "faderskomplexet": "faderskomplex",
    "faderskomplexets": "faderskomplex",
    "fadersnamnen": "fadersnamn",
    "fadersnamnens": "fadersnamn",
    "fadersnamnet": "fadersnamn",
    "fadersnamnets": "fadersnamn",
    "fadersnamns": "fadersnamn",
    "fadersvälden": "fadersvälde",
    "fadersväldena": "fadersvälde",
    "fadersväldenas": "fadersvälde",
    "fadersväldens": "fadersvälde",
    "fadersväldes": "fadersvälde",
    "fadersväldet": "fadersvälde",
    "fadersväldets": "fadersvälde",
    "fadervren": "fadervår",
    "fadervrens": "fadervår",
    "fadervret": "fadervår",
    "fadervrets": "fadervår",
    "fadervåren": "fadervår",
    "fadervårens": "fadervår",
    "fadervåret": "fadervår",
    "fadervårets": "fadervår",
    "fadervårs": "fadervår",
    "fadingen": "fading",
    "fadingens": "fading",
    "fadings": "fading",
    "fadäsen": "fadäs",
    "fadäsens": "fadäs",
    "fadäser": "fadäs",
    "fadäserna": "fadäs",
    "fadäsernas": "fadäs",
    "fadäsers": "fadäs",
    "fagers": "fager",
    "fagert": "fager",
    "fagerts": "fager",
    "fagotten": "fagott",
    "fagottens": "fagott",
    "fagotter": "fagott",
    "fagotterna": "fagott",
    "fagotternas": "fagott",
    "fagotters": "fagott",
    "fagotts": "fagott",
    "fagra": "fager",
    "fagrare": "fager",
    "fagrares": "fager",
    "fagras": "fager",
    "fagrast": "fager",
    "fagraste": "fager",
    "fagrastes": "fager",
    "fagrasts": "fager",
    "fagre": "fager",
    "fagres": "fager",
    "faiblessen": "faiblesse",
    "faiblessens": "faiblesse",
    "faiblesser": "faiblesse",
    "faiblesserna": "faiblesse",
    "faiblessernas": "faiblesse",
    "faiblessers": "faiblesse",
    "faiblesses": "faiblesse",
    "fajansen": "fajans",
    "fajansens": "fajans",
    "fajanser": "fajans",
    "fajanserna": "fajans",
    "fajansernas": "fajans",
    "fajansers": "fajans",
    "fajtades": "fajtas",
    "fajtats": "fajtas",
    "fajten": "fajt",
    "fajtens": "fajt",
    "fajter": "fajt",
    "fajtern": "fajter",
    "fajterna": "fajter",
    "fajternas": "fajter",
    "fajterns": "fajter",
    "fajters": "fajter",
    "fajtersarna": "fajter",
    "fajtersarnas": "fajter",
    "fajtersen": "fajter",
    "fajtersens": "fajter",
    "fajts": "fajt",
    "fakiren": "fakir",
    "fakirens": "fakir",
    "fakirer": "fakir",
    "fakirerna": "fakir",
    "fakirernas": "fakir",
    "fakirers": "fakir",
    "fakirs": "fakir",
    "faksimilen": "faksimile",
    "faksimilens": "faksimile",
    "faksimiler": "faksimile",
    "faksimilerna": "faksimile",
    "faksimilernas": "faksimile",
    "faksimilers": "faksimile",
    "faksimiles": "faksimile",
    "faksimilet": "faksimil",
    "faksimilets": "faksimil",
    "faksimils": "faksimil",
    "fakta": "faktum",
    "faktafelen": "faktafel",
    "faktafelens": "faktafel",
    "faktafelet": "faktafel",
    "faktafelets": "faktafel",
    "faktafels": "faktafel",
    "faktafoldern": "faktafolder",
    "faktafolderns": "faktafolder",
    "faktafolders": "faktafolder",
    "faktafoldrar": "faktafolder",
    "faktafoldrarna": "faktafolder",
    "faktafoldrarnas": "faktafolder",
    "faktafoldrars": "faktafolder",
    "faktagranskningar": "faktagranskning",
    "faktagranskningarna": "faktagranskning",
    "faktagranskningarnas": "faktagranskning",
    "faktagranskningars": "faktagranskning",
    "faktagranskningen": "faktagranskning",
    "faktagranskningens": "faktagranskning",
    "faktagransknings": "faktagranskning",
    "faktakollen": "faktakoll",
    "faktakollens": "faktakoll",
    "faktakolls": "faktakoll",
    "faktamässiga": "faktamässig",
    "faktamässigare": "faktamässig",
    "faktamässigares": "faktamässig",
    "faktamässigas": "faktamässig",
    "faktamässigast": "faktamässig",
    "faktamässigaste": "faktamässig",
    "faktamässigastes": "faktamässig",
    "faktamässigasts": "faktamässig",
    "faktamässige": "faktamässig",
    "faktamässiges": "faktamässig",
    "faktamässigs": "faktamässig",
    "faktamässigt": "faktamässig",
    "faktamässigts": "faktamässig",
    "faktan": "fakta",
    "faktana": "faktum",
    "faktanas": "faktum",
    "faktans": "fakta",
    "faktas": "faktum",
    "faktat": "fakta",
    "faktats": "fakta",
    "fakticiteten": "fakticitet",
    "fakticitetens": "fakticitet",
    "fakticiteter": "fakticitet",
    "fakticiteterna": "fakticitet",
    "fakticiteternas": "fakticitet",
    "fakticiteters": "fakticitet",
    "fakticitets": "fakticitet",
    "faktiska": "faktisk",
    "faktiskare": "faktisk",
    "faktiskares": "faktisk",
    "faktiskas": "faktisk",
    "faktiskast": "faktisk",
    "faktiskaste": "faktisk",
    "faktiskastes": "faktisk",
    "faktiskasts": "faktisk",
    "faktiske": "faktisk",
    "faktiskes": "faktisk",
    "faktisks": "faktisk",
    "faktiskt": "faktisk",
    "faktiskts": "faktisk",
    "faktoranalysen": "faktoranalys",
    "faktoranalysens": "faktoranalys",
    "faktoranalyser": "faktoranalys",
    "faktoranalyserna": "faktoranalys",
    "faktoranalysernas": "faktoranalys",
    "faktoranalysers": "faktoranalys",
    "faktorer": "faktor",
    "faktorerna": "faktor",
    "faktorernas": "faktor",
    "faktorers": "faktor",
    "faktorier": "faktori",
    "faktorierna": "faktori",
    "faktoriernas": "faktori",
    "faktoriers": "faktori",
    "faktoriet": "faktori",
    "faktoriets": "faktori",
    "faktoris": "faktori",
    "faktorit": "faktori",
    "faktorits": "faktori",
    "faktorn": "faktor",
    "faktorns": "faktor",
    "faktors": "faktor",
    "faktotumen": "faktotum",
    "faktotumens": "faktotum",
    "faktotumet": "faktotum",
    "faktotumets": "faktotum",
    "faktotums": "faktotum",
    "faktumen": "faktum",
    "faktumens": "faktum",
    "faktumet": "faktum",
    "faktumets": "faktum",
    "faktums": "faktum",
    "faktur": "faktura",
    "fakturan": "faktura",
    "fakturans": "faktura",
    "fakturas": "faktura",
    "fakture": "faktura",
    "fakturen": "faktur",
    "fakturens": "faktur",
    "fakturerad": "fakturera",
    "fakturerade": "fakturera",
    "fakturerades": "fakturera",
    "fakturerads": "fakturera",
    "fakturerande": "fakturera",
    "faktureranden": "fakturerande",
    "fakturerandena": "fakturerande",
    "fakturerandenas": "fakturerande",
    "fakturerandens": "fakturerande",
    "fakturerandes": "fakturerande",
    "fakturerandet": "fakturerande",
    "fakturerandets": "fakturerande",
    "fakturerar": "fakturera",
    "faktureras": "fakturera",
    "fakturerat": "fakturera",
    "fakturerats": "fakturera",
    "fakturerbara": "fakturerbar",
    "fakturerbarare": "fakturerbar",
    "fakturerbarares": "fakturerbar",
    "fakturerbaras": "fakturerbar",
    "fakturerbarast": "fakturerbar",
    "fakturerbaraste": "fakturerbar",
    "fakturerbarastes": "fakturerbar",
    "fakturerbarasts": "fakturerbar",
    "fakturerbare": "fakturerbar",
    "fakturerbares": "fakturerbar",
    "fakturerbarheten": "fakturerbarhet",
    "fakturerbarhetens": "fakturerbarhet",
    "fakturerbarhets": "fakturerbarhet",
    "fakturerbars": "fakturerbar",
    "fakturerbart": "fakturerbar",
    "fakturerbarts": "fakturerbar",
    "faktureringar": "fakturering",
    "faktureringarna": "fakturering",
    "faktureringarnas": "fakturering",
    "faktureringars": "fakturering",
    "faktureringen": "fakturering",
    "faktureringens": "fakturering",
    "fakturerings": "fakturering",
    "fakturor": "faktura",
    "fakturorna": "faktura",
    "fakturornas": "faktura",
    "fakturors": "faktura",
    "fakturs": "faktura",
    "fakultativa": "fakultativ",
    "fakultativare": "fakultativ",
    "fakultativares": "fakultativ",
    "fakultativas": "fakultativ",
    "fakultativast": "fakultativ",
    "fakultativaste": "fakultativ",
    "fakultativastes": "fakultativ",
    "fakultativasts": "fakultativ",
    "fakultative": "fakultativ",
    "fakultatives": "fakultativ",
    "fakultativs": "fakultativ",
    "fakultativt": "fakultativ",
    "fakultativts": "fakultativ",
    "fakulteten": "fakultet",
    "fakultetens": "fakultet",
    "fakulteter": "fakultet",
    "fakulteterna": "fakultet",
    "fakulteternas": "fakultet",
    "fakulteters": "fakultet",
    "fakultets": "fakultet",
    "fakultetsopponenten": "fakultetsopponent",
    "fakultetsopponentens": "fakultetsopponent",
    "fakultetsopponenter": "fakultetsopponent",
    "fakultetsopponenterna": "fakultetsopponent",
    "fakultetsopponenternas": "fakultetsopponent",
    "fakultetsopponenters": "fakultetsopponent",
    "fakultetsopponents": "fakultetsopponent",
    "fala": "fal",
    "falafelbull": "falafelbulle",
    "falafelbullar": "falafelbulle",
    "falafelbullarna": "falafelbulle",
    "falafelbullarnas": "falafelbulle",
    "falafelbullars": "falafelbulle",
    "falafelbullen": "falafelbulle",
    "falafelbullens": "falafelbulle",
    "falafelbulles": "falafelbulle",
    "falafelbulls": "falafelbulle",
    "falafeln": "falafel",
    "falafelns": "falafel",
    "falafels": "falafel",
    "falaflar": "falafel",
    "falaflarna": "falafel",
    "falaflarnas": "falafel",
    "falaflars": "falafel",
    "falafler": "falafel",
    "falaflerna": "falafel",
    "falaflernas": "falafel",
    "falaflers": "falafel",
    "falangen": "falang",
    "falangens": "falang",
    "falanger": "falang",
    "falangerna": "falang",
    "falangernas": "falang",
    "falangers": "falang",
    "falangisten": "falangist",
    "falangistens": "falangist",
    "falangister": "falangist",
    "falangisterna": "falangist",
    "falangisternas": "falangist",
    "falangisters": "falangist",
    "falangists": "falangist",
    "falangs": "falang",
    "falare": "fal",
    "falares": "fal",
    "falas": "fal",
    "falast": "fal",
    "falaste": "fal",
    "falastes": "fal",
    "falasts": "fal",
    "faldiga": "faldig",
    "faldigare": "faldig",
    "faldigares": "faldig",
    "faldigas": "faldig",
    "faldigast": "faldig",
    "faldigaste": "faldig",
    "faldigastes": "faldig",
    "faldigasts": "faldig",
    "faldige": "faldig",
    "faldiges": "faldig",
    "faldigs": "faldig",
    "faldigt": "faldig",
    "faldigts": "faldig",
    "fale": "fal",
    "falernern": "falerner",
    "falernerns": "falerner",
    "falerners": "falerner",
    "fales": "fal",
    "falheten": "falhet",
    "falhetens": "falhet",
    "falhets": "falhet",
    "falkade": "falka",
    "falkades": "falka",
    "falkande": "falka",
    "falkanden": "falkande",
    "falkandena": "falkande",
    "falkandenas": "falkande",
    "falkandens": "falkande",
    "falkandes": "falkande",
    "falkandet": "falkande",
    "falkandets": "falkande",
    "falkar": "falka",
    "falkarna": "falk",
    "falkarnas": "falk",
    "falkars": "falk",
    "falkas": "falka",
    "falkat": "falka",
    "falkats": "falka",
    "falkblicken": "falkblick",
    "falkblickens": "falkblick",
    "falkblicks": "falkblick",
    "falken": "falk",
    "falkenerar": "falkenerare",
    "falkeneraren": "falkenerare",
    "falkenerarens": "falkenerare",
    "falkenerares": "falkenerare",
    "falkenerarna": "falkenerare",
    "falkenerarnas": "falkenerare",
    "falkens": "falk",
    "falkjakten": "falkjakt",
    "falkjaktens": "falkjakt",
    "falkjakter": "falkjakt",
    "falkjakterna": "falkjakt",
    "falkjakternas": "falkjakt",
    "falkjakters": "falkjakt",
    "falkjakts": "falkjakt",
    "falkonetten": "falkonett",
    "falkonettens": "falkonett",
    "falkonetter": "falkonett",
    "falkonetterna": "falkonett",
    "falkonetternas": "falkonett",
    "falkonetters": "falkonett",
    "falkonetts": "falkonett",
    "falkögas": "falköga",
    "falkögat": "falköga",
    "falkögats": "falköga",
    "falkögon": "falköga",
    "falkögonen": "falköga",
    "falkögonens": "falköga",
    "falkögons": "falköga",
    "fall": "falla",
    "fallande": "falla",
    "fallanden": "fallande",
    "fallandena": "fallande",
    "fallandenas": "fallande",
    "fallandens": "fallande",
    "fallandes": "fallande",
    "fallandesjukan": "fallandesjuka",
    "fallandesjukans": "fallandesjuka",
    "fallandesjukas": "fallandesjuka",
    "fallandesjuke": "fallandesjuka",
    "fallandesjuks": "fallandesjuka",
    "fallandesoten": "fallandesot",
    "fallandesotens": "fallandesot",
    "fallandesots": "fallandesot",
    "fallandet": "fallande",
    "fallandets": "fallande",
    "fallas": "falla",
    "fallbeskrivningar": "fallbeskrivning",
    "fallbeskrivningarna": "fallbeskrivning",
    "fallbeskrivningarnas": "fallbeskrivning",
    "fallbeskrivningars": "fallbeskrivning",
    "fallbeskrivningen": "fallbeskrivning",
    "fallbeskrivningens": "fallbeskrivning",
    "fallbeskrivnings": "fallbeskrivning",
    "fallbil": "fallbila",
    "fallbilan": "fallbila",
    "fallbilans": "fallbila",
    "fallbilas": "fallbila",
    "fallbile": "fallbila",
    "fallbilor": "fallbila",
    "fallbilorna": "fallbila",
    "fallbilornas": "fallbila",
    "fallbilors": "fallbila",
    "fallbils": "fallbila",
    "falle": "falla",
    "fallen": "falla",
    "fallenheten": "fallenhet",
    "fallenhetens": "fallenhet",
    "fallenheter": "fallenhet",
    "fallenheterna": "fallenhet",
    "fallenheternas": "fallenhet",
    "fallenheters": "fallenhet",
    "fallenhets": "fallenhet",
    "fallens": "fallen",
    "faller": "falla",
    "fallerade": "fallera",
    "fallerades": "fallera",
    "fallerande": "fallera",
    "falleranden": "fallerande",
    "fallerandena": "fallerande",
    "fallerandenas": "fallerande",
    "fallerandens": "fallerande",
    "fallerandes": "fallerande",
    "fallerandet": "fallerande",
    "fallerandets": "fallerande",
    "fallerar": "fallera",
    "falleras": "fallera",
    "fallerat": "fallera",
    "fallerats": "fallera",
    "falleringar": "fallering",
    "falleringarna": "fallering",
    "falleringarnas": "fallering",
    "falleringars": "fallering",
    "falleringen": "fallering",
    "falleringens": "fallering",
    "fallerings": "fallering",
    "falles": "falla",
    "fallet": "fallen",
    "fallets": "fallen",
    "fallfaran": "fallfara",
    "fallfarans": "fallfara",
    "fallfaras": "fallfara",
    "fallfare": "fallfara",
    "fallfaro": "fallfara",
    "fallfrukten": "fallfrukt",
    "fallfruktens": "fallfrukt",
    "fallfrukter": "fallfrukt",
    "fallfrukterna": "fallfrukt",
    "fallfrukternas": "fallfrukt",
    "fallfrukters": "fallfrukt",
    "fallfrukts": "fallfrukt",
    "fallfärdiga": "fallfärdig",
    "fallfärdigare": "fallfärdig",
    "fallfärdigares": "fallfärdig",
    "fallfärdigas": "fallfärdig",
    "fallfärdigast": "fallfärdig",
    "fallfärdigaste": "fallfärdig",
    "fallfärdigastes": "fallfärdig",
    "fallfärdigasts": "fallfärdig",
    "fallfärdige": "fallfärdig",
    "fallfärdiges": "fallfärdig",
    "fallfärdigheten": "fallfärdighet",
    "fallfärdighetens": "fallfärdighet",
    "fallfärdighets": "fallfärdighet",
    "fallfärdigs": "fallfärdig",
    "fallfärdigt": "fallfärdig",
    "fallfärdigts": "fallfärdig",
    "fallgropar": "fallgrop",
    "fallgroparna": "fallgrop",
    "fallgroparnas": "fallgrop",
    "fallgropars": "fallgrop",
    "fallgropen": "fallgrop",
    "fallgropens": "fallgrop",
    "fallgrops": "fallgrop",
    "fallhammar": "fallhammare",
    "fallhammaren": "fallhammare",
    "fallhammarens": "fallhammare",
    "fallhammares": "fallhammare",
    "fallhamrar": "fallhammare",
    "fallhamrarna": "fallhammare",
    "fallhamrarnas": "fallhammare",
    "fallhamrars": "fallhammare",
    "fallhöjden": "fallhöjd",
    "fallhöjdens": "fallhöjd",
    "fallhöjder": "fallhöjd",
    "fallhöjderna": "fallhöjd",
    "fallhöjdernas": "fallhöjd",
    "fallhöjders": "fallhöjd",
    "fallhöjds": "fallhöjd",
    "fallissemangen": "fallissemang",
    "fallissemangens": "fallissemang",
    "fallissemanget": "fallissemang",
    "fallissemangets": "fallissemang",
    "fallissemangs": "fallissemang",
    "fallit": "falla",
    "fallits": "falla",
    "fallmålstavel": "fallmålstavla",
    "fallmålstavlan": "fallmålstavla",
    "fallmålstavlans": "fallmålstavla",
    "fallmålstavlas": "fallmålstavla",
    "fallmålstavle": "fallmålstavla",
    "fallmålstavlor": "fallmålstavla",
    "fallmålstavlorna": "fallmålstavla",
    "fallmålstavlornas": "fallmålstavla",
    "fallmålstavlors": "fallmålstavla",
    "fallna": "fallen",
    "fallnare": "fallen",
    "fallnares": "fallen",
    "fallnas": "fallen",
    "fallnast": "fallen",
    "fallnaste": "fallen",
    "fallnastes": "fallen",
    "fallnasts": "fallen",
    "fallne": "fallen",
    "fallnes": "fallen",
    "fallolyck": "fallolycka",
    "fallolyckan": "fallolycka",
    "fallolyckans": "fallolycka",
    "fallolyckas": "fallolycka",
    "fallolycke": "fallolycka",
    "fallolyckor": "fallolycka",
    "fallolyckorna": "fallolycka",
    "fallolyckornas": "fallolycka",
    "fallolyckors": "fallolycka",
    "fallolycks": "fallolycka",
    "fallosar": "fallos",
    "fallosarna": "fallos",
    "fallosarnas": "fallos",
    "fallosars": "fallos",
    "fallosen": "fallos",
    "fallosens": "fallos",
    "fallouts": "fallout",
    "fallrepen": "fallrep",
    "fallrepens": "fallrep",
    "fallrepet": "fallrep",
    "fallrepets": "fallrep",
    "fallreps": "fallrep",
    "falls": "falla",
    "fallsegern": "fallseger",
    "fallsegerns": "fallseger",
    "fallsegers": "fallseger",
    "fallsegrar": "fallseger",
    "fallsegrarna": "fallseger",
    "fallsegrarnas": "fallseger",
    "fallsegrars": "fallseger",
    "fallskärmar": "fallskärm",
    "fallskärmarna": "fallskärm",
    "fallskärmarnas": "fallskärm",
    "fallskärmars": "fallskärm",
    "fallskärmen": "fallskärm",
    "fallskärmens": "fallskärm",
    "fallskärms": "fallskärm",
    "fallskärmshoppar": "fallskärmshoppare",
    "fallskärmshopparen": "fallskärmshoppare",
    "fallskärmshopparens": "fallskärmshoppare",
    "fallskärmshoppares": "fallskärmshoppare",
    "fallskärmshopparna": "fallskärmshoppare",
    "fallskärmshopparnas": "fallskärmshoppare",
    "fallskärmsjägar": "fallskärmsjägare",
    "fallskärmsjägaren": "fallskärmsjägare",
    "fallskärmsjägarens": "fallskärmsjägare",
    "fallskärmsjägares": "fallskärmsjägare",
    "fallskärmsjägarna": "fallskärmsjägare",
    "fallskärmsjägarnas": "fallskärmsjägare",
    "fallskärmstricken": "fallskärmstrick",
    "fallskärmstrickens": "fallskärmstrick",
    "fallskärmstricket": "fallskärmstrick",
    "fallskärmstrickets": "fallskärmstrick",
    "fallskärmstricks": "fallskärmstrick",
    "fallskärmstruppen": "fallskärmstrupp",
    "fallskärmstruppens": "fallskärmstrupp",
    "fallskärmstrupper": "fallskärmstrupp",
    "fallskärmstrupperna": "fallskärmstrupp",
    "fallskärmstruppernas": "fallskärmstrupp",
    "fallskärmstruppers": "fallskärmstrupp",
    "fallskärmstrupps": "fallskärmstrupp",
    "fallstudien": "fallstudie",
    "fallstudiens": "fallstudie",
    "fallstudier": "fallstudie",
    "fallstudierna": "fallstudie",
    "fallstudiernas": "fallstudie",
    "fallstudiers": "fallstudie",
    "fallstudies": "fallstudie",
    "falltavel": "falltavla",
    "falltavlan": "falltavla",
    "falltavlans": "falltavla",
    "falltavlas": "falltavla",
    "falltavle": "falltavla",
    "falltavlor": "falltavla",
    "falltavlorna": "falltavla",
    "falltavlornas": "falltavla",
    "falltavlors": "falltavla",
    "falluck": "fallucka",
    "falluckan": "fallucka",
    "falluckans": "fallucka",
    "falluckas": "fallucka",
    "fallucke": "fallucka",
    "falluckor": "fallucka",
    "falluckorna": "fallucka",
    "falluckornas": "fallucka",
    "falluckors": "fallucka",
    "fallucks": "fallucka",
    "fallverken": "fallverk",
    "fallverkens": "fallverk",
    "fallverket": "fallverk",
    "fallverkets": "fallverk",
    "fallverks": "fallverk",
    "fallvindar": "fallvind",
    "fallvindarna": "fallvind",
    "fallvindarnas": "fallvind",
    "fallvindars": "fallvind",
    "fallvinden": "fallvind",
    "fallvindens": "fallvind",
    "fallvinds": "fallvind",
    "faln": "falna",
    "falnad": "falna",
    "falnade": "falna",
    "falnades": "falna",
    "falnads": "falna",
    "falnande": "falna",
    "falnanden": "falnande",
    "falnandena": "falnande",
    "falnandenas": "falnande",
    "falnandens": "falnande",
    "falnandes": "falnande",
    "falnandet": "falnande",
    "falnandets": "falnande",
    "falnar": "falna",
    "falnas": "falna",
    "falnat": "falna",
    "falnats": "falna",
    "fals": "falsa",
    "falsad": "falsa",
    "falsade": "falsa",
    "falsades": "falsa",
    "falsads": "falsa",
    "falsande": "falsa",
    "falsanden": "falsande",
    "falsandena": "falsande",
    "falsandenas": "falsande",
    "falsandens": "falsande",
    "falsandes": "falsande",
    "falsandet": "falsande",
    "falsandets": "falsande",
    "falsar": "falsa",
    "falsarie": "falsarium",
    "falsarier": "falsarium",
    "falsarierna": "falsarium",
    "falsariernas": "falsarium",
    "falsariers": "falsarium",
    "falsariet": "falsarium",
    "falsariets": "falsarium",
    "falsariums": "falsarium",
    "falsarna": "fals",
    "falsarnas": "fals",
    "falsars": "fals",
    "falsas": "falsa",
    "falsat": "falsa",
    "falsats": "falsa",
    "falsen": "fals",
    "falsens": "fals",
    "falsetten": "falsett",
    "falsettens": "falsett",
    "falsetts": "falsett",
    "falsifierad": "falsifiera",
    "falsifierade": "falsifiera",
    "falsifierades": "falsifiera",
    "falsifierads": "falsifiera",
    "falsifierande": "falsifiera",
    "falsifieranden": "falsifierande",
    "falsifierandena": "falsifierande",
    "falsifierandenas": "falsifierande",
    "falsifierandens": "falsifierande",
    "falsifierandes": "falsifierande",
    "falsifierandet": "falsifierande",
    "falsifierandets": "falsifierande",
    "falsifierar": "falsifiera",
    "falsifieras": "falsifiera",
    "falsifierat": "falsifiera",
    "falsifierats": "falsifiera",
    "falsifierbara": "falsifierbar",
    "falsifierbarare": "falsifierbar",
    "falsifierbarares": "falsifierbar",
    "falsifierbaras": "falsifierbar",
    "falsifierbarast": "falsifierbar",
    "falsifierbaraste": "falsifierbar",
    "falsifierbarastes": "falsifierbar",
    "falsifierbarasts": "falsifierbar",
    "falsifierbare": "falsifierbar",
    "falsifierbares": "falsifierbar",
    "falsifierbarheten": "falsifierbarhet",
    "falsifierbarhetens": "falsifierbarhet",
    "falsifierbarhets": "falsifierbarhet",
    "falsifierbars": "falsifierbar",
    "falsifierbart": "falsifierbar",
    "falsifierbarts": "falsifierbar",
    "falsifieringar": "falsifiering",
    "falsifieringarna": "falsifiering",
    "falsifieringarnas": "falsifiering",
    "falsifieringars": "falsifiering",
    "falsifieringen": "falsifiering",
    "falsifieringens": "falsifiering",
    "falsifierings": "falsifiering",
    "falsifikaten": "falsifikat",
    "falsifikatens": "falsifikat",
    "falsifikatet": "falsifikat",
    "falsifikatets": "falsifikat",
    "falsifikats": "falsifikat",
    "falska": "falsk",
    "falskalarmen": "falskalarm",
    "falskalarmens": "falskalarm",
    "falskalarmet": "falskalarm",
    "falskalarmets": "falskalarm",
    "falskalarms": "falskalarm",
    "falskare": "falsk",
    "falskares": "falsk",
    "falskas": "falsk",
    "falskast": "falsk",
    "falskaste": "falsk",
    "falskastes": "falsk",
    "falskasts": "falsk",
    "falske": "falsk",
    "falskes": "falsk",
    "falskheten": "falskhet",
    "falskhetens": "falskhet",
    "falskheter": "falskhet",
    "falskheterna": "falskhet",
    "falskheternas": "falskhet",
    "falskheters": "falskhet",
    "falskhets": "falskhet",
    "falsklarmen": "falsklarm",
    "falsklarmens": "falsklarm",
    "falsklarmet": "falsklarm",
    "falsklarmets": "falsklarm",
    "falsklarms": "falsklarm",
    "falskmyntar": "falskmyntare",
    "falskmyntaren": "falskmyntare",
    "falskmyntarens": "falskmyntare",
    "falskmyntares": "falskmyntare",
    "falskmyntarna": "falskmyntare",
    "falskmyntarnas": "falskmyntare",
    "falsks": "falsk",
    "falskskyltad": "falskskylta",
    "falskskyltade": "falskskylta",
    "falskskyltades": "falskskylta",
    "falskskyltads": "falskskylta",
    "falskskyltande": "falskskylta",
    "falskskyltanden": "falskskyltande",
    "falskskyltandena": "falskskyltande",
    "falskskyltandenas": "falskskyltande",
    "falskskyltandens": "falskskyltande",
    "falskskyltandes": "falskskyltande",
    "falskskyltandet": "falskskyltande",
    "falskskyltandets": "falskskyltande",
    "falskskyltar": "falskskylta",
    "falskskyltas": "falskskylta",
    "falskskyltat": "falskskylta",
    "falskskyltats": "falskskylta",
    "falskskyltningar": "falskskyltning",
    "falskskyltningarna": "falskskyltning",
    "falskskyltningarnas": "falskskyltning",
    "falskskyltningars": "falskskyltning",
    "falskskyltningen": "falskskyltning",
    "falskskyltningens": "falskskyltning",
    "falskskyltnings": "falskskyltning",
    "falskspelen": "falskspel",
    "falskspelens": "falskspel",
    "falskspelet": "falskspel",
    "falskspelets": "falskspel",
    "falskspels": "falskspel",
    "falskt": "falsk",
    "falskts": "falsk",
    "falt": "fal",
    "falts": "fal",
    "falukorvar": "falukorv",
    "falukorvarna": "falukorv",
    "falukorvarnas": "falukorv",
    "falukorvars": "falukorv",
    "falukorven": "falukorv",
    "falukorvens": "falukorv",
    "falukorvs": "falukorv",
    "faluröda": "faluröd",
    "falurödare": "faluröd",
    "falurödares": "faluröd",
    "falurödas": "faluröd",
    "falurödast": "faluröd",
    "falurödaste": "faluröd",
    "falurödastes": "faluröd",
    "falurödasts": "faluröd",
    "faluröde": "faluröd",
    "falurödes": "faluröd",
    "faluröds": "faluröd",
    "falurött": "faluröd",
    "falurötts": "faluröd",
    "familjariteten": "familjaritet",
    "familjaritetens": "familjaritet",
    "familjariteter": "familjaritet",
    "familjariteterna": "familjaritet",
    "familjariteternas": "familjaritet",
    "familjariteters": "familjaritet",
    "familjaritets": "familjaritet",
    "familje": "familj",
    "familjearkiven": "familjearkiv",
    "familjearkivens": "familjearkiv",
    "familjearkivet": "familjearkiv",
    "familjearkivets": "familjearkiv",
    "familjearkivs": "familjearkiv",
    "familjebanden": "familjeband",
    "familjebandens": "familjeband",
    "familjebandet": "familjeband",
    "familjebandets": "familjeband",
    "familjebands": "familjeband",
    "familjebidragen": "familjebidrag",
    "familjebidragens": "familjebidrag",
    "familjebidraget": "familjebidrag",
    "familjebidragets": "familjebidrag",
    "familjebidrags": "familjebidrag",
    "familjebilden": "familjebild",
    "familjebildens": "familjebild",
    "familjebilder": "familjebild",
    "familjebilderna": "familjebild",
    "familjebildernas": "familjebild",
    "familjebilders": "familjebild",
    "familjebilds": "familjebild",
    "familjebiljetten": "familjebiljett",
    "familjebiljettens": "familjebiljett",
    "familjebiljetter": "familjebiljett",
    "familjebiljetterna": "familjebiljett",
    "familjebiljetternas": "familjebiljett",
    "familjebiljetters": "familjebiljett",
    "familjebiljetts": "familjebiljett",
    "familjebolagen": "familjebolag",
    "familjebolagens": "familjebolag",
    "familjebolaget": "familjebolag",
    "familjebolagets": "familjebolag",
    "familjebolags": "familjebolag",
    "familjedaghemmen": "familjedaghem",
    "familjedaghemmens": "familjedaghem",
    "familjedaghemmet": "familjedaghem",
    "familjedaghemmets": "familjedaghem",
    "familjedaghems": "familjedaghem",
    "familjefejden": "familjefejd",
    "familjefejdens": "familjefejd",
    "familjefejder": "familjefejd",
    "familjefejderna": "familjefejd",
    "familjefejdernas": "familjefejd",
    "familjefejders": "familjefejd",
    "familjefejds": "familjefejd",
    "familjeflick": "familjeflicka",
    "familjeflickan": "familjeflicka",
    "familjeflickans": "familjeflicka",
    "familjeflickas": "familjeflicka",
    "familjeflicke": "familjeflicka",
    "familjeflickor": "familjeflicka",
    "familjeflickorna": "familjeflicka",
    "familjeflickornas": "familjeflicka",
    "familjeflickors": "familjeflicka",
    "familjeflicks": "familjeflicka",
    "familjefoton": "familjefoto",
    "familjefotona": "familjefoto",
    "familjefotonas": "familjefoto",
    "familjefotons": "familjefoto",
    "familjefotos": "familjefoto",
    "familjefotot": "familjefoto",
    "familjefotots": "familjefoto",
    "familjeföretagen": "familjeföretag",
    "familjeföretagens": "familjeföretag",
    "familjeföretaget": "familjeföretag",
    "familjeföretagets": "familjeföretag",
    "familjeföretags": "familjeföretag",
    "familjeförsörjar": "familjeförsörjare",
    "familjeförsörjaren": "familjeförsörjare",
    "familjeförsörjarens": "familjeförsörjare",
    "familjeförsörjares": "familjeförsörjare",
    "familjeförsörjarna": "familjeförsörjare",
    "familjeförsörjarnas": "familjeförsörjare",
    "familjegravar": "familjegrav",
    "familjegravarna": "familjegrav",
    "familjegravarnas": "familjegrav",
    "familjegravars": "familjegrav",
    "familjegraven": "familjegrav",
    "familjegravens": "familjegrav",
    "familjegravs": "familjegrav",
    "familjehemligheten": "familjehemlighet",
    "familjehemlighetens": "familjehemlighet",
    "familjehemligheter": "familjehemlighet",
    "familjehemligheterna": "familjehemlighet",
    "familjehemligheternas": "familjehemlighet",
    "familjehemligheters": "familjehemlighet",
    "familjehemlighets": "familjehemlighet",
    "familjehemmen": "familjehem",
    "familjehemmens": "familjehem",
    "familjehemmet": "familjehem",
    "familjehemmets": "familjehem",
    "familjehems": "familjehem",
    "familjehotellen": "familjehotell",
    "familjehotellens": "familjehotell",
    "familjehotellet": "familjehotell",
    "familjehotellets": "familjehotell",
    "familjehotells": "familjehotell",
    "familjejordbruken": "familjejordbruk",
    "familjejordbrukens": "familjejordbruk",
    "familjejordbruket": "familjejordbruk",
    "familjejordbrukets": "familjejordbruk",
    "familjejordbruks": "familjejordbruk",
    "familjekretsar": "familjekrets",
    "familjekretsarna": "familjekrets",
    "familjekretsarnas": "familjekrets",
    "familjekretsars": "familjekrets",
    "familjekretsen": "familjekrets",
    "familjekretsens": "familjekrets",
    "familjemedlemmar": "familjemedlem",
    "familjemedlemmarna": "familjemedlem",
    "familjemedlemmarnas": "familjemedlem",
    "familjemedlemmars": "familjemedlem",
    "familjemedlemmen": "familjemedlem",
    "familjemedlemmens": "familjemedlem",
    "familjemedlems": "familjemedlem",
    "familjemiddagar": "familjemiddag",
    "familjemiddagarna": "familjemiddag",
    "familjemiddagarnas": "familjemiddag",
    "familjemiddagars": "familjemiddag",
    "familjemiddagen": "familjemiddag",
    "familjemiddagens": "familjemiddag",
    "familjemiddags": "familjemiddag",
    "familjemysen": "familjemys",
    "familjemysens": "familjemys",
    "familjemyset": "familjemys",
    "familjemysets": "familjemys",
    "familjemässiga": "familjemässig",
    "familjemässigare": "familjemässig",
    "familjemässigares": "familjemässig",
    "familjemässigas": "familjemässig",
    "familjemässigast": "familjemässig",
    "familjemässigaste": "familjemässig",
    "familjemässigastes": "familjemässig",
    "familjemässigasts": "familjemässig",
    "familjemässige": "familjemässig",
    "familjemässiges": "familjemässig",
    "familjemässigs": "familjemässig",
    "familjemässigt": "familjemässig",
    "familjemässigts": "familjemässig",
    "familjen": "familj",
    "familjenamnen": "familjenamn",
    "familjenamnens": "familjenamn",
    "familjenamnet": "familjenamn",
    "familjenamnets": "familjenamn",
    "familjenamns": "familjenamn",
    "familjens": "familj",
    "familjepenningar": "familjepenning",
    "familjepenningarna": "familjepenning",
    "familjepenningarnas": "familjepenning",
    "familjepenningars": "familjepenning",
    "familjepenningen": "familjepenning",
    "familjepenningens": "familjepenning",
    "familjepennings": "familjepenning",
    "familjepensionen": "familjepension",
    "familjepensionens": "familjepension",
    "familjepensioner": "familjepension",
    "familjepensionerna": "familjepension",
    "familjepensionernas": "familjepension",
    "familjepensioners": "familjepension",
    "familjepensions": "familjepension",
    "familjeplaneringar": "familjeplanering",
    "familjeplaneringarna": "familjeplanering",
    "familjeplaneringarnas": "familjeplanering",
    "familjeplaneringars": "familjeplanering",
    "familjeplaneringen": "familjeplanering",
    "familjeplaneringens": "familjeplanering",
    "familjeplanerings": "familjeplanering",
    "familjeplaneringsregeln": "familjeplaneringsregel",
    "familjeplaneringsregelns": "familjeplaneringsregel",
    "familjeplaneringsregels": "familjeplaneringsregel",
    "familjeplaneringsregler": "familjeplaneringsregel",
    "familjeplaneringsreglerna": "familjeplaneringsregel",
    "familjeplaneringsreglernas": "familjeplaneringsregel",
    "familjeplaneringsreglers": "familjeplaneringsregel",
    "familjepolitiken": "familjepolitik",
    "familjepolitikens": "familjepolitik",
    "familjepolitiks": "familjepolitik",
    "familjepolitiska": "familjepolitisk",
    "familjepolitiskas": "familjepolitisk",
    "familjepolitiske": "familjepolitisk",
    "familjepolitiskes": "familjepolitisk",
    "familjepolitisks": "familjepolitisk",
    "familjepolitiskt": "familjepolitisk",
    "familjepolitiskts": "familjepolitisk",
    "familjer": "familj",
    "familjerabatten": "familjerabatt",
    "familjerabattens": "familjerabatt",
    "familjerabatter": "familjerabatt",
    "familjerabatterna": "familjerabatt",
    "familjerabatternas": "familjerabatt",
    "familjerabatters": "familjerabatt",
    "familjerabatts": "familjerabatt",
    "familjerna": "familj",
    "familjernas": "familj",
    "familjers": "familj",
    "familjerätten": "familjerätt",
    "familjerättens": "familjerätt",
    "familjerätts": "familjerätt",
    "familjerådgivningar": "familjerådgivning",
    "familjerådgivningarna": "familjerådgivning",
    "familjerådgivningarnas": "familjerådgivning",
    "familjerådgivningars": "familjerådgivning",
    "familjerådgivningen": "familjerådgivning",
    "familjerådgivningens": "familjerådgivning",
    "familjerådgivnings": "familjerådgivning",
    "familjeterapien": "familjeterapi",
    "familjeterapiens": "familjeterapi",
    "familjeterapin": "familjeterapi",
    "familjeterapins": "familjeterapi",
    "familjeterapis": "familjeterapi",
    "familjetillhörigheten": "familjetillhörighet",
    "familjetillhörighetens": "familjetillhörighet",
    "familjetillhörighets": "familjetillhörighet",
    "familjetraditionen": "familjetradition",
    "familjetraditionens": "familjetradition",
    "familjetraditioner": "familjetradition",
    "familjetraditionerna": "familjetradition",
    "familjetraditionernas": "familjetradition",
    "familjetraditioners": "familjetradition",
    "familjetraditions": "familjetradition",
    "familjevården": "familjevård",
    "familjevårdens": "familjevård",
    "familjevårds": "familjevård",
    "familjs": "familj",
    "familjära": "familjär",
    "familjärare": "familjär",
    "familjärares": "familjär",
    "familjäras": "familjär",
    "familjärast": "familjär",
    "familjäraste": "familjär",
    "familjärastes": "familjär",
    "familjärasts": "familjär",
    "familjäre": "familjär",
    "familjäres": "familjär",
    "familjärs": "familjär",
    "familjärt": "familjär",
    "familjärts": "familjär",
    "famlade": "famla",
    "famlades": "famla",
    "famlande": "famla",
    "famlanden": "famlande",
    "famlandena": "famlande",
    "famlandenas": "famlande",
    "famlandens": "famlande",
    "famlandes": "famlande",
    "famlandet": "famlande",
    "famlandets": "famlande",
    "famlar": "famla",
    "famlas": "famla",
    "famlat": "famla",
    "famlats": "famla",
    "fammel": "famla",
    "famn": "famna",
    "famnad": "famna",
    "famnade": "famna",
    "famnades": "famna",
    "famnads": "famna",
    "famnande": "famna",
    "famnanden": "famnande",
    "famnandena": "famnande",
    "famnandenas": "famnande",
    "famnandens": "famnande",
    "famnandes": "famnande",
    "famnandet": "famnande",
    "famnandets": "famnande",
    "famnar": "famna",
    "famnarna": "famn",
    "famnarnas": "famn",
    "famnars": "famn",
    "famnas": "famna",
    "famnat": "famna",
    "famnats": "famna",
    "famnen": "famn",
    "famnens": "famn",
    "famns": "famn",
    "famntagen": "famntag",
    "famntagens": "famntag",
    "famntaget": "famntag",
    "famntagets": "famntag",
    "famntags": "famntag",
    "famösa": "famös",
    "famösare": "famös",
    "famösares": "famös",
    "famösas": "famös",
    "famösast": "famös",
    "famösaste": "famös",
    "famösastes": "famös",
    "famösasts": "famös",
    "famöse": "famös",
    "famöses": "famös",
    "famöst": "famös",
    "famösts": "famös",
    "fan": "fana",
    "fanan": "fana",
    "fanans": "fana",
    "fanas": "fana",
    "fanatikern": "fanatiker",
    "fanatikerna": "fanatiker",
    "fanatikernas": "fanatiker",
    "fanatikerns": "fanatiker",
    "fanatikers": "fanatiker",
    "fanatiska": "fanatisk",
    "fanatiskare": "fanatisk",
    "fanatiskares": "fanatisk",
    "fanatiskas": "fanatisk",
    "fanatiskast": "fanatisk",
    "fanatiskaste": "fanatisk",
    "fanatiskastes": "fanatisk",
    "fanatiskasts": "fanatisk",
    "fanatiske": "fanatisk",
    "fanatiskes": "fanatisk",
    "fanatisks": "fanatisk",
    "fanatiskt": "fanatisk",
    "fanatiskts": "fanatisk",
    "fanatismen": "fanatism",
    "fanatismens": "fanatism",
    "fanatismer": "fanatism",
    "fanatismerna": "fanatism",
    "fanatismernas": "fanatism",
    "fanatismers": "fanatism",
    "fanatisms": "fanatism",
    "fanborgar": "fanborg",
    "fanborgarna": "fanborg",
    "fanborgarnas": "fanborg",
    "fanborgars": "fanborg",
    "fanborgen": "fanborg",
    "fanborgens": "fanborg",
    "fanborgs": "fanborg",
    "fandangoer": "fandango",
    "fandangoerna": "fandango",
    "fandangoernas": "fandango",
    "fandangoers": "fandango",
    "fandangon": "fandango",
    "fandangons": "fandango",
    "fandangor": "fandango",
    "fandangorna": "fandango",
    "fandangornas": "fandango",
    "fandangors": "fandango",
    "fandangos": "fandango",
    "fane": "fana",
    "fanen": "fan",
    "fanens": "fan",
    "faneren": "faner",
    "fanerens": "faner",
    "faneret": "faner",
    "fanerets": "faner",
    "fanerogama": "fanerogam",
    "fanerogamare": "fanerogam",
    "fanerogamares": "fanerogam",
    "fanerogamas": "fanerogam",
    "fanerogamast": "fanerogam",
    "fanerogamaste": "fanerogam",
    "fanerogamastes": "fanerogam",
    "fanerogamasts": "fanerogam",
    "fanerogame": "fanerogam",
    "fanerogamen": "fanerogam",
    "fanerogamens": "fanerogam",
    "fanerogamer": "fanerogam",
    "fanerogamerna": "fanerogam",
    "fanerogamernas": "fanerogam",
    "fanerogamers": "fanerogam",
    "fanerogames": "fanerogam",
    "fanerogams": "fanerogam",
    "fanerogamt": "fanerogam",
    "fanerogamts": "fanerogam",
    "faners": "faner",
    "fanet": "fan",
    "fanets": "fan",
    "fanfaren": "fanfar",
    "fanfarens": "fanfar",
    "fanfarer": "fanfar",
    "fanfarerna": "fanfar",
    "fanfarernas": "fanfar",
    "fanfarers": "fanfar",
    "fanfars": "fanfar",
    "fanflykten": "fanflykt",
    "fanflyktens": "fanflykt",
    "fanflykts": "fanflykt",
    "fanjunkar": "fanjunkare",
    "fanjunkaren": "fanjunkare",
    "fanjunkarens": "fanjunkare",
    "fanjunkares": "fanjunkare",
    "fanjunkarna": "fanjunkare",
    "fanjunkarnas": "fanjunkare",
    "fankens": "fanken",
    "fann": "finna",
    "fanns": "finnas",
    "fanor": "fana",
    "fanorna": "fana",
    "fanornas": "fana",
    "fanors": "fana",
    "fans": "fana",
    "fansarna": "fan",
    "fansarnas": "fan",
    "fansen": "fan",
    "fansens": "fan",
    "fanskapen": "fanskap",
    "fanskapens": "fanskap",
    "fanskapet": "fanskap",
    "fanskapets": "fanskap",
    "fanskaps": "fanskap",
    "fanstygen": "fanstyg",
    "fanstygens": "fanstyg",
    "fanstyget": "fanstyg",
    "fanstygets": "fanstyg",
    "fanstygs": "fanstyg",
    "fantasidjuren": "fantasidjur",
    "fantasidjurens": "fantasidjur",
    "fantasidjuret": "fantasidjur",
    "fantasidjurets": "fantasidjur",
    "fantasidjurs": "fantasidjur",
    "fantasien": "fantasi",
    "fantasiens": "fantasi",
    "fantasier": "fantasi",
    "fantasierna": "fantasi",
    "fantasiernas": "fantasi",
    "fantasiers": "fantasi",
    "fantasifosterna": "fantasifoster",
    "fantasifosternas": "fantasifoster",
    "fantasifosters": "fantasifoster",
    "fantasifostren": "fantasifoster",
    "fantasifostrens": "fantasifoster",
    "fantasifostret": "fantasifoster",
    "fantasifostrets": "fantasifoster",
    "fantasifulla": "fantasifull",
    "fantasifullare": "fantasifull",
    "fantasifullares": "fantasifull",
    "fantasifullas": "fantasifull",
    "fantasifullast": "fantasifull",
    "fantasifullaste": "fantasifull",
    "fantasifullastes": "fantasifull",
    "fantasifullasts": "fantasifull",
    "fantasifulle": "fantasifull",
    "fantasifulles": "fantasifull",
    "fantasifullheten": "fantasifullhet",
    "fantasifullhetens": "fantasifullhet",
    "fantasifullheter": "fantasifullhet",
    "fantasifullheterna": "fantasifullhet",
    "fantasifullheternas": "fantasifullhet",
    "fantasifullheters": "fantasifullhet",
    "fantasifullhets": "fantasifullhet",
    "fantasifulls": "fantasifull",
    "fantasifullt": "fantasifull",
    "fantasifullts": "fantasifull",
    "fantasigestalten": "fantasigestalt",
    "fantasigestaltens": "fantasigestalt",
    "fantasigestalter": "fantasigestalt",
    "fantasigestalterna": "fantasigestalt",
    "fantasigestalternas": "fantasigestalt",
    "fantasigestalters": "fantasigestalt",
    "fantasigestalts": "fantasigestalt",
    "fantasilösa": "fantasilös",
    "fantasilösare": "fantasilös",
    "fantasilösares": "fantasilös",
    "fantasilösas": "fantasilös",
    "fantasilösast": "fantasilös",
    "fantasilösaste": "fantasilös",
    "fantasilösastes": "fantasilös",
    "fantasilösasts": "fantasilös",
    "fantasilöse": "fantasilös",
    "fantasilöses": "fantasilös",
    "fantasilösheten": "fantasilöshet",
    "fantasilöshetens": "fantasilöshet",
    "fantasilösheter": "fantasilöshet",
    "fantasilösheterna": "fantasilöshet",
    "fantasilösheternas": "fantasilöshet",
    "fantasilösheters": "fantasilöshet",
    "fantasilöshets": "fantasilöshet",
    "fantasilöst": "fantasilös",
    "fantasilösts": "fantasilös",
    "fantasin": "fantasi",
    "fantasins": "fantasi",
    "fantasiprodukten": "fantasiprodukt",
    "fantasiproduktens": "fantasiprodukt",
    "fantasiprodukter": "fantasiprodukt",
    "fantasiprodukterna": "fantasiprodukt",
    "fantasiprodukternas": "fantasiprodukt",
    "fantasiprodukters": "fantasiprodukt",
    "fantasiprodukts": "fantasiprodukt",
    "fantasis": "fantasi",
    "fantasispelen": "fantasispel",
    "fantasispelens": "fantasispel",
    "fantasispelet": "fantasispel",
    "fantasispelets": "fantasispel",
    "fantasispels": "fantasispel",
    "fantasivärldar": "fantasivärld",
    "fantasivärldarna": "fantasivärld",
    "fantasivärldarnas": "fantasivärld",
    "fantasivärldars": "fantasivärld",
    "fantasivärlden": "fantasivärld",
    "fantasivärldens": "fantasivärld",
    "fantasivärlds": "fantasivärld",
    "fantasten": "fantast",
    "fantastens": "fantast",
    "fantaster": "fantast",
    "fantasterier": "fantasteri",
    "fantasterierna": "fantasteri",
    "fantasteriernas": "fantasteri",
    "fantasteriers": "fantasteri",
    "fantasteriet": "fantasteri",
    "fantasteriets": "fantasteri",
    "fantasteris": "fantasteri",
    "fantasterit": "fantasteri",
    "fantasterits": "fantasteri",
    "fantasterna": "fantast",
    "fantasternas": "fantast",
    "fantasters": "fantast",
    "fantastiken": "fantastik",
    "fantastikens": "fantastik",
    "fantastiks": "fantastik",
    "fantastiska": "fantastisk",
    "fantastiskare": "fantastisk",
    "fantastiskares": "fantastisk",
    "fantastiskas": "fantastisk",
    "fantastiskast": "fantastisk",
    "fantastiskaste": "fantastisk",
    "fantastiskastes": "fantastisk",
    "fantastiskasts": "fantastisk",
    "fantastiske": "fantastisk",
    "fantastiskes": "fantastisk",
    "fantastisks": "fantastisk",
    "fantastiskt": "fantastisk",
    "fantastiskts": "fantastisk",
    "fantasts": "fantast",
    "fantiserad": "fantisera",
    "fantiserade": "fantisera",
    "fantiserades": "fantisera",
    "fantiserads": "fantisera",
    "fantiserande": "fantisera",
    "fantiseranden": "fantiserande",
    "fantiserandena": "fantiserande",
    "fantiserandenas": "fantiserande",
    "fantiserandens": "fantiserande",
    "fantiserandes": "fantiserande",
    "fantiserandet": "fantiserande",
    "fantiserandets": "fantiserande",
    "fantiserar": "fantisera",
    "fantiseras": "fantisera",
    "fantiserat": "fantisera",
    "fantiserats": "fantisera",
    "fantiserbara": "fantiserbar",
    "fantiserbarare": "fantiserbar",
    "fantiserbarares": "fantiserbar",
    "fantiserbaras": "fantiserbar",
    "fantiserbarast": "fantiserbar",
    "fantiserbaraste": "fantiserbar",
    "fantiserbarastes": "fantiserbar",
    "fantiserbarasts": "fantiserbar",
    "fantiserbare": "fantiserbar",
    "fantiserbares": "fantiserbar",
    "fantiserbarheten": "fantiserbarhet",
    "fantiserbarhetens": "fantiserbarhet",
    "fantiserbarhets": "fantiserbarhet",
    "fantiserbars": "fantiserbar",
    "fantiserbart": "fantiserbar",
    "fantiserbarts": "fantiserbar",
    "fantiseringar": "fantisering",
    "fantiseringarna": "fantisering",
    "fantiseringarnas": "fantisering",
    "fantiseringars": "fantisering",
    "fantiseringen": "fantisering",
    "fantiseringens": "fantisering",
    "fantiserings": "fantisering",
    "fantombilden": "fantombild",
    "fantombildens": "fantombild",
    "fantombilder": "fantombild",
    "fantombilderna": "fantombild",
    "fantombildernas": "fantombild",
    "fantombilders": "fantombild",
    "fantombilds": "fantombild",
    "fantomen": "fantom",
    "fantomens": "fantom",
    "fantomer": "fantom",
    "fantomerna": "fantom",
    "fantomernas": "fantom",
    "fantomers": "fantom",
    "fantomet": "fantom",
    "fantomets": "fantom",
    "fantoms": "fantom",
    "fantomsmärt": "fantomsmärta",
    "fantomsmärtan": "fantomsmärta",
    "fantomsmärtans": "fantomsmärta",
    "fantomsmärtas": "fantomsmärta",
    "fantomsmärte": "fantomsmärta",
    "fantomsmärtor": "fantomsmärta",
    "fantomsmärtorna": "fantomsmärta",
    "fantomsmärtornas": "fantomsmärta",
    "fantomsmärtors": "fantomsmärta",
    "fantomsmärts": "fantomsmärta",
    "fantomsnygga": "fantomsnygg",
    "fantomsnyggare": "fantomsnygg",
    "fantomsnyggares": "fantomsnygg",
    "fantomsnyggas": "fantomsnygg",
    "fantomsnyggast": "fantomsnygg",
    "fantomsnyggaste": "fantomsnygg",
    "fantomsnyggastes": "fantomsnygg",
    "fantomsnyggasts": "fantomsnygg",
    "fantomsnygge": "fantomsnygg",
    "fantomsnygges": "fantomsnygg",
    "fantomsnyggheten": "fantomsnygghet",
    "fantomsnygghetens": "fantomsnygghet",
    "fantomsnygghets": "fantomsnygghet",
    "fantomsnyggs": "fantomsnygg",
    "fantomsnyggt": "fantomsnygg",
    "fantomsnyggts": "fantomsnygg",
    "far": "fara",
    "faraden": "farad",
    "faradens": "farad",
    "farads": "farad",
    "faran": "fara",
    "farande": "fara",
    "faranden": "farande",
    "farandena": "farande",
    "farandenas": "farande",
    "farandens": "farande",
    "farandes": "farande",
    "farandet": "farande",
    "farandets": "farande",
    "farans": "fara",
    "faraon": "farao",
    "faraoner": "farao",
    "faraonerna": "farao",
    "faraonernas": "farao",
    "faraoners": "farao",
    "faraoniska": "faraonisk",
    "faraoniskas": "faraonisk",
    "faraoniske": "faraonisk",
    "faraoniskes": "faraonisk",
    "faraonisks": "faraonisk",
    "faraoniskt": "faraonisk",
    "faraoniskts": "faraonisk",
    "faraons": "farao",
    "faraos": "farao",
    "faras": "fara",
    "farbara": "farbar",
    "farbarare": "farbar",
    "farbarares": "farbar",
    "farbaras": "farbar",
    "farbarast": "farbar",
    "farbaraste": "farbar",
    "farbarastes": "farbar",
    "farbarasts": "farbar",
    "farbare": "farbar",
    "farbares": "farbar",
    "farbarheten": "farbarhet",
    "farbarhetens": "farbarhet",
    "farbarhets": "farbarhet",
    "farbars": "farbar",
    "farbart": "farbar",
    "farbarts": "farbar",
    "farbroderliga": "farbroderlig",
    "farbroderligare": "farbroderlig",
    "farbroderligares": "farbroderlig",
    "farbroderligas": "farbroderlig",
    "farbroderligast": "farbroderlig",
    "farbroderligaste": "farbroderlig",
    "farbroderligastes": "farbroderlig",
    "farbroderligasts": "farbroderlig",
    "farbroderlige": "farbroderlig",
    "farbroderliges": "farbroderlig",
    "farbroderligheten": "farbroderlighet",
    "farbroderlighetens": "farbroderlighet",
    "farbroderlighets": "farbroderlighet",
    "farbroderligs": "farbroderlig",
    "farbroderligt": "farbroderlig",
    "farbroderligts": "farbroderlig",
    "farbrodern": "farbror",
    "farbroderns": "farbror",
    "farbrorn": "farbror",
    "farbrorns": "farbror",
    "farbrors": "farbror",
    "farbröder": "farbror",
    "farbröderna": "farbror",
    "farbrödernas": "farbror",
    "farbröders": "farbror",
    "fardagar": "fardag",
    "fardagarna": "fardag",
    "fardagarnas": "fardag",
    "fardagars": "fardag",
    "fardagen": "fardag",
    "fardagens": "fardag",
    "fardags": "fardag",
    "fare": "fara",
    "faren": "fara",
    "farens": "fara",
    "fares": "fara",
    "faret": "fara",
    "farets": "fara",
    "farfader": "farfar",
    "farfadern": "farfar",
    "farfaderns": "farfar",
    "farfaders": "farfar",
    "farfars": "farfar",
    "farfarsfader": "farfarsfar",
    "farfarsfadern": "farfarsfar",
    "farfarsfaderns": "farfarsfar",
    "farfarsfaders": "farfarsfar",
    "farfarsfars": "farfarsfar",
    "farfarsfasder": "farfarsfar",
    "farfarsfäder": "farfarsfar",
    "farfarsfäderna": "farfarsfar",
    "farfarsfädernas": "farfarsfar",
    "farfarsfäders": "farfarsfar",
    "farfasder": "farfar",
    "farfäder": "farfar",
    "farfäderna": "farfar",
    "farfädernas": "farfar",
    "farfäders": "farfar",
    "farföräldern": "farförälder",
    "farförälderns": "farförälder",
    "farförälders": "farförälder",
    "farföräldrar": "farförälder",
    "farföräldrarna": "farförälder",
    "farföräldrarnas": "farförälder",
    "farföräldrars": "farförälder",
    "fargaltar": "fargalt",
    "fargaltarna": "fargalt",
    "fargaltarnas": "fargalt",
    "fargaltars": "fargalt",
    "fargalten": "fargalt",
    "fargaltens": "fargalt",
    "fargalts": "fargalt",
    "farhåg": "farhåga",
    "farhågan": "farhåga",
    "farhågans": "farhåga",
    "farhågas": "farhåga",
    "farhåge": "farhåga",
    "farhågor": "farhåga",
    "farhågorna": "farhåga",
    "farhågornas": "farhåga",
    "farhågors": "farhåga",
    "farhågs": "farhåga",
    "farinen": "farin",
    "farinens": "farin",
    "farinet": "farin",
    "farinets": "farin",
    "farins": "farin",
    "farinsockers": "farinsocker",
    "farinsockret": "farinsocker",
    "farinsockrets": "farinsocker",
    "fariseiska": "fariseisk",
    "fariseiskare": "fariseisk",
    "fariseiskares": "fariseisk",
    "fariseiskas": "fariseisk",
    "fariseiskast": "fariseisk",
    "fariseiskaste": "fariseisk",
    "fariseiskastes": "fariseisk",
    "fariseiskasts": "fariseisk",
    "fariseiske": "fariseisk",
    "fariseiskes": "fariseisk",
    "fariseisks": "fariseisk",
    "fariseiskt": "fariseisk",
    "fariseiskts": "fariseisk",
    "fariseismen": "fariseism",
    "fariseismens": "fariseism",
    "fariseismer": "fariseism",
    "fariseismerna": "fariseism",
    "fariseismernas": "fariseism",
    "fariseismers": "fariseism",
    "fariseisms": "fariseism",
    "fariséen": "farisé",
    "fariséens": "farisé",
    "fariséer": "farisé",
    "fariséerna": "farisé",
    "fariséernas": "farisé",
    "fariséers": "farisé",
    "farisén": "farisé",
    "fariséns": "farisé",
    "farisés": "farisé",
    "farit": "fara",
    "farits": "fara",
    "farkosten": "farkost",
    "farkostens": "farkost",
    "farkoster": "farkost",
    "farkosterna": "farkost",
    "farkosternas": "farkost",
    "farkosters": "farkost",
    "farkosts": "farkost",
    "farleden": "farled",
    "farledens": "farled",
    "farleder": "farled",
    "farlederna": "farled",
    "farledernas": "farled",
    "farleders": "farled",
    "farleds": "farled",
    "farliga": "farlig",
    "farligare": "farlig",
    "farligares": "farlig",
    "farligas": "farlig",
    "farligast": "farlig",
    "farligaste": "farlig",
    "farligastes": "farlig",
    "farligasts": "farlig",
    "farlige": "farlig",
    "farliges": "farlig",
    "farligheten": "farlighet",
    "farlighetens": "farlighet",
    "farligheter": "farlighet",
    "farligheterna": "farlighet",
    "farligheternas": "farlighet",
    "farligheters": "farlighet",
    "farlighets": "farlighet",
    "farlighetsstämpeln": "farlighetsstämpel",
    "farlighetsstämpelns": "farlighetsstämpel",
    "farlighetsstämpels": "farlighetsstämpel",
    "farlighetsstämplar": "farlighetsstämpel",
    "farlighetsstämplarna": "farlighetsstämpel",
    "farlighetsstämplarnas": "farlighetsstämpel",
    "farlighetsstämplars": "farlighetsstämpel",
    "farligs": "farlig",
    "farligt": "farlig",
    "farligts": "farlig",
    "farmaceuten": "farmaceut",
    "farmaceutens": "farmaceut",
    "farmaceuter": "farmaceut",
    "farmaceuterna": "farmaceut",
    "farmaceuternas": "farmaceut",
    "farmaceuters": "farmaceut",
    "farmaceutiska": "farmaceutisk",
    "farmaceutiskare": "farmaceutisk",
    "farmaceutiskares": "farmaceutisk",
    "farmaceutiskas": "farmaceutisk",
    "farmaceutiskast": "farmaceutisk",
    "farmaceutiskaste": "farmaceutisk",
    "farmaceutiskastes": "farmaceutisk",
    "farmaceutiskasts": "farmaceutisk",
    "farmaceutiske": "farmaceutisk",
    "farmaceutiskes": "farmaceutisk",
    "farmaceutisks": "farmaceutisk",
    "farmaceutiskt": "farmaceutisk",
    "farmaceutiskts": "farmaceutisk",
    "farmaceuts": "farmaceut",
    "farmacevten": "farmacevt",
    "farmacevtens": "farmacevt",
    "farmacevter": "farmacevt",
    "farmacevterna": "farmacevt",
    "farmacevternas": "farmacevt",
    "farmacevters": "farmacevt",
    "farmacevtiska": "farmacevtisk",
    "farmacevtiskare": "farmacevtisk",
    "farmacevtiskares": "farmacevtisk",
    "farmacevtiskas": "farmacevtisk",
    "farmacevtiskast": "farmacevtisk",
    "farmacevtiskaste": "farmacevtisk",
    "farmacevtiskastes": "farmacevtisk",
    "farmacevtiskasts": "farmacevtisk",
    "farmacevtiske": "farmacevtisk",
    "farmacevtiskes": "farmacevtisk",
    "farmacevtisks": "farmacevtisk",
    "farmacevtiskt": "farmacevtisk",
    "farmacevtiskts": "farmacevtisk",
    "farmacevts": "farmacevt",
    "farmacien": "farmaci",
    "farmaciens": "farmaci",
    "farmacin": "farmaci",
    "farmacins": "farmaci",
    "farmacis": "farmaci",
    "farmakan": "farmaka",
    "farmakana": "farmaka",
    "farmakanas": "farmaka",
    "farmakans": "farmaka",
    "farmakas": "farmaka",
    "farmakat": "farmaka",
    "farmakats": "farmaka",
    "farmakognosien": "farmakognosi",
    "farmakognosiens": "farmakognosi",
    "farmakognosin": "farmakognosi",
    "farmakognosins": "farmakognosi",
    "farmakognosis": "farmakognosi",
    "farmakologen": "farmakolog",
    "farmakologens": "farmakolog",
    "farmakologer": "farmakolog",
    "farmakologerna": "farmakolog",
    "farmakologernas": "farmakolog",
    "farmakologers": "farmakolog",
    "farmakologien": "farmakologi",
    "farmakologiens": "farmakologi",
    "farmakologin": "farmakologi",
    "farmakologins": "farmakologi",
    "farmakologis": "farmakologi",
    "farmakologiska": "farmakologisk",
    "farmakologiskare": "farmakologisk",
    "farmakologiskares": "farmakologisk",
    "farmakologiskas": "farmakologisk",
    "farmakologiskast": "farmakologisk",
    "farmakologiskaste": "farmakologisk",
    "farmakologiskastes": "farmakologisk",
    "farmakologiskasts": "farmakologisk",
    "farmakologiske": "farmakologisk",
    "farmakologiskes": "farmakologisk",
    "farmakologisks": "farmakologisk",
    "farmakologiskt": "farmakologisk",
    "farmakologiskts": "farmakologisk",
    "farmakologs": "farmakolog",
    "farmakopéer": "farmakopé",
    "farmakopéerna": "farmakopé",
    "farmakopéernas": "farmakopé",
    "farmakopéers": "farmakopé",
    "farmakopén": "farmakopé",
    "farmakopéns": "farmakopé",
    "farmakopés": "farmakopé",
    "farmar": "farmare",
    "farmardomkraften": "farmardomkraft",
    "farmardomkraftens": "farmardomkraft",
    "farmardomkrafter": "farmardomkraft",
    "farmardomkrafterna": "farmardomkraft",
    "farmardomkrafternas": "farmardomkraft",
    "farmardomkrafters": "farmardomkraft",
    "farmardomkrafts": "farmardomkraft",
    "farmaren": "farmare",
    "farmarens": "farmare",
    "farmares": "farmare",
    "farmarna": "farmare",
    "farmarnas": "farmare",
    "farmars": "farm",
    "farmen": "farm",
    "farmens": "farm",
    "farmer": "farm",
    "farmerna": "farm",
    "farmernas": "farm",
    "farmers": "farm",
    "farmoder": "farmor",
    "farmodern": "farmor",
    "farmoderns": "farmor",
    "farmoders": "farmor",
    "farmors": "farmor",
    "farms": "farm",
    "farmödrar": "farmor",
    "farmödrarna": "farmor",
    "farmödrarnas": "farmor",
    "farmödrars": "farmor",
    "farna": "fara",
    "farnas": "fara",
    "farne": "fara",
    "farnes": "fara",
    "faro": "fara",
    "farofyllda": "farofylld",
    "farofylldare": "farofylld",
    "farofylldares": "farofylld",
    "farofylldas": "farofylld",
    "farofylldast": "farofylld",
    "farofylldaste": "farofylld",
    "farofylldastes": "farofylld",
    "farofylldasts": "farofylld",
    "farofyllde": "farofylld",
    "farofylldes": "farofylld",
    "farofylldheten": "farofylldhet",
    "farofylldhetens": "farofylldhet",
    "farofylldhets": "farofylldhet",
    "farofyllds": "farofylld",
    "farofyllt": "farofylld",
    "farofyllts": "farofylld",
    "faror": "fara",
    "farorna": "fara",
    "farornas": "fara",
    "farors": "fara",
    "farozonen": "farozon",
    "farozonens": "farozon",
    "farozoner": "farozon",
    "farozonerna": "farozon",
    "farozonernas": "farozon",
    "farozoners": "farozon",
    "farozons": "farozon",
    "fars": "farsa",
    "farsan": "farsa",
    "farsans": "farsa",
    "farsartade": "farsartad",
    "farsartades": "farsartad",
    "farsartads": "farsartad",
    "farsartat": "farsartad",
    "farsartats": "farsartad",
    "farsarven": "farsarv",
    "farsarvens": "farsarv",
    "farsarvet": "farsarv",
    "farsarvets": "farsarv",
    "farsarvs": "farsarv",
    "farsas": "farsa",
    "farse": "farsa",
    "farsen": "fars",
    "farsens": "fars",
    "farser": "fars",
    "farserna": "fars",
    "farsernas": "fars",
    "farsers": "fars",
    "farsgubb": "farsgubbe",
    "farsgubbar": "farsgubbe",
    "farsgubbarna": "farsgubbe",
    "farsgubbarnas": "farsgubbe",
    "farsgubbars": "farsgubbe",
    "farsgubben": "farsgubbe",
    "farsgubbens": "farsgubbe",
    "farsgubbes": "farsgubbe",
    "farsgubbs": "farsgubbe",
    "farsor": "farsa",
    "farsorna": "farsa",
    "farsornas": "farsa",
    "farsors": "farsa",
    "farsoten": "farsot",
    "farsotens": "farsot",
    "farsoter": "farsot",
    "farsoterna": "farsot",
    "farsoternas": "farsot",
    "farsoters": "farsot",
    "farsots": "farsot",
    "farstun": "farstu",
    "farstuns": "farstu",
    "farstur": "farstu",
    "farsturna": "farstu",
    "farsturnas": "farstu",
    "farsturs": "farstu",
    "farstus": "farstu",
    "farstutrapp": "farstutrappa",
    "farstutrappan": "farstutrappa",
    "farstutrappans": "farstutrappa",
    "farstutrappas": "farstutrappa",
    "farstutrappe": "farstutrappa",
    "farstutrappor": "farstutrappa",
    "farstutrapporna": "farstutrappa",
    "farstutrappornas": "farstutrappa",
    "farstutrappors": "farstutrappa",
    "farstutrapps": "farstutrappa",
    "fartblinda": "fartblind",
    "fartblindare": "fartblind",
    "fartblindares": "fartblind",
    "fartblindas": "fartblind",
    "fartblindast": "fartblind",
    "fartblindaste": "fartblind",
    "fartblindastes": "fartblind",
    "fartblindasts": "fartblind",
    "fartblinde": "fartblind",
    "fartblindes": "fartblind",
    "fartblindheten": "fartblindhet",
    "fartblindhetens": "fartblindhet",
    "fartblindhets": "fartblindhet",
    "fartblinds": "fartblind",
    "fartblint": "fartblind",
    "fartblints": "fartblind",
    "fartdår": "fartdåre",
    "fartdårar": "fartdåre",
    "fartdårarna": "fartdåre",
    "fartdårarnas": "fartdåre",
    "fartdårars": "fartdåre",
    "fartdåren": "fartdåre",
    "fartdårens": "fartdåre",
    "fartdåres": "fartdåre",
    "fartdårs": "fartdåre",
    "farten": "fart",
    "fartens": "fart",
    "farter": "fart",
    "farterna": "fart",
    "farternas": "fart",
    "farters": "fart",
    "fartfyllda": "fartfylld",
    "fartfylldare": "fartfylld",
    "fartfylldares": "fartfylld",
    "fartfylldas": "fartfylld",
    "fartfylldast": "fartfylld",
    "fartfylldaste": "fartfylld",
    "fartfylldastes": "fartfylld",
    "fartfylldasts": "fartfylld",
    "fartfyllde": "fartfylld",
    "fartfylldes": "fartfylld",
    "fartfylldheten": "fartfylldhet",
    "fartfylldhetens": "fartfylldhet",
    "fartfylldhets": "fartfylldhet",
    "fartfyllds": "fartfylld",
    "fartfyllt": "fartfylld",
    "fartfyllts": "fartfylld",
    "farthinderna": "farthinder",
    "farthindernas": "farthinder",
    "farthinders": "farthinder",
    "farthindren": "farthinder",
    "farthindrens": "farthinder",
    "farthindret": "farthinder",
    "farthindrets": "farthinder",
    "farthållar": "farthållare",
    "farthållaren": "farthållare",
    "farthållarens": "farthållare",
    "farthållares": "farthållare",
    "farthållarna": "farthållare",
    "farthållarnas": "farthållare",
    "fartkameran": "fartkamera",
    "fartkamerans": "fartkamera",
    "fartkameras": "fartkamera",
    "fartkameror": "fartkamera",
    "fartkamerorna": "fartkamera",
    "fartkamerornas": "fartkamera",
    "fartkamerors": "fartkamera",
    "fartminskningar": "fartminskning",
    "fartminskningarna": "fartminskning",
    "fartminskningarnas": "fartminskning",
    "fartminskningars": "fartminskning",
    "fartminskningen": "fartminskning",
    "fartminskningens": "fartminskning",
    "fartminsknings": "fartminskning",
    "fartranden": "fartrand",
    "fartrandens": "fartrand",
    "fartrands": "fartrand",
    "fartreglagen": "fartreglage",
    "fartreglagens": "fartreglage",
    "fartreglages": "fartreglage",
    "fartreglaget": "fartreglage",
    "fartreglagets": "fartreglage",
    "fartränder": "fartrand",
    "fartränderna": "fartrand",
    "farträndernas": "fartrand",
    "fartränders": "fartrand",
    "farts": "fart",
    "fartspärrar": "fartspärr",
    "fartspärrarna": "fartspärr",
    "fartspärrarnas": "fartspärr",
    "fartspärrars": "fartspärr",
    "fartspärren": "fartspärr",
    "fartspärrens": "fartspärr",
    "fartspärrs": "fartspärr",
    "fartvinden": "fartvind",
    "fartvindens": "fartvind",
    "fartvinds": "fartvind",
    "fartygen": "fartyg",
    "fartygens": "fartyg",
    "fartyget": "fartyg",
    "fartygets": "fartyg",
    "fartygs": "fartyg",
    "fartygsbesättningar": "fartygsbesättning",
    "fartygsbesättningarna": "fartygsbesättning",
    "fartygsbesättningarnas": "fartygsbesättning",
    "fartygsbesättningars": "fartygsbesättning",
    "fartygsbesättningen": "fartygsbesättning",
    "fartygsbesättningens": "fartygsbesättning",
    "fartygsbesättnings": "fartygsbesättning",
    "fartygsbottens": "fartygsbotten",
    "fartygsbottnar": "fartygsbotten",
    "fartygsbottnarna": "fartygsbotten",
    "fartygsbottnarnas": "fartygsbotten",
    "fartygsbottnars": "fartygsbotten",
    "fartygsbottnen": "fartygsbotten",
    "fartygsbottnens": "fartygsbotten",
    "fartygsbyggartraditionen": "fartygsbyggartradition",
    "fartygsbyggartraditionens": "fartygsbyggartradition",
    "fartygsbyggartraditioner": "fartygsbyggartradition",
    "fartygsbyggartraditionerna": "fartygsbyggartradition",
    "fartygsbyggartraditionernas": "fartygsbyggartradition",
    "fartygsbyggartraditioners": "fartygsbyggartradition",
    "fartygsbyggartraditions": "fartygsbyggartradition",
    "fartygsdäcken": "fartygsdäck",
    "fartygsdäckens": "fartygsdäck",
    "fartygsdäcket": "fartygsdäck",
    "fartygsdäckets": "fartygsdäck",
    "fartygsdäcks": "fartygsdäck",
    "fartygsflaggen": "fartygsflagg",
    "fartygsflaggens": "fartygsflagg",
    "fartygsflaggs": "fartygsflagg",
    "fartygskatastrofen": "fartygskatastrof",
    "fartygskatastrofens": "fartygskatastrof",
    "fartygskatastrofer": "fartygskatastrof",
    "fartygskatastroferna": "fartygskatastrof",
    "fartygskatastrofernas": "fartygskatastrof",
    "fartygskatastrofers": "fartygskatastrof",
    "fartygskatastrofs": "fartygskatastrof",
    "fartygskollisionen": "fartygskollision",
    "fartygskollisionens": "fartygskollision",
    "fartygskollisioner": "fartygskollision",
    "fartygskollisionerna": "fartygskollision",
    "fartygskollisionernas": "fartygskollision",
    "fartygskollisioners": "fartygskollision",
    "fartygskollisions": "fartygskollision",
    "fartygskursen": "fartygskurs",
    "fartygskursens": "fartygskurs",
    "fartygskurser": "fartygskurs",
    "fartygskurserna": "fartygskurs",
    "fartygskursernas": "fartygskurs",
    "fartygskursers": "fartygskurs",
    "fartygslasten": "fartygslast",
    "fartygslastens": "fartygslast",
    "fartygslaster": "fartygslast",
    "fartygslasterna": "fartygslast",
    "fartygslasternas": "fartygslast",
    "fartygslasters": "fartygslast",
    "fartygslasts": "fartygslast",
    "fartygsluck": "fartygslucka",
    "fartygsluckan": "fartygslucka",
    "fartygsluckans": "fartygslucka",
    "fartygsluckas": "fartygslucka",
    "fartygslucke": "fartygslucka",
    "fartygsluckor": "fartygslucka",
    "fartygsluckorna": "fartygslucka",
    "fartygsluckornas": "fartygslucka",
    "fartygsluckors": "fartygslucka",
    "fartygslucks": "fartygslucka",
    "fartygsorkestern": "fartygsorkester",
    "fartygsorkesterns": "fartygsorkester",
    "fartygsorkesters": "fartygsorkester",
    "fartygsorkestrar": "fartygsorkester",
    "fartygsorkestrarna": "fartygsorkester",
    "fartygsorkestrarnas": "fartygsorkester",
    "fartygsorkestrars": "fartygsorkester",
    "fartygsprovianten": "fartygsproviant",
    "fartygsproviantens": "fartygsproviant",
    "fartygsproviants": "fartygsproviant",
    "fartygssidan": "fartygssida",
    "fartygssidans": "fartygssida",
    "fartygssidas": "fartygssida",
    "fartygsside": "fartygssida",
    "fartygssides": "fartygssida",
    "fartygssidor": "fartygssida",
    "fartygssidorna": "fartygssida",
    "fartygssidornas": "fartygssida",
    "fartygssidors": "fartygssida",
    "fartygsskroven": "fartygsskrov",
    "fartygsskrovens": "fartygsskrov",
    "fartygsskrovet": "fartygsskrov",
    "fartygsskrovets": "fartygsskrov",
    "fartygsskrovs": "fartygsskrov",
    "fartygstjänstgöringar": "fartygstjänstgöring",
    "fartygstjänstgöringarna": "fartygstjänstgöring",
    "fartygstjänstgöringarnas": "fartygstjänstgöring",
    "fartygstjänstgöringars": "fartygstjänstgöring",
    "fartygstjänstgöringen": "fartygstjänstgöring",
    "fartygstjänstgöringens": "fartygstjänstgöring",
    "fartygstjänstgörings": "fartygstjänstgöring",
    "fartygstrafiken": "fartygstrafik",
    "fartygstrafikens": "fartygstrafik",
    "fartygstrafiks": "fartygstrafik",
    "fartygstypen": "fartygstyp",
    "fartygstypens": "fartygstyp",
    "fartygstyper": "fartygstyp",
    "fartygstyperna": "fartygstyp",
    "fartygstypernas": "fartygstyp",
    "fartygstypers": "fartygstyp",
    "fartygstyps": "fartygstyp",
    "farvattens": "farvatten",
    "farvattnen": "farvatten",
    "farvattnens": "farvatten",
    "farvattnet": "farvatten",
    "farvattnets": "farvatten",
    "farvälen": "farväl",
    "farvälens": "farväl",
    "farvälet": "farväl",
    "farvälets": "farväl",
    "farväls": "farväl",
    "faryngala": "faryngal",
    "faryngalare": "faryngal",
    "faryngalares": "faryngal",
    "faryngalas": "faryngal",
    "faryngalast": "faryngal",
    "faryngalaste": "faryngal",
    "faryngalastes": "faryngal",
    "faryngalasts": "faryngal",
    "faryngale": "faryngal",
    "faryngales": "faryngal",
    "faryngals": "faryngal",
    "faryngalt": "faryngal",
    "faryngalts": "faryngal",
    "fas": "fasa",
    "fasad": "fasa",
    "fasade": "fasa",
    "fasaden": "fasad",
    "fasadens": "fasad",
    "fasader": "fasad",
    "fasaderna": "fasad",
    "fasadernas": "fasad",
    "fasaders": "fasad",
    "fasades": "fasa",
    "fasadpanelen": "fasadpanel",
    "fasadpanelens": "fasadpanel",
    "fasadpanels": "fasadpanel",
    "fasadpenseln": "fasadpensel",
    "fasadpenselns": "fasadpensel",
    "fasadpensels": "fasadpensel",
    "fasadpenslar": "fasadpensel",
    "fasadpenslarna": "fasadpensel",
    "fasadpenslarnas": "fasadpensel",
    "fasadpenslars": "fasadpensel",
    "fasadplatt": "fasadplatta",
    "fasadplattan": "fasadplatta",
    "fasadplattans": "fasadplatta",
    "fasadplattas": "fasadplatta",
    "fasadplatte": "fasadplatta",
    "fasadplattor": "fasadplatta",
    "fasadplattorna": "fasadplatta",
    "fasadplattornas": "fasadplatta",
    "fasadplattors": "fasadplatta",
    "fasadplatts": "fasadplatta",
    "fasads": "fasad",
    "fasadtegels": "fasadtegel",
    "fasadteglen": "fasadtegel",
    "fasadteglens": "fasadtegel",
    "fasadteglet": "fasadtegel",
    "fasadteglets": "fasadtegel",
    "fasan": "fasa",
    "fasande": "fasa",
    "fasanden": "fasande",
    "fasandena": "fasande",
    "fasandenas": "fasande",
    "fasandens": "fasande",
    "fasandes": "fasande",
    "fasandet": "fasande",
    "fasandets": "fasande",
    "fasanen": "fasan",
    "fasanens": "fasan",
    "fasaner": "fasan",
    "fasanerna": "fasan",
    "fasanernas": "fasan",
    "fasaners": "fasan",
    "fasans": "fasan",
    "fasansfulla": "fasansfull",
    "fasansfullare": "fasansfull",
    "fasansfullares": "fasansfull",
    "fasansfullas": "fasansfull",
    "fasansfullast": "fasansfull",
    "fasansfullaste": "fasansfull",
    "fasansfullastes": "fasansfull",
    "fasansfullasts": "fasansfull",
    "fasansfulle": "fasansfull",
    "fasansfulles": "fasansfull",
    "fasansfullheten": "fasansfullhet",
    "fasansfullhetens": "fasansfullhet",
    "fasansfullheter": "fasansfullhet",
    "fasansfullheterna": "fasansfullhet",
    "fasansfullheternas": "fasansfullhet",
    "fasansfullheters": "fasansfullhet",
    "fasansfullhets": "fasansfullhet",
    "fasansfulls": "fasansfull",
    "fasansfullt": "fasansfull",
    "fasansfullts": "fasansfull",
    "fasar": "fasa",
    "fasas": "fasa",
    "fasat": "fasa",
    "fasats": "fasa",
    "fascinationen": "fascination",
    "fascinationens": "fascination",
    "fascinationer": "fascination",
    "fascinationerna": "fascination",
    "fascinationernas": "fascination",
    "fascinationers": "fascination",
    "fascinations": "fascination",
    "fascinerad": "fascinera",
    "fascinerade": "fascinerad",
    "fascinerades": "fascinerad",
    "fascinerads": "fascinerad",
    "fascinerande": "fascinera",
    "fascineranden": "fascinerande",
    "fascinerandena": "fascinerande",
    "fascinerandenas": "fascinerande",
    "fascinerandens": "fascinerande",
    "fascinerandes": "fascinerande",
    "fascinerandet": "fascinerande",
    "fascinerandets": "fascinerande",
    "fascinerar": "fascinera",
    "fascineras": "fascinera",
    "fascinerat": "fascinerad",
    "fascinerats": "fascinerad",
    "fascinerbara": "fascinerbar",
    "fascinerbarare": "fascinerbar",
    "fascinerbarares": "fascinerbar",
    "fascinerbaras": "fascinerbar",
    "fascinerbarast": "fascinerbar",
    "fascinerbaraste": "fascinerbar",
    "fascinerbarastes": "fascinerbar",
    "fascinerbarasts": "fascinerbar",
    "fascinerbare": "fascinerbar",
    "fascinerbares": "fascinerbar",
    "fascinerbarheten": "fascinerbarhet",
    "fascinerbarhetens": "fascinerbarhet",
    "fascinerbarhets": "fascinerbarhet",
    "fascinerbars": "fascinerbar",
    "fascinerbart": "fascinerbar",
    "fascinerbarts": "fascinerbar",
    "fascineringar": "fascinering",
    "fascineringarna": "fascinering",
    "fascineringarnas": "fascinering",
    "fascineringars": "fascinering",
    "fascineringen": "fascinering",
    "fascineringens": "fascinering",
    "fascinerings": "fascinering",
    "fascismen": "fascism",
    "fascismens": "fascism",
    "fascismer": "fascism",
    "fascismerna": "fascism",
    "fascismernas": "fascism",
    "fascismers": "fascism",
    "fascisms": "fascism",
    "fascisten": "fascist",
    "fascistens": "fascist",
    "fascister": "fascist",
    "fascisterna": "fascist",
    "fascisternas": "fascist",
    "fascisters": "fascist",
    "fascistiska": "fascistisk",
    "fascistiskare": "fascistisk",
    "fascistiskares": "fascistisk",
    "fascistiskas": "fascistisk",
    "fascistiskast": "fascistisk",
    "fascistiskaste": "fascistisk",
    "fascistiskastes": "fascistisk",
    "fascistiskasts": "fascistisk",
    "fascistiske": "fascistisk",
    "fascistiskes": "fascistisk",
    "fascistisks": "fascistisk",
    "fascistiskt": "fascistisk",
    "fascistiskts": "fascistisk",
    "fascistoida": "fascistoid",
    "fascistoidare": "fascistoid",
    "fascistoidares": "fascistoid",
    "fascistoidas": "fascistoid",
    "fascistoidast": "fascistoid",
    "fascistoidaste": "fascistoid",
    "fascistoidastes": "fascistoid",
    "fascistoidasts": "fascistoid",
    "fascistoide": "fascistoid",
    "fascistoides": "fascistoid",
    "fascistoids": "fascistoid",
    "fascists": "fascist",
    "fasder": "far",
    "fasen": "fas",
    "fasens": "fasen",
    "faser": "fas",
    "faserna": "fas",
    "fasernas": "fas",
    "fasers": "fas",
    "fasetten": "fasett",
    "fasettens": "fasett",
    "fasetter": "fasett",
    "fasetterad": "fasettera",
    "fasetterade": "fasetterad",
    "fasetterades": "fasetterad",
    "fasetterads": "fasetterad",
    "fasetterande": "fasettera",
    "fasetteranden": "fasetterande",
    "fasetterandena": "fasetterande",
    "fasetterandenas": "fasetterande",
    "fasetterandens": "fasetterande",
    "fasetterandes": "fasetterande",
    "fasetterandet": "fasetterande",
    "fasetterandets": "fasetterande",
    "fasetterar": "fasettera",
    "fasetteras": "fasettera",
    "fasetterat": "fasetterad",
    "fasetterats": "fasetterad",
    "fasetterbara": "fasetterbar",
    "fasetterbarare": "fasetterbar",
    "fasetterbarares": "fasetterbar",
    "fasetterbaras": "fasetterbar",
    "fasetterbarast": "fasetterbar",
    "fasetterbaraste": "fasetterbar",
    "fasetterbarastes": "fasetterbar",
    "fasetterbarasts": "fasetterbar",
    "fasetterbare": "fasetterbar",
    "fasetterbares": "fasetterbar",
    "fasetterbarheten": "fasetterbarhet",
    "fasetterbarhetens": "fasetterbarhet",
    "fasetterbarhets": "fasetterbarhet",
    "fasetterbars": "fasetterbar",
    "fasetterbart": "fasetterbar",
    "fasetterbarts": "fasetterbar",
    "fasetteringar": "fasettering",
    "fasetteringarna": "fasettering",
    "fasetteringarnas": "fasettering",
    "fasetteringars": "fasettering",
    "fasetteringen": "fasettering",
    "fasetteringens": "fasettering",
    "fasetterings": "fasettering",
    "fasetterna": "fasett",
    "fasetternas": "fasett",
    "fasetters": "fasett",
    "fasetts": "fasett",
    "fasettögas": "fasettöga",
    "fasettögat": "fasettöga",
    "fasettögats": "fasettöga",
    "fasettögon": "fasettöga",
    "fasettögonen": "fasettöga",
    "fasettögonens": "fasettöga",
    "fasettögons": "fasettöga",
    "fasförskjutningar": "fasförskjutning",
    "fasförskjutningarna": "fasförskjutning",
    "fasförskjutningarnas": "fasförskjutning",
    "fasförskjutningars": "fasförskjutning",
    "fasförskjutningen": "fasförskjutning",
    "fasförskjutningens": "fasförskjutning",
    "fasförskjutnings": "fasförskjutning",
    "fashionabels": "fashionabel",
    "fashionabelt": "fashionabel",
    "fashionabelts": "fashionabel",
    "fashionabla": "fashionabel",
    "fashionablare": "fashionabel",
    "fashionablares": "fashionabel",
    "fashionablas": "fashionabel",
    "fashionablast": "fashionabel",
    "fashionablaste": "fashionabel",
    "fashionablastes": "fashionabel",
    "fashionablasts": "fashionabel",
    "fashionable": "fashionabel",
    "fashionables": "fashionabel",
    "fasingens": "fasingen",
    "faskikeln": "faskikel",
    "faskikelns": "faskikel",
    "faskikels": "faskikel",
    "faskiklar": "faskikel",
    "faskiklarna": "faskikel",
    "faskiklarnas": "faskikel",
    "faskiklars": "faskikel",
    "faskinen": "faskin",
    "faskinens": "faskin",
    "faskiner": "faskin",
    "faskinerna": "faskin",
    "faskinernas": "faskin",
    "faskiners": "faskin",
    "faskinknivar": "faskinkniv",
    "faskinknivarna": "faskinkniv",
    "faskinknivarnas": "faskinkniv",
    "faskinknivars": "faskinkniv",
    "faskinkniven": "faskinkniv",
    "faskinknivens": "faskinkniv",
    "faskinknivs": "faskinkniv",
    "faskins": "faskin",
    "fasliga": "faslig",
    "fasligare": "faslig",
    "fasligares": "faslig",
    "fasligas": "faslig",
    "fasligast": "faslig",
    "fasligaste": "faslig",
    "fasligastes": "faslig",
    "fasligasts": "faslig",
    "faslige": "faslig",
    "fasliges": "faslig",
    "fasligheten": "faslighet",
    "faslighetens": "faslighet",
    "fasligheter": "faslighet",
    "fasligheterna": "faslighet",
    "fasligheternas": "faslighet",
    "fasligheters": "faslighet",
    "faslighets": "faslighet",
    "fasligs": "faslig",
    "fasligt": "faslig",
    "fasligts": "faslig",
    "fasonen": "fason",
    "fasonens": "fason",
    "fasoner": "fason",
    "fasonerad": "fasonera",
    "fasonerade": "fasonera",
    "fasonerades": "fasonera",
    "fasonerads": "fasonera",
    "fasonerande": "fasonera",
    "fasoneranden": "fasonerande",
    "fasonerandena": "fasonerande",
    "fasonerandenas": "fasonerande",
    "fasonerandens": "fasonerande",
    "fasonerandes": "fasonerande",
    "fasonerandet": "fasonerande",
    "fasonerandets": "fasonerande",
    "fasonerar": "fasonera",
    "fasoneras": "fasonera",
    "fasonerat": "fasonera",
    "fasonerats": "fasonera",
    "fasonerbara": "fasonerbar",
    "fasonerbarare": "fasonerbar",
    "fasonerbarares": "fasonerbar",
    "fasonerbaras": "fasonerbar",
    "fasonerbarast": "fasonerbar",
    "fasonerbaraste": "fasonerbar",
    "fasonerbarastes": "fasonerbar",
    "fasonerbarasts": "fasonerbar",
    "fasonerbare": "fasonerbar",
    "fasonerbares": "fasonerbar",
    "fasonerbarheten": "fasonerbarhet",
    "fasonerbarhetens": "fasonerbarhet",
    "fasonerbarhets": "fasonerbarhet",
    "fasonerbars": "fasonerbar",
    "fasonerbart": "fasonerbar",
    "fasonerbarts": "fasonerbar",
    "fasoneringar": "fasonering",
    "fasoneringarna": "fasonering",
    "fasoneringarnas": "fasonering",
    "fasoneringars": "fasonering",
    "fasoneringen": "fasonering",
    "fasoneringens": "fasonering",
    "fasonerings": "fasonering",
    "fasonerna": "fason",
    "fasonernas": "fason",
    "fasoners": "fason",
    "fasons": "fason",
    "fasor": "fasa",
    "fasorna": "fasa",
    "fasornas": "fasa",
    "fasors": "fasa",
    "fasspänningar": "fasspänning",
    "fasspänningarna": "fasspänning",
    "fasspänningarnas": "fasspänning",
    "fasspänningars": "fasspänning",
    "fasspänningen": "fasspänning",
    "fasspänningens": "fasspänning",
    "fasspännings": "fasspänning",
    "fasta": "fast",
    "fastade": "fasta",
    "fastades": "fasta",
    "fastagen": "fastage",
    "fastagens": "fastage",
    "fastages": "fastage",
    "fastaget": "fastage",
    "fastagets": "fastage",
    "fastan": "fasta",
    "fastande": "fasta",
    "fastanden": "fastande",
    "fastandena": "fastande",
    "fastandenas": "fastande",
    "fastandens": "fastande",
    "fastandes": "fastande",
    "fastandet": "fastande",
    "fastandets": "fastande",
    "fastans": "fastan",
    "fastar": "fasta",
    "fastare": "fast",
    "fastares": "fast",
    "fastas": "fasta",
    "fastast": "fast",
    "fastaste": "fast",
    "fastastes": "fast",
    "fastasts": "fast",
    "fastat": "fasta",
    "fastats": "fasta",
    "faste": "fasta",
    "fastemånaden": "fastemånad",
    "fastemånadens": "fastemånad",
    "fastemånader": "fastemånad",
    "fastemånaderna": "fastemånad",
    "fastemånadernas": "fastemånad",
    "fastemånaders": "fastemånad",
    "fastemånads": "fastemånad",
    "fastern": "faster",
    "fasterns": "faster",
    "fasters": "faster",
    "fastes": "fast",
    "fastetiden": "fastetid",
    "fastetidens": "fastetid",
    "fastetider": "fastetid",
    "fastetiderna": "fastetid",
    "fastetidernas": "fastetid",
    "fastetiders": "fastetid",
    "fastetids": "fastetid",
    "fastfrusens": "fastfrusen",
    "fastfruset": "fastfrusen",
    "fastfrusets": "fastfrusen",
    "fastfrusna": "fastfrusen",
    "fastfrusnare": "fastfrusen",
    "fastfrusnares": "fastfrusen",
    "fastfrusnas": "fastfrusen",
    "fastfrusnast": "fastfrusen",
    "fastfrusnaste": "fastfrusen",
    "fastfrusnastes": "fastfrusen",
    "fastfrusnasts": "fastfrusen",
    "fastfrusne": "fastfrusen",
    "fastfrusnes": "fastfrusen",
    "fastgjord": "fastgöra",
    "fastgjorda": "fastgöra",
    "fastgjordas": "fastgöra",
    "fastgjorde": "fastgöra",
    "fastgjordes": "fastgöra",
    "fastgjords": "fastgöra",
    "fastgjort": "fastgöra",
    "fastgjorts": "fastgöra",
    "fastgör": "fastgöra",
    "fastgörande": "fastgöra",
    "fastgöranden": "fastgörande",
    "fastgörandena": "fastgörande",
    "fastgörandenas": "fastgörande",
    "fastgörandens": "fastgörande",
    "fastgörandes": "fastgörande",
    "fastgörandet": "fastgörande",
    "fastgörandets": "fastgörande",
    "fastgöras": "fastgöra",
    "fastgöres": "fastgöra",
    "fastgörs": "fastgöra",
    "fastheten": "fasthet",
    "fasthetens": "fasthet",
    "fastheter": "fasthet",
    "fastheterna": "fasthet",
    "fastheternas": "fasthet",
    "fastheters": "fasthet",
    "fasthets": "fasthet",
    "fasthåll": "fasthålla",
    "fasthållande": "fasthålla",
    "fasthållanden": "fasthållande",
    "fasthållandena": "fasthållande",
    "fasthållandenas": "fasthållande",
    "fasthållandens": "fasthållande",
    "fasthållandes": "fasthållande",
    "fasthållandet": "fasthållande",
    "fasthållandets": "fasthållande",
    "fasthållas": "fasthålla",
    "fasthålle": "fasthålla",
    "fasthållen": "fasthålla",
    "fasthållens": "fasthålla",
    "fasthåller": "fasthålla",
    "fasthålles": "fasthålla",
    "fasthållet": "fasthålla",
    "fasthållets": "fasthålla",
    "fasthållit": "fasthålla",
    "fasthållits": "fasthålla",
    "fasthållna": "fasthålla",
    "fasthållnas": "fasthålla",
    "fasthållne": "fasthålla",
    "fasthållnes": "fasthålla",
    "fasthållningar": "fasthållning",
    "fasthållningarna": "fasthållning",
    "fasthållningarnas": "fasthållning",
    "fasthållningars": "fasthållning",
    "fasthållningen": "fasthållning",
    "fasthållningens": "fasthållning",
    "fasthållnings": "fasthållning",
    "fasthålls": "fasthålla",
    "fasthöll": "fasthålla",
    "fasthölle": "fasthålla",
    "fasthölles": "fasthålla",
    "fasthölls": "fasthålla",
    "fastigheten": "fastighet",
    "fastighetens": "fastighet",
    "fastigheter": "fastighet",
    "fastigheterna": "fastighet",
    "fastigheternas": "fastighet",
    "fastigheters": "fastighet",
    "fastighets": "fastighet",
    "fastighetsaffären": "fastighetsaffär",
    "fastighetsaffärens": "fastighetsaffär",
    "fastighetsaffärer": "fastighetsaffär",
    "fastighetsaffärerna": "fastighetsaffär",
    "fastighetsaffärernas": "fastighetsaffär",
    "fastighetsaffärers": "fastighetsaffär",
    "fastighetsaffärs": "fastighetsaffär",
    "fastighetsbubbel": "fastighetsbubbla",
    "fastighetsbubblan": "fastighetsbubbla",
    "fastighetsbubblans": "fastighetsbubbla",
    "fastighetsbubblas": "fastighetsbubbla",
    "fastighetsbubble": "fastighetsbubbla",
    "fastighetsbubblor": "fastighetsbubbla",
    "fastighetsbubblorna": "fastighetsbubbla",
    "fastighetsbubblornas": "fastighetsbubbla",
    "fastighetsbubblors": "fastighetsbubbla",
    "fastighetsbyråer": "fastighetsbyrå",
    "fastighetsbyråerna": "fastighetsbyrå",
    "fastighetsbyråernas": "fastighetsbyrå",
    "fastighetsbyråers": "fastighetsbyrå",
    "fastighetsbyrån": "fastighetsbyrå",
    "fastighetsbyråns": "fastighetsbyrå",
    "fastighetsbyrås": "fastighetsbyrå",
    "fastighetskontoren": "fastighetskontor",
    "fastighetskontorens": "fastighetskontor",
    "fastighetskontoret": "fastighetskontor",
    "fastighetskontorets": "fastighetskontor",
    "fastighetskontors": "fastighetskontor",
    "fastighetskrisen": "fastighetskris",
    "fastighetskrisens": "fastighetskris",
    "fastighetskriser": "fastighetskris",
    "fastighetskriserna": "fastighetskris",
    "fastighetskrisernas": "fastighetskris",
    "fastighetskrisers": "fastighetskris",
    "fastighetsköpen": "fastighetsköp",
    "fastighetsköpens": "fastighetsköp",
    "fastighetsköpet": "fastighetsköp",
    "fastighetsköpets": "fastighetsköp",
    "fastighetsköps": "fastighetsköp",
    "fastighetsmogulen": "fastighetsmogul",
    "fastighetsmogulens": "fastighetsmogul",
    "fastighetsmoguler": "fastighetsmogul",
    "fastighetsmogulerna": "fastighetsmogul",
    "fastighetsmogulernas": "fastighetsmogul",
    "fastighetsmogulers": "fastighetsmogul",
    "fastighetsmoguls": "fastighetsmogul",
    "fastighetsmäklar": "fastighetsmäklare",
    "fastighetsmäklaren": "fastighetsmäklare",
    "fastighetsmäklarens": "fastighetsmäklare",
    "fastighetsmäklares": "fastighetsmäklare",
    "fastighetsmäklarna": "fastighetsmäklare",
    "fastighetsmäklarnas": "fastighetsmäklare",
    "fastighetsprisen": "fastighetspris",
    "fastighetsprisens": "fastighetspris",
    "fastighetspriser": "fastighetspris",
    "fastighetspriserna": "fastighetspris",
    "fastighetsprisernas": "fastighetspris",
    "fastighetsprisers": "fastighetspris",
    "fastighetspriset": "fastighetspris",
    "fastighetsprisets": "fastighetspris",
    "fastighetsskatten": "fastighetsskatt",
    "fastighetsskattens": "fastighetsskatt",
    "fastighetsskatter": "fastighetsskatt",
    "fastighetsskatterna": "fastighetsskatt",
    "fastighetsskatternas": "fastighetsskatt",
    "fastighetsskatters": "fastighetsskatt",
    "fastighetsskatts": "fastighetsskatt",
    "fastighetsskötar": "fastighetsskötare",
    "fastighetsskötaren": "fastighetsskötare",
    "fastighetsskötarens": "fastighetsskötare",
    "fastighetsskötares": "fastighetsskötare",
    "fastighetsskötarna": "fastighetsskötare",
    "fastighetsskötarnas": "fastighetsskötare",
    "fastighetstaxerad": "fastighetstaxera",
    "fastighetstaxerade": "fastighetstaxera",
    "fastighetstaxerades": "fastighetstaxera",
    "fastighetstaxerads": "fastighetstaxera",
    "fastighetstaxerande": "fastighetstaxera",
    "fastighetstaxeranden": "fastighetstaxerande",
    "fastighetstaxerandena": "fastighetstaxerande",
    "fastighetstaxerandenas": "fastighetstaxerande",
    "fastighetstaxerandens": "fastighetstaxerande",
    "fastighetstaxerandes": "fastighetstaxerande",
    "fastighetstaxerandet": "fastighetstaxerande",
    "fastighetstaxerandets": "fastighetstaxerande",
    "fastighetstaxerar": "fastighetstaxera",
    "fastighetstaxeras": "fastighetstaxera",
    "fastighetstaxerat": "fastighetstaxera",
    "fastighetstaxerats": "fastighetstaxera",
    "fastighetstaxerbara": "fastighetstaxerbar",
    "fastighetstaxerbarare": "fastighetstaxerbar",
    "fastighetstaxerbarares": "fastighetstaxerbar",
    "fastighetstaxerbaras": "fastighetstaxerbar",
    "fastighetstaxerbarast": "fastighetstaxerbar",
    "fastighetstaxerbaraste": "fastighetstaxerbar",
    "fastighetstaxerbarastes": "fastighetstaxerbar",
    "fastighetstaxerbarasts": "fastighetstaxerbar",
    "fastighetstaxerbare": "fastighetstaxerbar",
    "fastighetstaxerbares": "fastighetstaxerbar",
    "fastighetstaxerbarheten": "fastighetstaxerbarhet",
    "fastighetstaxerbarhetens": "fastighetstaxerbarhet",
    "fastighetstaxerbarhets": "fastighetstaxerbarhet",
    "fastighetstaxerbars": "fastighetstaxerbar",
    "fastighetstaxerbart": "fastighetstaxerbar",
    "fastighetstaxerbarts": "fastighetstaxerbar",
    "fastighetstaxeringar": "fastighetstaxering",
    "fastighetstaxeringarna": "fastighetstaxering",
    "fastighetstaxeringarnas": "fastighetstaxering",
    "fastighetstaxeringars": "fastighetstaxering",
    "fastighetstaxeringen": "fastighetstaxering",
    "fastighetstaxeringens": "fastighetstaxering",
    "fastighetstaxerings": "fastighetstaxering",
    "fastkedj": "fastkedja",
    "fastkedjad": "fastkedja",
    "fastkedjade": "fastkedja",
    "fastkedjades": "fastkedja",
    "fastkedjads": "fastkedja",
    "fastkedjan": "fastkedja",
    "fastkedjande": "fastkedja",
    "fastkedjanden": "fastkedjande",
    "fastkedjandena": "fastkedjande",
    "fastkedjandenas": "fastkedjande",
    "fastkedjandens": "fastkedjande",
    "fastkedjandes": "fastkedjande",
    "fastkedjandet": "fastkedjande",
    "fastkedjandets": "fastkedjande",
    "fastkedjans": "fastkedja",
    "fastkedjar": "fastkedja",
    "fastkedjas": "fastkedja",
    "fastkedjat": "fastkedja",
    "fastkedjats": "fastkedja",
    "fastkedje": "fastkedja",
    "fastkedjor": "fastkedja",
    "fastkedjorna": "fastkedja",
    "fastkedjornas": "fastkedja",
    "fastkedjors": "fastkedja",
    "fastklistrad": "fastklistra",
    "fastklistrade": "fastklistra",
    "fastklistrades": "fastklistra",
    "fastklistrads": "fastklistra",
    "fastklistrande": "fastklistra",
    "fastklistranden": "fastklistrande",
    "fastklistrandena": "fastklistrande",
    "fastklistrandenas": "fastklistrande",
    "fastklistrandens": "fastklistrande",
    "fastklistrandes": "fastklistrande",
    "fastklistrandet": "fastklistrande",
    "fastklistrandets": "fastklistrande",
    "fastklistrar": "fastklistra",
    "fastklistras": "fastklistra",
    "fastklistrat": "fastklistra",
    "fastklistrats": "fastklistra",
    "fastla": "fastlägga",
    "fastlade": "fastlägga",
    "fastlades": "fastlägga",
    "fastlagd": "fastlägga",
    "fastlagda": "fastlägga",
    "fastlagdas": "fastlägga",
    "fastlagde": "fastlägga",
    "fastlagdes": "fastlägga",
    "fastlagds": "fastlägga",
    "fastlagen": "fastlag",
    "fastlagens": "fastlag",
    "fastlags": "fastlag",
    "fastlagsbull": "fastlagsbulle",
    "fastlagsbullan": "fastlagsbulla",
    "fastlagsbullans": "fastlagsbulla",
    "fastlagsbullar": "fastlagsbulle",
    "fastlagsbullarna": "fastlagsbulle",
    "fastlagsbullarnas": "fastlagsbulle",
    "fastlagsbullars": "fastlagsbulle",
    "fastlagsbullas": "fastlagsbulla",
    "fastlagsbulle": "fastlagsbulla",
    "fastlagsbullen": "fastlagsbulle",
    "fastlagsbullens": "fastlagsbulle",
    "fastlagsbulles": "fastlagsbulle",
    "fastlagsbullor": "fastlagsbulla",
    "fastlagsbullorna": "fastlagsbulla",
    "fastlagsbullornas": "fastlagsbulla",
    "fastlagsbullors": "fastlagsbulla",
    "fastlagsbulls": "fastlagsbulle",
    "fastlagsrisen": "fastlagsris",
    "fastlagsrisens": "fastlagsris",
    "fastlagsriset": "fastlagsris",
    "fastlagsrisets": "fastlagsris",
    "fastlagssöndagar": "fastlagssöndag",
    "fastlagssöndagarna": "fastlagssöndag",
    "fastlagssöndagarnas": "fastlagssöndag",
    "fastlagssöndagars": "fastlagssöndag",
    "fastlagssöndagen": "fastlagssöndag",
    "fastlagssöndagens": "fastlagssöndag",
    "fastlagssöndags": "fastlagssöndag",
    "fastlagt": "fastlägga",
    "fastlagts": "fastlägga",
    "fastlandet": "fastland",
    "fastlandets": "fastland",
    "fastlands": "fastland",
    "fastlandsklimatet": "fastlandsklimat",
    "fastlandsklimatets": "fastlandsklimat",
    "fastlandsklimats": "fastlandsklimat",
    "fastlas": "fastlägga",
    "fastlägg": "fastlägga",
    "fastläggande": "fastlägga",
    "fastlägganden": "fastläggande",
    "fastläggandena": "fastläggande",
    "fastläggandenas": "fastläggande",
    "fastläggandens": "fastläggande",
    "fastläggandes": "fastläggande",
    "fastläggandet": "fastläggande",
    "fastläggandets": "fastläggande",
    "fastläggas": "fastlägga",
    "fastlägger": "fastlägga",
    "fastlägges": "fastlägga",
    "fastläggs": "fastlägga",
    "fastlänningar": "fastlänning",
    "fastlänningarna": "fastlänning",
    "fastlänningarnas": "fastlänning",
    "fastlänningars": "fastlänning",
    "fastlänningen": "fastlänning",
    "fastlänningens": "fastlänning",
    "fastlännings": "fastlänning",
    "fastlåsta": "fastlåst",
    "fastlåstare": "fastlåst",
    "fastlåstares": "fastlåst",
    "fastlåstas": "fastlåst",
    "fastlåstast": "fastlåst",
    "fastlåstaste": "fastlåst",
    "fastlåstastes": "fastlåst",
    "fastlåstasts": "fastlåst",
    "fastlåste": "fastlåst",
    "fastlåstes": "fastlåst",
    "fastlåsts": "fastlåst",
    "fastnade": "fastna",
    "fastnades": "fastna",
    "fastnaglade": "fastnaglad",
    "fastnaglades": "fastnaglad",
    "fastnaglads": "fastnaglad",
    "fastnaglat": "fastnaglad",
    "fastnaglats": "fastnaglad",
    "fastnande": "fastna",
    "fastnanden": "fastnande",
    "fastnandena": "fastnande",
    "fastnandenas": "fastnande",
    "fastnandens": "fastnande",
    "fastnandes": "fastnande",
    "fastnandet": "fastnande",
    "fastnandets": "fastnande",
    "fastnar": "fastna",
    "fastnas": "fastna",
    "fastnat": "fastna",
    "fastnats": "fastna",
    "fastor": "fasta",
    "fastorna": "fasta",
    "fastornas": "fasta",
    "fastors": "fasta",
    "fastrar": "faster",
    "fastrarna": "faster",
    "fastrarnas": "faster",
    "fastrars": "faster",
    "fasts": "fast",
    "fastsatt": "fastsätta",
    "fastsatta": "fastsätta",
    "fastsattas": "fastsätta",
    "fastsatte": "fastsätta",
    "fastsattes": "fastsätta",
    "fastsatts": "fastsätta",
    "fastslagen": "fastslå",
    "fastslagens": "fastslå",
    "fastslaget": "fastslå",
    "fastslagets": "fastslå",
    "fastslagit": "fastslå",
    "fastslagits": "fastslå",
    "fastslagna": "fastslå",
    "fastslagnas": "fastslå",
    "fastslagne": "fastslå",
    "fastslagnes": "fastslå",
    "fastslog": "fastslå",
    "fastsloge": "fastslå",
    "fastsloges": "fastslå",
    "fastslogs": "fastslå",
    "fastslående": "fastslå",
    "fastslåenden": "fastslående",
    "fastslåendena": "fastslående",
    "fastslåendenas": "fastslående",
    "fastslåendens": "fastslående",
    "fastslåendes": "fastslående",
    "fastslåendet": "fastslående",
    "fastslåendets": "fastslående",
    "fastslår": "fastslå",
    "fastslås": "fastslå",
    "fastspänningen": "fastspänning",
    "fastspänningens": "fastspänning",
    "fastspännings": "fastspänning",
    "fastställ": "fastställa",
    "fastställande": "fastställa",
    "fastställanden": "fastställande",
    "fastställandena": "fastställande",
    "fastställandenas": "fastställande",
    "fastställandens": "fastställande",
    "fastställandes": "fastställande",
    "fastställandet": "fastställande",
    "fastställandets": "fastställande",
    "fastställas": "fastställa",
    "fastställd": "fastställa",
    "fastställda": "fastställa",
    "fastställdas": "fastställa",
    "fastställde": "fastställa",
    "fastställdes": "fastställa",
    "fastställds": "fastställa",
    "fastställer": "fastställa",
    "fastställes": "fastställa",
    "fastställs": "fastställa",
    "fastställt": "fastställa",
    "fastställts": "fastställa",
    "fastsätt": "fastsätta",
    "fastsättande": "fastsätta",
    "fastsättanden": "fastsättande",
    "fastsättandena": "fastsättande",
    "fastsättandenas": "fastsättande",
    "fastsättandens": "fastsättande",
    "fastsättandes": "fastsättande",
    "fastsättandet": "fastsättande",
    "fastsättandets": "fastsättande",
    "fastsättas": "fastsätta",
    "fastsätter": "fastsätta",
    "fastsättes": "fastsätta",
    "fastsättningar": "fastsättning",
    "fastsättningarna": "fastsättning",
    "fastsättningarnas": "fastsättning",
    "fastsättningars": "fastsättning",
    "fastsättningen": "fastsättning",
    "fastsättningens": "fastsättning",
    "fastsättnings": "fastsättning",
    "fastsätts": "fastsätta",
    "fasttag": "fastta",
    "fasttaga": "fastta",
    "fasttagande": "fastta",
    "fasttaganden": "fasttagande",
    "fasttagandena": "fasttagande",
    "fasttagandenas": "fasttagande",
    "fasttagandens": "fasttagande",
    "fasttagandes": "fasttagande",
    "fasttagandet": "fasttagande",
    "fasttagandets": "fasttagande",
    "fasttagas": "fastta",
    "fasttage": "fastta",
    "fasttagen": "fastta",
    "fasttagens": "fastta",
    "fasttager": "fastta",
    "fasttages": "fastta",
    "fasttaget": "fastta",
    "fasttagets": "fastta",
    "fasttagit": "fastta",
    "fasttagits": "fastta",
    "fasttagna": "fastta",
    "fasttagnas": "fastta",
    "fasttagne": "fastta",
    "fasttagnes": "fastta",
    "fasttags": "fastta",
    "fasttar": "fastta",
    "fasttas": "fastta",
    "fasttejpade": "fasttejpad",
    "fasttejpades": "fasttejpad",
    "fasttejpads": "fasttejpad",
    "fasttejpat": "fasttejpad",
    "fasttejpats": "fasttejpad",
    "fasttog": "fastta",
    "fasttoge": "fastta",
    "fasttoges": "fastta",
    "fasttogs": "fastta",
    "fataburen": "fatabur",
    "fataburens": "fatabur",
    "fataburer": "fatabur",
    "fataburerna": "fatabur",
    "fataburernas": "fatabur",
    "fataburers": "fatabur",
    "fataburs": "fatabur",
    "fatala": "fatal",
    "fatalare": "fatal",
    "fatalares": "fatal",
    "fatalas": "fatal",
    "fatalast": "fatal",
    "fatalaste": "fatal",
    "fatalastes": "fatal",
    "fatalasts": "fatal",
    "fatale": "fatal",
    "fatales": "fatal",
    "fatalie": "fatalier",
    "fataliedagar": "fataliedag",
    "fataliedagarna": "fataliedag",
    "fataliedagarnas": "fataliedag",
    "fataliedagars": "fataliedag",
    "fataliedagen": "fataliedag",
    "fataliedagens": "fataliedag",
    "fataliedags": "fataliedag",
    "fatalierna": "fatalier",
    "fataliernas": "fatalier",
    "fataliers": "fatalier",
    "fatalietiden": "fatalietid",
    "fatalietidens": "fatalietid",
    "fatalietider": "fatalietid",
    "fatalietiderna": "fatalietid",
    "fatalietidernas": "fatalietid",
    "fatalietiders": "fatalietid",
    "fatalietids": "fatalietid",
    "fatalismen": "fatalism",
    "fatalismens": "fatalism",
    "fatalismer": "fatalism",
    "fatalismerna": "fatalism",
    "fatalismernas": "fatalism",
    "fatalismers": "fatalism",
    "fatalisms": "fatalism",
    "fatalisten": "fatalist",
    "fatalistens": "fatalist",
    "fatalister": "fatalist",
    "fatalisterna": "fatalist",
    "fatalisternas": "fatalist",
    "fatalisters": "fatalist",
    "fatalistiska": "fatalistisk",
    "fatalistiskare": "fatalistisk",
    "fatalistiskares": "fatalistisk",
    "fatalistiskas": "fatalistisk",
    "fatalistiskast": "fatalistisk",
    "fatalistiskaste": "fatalistisk",
    "fatalistiskastes": "fatalistisk",
    "fatalistiskasts": "fatalistisk",
    "fatalistiske": "fatalistisk",
    "fatalistiskes": "fatalistisk",
    "fatalistisks": "fatalistisk",
    "fatalistiskt": "fatalistisk",
    "fatalistiskts": "fatalistisk",
    "fatalists": "fatalist",
    "fataliteten": "fatalitet",
    "fatalitetens": "fatalitet",
    "fataliteter": "fatalitet",
    "fataliteterna": "fatalitet",
    "fataliteternas": "fatalitet",
    "fataliteters": "fatalitet",
    "fatalitets": "fatalitet",
    "fatals": "fatal",
    "fatalt": "fatal",
    "fatalts": "fatal",
    "fatburen": "fatbur",
    "fatburens": "fatbur",
    "fatburer": "fatbur",
    "fatburerna": "fatbur",
    "fatburernas": "fatbur",
    "fatburers": "fatbur",
    "fatburs": "fatbur",
    "faten": "fat",
    "fatens": "fat",
    "fatet": "fat",
    "fatets": "fat",
    "fats": "fat",
    "fattade": "fattad",
    "fattades": "fattas",
    "fattads": "fattad",
    "fattande": "fatta",
    "fattanden": "fattande",
    "fattandena": "fattande",
    "fattandenas": "fattande",
    "fattandens": "fattande",
    "fattandes": "fattande",
    "fattandet": "fattande",
    "fattandets": "fattande",
    "fattar": "fatta",
    "fattas": "fatta",
    "fattat": "fattad",
    "fattats": "fattas",
    "fattbara": "fattbar",
    "fattbarare": "fattbar",
    "fattbarares": "fattbar",
    "fattbaras": "fattbar",
    "fattbarast": "fattbar",
    "fattbaraste": "fattbar",
    "fattbarastes": "fattbar",
    "fattbarasts": "fattbar",
    "fattbare": "fattbar",
    "fattbares": "fattbar",
    "fattbarheten": "fattbarhet",
    "fattbarhetens": "fattbarhet",
    "fattbarheter": "fattbarhet",
    "fattbarheterna": "fattbarhet",
    "fattbarheternas": "fattbarhet",
    "fattbarheters": "fattbarhet",
    "fattbarhets": "fattbarhet",
    "fattbars": "fattbar",
    "fattbart": "fattbar",
    "fattbarts": "fattbar",
    "fattiga": "fattig",
    "fattigare": "fattig",
    "fattigares": "fattig",
    "fattigas": "fattig",
    "fattigast": "fattig",
    "fattigaste": "fattig",
    "fattigastes": "fattig",
    "fattigasts": "fattig",
    "fattigbarnen": "fattigbarn",
    "fattigbarnens": "fattigbarn",
    "fattigbarnet": "fattigbarn",
    "fattigbarnets": "fattigbarn",
    "fattigbarns": "fattigbarn",
    "fattigdomar": "fattigdom",
    "fattigdomarna": "fattigdom",
    "fattigdomarnas": "fattigdom",
    "fattigdomars": "fattigdom",
    "fattigdomen": "fattigdom",
    "fattigdomens": "fattigdom",
    "fattigdoms": "fattigdom",
    "fattigdomsbevisen": "fattigdomsbevis",
    "fattigdomsbevisens": "fattigdomsbevis",
    "fattigdomsbeviset": "fattigdomsbevis",
    "fattigdomsbevisets": "fattigdomsbevis",
    "fattigdomsfäll": "fattigdomsfälla",
    "fattigdomsfällan": "fattigdomsfälla",
    "fattigdomsfällans": "fattigdomsfälla",
    "fattigdomsfällas": "fattigdomsfälla",
    "fattigdomsfälle": "fattigdomsfälla",
    "fattigdomsfällor": "fattigdomsfälla",
    "fattigdomsfällorna": "fattigdomsfälla",
    "fattigdomsfällornas": "fattigdomsfälla",
    "fattigdomsfällors": "fattigdomsfälla",
    "fattigdomsfälls": "fattigdomsfälla",
    "fattigdomsminskningar": "fattigdomsminskning",
    "fattigdomsminskningarna": "fattigdomsminskning",
    "fattigdomsminskningarnas": "fattigdomsminskning",
    "fattigdomsminskningars": "fattigdomsminskning",
    "fattigdomsminskningen": "fattigdomsminskning",
    "fattigdomsminskningens": "fattigdomsminskning",
    "fattigdomsminsknings": "fattigdomsminskning",
    "fattige": "fattig",
    "fattiges": "fattig",
    "fattighjonen": "fattighjon",
    "fattighjonens": "fattighjon",
    "fattighjonet": "fattighjon",
    "fattighjonets": "fattighjon",
    "fattighjons": "fattighjon",
    "fattighjälpen": "fattighjälp",
    "fattighjälpens": "fattighjälp",
    "fattighjälps": "fattighjälp",
    "fattigkvarteren": "fattigkvarter",
    "fattigkvarterens": "fattigkvarter",
    "fattigkvarteret": "fattigkvarter",
    "fattigkvarterets": "fattigkvarter",
    "fattigkvarters": "fattigkvarter",
    "fattiglappar": "fattiglapp",
    "fattiglapparna": "fattiglapp",
    "fattiglapparnas": "fattiglapp",
    "fattiglappars": "fattiglapp",
    "fattiglappen": "fattiglapp",
    "fattiglappens": "fattiglapp",
    "fattiglapps": "fattiglapp",
    "fattigs": "fattig",
    "fattigt": "fattig",
    "fattigts": "fattig",
    "fattigvården": "fattigvård",
    "fattigvårdens": "fattigvård",
    "fattigvårds": "fattigvård",
    "fattliga": "fattlig",
    "fattligare": "fattlig",
    "fattligares": "fattlig",
    "fattligas": "fattlig",
    "fattligast": "fattlig",
    "fattligaste": "fattlig",
    "fattligastes": "fattlig",
    "fattligasts": "fattlig",
    "fattlige": "fattlig",
    "fattliges": "fattlig",
    "fattligheten": "fattlighet",
    "fattlighetens": "fattlighet",
    "fattlighets": "fattlighet",
    "fattligs": "fattlig",
    "fattligt": "fattlig",
    "fattligts": "fattlig",
    "fattningar": "fattning",
    "fattningarna": "fattning",
    "fattningarnas": "fattning",
    "fattningars": "fattning",
    "fattningen": "fattning",
    "fattningens": "fattning",
    "fattnings": "fattning",
    "fattningsförmågan": "fattningsförmåga",
    "fattningsförmågans": "fattningsförmåga",
    "fattningsförmågas": "fattningsförmåga",
    "fattningsförmåge": "fattningsförmåga",
    "fatwan": "fatwa",
    "fatwans": "fatwa",
    "fatwas": "fatwa",
    "fatwor": "fatwa",
    "fatworna": "fatwa",
    "fatwornas": "fatwa",
    "fatwors": "fatwa",
    "fatölet": "fatöl",
    "fatölets": "fatöl",
    "fatöls": "fatöl",
    "faun": "fauna",
    "faunan": "fauna",
    "faunans": "fauna",
    "faunas": "fauna",
    "faune": "fauna",
    "faunen": "faun",
    "faunens": "faun",
    "fauner": "faun",
    "faunerna": "faun",
    "faunernas": "faun",
    "fauners": "faun",
    "faunisten": "faunist",
    "faunistens": "faunist",
    "faunister": "faunist",
    "faunisterna": "faunist",
    "faunisternas": "faunist",
    "faunisters": "faunist",
    "faunistiken": "faunistik",
    "faunistikens": "faunistik",
    "faunistiks": "faunistik",
    "faunistiska": "faunistisk",
    "faunistiskare": "faunistisk",
    "faunistiskares": "faunistisk",
    "faunistiskas": "faunistisk",
    "faunistiskast": "faunistisk",
    "faunistiskaste": "faunistisk",
    "faunistiskastes": "faunistisk",
    "faunistiskasts": "faunistisk",
    "faunistiske": "faunistisk",
    "faunistiskes": "faunistisk",
    "faunistisks": "faunistisk",
    "faunistiskt": "faunistisk",
    "faunistiskts": "faunistisk",
    "faunists": "faunist",
    "faunor": "fauna",
    "faunorna": "fauna",
    "faunornas": "fauna",
    "faunors": "fauna",
    "fauns": "fauna",
    "fauten": "faute",
    "fautens": "faute",
    "fauter": "faute",
    "fauterna": "faute",
    "fauternas": "faute",
    "fauters": "faute",
    "fautes": "faute",
    "favoriserad": "favorisera",
    "favoriserade": "favorisera",
    "favoriserades": "favorisera",
    "favoriserads": "favorisera",
    "favoriserande": "favorisera",
    "favoriseranden": "favoriserande",
    "favoriserandena": "favoriserande",
    "favoriserandenas": "favoriserande",
    "favoriserandens": "favoriserande",
    "favoriserandes": "favoriserande",
    "favoriserandet": "favoriserande",
    "favoriserandets": "favoriserande",
    "favoriserar": "favorisera",
    "favoriseras": "favorisera",
    "favoriserat": "favorisera",
    "favoriserats": "favorisera",
    "favoriserbara": "favoriserbar",
    "favoriserbarare": "favoriserbar",
    "favoriserbarares": "favoriserbar",
    "favoriserbaras": "favoriserbar",
    "favoriserbarast": "favoriserbar",
    "favoriserbaraste": "favoriserbar",
    "favoriserbarastes": "favoriserbar",
    "favoriserbarasts": "favoriserbar",
    "favoriserbare": "favoriserbar",
    "favoriserbares": "favoriserbar",
    "favoriserbarheten": "favoriserbarhet",
    "favoriserbarhetens": "favoriserbarhet",
    "favoriserbarhets": "favoriserbarhet",
    "favoriserbars": "favoriserbar",
    "favoriserbart": "favoriserbar",
    "favoriserbarts": "favoriserbar",
    "favoriseringar": "favorisering",
    "favoriseringarna": "favorisering",
    "favoriseringarnas": "favorisering",
    "favoriseringars": "favorisering",
    "favoriseringen": "favorisering",
    "favoriseringens": "favorisering",
    "favoriserings": "favorisering",
    "favoritaccessoaren": "favoritaccessoar",
    "favoritaccessoarens": "favoritaccessoar",
    "favoritaccessoarer": "favoritaccessoar",
    "favoritaccessoarerna": "favoritaccessoar",
    "favoritaccessoarernas": "favoritaccessoar",
    "favoritaccessoarers": "favoritaccessoar",
    "favoritaccessoars": "favoritaccessoar",
    "favoritbilden": "favoritbild",
    "favoritbildens": "favoritbild",
    "favoritbilder": "favoritbild",
    "favoritbilderna": "favoritbild",
    "favoritbildernas": "favoritbild",
    "favoritbilders": "favoritbild",
    "favoritbilds": "favoritbild",
    "favoriten": "favorit",
    "favoritens": "favorit",
    "favoriter": "favorit",
    "favoriterna": "favorit",
    "favoriternas": "favorit",
    "favoriters": "favorit",
    "favoritfiken": "favoritfik",
    "favoritfikens": "favoritfik",
    "favoritfiket": "favoritfik",
    "favoritfikets": "favoritfik",
    "favoritfiks": "favoritfik",
    "favoritförfattar": "favoritförfattare",
    "favoritförfattaren": "favoritförfattare",
    "favoritförfattarens": "favoritförfattare",
    "favoritförfattares": "favoritförfattare",
    "favoritförfattarna": "favoritförfattare",
    "favoritförfattarnas": "favoritförfattare",
    "favoritknepen": "favoritknep",
    "favoritknepens": "favoritknep",
    "favoritknepet": "favoritknep",
    "favoritknepets": "favoritknep",
    "favoritkneps": "favoritknep",
    "favoritpsalmen": "favoritpsalm",
    "favoritpsalmens": "favoritpsalm",
    "favoritpsalmer": "favoritpsalm",
    "favoritpsalmerna": "favoritpsalm",
    "favoritpsalmernas": "favoritpsalm",
    "favoritpsalmers": "favoritpsalm",
    "favoritpsalms": "favoritpsalm",
    "favoritrestaurangen": "favoritrestaurang",
    "favoritrestaurangens": "favoritrestaurang",
    "favoritrestauranger": "favoritrestaurang",
    "favoritrestaurangerna": "favoritrestaurang",
    "favoritrestaurangernas": "favoritrestaurang",
    "favoritrestaurangers": "favoritrestaurang",
    "favoritrestaurangs": "favoritrestaurang",
    "favoriträtten": "favoriträtt",
    "favoriträttens": "favoriträtt",
    "favoriträtter": "favoriträtt",
    "favoriträtterna": "favoriträtt",
    "favoriträtternas": "favoriträtt",
    "favoriträtters": "favoriträtt",
    "favoriträtts": "favoriträtt",
    "favorits": "favorit",
    "favoritstranden": "favoritstrand",
    "favoritstrandens": "favoritstrand",
    "favoritstrands": "favoritstrand",
    "favoritstränder": "favoritstrand",
    "favoritstränderna": "favoritstrand",
    "favoritsträndernas": "favoritstrand",
    "favoritstränders": "favoritstrand",
    "favorittippade": "favorittippad",
    "favorittippades": "favorittippad",
    "favorittippads": "favorittippad",
    "favorittippat": "favorittippad",
    "favorittippats": "favorittippad",
    "favören": "favör",
    "favörens": "favör",
    "favörer": "favör",
    "favörerna": "favör",
    "favörernas": "favör",
    "favörers": "favör",
    "favörs": "favör",
    "fax": "faxa",
    "faxad": "faxa",
    "faxade": "faxa",
    "faxades": "faxa",
    "faxads": "faxa",
    "faxande": "faxa",
    "faxanden": "faxande",
    "faxandena": "faxande",
    "faxandenas": "faxande",
    "faxandens": "faxande",
    "faxandes": "faxande",
    "faxandet": "faxande",
    "faxandets": "faxande",
    "faxar": "faxa",
    "faxarna": "fax",
    "faxarnas": "fax",
    "faxars": "fax",
    "faxas": "faxa",
    "faxat": "faxa",
    "faxats": "faxa",
    "faxen": "fax",
    "faxens": "fax",
    "faxet": "fax",
    "faxets": "fax",
    "featureprogrammen": "featureprogram",
    "featureprogrammens": "featureprogram",
    "featureprogrammet": "featureprogram",
    "featureprogrammets": "featureprogram",
    "featureprograms": "featureprogram",
    "feberanfallen": "feberanfall",
    "feberanfallens": "feberanfall",
    "feberanfallet": "feberanfall",
    "feberanfallets": "feberanfall",
    "feberanfalls": "feberanfall",
    "feberepidemien": "feberepidemi",
    "feberepidemiens": "feberepidemi",
    "feberepidemier": "feberepidemi",
    "feberepidemierna": "feberepidemi",
    "feberepidemiernas": "feberepidemi",
    "feberepidemiers": "feberepidemi",
    "feberepidemin": "feberepidemi",
    "feberepidemins": "feberepidemi",
    "feberepidemis": "feberepidemi",
    "feberfria": "feberfri",
    "feberfriare": "feberfri",
    "feberfriares": "feberfri",
    "feberfrias": "feberfri",
    "feberfriast": "feberfri",
    "feberfriaste": "feberfri",
    "feberfriastes": "feberfri",
    "feberfriasts": "feberfri",
    "feberfrie": "feberfri",
    "feberfries": "feberfri",
    "feberfris": "feberfri",
    "feberfritt": "feberfri",
    "feberfritts": "feberfri",
    "feberkurv": "feberkurva",
    "feberkurvan": "feberkurva",
    "feberkurvans": "feberkurva",
    "feberkurvas": "feberkurva",
    "feberkurve": "feberkurva",
    "feberkurvor": "feberkurva",
    "feberkurvorna": "feberkurva",
    "feberkurvornas": "feberkurva",
    "feberkurvors": "feberkurva",
    "feberkurvs": "feberkurva",
    "febern": "feber",
    "feberns": "feber",
    "febers": "feber",
    "febersjukdomar": "febersjukdom",
    "febersjukdomarna": "febersjukdom",
    "febersjukdomarnas": "febersjukdom",
    "febersjukdomars": "febersjukdom",
    "febersjukdomen": "febersjukdom",
    "febersjukdomens": "febersjukdom",
    "febersjukdoms": "febersjukdom",
    "febertermometern": "febertermometer",
    "febertermometerns": "febertermometer",
    "febertermometers": "febertermometer",
    "febertermometrar": "febertermometer",
    "febertermometrarna": "febertermometer",
    "febertermometrarnas": "febertermometer",
    "febertermometrars": "febertermometer",
    "febertoppar": "febertopp",
    "febertopparna": "febertopp",
    "febertopparnas": "febertopp",
    "febertoppars": "febertopp",
    "febertoppen": "febertopp",
    "febertoppens": "febertopp",
    "febertopps": "febertopp",
    "febrar": "feber",
    "febrarna": "feber",
    "febrarnas": "feber",
    "febrars": "feber",
    "febriga": "febrig",
    "febrigare": "febrig",
    "febrigares": "febrig",
    "febrigas": "febrig",
    "febrigast": "febrig",
    "febrigaste": "febrig",
    "febrigastes": "febrig",
    "febrigasts": "febrig",
    "febrige": "febrig",
    "febriges": "febrig",
    "febrigheten": "febrighet",
    "febrighetens": "febrighet",
    "febrighets": "febrighet",
    "febrigs": "febrig",
    "febrigt": "febrig",
    "febrigts": "febrig",
    "febrila": "febril",
    "febrilare": "febril",
    "febrilares": "febril",
    "febrilas": "febril",
    "febrilast": "febril",
    "febrilaste": "febril",
    "febrilastes": "febril",
    "febrilasts": "febril",
    "febrile": "febril",
    "febriles": "febril",
    "febrils": "febril",
    "febrilt": "febril",
    "febrilts": "febril",
    "februarioffensiven": "februarioffensiv",
    "februarioffensivens": "februarioffensiv",
    "februarioffensiver": "februarioffensiv",
    "februarioffensiverna": "februarioffensiv",
    "februarioffensivernas": "februarioffensiv",
    "februarioffensivers": "februarioffensiv",
    "februarioffensivs": "februarioffensiv",
    "februaris": "februari",
    "federala": "federal",
    "federalare": "federal",
    "federalares": "federal",
    "federalas": "federal",
    "federalast": "federal",
    "federalaste": "federal",
    "federalastes": "federal",
    "federalasts": "federal",
    "federale": "federal",
    "federales": "federal",
    "federalismen": "federalism",
    "federalismens": "federalism",
    "federalismer": "federalism",
    "federalismerna": "federalism",
    "federalismernas": "federalism",
    "federalismers": "federalism",
    "federalisms": "federalism",
    "federalisten": "federalist",
    "federalistens": "federalist",
    "federalister": "federalist",
    "federalisterna": "federalist",
    "federalisternas": "federalist",
    "federalisters": "federalist",
    "federalistiska": "federalistisk",
    "federalistiskare": "federalistisk",
    "federalistiskares": "federalistisk",
    "federalistiskas": "federalistisk",
    "federalistiskast": "federalistisk",
    "federalistiskaste": "federalistisk",
    "federalistiskastes": "federalistisk",
    "federalistiskasts": "federalistisk",
    "federalistiske": "federalistisk",
    "federalistiskes": "federalistisk",
    "federalistisks": "federalistisk",
    "federalistiskt": "federalistisk",
    "federalistiskts": "federalistisk",
    "federalists": "federalist",
    "federals": "federal",
    "federalt": "federal",
    "federalts": "federal",
    "federationen": "federation",
    "federationens": "federation",
    "federationer": "federation",
    "federationerna": "federation",
    "federationernas": "federation",
    "federationers": "federation",
    "federations": "federation",
    "federativa": "federativ",
    "federativare": "federativ",
    "federativares": "federativ",
    "federativas": "federativ",
    "federativast": "federativ",
    "federativaste": "federativ",
    "federativastes": "federativ",
    "federativasts": "federativ",
    "federative": "federativ",
    "federatives": "federativ",
    "federativs": "federativ",
    "federativt": "federativ",
    "federativts": "federativ",
    "federerade": "federerad",
    "federerades": "federerad",
    "federerads": "federerad",
    "federerat": "federerad",
    "federerats": "federerad",
    "feedbacken": "feedback",
    "feedbackens": "feedback",
    "feedbacks": "feedback",
    "feelen": "feel",
    "feelens": "feel",
    "feels": "feel",
    "feen": "fe",
    "feens": "fe",
    "feer": "fe",
    "feerier": "feeri",
    "feerierna": "feeri",
    "feeriernas": "feeri",
    "feeriers": "feeri",
    "feeriet": "feeri",
    "feeriets": "feeri",
    "feeris": "feeri",
    "feerit": "feeri",
    "feerits": "feeri",
    "feerna": "fe",
    "feernas": "fe",
    "feers": "fe",
    "fega": "feg",
    "fegare": "feg",
    "fegares": "feg",
    "fegas": "feg",
    "fegast": "feg",
    "fegaste": "feg",
    "fegastes": "feg",
    "fegasts": "feg",
    "fege": "feg",
    "feges": "feg",
    "fegheten": "feghet",
    "feghetens": "feghet",
    "fegheter": "feghet",
    "fegheterna": "feghet",
    "fegheternas": "feghet",
    "fegheters": "feghet",
    "feghets": "feghet",
    "fegisar": "fegis",
    "fegisarna": "fegis",
    "fegisarnas": "fegis",
    "fegisars": "fegis",
    "fegisen": "fegis",
    "fegisens": "fegis",
    "fegs": "feg",
    "fegspelen": "fegspel",
    "fegspelens": "fegspel",
    "fegspelet": "fegspel",
    "fegspelets": "fegspel",
    "fegspels": "fegspel",
    "fegt": "feg",
    "fegts": "feg",
    "fej": "feja",
    "fejad": "feja",
    "fejade": "feja",
    "fejades": "feja",
    "fejads": "feja",
    "fejande": "feja",
    "fejanden": "fejande",
    "fejandena": "fejande",
    "fejandenas": "fejande",
    "fejandens": "fejande",
    "fejandes": "fejande",
    "fejandet": "fejande",
    "fejandets": "fejande",
    "fejar": "feja",
    "fejas": "feja",
    "fejat": "feja",
    "fejats": "feja",
    "fejden": "fejd",
    "fejdens": "fejd",
    "fejder": "fejd",
    "fejderna": "fejd",
    "fejdernas": "fejd",
    "fejders": "fejd",
    "fejds": "fejd",
    "fejk": "fejka",
    "fejkad": "fejka",
    "fejkade": "fejka",
    "fejkades": "fejka",
    "fejkads": "fejka",
    "fejkande": "fejka",
    "fejkanden": "fejkande",
    "fejkandena": "fejkande",
    "fejkandenas": "fejkande",
    "fejkandens": "fejkande",
    "fejkandes": "fejkande",
    "fejkandet": "fejkande",
    "fejkandets": "fejkande",
    "fejkar": "fejka",
    "fejkas": "fejka",
    "fejkat": "fejka",
    "fejkats": "fejka",
    "fekala": "fekal",
    "fekalare": "fekal",
    "fekalares": "fekal",
    "fekalas": "fekal",
    "fekalast": "fekal",
    "fekalaste": "fekal",
    "fekalastes": "fekal",
    "fekalasts": "fekal",
    "fekale": "fekal",
    "fekales": "fekal",
    "fekals": "fekal",
    "fekalt": "fekal",
    "fekalts": "fekal",
    "fel": "fela",
    "felade": "fela",
    "felades": "felas",
    "felaktiga": "felaktig",
    "felaktigare": "felaktig",
    "felaktigares": "felaktig",
    "felaktigas": "felaktig",
    "felaktigast": "felaktig",
    "felaktigaste": "felaktig",
    "felaktigastes": "felaktig",
    "felaktigasts": "felaktig",
    "felaktige": "felaktig",
    "felaktiges": "felaktig",
    "felaktigheten": "felaktighet",
    "felaktighetens": "felaktighet",
    "felaktigheter": "felaktighet",
    "felaktigheterna": "felaktighet",
    "felaktigheternas": "felaktighet",
    "felaktigheters": "felaktighet",
    "felaktighets": "felaktighet",
    "felaktigs": "felaktig",
    "felaktigt": "felaktig",
    "felaktigts": "felaktig",
    "felan": "fela",
    "felande": "fela",
    "felanden": "felande",
    "felandena": "felande",
    "felandenas": "felande",
    "felandens": "felande",
    "felandes": "felande",
    "felandet": "felande",
    "felandets": "felande",
    "felans": "fela",
    "felar": "fela",
    "felas": "fela",
    "felat": "fela",
    "felats": "felas",
    "felbedöm": "felbedöma",
    "felbedömande": "felbedöma",
    "felbedömanden": "felbedömande",
    "felbedömandena": "felbedömande",
    "felbedömandenas": "felbedömande",
    "felbedömandens": "felbedömande",
    "felbedömandes": "felbedömande",
    "felbedömandet": "felbedömande",
    "felbedömandets": "felbedömande",
    "felbedömas": "felbedöma",
    "felbedömd": "felbedöma",
    "felbedömda": "felbedöma",
    "felbedömdas": "felbedöma",
    "felbedömde": "felbedöma",
    "felbedömdes": "felbedöma",
    "felbedömds": "felbedöma",
    "felbedömer": "felbedöma",
    "felbedömningar": "felbedömning",
    "felbedömningarna": "felbedömning",
    "felbedömningarnas": "felbedömning",
    "felbedömningars": "felbedömning",
    "felbedömningen": "felbedömning",
    "felbedömningens": "felbedömning",
    "felbedömnings": "felbedömning",
    "felbedöms": "felbedöma",
    "felbedömt": "felbedöma",
    "felbedömts": "felbedöma",
    "felbehandlingar": "felbehandling",
    "felbehandlingarna": "felbehandling",
    "felbehandlingarnas": "felbehandling",
    "felbehandlingars": "felbehandling",
    "felbehandlingen": "felbehandling",
    "felbehandlingens": "felbehandling",
    "felbehandlings": "felbehandling",
    "felberäkningar": "felberäkning",
    "felberäkningarna": "felberäkning",
    "felberäkningarnas": "felberäkning",
    "felberäkningars": "felberäkning",
    "felberäkningen": "felberäkning",
    "felberäkningens": "felberäkning",
    "felberäknings": "felberäkning",
    "feldiagnosen": "feldiagnos",
    "feldiagnosens": "feldiagnos",
    "feldiagnoser": "feldiagnos",
    "feldiagnoserna": "feldiagnos",
    "feldiagnosernas": "feldiagnos",
    "feldiagnosers": "feldiagnos",
    "feldragen": "feldrag",
    "feldragens": "feldrag",
    "feldraget": "feldrag",
    "feldragets": "feldrag",
    "feldrags": "feldrag",
    "fele": "fela",
    "felen": "fel",
    "felens": "fel",
    "felet": "fel",
    "felets": "fel",
    "felfinnar": "felfinnare",
    "felfinnaren": "felfinnare",
    "felfinnarens": "felfinnare",
    "felfinnares": "felfinnare",
    "felfinnarna": "felfinnare",
    "felfinnarnas": "felfinnare",
    "felfinneriet": "felfinneri",
    "felfinneriets": "felfinneri",
    "felfinneris": "felfinneri",
    "felfinnerit": "felfinneri",
    "felfinnerits": "felfinneri",
    "felfria": "felfri",
    "felfriare": "felfri",
    "felfriares": "felfri",
    "felfrias": "felfri",
    "felfriast": "felfri",
    "felfriaste": "felfri",
    "felfriastes": "felfri",
    "felfriasts": "felfri",
    "felfrie": "felfri",
    "felfries": "felfri",
    "felfris": "felfri",
    "felfritt": "felfri",
    "felfritts": "felfri",
    "felgreppen": "felgrepp",
    "felgreppens": "felgrepp",
    "felgreppet": "felgrepp",
    "felgreppets": "felgrepp",
    "felgrepps": "felgrepp",
    "felhandlingar": "felhandling",
    "felhandlingarna": "felhandling",
    "felhandlingarnas": "felhandling",
    "felhandlingars": "felhandling",
    "felhandlingen": "felhandling",
    "felhandlingens": "felhandling",
    "felhandlings": "felhandling",
    "felkonstruerade": "felkonstruerad",
    "felkonstruerades": "felkonstruerad",
    "felkonstruerads": "felkonstruerad",
    "felkonstruerat": "felkonstruerad",
    "felkonstruerats": "felkonstruerad",
    "felkäll": "felkälla",
    "felkällan": "felkälla",
    "felkällans": "felkälla",
    "felkällas": "felkälla",
    "felkälle": "felkälla",
    "felkällor": "felkälla",
    "felkällorna": "felkälla",
    "felkällornas": "felkälla",
    "felkällors": "felkälla",
    "felkälls": "felkälla",
    "felmarginalen": "felmarginal",
    "felmarginalens": "felmarginal",
    "felmarginaler": "felmarginal",
    "felmarginalerna": "felmarginal",
    "felmarginalernas": "felmarginal",
    "felmarginalers": "felmarginal",
    "felmarginals": "felmarginal",
    "felor": "fela",
    "felorna": "fela",
    "felornas": "fela",
    "felors": "fela",
    "felparkerad": "felparkera",
    "felparkerade": "felparkera",
    "felparkerades": "felparkera",
    "felparkerads": "felparkera",
    "felparkerande": "felparkera",
    "felparkeranden": "felparkerande",
    "felparkerandena": "felparkerande",
    "felparkerandenas": "felparkerande",
    "felparkerandens": "felparkerande",
    "felparkerandes": "felparkerande",
    "felparkerandet": "felparkerande",
    "felparkerandets": "felparkerande",
    "felparkerar": "felparkera",
    "felparkeras": "felparkera",
    "felparkerat": "felparkera",
    "felparkerats": "felparkera",
    "felparkerbara": "felparkerbar",
    "felparkerbarare": "felparkerbar",
    "felparkerbarares": "felparkerbar",
    "felparkerbaras": "felparkerbar",
    "felparkerbarast": "felparkerbar",
    "felparkerbaraste": "felparkerbar",
    "felparkerbarastes": "felparkerbar",
    "felparkerbarasts": "felparkerbar",
    "felparkerbare": "felparkerbar",
    "felparkerbares": "felparkerbar",
    "felparkerbarheten": "felparkerbarhet",
    "felparkerbarhetens": "felparkerbarhet",
    "felparkerbarhets": "felparkerbarhet",
    "felparkerbars": "felparkerbar",
    "felparkerbart": "felparkerbar",
    "felparkerbarts": "felparkerbar",
    "felparkeringar": "felparkering",
    "felparkeringarna": "felparkering",
    "felparkeringarnas": "felparkering",
    "felparkeringars": "felparkering",
    "felparkeringen": "felparkering",
    "felparkeringens": "felparkering",
    "felparkerings": "felparkering",
    "felprocenten": "felprocent",
    "felprocentens": "felprocent",
    "felprocents": "felprocent",
    "felräkningspengar": "felräkningspeng",
    "felräkningspengarna": "felräkningspeng",
    "felräkningspengarnas": "felräkningspeng",
    "felräkningspengars": "felräkningspeng",
    "felräkningspengen": "felräkningspeng",
    "felräkningspengens": "felräkningspeng",
    "felräkningspengs": "felräkningspeng",
    "fels": "fela",
    "felsatsningar": "felsatsning",
    "felsatsningarna": "felsatsning",
    "felsatsningarnas": "felsatsning",
    "felsatsningars": "felsatsning",
    "felsatsningen": "felsatsning",
    "felsatsningens": "felsatsning",
    "felsatsnings": "felsatsning",
    "felslagens": "felslagen",
    "felslaget": "felslagen",
    "felslagets": "felslagen",
    "felslagna": "felslagen",
    "felslagnare": "felslagen",
    "felslagnares": "felslagen",
    "felslagnas": "felslagen",
    "felslagnast": "felslagen",
    "felslagnaste": "felslagen",
    "felslagnastes": "felslagen",
    "felslagnasts": "felslagen",
    "felslagne": "felslagen",
    "felslagnes": "felslagen",
    "felsluten": "felslut",
    "felslutens": "felslut",
    "felslutet": "felslut",
    "felslutets": "felslut",
    "felsluts": "felslut",
    "felstavade": "felstavad",
    "felstavades": "felstavad",
    "felstavads": "felstavad",
    "felstavat": "felstavad",
    "felstavats": "felstavad",
    "felstegen": "felsteg",
    "felstegens": "felsteg",
    "felsteget": "felsteg",
    "felstegets": "felsteg",
    "felstegs": "felsteg",
    "felsynen": "felsyn",
    "felsynens": "felsyn",
    "felsyns": "felsyn",
    "felsägningar": "felsägning",
    "felsägningarna": "felsägning",
    "felsägningarnas": "felsägning",
    "felsägningars": "felsägning",
    "felsägningen": "felsägning",
    "felsägningens": "felsägning",
    "felsägnings": "felsägning",
    "feltolk": "feltolka",
    "feltolkad": "feltolka",
    "feltolkade": "feltolka",
    "feltolkades": "feltolka",
    "feltolkads": "feltolka",
    "feltolkande": "feltolka",
    "feltolkanden": "feltolkande",
    "feltolkandena": "feltolkande",
    "feltolkandenas": "feltolkande",
    "feltolkandens": "feltolkande",
    "feltolkandes": "feltolkande",
    "feltolkandet": "feltolkande",
    "feltolkandets": "feltolkande",
    "feltolkar": "feltolka",
    "feltolkas": "feltolka",
    "feltolkat": "feltolka",
    "feltolkats": "feltolka",
    "feltänken": "feltänk",
    "feltänkens": "feltänk",
    "feltänket": "feltänk",
    "feltänkets": "feltänk",
    "feltänks": "feltänk",
    "felunderrättade": "felunderrättad",
    "felunderrättades": "felunderrättad",
    "felunderrättads": "felunderrättad",
    "felunderrättat": "felunderrättad",
    "felunderrättats": "felunderrättad",
    "felvalen": "felval",
    "felvalens": "felval",
    "felvalet": "felval",
    "felvalets": "felval",
    "felvals": "felval",
    "femaktar": "femaktare",
    "femaktaren": "femaktare",
    "femaktarens": "femaktare",
    "femaktares": "femaktare",
    "femaktarna": "femaktare",
    "femaktarnas": "femaktare",
    "femarmade": "femarmad",
    "femarmades": "femarmad",
    "femarmads": "femarmad",
    "femarmat": "femarmad",
    "femarmats": "femarmad",
    "fembarnsmamman": "fembarnsmamma",
    "fembarnsmammans": "fembarnsmamma",
    "fembarnsmammas": "fembarnsmamma",
    "fembarnsmamme": "fembarnsmamma",
    "fembarnsmammor": "fembarnsmamma",
    "fembarnsmammorna": "fembarnsmamma",
    "fembarnsmammornas": "fembarnsmamma",
    "fembarnsmammors": "fembarnsmamma",
    "femdagarsveck": "femdagarsvecka",
    "femdagarsveckan": "femdagarsvecka",
    "femdagarsveckans": "femdagarsvecka",
    "femdagarsveckas": "femdagarsvecka",
    "femdagarsvecke": "femdagarsvecka",
    "femdagarsvecko": "femdagarsvecka",
    "femdagarsveckor": "femdagarsvecka",
    "femdagarsveckorna": "femdagarsvecka",
    "femdagarsveckornas": "femdagarsvecka",
    "femdagarsveckors": "femdagarsvecka",
    "femdagarsvecks": "femdagarsvecka",
    "femdubben": "femdubbel",
    "femdubbens": "femdubbel",
    "femdubbet": "femdubbel",
    "femdubbets": "femdubbel",
    "femdubbna": "femdubbel",
    "femdubbnas": "femdubbel",
    "femdubbne": "femdubbel",
    "femdubbnes": "femdubbel",
    "femdygnsprognosen": "femdygnsprognos",
    "femdygnsprognosens": "femdygnsprognos",
    "femdygnsprognoser": "femdygnsprognos",
    "femdygnsprognoserna": "femdygnsprognos",
    "femdygnsprognosernas": "femdygnsprognos",
    "femdygnsprognosers": "femdygnsprognos",
    "femett": "femetta",
    "femettan": "femetta",
    "femettans": "femetta",
    "femettas": "femetta",
    "femette": "femetta",
    "femettor": "femetta",
    "femettorna": "femetta",
    "femettornas": "femetta",
    "femettors": "femetta",
    "femetts": "femetta",
    "femfaldiga": "femfaldig",
    "femfaldigad": "femfaldiga",
    "femfaldigade": "femfaldiga",
    "femfaldigades": "femfaldiga",
    "femfaldigads": "femfaldiga",
    "femfaldigande": "femfaldiga",
    "femfaldiganden": "femfaldigande",
    "femfaldigandena": "femfaldigande",
    "femfaldigandenas": "femfaldigande",
    "femfaldigandens": "femfaldigande",
    "femfaldigandes": "femfaldigande",
    "femfaldigandet": "femfaldigande",
    "femfaldigandets": "femfaldigande",
    "femfaldigar": "femfaldiga",
    "femfaldigas": "femfaldiga",
    "femfaldigat": "femfaldiga",
    "femfaldigats": "femfaldiga",
    "femfaldige": "femfaldig",
    "femfaldiges": "femfaldig",
    "femfaldigs": "femfaldig",
    "femfaldigt": "femfaldig",
    "femfaldigts": "femfaldig",
    "femfem": "femfemma",
    "femfemman": "femfemma",
    "femfemmans": "femfemma",
    "femfemmas": "femfemma",
    "femfemme": "femfemma",
    "femfemmor": "femfemma",
    "femfemmorna": "femfemma",
    "femfemmornas": "femfemma",
    "femfemmors": "femfemma",
    "femfems": "femfemma",
    "femhundrade": "femhundra",
    "femhundrades": "femhundra",
    "femhundrakronorssedeln": "femhundrakronorssedel",
    "femhundrakronorssedelns": "femhundrakronorssedel",
    "femhundrakronorssedels": "femhundrakronorssedel",
    "femhundrakronorssedlar": "femhundrakronorssedel",
    "femhundrakronorssedlarna": "femhundrakronorssedel",
    "femhundrakronorssedlarnas": "femhundrakronorssedel",
    "femhundrakronorssedlars": "femhundrakronorssedel",
    "femhundras": "femhundra",
    "feminin": "femininum",
    "feminina": "feminin",
    "femininare": "feminin",
    "femininares": "feminin",
    "femininas": "feminin",
    "femininast": "feminin",
    "femininaste": "feminin",
    "femininastes": "feminin",
    "femininasts": "feminin",
    "feminine": "feminin",
    "femininen": "femininum",
    "femininens": "femininum",
    "femininer": "femininum",
    "femininerna": "femininum",
    "femininernas": "femininum",
    "femininers": "femininum",
    "feminines": "feminin",
    "femininet": "femininum",
    "femininets": "femininum",
    "feminins": "femininum",
    "feminint": "feminin",
    "feminints": "feminin",
    "femininumet": "femininum",
    "femininumets": "femininum",
    "femininums": "femininum",
    "feminiserade": "feminiserad",
    "feminiserades": "feminiserad",
    "feminiserads": "feminiserad",
    "feminiserat": "feminiserad",
    "feminiserats": "feminiserad",
    "feminismen": "feminism",
    "feminismens": "feminism",
    "feminismer": "feminism",
    "feminismerna": "feminism",
    "feminismernas": "feminism",
    "feminismers": "feminism",
    "feminisms": "feminism",
    "feministen": "feminist",
    "feministens": "feminist",
    "feminister": "feminist",
    "feministerna": "feminist",
    "feministernas": "feminist",
    "feministers": "feminist",
    "feministiska": "feministisk",
    "feministiskare": "feministisk",
    "feministiskares": "feministisk",
    "feministiskas": "feministisk",
    "feministiskast": "feministisk",
    "feministiskaste": "feministisk",
    "feministiskastes": "feministisk",
    "feministiskasts": "feministisk",
    "feministiske": "feministisk",
    "feministiskes": "feministisk",
    "feministisks": "feministisk",
    "feministiskt": "feministisk",
    "feministiskts": "feministisk",
    "feminists": "feminist",
    "feministtjafset": "feministtjafs",
    "feministtjafsets": "feministtjafs",
    "femkampen": "femkamp",
    "femkampens": "femkamp",
    "femkamper": "femkamp",
    "femkamperna": "femkamp",
    "femkampernas": "femkamp",
    "femkampers": "femkamp",
    "femkamps": "femkamp",
    "femkorts": "femkort",
    "femkron": "femkrona",
    "femkronan": "femkrona",
    "femkronans": "femkrona",
    "femkronas": "femkrona",
    "femkrone": "femkrona",
    "femkronor": "femkrona",
    "femkronorna": "femkrona",
    "femkronornas": "femkrona",
    "femkronors": "femkrona",
    "femkronorsmynten": "femkronorsmynt",
    "femkronorsmyntens": "femkronorsmynt",
    "femkronorsmyntet": "femkronorsmynt",
    "femkronorsmyntets": "femkronorsmynt",
    "femkronorsmynts": "femkronorsmynt",
    "femkrons": "femkrona",
    "femlingar": "femling",
    "femlingarna": "femling",
    "femlingarnas": "femling",
    "femlingars": "femling",
    "femlingen": "femling",
    "femlingens": "femling",
    "femlings": "femling",
    "femman": "femma",
    "femmans": "femma",
    "femmas": "femma",
    "femmilen": "femmil",
    "femmilens": "femmil",
    "femmils": "femmil",
    "femmor": "femma",
    "femmorna": "femma",
    "femmornas": "femma",
    "femmors": "femma",
    "fempunktslasern": "fempunktslaser",
    "fempunktslaserns": "fempunktslaser",
    "fempunktslasers": "fempunktslaser",
    "fempunktslasrar": "fempunktslaser",
    "fempunktslasrarna": "fempunktslaser",
    "fempunktslasrarnas": "fempunktslaser",
    "fempunktslasrars": "fempunktslaser",
    "femrummar": "femrummare",
    "femrummaren": "femrummare",
    "femrummarens": "femrummare",
    "femrummares": "femrummare",
    "femrummarna": "femrummare",
    "femrummarnas": "femrummare",
    "femrumslägenheten": "femrumslägenhet",
    "femrumslägenhetens": "femrumslägenhet",
    "femrumslägenheter": "femrumslägenhet",
    "femrumslägenheterna": "femrumslägenhet",
    "femrumslägenheternas": "femrumslägenhet",
    "femrumslägenheters": "femrumslägenhet",
    "femrumslägenhets": "femrumslägenhet",
    "fems": "fem",
    "femsnårets": "femsnåret",
    "femstämmiga": "femstämmig",
    "femstämmigare": "femstämmig",
    "femstämmigares": "femstämmig",
    "femstämmigas": "femstämmig",
    "femstämmigast": "femstämmig",
    "femstämmigaste": "femstämmig",
    "femstämmigastes": "femstämmig",
    "femstämmigasts": "femstämmig",
    "femstämmige": "femstämmig",
    "femstämmiges": "femstämmig",
    "femstämmigs": "femstämmig",
    "femstämmigt": "femstämmig",
    "femstämmigts": "femstämmig",
    "femte": "fem",
    "femtedelar": "femtedel",
    "femtedelarna": "femtedel",
    "femtedelarnas": "femtedel",
    "femtedelars": "femtedel",
    "femtedelen": "femtedel",
    "femtedelens": "femtedel",
    "femtedels": "femtedel",
    "femtekolonnar": "femtekolonnare",
    "femtekolonnaren": "femtekolonnare",
    "femtekolonnarens": "femtekolonnare",
    "femtekolonnares": "femtekolonnare",
    "femtekolonnarna": "femtekolonnare",
    "femtekolonnarnas": "femtekolonnare",
    "femtekolonnen": "femtekolonn",
    "femtekolonnens": "femtekolonn",
    "femtekolonner": "femtekolonn",
    "femtekolonnerna": "femtekolonn",
    "femtekolonnernas": "femtekolonn",
    "femtekolonners": "femtekolonn",
    "femtekolonns": "femtekolonn",
    "femtes": "fem",
    "femtidollarsedeln": "femtidollarsedel",
    "femtidollarsedelns": "femtidollarsedel",
    "femtidollarsedels": "femtidollarsedel",
    "femtidollarsedlar": "femtidollarsedel",
    "femtidollarsedlarna": "femtidollarsedel",
    "femtidollarsedlarnas": "femtidollarsedel",
    "femtidollarsedlars": "femtidollarsedel",
    "femtielfte": "femtielva",
    "femtielftes": "femtielva",
    "femtielvas": "femtielva",
    "femtikronorssedeln": "femtikronorssedel",
    "femtikronorssedelns": "femtikronorssedel",
    "femtikronorssedels": "femtikronorssedel",
    "femtikronorssedlar": "femtikronorssedel",
    "femtikronorssedlarna": "femtikronorssedel",
    "femtikronorssedlarnas": "femtikronorssedel",
    "femtikronorssedlars": "femtikronorssedel",
    "femtilappar": "femtilapp",
    "femtilapparna": "femtilapp",
    "femtilapparnas": "femtilapp",
    "femtilappars": "femtilapp",
    "femtilappen": "femtilapp",
    "femtilappens": "femtilapp",
    "femtilapps": "femtilapp",
    "femtiodollarsedeln": "femtiodollarsedel",
    "femtiodollarsedelns": "femtiodollarsedel",
    "femtiodollarsedels": "femtiodollarsedel",
    "femtiodollarsedlar": "femtiodollarsedel",
    "femtiodollarsedlarna": "femtiodollarsedel",
    "femtiodollarsedlarnas": "femtiodollarsedel",
    "femtiodollarsedlars": "femtiodollarsedel",
    "femtiokronorssedeln": "femtiokronorssedel",
    "femtiokronorssedelns": "femtiokronorssedel",
    "femtiokronorssedels": "femtiokronorssedel",
    "femtiokronorssedlar": "femtiokronorssedel",
    "femtiokronorssedlarna": "femtiokronorssedel",
    "femtiokronorssedlarnas": "femtiokronorssedel",
    "femtiokronorssedlars": "femtiokronorssedel",
    "femtionde": "femtio",
    "femtiondes": "femtio",
    "femtios": "femtio",
    "femtiotalen": "femtiotal",
    "femtiotalens": "femtiotal",
    "femtiotalet": "femtiotal",
    "femtiotalets": "femtiotal",
    "femtiotalisten": "femtiotalist",
    "femtiotalistens": "femtiotalist",
    "femtiotalister": "femtiotalist",
    "femtiotalisterna": "femtiotalist",
    "femtiotalisternas": "femtiotalist",
    "femtiotalisters": "femtiotalist",
    "femtiotalists": "femtiotalist",
    "femtiotals": "femtiotal",
    "femtioårsdagar": "femtioårsdag",
    "femtioårsdagarna": "femtioårsdag",
    "femtioårsdagarnas": "femtioårsdag",
    "femtioårsdagars": "femtioårsdag",
    "femtioårsdagen": "femtioårsdag",
    "femtioårsdagens": "femtioårsdag",
    "femtioårsdags": "femtioårsdag",
    "femtioöringar": "femtioöring",
    "femtioöringarna": "femtioöring",
    "femtioöringarnas": "femtioöring",
    "femtioöringars": "femtioöring",
    "femtioöringen": "femtioöring",
    "femtioöringens": "femtioöring",
    "femtioörings": "femtioöring",
    "femtis": "femti",
    "femtitalen": "femtital",
    "femtitalens": "femtital",
    "femtitalet": "femtital",
    "femtitalets": "femtital",
    "femtitalisten": "femtitalist",
    "femtitalistens": "femtitalist",
    "femtitalister": "femtitalist",
    "femtitalisterna": "femtitalist",
    "femtitalisternas": "femtitalist",
    "femtitalisters": "femtitalist",
    "femtitalists": "femtitalist",
    "femtitals": "femtital",
    "femtiårsdagar": "femtiårsdag",
    "femtiårsdagarna": "femtiårsdag",
    "femtiårsdagarnas": "femtiårsdag",
    "femtiårsdagars": "femtiårsdag",
    "femtiårsdagen": "femtiårsdag",
    "femtiårsdagens": "femtiårsdag",
    "femtiårsdags": "femtiårsdag",
    "femtiöringar": "femtiöring",
    "femtiöringarna": "femtiöring",
    "femtiöringarnas": "femtiöring",
    "femtiöringars": "femtiöring",
    "femtiöringen": "femtiöring",
    "femtiöringens": "femtiöring",
    "femtiörings": "femtiöring",
    "femtocellen": "femtocell",
    "femtocellens": "femtocell",
    "femtoceller": "femtocell",
    "femtocellerna": "femtocell",
    "femtocellernas": "femtocell",
    "femtocellers": "femtocell",
    "femtocells": "femtocell",
    "femtonde": "femton",
    "femtondes": "femton",
    "femtonhundrametersloppen": "femtonhundrameterslopp",
    "femtonhundrametersloppens": "femtonhundrameterslopp",
    "femtonhundrametersloppet": "femtonhundrameterslopp",
    "femtonhundrametersloppets": "femtonhundrameterslopp",
    "femtonhundrameterslopps": "femtonhundrameterslopp",
    "femtonhundratalet": "femtonhundratal",
    "femtonhundratalets": "femtonhundratal",
    "femtonhundratals": "femtonhundratal",
    "femtons": "femton",
    "femtonsnårets": "femtonsnåret",
    "femtontalet": "femtontal",
    "femtontalets": "femtontal",
    "femtontals": "femtontal",
    "femtonåriga": "femtonårig",
    "femtonårigas": "femtonårig",
    "femtonårige": "femtonårig",
    "femtonåriges": "femtonårig",
    "femtonårigs": "femtonårig",
    "femtonårigt": "femtonårig",
    "femtonårigts": "femtonårig",
    "femtonåringar": "femtonåring",
    "femtonåringarna": "femtonåring",
    "femtonåringarnas": "femtonåring",
    "femtonåringars": "femtonåring",
    "femtonåringen": "femtonåring",
    "femtonåringens": "femtonåring",
    "femtonårings": "femtonåring",
    "femtumsspikar": "femtumsspik",
    "femtumsspikarna": "femtumsspik",
    "femtumsspikarnas": "femtumsspik",
    "femtumsspikars": "femtumsspik",
    "femtumsspiken": "femtumsspik",
    "femtumsspikens": "femtumsspik",
    "femtumsspiks": "femtumsspik",
    "femuddiga": "femuddig",
    "femuddigare": "femuddig",
    "femuddigares": "femuddig",
    "femuddigas": "femuddig",
    "femuddigast": "femuddig",
    "femuddigaste": "femuddig",
    "femuddigastes": "femuddig",
    "femuddigasts": "femuddig",
    "femuddige": "femuddig",
    "femuddiges": "femuddig",
    "femuddigs": "femuddig",
    "femuddigt": "femuddig",
    "femuddigts": "femuddig",
    "femåriga": "femårig",
    "femårigas": "femårig",
    "femårige": "femårig",
    "femåriges": "femårig",
    "femårigs": "femårig",
    "femårigt": "femårig",
    "femårigts": "femårig",
    "femåringar": "femåring",
    "femåringarna": "femåring",
    "femåringarnas": "femåring",
    "femåringars": "femåring",
    "femåringen": "femåring",
    "femåringens": "femåring",
    "femårings": "femåring",
    "femårsperioden": "femårsperiod",
    "femårsperiodens": "femårsperiod",
    "femårsperioder": "femårsperiod",
    "femårsperioderna": "femårsperiod",
    "femårsperiodernas": "femårsperiod",
    "femårsperioders": "femårsperiod",
    "femårsperiods": "femårsperiod",
    "femårsplane": "femårsplan",
    "femårsplanen": "femårsplan",
    "femårsplanens": "femårsplan",
    "femårsplaner": "femårsplan",
    "femårsplanerna": "femårsplan",
    "femårsplanernas": "femårsplan",
    "femårsplaners": "femårsplan",
    "femårsplans": "femårsplan",
    "femöringar": "femöring",
    "femöringarna": "femöring",
    "femöringarnas": "femöring",
    "femöringars": "femöring",
    "femöringen": "femöring",
    "femöringens": "femöring",
    "femörings": "femöring",
    "fen": "fena",
    "fenan": "fena",
    "fenans": "fena",
    "fenas": "fena",
    "fendern": "fender",
    "fenderns": "fender",
    "fenders": "fender",
    "fendertar": "fendert",
    "fendertarna": "fendert",
    "fendertarnas": "fendert",
    "fendertars": "fendert",
    "fenderten": "fendert",
    "fendertens": "fendert",
    "fenderts": "fendert",
    "fendrar": "fender",
    "fendrarna": "fender",
    "fendrarnas": "fender",
    "fendrars": "fender",
    "fene": "fena",
    "fenedrinen": "fenedrin",
    "fenedrinens": "fenedrin",
    "fenedriner": "fenedrin",
    "fenedrinerna": "fenedrin",
    "fenedrinernas": "fenedrin",
    "fenedriners": "fenedrin",
    "fenedrinet": "fenedrin",
    "fenedrinets": "fenedrin",
    "fenedrins": "fenedrin",
    "feniciern": "fenicier",
    "fenicierna": "fenicier",
    "feniciernas": "fenicier",
    "fenicierns": "fenicier",
    "feniciers": "fenicier",
    "feniciska": "fenicisk",
    "feniciskare": "fenicisk",
    "feniciskares": "fenicisk",
    "feniciskas": "fenicisk",
    "feniciskast": "fenicisk",
    "feniciskaste": "fenicisk",
    "feniciskastes": "fenicisk",
    "feniciskasts": "fenicisk",
    "feniciske": "fenicisk",
    "feniciskes": "fenicisk",
    "fenicisks": "fenicisk",
    "feniciskt": "fenicisk",
    "feniciskts": "fenicisk",
    "fenkölar": "fenköl",
    "fenkölarna": "fenköl",
    "fenkölarnas": "fenköl",
    "fenkölars": "fenköl",
    "fenkölen": "fenköl",
    "fenkölens": "fenköl",
    "fenköls": "fenköl",
    "fenmetralinen": "fenmetralin",
    "fenmetralinens": "fenmetralin",
    "fenmetraliner": "fenmetralin",
    "fenmetralinerna": "fenmetralin",
    "fenmetralinernas": "fenmetralin",
    "fenmetraliners": "fenmetralin",
    "fenmetralinet": "fenmetralin",
    "fenmetralinets": "fenmetralin",
    "fenmetralins": "fenmetralin",
    "fennicismen": "fennicism",
    "fennicismens": "fennicism",
    "fennicismer": "fennicism",
    "fennicismerna": "fennicism",
    "fennicismernas": "fennicism",
    "fennicismers": "fennicism",
    "fennicisms": "fennicism",
    "fennomanen": "fennoman",
    "fennomanens": "fennoman",
    "fennomaner": "fennoman",
    "fennomanerna": "fennoman",
    "fennomanernas": "fennoman",
    "fennomaners": "fennoman",
    "fennomanien": "fennomani",
    "fennomaniens": "fennomani",
    "fennomanin": "fennomani",
    "fennomanins": "fennomani",
    "fennomanis": "fennomani",
    "fennomans": "fennoman",
    "fenolen": "fenol",
    "fenolens": "fenol",
    "fenoler": "fenol",
    "fenolerna": "fenol",
    "fenolernas": "fenol",
    "fenolers": "fenol",
    "fenolftaleinen": "fenolftalein",
    "fenolftaleinens": "fenolftalein",
    "fenolftaleiner": "fenolftalein",
    "fenolftaleinerna": "fenolftalein",
    "fenolftaleinernas": "fenolftalein",
    "fenolftaleiners": "fenolftalein",
    "fenolftaleinet": "fenolftalein",
    "fenolftaleinets": "fenolftalein",
    "fenolftaleins": "fenolftalein",
    "fenoliska": "fenolisk",
    "fenoliskare": "fenolisk",
    "fenoliskares": "fenolisk",
    "fenoliskas": "fenolisk",
    "fenoliskast": "fenolisk",
    "fenoliskaste": "fenolisk",
    "fenoliskastes": "fenolisk",
    "fenoliskasts": "fenolisk",
    "fenoliske": "fenolisk",
    "fenoliskes": "fenolisk",
    "fenolisks": "fenolisk",
    "fenoliskt": "fenolisk",
    "fenoliskts": "fenolisk",
    "fenols": "fenol",
    "fenomenala": "fenomenal",
    "fenomenalare": "fenomenal",
    "fenomenalares": "fenomenal",
    "fenomenalas": "fenomenal",
    "fenomenalast": "fenomenal",
    "fenomenalaste": "fenomenal",
    "fenomenalastes": "fenomenal",
    "fenomenalasts": "fenomenal",
    "fenomenale": "fenomenal",
    "fenomenales": "fenomenal",
    "fenomenalismen": "fenomenalism",
    "fenomenalismens": "fenomenalism",
    "fenomenalismer": "fenomenalism",
    "fenomenalismerna": "fenomenalism",
    "fenomenalismernas": "fenomenalism",
    "fenomenalismers": "fenomenalism",
    "fenomenalisms": "fenomenalism",
    "fenomenals": "fenomenal",
    "fenomenalt": "fenomenal",
    "fenomenalts": "fenomenal",
    "fenomenen": "fenomen",
    "fenomenens": "fenomen",
    "fenomenet": "fenomen",
    "fenomenets": "fenomen",
    "fenomenologien": "fenomenologi",
    "fenomenologiens": "fenomenologi",
    "fenomenologin": "fenomenologi",
    "fenomenologins": "fenomenologi",
    "fenomenologis": "fenomenologi",
    "fenomenologiska": "fenomenologisk",
    "fenomenologiskare": "fenomenologisk",
    "fenomenologiskares": "fenomenologisk",
    "fenomenologiskas": "fenomenologisk",
    "fenomenologiskast": "fenomenologisk",
    "fenomenologiskaste": "fenomenologisk",
    "fenomenologiskastes": "fenomenologisk",
    "fenomenologiskasts": "fenomenologisk",
    "fenomenologiske": "fenomenologisk",
    "fenomenologiskes": "fenomenologisk",
    "fenomenologisks": "fenomenologisk",
    "fenomenologiskt": "fenomenologisk",
    "fenomenologiskts": "fenomenologisk",
    "fenomens": "fenomen",
    "fenoplasten": "fenoplast",
    "fenoplastens": "fenoplast",
    "fenoplaster": "fenoplast",
    "fenoplasterna": "fenoplast",
    "fenoplasternas": "fenoplast",
    "fenoplasters": "fenoplast",
    "fenoplasts": "fenoplast",
    "fenor": "fena",
    "fenorna": "fena",
    "fenornas": "fena",
    "fenors": "fena",
    "fenotypen": "fenotyp",
    "fenotypens": "fenotyp",
    "fenotyper": "fenotyp",
    "fenotyperna": "fenotyp",
    "fenotypernas": "fenotyp",
    "fenotypers": "fenotyp",
    "fenotyps": "fenotyp",
    "fenoxisyran": "fenoxisyra",
    "fenoxisyrans": "fenoxisyra",
    "fenoxisyras": "fenoxisyra",
    "fenoxisyre": "fenoxisyra",
    "fenoxisyror": "fenoxisyra",
    "fenoxisyrorna": "fenoxisyra",
    "fenoxisyrornas": "fenoxisyra",
    "fenoxisyrors": "fenoxisyra",
    "fens": "fena",
    "fenvalar": "fenval",
    "fenvalarna": "fenval",
    "fenvalarnas": "fenval",
    "fenvalars": "fenval",
    "fenvalen": "fenval",
    "fenvalens": "fenval",
    "fenvals": "fenval",
    "feodala": "feodal",
    "feodalare": "feodal",
    "feodalares": "feodal",
    "feodalas": "feodal",
    "feodalast": "feodal",
    "feodalaste": "feodal",
    "feodalastes": "feodal",
    "feodalasts": "feodal",
    "feodale": "feodal",
    "feodales": "feodal",
    "feodalherrar": "feodalherre",
    "feodalherrarna": "feodalherre",
    "feodalherrarnas": "feodalherre",
    "feodalherrars": "feodalherre",
    "feodalherren": "feodalherre",
    "feodalherrens": "feodalherre",
    "feodalherres": "feodalherre",
    "feodalismen": "feodalism",
    "feodalismens": "feodalism",
    "feodalismer": "feodalism",
    "feodalismerna": "feodalism",
    "feodalismernas": "feodalism",
    "feodalismers": "feodalism",
    "feodalisms": "feodalism",
    "feodalistiska": "feodalistisk",
    "feodalistiskas": "feodalistisk",
    "feodalistiske": "feodalistisk",
    "feodalistiskes": "feodalistisk",
    "feodalistisks": "feodalistisk",
    "feodalistiskt": "feodalistisk",
    "feodalistiskts": "feodalistisk",
    "feodals": "feodal",
    "feodalt": "feodal",
    "feodalts": "feodal",
    "feodalväsendet": "feodalväsen",
    "feodalväsendets": "feodalväsen",
    "feodalväsenet": "feodalväsen",
    "feodalväsenets": "feodalväsen",
    "feodalväsens": "feodalväsen",
    "ferien": "ferie",
    "feriens": "ferie",
    "ferier": "ferie",
    "ferierna": "ferie",
    "feriernas": "ferie",
    "feriers": "ferie",
    "feries": "ferie",
    "ferma": "ferm",
    "fermare": "ferm",
    "fermares": "ferm",
    "fermas": "ferm",
    "fermast": "ferm",
    "fermaste": "ferm",
    "fermastes": "ferm",
    "fermasts": "ferm",
    "fermaten": "fermat",
    "fermatens": "fermat",
    "fermater": "fermat",
    "fermaterna": "fermat",
    "fermaternas": "fermat",
    "fermaters": "fermat",
    "fermatet": "fermat",
    "fermatets": "fermat",
    "fermats": "fermat",
    "ferme": "ferm",
    "fermenten": "ferment",
    "fermentens": "ferment",
    "fermenterad": "fermentera",
    "fermenterade": "fermentera",
    "fermenterades": "fermentera",
    "fermenterads": "fermentera",
    "fermenterande": "fermentera",
    "fermenteranden": "fermenterande",
    "fermenterandena": "fermenterande",
    "fermenterandenas": "fermenterande",
    "fermenterandens": "fermenterande",
    "fermenterandes": "fermenterande",
    "fermenterandet": "fermenterande",
    "fermenterandets": "fermenterande",
    "fermenterar": "fermentera",
    "fermenteras": "fermentera",
    "fermenterat": "fermentera",
    "fermenterats": "fermentera",
    "fermenterbara": "fermenterbar",
    "fermenterbarare": "fermenterbar",
    "fermenterbarares": "fermenterbar",
    "fermenterbaras": "fermenterbar",
    "fermenterbarast": "fermenterbar",
    "fermenterbaraste": "fermenterbar",
    "fermenterbarastes": "fermenterbar",
    "fermenterbarasts": "fermenterbar",
    "fermenterbare": "fermenterbar",
    "fermenterbares": "fermenterbar",
    "fermenterbarheten": "fermenterbarhet",
    "fermenterbarhetens": "fermenterbarhet",
    "fermenterbarhets": "fermenterbarhet",
    "fermenterbars": "fermenterbar",
    "fermenterbart": "fermenterbar",
    "fermenterbarts": "fermenterbar",
    "fermenteringar": "fermentering",
    "fermenteringarna": "fermentering",
    "fermenteringarnas": "fermentering",
    "fermenteringars": "fermentering",
    "fermenteringen": "fermentering",
    "fermenteringens": "fermentering",
    "fermenterings": "fermentering",
    "fermentet": "ferment",
    "fermentets": "ferment",
    "ferments": "ferment",
    "fermes": "ferm",
    "fermheten": "fermhet",
    "fermhetens": "fermhet",
    "fermhets": "fermhet",
    "fermiet": "fermium",
    "fermiets": "fermium",
    "fermiteten": "fermitet",
    "fermitetens": "fermitet",
    "fermiteter": "fermitet",
    "fermiteterna": "fermitet",
    "fermiteternas": "fermitet",
    "fermiteters": "fermitet",
    "fermitets": "fermitet",
    "fermiumet": "fermium",
    "fermiumets": "fermium",
    "fermiums": "fermium",
    "ferms": "ferm",
    "fermt": "ferm",
    "fermts": "ferm",
    "ferniss": "fernissa",
    "fernissad": "fernissa",
    "fernissade": "fernissa",
    "fernissades": "fernissa",
    "fernissads": "fernissa",
    "fernissan": "fernissa",
    "fernissande": "fernissa",
    "fernissanden": "fernissande",
    "fernissandena": "fernissande",
    "fernissandenas": "fernissande",
    "fernissandens": "fernissande",
    "fernissandes": "fernissande",
    "fernissandet": "fernissande",
    "fernissandets": "fernissande",
    "fernissans": "fernissa",
    "fernissar": "fernissa",
    "fernissas": "fernissa",
    "fernissat": "fernissa",
    "fernissats": "fernissa",
    "fernisse": "fernissa",
    "fernissor": "fernissa",
    "fernissorna": "fernissa",
    "fernissornas": "fernissa",
    "fernissors": "fernissa",
    "feromon": "feromoner",
    "feromonerna": "feromoner",
    "feromonernas": "feromoner",
    "feromoners": "feromoner",
    "feromons": "feromoner",
    "ferriten": "ferrit",
    "ferritens": "ferrit",
    "ferriter": "ferrit",
    "ferriterna": "ferrit",
    "ferriternas": "ferrit",
    "ferriters": "ferrit",
    "ferritkärnan": "ferritkärna",
    "ferritkärnans": "ferritkärna",
    "ferritkärnas": "ferritkärna",
    "ferritkärne": "ferritkärna",
    "ferritkärnor": "ferritkärna",
    "ferritkärnorna": "ferritkärna",
    "ferritkärnornas": "ferritkärna",
    "ferritkärnors": "ferritkärna",
    "ferrits": "ferrit",
    "ferrolegeringar": "ferrolegering",
    "ferrolegeringarna": "ferrolegering",
    "ferrolegeringarnas": "ferrolegering",
    "ferrolegeringars": "ferrolegering",
    "ferrolegeringen": "ferrolegering",
    "ferrolegeringens": "ferrolegering",
    "ferrolegerings": "ferrolegering",
    "ferrumet": "ferrum",
    "ferrumets": "ferrum",
    "ferrums": "ferrum",
    "fertila": "fertil",
    "fertilare": "fertil",
    "fertilares": "fertil",
    "fertilas": "fertil",
    "fertilast": "fertil",
    "fertilaste": "fertil",
    "fertilastes": "fertil",
    "fertilasts": "fertil",
    "fertile": "fertil",
    "fertiles": "fertil",
    "fertiliteten": "fertilitet",
    "fertilitetens": "fertilitet",
    "fertiliteter": "fertilitet",
    "fertiliteterna": "fertilitet",
    "fertiliteternas": "fertilitet",
    "fertiliteters": "fertilitet",
    "fertilitets": "fertilitet",
    "fertils": "fertil",
    "fertilt": "fertil",
    "fertilts": "fertil",
    "fes": "fisa",
    "festade": "festa",
    "festades": "festa",
    "festande": "festa",
    "festanden": "festande",
    "festandena": "festande",
    "festandenas": "festande",
    "festandens": "festande",
    "festandes": "festande",
    "festandet": "festande",
    "festandets": "festande",
    "festar": "festa",
    "festarrangören": "festarrangör",
    "festarrangörens": "festarrangör",
    "festarrangörer": "festarrangör",
    "festarrangörerna": "festarrangör",
    "festarrangörernas": "festarrangör",
    "festarrangörers": "festarrangör",
    "festarrangörs": "festarrangör",
    "festas": "festa",
    "festat": "festa",
    "festats": "festa",
    "festborden": "festbord",
    "festbordens": "festbord",
    "festbordet": "festbord",
    "festbordets": "festbord",
    "festbords": "festbord",
    "festen": "fest",
    "festens": "fest",
    "fester": "fest",
    "festerna": "fest",
    "festernas": "fest",
    "festers": "fest",
    "festivalen": "festival",
    "festivalens": "festival",
    "festivaler": "festival",
    "festivalerna": "festival",
    "festivalernas": "festival",
    "festivalers": "festival",
    "festivals": "festival",
    "festiviteten": "festivitet",
    "festivitetens": "festivitet",
    "festiviteter": "festivitet",
    "festiviteterna": "festivitet",
    "festiviteternas": "festivitet",
    "festiviteters": "festivitet",
    "festivitets": "festivitet",
    "festkläderna": "festkläder",
    "festklädernas": "festkläder",
    "festkläders": "festkläder",
    "festklädes": "festkläder",
    "festkläds": "festkläder",
    "festklänningar": "festklänning",
    "festklänningarna": "festklänning",
    "festklänningarnas": "festklänning",
    "festklänningars": "festklänning",
    "festklänningen": "festklänning",
    "festklänningens": "festklänning",
    "festklännings": "festklänning",
    "festkvällar": "festkväll",
    "festkvällarna": "festkväll",
    "festkvällarnas": "festkväll",
    "festkvällars": "festkväll",
    "festkvällen": "festkväll",
    "festkvällens": "festkväll",
    "festkvälls": "festkväll",
    "festliga": "festlig",
    "festligare": "festlig",
    "festligares": "festlig",
    "festligas": "festlig",
    "festligast": "festlig",
    "festligaste": "festlig",
    "festligastes": "festlig",
    "festligasts": "festlig",
    "festlige": "festlig",
    "festliges": "festlig",
    "festligheten": "festlighet",
    "festlighetens": "festlighet",
    "festligheter": "festlighet",
    "festligheterna": "festlighet",
    "festligheternas": "festlighet",
    "festligheters": "festlighet",
    "festlighets": "festlighet",
    "festligs": "festlig",
    "festligt": "festlig",
    "festligts": "festlig",
    "festlokalen": "festlokal",
    "festlokalens": "festlokal",
    "festlokaler": "festlokal",
    "festlokalerna": "festlokal",
    "festlokalernas": "festlokal",
    "festlokalers": "festlokal",
    "festlokals": "festlokal",
    "festmiddagar": "festmiddag",
    "festmiddagarna": "festmiddag",
    "festmiddagarnas": "festmiddag",
    "festmiddagars": "festmiddag",
    "festmiddagen": "festmiddag",
    "festmiddagens": "festmiddag",
    "festmiddags": "festmiddag",
    "festmåltiden": "festmåltid",
    "festmåltidens": "festmåltid",
    "festmåltider": "festmåltid",
    "festmåltiderna": "festmåltid",
    "festmåltidernas": "festmåltid",
    "festmåltiders": "festmåltid",
    "festmåltids": "festmåltid",
    "festonen": "feston",
    "festonens": "feston",
    "festoner": "feston",
    "festonerna": "feston",
    "festonernas": "feston",
    "festoners": "feston",
    "festongen": "festong",
    "festongens": "festong",
    "festonger": "festong",
    "festongerna": "festong",
    "festongernas": "festong",
    "festongers": "festong",
    "festongs": "festong",
    "festons": "feston",
    "festpriss": "festprisse",
    "festprissar": "festprisse",
    "festprissarna": "festprisse",
    "festprissarnas": "festprisse",
    "festprissars": "festprisse",
    "festprissen": "festprisse",
    "festprissens": "festprisse",
    "festprisses": "festprisse",
    "fests": "fest",
    "festskriften": "festskrift",
    "festskriftens": "festskrift",
    "festskrifter": "festskrift",
    "festskrifterna": "festskrift",
    "festskrifternas": "festskrift",
    "festskrifters": "festskrift",
    "festskrifts": "festskrift",
    "festspelen": "festspel",
    "festspelens": "festspel",
    "festspelet": "festspel",
    "festspelets": "festspel",
    "festspels": "festspel",
    "feststämningar": "feststämning",
    "feststämningarna": "feststämning",
    "feststämningarnas": "feststämning",
    "feststämningars": "feststämning",
    "feststämningen": "feststämning",
    "feststämningens": "feststämning",
    "feststämnings": "feststämning",
    "festtågen": "festtåg",
    "festtågens": "festtåg",
    "festtåget": "festtåg",
    "festtågets": "festtåg",
    "festtågs": "festtåg",
    "festutstyrseln": "festutstyrsel",
    "festutstyrselns": "festutstyrsel",
    "festutstyrsels": "festutstyrsel",
    "festutstyrslar": "festutstyrsel",
    "festutstyrslarna": "festutstyrsel",
    "festutstyrslarnas": "festutstyrsel",
    "festutstyrslars": "festutstyrsel",
    "festvärdinnan": "festvärdinna",
    "festvärdinnans": "festvärdinna",
    "festvärdinnas": "festvärdinna",
    "festvärdinne": "festvärdinna",
    "festvärdinnor": "festvärdinna",
    "festvärdinnorna": "festvärdinna",
    "festvärdinnornas": "festvärdinna",
    "festvärdinnors": "festvärdinna",
    "festvåningar": "festvåning",
    "festvåningarna": "festvåning",
    "festvåningarnas": "festvåning",
    "festvåningars": "festvåning",
    "festvåningen": "festvåning",
    "festvåningens": "festvåning",
    "festvånings": "festvåning",
    "fet": "f",
    "feta": "fet",
    "fetaosten": "fetaost",
    "fetaostens": "fetaost",
    "fetaosts": "fetaost",
    "fetare": "fet",
    "fetares": "fet",
    "fetas": "fet",
    "fetast": "fet",
    "fetaste": "fet",
    "fetastes": "fet",
    "fetasts": "fet",
    "fetbladen": "fetblad",
    "fetbladens": "fetblad",
    "fetbladet": "fetblad",
    "fetbladets": "fetblad",
    "fetblads": "fetblad",
    "fete": "fet",
    "feterad": "fetera",
    "feterade": "fetera",
    "feterades": "fetera",
    "feterads": "fetera",
    "feterande": "fetera",
    "feteranden": "feterande",
    "feterandena": "feterande",
    "feterandenas": "feterande",
    "feterandens": "feterande",
    "feterandes": "feterande",
    "feterandet": "feterande",
    "feterandets": "feterande",
    "feterar": "fetera",
    "feteras": "fetera",
    "feterat": "fetera",
    "feterats": "fetera",
    "feterbara": "feterbar",
    "feterbarare": "feterbar",
    "feterbarares": "feterbar",
    "feterbaras": "feterbar",
    "feterbarast": "feterbar",
    "feterbaraste": "feterbar",
    "feterbarastes": "feterbar",
    "feterbarasts": "feterbar",
    "feterbare": "feterbar",
    "feterbares": "feterbar",
    "feterbarheten": "feterbarhet",
    "feterbarhetens": "feterbarhet",
    "feterbarhets": "feterbarhet",
    "feterbars": "feterbar",
    "feterbart": "feterbar",
    "feterbarts": "feterbar",
    "feteringar": "fetering",
    "feteringarna": "fetering",
    "feteringarnas": "fetering",
    "feteringars": "fetering",
    "feteringen": "fetering",
    "feteringens": "fetering",
    "feterings": "fetering",
    "fetes": "fet",
    "fetheten": "fethet",
    "fethetens": "fethet",
    "fethets": "fethet",
    "fetischen": "fetisch",
    "fetischens": "fetisch",
    "fetischer": "fetisch",
    "fetischerna": "fetisch",
    "fetischernas": "fetisch",
    "fetischers": "fetisch",
    "fetischismen": "fetischism",
    "fetischismens": "fetischism",
    "fetischismer": "fetischism",
    "fetischismerna": "fetischism",
    "fetischismernas": "fetischism",
    "fetischismers": "fetischism",
    "fetischisms": "fetischism",
    "fetischisten": "fetischist",
    "fetischistens": "fetischist",
    "fetischister": "fetischist",
    "fetischisterna": "fetischist",
    "fetischisternas": "fetischist",
    "fetischisters": "fetischist",
    "fetischistiska": "fetischistisk",
    "fetischistiskas": "fetischistisk",
    "fetischistiske": "fetischistisk",
    "fetischistiskes": "fetischistisk",
    "fetischistisks": "fetischistisk",
    "fetischistiskt": "fetischistisk",
    "fetischistiskts": "fetischistisk",
    "fetischists": "fetischist",
    "fetischs": "fetisch",
    "fetknoppar": "fetknopp",
    "fetknopparna": "fetknopp",
    "fetknopparnas": "fetknopp",
    "fetknoppars": "fetknopp",
    "fetknoppen": "fetknopp",
    "fetknoppens": "fetknopp",
    "fetknopps": "fetknopp",
    "fetlagda": "fetlagd",
    "fetlagdare": "fetlagd",
    "fetlagdares": "fetlagd",
    "fetlagdas": "fetlagd",
    "fetlagdast": "fetlagd",
    "fetlagdaste": "fetlagd",
    "fetlagdastes": "fetlagd",
    "fetlagdasts": "fetlagd",
    "fetlagde": "fetlagd",
    "fetlagdes": "fetlagd",
    "fetlagdheten": "fetlagdhet",
    "fetlagdhetens": "fetlagdhet",
    "fetlagdhets": "fetlagdhet",
    "fetlagds": "fetlagd",
    "fetlagt": "fetlagd",
    "fetlagts": "fetlagd",
    "fetmade": "fetma",
    "fetmades": "fetma",
    "fetmaepidemien": "fetmaepidemi",
    "fetmaepidemiens": "fetmaepidemi",
    "fetmaepidemier": "fetmaepidemi",
    "fetmaepidemierna": "fetmaepidemi",
    "fetmaepidemiernas": "fetmaepidemi",
    "fetmaepidemiers": "fetmaepidemi",
    "fetmaepidemin": "fetmaepidemi",
    "fetmaepidemins": "fetmaepidemi",
    "fetmaepidemis": "fetmaepidemi",
    "fetman": "fetma",
    "fetmande": "fetma",
    "fetmanden": "fetmande",
    "fetmandena": "fetmande",
    "fetmandenas": "fetmande",
    "fetmandens": "fetmande",
    "fetmandes": "fetmande",
    "fetmandet": "fetmande",
    "fetmandets": "fetmande",
    "fetmans": "fetma",
    "fetmar": "fetma",
    "fetmas": "fetma",
    "fetmat": "fetma",
    "fetmats": "fetma",
    "fetnade": "fetna",
    "fetnades": "fetna",
    "fetnande": "fetna",
    "fetnanden": "fetnande",
    "fetnandena": "fetnande",
    "fetnandenas": "fetnande",
    "fetnandens": "fetnande",
    "fetnandes": "fetnande",
    "fetnandet": "fetnande",
    "fetnandets": "fetnande",
    "fetnar": "fetna",
    "fetnas": "fetna",
    "fetnat": "fetna",
    "fetnats": "fetna",
    "fets": "fet",
    "fetsen": "fets",
    "fetsens": "fets",
    "fetser": "fets",
    "fetserna": "fets",
    "fetsernas": "fets",
    "fetsers": "fets",
    "fetsillar": "fetsill",
    "fetsillarna": "fetsill",
    "fetsillarnas": "fetsill",
    "fetsillars": "fetsill",
    "fetsillen": "fetsill",
    "fetsillens": "fetsill",
    "fetsills": "fetsill",
    "fetstilar": "fetstil",
    "fetstilarna": "fetstil",
    "fetstilarnas": "fetstil",
    "fetstilars": "fetstil",
    "fetstilen": "fetstil",
    "fetstilens": "fetstil",
    "fetstils": "fetstil",
    "fett": "fet",
    "fetter": "fett",
    "fetterna": "fett",
    "fetternas": "fett",
    "fetters": "fett",
    "fettet": "fett",
    "fettets": "fett",
    "fettförbränningar": "fettförbränning",
    "fettförbränningarna": "fettförbränning",
    "fettförbränningarnas": "fettförbränning",
    "fettförbränningars": "fettförbränning",
    "fettförbränningen": "fettförbränning",
    "fettförbränningens": "fettförbränning",
    "fettförbrännings": "fettförbränning",
    "fetthalten": "fetthalt",
    "fetthaltens": "fetthalt",
    "fetthalter": "fetthalt",
    "fetthalterna": "fetthalt",
    "fetthalternas": "fetthalt",
    "fetthalters": "fetthalt",
    "fetthaltiga": "fetthaltig",
    "fetthaltigare": "fetthaltig",
    "fetthaltigares": "fetthaltig",
    "fetthaltigas": "fetthaltig",
    "fetthaltigast": "fetthaltig",
    "fetthaltigaste": "fetthaltig",
    "fetthaltigastes": "fetthaltig",
    "fetthaltigasts": "fetthaltig",
    "fetthaltige": "fetthaltig",
    "fetthaltiges": "fetthaltig",
    "fetthaltigheten": "fetthaltighet",
    "fetthaltighetens": "fetthaltighet",
    "fetthaltighets": "fetthaltighet",
    "fetthaltigs": "fetthaltig",
    "fetthaltigt": "fetthaltig",
    "fetthaltigts": "fetthaltig",
    "fetthalts": "fetthalt",
    "fetthjärt": "fetthjärta",
    "fetthjärtan": "fetthjärta",
    "fetthjärtana": "fetthjärta",
    "fetthjärtanas": "fetthjärta",
    "fetthjärtans": "fetthjärta",
    "fetthjärtas": "fetthjärta",
    "fetthjärtat": "fetthjärta",
    "fetthjärtats": "fetthjärta",
    "fetthjärts": "fetthjärta",
    "fetthärdningar": "fetthärdning",
    "fetthärdningarna": "fetthärdning",
    "fetthärdningarnas": "fetthärdning",
    "fetthärdningars": "fetthärdning",
    "fetthärdningen": "fetthärdning",
    "fetthärdningens": "fetthärdning",
    "fetthärdnings": "fetthärdning",
    "fettisdagar": "fettisdag",
    "fettisdagarna": "fettisdag",
    "fettisdagarnas": "fettisdag",
    "fettisdagars": "fettisdag",
    "fettisdagen": "fettisdag",
    "fettisdagens": "fettisdag",
    "fettisdags": "fettisdag",
    "fettisdagsbull": "fettisdagsbulle",
    "fettisdagsbullan": "fettisdagsbulla",
    "fettisdagsbullans": "fettisdagsbulla",
    "fettisdagsbullar": "fettisdagsbulle",
    "fettisdagsbullarna": "fettisdagsbulle",
    "fettisdagsbullarnas": "fettisdagsbulle",
    "fettisdagsbullars": "fettisdagsbulle",
    "fettisdagsbullas": "fettisdagsbulla",
    "fettisdagsbulle": "fettisdagsbulla",
    "fettisdagsbullen": "fettisdagsbulle",
    "fettisdagsbullens": "fettisdagsbulle",
    "fettisdagsbulles": "fettisdagsbulle",
    "fettisdagsbullor": "fettisdagsbulla",
    "fettisdagsbullorna": "fettisdagsbulla",
    "fettisdagsbullornas": "fettisdagsbulla",
    "fettisdagsbullors": "fettisdagsbulla",
    "fettisdagsbulls": "fettisdagsbulle",
    "fettklumpar": "fettklump",
    "fettklumparna": "fettklump",
    "fettklumparnas": "fettklump",
    "fettklumpars": "fettklump",
    "fettklumpen": "fettklump",
    "fettklumpens": "fettklump",
    "fettklumps": "fettklump",
    "fettkörteln": "fettkörtel",
    "fettkörtelns": "fettkörtel",
    "fettkörtels": "fettkörtel",
    "fettkörtlar": "fettkörtel",
    "fettkörtlarna": "fettkörtel",
    "fettkörtlarnas": "fettkörtel",
    "fettkörtlars": "fettkörtel",
    "fettlevern": "fettlever",
    "fettleverns": "fettlever",
    "fettlevers": "fettlever",
    "fettlevrar": "fettlever",
    "fettlevrarna": "fettlever",
    "fettlevrarnas": "fettlever",
    "fettlevrars": "fettlever",
    "fettlösliga": "fettlöslig",
    "fettlösligare": "fettlöslig",
    "fettlösligares": "fettlöslig",
    "fettlösligas": "fettlöslig",
    "fettlösligast": "fettlöslig",
    "fettlösligaste": "fettlöslig",
    "fettlösligastes": "fettlöslig",
    "fettlösligasts": "fettlöslig",
    "fettlöslige": "fettlöslig",
    "fettlösliges": "fettlöslig",
    "fettlösligheten": "fettlöslighet",
    "fettlöslighetens": "fettlöslighet",
    "fettlösligheter": "fettlöslighet",
    "fettlösligheterna": "fettlöslighet",
    "fettlösligheternas": "fettlöslighet",
    "fettlösligheters": "fettlöslighet",
    "fettlöslighets": "fettlöslighet",
    "fettlösligs": "fettlöslig",
    "fettlösligt": "fettlöslig",
    "fettlösligts": "fettlöslig",
    "fetton": "fetto",
    "fettona": "fetto",
    "fettonas": "fetto",
    "fettons": "fetto",
    "fettos": "fetto",
    "fettot": "fetto",
    "fettots": "fetto",
    "fettpärl": "fettpärla",
    "fettpärlan": "fettpärla",
    "fettpärlans": "fettpärla",
    "fettpärlas": "fettpärla",
    "fettpärle": "fettpärla",
    "fettpärlor": "fettpärla",
    "fettpärlorna": "fettpärla",
    "fettpärlornas": "fettpärla",
    "fettpärlors": "fettpärla",
    "fettpärls": "fettpärla",
    "fettreserven": "fettreserv",
    "fettreservens": "fettreserv",
    "fettreserver": "fettreserv",
    "fettreserverna": "fettreserv",
    "fettreservernas": "fettreserv",
    "fettreservers": "fettreserv",
    "fettreservs": "fettreserv",
    "fettrika": "fettrik",
    "fettrikare": "fettrik",
    "fettrikares": "fettrik",
    "fettrikas": "fettrik",
    "fettrikast": "fettrik",
    "fettrikaste": "fettrik",
    "fettrikastes": "fettrik",
    "fettrikasts": "fettrik",
    "fettrike": "fettrik",
    "fettrikes": "fettrik",
    "fettrikheten": "fettrikhet",
    "fettrikhetens": "fettrikhet",
    "fettrikhets": "fettrikhet",
    "fettriks": "fettrik",
    "fettrikt": "fettrik",
    "fettrikts": "fettrik",
    "fetts": "fett",
    "fettsoten": "fettsot",
    "fettsotens": "fettsot",
    "fettsots": "fettsot",
    "fettsprut": "fettspruta",
    "fettsprutan": "fettspruta",
    "fettsprutans": "fettspruta",
    "fettsprutas": "fettspruta",
    "fettsprute": "fettspruta",
    "fettsprutor": "fettspruta",
    "fettsprutorna": "fettspruta",
    "fettsprutornas": "fettspruta",
    "fettsprutors": "fettspruta",
    "fettspruts": "fettspruta",
    "fettsvansfåren": "fettsvansfår",
    "fettsvansfårens": "fettsvansfår",
    "fettsvansfåret": "fettsvansfår",
    "fettsvansfårets": "fettsvansfår",
    "fettsvansfårs": "fettsvansfår",
    "fettsyran": "fettsyra",
    "fettsyrans": "fettsyra",
    "fettsyras": "fettsyra",
    "fettsyre": "fettsyra",
    "fettsyror": "fettsyra",
    "fettsyrorna": "fettsyra",
    "fettsyrornas": "fettsyra",
    "fettsyrors": "fettsyra",
    "fettvalkar": "fettvalk",
    "fettvalkarna": "fettvalk",
    "fettvalkarnas": "fettvalk",
    "fettvalkars": "fettvalk",
    "fettvalken": "fettvalk",
    "fettvalkens": "fettvalk",
    "fettvalks": "fettvalk",
    "fettväven": "fettväv",
    "fettvävens": "fettväv",
    "fettvävnaden": "fettvävnad",
    "fettvävnadens": "fettvävnad",
    "fettvävnader": "fettvävnad",
    "fettvävnaderna": "fettvävnad",
    "fettvävnadernas": "fettvävnad",
    "fettvävnaders": "fettvävnad",
    "fettvävnads": "fettvävnad",
    "fettvävs": "fettväv",
    "fettämnen": "fettämne",
    "fettämnena": "fettämne",
    "fettämnenas": "fettämne",
    "fettämnens": "fettämne",
    "fettämnes": "fettämne",
    "fettämnet": "fettämne",
    "fettämnets": "fettämne",
    "fetvadden": "fetvadd",
    "fetvaddens": "fetvadd",
    "fetvadds": "fetvadd",
    "fezen": "fez",
    "fezens": "fez",
    "fezer": "fez",
    "fezerna": "fez",
    "fezernas": "fez",
    "fezers": "fez",
    "fialen": "fial",
    "fialens": "fial",
    "fialer": "fial",
    "fialerna": "fial",
    "fialernas": "fial",
    "fialers": "fial",
    "fials": "fial",
    "fian": "fia",
    "fians": "fia",
    "fias": "fia",
    "fiaskoartade": "fiaskoartad",
    "fiaskoartades": "fiaskoartad",
    "fiaskoartads": "fiaskoartad",
    "fiaskoartat": "fiaskoartad",
    "fiaskoartats": "fiaskoartad",
    "fiaskokonferensen": "fiaskokonferens",
    "fiaskokonferensens": "fiaskokonferens",
    "fiaskokonferenser": "fiaskokonferens",
    "fiaskokonferenserna": "fiaskokonferens",
    "fiaskokonferensernas": "fiaskokonferens",
    "fiaskokonferensers": "fiaskokonferens",
    "fiaskon": "fiasko",
    "fiaskona": "fiasko",
    "fiaskonas": "fiasko",
    "fiaskons": "fiasko",
    "fiaskos": "fiasko",
    "fiaskot": "fiasko",
    "fiaskots": "fiasko",
    "fiat": "fia",
    "fiats": "fia",
    "fibbel": "fibbla",
    "fibblan": "fibbla",
    "fibblans": "fibbla",
    "fibblas": "fibbla",
    "fibble": "fibbla",
    "fibblor": "fibbla",
    "fibblorna": "fibbla",
    "fibblornas": "fibbla",
    "fibblors": "fibbla",
    "fiberblandningar": "fiberblandning",
    "fiberblandningarna": "fiberblandning",
    "fiberblandningarnas": "fiberblandning",
    "fiberblandningars": "fiberblandning",
    "fiberblandningen": "fiberblandning",
    "fiberblandningens": "fiberblandning",
    "fiberblandnings": "fiberblandning",
    "fibern": "fiber",
    "fiberns": "fiber",
    "fiberoptiken": "fiberoptik",
    "fiberoptikens": "fiberoptik",
    "fiberoptiks": "fiberoptik",
    "fiberplatt": "fiberplatta",
    "fiberplattan": "fiberplatta",
    "fiberplattans": "fiberplatta",
    "fiberplattas": "fiberplatta",
    "fiberplatte": "fiberplatta",
    "fiberplattor": "fiberplatta",
    "fiberplattorna": "fiberplatta",
    "fiberplattornas": "fiberplatta",
    "fiberplattors": "fiberplatta",
    "fiberplatts": "fiberplatta",
    "fiberrika": "fiberrik",
    "fiberrikare": "fiberrik",
    "fiberrikares": "fiberrik",
    "fiberrikas": "fiberrik",
    "fiberrikast": "fiberrik",
    "fiberrikaste": "fiberrik",
    "fiberrikastes": "fiberrik",
    "fiberrikasts": "fiberrik",
    "fiberrike": "fiberrik",
    "fiberrikes": "fiberrik",
    "fiberrikheten": "fiberrikhet",
    "fiberrikhetens": "fiberrikhet",
    "fiberrikhets": "fiberrikhet",
    "fiberriks": "fiberrik",
    "fiberrikt": "fiberrik",
    "fiberrikts": "fiberrik",
    "fibers": "fiber",
    "fiberspikar": "fiberspik",
    "fiberspikarna": "fiberspik",
    "fiberspikarnas": "fiberspik",
    "fiberspikars": "fiberspik",
    "fiberspiken": "fiberspik",
    "fiberspikens": "fiberspik",
    "fiberspiks": "fiberspik",
    "fibertillsatsen": "fibertillsats",
    "fibertillsatsens": "fibertillsats",
    "fibertillsatser": "fibertillsats",
    "fibertillsatserna": "fibertillsats",
    "fibertillsatsernas": "fibertillsats",
    "fibertillsatsers": "fibertillsats",
    "fiberväxten": "fiberväxt",
    "fiberväxtens": "fiberväxt",
    "fiberväxter": "fiberväxt",
    "fiberväxterna": "fiberväxt",
    "fiberväxternas": "fiberväxt",
    "fiberväxters": "fiberväxt",
    "fiberväxts": "fiberväxt",
    "fibrer": "fiber",
    "fibrerna": "fiber",
    "fibrernas": "fiber",
    "fibrers": "fiber",
    "fibriga": "fibrig",
    "fibrigare": "fibrig",
    "fibrigares": "fibrig",
    "fibrigas": "fibrig",
    "fibrigast": "fibrig",
    "fibrigaste": "fibrig",
    "fibrigastes": "fibrig",
    "fibrigasts": "fibrig",
    "fibrige": "fibrig",
    "fibriges": "fibrig",
    "fibrigheten": "fibrighet",
    "fibrighetens": "fibrighet",
    "fibrighets": "fibrighet",
    "fibrigs": "fibrig",
    "fibrigt": "fibrig",
    "fibrigts": "fibrig",
    "fibrillen": "fibrill",
    "fibrillens": "fibrill",
    "fibriller": "fibrill",
    "fibrillerna": "fibrill",
    "fibrillernas": "fibrill",
    "fibrillers": "fibrill",
    "fibrills": "fibrill",
    "fibrinen": "fibrin",
    "fibrinens": "fibrin",
    "fibriner": "fibrin",
    "fibrinerna": "fibrin",
    "fibrinernas": "fibrin",
    "fibriners": "fibrin",
    "fibrinet": "fibrin",
    "fibrinets": "fibrin",
    "fibrins": "fibrin",
    "fibul": "fibula",
    "fibulan": "fibula",
    "fibulans": "fibula",
    "fibulas": "fibula",
    "fibule": "fibula",
    "fibulor": "fibula",
    "fibulorna": "fibula",
    "fibulornas": "fibula",
    "fibulors": "fibula",
    "fibuls": "fibula",
    "fick": "ficka",
    "fickan": "ficka",
    "fickans": "ficka",
    "fickas": "ficka",
    "ficke": "ficka",
    "fickformaten": "fickformat",
    "fickformatens": "fickformat",
    "fickformatet": "fickformat",
    "fickformatets": "fickformat",
    "fickformats": "fickformat",
    "fickhandboken": "fickhandbok",
    "fickhandbokens": "fickhandbok",
    "fickhandboks": "fickhandbok",
    "fickhandböcker": "fickhandbok",
    "fickhandböckerna": "fickhandbok",
    "fickhandböckernas": "fickhandbok",
    "fickhandböckers": "fickhandbok",
    "fickkalkylatorer": "fickkalkylator",
    "fickkalkylatorerna": "fickkalkylator",
    "fickkalkylatorernas": "fickkalkylator",
    "fickkalkylatorers": "fickkalkylator",
    "fickkalkylatorn": "fickkalkylator",
    "fickkalkylatorns": "fickkalkylator",
    "fickkalkylators": "fickkalkylator",
    "fickknivar": "fickkniv",
    "fickknivarna": "fickkniv",
    "fickknivarnas": "fickkniv",
    "fickknivars": "fickkniv",
    "fickkniven": "fickkniv",
    "fickknivens": "fickkniv",
    "fickknivs": "fickkniv",
    "ficklamp": "ficklampa",
    "ficklampan": "ficklampa",
    "ficklampans": "ficklampa",
    "ficklampas": "ficklampa",
    "ficklampe": "ficklampa",
    "ficklampor": "ficklampa",
    "ficklamporna": "ficklampa",
    "ficklampornas": "ficklampa",
    "ficklampors": "ficklampa",
    "ficklamps": "ficklampa",
    "fickor": "ficka",
    "fickorna": "ficka",
    "fickornas": "ficka",
    "fickors": "ficka",
    "fickparkerad": "fickparkera",
    "fickparkerade": "fickparkera",
    "fickparkerades": "fickparkera",
    "fickparkerads": "fickparkera",
    "fickparkerande": "fickparkera",
    "fickparkeranden": "fickparkerande",
    "fickparkerandena": "fickparkerande",
    "fickparkerandenas": "fickparkerande",
    "fickparkerandens": "fickparkerande",
    "fickparkerandes": "fickparkerande",
    "fickparkerandet": "fickparkerande",
    "fickparkerandets": "fickparkerande",
    "fickparkerar": "fickparkera",
    "fickparkeras": "fickparkera",
    "fickparkerat": "fickparkera",
    "fickparkerats": "fickparkera",
    "fickparkerbara": "fickparkerbar",
    "fickparkerbarare": "fickparkerbar",
    "fickparkerbarares": "fickparkerbar",
    "fickparkerbaras": "fickparkerbar",
    "fickparkerbarast": "fickparkerbar",
    "fickparkerbaraste": "fickparkerbar",
    "fickparkerbarastes": "fickparkerbar",
    "fickparkerbarasts": "fickparkerbar",
    "fickparkerbare": "fickparkerbar",
    "fickparkerbares": "fickparkerbar",
    "fickparkerbarheten": "fickparkerbarhet",
    "fickparkerbarhetens": "fickparkerbarhet",
    "fickparkerbarhets": "fickparkerbarhet",
    "fickparkerbars": "fickparkerbar",
    "fickparkerbart": "fickparkerbar",
    "fickparkerbarts": "fickparkerbar",
    "fickparkeringar": "fickparkering",
    "fickparkeringarna": "fickparkering",
    "fickparkeringarnas": "fickparkering",
    "fickparkeringars": "fickparkering",
    "fickparkeringen": "fickparkering",
    "fickparkeringens": "fickparkering",
    "fickparkerings": "fickparkering",
    "fickpengar": "fickpeng",
    "fickpengarna": "fickpeng",
    "fickpengarnas": "fickpeng",
    "fickpengars": "fickpeng",
    "fickpengen": "fickpeng",
    "fickpengens": "fickpeng",
    "fickpengs": "fickpeng",
    "fickplunt": "fickplunta",
    "fickpluntan": "fickplunta",
    "fickpluntans": "fickplunta",
    "fickpluntas": "fickplunta",
    "fickplunte": "fickplunta",
    "fickpluntor": "fickplunta",
    "fickpluntorna": "fickplunta",
    "fickpluntornas": "fickplunta",
    "fickpluntors": "fickplunta",
    "fickplunts": "fickplunta",
    "ficks": "ficka",
    "fickspegeln": "fickspegel",
    "fickspegelns": "fickspegel",
    "fickspegels": "fickspegel",
    "fickspeglar": "fickspegel",
    "fickspeglarna": "fickspegel",
    "fickspeglarnas": "fickspegel",
    "fickspeglars": "fickspegel",
    "ficktjuvar": "ficktjuv",
    "ficktjuvarna": "ficktjuv",
    "ficktjuvarnas": "ficktjuv",
    "ficktjuvars": "ficktjuv",
    "ficktjuven": "ficktjuv",
    "ficktjuvens": "ficktjuv",
    "ficktjuvs": "ficktjuv",
    "fickuren": "fickur",
    "fickurens": "fickur",
    "fickuret": "fickur",
    "fickurets": "fickur",
    "fickurs": "fickur",
    "fiction-novellen": "fiction-novell",
    "fiction-novellens": "fiction-novell",
    "fiction-noveller": "fiction-novell",
    "fiction-novellerna": "fiction-novell",
    "fiction-novellernas": "fiction-novell",
    "fiction-novellers": "fiction-novell",
    "fiction-novells": "fiction-novell",
    "fictions": "fiction",
    "fideikommissen": "fideikommiss",
    "fideikommissens": "fideikommiss",
    "fideikommisset": "fideikommiss",
    "fideikommissets": "fideikommiss",
    "fidjianen": "fidjian",
    "fidjianens": "fidjian",
    "fidjianer": "fidjian",
    "fidjianerna": "fidjian",
    "fidjianernas": "fidjian",
    "fidjianers": "fidjian",
    "fidjians": "fidjian",
    "fidusar": "fidus",
    "fidusarna": "fidus",
    "fidusarnas": "fidus",
    "fidusars": "fidus",
    "fidusen": "fidus",
    "fidusens": "fidus",
    "fien": "fi",
    "fiendearméer": "fiendearmé",
    "fiendearméerna": "fiendearmé",
    "fiendearméernas": "fiendearmé",
    "fiendearméers": "fiendearmé",
    "fiendearmén": "fiendearmé",
    "fiendearméns": "fiendearmé",
    "fiendearmés": "fiendearmé",
    "fienden": "fiende",
    "fiendens": "fiende",
    "fiender": "fiende",
    "fienderna": "fiende",
    "fiendernas": "fiende",
    "fienders": "fiende",
    "fiendes": "fiende",
    "fiendesoldaten": "fiendesoldat",
    "fiendesoldatens": "fiendesoldat",
    "fiendesoldater": "fiendesoldat",
    "fiendesoldaterna": "fiendesoldat",
    "fiendesoldaternas": "fiendesoldat",
    "fiendesoldaters": "fiendesoldat",
    "fiendesoldats": "fiendesoldat",
    "fiendskapen": "fiendskap",
    "fiendskapens": "fiendskap",
    "fiendskaper": "fiendskap",
    "fiendskaperna": "fiendskap",
    "fiendskapernas": "fiendskap",
    "fiendskapers": "fiendskap",
    "fiendskaps": "fiendskap",
    "fiens": "fi",
    "fientliga": "fientlig",
    "fientligare": "fientlig",
    "fientligares": "fientlig",
    "fientligas": "fientlig",
    "fientligast": "fientlig",
    "fientligaste": "fientlig",
    "fientligastes": "fientlig",
    "fientligasts": "fientlig",
    "fientlige": "fientlig",
    "fientliges": "fientlig",
    "fientligheten": "fientlighet",
    "fientlighetens": "fientlighet",
    "fientligheter": "fientlighet",
    "fientligheterna": "fientlighet",
    "fientligheternas": "fientlighet",
    "fientligheters": "fientlighet",
    "fientlighets": "fientlighet",
    "fientligs": "fientlig",
    "fientligt": "fientlig",
    "fientligts": "fientlig",
    "fiet": "fi",
    "fiets": "fi",
    "fiffel": "fiffla",
    "fiffels": "fiffel",
    "fiffiga": "fiffig",
    "fiffigare": "fiffig",
    "fiffigares": "fiffig",
    "fiffigas": "fiffig",
    "fiffigast": "fiffig",
    "fiffigaste": "fiffig",
    "fiffigastes": "fiffig",
    "fiffigasts": "fiffig",
    "fiffige": "fiffig",
    "fiffiges": "fiffig",
    "fiffigheten": "fiffighet",
    "fiffighetens": "fiffighet",
    "fiffigheter": "fiffighet",
    "fiffigheterna": "fiffighet",
    "fiffigheternas": "fiffighet",
    "fiffigheters": "fiffighet",
    "fiffighets": "fiffighet",
    "fiffigs": "fiffig",
    "fiffigt": "fiffig",
    "fiffigts": "fiffig",
    "fifflade": "fiffla",
    "fifflades": "fiffla",
    "fifflande": "fiffla",
    "fifflanden": "fifflande",
    "fifflandena": "fifflande",
    "fifflandenas": "fifflande",
    "fifflandens": "fifflande",
    "fifflandes": "fifflande",
    "fifflandet": "fifflande",
    "fifflandets": "fifflande",
    "fifflar": "fifflare",
    "fifflaren": "fifflare",
    "fifflarens": "fifflare",
    "fifflares": "fifflare",
    "fifflarna": "fifflare",
    "fifflarnas": "fifflare",
    "fifflas": "fiffla",
    "fifflat": "fiffla",
    "fifflats": "fiffla",
    "fifflet": "fiffel",
    "fifflets": "fiffel",
    "fightades": "fightas",
    "fightats": "fightas",
    "fighten": "fight",
    "fightens": "fight",
    "fighter": "fight",
    "fightern": "fighter",
    "fighterna": "fighter",
    "fighternas": "fighter",
    "fighterns": "fighter",
    "fighters": "fighter",
    "fightersarna": "fighter",
    "fightersarnas": "fighter",
    "fightersen": "fighter",
    "fightersens": "fighter",
    "fights": "fight",
    "figuranten": "figurant",
    "figurantens": "figurant",
    "figuranter": "figurant",
    "figuranterna": "figurant",
    "figuranternas": "figurant",
    "figuranters": "figurant",
    "figurants": "figurant",
    "figurationen": "figuration",
    "figurationens": "figuration",
    "figurationer": "figuration",
    "figurationerna": "figuration",
    "figurationernas": "figuration",
    "figurationers": "figuration",
    "figurations": "figuration",
    "figurativa": "figurativ",
    "figurativare": "figurativ",
    "figurativares": "figurativ",
    "figurativas": "figurativ",
    "figurativast": "figurativ",
    "figurativaste": "figurativ",
    "figurativastes": "figurativ",
    "figurativasts": "figurativ",
    "figurative": "figurativ",
    "figuratives": "figurativ",
    "figurativs": "figurativ",
    "figurativt": "figurativ",
    "figurativts": "figurativ",
    "figuren": "figur",
    "figurens": "figur",
    "figurer": "figur",
    "figurerade": "figurera",
    "figurerades": "figurera",
    "figurerande": "figurera",
    "figureranden": "figurerande",
    "figurerandena": "figurerande",
    "figurerandenas": "figurerande",
    "figurerandens": "figurerande",
    "figurerandes": "figurerande",
    "figurerandet": "figurerande",
    "figurerandets": "figurerande",
    "figurerar": "figurera",
    "figureras": "figurera",
    "figurerat": "figurera",
    "figurerats": "figurera",
    "figureringar": "figurering",
    "figureringarna": "figurering",
    "figureringarnas": "figurering",
    "figureringars": "figurering",
    "figureringen": "figurering",
    "figureringens": "figurering",
    "figurerings": "figurering",
    "figurerna": "figur",
    "figurernas": "figur",
    "figurers": "figur",
    "figurliga": "figurlig",
    "figurligare": "figurlig",
    "figurligares": "figurlig",
    "figurligas": "figurlig",
    "figurligast": "figurlig",
    "figurligaste": "figurlig",
    "figurligastes": "figurlig",
    "figurligasts": "figurlig",
    "figurlige": "figurlig",
    "figurliges": "figurlig",
    "figurligheten": "figurlighet",
    "figurlighetens": "figurlighet",
    "figurlighets": "figurlighet",
    "figurligs": "figurlig",
    "figurligt": "figurlig",
    "figurligts": "figurlig",
    "figurs": "figur",
    "figursydda": "figursydd",
    "figursyddare": "figursydd",
    "figursyddares": "figursydd",
    "figursyddas": "figursydd",
    "figursyddast": "figursydd",
    "figursyddaste": "figursydd",
    "figursyddastes": "figursydd",
    "figursyddasts": "figursydd",
    "figursydde": "figursydd",
    "figursyddes": "figursydd",
    "figursydds": "figursydd",
    "figursytt": "figursydd",
    "figursytts": "figursydd",
    "figuråkningar": "figuråkning",
    "figuråkningarna": "figuråkning",
    "figuråkningarnas": "figuråkning",
    "figuråkningars": "figuråkning",
    "figuråkningen": "figuråkning",
    "figuråkningens": "figuråkning",
    "figuråknings": "figuråkning",
    "fijianen": "fijian",
    "fijianens": "fijian",
    "fijianer": "fijian",
    "fijianerna": "fijian",
    "fijianernas": "fijian",
    "fijianers": "fijian",
    "fijians": "fijian",
    "fijiansk": "fijianska",
    "fijianska": "fijiansk",
    "fijianskan": "fijianska",
    "fijianskans": "fijianska",
    "fijianskare": "fijiansk",
    "fijianskares": "fijiansk",
    "fijianskas": "fijianska",
    "fijianskast": "fijiansk",
    "fijianskaste": "fijiansk",
    "fijianskastes": "fijiansk",
    "fijianskasts": "fijiansk",
    "fijianske": "fijianska",
    "fijianskes": "fijiansk",
    "fijianskor": "fijianska",
    "fijianskorna": "fijianska",
    "fijianskornas": "fijianska",
    "fijianskors": "fijianska",
    "fijiansks": "fijiansk",
    "fijianskt": "fijiansk",
    "fijianskts": "fijiansk",
    "fikade": "fika",
    "fikades": "fika",
    "fikahörnan": "fikahörna",
    "fikahörnans": "fikahörna",
    "fikahörnas": "fikahörna",
    "fikahörne": "fikahörna",
    "fikahörnor": "fikahörna",
    "fikahörnorna": "fikahörna",
    "fikahörnornas": "fikahörna",
    "fikahörnors": "fikahörna",
    "fikan": "fika",
    "fikande": "fika",
    "fikanden": "fikande",
    "fikandena": "fikande",
    "fikandenas": "fikande",
    "fikandens": "fikande",
    "fikandes": "fikande",
    "fikandet": "fikande",
    "fikandets": "fikande",
    "fikans": "fika",
    "fikapausen": "fikapaus",
    "fikapausens": "fikapaus",
    "fikapauser": "fikapaus",
    "fikapauserna": "fikapaus",
    "fikapausernas": "fikapaus",
    "fikapausers": "fikapaus",
    "fikar": "fika",
    "fikas": "fika",
    "fikat": "fika",
    "fikats": "fika",
    "fiken": "fik",
    "fikenheten": "fikenhet",
    "fikenhetens": "fikenhet",
    "fikenhets": "fikenhet",
    "fikens": "fiken",
    "fiket": "fiken",
    "fikets": "fiken",
    "fikna": "fiken",
    "fiknare": "fiken",
    "fiknares": "fiken",
    "fiknas": "fiken",
    "fiknast": "fiken",
    "fiknaste": "fiken",
    "fiknastes": "fiken",
    "fiknasts": "fiken",
    "fikne": "fiken",
    "fiknes": "fiken",
    "fikonen": "fikon",
    "fikonens": "fikon",
    "fikonet": "fikon",
    "fikonets": "fikon",
    "fikonlöven": "fikonlöv",
    "fikonlövens": "fikonlöv",
    "fikonlövet": "fikonlöv",
    "fikonlövets": "fikonlöv",
    "fikonlövs": "fikonlöv",
    "fikons": "fikon",
    "fikonspråken": "fikonspråk",
    "fikonspråkens": "fikonspråk",
    "fikonspråket": "fikonspråk",
    "fikonspråkets": "fikonspråk",
    "fikonspråks": "fikonspråk",
    "fikonträden": "fikonträd",
    "fikonträdens": "fikonträd",
    "fikonträdet": "fikonträd",
    "fikonträdets": "fikonträd",
    "fikonträds": "fikonträd",
    "fiks": "fik",
    "fiktionalismen": "fiktionalism",
    "fiktionalismens": "fiktionalism",
    "fiktionalismer": "fiktionalism",
    "fiktionalismerna": "fiktionalism",
    "fiktionalismernas": "fiktionalism",
    "fiktionalismers": "fiktionalism",
    "fiktionalisms": "fiktionalism",
    "fiktionen": "fiktion",
    "fiktionens": "fiktion",
    "fiktioner": "fiktion",
    "fiktionerna": "fiktion",
    "fiktionernas": "fiktion",
    "fiktioners": "fiktion",
    "fiktions": "fiktion",
    "fiktionsprosan": "fiktionsprosa",
    "fiktionsprosans": "fiktionsprosa",
    "fiktionsprosas": "fiktionsprosa",
    "fiktiva": "fiktiv",
    "fiktivare": "fiktiv",
    "fiktivares": "fiktiv",
    "fiktivas": "fiktiv",
    "fiktivast": "fiktiv",
    "fiktivaste": "fiktiv",
    "fiktivastes": "fiktiv",
    "fiktivasts": "fiktiv",
    "fiktive": "fiktiv",
    "fiktives": "fiktiv",
    "fiktivs": "fiktiv",
    "fiktivt": "fiktiv",
    "fiktivts": "fiktiv",
    "fikusar": "fikus",
    "fikusarna": "fikus",
    "fikusarnas": "fikus",
    "fikusars": "fikus",
    "fikusen": "fikus",
    "fikusens": "fikus",
    "fil": "fila",
    "filad": "fila",
    "filade": "fila",
    "filades": "fila",
    "filads": "fila",
    "filande": "fila",
    "filanden": "filande",
    "filandena": "filande",
    "filandenas": "filande",
    "filandens": "filande",
    "filandes": "filande",
    "filandet": "filande",
    "filandets": "filande",
    "filantropen": "filantrop",
    "filantropens": "filantrop",
    "filantroper": "filantrop",
    "filantroperna": "filantrop",
    "filantropernas": "filantrop",
    "filantropers": "filantrop",
    "filantropien": "filantropi",
    "filantropiens": "filantropi",
    "filantropin": "filantropi",
    "filantropins": "filantropi",
    "filantropis": "filantropi",
    "filantropiska": "filantropisk",
    "filantropiskare": "filantropisk",
    "filantropiskares": "filantropisk",
    "filantropiskas": "filantropisk",
    "filantropiskast": "filantropisk",
    "filantropiskaste": "filantropisk",
    "filantropiskastes": "filantropisk",
    "filantropiskasts": "filantropisk",
    "filantropiske": "filantropisk",
    "filantropiskes": "filantropisk",
    "filantropisks": "filantropisk",
    "filantropiskt": "filantropisk",
    "filantropiskts": "filantropisk",
    "filantrops": "filantrop",
    "filar": "fila",
    "filarna": "fil",
    "filarnas": "fil",
    "filars": "fil",
    "filas": "fila",
    "filat": "fila",
    "filatelien": "filateli",
    "filateliens": "filateli",
    "filatelin": "filateli",
    "filatelins": "filateli",
    "filatelis": "filateli",
    "filatelisten": "filatelist",
    "filatelistens": "filatelist",
    "filatelister": "filatelist",
    "filatelisterna": "filatelist",
    "filatelisternas": "filatelist",
    "filatelisters": "filatelist",
    "filatelists": "filatelist",
    "filats": "fila",
    "filbunk": "filbunke",
    "filbunkar": "filbunke",
    "filbunkarna": "filbunke",
    "filbunkarnas": "filbunke",
    "filbunkars": "filbunke",
    "filbunken": "filbunke",
    "filbunkens": "filbunke",
    "filbunkes": "filbunke",
    "filbunks": "filbunke",
    "filbyten": "filbyte",
    "filbytena": "filbyte",
    "filbytenas": "filbyte",
    "filbytens": "filbyte",
    "filbytes": "filbyte",
    "filbytet": "filbyte",
    "filbytets": "filbyte",
    "fildelningar": "fildelning",
    "fildelningarna": "fildelning",
    "fildelningarnas": "fildelning",
    "fildelningars": "fildelning",
    "fildelningen": "fildelning",
    "fildelningens": "fildelning",
    "fildelnings": "fildelning",
    "file": "filea",
    "filead": "filea",
    "fileade": "filea",
    "fileades": "filea",
    "fileads": "filea",
    "fileande": "filea",
    "fileanden": "fileande",
    "fileandena": "fileande",
    "fileandenas": "fileande",
    "fileandens": "fileande",
    "fileandes": "fileande",
    "fileandet": "fileande",
    "fileandets": "fileande",
    "filear": "filea",
    "fileas": "filea",
    "fileat": "filea",
    "fileats": "filea",
    "fileer": "file",
    "fileerna": "file",
    "fileernas": "file",
    "fileers": "file",
    "filen": "file",
    "filens": "file",
    "filer": "fil",
    "filerad": "filera",
    "filerade": "filera",
    "filerades": "filera",
    "filerads": "filera",
    "filerande": "filera",
    "fileranden": "filerande",
    "filerandena": "filerande",
    "filerandenas": "filerande",
    "filerandens": "filerande",
    "filerandes": "filerande",
    "filerandet": "filerande",
    "filerandets": "filerande",
    "filerar": "filera",
    "fileras": "filera",
    "filerat": "filera",
    "filerats": "filera",
    "filerbara": "filerbar",
    "filerbarare": "filerbar",
    "filerbarares": "filerbar",
    "filerbaras": "filerbar",
    "filerbarast": "filerbar",
    "filerbaraste": "filerbar",
    "filerbarastes": "filerbar",
    "filerbarasts": "filerbar",
    "filerbare": "filerbar",
    "filerbares": "filerbar",
    "filerbarheten": "filerbarhet",
    "filerbarhetens": "filerbarhet",
    "filerbarhets": "filerbarhet",
    "filerbars": "filerbar",
    "filerbart": "filerbar",
    "filerbarts": "filerbar",
    "fileringar": "filering",
    "fileringarna": "filering",
    "fileringarnas": "filering",
    "fileringars": "filering",
    "fileringen": "filering",
    "fileringens": "filering",
    "filerings": "filering",
    "filerna": "fil",
    "filernas": "fil",
    "filers": "fil",
    "files": "file",
    "filhandtagen": "filhandtag",
    "filhandtagens": "filhandtag",
    "filhandtaget": "filhandtag",
    "filhandtagets": "filhandtag",
    "filhandtags": "filhandtag",
    "filharmonien": "filharmoni",
    "filharmoniens": "filharmoni",
    "filharmonikern": "filharmoniker",
    "filharmonikerna": "filharmoniker",
    "filharmonikernas": "filharmoniker",
    "filharmonikerns": "filharmoniker",
    "filharmonikers": "filharmoniker",
    "filharmonin": "filharmoni",
    "filharmonins": "filharmoni",
    "filharmonis": "filharmoni",
    "filharmoniska": "filharmonisk",
    "filharmoniskare": "filharmonisk",
    "filharmoniskares": "filharmonisk",
    "filharmoniskas": "filharmonisk",
    "filharmoniskast": "filharmonisk",
    "filharmoniskaste": "filharmonisk",
    "filharmoniskastes": "filharmonisk",
    "filharmoniskasts": "filharmonisk",
    "filharmoniske": "filharmonisk",
    "filharmoniskes": "filharmonisk",
    "filharmonisks": "filharmonisk",
    "filharmoniskt": "filharmonisk",
    "filharmoniskts": "filharmonisk",
    "filialen": "filial",
    "filialens": "filial",
    "filialer": "filial",
    "filialerna": "filial",
    "filialernas": "filial",
    "filialers": "filial",
    "filials": "filial",
    "filibustern": "filibuster",
    "filibusterns": "filibuster",
    "filibusters": "filibuster",
    "filibustrar": "filibuster",
    "filibustrarna": "filibuster",
    "filibustrarnas": "filibuster",
    "filibustrars": "filibuster",
    "filibustringar": "filibustring",
    "filibustringarna": "filibustring",
    "filibustringarnas": "filibustring",
    "filibustringars": "filibustring",
    "filibustringen": "filibustring",
    "filibustringens": "filibustring",
    "filibustrings": "filibustring",
    "filigranen": "filigran",
    "filigranens": "filigran",
    "filigraner": "filigran",
    "filigranerna": "filigran",
    "filigranernas": "filigran",
    "filigraners": "filigran",
    "filigranet": "filigran",
    "filigranets": "filigran",
    "filigrans": "filigran",
    "filipinen": "filipin",
    "filipinens": "filipin",
    "filipiner": "filipin",
    "filipinerna": "filipin",
    "filipinernas": "filipin",
    "filipiners": "filipin",
    "filipins": "filipin",
    "filippiken": "filippik",
    "filippikens": "filippik",
    "filippiker": "filippik",
    "filippikerna": "filippik",
    "filippikernas": "filippik",
    "filippikers": "filippik",
    "filippiks": "filippik",
    "filippinar": "filippinare",
    "filippinaren": "filippinare",
    "filippinarens": "filippinare",
    "filippinares": "filippinare",
    "filippinarna": "filippinare",
    "filippinarnas": "filippinare",
    "filippinska": "filippinsk",
    "filippinskan": "filippinska",
    "filippinskans": "filippinska",
    "filippinskare": "filippinsk",
    "filippinskares": "filippinsk",
    "filippinskas": "filippinska",
    "filippinskast": "filippinsk",
    "filippinskaste": "filippinsk",
    "filippinskastes": "filippinsk",
    "filippinskasts": "filippinsk",
    "filippinske": "filippinska",
    "filippinskes": "filippinsk",
    "filippinskor": "filippinska",
    "filippinskorna": "filippinska",
    "filippinskornas": "filippinska",
    "filippinskors": "filippinska",
    "filippinsks": "filippinsk",
    "filippinskt": "filippinsk",
    "filippinskts": "filippinsk",
    "filistern": "filister",
    "filisterns": "filister",
    "filisters": "filister",
    "filistrar": "filister",
    "filistrarna": "filister",
    "filistrarnas": "filister",
    "filistrars": "filister",
    "filiströsa": "filiströs",
    "filiströsare": "filiströs",
    "filiströsares": "filiströs",
    "filiströsas": "filiströs",
    "filiströsast": "filiströs",
    "filiströsaste": "filiströs",
    "filiströsastes": "filiströs",
    "filiströsasts": "filiströs",
    "filiströse": "filiströs",
    "filiströses": "filiströs",
    "filiströst": "filiströs",
    "filiströsts": "filiströs",
    "filistéen": "filisté",
    "filistéens": "filisté",
    "filistéer": "filisté",
    "filistéerna": "filisté",
    "filistéernas": "filisté",
    "filistéers": "filisté",
    "filistén": "filisté",
    "filisténs": "filisté",
    "filistés": "filisté",
    "filklov": "filklove",
    "filklovar": "filklove",
    "filklovarna": "filklove",
    "filklovarnas": "filklove",
    "filklovars": "filklove",
    "filkloven": "filklove",
    "filklovens": "filklove",
    "filkloves": "filklove",
    "filklovs": "filklove",
    "filkörningar": "filkörning",
    "filkörningarna": "filkörning",
    "filkörningarnas": "filkörning",
    "filkörningars": "filkörning",
    "filkörningen": "filkörning",
    "filkörningens": "filkörning",
    "filkörnings": "filkörning",
    "fillern": "filler",
    "fillerns": "filler",
    "fillers": "filler",
    "film": "filma",
    "filmad": "filma",
    "filmade": "filma",
    "filmades": "filma",
    "filmads": "filma",
    "filmaffischen": "filmaffisch",
    "filmaffischens": "filmaffisch",
    "filmaffischer": "filmaffisch",
    "filmaffischerna": "filmaffisch",
    "filmaffischernas": "filmaffisch",
    "filmaffischers": "filmaffisch",
    "filmaffischs": "filmaffisch",
    "filmande": "filma",
    "filmanden": "filmande",
    "filmandena": "filmande",
    "filmandenas": "filmande",
    "filmandens": "filmande",
    "filmandes": "filmande",
    "filmandet": "filmande",
    "filmandets": "filmande",
    "filmar": "filmare",
    "filmaren": "filmare",
    "filmarens": "filmare",
    "filmares": "filmare",
    "filmarna": "filmare",
    "filmarnas": "filmare",
    "filmas": "filma",
    "filmaskinen": "filmaskin",
    "filmaskinens": "filmaskin",
    "filmaskiner": "filmaskin",
    "filmaskinerna": "filmaskin",
    "filmaskinernas": "filmaskin",
    "filmaskiners": "filmaskin",
    "filmaskins": "filmaskin",
    "filmat": "filma",
    "filmateljéer": "filmateljé",
    "filmateljéerna": "filmateljé",
    "filmateljéernas": "filmateljé",
    "filmateljéers": "filmateljé",
    "filmateljén": "filmateljé",
    "filmateljéns": "filmateljé",
    "filmateljés": "filmateljé",
    "filmatiserad": "filmatisera",
    "filmatiserade": "filmatisera",
    "filmatiserades": "filmatisera",
    "filmatiserads": "filmatisera",
    "filmatiserande": "filmatisera",
    "filmatiseranden": "filmatiserande",
    "filmatiserandena": "filmatiserande",
    "filmatiserandenas": "filmatiserande",
    "filmatiserandens": "filmatiserande",
    "filmatiserandes": "filmatiserande",
    "filmatiserandet": "filmatiserande",
    "filmatiserandets": "filmatiserande",
    "filmatiserar": "filmatisera",
    "filmatiseras": "filmatisera",
    "filmatiserat": "filmatisera",
    "filmatiserats": "filmatisera",
    "filmatiserbara": "filmatiserbar",
    "filmatiserbarare": "filmatiserbar",
    "filmatiserbarares": "filmatiserbar",
    "filmatiserbaras": "filmatiserbar",
    "filmatiserbarast": "filmatiserbar",
    "filmatiserbaraste": "filmatiserbar",
    "filmatiserbarastes": "filmatiserbar",
    "filmatiserbarasts": "filmatiserbar",
    "filmatiserbare": "filmatiserbar",
    "filmatiserbares": "filmatiserbar",
    "filmatiserbarheten": "filmatiserbarhet",
    "filmatiserbarhetens": "filmatiserbarhet",
    "filmatiserbarhets": "filmatiserbarhet",
    "filmatiserbars": "filmatiserbar",
    "filmatiserbart": "filmatiserbar",
    "filmatiserbarts": "filmatiserbar",
    "filmatiseringar": "filmatisering",
    "filmatiseringarna": "filmatisering",
    "filmatiseringarnas": "filmatisering",
    "filmatiseringars": "filmatisering",
    "filmatiseringen": "filmatisering",
    "filmatiseringens": "filmatisering",
    "filmatiserings": "filmatisering",
    "filmatiska": "filmatisk",
    "filmatiskare": "filmatisk",
    "filmatiskares": "filmatisk",
    "filmatiskas": "filmatisk",
    "filmatiskast": "filmatisk",
    "filmatiskaste": "filmatisk",
    "filmatiskastes": "filmatisk",
    "filmatiskasts": "filmatisk",
    "filmatiske": "filmatisk",
    "filmatiskes": "filmatisk",
    "filmatisks": "filmatisk",
    "filmatiskt": "filmatisk",
    "filmatiskts": "filmatisk",
    "filmats": "filma",
    "filmavsnitten": "filmavsnitt",
    "filmavsnittens": "filmavsnitt",
    "filmavsnittet": "filmavsnitt",
    "filmavsnittets": "filmavsnitt",
    "filmavsnitts": "filmavsnitt",
    "filmbilden": "filmbild",
    "filmbildens": "filmbild",
    "filmbilder": "filmbild",
    "filmbilderna": "filmbild",
    "filmbildernas": "filmbild",
    "filmbilders": "filmbild",
    "filmbilds": "filmbild",
    "filmcensuren": "filmcensur",
    "filmcensurens": "filmcensur",
    "filmcensurs": "filmcensur",
    "filmdebuten": "filmdebut",
    "filmdebutens": "filmdebut",
    "filmdebuter": "filmdebut",
    "filmdebuterna": "filmdebut",
    "filmdebuternas": "filmdebut",
    "filmdebuters": "filmdebut",
    "filmdebuts": "filmdebut",
    "filmen": "film",
    "filmens": "film",
    "filmer": "film",
    "filmerna": "film",
    "filmernas": "film",
    "filmers": "film",
    "filmexperten": "filmexpert",
    "filmexpertens": "filmexpert",
    "filmexperter": "filmexpert",
    "filmexperterna": "filmexpert",
    "filmexperternas": "filmexpert",
    "filmexperters": "filmexpert",
    "filmexperts": "filmexpert",
    "filmfarsen": "filmfars",
    "filmfarsens": "filmfars",
    "filmfarser": "filmfars",
    "filmfarserna": "filmfars",
    "filmfarsernas": "filmfars",
    "filmfarsers": "filmfars",
    "filmfestivalen": "filmfestival",
    "filmfestivalens": "filmfestival",
    "filmfestivaler": "filmfestival",
    "filmfestivalerna": "filmfestival",
    "filmfestivalernas": "filmfestival",
    "filmfestivalers": "filmfestival",
    "filmfestivals": "filmfestival",
    "filmfotografen": "filmfotograf",
    "filmfotografens": "filmfotograf",
    "filmfotografer": "filmfotograf",
    "filmfotograferna": "filmfotograf",
    "filmfotografernas": "filmfotograf",
    "filmfotografers": "filmfotograf",
    "filmfotografs": "filmfotograf",
    "filmframkallningar": "filmframkallning",
    "filmframkallningarna": "filmframkallning",
    "filmframkallningarnas": "filmframkallning",
    "filmframkallningars": "filmframkallning",
    "filmframkallningen": "filmframkallning",
    "filmframkallningens": "filmframkallning",
    "filmframkallnings": "filmframkallning",
    "filmgranskningar": "filmgranskning",
    "filmgranskningarna": "filmgranskning",
    "filmgranskningarnas": "filmgranskning",
    "filmgranskningars": "filmgranskning",
    "filmgranskningen": "filmgranskning",
    "filmgranskningens": "filmgranskning",
    "filmgransknings": "filmgranskning",
    "filmhistorian": "filmhistoria",
    "filmhistorians": "filmhistoria",
    "filmhistorias": "filmhistoria",
    "filmhistorien": "filmhistoria",
    "filmhistoriens": "filmhistoria",
    "filmhistorier": "filmhistoria",
    "filmhistorierna": "filmhistoria",
    "filmhistoriernas": "filmhistoria",
    "filmhistoriers": "filmhistoria",
    "filminspelningar": "filminspelning",
    "filminspelningarna": "filminspelning",
    "filminspelningarnas": "filminspelning",
    "filminspelningars": "filminspelning",
    "filminspelningen": "filminspelning",
    "filminspelningens": "filminspelning",
    "filminspelnings": "filminspelning",
    "filmintresserade": "filmintresserad",
    "filmintresserades": "filmintresserad",
    "filmintresserads": "filmintresserad",
    "filmintresserat": "filmintresserad",
    "filmintresserats": "filmintresserad",
    "filmiska": "filmisk",
    "filmiskare": "filmisk",
    "filmiskares": "filmisk",
    "filmiskas": "filmisk",
    "filmiskast": "filmisk",
    "filmiskaste": "filmisk",
    "filmiskastes": "filmisk",
    "filmiskasts": "filmisk",
    "filmiske": "filmisk",
    "filmiskes": "filmisk",
    "filmisks": "filmisk",
    "filmiskt": "filmisk",
    "filmiskts": "filmisk",
    "filmjölken": "filmjölk",
    "filmjölkens": "filmjölk",
    "filmjölks": "filmjölk",
    "filmkameran": "filmkamera",
    "filmkamerans": "filmkamera",
    "filmkameras": "filmkamera",
    "filmkameror": "filmkamera",
    "filmkamerorna": "filmkamera",
    "filmkamerornas": "filmkamera",
    "filmkamerors": "filmkamera",
    "filmklippen": "filmklipp",
    "filmklippens": "filmklipp",
    "filmklippet": "filmklipp",
    "filmklippets": "filmklipp",
    "filmklippningar": "filmklippning",
    "filmklippningarna": "filmklippning",
    "filmklippningarnas": "filmklippning",
    "filmklippningars": "filmklippning",
    "filmklippningen": "filmklippning",
    "filmklippningens": "filmklippning",
    "filmklippnings": "filmklippning",
    "filmklipps": "filmklipp",
    "filmkomedien": "filmkomedi",
    "filmkomediens": "filmkomedi",
    "filmkomedier": "filmkomedi",
    "filmkomedierna": "filmkomedi",
    "filmkomediernas": "filmkomedi",
    "filmkomediers": "filmkomedi",
    "filmkomedin": "filmkomedi",
    "filmkomedins": "filmkomedi",
    "filmkomedis": "filmkomedi",
    "filmmanuskripten": "filmmanuskript",
    "filmmanuskriptens": "filmmanuskript",
    "filmmanuskriptet": "filmmanuskript",
    "filmmanuskriptets": "filmmanuskript",
    "filmmanuskripts": "filmmanuskript",
    "filmmusiken": "filmmusik",
    "filmmusikens": "filmmusik",
    "filmmusiks": "filmmusik",
    "filmmässiga": "filmmässig",
    "filmmässigare": "filmmässig",
    "filmmässigares": "filmmässig",
    "filmmässigas": "filmmässig",
    "filmmässigast": "filmmässig",
    "filmmässigaste": "filmmässig",
    "filmmässigastes": "filmmässig",
    "filmmässigasts": "filmmässig",
    "filmmässige": "filmmässig",
    "filmmässiges": "filmmässig",
    "filmmässigs": "filmmässig",
    "filmmässigt": "filmmässig",
    "filmmässigts": "filmmässig",
    "filmningar": "filmning",
    "filmningarna": "filmning",
    "filmningarnas": "filmning",
    "filmningars": "filmning",
    "filmningen": "filmning",
    "filmningens": "filmning",
    "filmnings": "filmning",
    "filmoteken": "filmotek",
    "filmotekens": "filmotek",
    "filmoteket": "filmotek",
    "filmotekets": "filmotek",
    "filmoteks": "filmotek",
    "filmpremiären": "filmpremiär",
    "filmpremiärens": "filmpremiär",
    "filmpremiärer": "filmpremiär",
    "filmpremiärerna": "filmpremiär",
    "filmpremiärernas": "filmpremiär",
    "filmpremiärers": "filmpremiär",
    "filmpremiärs": "filmpremiär",
    "filmproducenten": "filmproducent",
    "filmproducentens": "filmproducent",
    "filmproducenter": "filmproducent",
    "filmproducenterna": "filmproducent",
    "filmproducenternas": "filmproducent",
    "filmproducenters": "filmproducent",
    "filmproducents": "filmproducent",
    "filmprofessoren": "filmprofessor",
    "filmprofessorens": "filmprofessor",
    "filmprofessorer": "filmprofessor",
    "filmprofessorerna": "filmprofessor",
    "filmprofessorernas": "filmprofessor",
    "filmprofessorers": "filmprofessor",
    "filmprofessors": "filmprofessor",
    "filmregissören": "filmregissör",
    "filmregissörens": "filmregissör",
    "filmregissörer": "filmregissör",
    "filmregissörerna": "filmregissör",
    "filmregissörernas": "filmregissör",
    "filmregissörers": "filmregissör",
    "filmregissörs": "filmregissör",
    "filmrull": "filmrulle",
    "filmrullar": "filmrulle",
    "filmrullarna": "filmrulle",
    "filmrullarnas": "filmrulle",
    "filmrullars": "filmrulle",
    "filmrullen": "filmrulle",
    "filmrullens": "filmrulle",
    "filmrulles": "filmrulle",
    "filmrulls": "filmrulle",
    "films": "film",
    "filmscenen": "filmscen",
    "filmscenens": "filmscen",
    "filmscener": "filmscen",
    "filmscenerna": "filmscen",
    "filmscenernas": "filmscen",
    "filmsceners": "filmscen",
    "filmscens": "filmscen",
    "filmskapar": "filmskapare",
    "filmskaparen": "filmskapare",
    "filmskaparens": "filmskapare",
    "filmskapares": "filmskapare",
    "filmskaparna": "filmskapare",
    "filmskaparnas": "filmskapare",
    "filmskådespelar": "filmskådespelare",
    "filmskådespelaren": "filmskådespelare",
    "filmskådespelarens": "filmskådespelare",
    "filmskådespelares": "filmskådespelare",
    "filmskådespelarna": "filmskådespelare",
    "filmskådespelarnas": "filmskådespelare",
    "filmsnuttar": "filmsnutt",
    "filmsnuttarna": "filmsnutt",
    "filmsnuttarnas": "filmsnutt",
    "filmsnuttars": "filmsnutt",
    "filmsnutten": "filmsnutt",
    "filmsnuttens": "filmsnutt",
    "filmsnutts": "filmsnutt",
    "filmstjärnan": "filmstjärna",
    "filmstjärnans": "filmstjärna",
    "filmstjärnas": "filmstjärna",
    "filmstjärne": "filmstjärna",
    "filmstjärnor": "filmstjärna",
    "filmstjärnorna": "filmstjärna",
    "filmstjärnornas": "filmstjärna",
    "filmstjärnors": "filmstjärna",
    "filmstudion": "filmstudio",
    "filmstudions": "filmstudio",
    "filmstudior": "filmstudio",
    "filmstudiorna": "filmstudio",
    "filmstudiornas": "filmstudio",
    "filmstudiors": "filmstudio",
    "filmstudios": "filmstudio",
    "filmtecknar": "filmtecknare",
    "filmtecknaren": "filmtecknare",
    "filmtecknarens": "filmtecknare",
    "filmtecknares": "filmtecknare",
    "filmtecknarna": "filmtecknare",
    "filmtecknarnas": "filmtecknare",
    "filmtidskriften": "filmtidskrift",
    "filmtidskriftens": "filmtidskrift",
    "filmtidskrifter": "filmtidskrift",
    "filmtidskrifterna": "filmtidskrift",
    "filmtidskrifternas": "filmtidskrift",
    "filmtidskrifters": "filmtidskrift",
    "filmtidskrifts": "filmtidskrift",
    "filmvetenskapen": "filmvetenskap",
    "filmvetenskapens": "filmvetenskap",
    "filmvetenskaper": "filmvetenskap",
    "filmvetenskaperna": "filmvetenskap",
    "filmvetenskapernas": "filmvetenskap",
    "filmvetenskapers": "filmvetenskap",
    "filmvetenskaps": "filmvetenskap",
    "filologen": "filolog",
    "filologens": "filolog",
    "filologer": "filolog",
    "filologerna": "filolog",
    "filologernas": "filolog",
    "filologers": "filolog",
    "filologien": "filologi",
    "filologiens": "filologi",
    "filologier": "filologi",
    "filologierna": "filologi",
    "filologiernas": "filologi",
    "filologiers": "filologi",
    "filologin": "filologi",
    "filologins": "filologi",
    "filologis": "filologi",
    "filologiska": "filologisk",
    "filologiskare": "filologisk",
    "filologiskares": "filologisk",
    "filologiskas": "filologisk",
    "filologiskast": "filologisk",
    "filologiskaste": "filologisk",
    "filologiskastes": "filologisk",
    "filologiskasts": "filologisk",
    "filologiske": "filologisk",
    "filologiskes": "filologisk",
    "filologisks": "filologisk",
    "filologiskt": "filologisk",
    "filologiskts": "filologisk",
    "filologs": "filolog",
    "filosofemen": "filosofem",
    "filosofemens": "filosofem",
    "filosofemer": "filosofem",
    "filosofemerna": "filosofem",
    "filosofemernas": "filosofem",
    "filosofemers": "filosofem",
    "filosofemet": "filosofem",
    "filosofemets": "filosofem",
    "filosofems": "filosofem",
    "filosofen": "filosof",
    "filosofens": "filosof",
    "filosofer": "filosof",
    "filosoferade": "filosofera",
    "filosoferades": "filosofera",
    "filosoferande": "filosofera",
    "filosoferanden": "filosoferande",
    "filosoferandena": "filosoferande",
    "filosoferandenas": "filosoferande",
    "filosoferandens": "filosoferande",
    "filosoferandes": "filosoferande",
    "filosoferandet": "filosoferande",
    "filosoferandets": "filosoferande",
    "filosoferar": "filosofera",
    "filosoferas": "filosofera",
    "filosoferat": "filosofera",
    "filosoferats": "filosofera",
    "filosoferingar": "filosofering",
    "filosoferingarna": "filosofering",
    "filosoferingarnas": "filosofering",
    "filosoferingars": "filosofering",
    "filosoferingen": "filosofering",
    "filosoferingens": "filosofering",
    "filosoferings": "filosofering",
    "filosoferna": "filosof",
    "filosofernas": "filosof",
    "filosofers": "filosof",
    "filosofien": "filosofi",
    "filosofiens": "filosofi",
    "filosofier": "filosofi",
    "filosofierna": "filosofi",
    "filosofiernas": "filosofi",
    "filosofiers": "filosofi",
    "filosofilärar": "filosofilärare",
    "filosofiläraren": "filosofilärare",
    "filosofilärarens": "filosofilärare",
    "filosofilärares": "filosofilärare",
    "filosofilärarna": "filosofilärare",
    "filosofilärarnas": "filosofilärare",
    "filosofin": "filosofi",
    "filosofins": "filosofi",
    "filosofis": "filosofi",
    "filosofiska": "filosofisk",
    "filosofiskare": "filosofisk",
    "filosofiskares": "filosofisk",
    "filosofiskas": "filosofisk",
    "filosofiskast": "filosofisk",
    "filosofiskaste": "filosofisk",
    "filosofiskastes": "filosofisk",
    "filosofiskasts": "filosofisk",
    "filosofiske": "filosofisk",
    "filosofiskes": "filosofisk",
    "filosofisks": "filosofisk",
    "filosofiskt": "filosofisk",
    "filosofiskts": "filosofisk",
    "filosofkollegan": "filosofkollega",
    "filosofkollegans": "filosofkollega",
    "filosofkollegas": "filosofkollega",
    "filosofkolleger": "filosofkollega",
    "filosofkollegerna": "filosofkollega",
    "filosofkollegernas": "filosofkollega",
    "filosofkollegers": "filosofkollega",
    "filosofkollegor": "filosofkollega",
    "filosofkollegorna": "filosofkollega",
    "filosofkollegornas": "filosofkollega",
    "filosofkollegors": "filosofkollega",
    "filosofs": "filosof",
    "fils": "fil",
    "filspånen": "filspån",
    "filspånens": "filspån",
    "filspånet": "filspån",
    "filspånets": "filspån",
    "filspåns": "filspån",
    "filt": "filta",
    "filtad": "filta",
    "filtade": "filta",
    "filtades": "filta",
    "filtads": "filta",
    "filtande": "filta",
    "filtanden": "filtande",
    "filtandena": "filtande",
    "filtandenas": "filtande",
    "filtandens": "filtande",
    "filtandes": "filtande",
    "filtandet": "filtande",
    "filtandets": "filtande",
    "filtar": "filta",
    "filtarna": "filt",
    "filtarnas": "filt",
    "filtars": "filt",
    "filtas": "filta",
    "filtat": "filta",
    "filtats": "filta",
    "filten": "filt",
    "filtens": "filt",
    "filtercigaretten": "filtercigarett",
    "filtercigarettens": "filtercigarett",
    "filtercigaretter": "filtercigarett",
    "filtercigaretterna": "filtercigarett",
    "filtercigaretternas": "filtercigarett",
    "filtercigaretters": "filtercigarett",
    "filtercigaretts": "filtercigarett",
    "filterluddet": "filterludd",
    "filterluddets": "filterludd",
    "filterludds": "filterludd",
    "filterna": "filter",
    "filternas": "filter",
    "filterpås": "filterpåse",
    "filterpåsar": "filterpåse",
    "filterpåsarna": "filterpåse",
    "filterpåsarnas": "filterpåse",
    "filterpåsars": "filterpåse",
    "filterpåsen": "filterpåse",
    "filterpåsens": "filterpåse",
    "filterpåses": "filterpåse",
    "filters": "filter",
    "filtraten": "filtrat",
    "filtratens": "filtrat",
    "filtratet": "filtrat",
    "filtratets": "filtrat",
    "filtrats": "filtrat",
    "filtren": "filter",
    "filtrens": "filter",
    "filtrerad": "filtrera",
    "filtrerade": "filtrera",
    "filtrerades": "filtrera",
    "filtrerads": "filtrera",
    "filtrerande": "filtrera",
    "filtreranden": "filtrerande",
    "filtrerandena": "filtrerande",
    "filtrerandenas": "filtrerande",
    "filtrerandens": "filtrerande",
    "filtrerandes": "filtrerande",
    "filtrerandet": "filtrerande",
    "filtrerandets": "filtrerande",
    "filtrerar": "filtrera",
    "filtreras": "filtrera",
    "filtrerat": "filtrera",
    "filtrerats": "filtrera",
    "filtrerbara": "filtrerbar",
    "filtrerbarare": "filtrerbar",
    "filtrerbarares": "filtrerbar",
    "filtrerbaras": "filtrerbar",
    "filtrerbarast": "filtrerbar",
    "filtrerbaraste": "filtrerbar",
    "filtrerbarastes": "filtrerbar",
    "filtrerbarasts": "filtrerbar",
    "filtrerbare": "filtrerbar",
    "filtrerbares": "filtrerbar",
    "filtrerbarheten": "filtrerbarhet",
    "filtrerbarhetens": "filtrerbarhet",
    "filtrerbarhets": "filtrerbarhet",
    "filtrerbars": "filtrerbar",
    "filtrerbart": "filtrerbar",
    "filtrerbarts": "filtrerbar",
    "filtreringar": "filtrering",
    "filtreringarna": "filtrering",
    "filtreringarnas": "filtrering",
    "filtreringars": "filtrering",
    "filtreringen": "filtrering",
    "filtreringens": "filtrering",
    "filtrerings": "filtrering",
    "filtrerpapperen": "filtrerpapper",
    "filtrerpapperens": "filtrerpapper",
    "filtrerpapperet": "filtrerpapper",
    "filtrerpapperets": "filtrerpapper",
    "filtrerpapperna": "filtrerpapper",
    "filtrerpappernas": "filtrerpapper",
    "filtrerpappers": "filtrerpapper",
    "filtrerpappren": "filtrerpapper",
    "filtrerpapprens": "filtrerpapper",
    "filtrerpappret": "filtrerpapper",
    "filtrerpapprets": "filtrerpapper",
    "filtret": "filter",
    "filtrets": "filter",
    "filts": "filt",
    "filtspetsar": "filtspets",
    "filtspetsarna": "filtspets",
    "filtspetsarnas": "filtspets",
    "filtspetsars": "filtspets",
    "filtspetsen": "filtspets",
    "filtspetsens": "filtspets",
    "filttoffeln": "filttoffel",
    "filttoffelns": "filttoffel",
    "filttoffels": "filttoffel",
    "filttoffla": "filttoffel",
    "filttofflan": "filttoffel",
    "filttofflans": "filttoffel",
    "filttofflas": "filttoffel",
    "filttoffle": "filttoffel",
    "filttofflor": "filttoffel",
    "filttofflorna": "filttoffel",
    "filttofflornas": "filttoffel",
    "filttofflors": "filttoffel",
    "filttomtar": "filttomte",
    "filttomtarna": "filttomte",
    "filttomtarnas": "filttomte",
    "filttomtars": "filttomte",
    "filttomten": "filttomte",
    "filttomtens": "filttomte",
    "filttomtes": "filttomte",
    "filuren": "filur",
    "filurens": "filur",
    "filurer": "filur",
    "filurerna": "filur",
    "filurernas": "filur",
    "filurers": "filur",
    "filurs": "filur",
    "filéer": "filé",
    "filéerna": "filé",
    "filéernas": "filé",
    "filéers": "filé",
    "filén": "filé",
    "filéns": "filé",
    "filés": "filé",
    "fimbulvintern": "fimbulvinter",
    "fimbulvinterns": "fimbulvinter",
    "fimbulvinters": "fimbulvinter",
    "fimbulvintrar": "fimbulvinter",
    "fimbulvintrarna": "fimbulvinter",
    "fimbulvintrarnas": "fimbulvinter",
    "fimbulvintrars": "fimbulvinter",
    "fimmelstänger": "fimmelstång",
    "fimmelstängerna": "fimmelstång",
    "fimmelstängernas": "fimmelstång",
    "fimmelstängers": "fimmelstång",
    "fimmelstången": "fimmelstång",
    "fimmelstångens": "fimmelstång",
    "fimmelstångs": "fimmelstång",
    "fimmerstänger": "fimmerstång",
    "fimmerstängerna": "fimmerstång",
    "fimmerstängernas": "fimmerstång",
    "fimmerstängers": "fimmerstång",
    "fimmerstången": "fimmerstång",
    "fimmerstångens": "fimmerstång",
    "fimmerstångs": "fimmerstång",
    "fimp": "fimpa",
    "fimpad": "fimpa",
    "fimpade": "fimpa",
    "fimpades": "fimpa",
    "fimpads": "fimpa",
    "fimpande": "fimpa",
    "fimpanden": "fimpande",
    "fimpandena": "fimpande",
    "fimpandenas": "fimpande",
    "fimpandens": "fimpande",
    "fimpandes": "fimpande",
    "fimpandet": "fimpande",
    "fimpandets": "fimpande",
    "fimpar": "fimpa",
    "fimparna": "fimp",
    "fimparnas": "fimp",
    "fimpars": "fimp",
    "fimpas": "fimpa",
    "fimpat": "fimpa",
    "fimpats": "fimpa",
    "fimpen": "fimp",
    "fimpens": "fimp",
    "fimps": "fimp",
    "fimpsugar": "fimpsug",
    "fimpsugarna": "fimpsug",
    "fimpsugarnas": "fimpsug",
    "fimpsugars": "fimpsug",
    "fimpsugen": "fimpsug",
    "fimpsugens": "fimpsug",
    "fimpsugs": "fimpsug",
    "fin": "fi",
    "fina": "fin",
    "finala": "final",
    "finalare": "final",
    "finalares": "final",
    "finalas": "final",
    "finalast": "final",
    "finalaste": "final",
    "finalastes": "final",
    "finalasts": "final",
    "finale": "final",
    "finalen": "final",
    "finalens": "final",
    "finaler": "final",
    "finalerna": "final",
    "finalernas": "final",
    "finalers": "final",
    "finales": "final",
    "finalisten": "finalist",
    "finalistens": "finalist",
    "finalister": "finalist",
    "finalisterna": "finalist",
    "finalisternas": "finalist",
    "finalisters": "finalist",
    "finalists": "finalist",
    "finalklara": "finalklar",
    "finalklarare": "finalklar",
    "finalklarares": "finalklar",
    "finalklaras": "finalklar",
    "finalklarast": "finalklar",
    "finalklaraste": "finalklar",
    "finalklarastes": "finalklar",
    "finalklarasts": "finalklar",
    "finalklare": "finalklar",
    "finalklares": "finalklar",
    "finalklars": "finalklar",
    "finalklart": "finalklar",
    "finalklarts": "finalklar",
    "finalplatsen": "finalplats",
    "finalplatsens": "finalplats",
    "finalplatser": "finalplats",
    "finalplatserna": "finalplats",
    "finalplatsernas": "finalplats",
    "finalplatsers": "finalplats",
    "finals": "final",
    "finalt": "final",
    "finalts": "final",
    "finans": "finanser",
    "finanschefen": "finanschef",
    "finanschefens": "finanschef",
    "finanschefer": "finanschef",
    "finanscheferna": "finanschef",
    "finanschefernas": "finanschef",
    "finanschefers": "finanschef",
    "finanschefs": "finanschef",
    "finansdebatten": "finansdebatt",
    "finansdebattens": "finansdebatt",
    "finansdebatter": "finansdebatt",
    "finansdebatterna": "finansdebatt",
    "finansdebatternas": "finansdebatt",
    "finansdebatters": "finansdebatt",
    "finansdebatts": "finansdebatt",
    "finansdepartementen": "finansdepartement",
    "finansdepartementens": "finansdepartement",
    "finansdepartementet": "finansdepartement",
    "finansdepartementets": "finansdepartement",
    "finansdepartements": "finansdepartement",
    "finanserna": "finanser",
    "finansernas": "finanser",
    "finansers": "finanser",
    "finansiella": "finansiell",
    "finansiellare": "finansiell",
    "finansiellares": "finansiell",
    "finansiellas": "finansiell",
    "finansiellast": "finansiell",
    "finansiellaste": "finansiell",
    "finansiellastes": "finansiell",
    "finansiellasts": "finansiell",
    "finansielle": "finansiell",
    "finansielles": "finansiell",
    "finansiells": "finansiell",
    "finansiellt": "finansiell",
    "finansiellts": "finansiell",
    "finansierad": "finansiera",
    "finansierade": "finansiera",
    "finansierades": "finansiera",
    "finansierads": "finansiera",
    "finansierande": "finansiera",
    "finansieranden": "finansierande",
    "finansierandena": "finansierande",
    "finansierandenas": "finansierande",
    "finansierandens": "finansierande",
    "finansierandes": "finansierande",
    "finansierandet": "finansierande",
    "finansierandets": "finansierande",
    "finansierar": "finansiera",
    "finansieras": "finansiera",
    "finansierat": "finansiera",
    "finansierats": "finansiera",
    "finansierbara": "finansierbar",
    "finansierbarare": "finansierbar",
    "finansierbarares": "finansierbar",
    "finansierbaras": "finansierbar",
    "finansierbarast": "finansierbar",
    "finansierbaraste": "finansierbar",
    "finansierbarastes": "finansierbar",
    "finansierbarasts": "finansierbar",
    "finansierbare": "finansierbar",
    "finansierbares": "finansierbar",
    "finansierbarheten": "finansierbarhet",
    "finansierbarhetens": "finansierbarhet",
    "finansierbarhets": "finansierbarhet",
    "finansierbars": "finansierbar",
    "finansierbart": "finansierbar",
    "finansierbarts": "finansierbar",
    "finansieringar": "finansiering",
    "finansieringarna": "finansiering",
    "finansieringarnas": "finansiering",
    "finansieringars": "finansiering",
    "finansieringen": "finansiering",
    "finansieringens": "finansiering",
    "finansierings": "finansiering",
    "finansinspektionen": "finansinspektion",
    "finansinspektionens": "finansinspektion",
    "finansinspektioner": "finansinspektion",
    "finansinspektionerna": "finansinspektion",
    "finansinspektionernas": "finansinspektion",
    "finansinspektioners": "finansinspektion",
    "finansinspektions": "finansinspektion",
    "finansiären": "finansiär",
    "finansiärens": "finansiär",
    "finansiärer": "finansiär",
    "finansiärerna": "finansiär",
    "finansiärernas": "finansiär",
    "finansiärers": "finansiär",
    "finansiärs": "finansiär",
    "finanskraschen": "finanskrasch",
    "finanskraschens": "finanskrasch",
    "finanskrascher": "finanskrasch",
    "finanskrascherna": "finanskrasch",
    "finanskraschernas": "finanskrasch",
    "finanskraschers": "finanskrasch",
    "finanskraschs": "finanskrasch",
    "finanskrisen": "finanskris",
    "finanskrisens": "finanskris",
    "finanskriser": "finanskris",
    "finanskriserna": "finanskris",
    "finanskrisernas": "finanskris",
    "finanskrisers": "finanskris",
    "finansmannen": "finansman",
    "finansmannens": "finansman",
    "finansmans": "finansman",
    "finansmarknaden": "finansmarknad",
    "finansmarknadens": "finansmarknad",
    "finansmarknader": "finansmarknad",
    "finansmarknaderna": "finansmarknad",
    "finansmarknadernas": "finansmarknad",
    "finansmarknaders": "finansmarknad",
    "finansmarknads": "finansmarknad",
    "finansministern": "finansminister",
    "finansministerns": "finansminister",
    "finansministers": "finansminister",
    "finansministrar": "finansminister",
    "finansministrarna": "finansminister",
    "finansministrarnas": "finansminister",
    "finansministrars": "finansminister",
    "finansmän": "finansman",
    "finansmännen": "finansman",
    "finansmännens": "finansman",
    "finansmäns": "finansman",
    "finansplane": "finansplan",
    "finansplanen": "finansplan",
    "finansplanens": "finansplan",
    "finansplaner": "finansplan",
    "finansplanerna": "finansplan",
    "finansplanernas": "finansplan",
    "finansplaners": "finansplan",
    "finansplans": "finansplan",
    "finanspolitiken": "finanspolitik",
    "finanspolitikens": "finanspolitik",
    "finanspolitiks": "finanspolitik",
    "finanspolitiska": "finanspolitisk",
    "finanspolitiskas": "finanspolitisk",
    "finanspolitiske": "finanspolitisk",
    "finanspolitiskes": "finanspolitisk",
    "finanspolitisks": "finanspolitisk",
    "finanspolitiskt": "finanspolitisk",
    "finanspolitiskts": "finanspolitisk",
    "finansrätten": "finansrätt",
    "finansrättens": "finansrätt",
    "finansrätts": "finansrätt",
    "finansvalpar": "finansvalp",
    "finansvalparna": "finansvalp",
    "finansvalparnas": "finansvalp",
    "finansvalpars": "finansvalp",
    "finansvalpen": "finansvalp",
    "finansvalpens": "finansvalp",
    "finansvalps": "finansvalp",
    "finare": "fin",
    "finares": "fin",
    "finas": "fin",
    "finast": "fin",
    "finaste": "fin",
    "finastes": "fin",
    "finasts": "fin",
    "finbruken": "finbruk",
    "finbrukens": "finbruk",
    "finbruket": "finbruk",
    "finbrukets": "finbruk",
    "finbruks": "finbruk",
    "finbränd": "finbränna",
    "finbrända": "finbränna",
    "finbrändas": "finbränna",
    "finbrände": "finbränna",
    "finbrändes": "finbränna",
    "finbränds": "finbränna",
    "finbränn": "finbränna",
    "finbrännande": "finbränna",
    "finbrännanden": "finbrännande",
    "finbrännandena": "finbrännande",
    "finbrännandenas": "finbrännande",
    "finbrännandens": "finbrännande",
    "finbrännandes": "finbrännande",
    "finbrännandet": "finbrännande",
    "finbrännandets": "finbrännande",
    "finbrännas": "finbränna",
    "finbränner": "finbränna",
    "finbrännes": "finbränna",
    "finbränns": "finbränna",
    "finbränt": "finbränna",
    "finbränts": "finbränna",
    "fine": "fin",
    "fines": "fin",
    "finessen": "finess",
    "finessens": "finess",
    "finesser": "finess",
    "finesserna": "finess",
    "finessernas": "finess",
    "finessers": "finess",
    "finfina": "finfin",
    "finfinare": "finfin",
    "finfinares": "finfin",
    "finfinas": "finfin",
    "finfinast": "finfin",
    "finfinaste": "finfin",
    "finfinastes": "finfin",
    "finfinasts": "finfin",
    "finfine": "finfin",
    "finfines": "finfin",
    "finfins": "finfin",
    "finfint": "finfin",
    "finfints": "finfin",
    "finfördel": "finfördela",
    "finfördelad": "finfördela",
    "finfördelade": "finfördela",
    "finfördelades": "finfördela",
    "finfördelads": "finfördela",
    "finfördelande": "finfördela",
    "finfördelanden": "finfördelande",
    "finfördelandena": "finfördelande",
    "finfördelandenas": "finfördelande",
    "finfördelandens": "finfördelande",
    "finfördelandes": "finfördelande",
    "finfördelandet": "finfördelande",
    "finfördelandets": "finfördelande",
    "finfördelar": "finfördela",
    "finfördelas": "finfördela",
    "finfördelat": "finfördela",
    "finfördelats": "finfördela",
    "finge": "få",
    "fingerad": "fingera",
    "fingerade": "fingerad",
    "fingerades": "fingerad",
    "fingerads": "fingerad",
    "fingerande": "fingera",
    "fingeranden": "fingerande",
    "fingerandena": "fingerande",
    "fingerandenas": "fingerande",
    "fingerandens": "fingerande",
    "fingerandes": "fingerande",
    "fingerandet": "fingerande",
    "fingerandets": "fingerande",
    "fingerar": "fingera",
    "fingeras": "fingera",
    "fingerat": "fingerad",
    "fingerats": "fingerad",
    "fingeravtrycken": "fingeravtryck",
    "fingeravtryckens": "fingeravtryck",
    "fingeravtrycket": "fingeravtryck",
    "fingeravtryckets": "fingeravtryck",
    "fingeravtrycks": "fingeravtryck",
    "fingerbara": "fingerbar",
    "fingerbarare": "fingerbar",
    "fingerbarares": "fingerbar",
    "fingerbaras": "fingerbar",
    "fingerbarast": "fingerbar",
    "fingerbaraste": "fingerbar",
    "fingerbarastes": "fingerbar",
    "fingerbarasts": "fingerbar",
    "fingerbare": "fingerbar",
    "fingerbares": "fingerbar",
    "fingerbarheten": "fingerbarhet",
    "fingerbarhetens": "fingerbarhet",
    "fingerbarhets": "fingerbarhet",
    "fingerbars": "fingerbar",
    "fingerbart": "fingerbar",
    "fingerbarts": "fingerbar",
    "fingerblom": "fingerblomma",
    "fingerblomman": "fingerblomma",
    "fingerblommans": "fingerblomma",
    "fingerblommas": "fingerblomma",
    "fingerblomme": "fingerblomma",
    "fingerblommor": "fingerblomma",
    "fingerblommorna": "fingerblomma",
    "fingerblommornas": "fingerblomma",
    "fingerblommors": "fingerblomma",
    "fingerbloms": "fingerblomma",
    "fingerborgar": "fingerborg",
    "fingerborgarna": "fingerborg",
    "fingerborgarnas": "fingerborg",
    "fingerborgars": "fingerborg",
    "fingerborgen": "fingerborg",
    "fingerborgens": "fingerborg",
    "fingerborgs": "fingerborg",
    "fingerborgsblom": "fingerborgsblomma",
    "fingerborgsblomman": "fingerborgsblomma",
    "fingerborgsblommans": "fingerborgsblomma",
    "fingerborgsblommas": "fingerborgsblomma",
    "fingerborgsblomme": "fingerborgsblomma",
    "fingerborgsblommor": "fingerborgsblomma",
    "fingerborgsblommorna": "fingerborgsblomma",
    "fingerborgsblommornas": "fingerborgsblomma",
    "fingerborgsblommors": "fingerborgsblomma",
    "fingerborgsbloms": "fingerborgsblomma",
    "fingerböjarmuskeln": "fingerböjarmuskel",
    "fingerböjarmuskelns": "fingerböjarmuskel",
    "fingerböjarmuskels": "fingerböjarmuskel",
    "fingerböjarmuskler": "fingerböjarmuskel",
    "fingerböjarmusklerna": "fingerböjarmuskel",
    "fingerböjarmusklernas": "fingerböjarmuskel",
    "fingerböjarmusklers": "fingerböjarmuskel",
    "fingerfärdiga": "fingerfärdig",
    "fingerfärdigare": "fingerfärdig",
    "fingerfärdigares": "fingerfärdig",
    "fingerfärdigas": "fingerfärdig",
    "fingerfärdigast": "fingerfärdig",
    "fingerfärdigaste": "fingerfärdig",
    "fingerfärdigastes": "fingerfärdig",
    "fingerfärdigasts": "fingerfärdig",
    "fingerfärdige": "fingerfärdig",
    "fingerfärdiges": "fingerfärdig",
    "fingerfärdigheten": "fingerfärdighet",
    "fingerfärdighetens": "fingerfärdighet",
    "fingerfärdighets": "fingerfärdighet",
    "fingerfärdigs": "fingerfärdig",
    "fingerfärdigt": "fingerfärdig",
    "fingerfärdigts": "fingerfärdig",
    "fingerfärgen": "fingerfärg",
    "fingerfärgens": "fingerfärg",
    "fingerfärger": "fingerfärg",
    "fingerfärgerna": "fingerfärg",
    "fingerfärgernas": "fingerfärg",
    "fingerfärgers": "fingerfärg",
    "fingerfärgs": "fingerfärg",
    "fingerhudar": "fingerhud",
    "fingerhudarna": "fingerhud",
    "fingerhudarnas": "fingerhud",
    "fingerhudars": "fingerhud",
    "fingerhuden": "fingerhud",
    "fingerhudens": "fingerhud",
    "fingerhuds": "fingerhud",
    "fingeringar": "fingering",
    "fingeringarna": "fingering",
    "fingeringarnas": "fingering",
    "fingeringars": "fingering",
    "fingeringen": "fingering",
    "fingeringens": "fingering",
    "fingerings": "fingering",
    "fingerkroken": "fingerkrok",
    "fingerkrokens": "fingerkrok",
    "fingerkroks": "fingerkrok",
    "fingerleden": "fingerled",
    "fingerledens": "fingerled",
    "fingerleder": "fingerled",
    "fingerlederna": "fingerled",
    "fingerledernas": "fingerled",
    "fingerleders": "fingerled",
    "fingerleds": "fingerled",
    "fingern": "finger",
    "fingernageln": "fingernagel",
    "fingernagelns": "fingernagel",
    "fingernagels": "fingernagel",
    "fingernaglar": "fingernagel",
    "fingernaglarna": "fingernagel",
    "fingernaglarnas": "fingernagel",
    "fingernaglars": "fingernagel",
    "fingernerven": "fingernerv",
    "fingernervens": "fingernerv",
    "fingernerver": "fingernerv",
    "fingernerverna": "fingernerv",
    "fingernervernas": "fingernerv",
    "fingernervers": "fingernerv",
    "fingernervs": "fingernerv",
    "fingerns": "finger",
    "fingerproven": "fingerprov",
    "fingerprovens": "fingerprov",
    "fingerprovet": "fingerprov",
    "fingerprovets": "fingerprov",
    "fingerprovs": "fingerprov",
    "fingerringar": "fingerring",
    "fingerringarna": "fingerring",
    "fingerringarnas": "fingerring",
    "fingerringars": "fingerring",
    "fingerringen": "fingerring",
    "fingerringens": "fingerring",
    "fingerrings": "fingerring",
    "fingers": "finger",
    "fingerskivan": "fingerskiva",
    "fingerskivans": "fingerskiva",
    "fingerskivas": "fingerskiva",
    "fingerskive": "fingerskiva",
    "fingerskivor": "fingerskiva",
    "fingerskivorna": "fingerskiva",
    "fingerskivornas": "fingerskiva",
    "fingerskivors": "fingerskiva",
    "fingersträckarmuskeln": "fingersträckarmuskel",
    "fingersträckarmuskelns": "fingersträckarmuskel",
    "fingersträckarmuskels": "fingersträckarmuskel",
    "fingersträckarmuskler": "fingersträckarmuskel",
    "fingersträckarmusklerna": "fingersträckarmuskel",
    "fingersträckarmusklernas": "fingersträckarmuskel",
    "fingersträckarmusklers": "fingersträckarmuskel",
    "fingersvampar": "fingersvamp",
    "fingersvamparna": "fingersvamp",
    "fingersvamparnas": "fingersvamp",
    "fingersvampars": "fingersvamp",
    "fingersvampen": "fingersvamp",
    "fingersvampens": "fingersvamp",
    "fingersvamps": "fingersvamp",
    "fingersättningar": "fingersättning",
    "fingersättningarna": "fingersättning",
    "fingersättningarnas": "fingersättning",
    "fingersättningars": "fingersättning",
    "fingersättningen": "fingersättning",
    "fingersättningens": "fingersättning",
    "fingersättnings": "fingersättning",
    "fingertoppar": "fingertopp",
    "fingertopparna": "fingertopp",
    "fingertopparnas": "fingertopp",
    "fingertoppars": "fingertopp",
    "fingertoppen": "fingertopp",
    "fingertoppens": "fingertopp",
    "fingertopps": "fingertopp",
    "fingertoppskänslan": "fingertoppskänsla",
    "fingertoppskänslans": "fingertoppskänsla",
    "fingertoppskänslas": "fingertoppskänsla",
    "fingertoppskänsle": "fingertoppskänsla",
    "fingertoppskänslo": "fingertoppskänsla",
    "fingertoppsnyansen": "fingertoppsnyans",
    "fingertoppsnyansens": "fingertoppsnyans",
    "fingertoppsnyanser": "fingertoppsnyans",
    "fingertoppsnyanserna": "fingertoppsnyans",
    "fingertoppsnyansernas": "fingertoppsnyans",
    "fingertoppsnyansers": "fingertoppsnyans",
    "fingertut": "fingertuta",
    "fingertutan": "fingertuta",
    "fingertutans": "fingertuta",
    "fingertutas": "fingertuta",
    "fingertute": "fingertuta",
    "fingertutor": "fingertuta",
    "fingertutorna": "fingertuta",
    "fingertutornas": "fingertuta",
    "fingertutors": "fingertuta",
    "fingertuts": "fingertuta",
    "fingervant": "fingervante",
    "fingervantar": "fingervante",
    "fingervantarna": "fingervante",
    "fingervantarnas": "fingervante",
    "fingervantars": "fingervante",
    "fingervanten": "fingervante",
    "fingervantens": "fingervante",
    "fingervantes": "fingervante",
    "fingervants": "fingervante",
    "fingervisningar": "fingervisning",
    "fingervisningarna": "fingervisning",
    "fingervisningarnas": "fingervisning",
    "fingervisningars": "fingervisning",
    "fingervisningen": "fingervisning",
    "fingervisningens": "fingervisning",
    "fingervisnings": "fingervisning",
    "fingerörten": "fingerört",
    "fingerörtens": "fingerört",
    "fingerörter": "fingerört",
    "fingerörterna": "fingerört",
    "fingerörternas": "fingerört",
    "fingerörters": "fingerört",
    "fingerörts": "fingerört",
    "finges": "få",
    "fingrade": "fingrad",
    "fingraderade": "fingraderad",
    "fingraderades": "fingraderad",
    "fingraderads": "fingraderad",
    "fingraderat": "fingraderad",
    "fingraderats": "fingraderad",
    "fingrades": "fingrad",
    "fingrads": "fingrad",
    "fingrande": "fingra",
    "fingranden": "fingrande",
    "fingrandena": "fingrande",
    "fingrandenas": "fingrande",
    "fingrandens": "fingrande",
    "fingrandes": "fingrande",
    "fingrandet": "fingrande",
    "fingrandets": "fingrande",
    "fingranskad": "fingranska",
    "fingranskade": "fingranska",
    "fingranskades": "fingranska",
    "fingranskads": "fingranska",
    "fingranskande": "fingranska",
    "fingranskanden": "fingranskande",
    "fingranskandena": "fingranskande",
    "fingranskandenas": "fingranskande",
    "fingranskandens": "fingranskande",
    "fingranskandes": "fingranskande",
    "fingranskandet": "fingranskande",
    "fingranskandets": "fingranskande",
    "fingranskar": "fingranska",
    "fingranskas": "fingranska",
    "fingranskat": "fingranska",
    "fingranskats": "fingranska",
    "fingrar": "fingra",
    "fingrarna": "finger",
    "fingrarnas": "finger",
    "fingrars": "finger",
    "fingras": "fingra",
    "fingrat": "fingrad",
    "fingrats": "fingrad",
    "fingret": "finger",
    "fingrets": "finger",
    "finhackad": "finhacka",
    "finhackade": "finhackad",
    "finhackades": "finhackad",
    "finhackads": "finhackad",
    "finhackande": "finhacka",
    "finhackandes": "finhacka",
    "finhackar": "finhacka",
    "finhackas": "finhacka",
    "finhackat": "finhackad",
    "finhackats": "finhackad",
    "finheten": "finhet",
    "finhetens": "finhet",
    "finheter": "finhet",
    "finheterna": "finhet",
    "finheternas": "finhet",
    "finheters": "finhet",
    "finhets": "finhet",
    "finhyllta": "finhyllt",
    "finhylltare": "finhyllt",
    "finhylltares": "finhyllt",
    "finhylltas": "finhyllt",
    "finhylltast": "finhyllt",
    "finhylltaste": "finhyllt",
    "finhylltastes": "finhyllt",
    "finhylltasts": "finhyllt",
    "finhyllte": "finhyllt",
    "finhylltes": "finhyllt",
    "finhylltheten": "finhyllthet",
    "finhyllthetens": "finhyllthet",
    "finhyllthets": "finhyllthet",
    "finhyllts": "finhyllt",
    "finingångar": "finingång",
    "finingångarna": "finingång",
    "finingångarnas": "finingång",
    "finingångars": "finingång",
    "finingången": "finingång",
    "finingångens": "finingång",
    "finingångs": "finingång",
    "fininställ": "fininställa",
    "fininställande": "fininställa",
    "fininställanden": "fininställande",
    "fininställandena": "fininställande",
    "fininställandenas": "fininställande",
    "fininställandens": "fininställande",
    "fininställandes": "fininställande",
    "fininställandet": "fininställande",
    "fininställandets": "fininställande",
    "fininställas": "fininställa",
    "fininställd": "fininställa",
    "fininställda": "fininställa",
    "fininställdas": "fininställa",
    "fininställde": "fininställa",
    "fininställdes": "fininställa",
    "fininställds": "fininställa",
    "fininställer": "fininställa",
    "fininställes": "fininställa",
    "fininställs": "fininställa",
    "fininställt": "fininställa",
    "fininställts": "fininställa",
    "finishar": "finish",
    "finisharna": "finish",
    "finisharnas": "finish",
    "finishars": "finish",
    "finishen": "finish",
    "finishens": "finish",
    "finishs": "finish",
    "finita": "finit",
    "finitare": "finit",
    "finitares": "finit",
    "finitas": "finit",
    "finitast": "finit",
    "finitaste": "finit",
    "finitastes": "finit",
    "finitasts": "finit",
    "finite": "finit",
    "finites": "finit",
    "finits": "finit",
    "finjusterad": "finjustera",
    "finjusterade": "finjustera",
    "finjusterades": "finjustera",
    "finjusterads": "finjustera",
    "finjusterande": "finjustera",
    "finjusteranden": "finjusterande",
    "finjusterandena": "finjusterande",
    "finjusterandenas": "finjusterande",
    "finjusterandens": "finjusterande",
    "finjusterandes": "finjusterande",
    "finjusterandet": "finjusterande",
    "finjusterandets": "finjusterande",
    "finjusterar": "finjustera",
    "finjusteras": "finjustera",
    "finjusterat": "finjustera",
    "finjusterats": "finjustera",
    "finjusterbara": "finjusterbar",
    "finjusterbarare": "finjusterbar",
    "finjusterbarares": "finjusterbar",
    "finjusterbaras": "finjusterbar",
    "finjusterbarast": "finjusterbar",
    "finjusterbaraste": "finjusterbar",
    "finjusterbarastes": "finjusterbar",
    "finjusterbarasts": "finjusterbar",
    "finjusterbare": "finjusterbar",
    "finjusterbares": "finjusterbar",
    "finjusterbarheten": "finjusterbarhet",
    "finjusterbarhetens": "finjusterbarhet",
    "finjusterbarhets": "finjusterbarhet",
    "finjusterbars": "finjusterbar",
    "finjusterbart": "finjusterbar",
    "finjusterbarts": "finjusterbar",
    "finjusteringar": "finjustering",
    "finjusteringarna": "finjustering",
    "finjusteringarnas": "finjustering",
    "finjusteringars": "finjustering",
    "finjusteringen": "finjustering",
    "finjusteringens": "finjustering",
    "finjusterings": "finjustering",
    "fink": "finka",
    "finkad": "finka",
    "finkade": "finka",
    "finkades": "finka",
    "finkads": "finka",
    "finkalibriga": "finkalibrig",
    "finkalibrigare": "finkalibrig",
    "finkalibrigares": "finkalibrig",
    "finkalibrigas": "finkalibrig",
    "finkalibrigast": "finkalibrig",
    "finkalibrigaste": "finkalibrig",
    "finkalibrigastes": "finkalibrig",
    "finkalibrigasts": "finkalibrig",
    "finkalibrige": "finkalibrig",
    "finkalibriges": "finkalibrig",
    "finkalibrigheten": "finkalibrighet",
    "finkalibrighetens": "finkalibrighet",
    "finkalibrighets": "finkalibrighet",
    "finkalibrigs": "finkalibrig",
    "finkalibrigt": "finkalibrig",
    "finkalibrigts": "finkalibrig",
    "finkammad": "finkamma",
    "finkammade": "finkamma",
    "finkammades": "finkamma",
    "finkammads": "finkamma",
    "finkammande": "finkamma",
    "finkammanden": "finkammande",
    "finkammandena": "finkammande",
    "finkammandenas": "finkammande",
    "finkammandens": "finkammande",
    "finkammandes": "finkammande",
    "finkammandet": "finkammande",
    "finkammandets": "finkammande",
    "finkammar": "finkamma",
    "finkammas": "finkamma",
    "finkammat": "finkamma",
    "finkammats": "finkamma",
    "finkamningar": "finkamning",
    "finkamningarna": "finkamning",
    "finkamningarnas": "finkamning",
    "finkamningars": "finkamning",
    "finkamningen": "finkamning",
    "finkamningens": "finkamning",
    "finkamnings": "finkamning",
    "finkan": "finka",
    "finkande": "finka",
    "finkanden": "finkande",
    "finkandena": "finkande",
    "finkandenas": "finkande",
    "finkandens": "finkande",
    "finkandes": "finkande",
    "finkandet": "finkande",
    "finkandets": "finkande",
    "finkans": "finka",
    "finkar": "finka",
    "finkarna": "fink",
    "finkarnas": "fink",
    "finkars": "fink",
    "finkarten": "finkart",
    "finkartens": "finkart",
    "finkarter": "finkart",
    "finkarterna": "finkart",
    "finkarternas": "finkart",
    "finkarters": "finkart",
    "finkarts": "finkart",
    "finkas": "finka",
    "finkat": "finka",
    "finkats": "finka",
    "finke": "finka",
    "finkeln": "finkel",
    "finkelns": "finkel",
    "finkeloljan": "finkelolja",
    "finkeloljans": "finkelolja",
    "finkeloljas": "finkelolja",
    "finkelolje": "finkelolja",
    "finkeloljor": "finkelolja",
    "finkeloljorna": "finkelolja",
    "finkeloljornas": "finkelolja",
    "finkeloljors": "finkelolja",
    "finkels": "finkel",
    "finken": "fink",
    "finkens": "fink",
    "finkfågeln": "finkfågel",
    "finkfågelns": "finkfågel",
    "finkfågels": "finkfågel",
    "finkfåglar": "finkfågel",
    "finkfåglarna": "finkfågel",
    "finkfåglarnas": "finkfågel",
    "finkfåglars": "finkfågel",
    "finklädda": "finklädd",
    "finkläddare": "finklädd",
    "finkläddares": "finklädd",
    "finkläddas": "finklädd",
    "finkläddast": "finklädd",
    "finkläddaste": "finklädd",
    "finkläddastes": "finklädd",
    "finkläddasts": "finklädd",
    "finklädde": "finklädd",
    "finkläddes": "finklädd",
    "finkläddheten": "finkläddhet",
    "finkläddhetens": "finkläddhet",
    "finkläddhets": "finkläddhet",
    "finklädds": "finklädd",
    "finkläderna": "finkläder",
    "finklädernas": "finkläder",
    "finkläders": "finkläder",
    "finklädes": "finkläder",
    "finkläds": "finkläder",
    "finklätt": "finklädd",
    "finklätts": "finklädd",
    "finkor": "finka",
    "finkorna": "finka",
    "finkornas": "finka",
    "finkorniga": "finkornig",
    "finkornigare": "finkornig",
    "finkornigares": "finkornig",
    "finkornigas": "finkornig",
    "finkornigast": "finkornig",
    "finkornigaste": "finkornig",
    "finkornigastes": "finkornig",
    "finkornigasts": "finkornig",
    "finkornige": "finkornig",
    "finkorniges": "finkornig",
    "finkornigheten": "finkornighet",
    "finkornighetens": "finkornighet",
    "finkornighets": "finkornighet",
    "finkornigs": "finkornig",
    "finkornigt": "finkornig",
    "finkornigts": "finkornig",
    "finkors": "finka",
    "finks": "finka",
    "finkulturen": "finkultur",
    "finkulturens": "finkultur",
    "finkulturs": "finkultur",
    "finkungar": "finkunge",
    "finkungarna": "finkunge",
    "finkungarnas": "finkunge",
    "finkungars": "finkunge",
    "finkungen": "finkunge",
    "finkungens": "finkunge",
    "finkunges": "finkunge",
    "finkänsl": "finkänsla",
    "finkänslan": "finkänsla",
    "finkänslans": "finkänsla",
    "finkänslas": "finkänsla",
    "finkänsle": "finkänsla",
    "finkänsliga": "finkänslig",
    "finkänsligare": "finkänslig",
    "finkänsligares": "finkänslig",
    "finkänsligas": "finkänslig",
    "finkänsligast": "finkänslig",
    "finkänsligaste": "finkänslig",
    "finkänsligastes": "finkänslig",
    "finkänsligasts": "finkänslig",
    "finkänslige": "finkänslig",
    "finkänsliges": "finkänslig",
    "finkänsligheten": "finkänslighet",
    "finkänslighetens": "finkänslighet",
    "finkänsligheter": "finkänslighet",
    "finkänsligheterna": "finkänslighet",
    "finkänsligheternas": "finkänslighet",
    "finkänsligheters": "finkänslighet",
    "finkänslighets": "finkänslighet",
    "finkänsligs": "finkänslig",
    "finkänsligt": "finkänslig",
    "finkänsligts": "finkänslig",
    "finkänslo": "finkänsla",
    "finkänslor": "finkänsla",
    "finkänslorna": "finkänsla",
    "finkänslornas": "finkänsla",
    "finkänslors": "finkänsla",
    "finlandiserad": "finlandisera",
    "finlandiserade": "finlandisera",
    "finlandiserades": "finlandisera",
    "finlandiserads": "finlandisera",
    "finlandiserande": "finlandisera",
    "finlandiseranden": "finlandiserande",
    "finlandiserandena": "finlandiserande",
    "finlandiserandenas": "finlandiserande",
    "finlandiserandens": "finlandiserande",
    "finlandiserandes": "finlandiserande",
    "finlandiserandet": "finlandiserande",
    "finlandiserandets": "finlandiserande",
    "finlandiserar": "finlandisera",
    "finlandiseras": "finlandisera",
    "finlandiserat": "finlandisera",
    "finlandiserats": "finlandisera",
    "finlandiserbara": "finlandiserbar",
    "finlandiserbarare": "finlandiserbar",
    "finlandiserbarares": "finlandiserbar",
    "finlandiserbaras": "finlandiserbar",
    "finlandiserbarast": "finlandiserbar",
    "finlandiserbaraste": "finlandiserbar",
    "finlandiserbarastes": "finlandiserbar",
    "finlandiserbarasts": "finlandiserbar",
    "finlandiserbare": "finlandiserbar",
    "finlandiserbares": "finlandiserbar",
    "finlandiserbarheten": "finlandiserbarhet",
    "finlandiserbarhetens": "finlandiserbarhet",
    "finlandiserbarhets": "finlandiserbarhet",
    "finlandiserbars": "finlandiserbar",
    "finlandiserbart": "finlandiserbar",
    "finlandiserbarts": "finlandiserbar",
    "finlandiseringar": "finlandisering",
    "finlandiseringarna": "finlandisering",
    "finlandiseringarnas": "finlandisering",
    "finlandiseringars": "finlandisering",
    "finlandiseringen": "finlandisering",
    "finlandiseringens": "finlandisering",
    "finlandiserings": "finlandisering",
    "finlandismen": "finlandism",
    "finlandismens": "finlandism",
    "finlandismer": "finlandism",
    "finlandismerna": "finlandism",
    "finlandismernas": "finlandism",
    "finlandismers": "finlandism",
    "finlandisms": "finlandism",
    "finlandssvensk": "finlandssvenska",
    "finlandssvenska": "finlandssvensk",
    "finlandssvenskan": "finlandssvenska",
    "finlandssvenskans": "finlandssvenska",
    "finlandssvenskar": "finlandssvensk",
    "finlandssvenskare": "finlandssvensk",
    "finlandssvenskares": "finlandssvensk",
    "finlandssvenskarna": "finlandssvensk",
    "finlandssvenskarnas": "finlandssvensk",
    "finlandssvenskars": "finlandssvensk",
    "finlandssvenskas": "finlandssvenska",
    "finlandssvenskast": "finlandssvensk",
    "finlandssvenskaste": "finlandssvensk",
    "finlandssvenskastes": "finlandssvensk",
    "finlandssvenskasts": "finlandssvensk",
    "finlandssvenske": "finlandssvenska",
    "finlandssvensken": "finlandssvensk",
    "finlandssvenskens": "finlandssvensk",
    "finlandssvenskes": "finlandssvensk",
    "finlandssvenskor": "finlandssvenska",
    "finlandssvenskorna": "finlandssvenska",
    "finlandssvenskornas": "finlandssvenska",
    "finlandssvenskors": "finlandssvenska",
    "finlandssvensks": "finlandssvensk",
    "finlandssvenskt": "finlandssvensk",
    "finlandssvenskts": "finlandssvensk",
    "finlekar": "finlek",
    "finlekarna": "finlek",
    "finlekarnas": "finlek",
    "finlekars": "finlek",
    "finleken": "finlek",
    "finlekens": "finlek",
    "finleks": "finlek",
    "finlemmade": "finlemmad",
    "finlemmades": "finlemmad",
    "finlemmads": "finlemmad",
    "finlemmat": "finlemmad",
    "finlemmats": "finlemmad",
    "finliren": "finlir",
    "finlirens": "finlir",
    "finliret": "finlir",
    "finlirets": "finlir",
    "finlirs": "finlir",
    "finländar": "finländare",
    "finländaren": "finländare",
    "finländarens": "finländare",
    "finländares": "finländare",
    "finländarna": "finländare",
    "finländarnas": "finländare",
    "finländska": "finländsk",
    "finländskan": "finländska",
    "finländskans": "finländska",
    "finländskare": "finländsk",
    "finländskares": "finländsk",
    "finländskas": "finländska",
    "finländskast": "finländsk",
    "finländskaste": "finländsk",
    "finländskastes": "finländsk",
    "finländskasts": "finländsk",
    "finländske": "finländska",
    "finländskes": "finländsk",
    "finländskor": "finländska",
    "finländskorna": "finländska",
    "finländskornas": "finländska",
    "finländskors": "finländska",
    "finländsks": "finländsk",
    "finländskt": "finländsk",
    "finländskts": "finländsk",
    "finmaskiga": "finmaskig",
    "finmaskigare": "finmaskig",
    "finmaskigares": "finmaskig",
    "finmaskigas": "finmaskig",
    "finmaskigast": "finmaskig",
    "finmaskigaste": "finmaskig",
    "finmaskigastes": "finmaskig",
    "finmaskigasts": "finmaskig",
    "finmaskige": "finmaskig",
    "finmaskiges": "finmaskig",
    "finmaskigheten": "finmaskighet",
    "finmaskighetens": "finmaskighet",
    "finmaskighets": "finmaskighet",
    "finmaskigs": "finmaskig",
    "finmaskigt": "finmaskig",
    "finmaskigts": "finmaskig",
    "finmaten": "finmat",
    "finmatens": "finmat",
    "finmats": "finmat",
    "finmekanikern": "finmekaniker",
    "finmekanikerna": "finmekaniker",
    "finmekanikernas": "finmekaniker",
    "finmekanikerns": "finmekaniker",
    "finmekanikers": "finmekaniker",
    "finmekaniska": "finmekanisk",
    "finmekaniskare": "finmekanisk",
    "finmekaniskares": "finmekanisk",
    "finmekaniskas": "finmekanisk",
    "finmekaniskast": "finmekanisk",
    "finmekaniskaste": "finmekanisk",
    "finmekaniskastes": "finmekanisk",
    "finmekaniskasts": "finmekanisk",
    "finmekaniske": "finmekanisk",
    "finmekaniskes": "finmekanisk",
    "finmekanisks": "finmekanisk",
    "finmekaniskt": "finmekanisk",
    "finmekaniskts": "finmekanisk",
    "finmotoriken": "finmotorik",
    "finmotorikens": "finmotorik",
    "finmotoriks": "finmotorik",
    "finn": "finne",
    "finnande": "finna",
    "finnanden": "finnande",
    "finnandena": "finnande",
    "finnandenas": "finnande",
    "finnandens": "finnande",
    "finnandes": "finnande",
    "finnandet": "finnande",
    "finnandets": "finnande",
    "finnar": "finne",
    "finnarna": "finne",
    "finnarnas": "finne",
    "finnars": "finne",
    "finnas": "finna",
    "finne": "finna",
    "finnen": "finne",
    "finnens": "finne",
    "finner": "finna",
    "finnes": "finne",
    "finniga": "finnig",
    "finnigare": "finnig",
    "finnigares": "finnig",
    "finnigas": "finnig",
    "finnigast": "finnig",
    "finnigaste": "finnig",
    "finnigastes": "finnig",
    "finnigasts": "finnig",
    "finnige": "finnig",
    "finniges": "finnig",
    "finnigheten": "finnighet",
    "finnighetens": "finnighet",
    "finnighets": "finnighet",
    "finnigs": "finnig",
    "finnigt": "finnig",
    "finnigts": "finnig",
    "finnjoll": "finnjolle",
    "finnjollar": "finnjolle",
    "finnjollarna": "finnjolle",
    "finnjollarnas": "finnjolle",
    "finnjollars": "finnjolle",
    "finnjollen": "finnjolle",
    "finnjollens": "finnjolle",
    "finnjolles": "finnjolle",
    "finnjolls": "finnjolle",
    "finnmarken": "finnmark",
    "finnmarkens": "finnmark",
    "finnmarker": "finnmark",
    "finnmarkerna": "finnmark",
    "finnmarkernas": "finnmark",
    "finnmarkers": "finnmark",
    "finnmarks": "finnmark",
    "finns": "finne",
    "finputs": "finputsa",
    "finputsad": "finputsa",
    "finputsade": "finputsa",
    "finputsades": "finputsa",
    "finputsads": "finputsa",
    "finputsande": "finputsa",
    "finputsanden": "finputsande",
    "finputsandena": "finputsande",
    "finputsandenas": "finputsande",
    "finputsandens": "finputsande",
    "finputsandes": "finputsande",
    "finputsandet": "finputsande",
    "finputsandets": "finputsande",
    "finputsar": "finputsa",
    "finputsas": "finputsa",
    "finputsat": "finputsa",
    "finputsats": "finputsa",
    "finputsen": "finputs",
    "finputsens": "finputs",
    "finrummen": "finrum",
    "finrummens": "finrum",
    "finrummet": "finrum",
    "finrummets": "finrum",
    "finrums": "finrum",
    "fins": "fin",
    "finsk": "finska",
    "finsk-ugriska": "finsk-ugrisk",
    "finsk-ugriskare": "finsk-ugrisk",
    "finsk-ugriskares": "finsk-ugrisk",
    "finsk-ugriskas": "finsk-ugrisk",
    "finsk-ugriskast": "finsk-ugrisk",
    "finsk-ugriskaste": "finsk-ugrisk",
    "finsk-ugriskastes": "finsk-ugrisk",
    "finsk-ugriskasts": "finsk-ugrisk",
    "finsk-ugriske": "finsk-ugrisk",
    "finsk-ugriskes": "finsk-ugrisk",
    "finsk-ugrisks": "finsk-ugrisk",
    "finsk-ugriskt": "finsk-ugrisk",
    "finsk-ugriskts": "finsk-ugrisk",
    "finska": "finsk",
    "finskan": "finska",
    "finskans": "finska",
    "finskare": "finsk",
    "finskares": "finsk",
    "finskas": "finska",
    "finskast": "finsk",
    "finskaste": "finsk",
    "finskastes": "finsk",
    "finskasts": "finsk",
    "finske": "finska",
    "finskes": "finsk",
    "finskheten": "finskhet",
    "finskhetens": "finskhet",
    "finskheter": "finskhet",
    "finskheterna": "finskhet",
    "finskheternas": "finskhet",
    "finskheters": "finskhet",
    "finskhets": "finskhet",
    "finskon": "finsko",
    "finskons": "finsko",
    "finskor": "finsko",
    "finskorna": "finsko",
    "finskornas": "finsko",
    "finskors": "finsko",
    "finskos": "finsko",
    "finsks": "finsk",
    "finskspråkiga": "finskspråkig",
    "finskspråkigas": "finskspråkig",
    "finskspråkige": "finskspråkig",
    "finskspråkiges": "finskspråkig",
    "finskspråkigs": "finskspråkig",
    "finskspråkigt": "finskspråkig",
    "finskspråkigts": "finskspråkig",
    "finskt": "finsk",
    "finskts": "finsk",
    "finskåpen": "finskåp",
    "finskåpens": "finskåp",
    "finskåpet": "finskåp",
    "finskåpets": "finskåp",
    "finskåps": "finskåp",
    "finslip": "finslipa",
    "finslipad": "finslipa",
    "finslipade": "finslipa",
    "finslipades": "finslipa",
    "finslipads": "finslipa",
    "finslipande": "finslipa",
    "finslipanden": "finslipande",
    "finslipandena": "finslipande",
    "finslipandenas": "finslipande",
    "finslipandens": "finslipande",
    "finslipandes": "finslipande",
    "finslipandet": "finslipande",
    "finslipandets": "finslipande",
    "finslipar": "finslipa",
    "finslipas": "finslipa",
    "finslipat": "finslipa",
    "finslipats": "finslipa",
    "finsmakar": "finsmakare",
    "finsmakaren": "finsmakare",
    "finsmakarens": "finsmakare",
    "finsmakares": "finsmakare",
    "finsmakarna": "finsmakare",
    "finsmakarnas": "finsmakare",
    "finsmiden": "finsmide",
    "finsmidena": "finsmide",
    "finsmidenas": "finsmide",
    "finsmidens": "finsmide",
    "finsmides": "finsmide",
    "finsmidet": "finsmide",
    "finsmidets": "finsmide",
    "finsnickar": "finsnickare",
    "finsnickaren": "finsnickare",
    "finsnickarens": "finsnickare",
    "finsnickares": "finsnickare",
    "finsnickarna": "finsnickare",
    "finsnickarnas": "finsnickare",
    "finsnickerier": "finsnickeri",
    "finsnickerierna": "finsnickeri",
    "finsnickeriernas": "finsnickeri",
    "finsnickeriers": "finsnickeri",
    "finsnickeriet": "finsnickeri",
    "finsnickeriets": "finsnickeri",
    "finsnickeris": "finsnickeri",
    "finsnickerit": "finsnickeri",
    "finsnickerits": "finsnickeri",
    "finspackels": "finspackel",
    "finspacklet": "finspackel",
    "finspacklets": "finspackel",
    "finspriten": "finsprit",
    "finspritens": "finsprit",
    "finsprits": "finsprit",
    "finspunna": "finspunnen",
    "finspunnare": "finspunnen",
    "finspunnares": "finspunnen",
    "finspunnas": "finspunnen",
    "finspunnast": "finspunnen",
    "finspunnaste": "finspunnen",
    "finspunnastes": "finspunnen",
    "finspunnasts": "finspunnen",
    "finspunne": "finspunnen",
    "finspunnens": "finspunnen",
    "finspunnes": "finspunnen",
    "finspunnet": "finspunnen",
    "finspunnets": "finspunnen",
    "finspäntade": "finspäntad",
    "finspäntades": "finspäntad",
    "finspäntads": "finspäntad",
    "finspäntat": "finspäntad",
    "finspäntats": "finspäntad",
    "finstilen": "finstil",
    "finstilens": "finstil",
    "finstils": "finstil",
    "finstilta": "finstilt",
    "finstiltare": "finstilt",
    "finstiltares": "finstilt",
    "finstiltas": "finstilt",
    "finstiltast": "finstilt",
    "finstiltaste": "finstilt",
    "finstiltastes": "finstilt",
    "finstiltasts": "finstilt",
    "finstilte": "finstilt",
    "finstiltes": "finstilt",
    "finstilts": "finstilt",
    "finstrukturen": "finstruktur",
    "finstrukturens": "finstruktur",
    "finstrukturer": "finstruktur",
    "finstrukturerna": "finstruktur",
    "finstrukturernas": "finstruktur",
    "finstrukturers": "finstruktur",
    "finstrukturs": "finstruktur",
    "finstämda": "finstämd",
    "finstämdare": "finstämd",
    "finstämdares": "finstämd",
    "finstämdas": "finstämd",
    "finstämdast": "finstämd",
    "finstämdaste": "finstämd",
    "finstämdastes": "finstämd",
    "finstämdasts": "finstämd",
    "finstämde": "finstämd",
    "finstämdes": "finstämd",
    "finstämdheten": "finstämdhet",
    "finstämdhetens": "finstämdhet",
    "finstämdhets": "finstämdhet",
    "finstämds": "finstämd",
    "finstämt": "finstämd",
    "finstämts": "finstämd",
    "fint": "finta",
    "fintad": "finta",
    "fintade": "finta",
    "fintades": "finta",
    "fintads": "finta",
    "fintande": "finta",
    "fintanden": "fintande",
    "fintandena": "fintande",
    "fintandenas": "fintande",
    "fintandens": "fintande",
    "fintandes": "fintande",
    "fintandet": "fintande",
    "fintandets": "fintande",
    "fintar": "finta",
    "fintas": "finta",
    "fintat": "finta",
    "fintats": "finta",
    "finten": "fint",
    "fintens": "fint",
    "finter": "fint",
    "finterna": "fint",
    "finternas": "fint",
    "finters": "fint",
    "fintliga": "fintlig",
    "fintligare": "fintlig",
    "fintligares": "fintlig",
    "fintligas": "fintlig",
    "fintligast": "fintlig",
    "fintligaste": "fintlig",
    "fintligastes": "fintlig",
    "fintligasts": "fintlig",
    "fintlige": "fintlig",
    "fintliges": "fintlig",
    "fintligheten": "fintlighet",
    "fintlighetens": "fintlighet",
    "fintligheter": "fintlighet",
    "fintligheterna": "fintlighet",
    "fintligheternas": "fintlighet",
    "fintligheters": "fintlighet",
    "fintlighets": "fintlighet",
    "fintligs": "fintlig",
    "fintligt": "fintlig",
    "fintligts": "fintlig",
    "fints": "fint",
    "fintvättar": "fintvätt",
    "fintvättarna": "fintvätt",
    "fintvättarnas": "fintvätt",
    "fintvättars": "fintvätt",
    "fintvätten": "fintvätt",
    "fintvättens": "fintvätt",
    "fintvätts": "fintvätt",
    "finurliga": "finurlig",
    "finurligare": "finurlig",
    "finurligares": "finurlig",
    "finurligas": "finurlig",
    "finurligast": "finurlig",
    "finurligaste": "finurlig",
    "finurligastes": "finurlig",
    "finurligasts": "finurlig",
    "finurlige": "finurlig",
    "finurliges": "finurlig",
    "finurligheten": "finurlighet",
    "finurlighetens": "finurlighet",
    "finurligheter": "finurlighet",
    "finurligheterna": "finurlighet",
    "finurligheternas": "finurlighet",
    "finurligheters": "finurlighet",
    "finurlighets": "finurlighet",
    "finurligs": "finurlig",
    "finurligt": "finurlig",
    "finurligts": "finurlig",
    "fiolblocken": "fiolblock",
    "fiolblockens": "fiolblock",
    "fiolblocket": "fiolblock",
    "fiolblockets": "fiolblock",
    "fiolblocks": "fiolblock",
    "fiolen": "fiol",
    "fiolens": "fiol",
    "fioler": "fiol",
    "fiolerna": "fiol",
    "fiolernas": "fiol",
    "fiolers": "fiol",
    "fiols": "fiol",
    "fiolspelar": "fiolspelare",
    "fiolspelaren": "fiolspelare",
    "fiolspelarens": "fiolspelare",
    "fiolspelares": "fiolspelare",
    "fiolspelarna": "fiolspelare",
    "fiolspelarnas": "fiolspelare",
    "fiolsträngar": "fiolsträng",
    "fiolsträngarna": "fiolsträng",
    "fiolsträngarnas": "fiolsträng",
    "fiolsträngars": "fiolsträng",
    "fiolsträngen": "fiolsträng",
    "fiolsträngens": "fiolsträng",
    "fiolsträngs": "fiolsträng",
    "fiorituren": "fioritur",
    "fioriturens": "fioritur",
    "fioriturer": "fioritur",
    "fioriturerna": "fioritur",
    "fioriturernas": "fioritur",
    "fioriturers": "fioritur",
    "fioriturs": "fioritur",
    "fippel": "fippla",
    "fipplade": "fippla",
    "fipplades": "fippla",
    "fipplande": "fippla",
    "fipplanden": "fipplande",
    "fipplandena": "fipplande",
    "fipplandenas": "fipplande",
    "fipplandens": "fipplande",
    "fipplandes": "fipplande",
    "fipplandet": "fipplande",
    "fipplandets": "fipplande",
    "fipplar": "fippla",
    "fipplas": "fippla",
    "fipplat": "fippla",
    "fipplats": "fippla",
    "fippliga": "fipplig",
    "fippligare": "fipplig",
    "fippligares": "fipplig",
    "fippligas": "fipplig",
    "fippligast": "fipplig",
    "fippligaste": "fipplig",
    "fippligastes": "fipplig",
    "fippligasts": "fipplig",
    "fipplige": "fipplig",
    "fippliges": "fipplig",
    "fippligheten": "fipplighet",
    "fipplighetens": "fipplighet",
    "fipplighets": "fipplighet",
    "fippligs": "fipplig",
    "fippligt": "fipplig",
    "fippligts": "fipplig",
    "fir": "fira",
    "firad": "fira",
    "firade": "fira",
    "firades": "fira",
    "firads": "fira",
    "firande": "fira",
    "firanden": "firande",
    "firandena": "firande",
    "firandenas": "firande",
    "firandens": "firande",
    "firandes": "firande",
    "firandet": "firande",
    "firandets": "firande",
    "firar": "fira",
    "firas": "fira",
    "firat": "fira",
    "firats": "fira",
    "firmafesten": "firmafest",
    "firmafestens": "firmafest",
    "firmafester": "firmafest",
    "firmafesterna": "firmafest",
    "firmafesternas": "firmafest",
    "firmafesters": "firmafest",
    "firmafests": "firmafest",
    "firmamentet": "firmament",
    "firmamentets": "firmament",
    "firmaments": "firmament",
    "firmamärken": "firmamärke",
    "firmamärkena": "firmamärke",
    "firmamärkenas": "firmamärke",
    "firmamärkens": "firmamärke",
    "firmamärkes": "firmamärke",
    "firmamärket": "firmamärke",
    "firmamärkets": "firmamärke",
    "firman": "firma",
    "firmanamnen": "firmanamn",
    "firmanamnens": "firmanamn",
    "firmanamnet": "firmanamn",
    "firmanamnets": "firmanamn",
    "firmanamns": "firmanamn",
    "firmans": "firma",
    "firmas": "firma",
    "firmatecknar": "firmatecknare",
    "firmatecknaren": "firmatecknare",
    "firmatecknarens": "firmatecknare",
    "firmatecknares": "firmatecknare",
    "firmatecknarna": "firmatecknare",
    "firmatecknarnas": "firmatecknare",
    "firmateckningar": "firmateckning",
    "firmateckningarna": "firmateckning",
    "firmateckningarnas": "firmateckning",
    "firmateckningars": "firmateckning",
    "firmateckningen": "firmateckning",
    "firmateckningens": "firmateckning",
    "firmatecknings": "firmateckning",
    "firmor": "firma",
    "firmorna": "firma",
    "firmornas": "firma",
    "firmors": "firma",
    "firnen": "firn",
    "firnens": "firn",
    "firngränsen": "firngräns",
    "firngränsens": "firngräns",
    "firngränser": "firngräns",
    "firngränserna": "firngräns",
    "firngränsernas": "firngräns",
    "firngränsers": "firngräns",
    "firns": "firn",
    "firr": "firre",
    "firrar": "firre",
    "firrarna": "firre",
    "firrarnas": "firre",
    "firrars": "firre",
    "firren": "firre",
    "firrens": "firre",
    "firres": "firre",
    "firrs": "firre",
    "fis": "fisa",
    "fisande": "fisa",
    "fisanden": "fisande",
    "fisandena": "fisande",
    "fisandenas": "fisande",
    "fisandens": "fisande",
    "fisandes": "fisande",
    "fisandet": "fisande",
    "fisandets": "fisande",
    "fisar": "fis",
    "fisarna": "fis",
    "fisarnas": "fis",
    "fisars": "fis",
    "fisas": "fisa",
    "fischyer": "fischy",
    "fischyerna": "fischy",
    "fischyernas": "fischy",
    "fischyers": "fischy",
    "fischyn": "fischy",
    "fischyns": "fischy",
    "fischys": "fischy",
    "fise": "fisa",
    "fisen": "fis",
    "fisens": "fis",
    "fiser": "fisa",
    "fises": "fisa",
    "fisförnäma": "fisförnäm",
    "fisförnämare": "fisförnäm",
    "fisförnämares": "fisförnäm",
    "fisförnämas": "fisförnäm",
    "fisförnämast": "fisförnäm",
    "fisförnämaste": "fisförnäm",
    "fisförnämastes": "fisförnäm",
    "fisförnämasts": "fisförnäm",
    "fisförnäme": "fisförnäm",
    "fisförnämes": "fisförnäm",
    "fisförnämheten": "fisförnämhet",
    "fisförnämhetens": "fisförnämhet",
    "fisförnämhets": "fisförnämhet",
    "fisförnäms": "fisförnäm",
    "fisförnämt": "fisförnäm",
    "fisförnämts": "fisförnäm",
    "fisiga": "fisig",
    "fisigare": "fisig",
    "fisigares": "fisig",
    "fisigas": "fisig",
    "fisigast": "fisig",
    "fisigaste": "fisig",
    "fisigastes": "fisig",
    "fisigasts": "fisig",
    "fisige": "fisig",
    "fisiges": "fisig",
    "fisigs": "fisig",
    "fisigt": "fisig",
    "fisigts": "fisig",
    "fisit": "fisa",
    "fisits": "fisa",
    "fiskad": "fiska",
    "fiskade": "fiska",
    "fiskades": "fiska",
    "fiskads": "fiska",
    "fiskafängen": "fiskafänge",
    "fiskafängena": "fiskafänge",
    "fiskafängenas": "fiskafänge",
    "fiskafängens": "fiskafänge",
    "fiskafänges": "fiskafänge",
    "fiskafänget": "fiskafänge",
    "fiskafängets": "fiskafänge",
    "fiskafängs": "fiskafänge",
    "fiskala": "fiskal",
    "fiskalare": "fiskal",
    "fiskalares": "fiskal",
    "fiskalas": "fiskal",
    "fiskalast": "fiskal",
    "fiskalaste": "fiskal",
    "fiskalastes": "fiskal",
    "fiskalasts": "fiskal",
    "fiskale": "fiskal",
    "fiskales": "fiskal",
    "fiskaliska": "fiskalisk",
    "fiskaliskare": "fiskalisk",
    "fiskaliskares": "fiskalisk",
    "fiskaliskas": "fiskalisk",
    "fiskaliskast": "fiskalisk",
    "fiskaliskaste": "fiskalisk",
    "fiskaliskastes": "fiskalisk",
    "fiskaliskasts": "fiskalisk",
    "fiskaliske": "fiskalisk",
    "fiskaliskes": "fiskalisk",
    "fiskalisks": "fiskalisk",
    "fiskaliskt": "fiskalisk",
    "fiskaliskts": "fiskalisk",
    "fiskals": "fiskal",
    "fiskalt": "fiskal",
    "fiskalts": "fiskal",
    "fiskande": "fiska",
    "fiskanden": "fiskande",
    "fiskandena": "fiskande",
    "fiskandenas": "fiskande",
    "fiskandens": "fiskande",
    "fiskandes": "fiskande",
    "fiskandet": "fiskande",
    "fiskandets": "fiskande",
    "fiskar": "fiskare",
    "fiskaren": "fiskare",
    "fiskarens": "fiskare",
    "fiskares": "fiskare",
    "fiskarna": "fiskare",
    "fiskarnas": "fiskare",
    "fiskars": "fisk",
    "fiskarten": "fiskart",
    "fiskartens": "fiskart",
    "fiskarter": "fiskart",
    "fiskarterna": "fiskart",
    "fiskarternas": "fiskart",
    "fiskarters": "fiskart",
    "fiskarts": "fiskart",
    "fiskas": "fiska",
    "fiskat": "fiska",
    "fiskats": "fiska",
    "fiskbenen": "fiskben",
    "fiskbenens": "fiskben",
    "fiskbenet": "fiskben",
    "fiskbenets": "fiskben",
    "fiskbens": "fiskben",
    "fiskbensmönsterna": "fiskbensmönster",
    "fiskbensmönsternas": "fiskbensmönster",
    "fiskbensmönsters": "fiskbensmönster",
    "fiskbensmönstren": "fiskbensmönster",
    "fiskbensmönstrens": "fiskbensmönster",
    "fiskbensmönstret": "fiskbensmönster",
    "fiskbensmönstrets": "fiskbensmönster",
    "fiskblås": "fiskblåsa",
    "fiskblåsan": "fiskblåsa",
    "fiskblåsans": "fiskblåsa",
    "fiskblåsas": "fiskblåsa",
    "fiskblåse": "fiskblåsa",
    "fiskblåsor": "fiskblåsa",
    "fiskblåsorna": "fiskblåsa",
    "fiskblåsornas": "fiskblåsa",
    "fiskblåsors": "fiskblåsa",
    "fiskbull": "fiskbulle",
    "fiskbullar": "fiskbulle",
    "fiskbullarna": "fiskbulle",
    "fiskbullarnas": "fiskbulle",
    "fiskbullars": "fiskbulle",
    "fiskbullen": "fiskbulle",
    "fiskbullens": "fiskbulle",
    "fiskbulles": "fiskbulle",
    "fiskbulls": "fiskbulle",
    "fiskdammar": "fiskdamm",
    "fiskdammarna": "fiskdamm",
    "fiskdammarnas": "fiskdamm",
    "fiskdammars": "fiskdamm",
    "fiskdammen": "fiskdamm",
    "fiskdammens": "fiskdamm",
    "fiskdamms": "fiskdamm",
    "fiskdöden": "fiskdöd",
    "fiskdödens": "fiskdöd",
    "fiskdöds": "fiskdöd",
    "fiske": "fiska",
    "fiskeansvariga": "fiskeansvarig",
    "fiskeansvarigas": "fiskeansvarig",
    "fiskeansvarige": "fiskeansvarig",
    "fiskeansvariges": "fiskeansvarig",
    "fiskeansvarigs": "fiskeansvarig",
    "fiskeansvarigt": "fiskeansvarig",
    "fiskeansvarigts": "fiskeansvarig",
    "fiskebankar": "fiskebank",
    "fiskebankarna": "fiskebank",
    "fiskebankarnas": "fiskebank",
    "fiskebankars": "fiskebank",
    "fiskebanken": "fiskebank",
    "fiskebankens": "fiskebank",
    "fiskebanks": "fiskebank",
    "fiskebåtar": "fiskebåt",
    "fiskebåtarna": "fiskebåt",
    "fiskebåtarnas": "fiskebåt",
    "fiskebåtars": "fiskebåt",
    "fiskebåten": "fiskebåt",
    "fiskebåtens": "fiskebåt",
    "fiskebåts": "fiskebåt",
    "fiskebåtsbesättningar": "fiskebåtsbesättning",
    "fiskebåtsbesättningarna": "fiskebåtsbesättning",
    "fiskebåtsbesättningarnas": "fiskebåtsbesättning",
    "fiskebåtsbesättningars": "fiskebåtsbesättning",
    "fiskebåtsbesättningen": "fiskebåtsbesättning",
    "fiskebåtsbesättningens": "fiskebåtsbesättning",
    "fiskebåtsbesättnings": "fiskebåtsbesättning",
    "fiskedragen": "fiskedrag",
    "fiskedragens": "fiskedrag",
    "fiskedraget": "fiskedrag",
    "fiskedragets": "fiskedrag",
    "fiskedrags": "fiskedrag",
    "fiskefartygen": "fiskefartyg",
    "fiskefartygens": "fiskefartyg",
    "fiskefartyget": "fiskefartyg",
    "fiskefartygets": "fiskefartyg",
    "fiskefartygs": "fiskefartyg",
    "fiskegränsen": "fiskegräns",
    "fiskegränsens": "fiskegräns",
    "fiskegränser": "fiskegräns",
    "fiskegränserna": "fiskegräns",
    "fiskegränsernas": "fiskegräns",
    "fiskegränsers": "fiskegräns",
    "fiskekorten": "fiskekort",
    "fiskekortens": "fiskekort",
    "fiskekortet": "fiskekort",
    "fiskekortets": "fiskekort",
    "fiskekorts": "fiskekort",
    "fiskekrokar": "fiskekrok",
    "fiskekrokarna": "fiskekrok",
    "fiskekrokarnas": "fiskekrok",
    "fiskekrokars": "fiskekrok",
    "fiskekroken": "fiskekrok",
    "fiskekrokens": "fiskekrok",
    "fiskekroks": "fiskekrok",
    "fiskelagar": "fiskelag",
    "fiskelagarna": "fiskelag",
    "fiskelagarnas": "fiskelag",
    "fiskelagars": "fiskelag",
    "fiskelagen": "fiskelag",
    "fiskelagens": "fiskelag",
    "fiskelags": "fiskelag",
    "fiskelägen": "fiskeläge",
    "fiskelägena": "fiskeläge",
    "fiskelägenas": "fiskeläge",
    "fiskelägens": "fiskeläge",
    "fiskeläges": "fiskeläge",
    "fiskeläget": "fiskeläge",
    "fiskelägets": "fiskeläge",
    "fisken": "fisk",
    "fiskenationen": "fiskenation",
    "fiskenationens": "fiskenation",
    "fiskenationer": "fiskenation",
    "fiskenationerna": "fiskenation",
    "fiskenationernas": "fiskenation",
    "fiskenationers": "fiskenation",
    "fiskenations": "fiskenation",
    "fiskens": "fisk",
    "fiskenäten": "fiskenät",
    "fiskenätens": "fiskenät",
    "fiskenätet": "fiskenät",
    "fiskenätets": "fiskenät",
    "fiskenäts": "fiskenät",
    "fiskeolyck": "fiskeolycka",
    "fiskeolyckan": "fiskeolycka",
    "fiskeolyckans": "fiskeolycka",
    "fiskeolyckas": "fiskeolycka",
    "fiskeolycke": "fiskeolycka",
    "fiskeolyckor": "fiskeolycka",
    "fiskeolyckorna": "fiskeolycka",
    "fiskeolyckornas": "fiskeolycka",
    "fiskeolyckors": "fiskeolycka",
    "fiskeolycks": "fiskeolycka",
    "fiskeredskapen": "fiskeredskap",
    "fiskeredskapens": "fiskeredskap",
    "fiskeredskapet": "fiskeredskap",
    "fiskeredskapets": "fiskeredskap",
    "fiskeredskaps": "fiskeredskap",
    "fiskerier": "fiskeri",
    "fiskerierna": "fiskeri",
    "fiskeriernas": "fiskeri",
    "fiskeriers": "fiskeri",
    "fiskeriet": "fiskeri",
    "fiskeriets": "fiskeri",
    "fiskeris": "fiskeri",
    "fiskeristyrelsen": "fiskeristyrelse",
    "fiskeristyrelsens": "fiskeristyrelse",
    "fiskeristyrelser": "fiskeristyrelse",
    "fiskeristyrelserna": "fiskeristyrelse",
    "fiskeristyrelsernas": "fiskeristyrelse",
    "fiskeristyrelsers": "fiskeristyrelse",
    "fiskeristyrelses": "fiskeristyrelse",
    "fiskerit": "fiskeri",
    "fiskerits": "fiskeri",
    "fiskes": "fiske",
    "fiskestugan": "fiskestuga",
    "fiskestugans": "fiskestuga",
    "fiskestugas": "fiskestuga",
    "fiskestuge": "fiskestuga",
    "fiskestugor": "fiskestuga",
    "fiskestugorna": "fiskestuga",
    "fiskestugornas": "fiskestuga",
    "fiskestugors": "fiskestuga",
    "fiskestugu": "fiskestuga",
    "fisket": "fiske",
    "fiskets": "fiske",
    "fiskevattens": "fiskevatten",
    "fiskevattnen": "fiskevatten",
    "fiskevattnens": "fiskevatten",
    "fiskevattnet": "fiskevatten",
    "fiskevattnets": "fiskevatten",
    "fiskevården": "fiskevård",
    "fiskevårdens": "fiskevård",
    "fiskevårds": "fiskevård",
    "fiskezonen": "fiskezon",
    "fiskezonens": "fiskezon",
    "fiskezoner": "fiskezon",
    "fiskezonerna": "fiskezon",
    "fiskezonernas": "fiskezon",
    "fiskezoners": "fiskezon",
    "fiskezons": "fiskezon",
    "fiskfiléer": "fiskfilé",
    "fiskfiléerna": "fiskfilé",
    "fiskfiléernas": "fiskfilé",
    "fiskfiléers": "fiskfilé",
    "fiskfilén": "fiskfilé",
    "fiskfiléns": "fiskfilé",
    "fiskfilés": "fiskfilé",
    "fiskgjus": "fiskgjuse",
    "fiskgjusar": "fiskgjuse",
    "fiskgjusarna": "fiskgjuse",
    "fiskgjusarnas": "fiskgjuse",
    "fiskgjusars": "fiskgjuse",
    "fiskgjusen": "fiskgjuse",
    "fiskgjusens": "fiskgjuse",
    "fiskgjuses": "fiskgjuse",
    "fiskguanon": "fiskguano",
    "fiskguanons": "fiskguano",
    "fiskguanos": "fiskguano",
    "fiskguanot": "fiskguano",
    "fiskguanots": "fiskguano",
    "fiskhamnar": "fiskhamn",
    "fiskhamnarna": "fiskhamn",
    "fiskhamnarnas": "fiskhamn",
    "fiskhamnars": "fiskhamn",
    "fiskhamnen": "fiskhamn",
    "fiskhamnens": "fiskhamn",
    "fiskhamns": "fiskhamn",
    "fiskkrokar": "fiskkrok",
    "fiskkrokarna": "fiskkrok",
    "fiskkrokarnas": "fiskkrok",
    "fiskkrokars": "fiskkrok",
    "fiskkroken": "fiskkrok",
    "fiskkrokens": "fiskkrok",
    "fiskkroks": "fiskkrok",
    "fiskleveroljan": "fiskleverolja",
    "fiskleveroljans": "fiskleverolja",
    "fiskleveroljas": "fiskleverolja",
    "fiskleverolje": "fiskleverolja",
    "fiskliret": "fisklir",
    "fisklirets": "fisklir",
    "fisklirs": "fisklir",
    "fiskmjölet": "fiskmjöl",
    "fiskmjölets": "fiskmjöl",
    "fiskmjöls": "fiskmjöl",
    "fiskmunnar": "fiskmun",
    "fiskmunnarna": "fiskmun",
    "fiskmunnarnas": "fiskmun",
    "fiskmunnars": "fiskmun",
    "fiskmunnen": "fiskmun",
    "fiskmunnens": "fiskmun",
    "fiskmuns": "fiskmun",
    "fiskmåltiden": "fiskmåltid",
    "fiskmåltidens": "fiskmåltid",
    "fiskmåltider": "fiskmåltid",
    "fiskmåltiderna": "fiskmåltid",
    "fiskmåltidernas": "fiskmåltid",
    "fiskmåltiders": "fiskmåltid",
    "fiskmåltids": "fiskmåltid",
    "fiskmåsar": "fiskmås",
    "fiskmåsarna": "fiskmås",
    "fiskmåsarnas": "fiskmås",
    "fiskmåsars": "fiskmås",
    "fiskmåsen": "fiskmås",
    "fiskmåsens": "fiskmås",
    "fisknotar": "fisknot",
    "fisknotarna": "fisknot",
    "fisknotarnas": "fisknot",
    "fisknotars": "fisknot",
    "fisknoten": "fisknot",
    "fisknotens": "fisknot",
    "fisknots": "fisknot",
    "fisknäten": "fisknät",
    "fisknätens": "fisknät",
    "fisknätet": "fisknät",
    "fisknätets": "fisknät",
    "fisknäts": "fisknät",
    "fiskodlingar": "fiskodling",
    "fiskodlingarna": "fiskodling",
    "fiskodlingarnas": "fiskodling",
    "fiskodlingars": "fiskodling",
    "fiskodlingen": "fiskodling",
    "fiskodlingens": "fiskodling",
    "fiskodlings": "fiskodling",
    "fiskoljan": "fiskolja",
    "fiskoljans": "fiskolja",
    "fiskoljas": "fiskolja",
    "fiskolje": "fiskolja",
    "fiskpinn": "fiskpinne",
    "fiskpinnar": "fiskpinne",
    "fiskpinnarna": "fiskpinne",
    "fiskpinnarnas": "fiskpinne",
    "fiskpinnars": "fiskpinne",
    "fiskpinnen": "fiskpinne",
    "fiskpinnens": "fiskpinne",
    "fiskpinnes": "fiskpinne",
    "fiskpinns": "fiskpinne",
    "fiskpuddingar": "fiskpudding",
    "fiskpuddingarna": "fiskpudding",
    "fiskpuddingarnas": "fiskpudding",
    "fiskpuddingars": "fiskpudding",
    "fiskpuddingen": "fiskpudding",
    "fiskpuddingens": "fiskpudding",
    "fiskpuddings": "fiskpudding",
    "fiskredskapen": "fiskredskap",
    "fiskredskapens": "fiskredskap",
    "fiskredskapet": "fiskredskap",
    "fiskredskapets": "fiskredskap",
    "fiskredskaps": "fiskredskap",
    "fiskrenset": "fiskrens",
    "fiskrensets": "fiskrens",
    "fiskrommen": "fiskrom",
    "fiskrommens": "fiskrom",
    "fiskroms": "fiskrom",
    "fiskrätten": "fiskrätt",
    "fiskrättens": "fiskrätt",
    "fiskrätter": "fiskrätt",
    "fiskrätterna": "fiskrätt",
    "fiskrätternas": "fiskrätt",
    "fiskrätters": "fiskrätt",
    "fiskrätts": "fiskrätt",
    "fisks": "fisk",
    "fisksopp": "fisksoppa",
    "fisksoppan": "fisksoppa",
    "fisksoppans": "fisksoppa",
    "fisksoppas": "fisksoppa",
    "fisksoppe": "fisksoppa",
    "fisksoppor": "fisksoppa",
    "fisksopporna": "fisksoppa",
    "fisksoppornas": "fisksoppa",
    "fisksoppors": "fisksoppa",
    "fisksopps": "fisksoppa",
    "fiskstimmen": "fiskstim",
    "fiskstimmens": "fiskstim",
    "fiskstimmet": "fiskstim",
    "fiskstimmets": "fiskstim",
    "fiskstims": "fiskstim",
    "fisksumpar": "fisksump",
    "fisksumparna": "fisksump",
    "fisksumparnas": "fisksump",
    "fisksumpars": "fisksump",
    "fisksumpen": "fisksump",
    "fisksumpens": "fisksump",
    "fisksumps": "fisksump",
    "fisktomheten": "fisktomhet",
    "fisktomhetens": "fisktomhet",
    "fisktomhets": "fisktomhet",
    "fisktomma": "fisktom",
    "fisktommare": "fisktom",
    "fisktommares": "fisktom",
    "fisktommas": "fisktom",
    "fisktommast": "fisktom",
    "fisktommaste": "fisktom",
    "fisktommastes": "fisktom",
    "fisktommasts": "fisktom",
    "fisktomme": "fisktom",
    "fisktommes": "fisktom",
    "fisktoms": "fisktom",
    "fisktomt": "fisktom",
    "fisktomts": "fisktom",
    "fisktrapp": "fisktrappa",
    "fisktrappan": "fisktrappa",
    "fisktrappans": "fisktrappa",
    "fisktrappas": "fisktrappa",
    "fisktrappe": "fisktrappa",
    "fisktrappor": "fisktrappa",
    "fisktrapporna": "fisktrappa",
    "fisktrappornas": "fisktrappa",
    "fisktrappors": "fisktrappa",
    "fisktrapps": "fisktrappa",
    "fiskvandringar": "fiskvandring",
    "fiskvandringarna": "fiskvandring",
    "fiskvandringarnas": "fiskvandring",
    "fiskvandringars": "fiskvandring",
    "fiskvandringen": "fiskvandring",
    "fiskvandringens": "fiskvandring",
    "fiskvandrings": "fiskvandring",
    "fiskyngels": "fiskyngel",
    "fiskynglen": "fiskyngel",
    "fiskynglens": "fiskyngel",
    "fiskynglet": "fiskyngel",
    "fiskynglets": "fiskyngel",
    "fiskätandes": "fiskätande",
    "fiskätandet": "fiskätande",
    "fiskätandets": "fiskätande",
    "fiskåder": "fiskådra",
    "fiskådran": "fiskådra",
    "fiskådrans": "fiskådra",
    "fiskådras": "fiskådra",
    "fiskådre": "fiskådra",
    "fiskådror": "fiskådra",
    "fiskådrorna": "fiskådra",
    "fiskådrornas": "fiskådra",
    "fiskådrors": "fiskådra",
    "fisködlan": "fisködla",
    "fisködlans": "fisködla",
    "fisködlas": "fisködla",
    "fisködle": "fisködla",
    "fisködlor": "fisködla",
    "fisködlorna": "fisködla",
    "fisködlornas": "fisködla",
    "fisködlors": "fisködla",
    "fiskögas": "fisköga",
    "fiskögat": "fisköga",
    "fiskögats": "fisköga",
    "fiskögon": "fisköga",
    "fiskögonen": "fisköga",
    "fiskögonens": "fisköga",
    "fiskögons": "fisköga",
    "fissila": "fissil",
    "fissilare": "fissil",
    "fissilares": "fissil",
    "fissilas": "fissil",
    "fissilast": "fissil",
    "fissilaste": "fissil",
    "fissilastes": "fissil",
    "fissilasts": "fissil",
    "fissile": "fissil",
    "fissiles": "fissil",
    "fissils": "fissil",
    "fissilt": "fissil",
    "fissilts": "fissil",
    "fissionen": "fission",
    "fissionens": "fission",
    "fissioner": "fission",
    "fissionerna": "fission",
    "fissionernas": "fission",
    "fissioners": "fission",
    "fissions": "fission",
    "fissuren": "fissur",
    "fissurens": "fissur",
    "fissurer": "fissur",
    "fissurerna": "fissur",
    "fissurernas": "fissur",
    "fissurers": "fissur",
    "fissurs": "fissur",
    "fisteln": "fistel",
    "fistelns": "fistel",
    "fistels": "fistel",
    "fistlar": "fistel",
    "fistlarna": "fistel",
    "fistlarnas": "fistel",
    "fistlars": "fistel",
    "fistulösa": "fistulös",
    "fistulösare": "fistulös",
    "fistulösares": "fistulös",
    "fistulösas": "fistulös",
    "fistulösast": "fistulös",
    "fistulösaste": "fistulös",
    "fistulösastes": "fistulös",
    "fistulösasts": "fistulös",
    "fistulöse": "fistulös",
    "fistulöses": "fistulös",
    "fistulöst": "fistulös",
    "fistulösts": "fistulös",
    "fit": "fi",
    "fits": "fi",
    "fitt": "fitta",
    "fittan": "fitta",
    "fittans": "fitta",
    "fittas": "fitta",
    "fitte": "fitta",
    "fittor": "fitta",
    "fittorna": "fitta",
    "fittornas": "fitta",
    "fittors": "fitta",
    "fittrakten": "fittrakt",
    "fittraktens": "fittrakt",
    "fittrakter": "fittrakt",
    "fittrakterna": "fittrakt",
    "fittrakternas": "fittrakt",
    "fittrakters": "fittrakt",
    "fittrakts": "fittrakt",
    "fitts": "fitta",
    "fittstimen": "fittstim",
    "fittstimens": "fittstim",
    "fittstimet": "fittstim",
    "fittstimets": "fittstim",
    "fittstims": "fittstim",
    "fix": "fixa",
    "fixa": "fix",
    "fixad": "fixa",
    "fixade": "fixa",
    "fixades": "fixa",
    "fixads": "fixa",
    "fixande": "fixa",
    "fixanden": "fixande",
    "fixandena": "fixande",
    "fixandenas": "fixande",
    "fixandens": "fixande",
    "fixandes": "fixande",
    "fixandet": "fixande",
    "fixandets": "fixande",
    "fixar": "fixare",
    "fixare": "fix",
    "fixaren": "fixare",
    "fixarens": "fixare",
    "fixares": "fixare",
    "fixarna": "fixare",
    "fixarnas": "fixare",
    "fixars": "fix",
    "fixas": "fixa",
    "fixast": "fix",
    "fixaste": "fix",
    "fixastes": "fix",
    "fixasts": "fix",
    "fixat": "fixa",
    "fixativen": "fixativ",
    "fixativens": "fixativ",
    "fixativet": "fixativ",
    "fixativets": "fixativ",
    "fixativs": "fixativ",
    "fixats": "fixa",
    "fixe": "fix",
    "fixen": "fix",
    "fixens": "fix",
    "fixerad": "fixera",
    "fixerade": "fixerad",
    "fixerades": "fixerad",
    "fixerads": "fixerad",
    "fixerande": "fixera",
    "fixeranden": "fixerande",
    "fixerandena": "fixerande",
    "fixerandenas": "fixerande",
    "fixerandens": "fixerande",
    "fixerandes": "fixerande",
    "fixerandet": "fixerande",
    "fixerandets": "fixerande",
    "fixerar": "fixera",
    "fixeras": "fixera",
    "fixerat": "fixerad",
    "fixerats": "fixerad",
    "fixerbaden": "fixerbad",
    "fixerbadens": "fixerbad",
    "fixerbadet": "fixerbad",
    "fixerbadets": "fixerbad",
    "fixerbads": "fixerbad",
    "fixerbara": "fixerbar",
    "fixerbarare": "fixerbar",
    "fixerbarares": "fixerbar",
    "fixerbaras": "fixerbar",
    "fixerbarast": "fixerbar",
    "fixerbaraste": "fixerbar",
    "fixerbarastes": "fixerbar",
    "fixerbarasts": "fixerbar",
    "fixerbare": "fixerbar",
    "fixerbares": "fixerbar",
    "fixerbarheten": "fixerbarhet",
    "fixerbarhetens": "fixerbarhet",
    "fixerbarhets": "fixerbarhet",
    "fixerbars": "fixerbar",
    "fixerbart": "fixerbar",
    "fixerbarts": "fixerbar",
    "fixeringar": "fixering",
    "fixeringarna": "fixering",
    "fixeringarnas": "fixering",
    "fixeringars": "fixering",
    "fixeringen": "fixering",
    "fixeringens": "fixering",
    "fixerings": "fixering",
    "fixeringsbilden": "fixeringsbild",
    "fixeringsbildens": "fixeringsbild",
    "fixeringsbilder": "fixeringsbild",
    "fixeringsbilderna": "fixeringsbild",
    "fixeringsbildernas": "fixeringsbild",
    "fixeringsbilders": "fixeringsbild",
    "fixeringsbilds": "fixeringsbild",
    "fixes": "fix",
    "fixet": "fix",
    "fixets": "fix",
    "fixheten": "fixhet",
    "fixhetens": "fixhet",
    "fixhets": "fixhet",
    "fixkammar": "fixkam",
    "fixkammarna": "fixkam",
    "fixkammarnas": "fixkam",
    "fixkammars": "fixkam",
    "fixkammen": "fixkam",
    "fixkammens": "fixkam",
    "fixkams": "fixkam",
    "fixpunkten": "fixpunkt",
    "fixpunktens": "fixpunkt",
    "fixpunkter": "fixpunkt",
    "fixpunkterna": "fixpunkt",
    "fixpunkternas": "fixpunkt",
    "fixpunkters": "fixpunkt",
    "fixpunkts": "fixpunkt",
    "fixstjärnan": "fixstjärna",
    "fixstjärnans": "fixstjärna",
    "fixstjärnas": "fixstjärna",
    "fixstjärne": "fixstjärna",
    "fixstjärnor": "fixstjärna",
    "fixstjärnorna": "fixstjärna",
    "fixstjärnornas": "fixstjärna",
    "fixstjärnors": "fixstjärna",
    "fixt": "fix",
    "fixts": "fix",
    "fixturen": "fixtur",
    "fixturens": "fixtur",
    "fixturer": "fixtur",
    "fixturerna": "fixtur",
    "fixturernas": "fixtur",
    "fixturers": "fixtur",
    "fixturs": "fixtur",
    "fjant": "fjanta",
    "fjantade": "fjanta",
    "fjantades": "fjanta",
    "fjantande": "fjanta",
    "fjantanden": "fjantande",
    "fjantandena": "fjantande",
    "fjantandenas": "fjantande",
    "fjantandens": "fjantande",
    "fjantandes": "fjantande",
    "fjantandet": "fjantande",
    "fjantandets": "fjantande",
    "fjantar": "fjanta",
    "fjantarna": "fjant",
    "fjantarnas": "fjant",
    "fjantars": "fjant",
    "fjantas": "fjanta",
    "fjantat": "fjanta",
    "fjantats": "fjanta",
    "fjanten": "fjant",
    "fjantens": "fjant",
    "fjanterier": "fjanteri",
    "fjanterierna": "fjanteri",
    "fjanteriernas": "fjanteri",
    "fjanteriers": "fjanteri",
    "fjanteriet": "fjanteri",
    "fjanteriets": "fjanteri",
    "fjanteris": "fjanteri",
    "fjanterit": "fjanteri",
    "fjanterits": "fjanteri",
    "fjantiga": "fjantig",
    "fjantigare": "fjantig",
    "fjantigares": "fjantig",
    "fjantigas": "fjantig",
    "fjantigast": "fjantig",
    "fjantigaste": "fjantig",
    "fjantigastes": "fjantig",
    "fjantigasts": "fjantig",
    "fjantige": "fjantig",
    "fjantiges": "fjantig",
    "fjantigheten": "fjantighet",
    "fjantighetens": "fjantighet",
    "fjantighets": "fjantighet",
    "fjantigs": "fjantig",
    "fjantigt": "fjantig",
    "fjantigts": "fjantig",
    "fjants": "fjant",
    "fjoll": "fjolla",
    "fjollades": "fjollas",
    "fjollan": "fjolla",
    "fjollans": "fjolla",
    "fjollas": "fjolla",
    "fjollats": "fjollas",
    "fjolle": "fjolla",
    "fjollerier": "fjolleri",
    "fjollerierna": "fjolleri",
    "fjolleriernas": "fjolleri",
    "fjolleriers": "fjolleri",
    "fjolleriet": "fjolleri",
    "fjolleriets": "fjolleri",
    "fjolleris": "fjolleri",
    "fjollerit": "fjolleri",
    "fjollerits": "fjolleri",
    "fjolliga": "fjollig",
    "fjolligare": "fjollig",
    "fjolligares": "fjollig",
    "fjolligas": "fjollig",
    "fjolligast": "fjollig",
    "fjolligaste": "fjollig",
    "fjolligastes": "fjollig",
    "fjolligasts": "fjollig",
    "fjollige": "fjollig",
    "fjolliges": "fjollig",
    "fjolligheten": "fjollighet",
    "fjollighetens": "fjollighet",
    "fjolligheter": "fjollighet",
    "fjolligheterna": "fjollighet",
    "fjolligheternas": "fjollighet",
    "fjolligheters": "fjollighet",
    "fjollighets": "fjollighet",
    "fjolligs": "fjollig",
    "fjolligt": "fjollig",
    "fjolligts": "fjollig",
    "fjollor": "fjolla",
    "fjollorna": "fjolla",
    "fjollornas": "fjolla",
    "fjollors": "fjolla",
    "fjolls": "fjolla",
    "fjolåren": "fjolår",
    "fjolårens": "fjolår",
    "fjolåret": "fjolår",
    "fjolårets": "fjolår",
    "fjolårs": "fjolår",
    "fjolårsgräsen": "fjolårsgräs",
    "fjolårsgräsens": "fjolårsgräs",
    "fjolårsgräset": "fjolårsgräs",
    "fjolårsgräsets": "fjolårsgräs",
    "fjomperier": "fjomperi",
    "fjomperierna": "fjomperi",
    "fjomperiernas": "fjomperi",
    "fjomperiers": "fjomperi",
    "fjomperiet": "fjomperi",
    "fjomperiets": "fjomperi",
    "fjomperis": "fjomperi",
    "fjomperit": "fjomperi",
    "fjomperits": "fjomperi",
    "fjompiga": "fjompig",
    "fjompigare": "fjompig",
    "fjompigares": "fjompig",
    "fjompigas": "fjompig",
    "fjompigast": "fjompig",
    "fjompigaste": "fjompig",
    "fjompigastes": "fjompig",
    "fjompigasts": "fjompig",
    "fjompige": "fjompig",
    "fjompiges": "fjompig",
    "fjompigheten": "fjompighet",
    "fjompighetens": "fjompighet",
    "fjompighets": "fjompighet",
    "fjompigs": "fjompig",
    "fjompigt": "fjompig",
    "fjompigts": "fjompig",
    "fjongen": "fjong",
    "fjongens": "fjong",
    "fjonget": "fjong",
    "fjongets": "fjong",
    "fjongs": "fjong",
    "fjordar": "fjord",
    "fjordarna": "fjord",
    "fjordarnas": "fjord",
    "fjordars": "fjord",
    "fjorden": "fjord",
    "fjordens": "fjord",
    "fjordhästar": "fjordhäst",
    "fjordhästarna": "fjordhäst",
    "fjordhästarnas": "fjordhäst",
    "fjordhästars": "fjordhäst",
    "fjordhästen": "fjordhäst",
    "fjordhästens": "fjordhäst",
    "fjordhästs": "fjordhäst",
    "fjordingar": "fjording",
    "fjordingarna": "fjording",
    "fjordingarnas": "fjording",
    "fjordingars": "fjording",
    "fjordingen": "fjording",
    "fjordingens": "fjording",
    "fjordings": "fjording",
    "fjords": "fjord",
    "fjortonde": "fjorton",
    "fjortondes": "fjorton",
    "fjortonhundratalet": "fjortonhundratal",
    "fjortonhundratalets": "fjortonhundratal",
    "fjortonhundratals": "fjortonhundratal",
    "fjortons": "fjorton",
    "fjortonsnårets": "fjortonsnåret",
    "fjortonåriga": "fjortonårig",
    "fjortonårigas": "fjortonårig",
    "fjortonårige": "fjortonårig",
    "fjortonåriges": "fjortonårig",
    "fjortonårigs": "fjortonårig",
    "fjortonårigt": "fjortonårig",
    "fjortonårigts": "fjortonårig",
    "fjortonåringar": "fjortonåring",
    "fjortonåringarna": "fjortonåring",
    "fjortonåringarnas": "fjortonåring",
    "fjortonåringars": "fjortonåring",
    "fjortonåringen": "fjortonåring",
    "fjortonåringens": "fjortonåring",
    "fjortonårings": "fjortonåring",
    "fjunen": "fjun",
    "fjunens": "fjun",
    "fjunet": "fjun",
    "fjunets": "fjun",
    "fjuniga": "fjunig",
    "fjunigare": "fjunig",
    "fjunigares": "fjunig",
    "fjunigas": "fjunig",
    "fjunigast": "fjunig",
    "fjunigaste": "fjunig",
    "fjunigastes": "fjunig",
    "fjunigasts": "fjunig",
    "fjunige": "fjunig",
    "fjuniges": "fjunig",
    "fjunigs": "fjunig",
    "fjunigt": "fjunig",
    "fjunigts": "fjunig",
    "fjuns": "fjun",
    "fjuttiga": "fjuttig",
    "fjuttigare": "fjuttig",
    "fjuttigares": "fjuttig",
    "fjuttigas": "fjuttig",
    "fjuttigast": "fjuttig",
    "fjuttigaste": "fjuttig",
    "fjuttigastes": "fjuttig",
    "fjuttigasts": "fjuttig",
    "fjuttige": "fjuttig",
    "fjuttiges": "fjuttig",
    "fjuttigheten": "fjuttighet",
    "fjuttighetens": "fjuttighet",
    "fjuttighets": "fjuttighet",
    "fjuttigs": "fjuttig",
    "fjuttigt": "fjuttig",
    "fjuttigts": "fjuttig",
    "fjäderbollar": "fjäderboll",
    "fjäderbollarna": "fjäderboll",
    "fjäderbollarnas": "fjäderboll",
    "fjäderbollars": "fjäderboll",
    "fjäderbollen": "fjäderboll",
    "fjäderbollens": "fjäderboll",
    "fjäderbolls": "fjäderboll",
    "fjäderbusk": "fjäderbuske",
    "fjäderbuskar": "fjäderbuske",
    "fjäderbuskarna": "fjäderbuske",
    "fjäderbuskarnas": "fjäderbuske",
    "fjäderbuskars": "fjäderbuske",
    "fjäderbusken": "fjäderbuske",
    "fjäderbuskens": "fjäderbuske",
    "fjäderbuskes": "fjäderbuske",
    "fjäderdos": "fjäderdosa",
    "fjäderdosan": "fjäderdosa",
    "fjäderdosans": "fjäderdosa",
    "fjäderdosas": "fjäderdosa",
    "fjäderdose": "fjäderdosa",
    "fjäderdosor": "fjäderdosa",
    "fjäderdosorna": "fjäderdosa",
    "fjäderdosornas": "fjäderdosa",
    "fjäderdosors": "fjäderdosa",
    "fjäderdräkten": "fjäderdräkt",
    "fjäderdräktens": "fjäderdräkt",
    "fjäderdräkter": "fjäderdräkt",
    "fjäderdräkterna": "fjäderdräkt",
    "fjäderdräkternas": "fjäderdräkt",
    "fjäderdräkters": "fjäderdräkt",
    "fjäderdräkts": "fjäderdräkt",
    "fjäderformade": "fjäderformad",
    "fjäderformades": "fjäderformad",
    "fjäderformads": "fjäderformad",
    "fjäderformat": "fjäderformad",
    "fjäderformats": "fjäderformad",
    "fjäderfäet": "fjäderfä",
    "fjäderfäets": "fjäderfä",
    "fjäderfän": "fjäderfä",
    "fjäderfäna": "fjäderfä",
    "fjäderfänas": "fjäderfä",
    "fjäderfäns": "fjäderfä",
    "fjäderfäs": "fjäderfä",
    "fjäderfät": "fjäderfä",
    "fjäderfäts": "fjäderfä",
    "fjädergräset": "fjädergräs",
    "fjädergräsets": "fjädergräs",
    "fjäderklädda": "fjäderklädd",
    "fjäderkläddare": "fjäderklädd",
    "fjäderkläddares": "fjäderklädd",
    "fjäderkläddas": "fjäderklädd",
    "fjäderkläddast": "fjäderklädd",
    "fjäderkläddaste": "fjäderklädd",
    "fjäderkläddastes": "fjäderklädd",
    "fjäderkläddasts": "fjäderklädd",
    "fjäderklädde": "fjäderklädd",
    "fjäderkläddes": "fjäderklädd",
    "fjäderklädds": "fjäderklädd",
    "fjäderklätt": "fjäderklädd",
    "fjäderklätts": "fjäderklädd",
    "fjäderlätta": "fjäderlätt",
    "fjäderlättare": "fjäderlätt",
    "fjäderlättares": "fjäderlätt",
    "fjäderlättas": "fjäderlätt",
    "fjäderlättast": "fjäderlätt",
    "fjäderlättaste": "fjäderlätt",
    "fjäderlättastes": "fjäderlätt",
    "fjäderlättasts": "fjäderlätt",
    "fjäderlätte": "fjäderlätt",
    "fjäderlättes": "fjäderlätt",
    "fjäderlättheten": "fjäderlätthet",
    "fjäderlätthetens": "fjäderlätthet",
    "fjäderlätthets": "fjäderlätthet",
    "fjäderlätts": "fjäderlätt",
    "fjädermolnen": "fjädermoln",
    "fjädermolnens": "fjädermoln",
    "fjädermolnet": "fjädermoln",
    "fjädermolnets": "fjädermoln",
    "fjädermolns": "fjädermoln",
    "fjädermygg": "fjädermygga",
    "fjädermyggan": "fjädermygga",
    "fjädermyggans": "fjädermygga",
    "fjädermyggas": "fjädermygga",
    "fjädermygge": "fjädermygga",
    "fjädermyggor": "fjädermygga",
    "fjädermyggorna": "fjädermygga",
    "fjädermyggornas": "fjädermygga",
    "fjädermyggors": "fjädermygga",
    "fjädermyggs": "fjädermygga",
    "fjädern": "fjäder",
    "fjäderns": "fjäder",
    "fjäderpenseln": "fjäderpensel",
    "fjäderpenselns": "fjäderpensel",
    "fjäderpensels": "fjäderpensel",
    "fjäderpenslar": "fjäderpensel",
    "fjäderpenslarna": "fjäderpensel",
    "fjäderpenslarnas": "fjäderpensel",
    "fjäderpenslars": "fjäderpensel",
    "fjäders": "fjäder",
    "fjäderskrudar": "fjäderskrud",
    "fjäderskrudarna": "fjäderskrud",
    "fjäderskrudarnas": "fjäderskrud",
    "fjäderskrudars": "fjäderskrud",
    "fjäderskruden": "fjäderskrud",
    "fjäderskrudens": "fjäderskrud",
    "fjäderskruds": "fjäderskrud",
    "fjädertypen": "fjädertyp",
    "fjädertypens": "fjädertyp",
    "fjädertyper": "fjädertyp",
    "fjädertyperna": "fjädertyp",
    "fjädertypernas": "fjädertyp",
    "fjädertypers": "fjädertyp",
    "fjädertyps": "fjädertyp",
    "fjädervikten": "fjädervikt",
    "fjäderviktens": "fjädervikt",
    "fjädervikts": "fjädervikt",
    "fjäderving": "fjädervinge",
    "fjädervingar": "fjädervinge",
    "fjädervingarna": "fjädervinge",
    "fjädervingarnas": "fjädervinge",
    "fjädervingars": "fjädervinge",
    "fjädervingen": "fjädervinge",
    "fjädervingens": "fjädervinge",
    "fjädervinges": "fjädervinge",
    "fjädervings": "fjädervinge",
    "fjädervågar": "fjädervåg",
    "fjädervågarna": "fjädervåg",
    "fjädervågarnas": "fjädervåg",
    "fjädervågars": "fjädervåg",
    "fjädervågen": "fjädervåg",
    "fjädervågens": "fjädervåg",
    "fjädervågs": "fjädervåg",
    "fjädrade": "fjädra",
    "fjädrades": "fjädra",
    "fjädrande": "fjädra",
    "fjädranden": "fjädrande",
    "fjädrandena": "fjädrande",
    "fjädrandenas": "fjädrande",
    "fjädrandens": "fjädrande",
    "fjädrandes": "fjädrande",
    "fjädrandet": "fjädrande",
    "fjädrandets": "fjädrande",
    "fjädrar": "fjädra",
    "fjädrarna": "fjäder",
    "fjädrarnas": "fjäder",
    "fjädrars": "fjäder",
    "fjädras": "fjädra",
    "fjädrat": "fjädra",
    "fjädrats": "fjädra",
    "fjädringar": "fjädring",
    "fjädringarna": "fjädring",
    "fjädringarnas": "fjädring",
    "fjädringars": "fjädring",
    "fjädringen": "fjädring",
    "fjädringens": "fjädring",
    "fjädrings": "fjädring",
    "fjädringskapaciteten": "fjädringskapacitet",
    "fjädringskapacitetens": "fjädringskapacitet",
    "fjädringskapacitets": "fjädringskapacitet",
    "fjädringsmekanismen": "fjädringsmekanism",
    "fjädringsmekanismens": "fjädringsmekanism",
    "fjädringsmekanismer": "fjädringsmekanism",
    "fjädringsmekanismerna": "fjädringsmekanism",
    "fjädringsmekanismernas": "fjädringsmekanism",
    "fjädringsmekanismers": "fjädringsmekanism",
    "fjädringsmekanisms": "fjädringsmekanism",
    "fjäll": "fjälla",
    "fjällad": "fjälla",
    "fjällade": "fjälla",
    "fjällades": "fjälla",
    "fjällads": "fjälla",
    "fjällan": "fjälla",
    "fjällande": "fjälla",
    "fjällanden": "fjällande",
    "fjällandena": "fjällande",
    "fjällandenas": "fjällande",
    "fjällandens": "fjällande",
    "fjällandes": "fjällande",
    "fjällandet": "fjällande",
    "fjällandets": "fjällande",
    "fjällans": "fjälla",
    "fjällar": "fjälla",
    "fjällas": "fjälla",
    "fjällat": "fjälla",
    "fjällats": "fjälla",
    "fjällbjörkar": "fjällbjörk",
    "fjällbjörkarna": "fjällbjörk",
    "fjällbjörkarnas": "fjällbjörk",
    "fjällbjörkars": "fjällbjörk",
    "fjällbjörken": "fjällbjörk",
    "fjällbjörkens": "fjällbjörk",
    "fjällbjörks": "fjällbjörk",
    "fjällbrudar": "fjällbrud",
    "fjällbrudarna": "fjällbrud",
    "fjällbrudarnas": "fjällbrud",
    "fjällbrudars": "fjällbrud",
    "fjällbruden": "fjällbrud",
    "fjällbrudens": "fjällbrud",
    "fjällbruds": "fjällbrud",
    "fjällbäckar": "fjällbäck",
    "fjällbäckarna": "fjällbäck",
    "fjällbäckarnas": "fjällbäck",
    "fjällbäckars": "fjällbäck",
    "fjällbäcken": "fjällbäck",
    "fjällbäckens": "fjällbäck",
    "fjällbäcks": "fjällbäck",
    "fjälle": "fjälla",
    "fjällen": "fjäll",
    "fjällens": "fjäll",
    "fjället": "fjäll",
    "fjällets": "fjäll",
    "fjälliga": "fjällig",
    "fjälligare": "fjällig",
    "fjälligares": "fjällig",
    "fjälligas": "fjällig",
    "fjälligast": "fjällig",
    "fjälligaste": "fjällig",
    "fjälligastes": "fjällig",
    "fjälligasts": "fjällig",
    "fjällige": "fjällig",
    "fjälliges": "fjällig",
    "fjälligheten": "fjällighet",
    "fjällighetens": "fjällighet",
    "fjällighets": "fjällighet",
    "fjälligs": "fjällig",
    "fjälligt": "fjällig",
    "fjälligts": "fjällig",
    "fjällika": "fjällik",
    "fjällikare": "fjällik",
    "fjällikares": "fjällik",
    "fjällikas": "fjällik",
    "fjällikast": "fjällik",
    "fjällikaste": "fjällik",
    "fjällikastes": "fjällik",
    "fjällikasts": "fjällik",
    "fjällike": "fjällik",
    "fjällikes": "fjällik",
    "fjällikheten": "fjällikhet",
    "fjällikhetens": "fjällikhet",
    "fjällikhets": "fjällikhet",
    "fjälliks": "fjällik",
    "fjällikt": "fjällik",
    "fjällikts": "fjällik",
    "fjällkedjan": "fjällkedja",
    "fjällkedjans": "fjällkedja",
    "fjällkedjas": "fjällkedja",
    "fjällkedje": "fjällkedja",
    "fjällkedjor": "fjällkedja",
    "fjällkedjorna": "fjällkedja",
    "fjällkedjornas": "fjällkedja",
    "fjällkedjors": "fjällkedja",
    "fjällor": "fjälla",
    "fjällorna": "fjälla",
    "fjällornas": "fjälla",
    "fjällors": "fjälla",
    "fjällpanelen": "fjällpanel",
    "fjällpanelens": "fjällpanel",
    "fjällpanels": "fjällpanel",
    "fjällpanelshusen": "fjällpanelshus",
    "fjällpanelshusens": "fjällpanelshus",
    "fjällpanelshuset": "fjällpanelshus",
    "fjällpanelshusets": "fjällpanelshus",
    "fjällpansaren": "fjällpansar",
    "fjällpansarens": "fjällpansar",
    "fjällpansaret": "fjällpansar",
    "fjällpansarets": "fjällpansar",
    "fjällpansarna": "fjällpansar",
    "fjällpansarnas": "fjällpansar",
    "fjällpansars": "fjällpansar",
    "fjällpartier": "fjällparti",
    "fjällpartierna": "fjällparti",
    "fjällpartiernas": "fjällparti",
    "fjällpartiers": "fjällparti",
    "fjällpartiet": "fjällparti",
    "fjällpartiets": "fjällparti",
    "fjällpartis": "fjällparti",
    "fjällpartit": "fjällparti",
    "fjällpartits": "fjällparti",
    "fjällpipar": "fjällpipare",
    "fjällpiparen": "fjällpipare",
    "fjällpiparens": "fjällpipare",
    "fjällpipares": "fjällpipare",
    "fjällpiparna": "fjällpipare",
    "fjällpiparnas": "fjällpipare",
    "fjällplatåer": "fjällplatå",
    "fjällplatåerna": "fjällplatå",
    "fjällplatåernas": "fjällplatå",
    "fjällplatåers": "fjällplatå",
    "fjällplatån": "fjällplatå",
    "fjällplatåns": "fjällplatå",
    "fjällplatås": "fjällplatå",
    "fjällrip": "fjällripa",
    "fjällripan": "fjällripa",
    "fjällripans": "fjällripa",
    "fjällripas": "fjällripa",
    "fjällripe": "fjällripa",
    "fjällripor": "fjällripa",
    "fjällriporna": "fjällripa",
    "fjällripornas": "fjällripa",
    "fjällripors": "fjällripa",
    "fjällrips": "fjällripa",
    "fjällrävar": "fjällräv",
    "fjällrävarna": "fjällräv",
    "fjällrävarnas": "fjällräv",
    "fjällrävars": "fjällräv",
    "fjällräven": "fjällräv",
    "fjällrävens": "fjällräv",
    "fjällrävs": "fjällräv",
    "fjälls": "fjälla",
    "fjällsemestern": "fjällsemester",
    "fjällsemesterns": "fjällsemester",
    "fjällsemesters": "fjällsemester",
    "fjällsemestrar": "fjällsemester",
    "fjällsemestrarna": "fjällsemester",
    "fjällsemestrarnas": "fjällsemester",
    "fjällsemestrars": "fjällsemester",
    "fjällskivlingar": "fjällskivling",
    "fjällskivlingarna": "fjällskivling",
    "fjällskivlingarnas": "fjällskivling",
    "fjällskivlingars": "fjällskivling",
    "fjällskivlingen": "fjällskivling",
    "fjällskivlingens": "fjällskivling",
    "fjällskivlings": "fjällskivling",
    "fjällsluttningar": "fjällsluttning",
    "fjällsluttningarna": "fjällsluttning",
    "fjällsluttningarnas": "fjällsluttning",
    "fjällsluttningars": "fjällsluttning",
    "fjällsluttningen": "fjällsluttning",
    "fjällsluttningens": "fjällsluttning",
    "fjällsluttnings": "fjällsluttning",
    "fjällstugan": "fjällstuga",
    "fjällstugans": "fjällstuga",
    "fjällstugas": "fjällstuga",
    "fjällstuge": "fjällstuga",
    "fjällstugor": "fjällstuga",
    "fjällstugorna": "fjällstuga",
    "fjällstugornas": "fjällstuga",
    "fjällstugors": "fjällstuga",
    "fjällstugu": "fjällstuga",
    "fjällsyran": "fjällsyra",
    "fjällsyrans": "fjällsyra",
    "fjällsyras": "fjällsyra",
    "fjällsyre": "fjällsyra",
    "fjällsyror": "fjällsyra",
    "fjällsyrorna": "fjällsyra",
    "fjällsyrornas": "fjällsyra",
    "fjällsyrors": "fjällsyra",
    "fjälltrakten": "fjälltrakt",
    "fjälltraktens": "fjälltrakt",
    "fjälltrakter": "fjälltrakt",
    "fjälltrakterna": "fjälltrakt",
    "fjälltrakternas": "fjälltrakt",
    "fjälltrakters": "fjälltrakt",
    "fjälltrakts": "fjälltrakt",
    "fjällturisten": "fjällturist",
    "fjällturistens": "fjällturist",
    "fjällturister": "fjällturist",
    "fjällturisterna": "fjällturist",
    "fjällturisternas": "fjällturist",
    "fjällturisters": "fjällturist",
    "fjällturists": "fjällturist",
    "fjällugglan": "fjälluggla",
    "fjällugglans": "fjälluggla",
    "fjällugglas": "fjälluggla",
    "fjälluggle": "fjälluggla",
    "fjällugglor": "fjälluggla",
    "fjällugglorna": "fjälluggla",
    "fjällugglornas": "fjälluggla",
    "fjällugglors": "fjälluggla",
    "fjällvandrade": "fjällvandra",
    "fjällvandrades": "fjällvandra",
    "fjällvandrande": "fjällvandra",
    "fjällvandranden": "fjällvandrande",
    "fjällvandrandena": "fjällvandrande",
    "fjällvandrandenas": "fjällvandrande",
    "fjällvandrandens": "fjällvandrande",
    "fjällvandrandes": "fjällvandrande",
    "fjällvandrandet": "fjällvandrande",
    "fjällvandrandets": "fjällvandrande",
    "fjällvandrar": "fjällvandrare",
    "fjällvandraren": "fjällvandrare",
    "fjällvandrarens": "fjällvandrare",
    "fjällvandrares": "fjällvandrare",
    "fjällvandrarna": "fjällvandrare",
    "fjällvandrarnas": "fjällvandrare",
    "fjällvandras": "fjällvandra",
    "fjällvandrat": "fjällvandra",
    "fjällvandrats": "fjällvandra",
    "fjällvandringar": "fjällvandring",
    "fjällvandringarna": "fjällvandring",
    "fjällvandringarnas": "fjällvandring",
    "fjällvandringars": "fjällvandring",
    "fjällvandringen": "fjällvandring",
    "fjällvandringens": "fjällvandring",
    "fjällvandrings": "fjällvandring",
    "fjällvråkar": "fjällvråk",
    "fjällvråkarna": "fjällvråk",
    "fjällvråkarnas": "fjällvråk",
    "fjällvråkars": "fjällvråk",
    "fjällvråken": "fjällvråk",
    "fjällvråkens": "fjällvråk",
    "fjällvråks": "fjällvråk",
    "fjällvärldar": "fjällvärld",
    "fjällvärldarna": "fjällvärld",
    "fjällvärldarnas": "fjällvärld",
    "fjällvärldars": "fjällvärld",
    "fjällvärlden": "fjällvärld",
    "fjällvärldens": "fjällvärld",
    "fjällvärlds": "fjällvärld",
    "fjällämlar": "fjällämmel",
    "fjällämlarna": "fjällämmel",
    "fjällämlarnas": "fjällämmel",
    "fjällämlars": "fjällämmel",
    "fjällämmeln": "fjällämmel",
    "fjällämmelns": "fjällämmel",
    "fjällämmels": "fjällämmel",
    "fjällämmlar": "fjällämmel",
    "fjällämmlarna": "fjällämmel",
    "fjällämmlarnas": "fjällämmel",
    "fjällämmlars": "fjällämmel",
    "fjälsterna": "fjälster",
    "fjälsternas": "fjälster",
    "fjälsters": "fjälster",
    "fjälstren": "fjälster",
    "fjälstrens": "fjälster",
    "fjälstret": "fjälster",
    "fjälstrets": "fjälster",
    "fjära": "fjär",
    "fjärare": "fjär",
    "fjärares": "fjär",
    "fjäras": "fjär",
    "fjärast": "fjär",
    "fjäraste": "fjär",
    "fjärastes": "fjär",
    "fjärasts": "fjär",
    "fjärdar": "fjärd",
    "fjärdarna": "fjärd",
    "fjärdarnas": "fjärd",
    "fjärdars": "fjärd",
    "fjärde": "fyra",
    "fjärdedelar": "fjärdedel",
    "fjärdedelarna": "fjärdedel",
    "fjärdedelarnas": "fjärdedel",
    "fjärdedelars": "fjärdedel",
    "fjärdedelen": "fjärdedel",
    "fjärdedelens": "fjärdedel",
    "fjärdedels": "fjärdedel",
    "fjärden": "fjärd",
    "fjärdens": "fjärd",
    "fjärdes": "fyra",
    "fjärdingar": "fjärding",
    "fjärdingarna": "fjärding",
    "fjärdingarnas": "fjärding",
    "fjärdingars": "fjärding",
    "fjärdingen": "fjärding",
    "fjärdingens": "fjärding",
    "fjärdings": "fjärding",
    "fjärdingsmannen": "fjärdingsman",
    "fjärdingsmannens": "fjärdingsman",
    "fjärdingsmans": "fjärdingsman",
    "fjärdingsmän": "fjärdingsman",
    "fjärdingsmännen": "fjärdingsman",
    "fjärdingsmännens": "fjärdingsman",
    "fjärdingsmäns": "fjärdingsman",
    "fjärdingsvägen": "fjärdingsväg",
    "fjärdingsvägens": "fjärdingsväg",
    "fjärdingsvägs": "fjärdingsväg",
    "fjärds": "fjärd",
    "fjäre": "fjär",
    "fjäres": "fjär",
    "fjärheten": "fjärhet",
    "fjärhetens": "fjärhet",
    "fjärhets": "fjärhet",
    "fjärilar": "fjäril",
    "fjärilarna": "fjäril",
    "fjärilarnas": "fjäril",
    "fjärilars": "fjäril",
    "fjärilen": "fjäril",
    "fjärilens": "fjäril",
    "fjäriln": "fjäril",
    "fjärilns": "fjäril",
    "fjärils": "fjäril",
    "fjärilsarten": "fjärilsart",
    "fjärilsartens": "fjärilsart",
    "fjärilsarter": "fjärilsart",
    "fjärilsarterna": "fjärilsart",
    "fjärilsarternas": "fjärilsart",
    "fjärilsarters": "fjärilsart",
    "fjärilsarts": "fjärilsart",
    "fjärilsblom": "fjärilsblomma",
    "fjärilsblomman": "fjärilsblomma",
    "fjärilsblommans": "fjärilsblomma",
    "fjärilsblommas": "fjärilsblomma",
    "fjärilsblomme": "fjärilsblomma",
    "fjärilsblommor": "fjärilsblomma",
    "fjärilsblommorna": "fjärilsblomma",
    "fjärilsblommornas": "fjärilsblomma",
    "fjärilsblommors": "fjärilsblomma",
    "fjärilsbloms": "fjärilsblomma",
    "fjärilseffekten": "fjärilseffekt",
    "fjärilseffektens": "fjärilseffekt",
    "fjärilseffekts": "fjärilseffekt",
    "fjärilsimmet": "fjärilsim",
    "fjärilsimmets": "fjärilsim",
    "fjärilsims": "fjärilsim",
    "fjärilslarven": "fjärilslarv",
    "fjärilslarvens": "fjärilslarv",
    "fjärilslarver": "fjärilslarv",
    "fjärilslarverna": "fjärilslarv",
    "fjärilslarvernas": "fjärilslarv",
    "fjärilslarvers": "fjärilslarv",
    "fjärilslarvs": "fjärilslarv",
    "fjärilssimmet": "fjärilssim",
    "fjärilssimmets": "fjärilssim",
    "fjärilssims": "fjärilssim",
    "fjärm": "fjärma",
    "fjärmad": "fjärma",
    "fjärmade": "fjärma",
    "fjärmades": "fjärma",
    "fjärmads": "fjärma",
    "fjärmande": "fjärma",
    "fjärmanden": "fjärmande",
    "fjärmandena": "fjärmande",
    "fjärmandenas": "fjärmande",
    "fjärmandens": "fjärmande",
    "fjärmandes": "fjärmande",
    "fjärmandet": "fjärmande",
    "fjärmandets": "fjärmande",
    "fjärmar": "fjärma",
    "fjärmas": "fjärma",
    "fjärmat": "fjärma",
    "fjärmats": "fjärma",
    "fjärrar": "fjärr",
    "fjärrarna": "fjärr",
    "fjärrarnas": "fjärr",
    "fjärrars": "fjärr",
    "fjärrblockerad": "fjärrblockera",
    "fjärrblockerade": "fjärrblockera",
    "fjärrblockerades": "fjärrblockera",
    "fjärrblockerads": "fjärrblockera",
    "fjärrblockerande": "fjärrblockera",
    "fjärrblockeranden": "fjärrblockerande",
    "fjärrblockerandena": "fjärrblockerande",
    "fjärrblockerandenas": "fjärrblockerande",
    "fjärrblockerandens": "fjärrblockerande",
    "fjärrblockerandes": "fjärrblockerande",
    "fjärrblockerandet": "fjärrblockerande",
    "fjärrblockerandets": "fjärrblockerande",
    "fjärrblockerar": "fjärrblockera",
    "fjärrblockeras": "fjärrblockera",
    "fjärrblockerat": "fjärrblockera",
    "fjärrblockerats": "fjärrblockera",
    "fjärrblockerbara": "fjärrblockerbar",
    "fjärrblockerbarare": "fjärrblockerbar",
    "fjärrblockerbarares": "fjärrblockerbar",
    "fjärrblockerbaras": "fjärrblockerbar",
    "fjärrblockerbarast": "fjärrblockerbar",
    "fjärrblockerbaraste": "fjärrblockerbar",
    "fjärrblockerbarastes": "fjärrblockerbar",
    "fjärrblockerbarasts": "fjärrblockerbar",
    "fjärrblockerbare": "fjärrblockerbar",
    "fjärrblockerbares": "fjärrblockerbar",
    "fjärrblockerbarheten": "fjärrblockerbarhet",
    "fjärrblockerbarhetens": "fjärrblockerbarhet",
    "fjärrblockerbarhets": "fjärrblockerbarhet",
    "fjärrblockerbars": "fjärrblockerbar",
    "fjärrblockerbart": "fjärrblockerbar",
    "fjärrblockerbarts": "fjärrblockerbar",
    "fjärrblockeringar": "fjärrblockering",
    "fjärrblockeringarna": "fjärrblockering",
    "fjärrblockeringarnas": "fjärrblockering",
    "fjärrblockeringars": "fjärrblockering",
    "fjärrblockeringen": "fjärrblockering",
    "fjärrblockeringens": "fjärrblockering",
    "fjärrblockerings": "fjärrblockering",
    "fjärren": "fjärr",
    "fjärrens": "fjärr",
    "fjärrisar": "fjärris",
    "fjärrisarna": "fjärris",
    "fjärrisarnas": "fjärris",
    "fjärrisars": "fjärris",
    "fjärrisen": "fjärris",
    "fjärrisens": "fjärris",
    "fjärrkontrollen": "fjärrkontroll",
    "fjärrkontrollens": "fjärrkontroll",
    "fjärrkontroller": "fjärrkontroll",
    "fjärrkontrollerna": "fjärrkontroll",
    "fjärrkontrollernas": "fjärrkontroll",
    "fjärrkontrollers": "fjärrkontroll",
    "fjärrkontrolls": "fjärrkontroll",
    "fjärrpunkten": "fjärrpunkt",
    "fjärrpunktens": "fjärrpunkt",
    "fjärrpunkter": "fjärrpunkt",
    "fjärrpunkterna": "fjärrpunkt",
    "fjärrpunkternas": "fjärrpunkt",
    "fjärrpunkters": "fjärrpunkt",
    "fjärrpunkts": "fjärrpunkt",
    "fjärrs": "fjärr",
    "fjärrskrivar": "fjärrskrivare",
    "fjärrskrivaren": "fjärrskrivare",
    "fjärrskrivarens": "fjärrskrivare",
    "fjärrskrivares": "fjärrskrivare",
    "fjärrskrivarna": "fjärrskrivare",
    "fjärrskrivarnas": "fjärrskrivare",
    "fjärrskrivmaskinen": "fjärrskrivmaskin",
    "fjärrskrivmaskinens": "fjärrskrivmaskin",
    "fjärrskrivmaskiner": "fjärrskrivmaskin",
    "fjärrskrivmaskinerna": "fjärrskrivmaskin",
    "fjärrskrivmaskinernas": "fjärrskrivmaskin",
    "fjärrskrivmaskiners": "fjärrskrivmaskin",
    "fjärrskrivmaskins": "fjärrskrivmaskin",
    "fjärrskådar": "fjärrskådare",
    "fjärrskådaren": "fjärrskådare",
    "fjärrskådarens": "fjärrskådare",
    "fjärrskådares": "fjärrskådare",
    "fjärrskådarna": "fjärrskådare",
    "fjärrskådarnas": "fjärrskådare",
    "fjärrströmbrytar": "fjärrströmbrytare",
    "fjärrströmbrytaren": "fjärrströmbrytare",
    "fjärrströmbrytarens": "fjärrströmbrytare",
    "fjärrströmbrytares": "fjärrströmbrytare",
    "fjärrströmbrytarna": "fjärrströmbrytare",
    "fjärrströmbrytarnas": "fjärrströmbrytare",
    "fjärrstyrda": "fjärrstyrd",
    "fjärrstyrdare": "fjärrstyrd",
    "fjärrstyrdares": "fjärrstyrd",
    "fjärrstyrdas": "fjärrstyrd",
    "fjärrstyrdast": "fjärrstyrd",
    "fjärrstyrdaste": "fjärrstyrd",
    "fjärrstyrdastes": "fjärrstyrd",
    "fjärrstyrdasts": "fjärrstyrd",
    "fjärrstyrde": "fjärrstyrd",
    "fjärrstyrdes": "fjärrstyrd",
    "fjärrstyrds": "fjärrstyrd",
    "fjärrstyrt": "fjärrstyrd",
    "fjärrstyrts": "fjärrstyrd",
    "fjärrtrafiken": "fjärrtrafik",
    "fjärrtrafikens": "fjärrtrafik",
    "fjärrtrafiks": "fjärrtrafik",
    "fjärrtågen": "fjärrtåg",
    "fjärrtågens": "fjärrtåg",
    "fjärrtåget": "fjärrtåg",
    "fjärrtågets": "fjärrtåg",
    "fjärrtågs": "fjärrtåg",
    "fjärrvärmegranskningar": "fjärrvärmegranskning",
    "fjärrvärmegranskningarna": "fjärrvärmegranskning",
    "fjärrvärmegranskningarnas": "fjärrvärmegranskning",
    "fjärrvärmegranskningars": "fjärrvärmegranskning",
    "fjärrvärmegranskningen": "fjärrvärmegranskning",
    "fjärrvärmegranskningens": "fjärrvärmegranskning",
    "fjärrvärmegransknings": "fjärrvärmegranskning",
    "fjärrvärmen": "fjärrvärme",
    "fjärrvärmens": "fjärrvärme",
    "fjärrvärmepriser": "fjärrvärmepris",
    "fjärrvärmepriserna": "fjärrvärmepris",
    "fjärrvärmeprisernas": "fjärrvärmepris",
    "fjärrvärmeprisers": "fjärrvärmepris",
    "fjärrvärmepriset": "fjärrvärmepris",
    "fjärrvärmeprisets": "fjärrvärmepris",
    "fjärrvärmes": "fjärrvärme",
    "fjärs": "fjär",
    "fjärsingar": "fjärsing",
    "fjärsingarna": "fjärsing",
    "fjärsingarnas": "fjärsing",
    "fjärsingars": "fjärsing",
    "fjärsingen": "fjärsing",
    "fjärsingens": "fjärsing",
    "fjärsings": "fjärsing",
    "fjärt": "fjärta",
    "fjärtade": "fjärta",
    "fjärtades": "fjärta",
    "fjärtande": "fjärta",
    "fjärtanden": "fjärtande",
    "fjärtandena": "fjärtande",
    "fjärtandenas": "fjärtande",
    "fjärtandens": "fjärtande",
    "fjärtandes": "fjärtande",
    "fjärtandet": "fjärtande",
    "fjärtandets": "fjärtande",
    "fjärtar": "fjärta",
    "fjärtarna": "fjärt",
    "fjärtarnas": "fjärt",
    "fjärtars": "fjärt",
    "fjärtas": "fjärta",
    "fjärtat": "fjärta",
    "fjärtats": "fjärta",
    "fjärten": "fjärt",
    "fjärtens": "fjärt",
    "fjärts": "fjärt",
    "fjäsk": "fjäska",
    "fjäskade": "fjäska",
    "fjäskades": "fjäska",
    "fjäskande": "fjäska",
    "fjäskanden": "fjäskande",
    "fjäskandena": "fjäskande",
    "fjäskandenas": "fjäskande",
    "fjäskandens": "fjäskande",
    "fjäskandes": "fjäskande",
    "fjäskandet": "fjäskande",
    "fjäskandets": "fjäskande",
    "fjäskar": "fjäsker",
    "fjäskarna": "fjäsker",
    "fjäskarnas": "fjäsker",
    "fjäskars": "fjäsker",
    "fjäskas": "fjäska",
    "fjäskat": "fjäska",
    "fjäskats": "fjäska",
    "fjäskern": "fjäsker",
    "fjäskerns": "fjäsker",
    "fjäskers": "fjäsker",
    "fjäsket": "fjäsk",
    "fjäskets": "fjäsk",
    "fjäskiga": "fjäskig",
    "fjäskigare": "fjäskig",
    "fjäskigares": "fjäskig",
    "fjäskigas": "fjäskig",
    "fjäskigast": "fjäskig",
    "fjäskigaste": "fjäskig",
    "fjäskigastes": "fjäskig",
    "fjäskigasts": "fjäskig",
    "fjäskige": "fjäskig",
    "fjäskiges": "fjäskig",
    "fjäskigheten": "fjäskighet",
    "fjäskighetens": "fjäskighet",
    "fjäskighets": "fjäskighet",
    "fjäskigs": "fjäskig",
    "fjäskigt": "fjäskig",
    "fjäskigts": "fjäskig",
    "fjäskrar": "fjäsker",
    "fjäskrarna": "fjäsker",
    "fjäskrarnas": "fjäsker",
    "fjäskrars": "fjäsker",
    "fjäsks": "fjäsk",
    "fjäten": "fjät",
    "fjätens": "fjät",
    "fjätet": "fjät",
    "fjätets": "fjät",
    "fjäts": "fjät",
    "fjätter": "fjättra",
    "fjättrad": "fjättra",
    "fjättrade": "fjättra",
    "fjättrades": "fjättra",
    "fjättrads": "fjättra",
    "fjättrande": "fjättra",
    "fjättranden": "fjättrande",
    "fjättrandena": "fjättrande",
    "fjättrandenas": "fjättrande",
    "fjättrandens": "fjättrande",
    "fjättrandes": "fjättrande",
    "fjättrandet": "fjättrande",
    "fjättrandets": "fjättrande",
    "fjättrar": "fjättra",
    "fjättrarna": "fjättrar",
    "fjättrarnas": "fjättrar",
    "fjättrars": "fjättrar",
    "fjättras": "fjättra",
    "fjättrat": "fjättra",
    "fjättrats": "fjättra",
    "fjöl": "fjöla",
    "fjölade": "fjöla",
    "fjölades": "fjöla",
    "fjölande": "fjöla",
    "fjölandes": "fjöla",
    "fjölar": "fjöla",
    "fjölarna": "fjöl",
    "fjölarnas": "fjöl",
    "fjölars": "fjöl",
    "fjölas": "fjöla",
    "fjölat": "fjöla",
    "fjölats": "fjöla",
    "fjölen": "fjöl",
    "fjölens": "fjöl",
    "fjöls": "fjöl",
    "flabb": "flabba",
    "flabbade": "flabba",
    "flabbades": "flabba",
    "flabbande": "flabba",
    "flabbanden": "flabbande",
    "flabbandena": "flabbande",
    "flabbandenas": "flabbande",
    "flabbandens": "flabbande",
    "flabbandes": "flabbande",
    "flabbandet": "flabbande",
    "flabbandets": "flabbande",
    "flabbar": "flabba",
    "flabbarna": "flabb",
    "flabbarnas": "flabb",
    "flabbars": "flabb",
    "flabbas": "flabba",
    "flabbat": "flabba",
    "flabbats": "flabba",
    "flabben": "flabb",
    "flabbens": "flabb",
    "flabbet": "flabb",
    "flabbets": "flabb",
    "flabbiga": "flabbig",
    "flabbigare": "flabbig",
    "flabbigares": "flabbig",
    "flabbigas": "flabbig",
    "flabbigast": "flabbig",
    "flabbigaste": "flabbig",
    "flabbigastes": "flabbig",
    "flabbigasts": "flabbig",
    "flabbige": "flabbig",
    "flabbiges": "flabbig",
    "flabbigheten": "flabbighet",
    "flabbighetens": "flabbighet",
    "flabbighets": "flabbighet",
    "flabbigs": "flabbig",
    "flabbigt": "flabbig",
    "flabbigts": "flabbig",
    "flabbs": "flabb",
    "flacka": "flack",
    "flackade": "flacka",
    "flackades": "flacka",
    "flackande": "flacka",
    "flackanden": "flackande",
    "flackandena": "flackande",
    "flackandenas": "flackande",
    "flackandens": "flackande",
    "flackandes": "flackande",
    "flackandet": "flackande",
    "flackandets": "flackande",
    "flackar": "flacka",
    "flackare": "flack",
    "flackares": "flack",
    "flackas": "flacka",
    "flackast": "flack",
    "flackaste": "flack",
    "flackastes": "flack",
    "flackasts": "flack",
    "flackat": "flacka",
    "flackats": "flacka",
    "flackbanepjäsen": "flackbanepjäs",
    "flackbanepjäsens": "flackbanepjäs",
    "flackbanepjäser": "flackbanepjäs",
    "flackbanepjäserna": "flackbanepjäs",
    "flackbanepjäsernas": "flackbanepjäs",
    "flackbanepjäsers": "flackbanepjäs",
    "flacke": "flack",
    "flackelden": "flackeld",
    "flackeldens": "flackeld",
    "flackelds": "flackeld",
    "flackes": "flack",
    "flackheten": "flackhet",
    "flackhetens": "flackhet",
    "flackhets": "flackhet",
    "flacks": "flack",
    "flackt": "flack",
    "flackts": "flack",
    "fladder": "fladdra",
    "fladdermusen": "fladdermus",
    "fladdermusens": "fladdermus",
    "fladdermusfåtöljen": "fladdermusfåtölj",
    "fladdermusfåtöljens": "fladdermusfåtölj",
    "fladdermusfåtöljer": "fladdermusfåtölj",
    "fladdermusfåtöljerna": "fladdermusfåtölj",
    "fladdermusfåtöljernas": "fladdermusfåtölj",
    "fladdermusfåtöljers": "fladdermusfåtölj",
    "fladdermusfåtöljs": "fladdermusfåtölj",
    "fladdermöss": "fladdermus",
    "fladdermössen": "fladdermus",
    "fladdermössens": "fladdermus",
    "fladders": "fladder",
    "fladdrade": "fladdra",
    "fladdrades": "fladdra",
    "fladdrande": "fladdra",
    "fladdranden": "fladdrande",
    "fladdrandena": "fladdrande",
    "fladdrandenas": "fladdrande",
    "fladdrandens": "fladdrande",
    "fladdrandes": "fladdrande",
    "fladdrandet": "fladdrande",
    "fladdrandets": "fladdrande",
    "fladdrar": "fladdra",
    "fladdras": "fladdra",
    "fladdrat": "fladdra",
    "fladdrats": "fladdra",
    "fladdret": "fladder",
    "fladdrets": "fladder",
    "fladdriga": "fladdrig",
    "fladdrigare": "fladdrig",
    "fladdrigares": "fladdrig",
    "fladdrigas": "fladdrig",
    "fladdrigast": "fladdrig",
    "fladdrigaste": "fladdrig",
    "fladdrigastes": "fladdrig",
    "fladdrigasts": "fladdrig",
    "fladdrige": "fladdrig",
    "fladdriges": "fladdrig",
    "fladdrigheten": "fladdrighet",
    "fladdrighetens": "fladdrighet",
    "fladdrighets": "fladdrighet",
    "fladdrigs": "fladdrig",
    "fladdrigt": "fladdrig",
    "fladdrigts": "fladdrig",
    "flag": "flaga",
    "flagade": "flaga",
    "flagades": "flaga",
    "flagan": "flaga",
    "flagande": "flaga",
    "flaganden": "flagande",
    "flagandena": "flagande",
    "flagandenas": "flagande",
    "flagandens": "flagande",
    "flagandes": "flagande",
    "flagandet": "flagande",
    "flagandets": "flagande",
    "flagans": "flaga",
    "flagar": "flaga",
    "flagas": "flaga",
    "flagat": "flaga",
    "flagats": "flaga",
    "flage": "flaga",
    "flagellanten": "flagellant",
    "flagellantens": "flagellant",
    "flagellanter": "flagellant",
    "flagellanterna": "flagellant",
    "flagellanternas": "flagellant",
    "flagellanters": "flagellant",
    "flagellants": "flagellant",
    "flagellaten": "flagellat",
    "flagellatens": "flagellat",
    "flagellater": "flagellat",
    "flagellaterna": "flagellat",
    "flagellaternas": "flagellat",
    "flagellaters": "flagellat",
    "flagellats": "flagellat",
    "flagellen": "flagell",
    "flagellens": "flagell",
    "flageller": "flagell",
    "flagellerna": "flagell",
    "flagellernas": "flagell",
    "flagellers": "flagell",
    "flagells": "flagell",
    "flageoletten": "flageolett",
    "flageolettens": "flageolett",
    "flageoletter": "flageolett",
    "flageoletterna": "flageolett",
    "flageoletternas": "flageolett",
    "flageoletters": "flageolett",
    "flageoletts": "flageolett",
    "flagg": "flagga",
    "flaggad": "flagga",
    "flaggade": "flagga",
    "flaggades": "flagga",
    "flaggads": "flagga",
    "flaggan": "flagga",
    "flaggande": "flagga",
    "flagganden": "flaggande",
    "flaggandena": "flaggande",
    "flaggandenas": "flaggande",
    "flaggandens": "flaggande",
    "flaggandes": "flaggande",
    "flaggandet": "flaggande",
    "flaggandets": "flaggande",
    "flaggans": "flagga",
    "flaggar": "flagga",
    "flaggas": "flagga",
    "flaggat": "flagga",
    "flaggats": "flagga",
    "flaggdagar": "flaggdag",
    "flaggdagarna": "flaggdag",
    "flaggdagarnas": "flaggdag",
    "flaggdagars": "flaggdag",
    "flaggdagen": "flaggdag",
    "flaggdagens": "flaggdag",
    "flaggdags": "flaggdag",
    "flagge": "flagga",
    "flaggen": "flagg",
    "flaggens": "flagg",
    "flaggkaptenen": "flaggkapten",
    "flaggkaptenens": "flaggkapten",
    "flaggkaptener": "flaggkapten",
    "flaggkaptenerna": "flaggkapten",
    "flaggkaptenernas": "flaggkapten",
    "flaggkapteners": "flaggkapten",
    "flaggkaptens": "flaggkapten",
    "flagglin": "flagglina",
    "flagglinan": "flagglina",
    "flagglinans": "flagglina",
    "flagglinas": "flagglina",
    "flaggline": "flagglina",
    "flagglinor": "flagglina",
    "flagglinorna": "flagglina",
    "flagglinornas": "flagglina",
    "flagglinors": "flagglina",
    "flagglins": "flagglina",
    "flaggmannen": "flaggman",
    "flaggmannens": "flaggman",
    "flaggmans": "flaggman",
    "flaggmän": "flaggman",
    "flaggmännen": "flaggman",
    "flaggmännens": "flaggman",
    "flaggmäns": "flaggman",
    "flaggningar": "flaggning",
    "flaggningarna": "flaggning",
    "flaggningarnas": "flaggning",
    "flaggningars": "flaggning",
    "flaggningen": "flaggning",
    "flaggningens": "flaggning",
    "flaggnings": "flaggning",
    "flaggor": "flagga",
    "flaggorna": "flagga",
    "flaggornas": "flagga",
    "flaggors": "flagga",
    "flaggs": "flagga",
    "flaggskeppen": "flaggskepp",
    "flaggskeppens": "flaggskepp",
    "flaggskeppet": "flaggskepp",
    "flaggskeppets": "flaggskepp",
    "flaggskepps": "flaggskepp",
    "flaggskändningar": "flaggskändning",
    "flaggskändningarna": "flaggskändning",
    "flaggskändningarnas": "flaggskändning",
    "flaggskändningars": "flaggskändning",
    "flaggskändningen": "flaggskändning",
    "flaggskändningens": "flaggskändning",
    "flaggskändnings": "flaggskändning",
    "flaggspelen": "flaggspel",
    "flaggspelens": "flaggspel",
    "flaggspelet": "flaggspel",
    "flaggspelets": "flaggspel",
    "flaggspels": "flaggspel",
    "flaggstänger": "flaggstång",
    "flaggstängerna": "flaggstång",
    "flaggstängernas": "flaggstång",
    "flaggstängers": "flaggstång",
    "flaggstången": "flaggstång",
    "flaggstångens": "flaggstång",
    "flaggstångs": "flaggstång",
    "flaggvakten": "flaggvakt",
    "flaggvaktens": "flaggvakt",
    "flaggvakter": "flaggvakt",
    "flaggvakterna": "flaggvakt",
    "flaggvakternas": "flaggvakt",
    "flaggvakters": "flaggvakt",
    "flaggvakts": "flaggvakt",
    "flagiga": "flagig",
    "flagigare": "flagig",
    "flagigares": "flagig",
    "flagigas": "flagig",
    "flagigast": "flagig",
    "flagigaste": "flagig",
    "flagigastes": "flagig",
    "flagigasts": "flagig",
    "flagige": "flagig",
    "flagiges": "flagig",
    "flagigs": "flagig",
    "flagigt": "flagig",
    "flagigts": "flagig",
    "flagn": "flagna",
    "flagnad": "flagna",
    "flagnade": "flagna",
    "flagnades": "flagna",
    "flagnads": "flagna",
    "flagnande": "flagna",
    "flagnanden": "flagnande",
    "flagnandena": "flagnande",
    "flagnandenas": "flagnande",
    "flagnandens": "flagnande",
    "flagnandes": "flagnande",
    "flagnandet": "flagnande",
    "flagnandets": "flagnande",
    "flagnar": "flagna",
    "flagnas": "flagna",
    "flagnat": "flagna",
    "flagnats": "flagna",
    "flagor": "flaga",
    "flagorna": "flaga",
    "flagornas": "flaga",
    "flagors": "flaga",
    "flagranta": "flagrant",
    "flagrantare": "flagrant",
    "flagrantares": "flagrant",
    "flagrantas": "flagrant",
    "flagrantast": "flagrant",
    "flagrantaste": "flagrant",
    "flagrantastes": "flagrant",
    "flagrantasts": "flagrant",
    "flagrante": "flagrant",
    "flagrantes": "flagrant",
    "flagrants": "flagrant",
    "flags": "flaga",
    "flaken": "flak",
    "flakens": "flak",
    "flaket": "flak",
    "flakets": "flak",
    "flakongen": "flakong",
    "flakongens": "flakong",
    "flakonger": "flakong",
    "flakongerna": "flakong",
    "flakongernas": "flakong",
    "flakongers": "flakong",
    "flakongs": "flakong",
    "flaks": "flak",
    "flakvagnar": "flakvagn",
    "flakvagnarna": "flakvagn",
    "flakvagnarnas": "flakvagn",
    "flakvagnars": "flakvagn",
    "flakvagnen": "flakvagn",
    "flakvagnens": "flakvagn",
    "flakvagns": "flakvagn",
    "flam": "flamma",
    "flamberad": "flambera",
    "flamberade": "flambera",
    "flamberades": "flambera",
    "flamberads": "flambera",
    "flamberande": "flambera",
    "flamberanden": "flamberande",
    "flamberandena": "flamberande",
    "flamberandenas": "flamberande",
    "flamberandens": "flamberande",
    "flamberandes": "flamberande",
    "flamberandet": "flamberande",
    "flamberandets": "flamberande",
    "flamberar": "flambera",
    "flamberas": "flambera",
    "flamberat": "flambera",
    "flamberats": "flambera",
    "flamberbara": "flamberbar",
    "flamberbarare": "flamberbar",
    "flamberbarares": "flamberbar",
    "flamberbaras": "flamberbar",
    "flamberbarast": "flamberbar",
    "flamberbaraste": "flamberbar",
    "flamberbarastes": "flamberbar",
    "flamberbarasts": "flamberbar",
    "flamberbare": "flamberbar",
    "flamberbares": "flamberbar",
    "flamberbarheten": "flamberbarhet",
    "flamberbarhetens": "flamberbarhet",
    "flamberbarhets": "flamberbarhet",
    "flamberbars": "flamberbar",
    "flamberbart": "flamberbar",
    "flamberbarts": "flamberbar",
    "flamberingar": "flambering",
    "flamberingarna": "flambering",
    "flamberingarnas": "flambering",
    "flamberingars": "flambering",
    "flamberingen": "flambering",
    "flamberingens": "flambering",
    "flamberings": "flambering",
    "flamencoer": "flamenco",
    "flamencoerna": "flamenco",
    "flamencoernas": "flamenco",
    "flamencoers": "flamenco",
    "flamencon": "flamenco",
    "flamencons": "flamenco",
    "flamencor": "flamenco",
    "flamencorna": "flamenco",
    "flamencornas": "flamenco",
    "flamencors": "flamenco",
    "flamencos": "flamenco",
    "flamingon": "flamingo",
    "flamingons": "flamingo",
    "flamingor": "flamingo",
    "flamingorna": "flamingo",
    "flamingornas": "flamingo",
    "flamingors": "flamingo",
    "flamingos": "flamingo",
    "flamländar": "flamländare",
    "flamländaren": "flamländare",
    "flamländarens": "flamländare",
    "flamländares": "flamländare",
    "flamländarna": "flamländare",
    "flamländarnas": "flamländare",
    "flamländsk": "flamländska",
    "flamländska": "flamländsk",
    "flamländskan": "flamländska",
    "flamländskans": "flamländska",
    "flamländskare": "flamländsk",
    "flamländskares": "flamländsk",
    "flamländskas": "flamländska",
    "flamländskast": "flamländsk",
    "flamländskaste": "flamländsk",
    "flamländskastes": "flamländsk",
    "flamländskasts": "flamländsk",
    "flamländske": "flamländska",
    "flamländskes": "flamländsk",
    "flamländskor": "flamländska",
    "flamländskorna": "flamländska",
    "flamländskornas": "flamländska",
    "flamländskors": "flamländska",
    "flamländsks": "flamländsk",
    "flamländskt": "flamländsk",
    "flamländskts": "flamländsk",
    "flammade": "flamma",
    "flammades": "flamma",
    "flamman": "flamma",
    "flammande": "flamma",
    "flammanden": "flammande",
    "flammandena": "flammande",
    "flammandenas": "flammande",
    "flammandens": "flammande",
    "flammandes": "flammande",
    "flammandet": "flammande",
    "flammandets": "flammande",
    "flammans": "flamma",
    "flammar": "flamma",
    "flammas": "flamma",
    "flammat": "flamma",
    "flammats": "flamma",
    "flamme": "flamma",
    "flammiga": "flammig",
    "flammigare": "flammig",
    "flammigares": "flammig",
    "flammigas": "flammig",
    "flammigast": "flammig",
    "flammigaste": "flammig",
    "flammigastes": "flammig",
    "flammigasts": "flammig",
    "flammige": "flammig",
    "flammiges": "flammig",
    "flammigheten": "flammighet",
    "flammighetens": "flammighet",
    "flammighets": "flammighet",
    "flammigs": "flammig",
    "flammigt": "flammig",
    "flammigts": "flammig",
    "flammor": "flamma",
    "flammorna": "flamma",
    "flammornas": "flamma",
    "flammors": "flamma",
    "flampunkten": "flampunkt",
    "flampunktens": "flampunkt",
    "flampunkter": "flampunkt",
    "flampunkterna": "flampunkt",
    "flampunkternas": "flampunkt",
    "flampunkters": "flampunkt",
    "flampunkts": "flampunkt",
    "flams": "flamsa",
    "flamsade": "flamsa",
    "flamsades": "flamsa",
    "flamsande": "flamsa",
    "flamsanden": "flamsande",
    "flamsandena": "flamsande",
    "flamsandenas": "flamsande",
    "flamsandens": "flamsande",
    "flamsandes": "flamsande",
    "flamsandet": "flamsande",
    "flamsandets": "flamsande",
    "flamsar": "flamsa",
    "flamsas": "flamsa",
    "flamsat": "flamsa",
    "flamsats": "flamsa",
    "flamset": "flams",
    "flamsets": "flams",
    "flamsiga": "flamsig",
    "flamsigare": "flamsig",
    "flamsigares": "flamsig",
    "flamsigas": "flamsig",
    "flamsigast": "flamsig",
    "flamsigaste": "flamsig",
    "flamsigastes": "flamsig",
    "flamsigasts": "flamsig",
    "flamsige": "flamsig",
    "flamsiges": "flamsig",
    "flamsigheten": "flamsighet",
    "flamsighetens": "flamsighet",
    "flamsighets": "flamsighet",
    "flamsigs": "flamsig",
    "flamsigt": "flamsig",
    "flamsigts": "flamsig",
    "flamska": "flamsk",
    "flamskare": "flamsk",
    "flamskares": "flamsk",
    "flamskas": "flamsk",
    "flamskast": "flamsk",
    "flamskaste": "flamsk",
    "flamskastes": "flamsk",
    "flamskasts": "flamsk",
    "flamske": "flamsk",
    "flamskes": "flamsk",
    "flamskheten": "flamskhet",
    "flamskhetens": "flamskhet",
    "flamskhets": "flamskhet",
    "flamsks": "flamsk",
    "flamskt": "flamsk",
    "flamskts": "flamsk",
    "flamskvävnaden": "flamskvävnad",
    "flamskvävnadens": "flamskvävnad",
    "flamskvävnader": "flamskvävnad",
    "flamskvävnaderna": "flamskvävnad",
    "flamskvävnadernas": "flamskvävnad",
    "flamskvävnaders": "flamskvävnad",
    "flamskvävnads": "flamskvävnad",
    "flamskyddsmedels": "flamskyddsmedel",
    "flamskyddsmedlen": "flamskyddsmedel",
    "flamskyddsmedlens": "flamskyddsmedel",
    "flamskyddsmedlet": "flamskyddsmedel",
    "flamskyddsmedlets": "flamskyddsmedel",
    "flamugnar": "flamugn",
    "flamugnarna": "flamugn",
    "flamugnarnas": "flamugn",
    "flamugnars": "flamugn",
    "flamugnen": "flamugn",
    "flamugnens": "flamugn",
    "flamugns": "flamugn",
    "flandriska": "flandrisk",
    "flandriskare": "flandrisk",
    "flandriskares": "flandrisk",
    "flandriskas": "flandrisk",
    "flandriskast": "flandrisk",
    "flandriskaste": "flandrisk",
    "flandriskastes": "flandrisk",
    "flandriskasts": "flandrisk",
    "flandriske": "flandrisk",
    "flandriskes": "flandrisk",
    "flandrisks": "flandrisk",
    "flandriskt": "flandrisk",
    "flandriskts": "flandrisk",
    "flanellborst": "flanellborste",
    "flanellborstar": "flanellborste",
    "flanellborstarna": "flanellborste",
    "flanellborstarnas": "flanellborste",
    "flanellborstars": "flanellborste",
    "flanellborsten": "flanellborste",
    "flanellborstens": "flanellborste",
    "flanellborstes": "flanellborste",
    "flanellen": "flanell",
    "flanellens": "flanell",
    "flaneller": "flanell",
    "flanellerna": "flanell",
    "flanellernas": "flanell",
    "flanellers": "flanell",
    "flanellet": "flanell",
    "flanellets": "flanell",
    "flanellkostymen": "flanellkostym",
    "flanellkostymens": "flanellkostym",
    "flanellkostymer": "flanellkostym",
    "flanellkostymerna": "flanellkostym",
    "flanellkostymernas": "flanellkostym",
    "flanellkostymers": "flanellkostym",
    "flanellkostyms": "flanellkostym",
    "flanellografen": "flanellograf",
    "flanellografens": "flanellograf",
    "flanellografer": "flanellograf",
    "flanellograferna": "flanellograf",
    "flanellografernas": "flanellograf",
    "flanellografers": "flanellograf",
    "flanellografs": "flanellograf",
    "flanells": "flanell",
    "flanerade": "flanera",
    "flanerades": "flanera",
    "flanerande": "flanera",
    "flaneranden": "flanerande",
    "flanerandena": "flanerande",
    "flanerandenas": "flanerande",
    "flanerandens": "flanerande",
    "flanerandes": "flanerande",
    "flanerandet": "flanerande",
    "flanerandets": "flanerande",
    "flanerar": "flanera",
    "flaneras": "flanera",
    "flanerat": "flanera",
    "flanerats": "flanera",
    "flaneringar": "flanering",
    "flaneringarna": "flanering",
    "flaneringarnas": "flanering",
    "flaneringars": "flanering",
    "flaneringen": "flanering",
    "flaneringens": "flanering",
    "flanerings": "flanering",
    "flankanfallen": "flankanfall",
    "flankanfallens": "flankanfall",
    "flankanfallet": "flankanfall",
    "flankanfallets": "flankanfall",
    "flankanfalls": "flankanfall",
    "flanken": "flank",
    "flankens": "flank",
    "flanker": "flank",
    "flankerad": "flankera",
    "flankerade": "flankera",
    "flankerades": "flankera",
    "flankerads": "flankera",
    "flankerande": "flankera",
    "flankeranden": "flankerande",
    "flankerandena": "flankerande",
    "flankerandenas": "flankerande",
    "flankerandens": "flankerande",
    "flankerandes": "flankerande",
    "flankerandet": "flankerande",
    "flankerandets": "flankerande",
    "flankerar": "flankera",
    "flankeras": "flankera",
    "flankerat": "flankera",
    "flankerats": "flankera",
    "flankerbara": "flankerbar",
    "flankerbarare": "flankerbar",
    "flankerbarares": "flankerbar",
    "flankerbaras": "flankerbar",
    "flankerbarast": "flankerbar",
    "flankerbaraste": "flankerbar",
    "flankerbarastes": "flankerbar",
    "flankerbarasts": "flankerbar",
    "flankerbare": "flankerbar",
    "flankerbares": "flankerbar",
    "flankerbarheten": "flankerbarhet",
    "flankerbarhetens": "flankerbarhet",
    "flankerbarhets": "flankerbarhet",
    "flankerbars": "flankerbar",
    "flankerbart": "flankerbar",
    "flankerbarts": "flankerbar",
    "flankeringar": "flankering",
    "flankeringarna": "flankering",
    "flankeringarnas": "flankering",
    "flankeringars": "flankering",
    "flankeringen": "flankering",
    "flankeringens": "flankering",
    "flankerings": "flankering",
    "flankerna": "flank",
    "flankernas": "flank",
    "flankers": "flank",
    "flanks": "flank",
    "flanören": "flanör",
    "flanörens": "flanör",
    "flanörer": "flanör",
    "flanörerna": "flanör",
    "flanörernas": "flanör",
    "flanörers": "flanör",
    "flanörs": "flanör",
    "flarkar": "flark",
    "flarkarna": "flark",
    "flarkarnas": "flark",
    "flarkars": "flark",
    "flarken": "flark",
    "flarkens": "flark",
    "flarks": "flark",
    "flarnen": "flarn",
    "flarnens": "flarn",
    "flarnet": "flarn",
    "flarnets": "flarn",
    "flarns": "flarn",
    "flask": "flaska",
    "flaskan": "flaska",
    "flaskans": "flaska",
    "flaskas": "flaska",
    "flaskbarnen": "flaskbarn",
    "flaskbarnens": "flaskbarn",
    "flaskbarnet": "flaskbarn",
    "flaskbarnets": "flaskbarn",
    "flaskbarns": "flaskbarn",
    "flaskborst": "flaskborste",
    "flaskborstar": "flaskborste",
    "flaskborstarna": "flaskborste",
    "flaskborstarnas": "flaskborste",
    "flaskborstars": "flaskborste",
    "flaskborsten": "flaskborste",
    "flaskborstens": "flaskborste",
    "flaskborstes": "flaskborste",
    "flaskbristen": "flaskbrist",
    "flaskbristens": "flaskbrist",
    "flaskbrists": "flaskbrist",
    "flaske": "flaska",
    "flaskhalsar": "flaskhals",
    "flaskhalsarna": "flaskhals",
    "flaskhalsarnas": "flaskhals",
    "flaskhalsars": "flaskhals",
    "flaskhalsen": "flaskhals",
    "flaskhalsens": "flaskhals",
    "flaskhålen": "flaskhål",
    "flaskhålens": "flaskhål",
    "flaskhålet": "flaskhål",
    "flaskhålets": "flaskhål",
    "flaskhåls": "flaskhål",
    "flaskkurbitsar": "flaskkurbits",
    "flaskkurbitsarna": "flaskkurbits",
    "flaskkurbitsarnas": "flaskkurbits",
    "flaskkurbitsars": "flaskkurbits",
    "flaskkurbitsen": "flaskkurbits",
    "flaskkurbitsens": "flaskkurbits",
    "flaskor": "flaska",
    "flaskorna": "flaska",
    "flaskornas": "flaska",
    "flaskors": "flaska",
    "flaskposten": "flaskpost",
    "flaskpostens": "flaskpost",
    "flaskposts": "flaskpost",
    "flasköppnar": "flasköppnare",
    "flasköppnaren": "flasköppnare",
    "flasköppnarens": "flasköppnare",
    "flasköppnares": "flasköppnare",
    "flasköppnarna": "flasköppnare",
    "flasköppnarnas": "flasköppnare",
    "flasköppningar": "flasköppning",
    "flasköppningarna": "flasköppning",
    "flasköppningarnas": "flasköppning",
    "flasköppningars": "flasköppning",
    "flasköppningen": "flasköppning",
    "flasköppningens": "flasköppning",
    "flasköppnings": "flasköppning",
    "flat": "flata",
    "flata": "flat",
    "flatan": "flata",
    "flatans": "flata",
    "flatare": "flat",
    "flatares": "flat",
    "flatas": "flata",
    "flatast": "flat",
    "flataste": "flat",
    "flatastes": "flat",
    "flatasts": "flat",
    "flatbottnade": "flatbottnad",
    "flatbottnades": "flatbottnad",
    "flatbottnads": "flatbottnad",
    "flatbottnat": "flatbottnad",
    "flatbottnats": "flatbottnad",
    "flatbröden": "flatbröd",
    "flatbrödens": "flatbröd",
    "flatbrödet": "flatbröd",
    "flatbrödets": "flatbröd",
    "flatbröds": "flatbröd",
    "flate": "flata",
    "flates": "flat",
    "flatfiskar": "flatfisk",
    "flatfiskarna": "flatfisk",
    "flatfiskarnas": "flatfisk",
    "flatfiskars": "flatfisk",
    "flatfisken": "flatfisk",
    "flatfiskens": "flatfisk",
    "flatfisks": "flatfisk",
    "flatheten": "flathet",
    "flathetens": "flathet",
    "flathets": "flathet",
    "flatlusen": "flatlus",
    "flatlusens": "flatlus",
    "flatlöss": "flatlus",
    "flatlössen": "flatlus",
    "flatlössens": "flatlus",
    "flator": "flata",
    "flatorna": "flata",
    "flatornas": "flata",
    "flators": "flata",
    "flats": "flata",
    "flatskrattade": "flatskratta",
    "flatskrattades": "flatskratta",
    "flatskrattande": "flatskratta",
    "flatskrattanden": "flatskrattande",
    "flatskrattandena": "flatskrattande",
    "flatskrattandenas": "flatskrattande",
    "flatskrattandens": "flatskrattande",
    "flatskrattandes": "flatskrattande",
    "flatskrattandet": "flatskrattande",
    "flatskrattandets": "flatskrattande",
    "flatskrattar": "flatskratta",
    "flatskrattas": "flatskratta",
    "flatskrattat": "flatskratta",
    "flatskrattats": "flatskratta",
    "flatskratten": "flatskratt",
    "flatskrattens": "flatskratt",
    "flatskrattet": "flatskratt",
    "flatskrattets": "flatskratt",
    "flatskratts": "flatskratt",
    "flatterad": "flattera",
    "flatterade": "flattera",
    "flatterades": "flattera",
    "flatterads": "flattera",
    "flatterande": "flattera",
    "flatteranden": "flatterande",
    "flatterandena": "flatterande",
    "flatterandenas": "flatterande",
    "flatterandens": "flatterande",
    "flatterandes": "flatterande",
    "flatterandet": "flatterande",
    "flatterandets": "flatterande",
    "flatterar": "flattera",
    "flatteras": "flattera",
    "flatterat": "flattera",
    "flatterats": "flattera",
    "flatterbara": "flatterbar",
    "flatterbarare": "flatterbar",
    "flatterbarares": "flatterbar",
    "flatterbaras": "flatterbar",
    "flatterbarast": "flatterbar",
    "flatterbaraste": "flatterbar",
    "flatterbarastes": "flatterbar",
    "flatterbarasts": "flatterbar",
    "flatterbare": "flatterbar",
    "flatterbares": "flatterbar",
    "flatterbarheten": "flatterbarhet",
    "flatterbarhetens": "flatterbarhet",
    "flatterbarhets": "flatterbarhet",
    "flatterbars": "flatterbar",
    "flatterbart": "flatterbar",
    "flatterbarts": "flatterbar",
    "flatteringar": "flattering",
    "flatteringarna": "flattering",
    "flatteringarnas": "flattering",
    "flatteringars": "flattering",
    "flatteringen": "flattering",
    "flatteringens": "flattering",
    "flatterings": "flattering",
    "flatulensen": "flatulens",
    "flatulensens": "flatulens",
    "flatulenser": "flatulens",
    "flatulenserna": "flatulens",
    "flatulensernas": "flatulens",
    "flatulensers": "flatulens",
    "flax": "flaxa",
    "flaxade": "flaxa",
    "flaxades": "flaxa",
    "flaxande": "flaxa",
    "flaxanden": "flaxande",
    "flaxandena": "flaxande",
    "flaxandenas": "flaxande",
    "flaxandens": "flaxande",
    "flaxandes": "flaxande",
    "flaxandet": "flaxande",
    "flaxandets": "flaxande",
    "flaxar": "flaxa",
    "flaxarna": "flax",
    "flaxarnas": "flax",
    "flaxars": "flax",
    "flaxas": "flaxa",
    "flaxat": "flaxa",
    "flaxats": "flaxa",
    "flaxen": "flax",
    "flaxens": "flax",
    "flaxet": "flax",
    "flaxets": "flax",
    "flaxiga": "flaxig",
    "flaxigare": "flaxig",
    "flaxigares": "flaxig",
    "flaxigas": "flaxig",
    "flaxigast": "flaxig",
    "flaxigaste": "flaxig",
    "flaxigastes": "flaxig",
    "flaxigasts": "flaxig",
    "flaxige": "flaxig",
    "flaxiges": "flaxig",
    "flaxigs": "flaxig",
    "flaxigt": "flaxig",
    "flaxigts": "flaxig",
    "fleece-foderna": "fleece-foder",
    "fleece-fodernas": "fleece-foder",
    "fleece-foders": "fleece-foder",
    "fleece-fodren": "fleece-foder",
    "fleece-fodrens": "fleece-foder",
    "fleece-fodret": "fleece-foder",
    "fleece-fodrets": "fleece-foder",
    "fleecen": "fleece",
    "fleecens": "fleece",
    "fleeces": "fleece",
    "fleecet": "fleece",
    "fleecets": "fleece",
    "flegman": "flegma",
    "flegmans": "flegma",
    "flegmas": "flegma",
    "flegmatikern": "flegmatiker",
    "flegmatikerna": "flegmatiker",
    "flegmatikernas": "flegmatiker",
    "flegmatikerns": "flegmatiker",
    "flegmatikers": "flegmatiker",
    "flegmatiska": "flegmatisk",
    "flegmatiskare": "flegmatisk",
    "flegmatiskares": "flegmatisk",
    "flegmatiskas": "flegmatisk",
    "flegmatiskast": "flegmatisk",
    "flegmatiskaste": "flegmatisk",
    "flegmatiskastes": "flegmatisk",
    "flegmatiskasts": "flegmatisk",
    "flegmatiske": "flegmatisk",
    "flegmatiskes": "flegmatisk",
    "flegmatisks": "flegmatisk",
    "flegmatiskt": "flegmatisk",
    "flegmatiskts": "flegmatisk",
    "flekterad": "flektera",
    "flekterade": "flektera",
    "flekterades": "flektera",
    "flekterads": "flektera",
    "flekterande": "flektera",
    "flekteranden": "flekterande",
    "flekterandena": "flekterande",
    "flekterandenas": "flekterande",
    "flekterandens": "flekterande",
    "flekterandes": "flekterande",
    "flekterandet": "flekterande",
    "flekterandets": "flekterande",
    "flekterar": "flektera",
    "flekteras": "flektera",
    "flekterat": "flektera",
    "flekterats": "flektera",
    "flekterbara": "flekterbar",
    "flekterbarare": "flekterbar",
    "flekterbarares": "flekterbar",
    "flekterbaras": "flekterbar",
    "flekterbarast": "flekterbar",
    "flekterbaraste": "flekterbar",
    "flekterbarastes": "flekterbar",
    "flekterbarasts": "flekterbar",
    "flekterbare": "flekterbar",
    "flekterbares": "flekterbar",
    "flekterbarheten": "flekterbarhet",
    "flekterbarhetens": "flekterbarhet",
    "flekterbarhets": "flekterbarhet",
    "flekterbars": "flekterbar",
    "flekterbart": "flekterbar",
    "flekterbarts": "flekterbar",
    "flekteringar": "flektering",
    "flekteringarna": "flektering",
    "flekteringarnas": "flektering",
    "flekteringars": "flektering",
    "flekteringen": "flektering",
    "flekteringens": "flektering",
    "flekterings": "flektering",
    "flektionen": "flektion",
    "flektionens": "flektion",
    "flektioner": "flektion",
    "flektionerna": "flektion",
    "flektionernas": "flektion",
    "flektioners": "flektion",
    "flektions": "flektion",
    "fler": "mången",
    "flera": "mången",
    "fleras": "mången",
    "flerbarnsfamiljen": "flerbarnsfamilj",
    "flerbarnsfamiljens": "flerbarnsfamilj",
    "flerbarnsfamiljer": "flerbarnsfamilj",
    "flerbarnsfamiljerna": "flerbarnsfamilj",
    "flerbarnsfamiljernas": "flerbarnsfamilj",
    "flerbarnsfamiljers": "flerbarnsfamilj",
    "flerbarnsfamiljs": "flerbarnsfamilj",
    "flerbarnsmamman": "flerbarnsmamma",
    "flerbarnsmammans": "flerbarnsmamma",
    "flerbarnsmammas": "flerbarnsmamma",
    "flerbarnsmamme": "flerbarnsmamma",
    "flerbarnsmammor": "flerbarnsmamma",
    "flerbarnsmammorna": "flerbarnsmamma",
    "flerbarnsmammornas": "flerbarnsmamma",
    "flerbarnsmammors": "flerbarnsmamma",
    "flerbarnsmoder": "flerbarnsmor",
    "flerbarnsmodern": "flerbarnsmor",
    "flerbarnsmoderns": "flerbarnsmor",
    "flerbarnsmoders": "flerbarnsmor",
    "flerbarnsmors": "flerbarnsmor",
    "flerbarnsmödrar": "flerbarnsmor",
    "flerbarnsmödrarna": "flerbarnsmor",
    "flerbarnsmödrarnas": "flerbarnsmor",
    "flerbarnsmödrars": "flerbarnsmor",
    "flerbostadshusen": "flerbostadshus",
    "flerbostadshusens": "flerbostadshus",
    "flerbostadshuset": "flerbostadshus",
    "flerbostadshusets": "flerbostadshus",
    "flercelliga": "flercellig",
    "flercelligare": "flercellig",
    "flercelligares": "flercellig",
    "flercelligas": "flercellig",
    "flercelligast": "flercellig",
    "flercelligaste": "flercellig",
    "flercelligastes": "flercellig",
    "flercelligasts": "flercellig",
    "flercellige": "flercellig",
    "flercelliges": "flercellig",
    "flercelligheten": "flercellighet",
    "flercellighetens": "flercellighet",
    "flercellighets": "flercellighet",
    "flercelligs": "flercellig",
    "flercelligt": "flercellig",
    "flercelligts": "flercellig",
    "flerdubbels": "flerdubbel",
    "flerdubbelt": "flerdubbel",
    "flerdubbelts": "flerdubbel",
    "flerdubbla": "flerdubbel",
    "flerdubblad": "flerdubbla",
    "flerdubblade": "flerdubbla",
    "flerdubblades": "flerdubbla",
    "flerdubblads": "flerdubbla",
    "flerdubblande": "flerdubbla",
    "flerdubblanden": "flerdubblande",
    "flerdubblandena": "flerdubblande",
    "flerdubblandenas": "flerdubblande",
    "flerdubblandens": "flerdubblande",
    "flerdubblandes": "flerdubblande",
    "flerdubblandet": "flerdubblande",
    "flerdubblandets": "flerdubblande",
    "flerdubblar": "flerdubbla",
    "flerdubblare": "flerdubbel",
    "flerdubblares": "flerdubbel",
    "flerdubblas": "flerdubbla",
    "flerdubblast": "flerdubbel",
    "flerdubblaste": "flerdubbel",
    "flerdubblastes": "flerdubbel",
    "flerdubblasts": "flerdubbel",
    "flerdubblat": "flerdubbla",
    "flerdubblats": "flerdubbla",
    "flerdubble": "flerdubbel",
    "flerdubbles": "flerdubbel",
    "flerfaldig": "flerfaldiga",
    "flerfaldiga": "flerfaldig",
    "flerfaldigad": "flerfaldiga",
    "flerfaldigade": "flerfaldiga",
    "flerfaldigades": "flerfaldiga",
    "flerfaldigads": "flerfaldiga",
    "flerfaldigande": "flerfaldiga",
    "flerfaldiganden": "flerfaldigande",
    "flerfaldigandena": "flerfaldigande",
    "flerfaldigandenas": "flerfaldigande",
    "flerfaldigandens": "flerfaldigande",
    "flerfaldigandes": "flerfaldigande",
    "flerfaldigandet": "flerfaldigande",
    "flerfaldigandets": "flerfaldigande",
    "flerfaldigar": "flerfaldiga",
    "flerfaldigare": "flerfaldig",
    "flerfaldigares": "flerfaldig",
    "flerfaldigas": "flerfaldiga",
    "flerfaldigast": "flerfaldig",
    "flerfaldigaste": "flerfaldig",
    "flerfaldigastes": "flerfaldig",
    "flerfaldigasts": "flerfaldig",
    "flerfaldigat": "flerfaldiga",
    "flerfaldigats": "flerfaldiga",
    "flerfaldige": "flerfaldig",
    "flerfaldiges": "flerfaldig",
    "flerfaldigs": "flerfaldig",
    "flerfaldigt": "flerfaldig",
    "flerfaldigts": "flerfaldig",
    "flerfamiljshusen": "flerfamiljshus",
    "flerfamiljshusens": "flerfamiljshus",
    "flerfamiljshuset": "flerfamiljshus",
    "flerfamiljshusets": "flerfamiljshus",
    "flerfärgade": "flerfärgad",
    "flerfärgades": "flerfärgad",
    "flerfärgads": "flerfärgad",
    "flerfärgat": "flerfärgad",
    "flerfärgats": "flerfärgad",
    "flerfärgstrycken": "flerfärgstryck",
    "flerfärgstryckens": "flerfärgstryck",
    "flerfärgstrycket": "flerfärgstryck",
    "flerfärgstryckets": "flerfärgstryck",
    "flerfärgstrycks": "flerfärgstryck",
    "flerhandikappade": "flerhandikappad",
    "flerhandikappades": "flerhandikappad",
    "flerhandikappads": "flerhandikappad",
    "flerhandikappat": "flerhandikappad",
    "flerhandikappats": "flerhandikappad",
    "flerhandikappen": "flerhandikapp",
    "flerhandikappens": "flerhandikapp",
    "flerhandikappet": "flerhandikapp",
    "flerhandikappets": "flerhandikapp",
    "flerhandikapps": "flerhandikapp",
    "flermansvalkretsar": "flermansvalkrets",
    "flermansvalkretsarna": "flermansvalkrets",
    "flermansvalkretsarnas": "flermansvalkrets",
    "flermansvalkretsars": "flermansvalkrets",
    "flermansvalkretsen": "flermansvalkrets",
    "flermansvalkretsens": "flermansvalkrets",
    "fleromättade": "fleromättad",
    "fleromättades": "fleromättad",
    "fleromättads": "fleromättad",
    "fleromättat": "fleromättad",
    "fleromättats": "fleromättad",
    "flerordingar": "flerording",
    "flerordingarna": "flerording",
    "flerordingarnas": "flerording",
    "flerordingars": "flerording",
    "flerordingen": "flerording",
    "flerordingens": "flerording",
    "flerordings": "flerording",
    "flerordsenheten": "flerordsenhet",
    "flerordsenhetens": "flerordsenhet",
    "flerordsenheter": "flerordsenhet",
    "flerordsenheterna": "flerordsenhet",
    "flerordsenheternas": "flerordsenhet",
    "flerordsenheters": "flerordsenhet",
    "flerordsenhets": "flerordsenhet",
    "flerpartisystemen": "flerpartisystem",
    "flerpartisystemens": "flerpartisystem",
    "flerpartisystemet": "flerpartisystem",
    "flerpartisystemets": "flerpartisystem",
    "flerpartisystems": "flerpartisystem",
    "flers": "mången",
    "flerspråkiga": "flerspråkig",
    "flerspråkigare": "flerspråkig",
    "flerspråkigares": "flerspråkig",
    "flerspråkigas": "flerspråkig",
    "flerspråkigast": "flerspråkig",
    "flerspråkigaste": "flerspråkig",
    "flerspråkigastes": "flerspråkig",
    "flerspråkigasts": "flerspråkig",
    "flerspråkige": "flerspråkig",
    "flerspråkiges": "flerspråkig",
    "flerspråkigheten": "flerspråkighet",
    "flerspråkighetens": "flerspråkighet",
    "flerspråkighets": "flerspråkighet",
    "flerspråkigs": "flerspråkig",
    "flerspråkigt": "flerspråkig",
    "flerspråkigts": "flerspråkig",
    "flerstammiga": "flerstammig",
    "flerstammigare": "flerstammig",
    "flerstammigares": "flerstammig",
    "flerstammigas": "flerstammig",
    "flerstammigast": "flerstammig",
    "flerstammigaste": "flerstammig",
    "flerstammigastes": "flerstammig",
    "flerstammigasts": "flerstammig",
    "flerstammige": "flerstammig",
    "flerstammiges": "flerstammig",
    "flerstammigs": "flerstammig",
    "flerstammigt": "flerstammig",
    "flerstammigts": "flerstammig",
    "flerstämmiga": "flerstämmig",
    "flerstämmigare": "flerstämmig",
    "flerstämmigares": "flerstämmig",
    "flerstämmigas": "flerstämmig",
    "flerstämmigast": "flerstämmig",
    "flerstämmigaste": "flerstämmig",
    "flerstämmigastes": "flerstämmig",
    "flerstämmigasts": "flerstämmig",
    "flerstämmige": "flerstämmig",
    "flerstämmiges": "flerstämmig",
    "flerstämmigheten": "flerstämmighet",
    "flerstämmighetens": "flerstämmighet",
    "flerstämmighets": "flerstämmighet",
    "flerstämmigs": "flerstämmig",
    "flerstämmigt": "flerstämmig",
    "flerstämmigts": "flerstämmig",
    "flertalet": "flertal",
    "flertalets": "flertal",
    "flertals": "flertal",
    "flertydiga": "flertydig",
    "flertydigare": "flertydig",
    "flertydigares": "flertydig",
    "flertydigas": "flertydig",
    "flertydigast": "flertydig",
    "flertydigaste": "flertydig",
    "flertydigastes": "flertydig",
    "flertydigasts": "flertydig",
    "flertydige": "flertydig",
    "flertydiges": "flertydig",
    "flertydigheten": "flertydighet",
    "flertydighetens": "flertydighet",
    "flertydighets": "flertydighet",
    "flertydigs": "flertydig",
    "flertydigt": "flertydig",
    "flertydigts": "flertydig",
    "flervalsfrågan": "flervalsfråga",
    "flervalsfrågans": "flervalsfråga",
    "flervalsfrågas": "flervalsfråga",
    "flervalsfråge": "flervalsfråga",
    "flervalsfrågor": "flervalsfråga",
    "flervalsfrågorna": "flervalsfråga",
    "flervalsfrågornas": "flervalsfråga",
    "flervalsfrågors": "flervalsfråga",
    "flervalstesten": "flervalstest",
    "flervalstestens": "flervalstest",
    "flervalstester": "flervalstest",
    "flervalstesterna": "flervalstest",
    "flervalstesternas": "flervalstest",
    "flervalstesters": "flervalstest",
    "flervalstestet": "flervalstest",
    "flervalstestets": "flervalstest",
    "flervalstests": "flervalstest",
    "flervalsuppgiften": "flervalsuppgift",
    "flervalsuppgiftens": "flervalsuppgift",
    "flervalsuppgifter": "flervalsuppgift",
    "flervalsuppgifterna": "flervalsuppgift",
    "flervalsuppgifternas": "flervalsuppgift",
    "flervalsuppgifters": "flervalsuppgift",
    "flervalsuppgifts": "flervalsuppgift",
    "flervåningshusen": "flervåningshus",
    "flervåningshusens": "flervåningshus",
    "flervåningshuset": "flervåningshus",
    "flervåningshusets": "flervåningshus",
    "fleråriga": "flerårig",
    "flerårigas": "flerårig",
    "flerårige": "flerårig",
    "fleråriges": "flerårig",
    "flerårigs": "flerårig",
    "flerårigt": "flerårig",
    "flerårigts": "flerårig",
    "flesar": "fles",
    "flesarna": "fles",
    "flesarnas": "fles",
    "flesars": "fles",
    "flesen": "fles",
    "flesens": "fles",
    "flest": "mången",
    "flesta": "mången",
    "flestas": "mången",
    "flests": "mången",
    "flex": "flexa",
    "flexade": "flexa",
    "flexades": "flexa",
    "flexande": "flexa",
    "flexanden": "flexande",
    "flexandena": "flexande",
    "flexandenas": "flexande",
    "flexandens": "flexande",
    "flexandes": "flexande",
    "flexandet": "flexande",
    "flexandets": "flexande",
    "flexar": "flexa",
    "flexas": "flexa",
    "flexat": "flexa",
    "flexats": "flexa",
    "flexibels": "flexibel",
    "flexibelt": "flexibel",
    "flexibelts": "flexibel",
    "flexibiliteten": "flexibilitet",
    "flexibilitetens": "flexibilitet",
    "flexibilitets": "flexibilitet",
    "flexibla": "flexibel",
    "flexiblare": "flexibel",
    "flexiblares": "flexibel",
    "flexiblas": "flexibel",
    "flexiblast": "flexibel",
    "flexiblaste": "flexibel",
    "flexiblastes": "flexibel",
    "flexiblasts": "flexibel",
    "flexible": "flexibel",
    "flexibles": "flexibel",
    "flexionen": "flexion",
    "flexionens": "flexion",
    "flexioner": "flexion",
    "flexionerna": "flexion",
    "flexionernas": "flexion",
    "flexioners": "flexion",
    "flexions": "flexion",
    "flexislangar": "flexislang",
    "flexislangarna": "flexislang",
    "flexislangarnas": "flexislang",
    "flexislangars": "flexislang",
    "flexislangen": "flexislang",
    "flexislangens": "flexislang",
    "flexislangs": "flexislang",
    "flexklock": "flexklocka",
    "flexklockan": "flexklocka",
    "flexklockans": "flexklocka",
    "flexklockas": "flexklocka",
    "flexklocke": "flexklocka",
    "flexklockor": "flexklocka",
    "flexklockorna": "flexklocka",
    "flexklockornas": "flexklocka",
    "flexklockors": "flexklocka",
    "flexklocks": "flexklocka",
    "flextiden": "flextid",
    "flextidens": "flextid",
    "flextider": "flextid",
    "flextiderna": "flextid",
    "flextidernas": "flextid",
    "flextiders": "flextid",
    "flextids": "flextid",
    "flexuren": "flexur",
    "flexurens": "flexur",
    "flexurer": "flexur",
    "flexurerna": "flexur",
    "flexurernas": "flexur",
    "flexurers": "flexur",
    "flexurs": "flexur",
    "flick": "flicka",
    "flickan": "flicka",
    "flickans": "flicka",
    "flickansikten": "flickansikte",
    "flickansiktena": "flickansikte",
    "flickansiktenas": "flickansikte",
    "flickansiktens": "flickansikte",
    "flickansiktes": "flickansikte",
    "flickansiktet": "flickansikte",
    "flickansiktets": "flickansikte",
    "flickansikts": "flickansikte",
    "flickas": "flicka",
    "flicke": "flicka",
    "flickebarnen": "flickebarn",
    "flickebarnens": "flickebarn",
    "flickebarnet": "flickebarn",
    "flickebarnets": "flickebarn",
    "flickebarns": "flickebarn",
    "flickjägar": "flickjägare",
    "flickjägaren": "flickjägare",
    "flickjägarens": "flickjägare",
    "flickjägares": "flickjägare",
    "flickjägarna": "flickjägare",
    "flickjägarnas": "flickjägare",
    "flickkalvar": "flickkalv",
    "flickkalvarna": "flickkalv",
    "flickkalvarnas": "flickkalv",
    "flickkalvars": "flickkalv",
    "flickkalven": "flickkalv",
    "flickkalvens": "flickkalv",
    "flickkalvs": "flickkalv",
    "flickkören": "flickkör",
    "flickkörens": "flickkör",
    "flickkörer": "flickkör",
    "flickkörerna": "flickkör",
    "flickkörernas": "flickkör",
    "flickkörers": "flickkör",
    "flickkörs": "flickkör",
    "flickmatchen": "flickmatch",
    "flickmatchens": "flickmatch",
    "flickmatcher": "flickmatch",
    "flickmatcherna": "flickmatch",
    "flickmatchernas": "flickmatch",
    "flickmatchers": "flickmatch",
    "flickmatchs": "flickmatch",
    "flicknamnen": "flicknamn",
    "flicknamnens": "flicknamn",
    "flicknamnet": "flicknamn",
    "flicknamnets": "flicknamn",
    "flicknamns": "flicknamn",
    "flickor": "flicka",
    "flickorna": "flicka",
    "flickornas": "flicka",
    "flickors": "flicka",
    "flickpensionen": "flickpension",
    "flickpensionens": "flickpension",
    "flickpensioner": "flickpension",
    "flickpensionerna": "flickpension",
    "flickpensionernas": "flickpension",
    "flickpensioners": "flickpension",
    "flickpensions": "flickpension",
    "flicks": "flicka",
    "flickskolan": "flickskola",
    "flickskolans": "flickskola",
    "flickskolas": "flickskola",
    "flickskole": "flickskola",
    "flickskolor": "flickskola",
    "flickskolorna": "flickskola",
    "flickskolornas": "flickskola",
    "flickskolors": "flickskola",
    "flicksländ": "flickslända",
    "flicksländan": "flickslända",
    "flicksländans": "flickslända",
    "flicksländas": "flickslända",
    "flickslände": "flickslända",
    "flicksländor": "flickslända",
    "flicksländorna": "flickslända",
    "flicksländornas": "flickslända",
    "flicksländors": "flickslända",
    "flicksländs": "flickslända",
    "flicktyckes": "flicktycke",
    "flicktycket": "flicktycke",
    "flicktyckets": "flicktycke",
    "flickvännen": "flickvän",
    "flickvännens": "flickvän",
    "flickvänner": "flickvän",
    "flickvännerna": "flickvän",
    "flickvännernas": "flickvän",
    "flickvänners": "flickvän",
    "flickväns": "flickvän",
    "flighten": "flight",
    "flightens": "flight",
    "flighter": "flight",
    "flighterna": "flight",
    "flighternas": "flight",
    "flighters": "flight",
    "flights": "flight",
    "flikar": "flik",
    "flikarna": "flik",
    "flikarnas": "flik",
    "flikars": "flik",
    "fliken": "flik",
    "flikens": "flik",
    "flikiga": "flikig",
    "flikigare": "flikig",
    "flikigares": "flikig",
    "flikigas": "flikig",
    "flikigast": "flikig",
    "flikigaste": "flikig",
    "flikigastes": "flikig",
    "flikigasts": "flikig",
    "flikige": "flikig",
    "flikiges": "flikig",
    "flikigs": "flikig",
    "flikigt": "flikig",
    "flikigts": "flikig",
    "fliks": "flik",
    "flimmer": "flimra",
    "flimmercellen": "flimmercell",
    "flimmercellens": "flimmercell",
    "flimmerceller": "flimmercell",
    "flimmercellerna": "flimmercell",
    "flimmercellernas": "flimmercell",
    "flimmercellers": "flimmercell",
    "flimmercells": "flimmercell",
    "flimmerhåren": "flimmerhår",
    "flimmerhårens": "flimmerhår",
    "flimmerhåret": "flimmerhår",
    "flimmerhårets": "flimmerhår",
    "flimmerhårs": "flimmerhår",
    "flimmers": "flimmer",
    "flimrade": "flimra",
    "flimrades": "flimra",
    "flimrande": "flimra",
    "flimranden": "flimrande",
    "flimrandena": "flimrande",
    "flimrandenas": "flimrande",
    "flimrandens": "flimrande",
    "flimrandes": "flimrande",
    "flimrandet": "flimrande",
    "flimrandets": "flimrande",
    "flimrar": "flimra",
    "flimras": "flimra",
    "flimrat": "flimra",
    "flimrats": "flimra",
    "flimret": "flimmer",
    "flimrets": "flimmer",
    "flimriga": "flimrig",
    "flimrigare": "flimrig",
    "flimrigares": "flimrig",
    "flimrigas": "flimrig",
    "flimrigast": "flimrig",
    "flimrigaste": "flimrig",
    "flimrigastes": "flimrig",
    "flimrigasts": "flimrig",
    "flimrige": "flimrig",
    "flimriges": "flimrig",
    "flimrigheten": "flimrighet",
    "flimrighetens": "flimrighet",
    "flimrighets": "flimrighet",
    "flimrigs": "flimrig",
    "flimrigt": "flimrig",
    "flimrigts": "flimrig",
    "flin": "flina",
    "flinade": "flina",
    "flinades": "flina",
    "flinande": "flina",
    "flinanden": "flinande",
    "flinandena": "flinande",
    "flinandenas": "flinande",
    "flinandens": "flinande",
    "flinandes": "flinande",
    "flinandet": "flinande",
    "flinandets": "flinande",
    "flinar": "flina",
    "flinas": "flina",
    "flinat": "flina",
    "flinats": "flina",
    "flinen": "flin",
    "flinens": "flin",
    "flinet": "flin",
    "flinets": "flin",
    "fling": "flinga",
    "flingan": "flinga",
    "flingans": "flinga",
    "flingas": "flinga",
    "flinge": "flinga",
    "flingor": "flinga",
    "flingorna": "flinga",
    "flingornas": "flinga",
    "flingors": "flinga",
    "flings": "flinga",
    "flinka": "flink",
    "flinkare": "flink",
    "flinkares": "flink",
    "flinkas": "flink",
    "flinkast": "flink",
    "flinkaste": "flink",
    "flinkastes": "flink",
    "flinkasts": "flink",
    "flinke": "flink",
    "flinkes": "flink",
    "flinkheten": "flinkhet",
    "flinkhetens": "flinkhet",
    "flinkhets": "flinkhet",
    "flinks": "flink",
    "flinkt": "flink",
    "flinkts": "flink",
    "flins": "flin",
    "flint": "flinta",
    "flintan": "flinta",
    "flintans": "flinta",
    "flintas": "flinta",
    "flinte": "flinta",
    "flinten": "flint",
    "flintens": "flint",
    "flintgodset": "flintgods",
    "flintgodsets": "flintgods",
    "flintlåsen": "flintlås",
    "flintlåsens": "flintlås",
    "flintlåset": "flintlås",
    "flintlåsets": "flintlås",
    "flintlåsgevären": "flintlåsgevär",
    "flintlåsgevärens": "flintlåsgevär",
    "flintlåsgeväret": "flintlåsgevär",
    "flintlåsgevärets": "flintlåsgevär",
    "flintlåsgevärs": "flintlåsgevär",
    "flintor": "flinta",
    "flintorna": "flinta",
    "flintornas": "flinta",
    "flintors": "flinta",
    "flints": "flinta",
    "flintskall": "flintskalle",
    "flintskallar": "flintskalle",
    "flintskallarna": "flintskalle",
    "flintskallarnas": "flintskalle",
    "flintskallars": "flintskalle",
    "flintskallen": "flintskalle",
    "flintskallens": "flintskalle",
    "flintskalles": "flintskalle",
    "flintskalliga": "flintskallig",
    "flintskalligare": "flintskallig",
    "flintskalligares": "flintskallig",
    "flintskalligas": "flintskallig",
    "flintskalligast": "flintskallig",
    "flintskalligaste": "flintskallig",
    "flintskalligastes": "flintskallig",
    "flintskalligasts": "flintskallig",
    "flintskallige": "flintskallig",
    "flintskalliges": "flintskallig",
    "flintskalligheten": "flintskallighet",
    "flintskallighetens": "flintskallighet",
    "flintskallighets": "flintskallighet",
    "flintskalligs": "flintskallig",
    "flintskalligt": "flintskallig",
    "flintskalligts": "flintskallig",
    "flintskalls": "flintskalle",
    "flipperspelen": "flipperspel",
    "flipperspelens": "flipperspel",
    "flipperspelet": "flipperspel",
    "flipperspelets": "flipperspel",
    "flipperspels": "flipperspel",
    "flirt": "flirta",
    "flirtade": "flirta",
    "flirtades": "flirta",
    "flirtande": "flirta",
    "flirtanden": "flirtande",
    "flirtandena": "flirtande",
    "flirtandenas": "flirtande",
    "flirtandens": "flirtande",
    "flirtandes": "flirtande",
    "flirtandet": "flirtande",
    "flirtandets": "flirtande",
    "flirtar": "flirta",
    "flirtas": "flirta",
    "flirtat": "flirta",
    "flirtats": "flirta",
    "flirten": "flirt",
    "flirtens": "flirt",
    "flirtiga": "flirtig",
    "flirtigare": "flirtig",
    "flirtigares": "flirtig",
    "flirtigas": "flirtig",
    "flirtigast": "flirtig",
    "flirtigaste": "flirtig",
    "flirtigastes": "flirtig",
    "flirtigasts": "flirtig",
    "flirtige": "flirtig",
    "flirtiges": "flirtig",
    "flirtigheten": "flirtighet",
    "flirtighetens": "flirtighet",
    "flirtighets": "flirtighet",
    "flirtigs": "flirtig",
    "flirtigt": "flirtig",
    "flirtigts": "flirtig",
    "flirts": "flirt",
    "flis": "flisa",
    "flisan": "flisa",
    "flisans": "flisa",
    "flisas": "flisa",
    "flise": "flisa",
    "flisen": "flis",
    "flisens": "flis",
    "fliset": "flis",
    "flisets": "flis",
    "flisiga": "flisig",
    "flisigare": "flisig",
    "flisigares": "flisig",
    "flisigas": "flisig",
    "flisigast": "flisig",
    "flisigaste": "flisig",
    "flisigastes": "flisig",
    "flisigasts": "flisig",
    "flisige": "flisig",
    "flisiges": "flisig",
    "flisigs": "flisig",
    "flisigt": "flisig",
    "flisigts": "flisig",
    "flisor": "flisa",
    "flisorna": "flisa",
    "flisornas": "flisa",
    "flisors": "flisa",
    "fliten": "flit",
    "flitens": "flit",
    "flitiga": "flitig",
    "flitigare": "flitig",
    "flitigares": "flitig",
    "flitigas": "flitig",
    "flitigast": "flitig",
    "flitigaste": "flitig",
    "flitigastes": "flitig",
    "flitigasts": "flitig",
    "flitige": "flitig",
    "flitiges": "flitig",
    "flitigs": "flitig",
    "flitigt": "flitig",
    "flitigts": "flitig",
    "flits": "flit",
    "floar": "flo",
    "floarna": "flo",
    "floarnas": "flo",
    "floars": "flo",
    "floatglaset": "floatglas",
    "floatglasets": "floatglas",
    "flockades": "flockas",
    "flockar": "flock",
    "flockarna": "flock",
    "flockarnas": "flock",
    "flockars": "flock",
    "flockats": "flockas",
    "flockblommiga": "flockblommig",
    "flockblommigare": "flockblommig",
    "flockblommigares": "flockblommig",
    "flockblommigas": "flockblommig",
    "flockblommigast": "flockblommig",
    "flockblommigaste": "flockblommig",
    "flockblommigastes": "flockblommig",
    "flockblommigasts": "flockblommig",
    "flockblommige": "flockblommig",
    "flockblommiges": "flockblommig",
    "flockblommigs": "flockblommig",
    "flockblommigt": "flockblommig",
    "flockblommigts": "flockblommig",
    "flockdjuren": "flockdjur",
    "flockdjurens": "flockdjur",
    "flockdjuret": "flockdjur",
    "flockdjurets": "flockdjur",
    "flockdjurs": "flockdjur",
    "flocken": "flock",
    "flockens": "flock",
    "flocket": "flock",
    "flockets": "flock",
    "flockiga": "flockig",
    "flockigare": "flockig",
    "flockigares": "flockig",
    "flockigas": "flockig",
    "flockigast": "flockig",
    "flockigaste": "flockig",
    "flockigastes": "flockig",
    "flockigasts": "flockig",
    "flockige": "flockig",
    "flockiges": "flockig",
    "flockigheten": "flockighet",
    "flockighetens": "flockighet",
    "flockighets": "flockighet",
    "flockigs": "flockig",
    "flockigt": "flockig",
    "flockigts": "flockig",
    "flockinstinkten": "flockinstinkt",
    "flockinstinktens": "flockinstinkt",
    "flockinstinkter": "flockinstinkt",
    "flockinstinkterna": "flockinstinkt",
    "flockinstinkternas": "flockinstinkt",
    "flockinstinkters": "flockinstinkt",
    "flockinstinkts": "flockinstinkt",
    "flockkamraten": "flockkamrat",
    "flockkamratens": "flockkamrat",
    "flockkamrater": "flockkamrat",
    "flockkamraterna": "flockkamrat",
    "flockkamraternas": "flockkamrat",
    "flockkamraters": "flockkamrat",
    "flockkamrats": "flockkamrat",
    "flocks": "flock",
    "flodarmar": "flodarm",
    "flodarmarna": "flodarm",
    "flodarmarnas": "flodarm",
    "flodarmars": "flodarm",
    "flodarmen": "flodarm",
    "flodarmens": "flodarm",
    "flodarms": "flodarm",
    "flodbräddar": "flodbrädd",
    "flodbräddarna": "flodbrädd",
    "flodbräddarnas": "flodbrädd",
    "flodbräddars": "flodbrädd",
    "flodbrädden": "flodbrädd",
    "flodbräddens": "flodbrädd",
    "flodbrädds": "flodbrädd",
    "flodbäddar": "flodbädd",
    "flodbäddarna": "flodbädd",
    "flodbäddarnas": "flodbädd",
    "flodbäddars": "flodbädd",
    "flodbädden": "flodbädd",
    "flodbäddens": "flodbädd",
    "flodbädds": "flodbädd",
    "floddalar": "floddal",
    "floddalarna": "floddal",
    "floddalarnas": "floddal",
    "floddalars": "floddal",
    "floddalen": "floddal",
    "floddalens": "floddal",
    "floddals": "floddal",
    "floden": "flod",
    "flodens": "flod",
    "floder": "flod",
    "floderna": "flod",
    "flodernas": "flod",
    "floders": "flod",
    "flodfår": "flodfåra",
    "flodfåran": "flodfåra",
    "flodfårans": "flodfåra",
    "flodfåras": "flodfåra",
    "flodfåre": "flodfåra",
    "flodfåror": "flodfåra",
    "flodfårorna": "flodfåra",
    "flodfårornas": "flodfåra",
    "flodfårors": "flodfåra",
    "flodfårs": "flodfåra",
    "flodhästar": "flodhäst",
    "flodhästarna": "flodhäst",
    "flodhästarnas": "flodhäst",
    "flodhästars": "flodhäst",
    "flodhästen": "flodhäst",
    "flodhästens": "flodhäst",
    "flodhästs": "flodhäst",
    "flodhästungar": "flodhästunge",
    "flodhästungarna": "flodhästunge",
    "flodhästungarnas": "flodhästunge",
    "flodhästungars": "flodhästunge",
    "flodhästungen": "flodhästunge",
    "flodhästungens": "flodhästunge",
    "flodhästunges": "flodhästunge",
    "flodillern": "flodiller",
    "flodillerns": "flodiller",
    "flodillers": "flodiller",
    "flodillrar": "flodiller",
    "flodillrarna": "flodiller",
    "flodillrarnas": "flodiller",
    "flodillrars": "flodiller",
    "flodkrabb": "flodkrabba",
    "flodkrabban": "flodkrabba",
    "flodkrabbans": "flodkrabba",
    "flodkrabbas": "flodkrabba",
    "flodkrabbe": "flodkrabba",
    "flodkrabbor": "flodkrabba",
    "flodkrabborna": "flodkrabba",
    "flodkrabbornas": "flodkrabba",
    "flodkrabbors": "flodkrabba",
    "flodkrabbs": "flodkrabba",
    "flodkrökar": "flodkrök",
    "flodkrökarna": "flodkrök",
    "flodkrökarnas": "flodkrök",
    "flodkrökars": "flodkrök",
    "flodkröken": "flodkrök",
    "flodkrökens": "flodkrök",
    "flodkröks": "flodkrök",
    "flodmynningar": "flodmynning",
    "flodmynningarna": "flodmynning",
    "flodmynningarnas": "flodmynning",
    "flodmynningars": "flodmynning",
    "flodmynningen": "flodmynning",
    "flodmynningens": "flodmynning",
    "flodmynnings": "flodmynning",
    "flodområden": "flodområde",
    "flodområdena": "flodområde",
    "flodområdenas": "flodområde",
    "flodområdens": "flodområde",
    "flodområdes": "flodområde",
    "flodområdet": "flodområde",
    "flodområdets": "flodområde",
    "flodprofilen": "flodprofil",
    "flodprofilens": "flodprofil",
    "flodprofiler": "flodprofil",
    "flodprofilerna": "flodprofil",
    "flodprofilernas": "flodprofil",
    "flodprofilers": "flodprofil",
    "flodprofils": "flodprofil",
    "flods": "flod",
    "flodslätten": "flodslätt",
    "flodslättens": "flodslätt",
    "flodslätter": "flodslätt",
    "flodslätterna": "flodslätt",
    "flodslätternas": "flodslätt",
    "flodslätters": "flodslätt",
    "flodslätts": "flodslätt",
    "flodstranden": "flodstrand",
    "flodstrandens": "flodstrand",
    "flodstrands": "flodstrand",
    "flodstränder": "flodstrand",
    "flodstränderna": "flodstrand",
    "flodsträndernas": "flodstrand",
    "flodstränders": "flodstrand",
    "flodsvinen": "flodsvin",
    "flodsvinens": "flodsvin",
    "flodsvinet": "flodsvin",
    "flodsvinets": "flodsvin",
    "flodsvins": "flodsvin",
    "flodsystemen": "flodsystem",
    "flodsystemens": "flodsystem",
    "flodsystemet": "flodsystem",
    "flodsystemets": "flodsystem",
    "flodsystems": "flodsystem",
    "flodterrassen": "flodterrass",
    "flodterrassens": "flodterrass",
    "flodterrasser": "flodterrass",
    "flodterrasserna": "flodterrass",
    "flodterrassernas": "flodterrass",
    "flodterrassers": "flodterrass",
    "flodvågen": "flodvåg",
    "flodvågens": "flodvåg",
    "flodvågor": "flodvåg",
    "flodvågorna": "flodvåg",
    "flodvågornas": "flodvåg",
    "flodvågors": "flodvåg",
    "flodvågs": "flodvåg",
    "flogrönnar": "flogrönn",
    "flogrönnarna": "flogrönn",
    "flogrönnarnas": "flogrönn",
    "flogrönnars": "flogrönn",
    "flogrönnen": "flogrönn",
    "flogrönnens": "flogrönn",
    "flogrönns": "flogrönn",
    "flon": "flo",
    "flons": "flo",
    "flopar": "flop",
    "floparna": "flop",
    "floparnas": "flop",
    "flopars": "flop",
    "flopen": "flop",
    "flopens": "flop",
    "floppar": "flopp",
    "flopparna": "flopp",
    "flopparnas": "flopp",
    "floppars": "flopp",
    "floppen": "flopp",
    "floppens": "flopp",
    "flopps": "flopp",
    "floppsatsningar": "floppsatsning",
    "floppsatsningarna": "floppsatsning",
    "floppsatsningarnas": "floppsatsning",
    "floppsatsningars": "floppsatsning",
    "floppsatsningen": "floppsatsning",
    "floppsatsningens": "floppsatsning",
    "floppsatsnings": "floppsatsning",
    "flops": "flop",
    "flor": "flora",
    "floran": "flora",
    "florans": "flora",
    "floras": "flora",
    "flore": "flora",
    "floren": "flor",
    "florens": "flor",
    "florentinska": "florentinsk",
    "florentinskare": "florentinsk",
    "florentinskares": "florentinsk",
    "florentinskas": "florentinsk",
    "florentinskast": "florentinsk",
    "florentinskaste": "florentinsk",
    "florentinskastes": "florentinsk",
    "florentinskasts": "florentinsk",
    "florentinske": "florentinsk",
    "florentinskes": "florentinsk",
    "florentinsks": "florentinsk",
    "florentinskt": "florentinsk",
    "florentinskts": "florentinsk",
    "florerade": "florera",
    "florerades": "florera",
    "florerande": "florera",
    "floreranden": "florerande",
    "florerandena": "florerande",
    "florerandenas": "florerande",
    "florerandens": "florerande",
    "florerandes": "florerande",
    "florerandet": "florerande",
    "florerandets": "florerande",
    "florerar": "florera",
    "floreras": "florera",
    "florerat": "florera",
    "florerats": "florera",
    "floreringar": "florering",
    "floreringarna": "florering",
    "floreringarnas": "florering",
    "floreringars": "florering",
    "floreringen": "florering",
    "floreringens": "florering",
    "florerings": "florering",
    "floret": "flor",
    "florets": "flor",
    "floretten": "florett",
    "florettens": "florett",
    "floretter": "florett",
    "floretterna": "florett",
    "floretternas": "florett",
    "floretters": "florett",
    "florettfäktningar": "florettfäktning",
    "florettfäktningarna": "florettfäktning",
    "florettfäktningarnas": "florettfäktning",
    "florettfäktningars": "florettfäktning",
    "florettfäktningen": "florettfäktning",
    "florettfäktningens": "florettfäktning",
    "florettfäktnings": "florettfäktning",
    "florettfäktningskursen": "florettfäktningskurs",
    "florettfäktningskursens": "florettfäktningskurs",
    "florettfäktningskurser": "florettfäktningskurs",
    "florettfäktningskurserna": "florettfäktningskurs",
    "florettfäktningskursernas": "florettfäktningskurs",
    "florettfäktningskursers": "florettfäktningskurs",
    "floretts": "florett",
    "florilegie": "florilegium",
    "florilegier": "florilegium",
    "florilegierna": "florilegium",
    "florilegiernas": "florilegium",
    "florilegiers": "florilegium",
    "florilegiet": "florilegium",
    "florilegiets": "florilegium",
    "florilegiums": "florilegium",
    "florinen": "florin",
    "florinens": "florin",
    "floriner": "florin",
    "florinerna": "florin",
    "florinernas": "florin",
    "floriners": "florin",
    "florins": "florin",
    "floristen": "florist",
    "floristens": "florist",
    "florister": "florist",
    "floristerna": "florist",
    "floristernas": "florist",
    "floristers": "florist",
    "floristiken": "floristik",
    "floristikens": "floristik",
    "floristiks": "floristik",
    "floristiska": "floristisk",
    "floristiskare": "floristisk",
    "floristiskares": "floristisk",
    "floristiskas": "floristisk",
    "floristiskast": "floristisk",
    "floristiskaste": "floristisk",
    "floristiskastes": "floristisk",
    "floristiskasts": "floristisk",
    "floristiske": "floristisk",
    "floristiskes": "floristisk",
    "floristisks": "floristisk",
    "floristiskt": "floristisk",
    "floristiskts": "floristisk",
    "florists": "florist",
    "floror": "flora",
    "flororna": "flora",
    "florornas": "flora",
    "florors": "flora",
    "flors": "flora",
    "florsockers": "florsocker",
    "florsockret": "florsocker",
    "florsockrets": "florsocker",
    "flos": "flo",
    "floskeln": "floskel",
    "floskelns": "floskel",
    "floskelpatrioten": "floskelpatriot",
    "floskelpatriotens": "floskelpatriot",
    "floskelpatrioter": "floskelpatriot",
    "floskelpatrioterna": "floskelpatriot",
    "floskelpatrioternas": "floskelpatriot",
    "floskelpatrioters": "floskelpatriot",
    "floskelpatriots": "floskelpatriot",
    "floskels": "floskel",
    "floskler": "floskel",
    "flosklerna": "floskel",
    "flosklernas": "floskel",
    "flosklers": "floskel",
    "floskulösa": "floskulös",
    "floskulösare": "floskulös",
    "floskulösares": "floskulös",
    "floskulösas": "floskulös",
    "floskulösast": "floskulös",
    "floskulösaste": "floskulös",
    "floskulösastes": "floskulös",
    "floskulösasts": "floskulös",
    "floskulöse": "floskulös",
    "floskulöses": "floskulös",
    "floskulöst": "floskulös",
    "floskulösts": "floskulös",
    "floss": "flossa",
    "flossade": "flossad",
    "flossades": "flossad",
    "flossads": "flossad",
    "flossan": "flossa",
    "flossans": "flossa",
    "flossas": "flossa",
    "flossat": "flossad",
    "flossats": "flossad",
    "flosse": "flossa",
    "flossor": "flossa",
    "flossorna": "flossa",
    "flossornas": "flossa",
    "flossors": "flossa",
    "flotationen": "flotation",
    "flotationens": "flotation",
    "flotationer": "flotation",
    "flotationerna": "flotation",
    "flotationernas": "flotation",
    "flotationers": "flotation",
    "flotations": "flotation",
    "flott": "flotte",
    "flotta": "flott",
    "flottad": "flotta",
    "flottade": "flotta",
    "flottades": "flotta",
    "flottads": "flotta",
    "flottan": "flotta",
    "flottande": "flotta",
    "flottanden": "flottande",
    "flottandena": "flottande",
    "flottandenas": "flottande",
    "flottandens": "flottande",
    "flottandes": "flottande",
    "flottandet": "flottande",
    "flottandets": "flottande",
    "flottans": "flotta",
    "flottar": "flotte",
    "flottare": "flott",
    "flottaren": "flottare",
    "flottarens": "flottare",
    "flottares": "flottare",
    "flottarna": "flotte",
    "flottarnas": "flotte",
    "flottars": "flotte",
    "flottas": "flotta",
    "flottast": "flott",
    "flottaste": "flott",
    "flottastes": "flott",
    "flottasts": "flott",
    "flottat": "flotta",
    "flottats": "flotta",
    "flottbasen": "flottbas",
    "flottbasens": "flottbas",
    "flottbaser": "flottbas",
    "flottbaserna": "flottbas",
    "flottbasernas": "flottbas",
    "flottbasers": "flottbas",
    "flottbesöken": "flottbesök",
    "flottbesökens": "flottbesök",
    "flottbesöket": "flottbesök",
    "flottbesökets": "flottbesök",
    "flottbesöks": "flottbesök",
    "flottbroar": "flottbro",
    "flottbroarna": "flottbro",
    "flottbroarnas": "flottbro",
    "flottbroars": "flottbro",
    "flottbron": "flottbro",
    "flottbrons": "flottbro",
    "flottbros": "flottbro",
    "flotte": "flotta",
    "flotten": "flotte",
    "flottenheten": "flottenhet",
    "flottenhetens": "flottenhet",
    "flottenheter": "flottenhet",
    "flottenheterna": "flottenhet",
    "flottenheternas": "flottenhet",
    "flottenheters": "flottenhet",
    "flottenhets": "flottenhet",
    "flottens": "flotte",
    "flottes": "flotte",
    "flottet": "flott",
    "flottets": "flott",
    "flottfläckar": "flottfläck",
    "flottfläckarna": "flottfläck",
    "flottfläckarnas": "flottfläck",
    "flottfläckars": "flottfläck",
    "flottfläcken": "flottfläck",
    "flottfläckens": "flottfläck",
    "flottfläcks": "flottfläck",
    "flottheten": "flotthet",
    "flotthetens": "flotthet",
    "flotthets": "flotthet",
    "flottiga": "flottig",
    "flottigare": "flottig",
    "flottigares": "flottig",
    "flottigas": "flottig",
    "flottigast": "flottig",
    "flottigaste": "flottig",
    "flottigastes": "flottig",
    "flottigasts": "flottig",
    "flottige": "flottig",
    "flottiges": "flottig",
    "flottigheten": "flottighet",
    "flottighetens": "flottighet",
    "flottighets": "flottighet",
    "flottigs": "flottig",
    "flottigt": "flottig",
    "flottigts": "flottig",
    "flottiljen": "flottilj",
    "flottiljens": "flottilj",
    "flottiljer": "flottilj",
    "flottiljerna": "flottilj",
    "flottiljernas": "flottilj",
    "flottiljers": "flottilj",
    "flottiljs": "flottilj",
    "flottisten": "flottist",
    "flottistens": "flottist",
    "flottister": "flottist",
    "flottisterna": "flottist",
    "flottisternas": "flottist",
    "flottisters": "flottist",
    "flottists": "flottist",
    "flottleden": "flottled",
    "flottledens": "flottled",
    "flottleder": "flottled",
    "flottlederna": "flottled",
    "flottledernas": "flottled",
    "flottleders": "flottled",
    "flottleds": "flottled",
    "flottningar": "flottning",
    "flottningarna": "flottning",
    "flottningarnas": "flottning",
    "flottningars": "flottning",
    "flottningen": "flottning",
    "flottningens": "flottning",
    "flottnings": "flottning",
    "flottningstimmerna": "flottningstimmer",
    "flottningstimmernas": "flottningstimmer",
    "flottningstimmers": "flottningstimmer",
    "flottningstimren": "flottningstimmer",
    "flottningstimrens": "flottningstimmer",
    "flottningstimret": "flottningstimmer",
    "flottningstimrets": "flottningstimmer",
    "flottor": "flotta",
    "flottorna": "flotta",
    "flottornas": "flotta",
    "flottors": "flotta",
    "flotts": "flotte",
    "flottstyrmannen": "flottstyrman",
    "flottstyrmannens": "flottstyrman",
    "flottstyrmans": "flottstyrman",
    "flottstyrmän": "flottstyrman",
    "flottstyrmännen": "flottstyrman",
    "flottstyrmännens": "flottstyrman",
    "flottstyrmäns": "flottstyrman",
    "flottyren": "flottyr",
    "flottyrens": "flottyr",
    "flottyrer": "flottyr",
    "flottyrerna": "flottyr",
    "flottyrernas": "flottyr",
    "flottyrers": "flottyr",
    "flottyrkok": "flottyrkoka",
    "flottyrkokad": "flottyrkoka",
    "flottyrkokade": "flottyrkoka",
    "flottyrkokades": "flottyrkoka",
    "flottyrkokads": "flottyrkoka",
    "flottyrkokande": "flottyrkoka",
    "flottyrkokanden": "flottyrkokande",
    "flottyrkokandena": "flottyrkokande",
    "flottyrkokandenas": "flottyrkokande",
    "flottyrkokandens": "flottyrkokande",
    "flottyrkokandes": "flottyrkokande",
    "flottyrkokandet": "flottyrkokande",
    "flottyrkokandets": "flottyrkokande",
    "flottyrkokar": "flottyrkoka",
    "flottyrkokas": "flottyrkoka",
    "flottyrkokat": "flottyrkoka",
    "flottyrkokats": "flottyrkoka",
    "flottyrkoker": "flottyrkoka",
    "flottyrkokes": "flottyrkoka",
    "flottyrkoks": "flottyrkoka",
    "flottyrkokt": "flottyrkoka",
    "flottyrkokta": "flottyrkoka",
    "flottyrkoktas": "flottyrkoka",
    "flottyrkokte": "flottyrkoka",
    "flottyrkoktes": "flottyrkoka",
    "flottyrkokts": "flottyrkoka",
    "flottyrs": "flottyr",
    "flottören": "flottör",
    "flottörens": "flottör",
    "flottörer": "flottör",
    "flottörerna": "flottör",
    "flottörernas": "flottör",
    "flottörers": "flottör",
    "flottörs": "flottör",
    "floxar": "flox",
    "floxarna": "flox",
    "floxarnas": "flox",
    "floxars": "flox",
    "floxen": "flox",
    "floxens": "flox",
    "fluffiga": "fluffig",
    "fluffigare": "fluffig",
    "fluffigares": "fluffig",
    "fluffigas": "fluffig",
    "fluffigast": "fluffig",
    "fluffigaste": "fluffig",
    "fluffigastes": "fluffig",
    "fluffigasts": "fluffig",
    "fluffige": "fluffig",
    "fluffiges": "fluffig",
    "fluffigheten": "fluffighet",
    "fluffighetens": "fluffighet",
    "fluffigheter": "fluffighet",
    "fluffigheterna": "fluffighet",
    "fluffigheternas": "fluffighet",
    "fluffigheters": "fluffighet",
    "fluffighets": "fluffighet",
    "fluffigs": "fluffig",
    "fluffigt": "fluffig",
    "fluffigts": "fluffig",
    "flug": "fluga",
    "flugan": "fluga",
    "flugans": "fluga",
    "flugas": "fluga",
    "flugblomsterna": "flugblomster",
    "flugblomsternas": "flugblomster",
    "flugblomsters": "flugblomster",
    "flugblomstren": "flugblomster",
    "flugblomstrens": "flugblomster",
    "flugblomstret": "flugblomster",
    "flugblomstrets": "flugblomster",
    "fluge": "fluga",
    "flugen": "flyga",
    "flugens": "flyga",
    "fluget": "flyga",
    "flugets": "flyga",
    "flugfiskes": "flugfiske",
    "flugfisket": "flugfiske",
    "flugfiskets": "flugfiske",
    "flugit": "flyga",
    "flugits": "flyga",
    "flugna": "flyga",
    "flugnas": "flyga",
    "flugne": "flyga",
    "flugnes": "flyga",
    "flugor": "fluga",
    "flugorna": "fluga",
    "flugornas": "fluga",
    "flugors": "fluga",
    "flugs": "fluga",
    "flugsmäll": "flugsmälla",
    "flugsmällan": "flugsmälla",
    "flugsmällans": "flugsmälla",
    "flugsmällas": "flugsmälla",
    "flugsmälle": "flugsmälla",
    "flugsmällor": "flugsmälla",
    "flugsmällorna": "flugsmälla",
    "flugsmällornas": "flugsmälla",
    "flugsmällors": "flugsmälla",
    "flugsmälls": "flugsmälla",
    "flugsnappar": "flugsnappare",
    "flugsnapparen": "flugsnappare",
    "flugsnapparens": "flugsnappare",
    "flugsnappares": "flugsnappare",
    "flugsnapparna": "flugsnappare",
    "flugsnapparnas": "flugsnappare",
    "flugsvampar": "flugsvamp",
    "flugsvamparna": "flugsvamp",
    "flugsvamparnas": "flugsvamp",
    "flugsvampars": "flugsvamp",
    "flugsvampen": "flugsvamp",
    "flugsvampens": "flugsvamp",
    "flugsvamps": "flugsvamp",
    "flugvift": "flugvifta",
    "flugviftan": "flugvifta",
    "flugviftans": "flugvifta",
    "flugviftas": "flugvifta",
    "flugvifte": "flugvifta",
    "flugviftor": "flugvifta",
    "flugviftorna": "flugvifta",
    "flugviftornas": "flugvifta",
    "flugviftors": "flugvifta",
    "flugvifts": "flugvifta",
    "flugvikten": "flugvikt",
    "flugviktens": "flugvikt",
    "flugvikts": "flugvikt",
    "fluida": "fluidum",
    "fluidana": "fluidum",
    "fluidanas": "fluidum",
    "fluidas": "fluidum",
    "fluide": "fluidum",
    "fluiden": "fluid",
    "fluidens": "fluid",
    "fluider": "fluidum",
    "fluiderna": "fluidum",
    "fluidernas": "fluidum",
    "fluiders": "fluidum",
    "fluidet": "fluidum",
    "fluidets": "fluidum",
    "fluidiserad": "fluidisera",
    "fluidiserade": "fluidisera",
    "fluidiserades": "fluidisera",
    "fluidiserads": "fluidisera",
    "fluidiserande": "fluidisera",
    "fluidiseranden": "fluidiserande",
    "fluidiserandena": "fluidiserande",
    "fluidiserandenas": "fluidiserande",
    "fluidiserandens": "fluidiserande",
    "fluidiserandes": "fluidiserande",
    "fluidiserandet": "fluidiserande",
    "fluidiserandets": "fluidiserande",
    "fluidiserar": "fluidisera",
    "fluidiseras": "fluidisera",
    "fluidiserat": "fluidisera",
    "fluidiserats": "fluidisera",
    "fluidiserbara": "fluidiserbar",
    "fluidiserbarare": "fluidiserbar",
    "fluidiserbarares": "fluidiserbar",
    "fluidiserbaras": "fluidiserbar",
    "fluidiserbarast": "fluidiserbar",
    "fluidiserbaraste": "fluidiserbar",
    "fluidiserbarastes": "fluidiserbar",
    "fluidiserbarasts": "fluidiserbar",
    "fluidiserbare": "fluidiserbar",
    "fluidiserbares": "fluidiserbar",
    "fluidiserbarheten": "fluidiserbarhet",
    "fluidiserbarhetens": "fluidiserbarhet",
    "fluidiserbarhets": "fluidiserbarhet",
    "fluidiserbars": "fluidiserbar",
    "fluidiserbart": "fluidiserbar",
    "fluidiserbarts": "fluidiserbar",
    "fluidiseringar": "fluidisering",
    "fluidiseringarna": "fluidisering",
    "fluidiseringarnas": "fluidisering",
    "fluidiseringars": "fluidisering",
    "fluidiseringen": "fluidisering",
    "fluidiseringens": "fluidisering",
    "fluidiserings": "fluidisering",
    "fluids": "fluid",
    "fluidums": "fluidum",
    "flukt": "flukta",
    "fluktade": "flukta",
    "fluktades": "flukta",
    "fluktande": "flukta",
    "fluktanden": "fluktande",
    "fluktandena": "fluktande",
    "fluktandenas": "fluktande",
    "fluktandens": "fluktande",
    "fluktandes": "fluktande",
    "fluktandet": "fluktande",
    "fluktandets": "fluktande",
    "fluktar": "flukta",
    "fluktarna": "flukt",
    "fluktarnas": "flukt",
    "fluktars": "flukt",
    "fluktas": "flukta",
    "fluktat": "flukta",
    "fluktats": "flukta",
    "flukten": "flukt",
    "fluktens": "flukt",
    "flukts": "flukt",
    "fluktuationen": "fluktuation",
    "fluktuationens": "fluktuation",
    "fluktuationer": "fluktuation",
    "fluktuationerna": "fluktuation",
    "fluktuationernas": "fluktuation",
    "fluktuationers": "fluktuation",
    "fluktuations": "fluktuation",
    "fluktuerade": "fluktuera",
    "fluktuerades": "fluktuera",
    "fluktuerande": "fluktuera",
    "fluktueranden": "fluktuerande",
    "fluktuerandena": "fluktuerande",
    "fluktuerandenas": "fluktuerande",
    "fluktuerandens": "fluktuerande",
    "fluktuerandes": "fluktuerande",
    "fluktuerandet": "fluktuerande",
    "fluktuerandets": "fluktuerande",
    "fluktuerar": "fluktuera",
    "fluktueras": "fluktuera",
    "fluktuerat": "fluktuera",
    "fluktuerats": "fluktuera",
    "fluktueringar": "fluktuering",
    "fluktueringarna": "fluktuering",
    "fluktueringarnas": "fluktuering",
    "fluktueringars": "fluktuering",
    "fluktueringen": "fluktuering",
    "fluktueringens": "fluktuering",
    "fluktuerings": "fluktuering",
    "flummade": "flumma",
    "flummades": "flumma",
    "flummande": "flumma",
    "flummanden": "flummande",
    "flummandena": "flummande",
    "flummandenas": "flummande",
    "flummandens": "flummande",
    "flummandes": "flummande",
    "flummandet": "flummande",
    "flummandets": "flummande",
    "flummar": "flumma",
    "flummas": "flumma",
    "flummat": "flumma",
    "flummats": "flumma",
    "flummet": "flum",
    "flummets": "flum",
    "flummiga": "flummig",
    "flummigare": "flummig",
    "flummigares": "flummig",
    "flummigas": "flummig",
    "flummigast": "flummig",
    "flummigaste": "flummig",
    "flummigastes": "flummig",
    "flummigasts": "flummig",
    "flummige": "flummig",
    "flummiges": "flummig",
    "flummigheten": "flummighet",
    "flummighetens": "flummighet",
    "flummighets": "flummighet",
    "flummigs": "flummig",
    "flummigt": "flummig",
    "flummigts": "flummig",
    "flumpedagogiken": "flumpedagogik",
    "flumpedagogikens": "flumpedagogik",
    "flumpedagogiks": "flumpedagogik",
    "flums": "flum",
    "flundran": "flundra",
    "flundrans": "flundra",
    "flundras": "flundra",
    "flundre": "flundra",
    "flundror": "flundra",
    "flundrorna": "flundra",
    "flundrornas": "flundra",
    "flundrors": "flundra",
    "flunsan": "flunsa",
    "flunsans": "flunsa",
    "flunsas": "flunsa",
    "flunsor": "flunsa",
    "flunsorna": "flunsa",
    "flunsornas": "flunsa",
    "flunsors": "flunsa",
    "fluorbehandlingar": "fluorbehandling",
    "fluorbehandlingarna": "fluorbehandling",
    "fluorbehandlingarnas": "fluorbehandling",
    "fluorbehandlingars": "fluorbehandling",
    "fluorbehandlingen": "fluorbehandling",
    "fluorbehandlingens": "fluorbehandling",
    "fluorbehandlings": "fluorbehandling",
    "fluoren": "fluor",
    "fluorens": "fluor",
    "fluorerad": "fluorera",
    "fluorerade": "fluorera",
    "fluorerades": "fluorera",
    "fluorerads": "fluorera",
    "fluorerande": "fluorera",
    "fluoreranden": "fluorerande",
    "fluorerandena": "fluorerande",
    "fluorerandenas": "fluorerande",
    "fluorerandens": "fluorerande",
    "fluorerandes": "fluorerande",
    "fluorerandet": "fluorerande",
    "fluorerandets": "fluorerande",
    "fluorerar": "fluorera",
    "fluoreras": "fluorera",
    "fluorerat": "fluorera",
    "fluorerats": "fluorera",
    "fluorerbara": "fluorerbar",
    "fluorerbarare": "fluorerbar",
    "fluorerbarares": "fluorerbar",
    "fluorerbaras": "fluorerbar",
    "fluorerbarast": "fluorerbar",
    "fluorerbaraste": "fluorerbar",
    "fluorerbarastes": "fluorerbar",
    "fluorerbarasts": "fluorerbar",
    "fluorerbare": "fluorerbar",
    "fluorerbares": "fluorerbar",
    "fluorerbarheten": "fluorerbarhet",
    "fluorerbarhetens": "fluorerbarhet",
    "fluorerbarhets": "fluorerbarhet",
    "fluorerbars": "fluorerbar",
    "fluorerbart": "fluorerbar",
    "fluorerbarts": "fluorerbar",
    "fluoreringar": "fluorering",
    "fluoreringarna": "fluorering",
    "fluoreringarnas": "fluorering",
    "fluoreringars": "fluorering",
    "fluoreringen": "fluorering",
    "fluoreringens": "fluorering",
    "fluorerings": "fluorering",
    "fluorescensen": "fluorescens",
    "fluorescensens": "fluorescens",
    "fluorescerade": "fluorescera",
    "fluorescerades": "fluorescera",
    "fluorescerande": "fluorescera",
    "fluoresceranden": "fluorescerande",
    "fluorescerandena": "fluorescerande",
    "fluorescerandenas": "fluorescerande",
    "fluorescerandens": "fluorescerande",
    "fluorescerandes": "fluorescerande",
    "fluorescerandet": "fluorescerande",
    "fluorescerandets": "fluorescerande",
    "fluorescerar": "fluorescera",
    "fluoresceras": "fluorescera",
    "fluorescerat": "fluorescera",
    "fluorescerats": "fluorescera",
    "fluoresceringar": "fluorescering",
    "fluoresceringarna": "fluorescering",
    "fluoresceringarnas": "fluorescering",
    "fluoresceringars": "fluorescering",
    "fluoresceringen": "fluorescering",
    "fluoresceringens": "fluorescering",
    "fluorescerings": "fluorescering",
    "fluoret": "fluor",
    "fluorets": "fluor",
    "fluorhalten": "fluorhalt",
    "fluorhaltens": "fluorhalt",
    "fluorhalter": "fluorhalt",
    "fluorhalterna": "fluorhalt",
    "fluorhalternas": "fluorhalt",
    "fluorhalters": "fluorhalt",
    "fluorhaltiga": "fluorhaltig",
    "fluorhaltigare": "fluorhaltig",
    "fluorhaltigares": "fluorhaltig",
    "fluorhaltigas": "fluorhaltig",
    "fluorhaltigast": "fluorhaltig",
    "fluorhaltigaste": "fluorhaltig",
    "fluorhaltigastes": "fluorhaltig",
    "fluorhaltigasts": "fluorhaltig",
    "fluorhaltige": "fluorhaltig",
    "fluorhaltiges": "fluorhaltig",
    "fluorhaltigs": "fluorhaltig",
    "fluorhaltigt": "fluorhaltig",
    "fluorhaltigts": "fluorhaltig",
    "fluorhalts": "fluorhalt",
    "fluoriden": "fluorid",
    "fluoridens": "fluorid",
    "fluorider": "fluorid",
    "fluoriderad": "fluoridera",
    "fluoriderade": "fluoridera",
    "fluoriderades": "fluoridera",
    "fluoriderads": "fluoridera",
    "fluoriderande": "fluoridera",
    "fluorideranden": "fluoriderande",
    "fluoriderandena": "fluoriderande",
    "fluoriderandenas": "fluoriderande",
    "fluoriderandens": "fluoriderande",
    "fluoriderandes": "fluoriderande",
    "fluoriderandet": "fluoriderande",
    "fluoriderandets": "fluoriderande",
    "fluoriderar": "fluoridera",
    "fluorideras": "fluoridera",
    "fluoriderat": "fluoridera",
    "fluoriderats": "fluoridera",
    "fluoriderbara": "fluoriderbar",
    "fluoriderbarare": "fluoriderbar",
    "fluoriderbarares": "fluoriderbar",
    "fluoriderbaras": "fluoriderbar",
    "fluoriderbarast": "fluoriderbar",
    "fluoriderbaraste": "fluoriderbar",
    "fluoriderbarastes": "fluoriderbar",
    "fluoriderbarasts": "fluoriderbar",
    "fluoriderbare": "fluoriderbar",
    "fluoriderbares": "fluoriderbar",
    "fluoriderbarheten": "fluoriderbarhet",
    "fluoriderbarhetens": "fluoriderbarhet",
    "fluoriderbarhets": "fluoriderbarhet",
    "fluoriderbars": "fluoriderbar",
    "fluoriderbart": "fluoriderbar",
    "fluoriderbarts": "fluoriderbar",
    "fluorideringar": "fluoridering",
    "fluorideringarna": "fluoridering",
    "fluorideringarnas": "fluoridering",
    "fluorideringars": "fluoridering",
    "fluorideringen": "fluoridering",
    "fluorideringens": "fluoridering",
    "fluoriderings": "fluoridering",
    "fluoriderna": "fluorid",
    "fluoridernas": "fluorid",
    "fluoriders": "fluorid",
    "fluorids": "fluorid",
    "fluors": "fluor",
    "flussen": "fluss",
    "flussens": "fluss",
    "flusser": "fluss",
    "flusserna": "fluss",
    "flussernas": "fluss",
    "flussers": "fluss",
    "flussglaset": "flussglas",
    "flussglasets": "flussglas",
    "flussmedels": "flussmedel",
    "flussmedlen": "flussmedel",
    "flussmedlens": "flussmedel",
    "flussmedlet": "flussmedel",
    "flussmedlets": "flussmedel",
    "flusspaten": "flusspat",
    "flusspatens": "flusspat",
    "flusspats": "flusspat",
    "flusterna": "fluster",
    "flusternas": "fluster",
    "flusters": "fluster",
    "flustren": "fluster",
    "flustrens": "fluster",
    "flustret": "fluster",
    "flustrets": "fluster",
    "fluten": "flyta",
    "flutens": "flyta",
    "flutet": "flyta",
    "flutets": "flyta",
    "flutit": "flyta",
    "flutits": "flyta",
    "flutna": "flyta",
    "flutnas": "flyta",
    "flutne": "flyta",
    "flutnes": "flyta",
    "fluviala": "fluvial",
    "fluvialare": "fluvial",
    "fluvialares": "fluvial",
    "fluvialas": "fluvial",
    "fluvialast": "fluvial",
    "fluvialaste": "fluvial",
    "fluvialastes": "fluvial",
    "fluvialasts": "fluvial",
    "fluviale": "fluvial",
    "fluviales": "fluvial",
    "fluvials": "fluvial",
    "fluvialt": "fluvial",
    "fluvialts": "fluvial",
    "flydd": "fly",
    "flydda": "fly",
    "flyddas": "fly",
    "flydde": "fly",
    "flyddes": "fly",
    "flydds": "fly",
    "flyen": "fly",
    "flyende": "fly",
    "flyenden": "flyende",
    "flyendena": "flyende",
    "flyendenas": "flyende",
    "flyendens": "flyende",
    "flyendes": "flyende",
    "flyendet": "flyende",
    "flyendets": "flyende",
    "flyens": "fly",
    "flyet": "fly",
    "flyets": "fly",
    "flyfotade": "flyfotad",
    "flyfotades": "flyfotad",
    "flyfotadheten": "flyfotadhet",
    "flyfotadhetens": "flyfotadhet",
    "flyfotadhets": "flyfotadhet",
    "flyfotads": "flyfotad",
    "flyfotat": "flyfotad",
    "flyfotats": "flyfotad",
    "flyg": "flyga",
    "flygande": "flyga",
    "flyganden": "flygande",
    "flygandena": "flygande",
    "flygandenas": "flygande",
    "flygandens": "flygande",
    "flygandes": "flygande",
    "flygandet": "flygande",
    "flygandets": "flygande",
    "flyganfallen": "flyganfall",
    "flyganfallens": "flyganfall",
    "flyganfallet": "flyganfall",
    "flyganfallets": "flyganfall",
    "flyganfalls": "flyganfall",
    "flygankomsten": "flygankomst",
    "flygankomstens": "flygankomst",
    "flygankomster": "flygankomst",
    "flygankomsterna": "flygankomst",
    "flygankomsternas": "flygankomst",
    "flygankomsters": "flygankomst",
    "flygankomsts": "flygankomst",
    "flygar": "flygare",
    "flygaren": "flygare",
    "flygarens": "flygare",
    "flygares": "flygare",
    "flygarna": "flygare",
    "flygarnas": "flygare",
    "flygas": "flyga",
    "flygattachéer": "flygattaché",
    "flygattachéerna": "flygattaché",
    "flygattachéernas": "flygattaché",
    "flygattachéers": "flygattaché",
    "flygattachén": "flygattaché",
    "flygattachéns": "flygattaché",
    "flygattachés": "flygattaché",
    "flygattacken": "flygattack",
    "flygattackens": "flygattack",
    "flygattacker": "flygattack",
    "flygattackerna": "flygattack",
    "flygattackernas": "flygattack",
    "flygattackers": "flygattack",
    "flygattacks": "flygattack",
    "flygavgångar": "flygavgång",
    "flygavgångarna": "flygavgång",
    "flygavgångarnas": "flygavgång",
    "flygavgångars": "flygavgång",
    "flygavgången": "flygavgång",
    "flygavgångens": "flygavgång",
    "flygavgångs": "flygavgång",
    "flygbasen": "flygbas",
    "flygbasens": "flygbas",
    "flygbaser": "flygbas",
    "flygbaserna": "flygbas",
    "flygbasernas": "flygbas",
    "flygbasers": "flygbas",
    "flygbensinen": "flygbensin",
    "flygbensinens": "flygbensin",
    "flygbensins": "flygbensin",
    "flygbilden": "flygbild",
    "flygbildens": "flygbild",
    "flygbilder": "flygbild",
    "flygbilderna": "flygbild",
    "flygbildernas": "flygbild",
    "flygbilders": "flygbild",
    "flygbilds": "flygbild",
    "flygbiljetten": "flygbiljett",
    "flygbiljettens": "flygbiljett",
    "flygbiljetter": "flygbiljett",
    "flygbiljetterna": "flygbiljett",
    "flygbiljetternas": "flygbiljett",
    "flygbiljetters": "flygbiljett",
    "flygbiljetts": "flygbiljett",
    "flygbladen": "flygblad",
    "flygbladens": "flygblad",
    "flygbladet": "flygblad",
    "flygbladets": "flygblad",
    "flygblads": "flygblad",
    "flygbolagen": "flygbolag",
    "flygbolagens": "flygbolag",
    "flygbolaget": "flygbolag",
    "flygbolagets": "flygbolag",
    "flygbolags": "flygbolag",
    "flygbombad": "flygbomba",
    "flygbombade": "flygbomba",
    "flygbombades": "flygbomba",
    "flygbombads": "flygbomba",
    "flygbombande": "flygbomba",
    "flygbombanden": "flygbombande",
    "flygbombandena": "flygbombande",
    "flygbombandenas": "flygbombande",
    "flygbombandens": "flygbombande",
    "flygbombandes": "flygbombande",
    "flygbombandet": "flygbombande",
    "flygbombandets": "flygbombande",
    "flygbombar": "flygbomba",
    "flygbombas": "flygbomba",
    "flygbombat": "flygbomba",
    "flygbombats": "flygbomba",
    "flygbomben": "flygbomb",
    "flygbombens": "flygbomb",
    "flygbomber": "flygbomb",
    "flygbomberna": "flygbomb",
    "flygbombernas": "flygbomb",
    "flygbombers": "flygbomb",
    "flygbombs": "flygbomb",
    "flygbränslen": "flygbränsle",
    "flygbränslena": "flygbränsle",
    "flygbränslenas": "flygbränsle",
    "flygbränslens": "flygbränsle",
    "flygbränsles": "flygbränsle",
    "flygbränslet": "flygbränsle",
    "flygbränslets": "flygbränsle",
    "flygbåtar": "flygbåt",
    "flygbåtarna": "flygbåt",
    "flygbåtarnas": "flygbåt",
    "flygbåtars": "flygbåt",
    "flygbåten": "flygbåt",
    "flygbåtens": "flygbåt",
    "flygbåts": "flygbåt",
    "flygcertifikaten": "flygcertifikat",
    "flygcertifikatens": "flygcertifikat",
    "flygcertifikatet": "flygcertifikat",
    "flygcertifikatets": "flygcertifikat",
    "flygcertifikats": "flygcertifikat",
    "flygdraman": "flygdrama",
    "flygdramana": "flygdrama",
    "flygdramanas": "flygdrama",
    "flygdramans": "flygdrama",
    "flygdramas": "flygdrama",
    "flygdramat": "flygdrama",
    "flygdramats": "flygdrama",
    "flygdramer": "flygdrama",
    "flygdramerna": "flygdrama",
    "flygdramernas": "flygdrama",
    "flygdramers": "flygdrama",
    "flyge": "flyga",
    "flygekorr": "flygekorre",
    "flygekorrar": "flygekorre",
    "flygekorrarna": "flygekorre",
    "flygekorrarnas": "flygekorre",
    "flygekorrars": "flygekorre",
    "flygekorren": "flygekorre",
    "flygekorrens": "flygekorre",
    "flygekorres": "flygekorre",
    "flygekorrs": "flygekorre",
    "flygeln": "flygel",
    "flygelns": "flygel",
    "flygels": "flygel",
    "flygen": "flyg",
    "flygens": "flyg",
    "flyger": "flyga",
    "flyges": "flyga",
    "flyget": "flyg",
    "flygets": "flyg",
    "flygfiskar": "flygfisk",
    "flygfiskarna": "flygfisk",
    "flygfiskarnas": "flygfisk",
    "flygfiskars": "flygfisk",
    "flygfisken": "flygfisk",
    "flygfiskens": "flygfisk",
    "flygfisks": "flygfisk",
    "flygflottan": "flygflotta",
    "flygflottans": "flygflotta",
    "flygflottas": "flygflotta",
    "flygflotte": "flygflotta",
    "flygflottor": "flygflotta",
    "flygflottorna": "flygflotta",
    "flygflottornas": "flygflotta",
    "flygflottors": "flygflotta",
    "flygfotogenen": "flygfotogen",
    "flygfotogenens": "flygfotogen",
    "flygfotogenet": "flygfotogen",
    "flygfotogenets": "flygfotogen",
    "flygfotogens": "flygfotogen",
    "flygfotografier": "flygfotografi",
    "flygfotografierna": "flygfotografi",
    "flygfotografiernas": "flygfotografi",
    "flygfotografiers": "flygfotografi",
    "flygfotografiet": "flygfotografi",
    "flygfotografiets": "flygfotografi",
    "flygfotografis": "flygfotografi",
    "flygfotografit": "flygfotografi",
    "flygfotografits": "flygfotografi",
    "flygfoton": "flygfoto",
    "flygfotona": "flygfoto",
    "flygfotonas": "flygfoto",
    "flygfotons": "flygfoto",
    "flygfotos": "flygfoto",
    "flygfotot": "flygfoto",
    "flygfotots": "flygfoto",
    "flygfrakten": "flygfrakt",
    "flygfraktens": "flygfrakt",
    "flygfrakter": "flygfrakt",
    "flygfrakterna": "flygfrakt",
    "flygfrakternas": "flygfrakt",
    "flygfrakters": "flygfrakt",
    "flygfrakts": "flygfrakt",
    "flygfäet": "flygfä",
    "flygfäets": "flygfä",
    "flygfälten": "flygfält",
    "flygfältens": "flygfält",
    "flygfältet": "flygfält",
    "flygfältets": "flygfält",
    "flygfälts": "flygfält",
    "flygfän": "flygfä",
    "flygfäna": "flygfä",
    "flygfänas": "flygfä",
    "flygfäns": "flygfä",
    "flygfärden": "flygfärd",
    "flygfärdens": "flygfärd",
    "flygfärder": "flygfärd",
    "flygfärderna": "flygfärd",
    "flygfärdernas": "flygfärd",
    "flygfärders": "flygfärd",
    "flygfärdiga": "flygfärdig",
    "flygfärdigare": "flygfärdig",
    "flygfärdigares": "flygfärdig",
    "flygfärdigas": "flygfärdig",
    "flygfärdigast": "flygfärdig",
    "flygfärdigaste": "flygfärdig",
    "flygfärdigastes": "flygfärdig",
    "flygfärdigasts": "flygfärdig",
    "flygfärdige": "flygfärdig",
    "flygfärdiges": "flygfärdig",
    "flygfärdigheten": "flygfärdighet",
    "flygfärdighetens": "flygfärdighet",
    "flygfärdighets": "flygfärdighet",
    "flygfärdigs": "flygfärdig",
    "flygfärdigt": "flygfärdig",
    "flygfärdigts": "flygfärdig",
    "flygfärds": "flygfärd",
    "flygfäs": "flygfä",
    "flygfät": "flygfä",
    "flygfäts": "flygfä",
    "flygförar": "flygförare",
    "flygföraren": "flygförare",
    "flygförarens": "flygförare",
    "flygförares": "flygförare",
    "flygförarna": "flygförare",
    "flygförarnas": "flygförare",
    "flygförbanden": "flygförband",
    "flygförbandens": "flygförband",
    "flygförbandet": "flygförband",
    "flygförbandets": "flygförband",
    "flygförbands": "flygförband",
    "flygförbuden": "flygförbud",
    "flygförbudens": "flygförbud",
    "flygförbudet": "flygförbud",
    "flygförbudets": "flygförbud",
    "flygförbuds": "flygförbud",
    "flygga": "flygg",
    "flyggare": "flygg",
    "flyggares": "flygg",
    "flyggas": "flygg",
    "flyggast": "flygg",
    "flyggaste": "flygg",
    "flyggastes": "flygg",
    "flyggasts": "flygg",
    "flygge": "flygg",
    "flygges": "flygg",
    "flyggheten": "flygghet",
    "flygghetens": "flygghet",
    "flygghets": "flygghet",
    "flyggs": "flygg",
    "flyggt": "flygg",
    "flyggts": "flygg",
    "flyghastigheten": "flyghastighet",
    "flyghastighetens": "flyghastighet",
    "flyghastigheter": "flyghastighet",
    "flyghastigheterna": "flyghastighet",
    "flyghastigheternas": "flyghastighet",
    "flyghastigheters": "flyghastighet",
    "flyghastighets": "flyghastighet",
    "flyghavren": "flyghavre",
    "flyghavrens": "flyghavre",
    "flyghavres": "flyghavre",
    "flyghundar": "flyghund",
    "flyghundarna": "flyghund",
    "flyghundarnas": "flyghund",
    "flyghundars": "flyghund",
    "flyghunden": "flyghund",
    "flyghundens": "flyghund",
    "flyghunds": "flyghund",
    "flygindustrien": "flygindustri",
    "flygindustriens": "flygindustri",
    "flygindustrier": "flygindustri",
    "flygindustrierna": "flygindustri",
    "flygindustriernas": "flygindustri",
    "flygindustriers": "flygindustri",
    "flygindustrin": "flygindustri",
    "flygindustrins": "flygindustri",
    "flygindustris": "flygindustri",
    "flygkaosen": "flygkaos",
    "flygkaosens": "flygkaos",
    "flygkaoset": "flygkaos",
    "flygkaosets": "flygkaos",
    "flygkapaciteten": "flygkapacitet",
    "flygkapacitetens": "flygkapacitet",
    "flygkapaciteter": "flygkapacitet",
    "flygkapaciteterna": "flygkapacitet",
    "flygkapaciteternas": "flygkapacitet",
    "flygkapaciteters": "flygkapacitet",
    "flygkapacitets": "flygkapacitet",
    "flygkapningar": "flygkapning",
    "flygkapningarna": "flygkapning",
    "flygkapningarnas": "flygkapning",
    "flygkapningars": "flygkapning",
    "flygkapningen": "flygkapning",
    "flygkapningens": "flygkapning",
    "flygkapnings": "flygkapning",
    "flygkaptenen": "flygkapten",
    "flygkaptenens": "flygkapten",
    "flygkaptener": "flygkapten",
    "flygkaptenerna": "flygkapten",
    "flygkaptenernas": "flygkapten",
    "flygkapteners": "flygkapten",
    "flygkaptens": "flygkapten",
    "flygkatastrofen": "flygkatastrof",
    "flygkatastrofens": "flygkatastrof",
    "flygkatastrofer": "flygkatastrof",
    "flygkatastroferna": "flygkatastrof",
    "flygkatastrofernas": "flygkatastrof",
    "flygkatastrofers": "flygkatastrof",
    "flygkatastrofs": "flygkatastrof",
    "flygkonsten": "flygkonst",
    "flygkonstens": "flygkonst",
    "flygkonster": "flygkonst",
    "flygkonsterna": "flygkonst",
    "flygkonsternas": "flygkonst",
    "flygkonsters": "flygkonst",
    "flygkonsts": "flygkonst",
    "flygkorridoren": "flygkorridor",
    "flygkorridorens": "flygkorridor",
    "flygkorridorer": "flygkorridor",
    "flygkorridorerna": "flygkorridor",
    "flygkorridorernas": "flygkorridor",
    "flygkorridorers": "flygkorridor",
    "flygkorridors": "flygkorridor",
    "flygkroppar": "flygkropp",
    "flygkropparna": "flygkropp",
    "flygkropparnas": "flygkropp",
    "flygkroppars": "flygkropp",
    "flygkroppen": "flygkropp",
    "flygkroppens": "flygkropp",
    "flygkropps": "flygkropp",
    "flygkåren": "flygkår",
    "flygkårens": "flygkår",
    "flygkårer": "flygkår",
    "flygkårerna": "flygkår",
    "flygkårernas": "flygkår",
    "flygkårers": "flygkår",
    "flygkårs": "flygkår",
    "flyglar": "flygel",
    "flyglarmen": "flyglarm",
    "flyglarmens": "flyglarm",
    "flyglarmet": "flyglarm",
    "flyglarmets": "flyglarm",
    "flyglarms": "flyglarm",
    "flyglarna": "flygel",
    "flyglarnas": "flygel",
    "flyglars": "flygel",
    "flygledar": "flygledare",
    "flygledaren": "flygledare",
    "flygledarens": "flygledare",
    "flygledares": "flygledare",
    "flygledarna": "flygledare",
    "flygledarnas": "flygledare",
    "flygledarstrejken": "flygledarstrejk",
    "flygledarstrejkens": "flygledarstrejk",
    "flygledarstrejker": "flygledarstrejk",
    "flygledarstrejkerna": "flygledarstrejk",
    "flygledarstrejkernas": "flygledarstrejk",
    "flygledarstrejkers": "flygledarstrejk",
    "flygledarstrejks": "flygledarstrejk",
    "flygledningar": "flygledning",
    "flygledningarna": "flygledning",
    "flygledningarnas": "flygledning",
    "flygledningars": "flygledning",
    "flygledningen": "flygledning",
    "flygledningens": "flygledning",
    "flyglednings": "flygledning",
    "flyglinjen": "flyglinje",
    "flyglinjens": "flyglinje",
    "flyglinjer": "flyglinje",
    "flyglinjerna": "flyglinje",
    "flyglinjernas": "flyglinje",
    "flyglinjers": "flyglinje",
    "flyglinjes": "flyglinje",
    "flyglägenheten": "flyglägenhet",
    "flyglägenhetens": "flyglägenhet",
    "flyglägenheter": "flyglägenhet",
    "flyglägenheterna": "flyglägenhet",
    "flyglägenheternas": "flyglägenhet",
    "flyglägenheters": "flyglägenhet",
    "flyglägenhets": "flyglägenhet",
    "flygmaskinen": "flygmaskin",
    "flygmaskinens": "flygmaskin",
    "flygmaskiner": "flygmaskin",
    "flygmaskinerna": "flygmaskin",
    "flygmaskinernas": "flygmaskin",
    "flygmaskiners": "flygmaskin",
    "flygmaskins": "flygmaskin",
    "flygmyr": "flygmyra",
    "flygmyran": "flygmyra",
    "flygmyrans": "flygmyra",
    "flygmyras": "flygmyra",
    "flygmyre": "flygmyra",
    "flygmyror": "flygmyra",
    "flygmyrorna": "flygmyra",
    "flygmyrornas": "flygmyra",
    "flygmyrors": "flygmyra",
    "flygmyrs": "flygmyra",
    "flygningar": "flygning",
    "flygningarna": "flygning",
    "flygningarnas": "flygning",
    "flygningars": "flygning",
    "flygningen": "flygning",
    "flygningens": "flygning",
    "flygnings": "flygning",
    "flygpassagerar": "flygpassagerare",
    "flygpassageraren": "flygpassagerare",
    "flygpassagerarens": "flygpassagerare",
    "flygpassagerares": "flygpassagerare",
    "flygpassagerarna": "flygpassagerare",
    "flygpassagerarnas": "flygpassagerare",
    "flygplanen": "flygplan",
    "flygplanens": "flygplan",
    "flygplanet": "flygplan",
    "flygplanets": "flygplan",
    "flygplans": "flygplan",
    "flygplanshangarer": "flygplanshangar",
    "flygplanshangarerna": "flygplanshangar",
    "flygplanshangarernas": "flygplanshangar",
    "flygplanshangarers": "flygplanshangar",
    "flygplanshangarn": "flygplanshangar",
    "flygplanshangarns": "flygplanshangar",
    "flygplanshangars": "flygplanshangar",
    "flygplanskabinen": "flygplanskabin",
    "flygplanskabinens": "flygplanskabin",
    "flygplanskabiner": "flygplanskabin",
    "flygplanskabinerna": "flygplanskabin",
    "flygplanskabinernas": "flygplanskabin",
    "flygplanskabiners": "flygplanskabin",
    "flygplanskabins": "flygplanskabin",
    "flygplansmodellen": "flygplansmodell",
    "flygplansmodellens": "flygplansmodell",
    "flygplansmodeller": "flygplansmodell",
    "flygplansmodellerna": "flygplansmodell",
    "flygplansmodellernas": "flygplansmodell",
    "flygplansmodellers": "flygplansmodell",
    "flygplansmodells": "flygplansmodell",
    "flygplansroderna": "flygplansroder",
    "flygplansrodernas": "flygplansroder",
    "flygplansroders": "flygplansroder",
    "flygplansrodren": "flygplansroder",
    "flygplansrodrens": "flygplansroder",
    "flygplansrodret": "flygplansroder",
    "flygplansrodrets": "flygplansroder",
    "flygplanstillverkar": "flygplanstillverkare",
    "flygplanstillverkaren": "flygplanstillverkare",
    "flygplanstillverkarens": "flygplanstillverkare",
    "flygplanstillverkares": "flygplanstillverkare",
    "flygplanstillverkarna": "flygplanstillverkare",
    "flygplanstillverkarnas": "flygplanstillverkare",
    "flygplansving": "flygplansvinge",
    "flygplansvingar": "flygplansvinge",
    "flygplansvingarna": "flygplansvinge",
    "flygplansvingarnas": "flygplansvinge",
    "flygplansvingars": "flygplansvinge",
    "flygplansvingen": "flygplansvinge",
    "flygplansvingens": "flygplansvinge",
    "flygplansvinges": "flygplansvinge",
    "flygplansvings": "flygplansvinge",
    "flygplatsen": "flygplats",
    "flygplatsens": "flygplats",
    "flygplatser": "flygplats",
    "flygplatserna": "flygplats",
    "flygplatsernas": "flygplats",
    "flygplatsers": "flygplats",
    "flygplatsserveringar": "flygplatsservering",
    "flygplatsserveringarna": "flygplatsservering",
    "flygplatsserveringarnas": "flygplatsservering",
    "flygplatsserveringars": "flygplatsservering",
    "flygplatsserveringen": "flygplatsservering",
    "flygplatsserveringens": "flygplatsservering",
    "flygplatsserverings": "flygplatsservering",
    "flygposten": "flygpost",
    "flygpostens": "flygpost",
    "flygposts": "flygpost",
    "flygräden": "flygräd",
    "flygrädens": "flygräd",
    "flygräder": "flygräd",
    "flygräderna": "flygräd",
    "flygrädernas": "flygräd",
    "flygräders": "flygräd",
    "flygräds": "flygräd",
    "flygrönnar": "flygrönn",
    "flygrönnarna": "flygrönn",
    "flygrönnarnas": "flygrönn",
    "flygrönnars": "flygrönn",
    "flygrönnen": "flygrönn",
    "flygrönnens": "flygrönn",
    "flygrönns": "flygrönn",
    "flygs": "flyga",
    "flygsanden": "flygsand",
    "flygsandens": "flygsand",
    "flygsands": "flygsand",
    "flygstolar": "flygstol",
    "flygstolarna": "flygstol",
    "flygstolarnas": "flygstol",
    "flygstolars": "flygstol",
    "flygstolen": "flygstol",
    "flygstolens": "flygstol",
    "flygstols": "flygstol",
    "flygstoppen": "flygstopp",
    "flygstoppens": "flygstopp",
    "flygstoppet": "flygstopp",
    "flygstoppets": "flygstopp",
    "flygstopps": "flygstopp",
    "flygsäkerheten": "flygsäkerhet",
    "flygsäkerhetens": "flygsäkerhet",
    "flygsäkerhets": "flygsäkerhet",
    "flygsäkerhetsexperten": "flygsäkerhetsexpert",
    "flygsäkerhetsexpertens": "flygsäkerhetsexpert",
    "flygsäkerhetsexperter": "flygsäkerhetsexpert",
    "flygsäkerhetsexperterna": "flygsäkerhetsexpert",
    "flygsäkerhetsexperternas": "flygsäkerhetsexpert",
    "flygsäkerhetsexperters": "flygsäkerhetsexpert",
    "flygsäkerhetsexperts": "flygsäkerhetsexpert",
    "flygsäkerhetskonsulten": "flygsäkerhetskonsult",
    "flygsäkerhetskonsultens": "flygsäkerhetskonsult",
    "flygsäkerhetskonsulter": "flygsäkerhetskonsult",
    "flygsäkerhetskonsulterna": "flygsäkerhetskonsult",
    "flygsäkerhetskonsulternas": "flygsäkerhetskonsult",
    "flygsäkerhetskonsulters": "flygsäkerhetskonsult",
    "flygsäkerhetskonsults": "flygsäkerhetskonsult",
    "flygterminalen": "flygterminal",
    "flygterminalens": "flygterminal",
    "flygterminaler": "flygterminal",
    "flygterminalerna": "flygterminal",
    "flygterminalernas": "flygterminal",
    "flygterminalers": "flygterminal",
    "flygterminals": "flygterminal",
    "flygtidtabellen": "flygtidtabell",
    "flygtidtabellens": "flygtidtabell",
    "flygtidtabeller": "flygtidtabell",
    "flygtidtabellerna": "flygtidtabell",
    "flygtidtabellernas": "flygtidtabell",
    "flygtidtabellers": "flygtidtabell",
    "flygtidtabells": "flygtidtabell",
    "flygtrafiken": "flygtrafik",
    "flygtrafikens": "flygtrafik",
    "flygtrafiks": "flygtrafik",
    "flygtransporten": "flygtransport",
    "flygtransportens": "flygtransport",
    "flygtransporter": "flygtransport",
    "flygtransporterna": "flygtransport",
    "flygtransporternas": "flygtransport",
    "flygtransporters": "flygtransport",
    "flygtransports": "flygtransport",
    "flygturen": "flygtur",
    "flygturens": "flygtur",
    "flygturer": "flygtur",
    "flygturerna": "flygtur",
    "flygturernas": "flygtur",
    "flygturers": "flygtur",
    "flygturs": "flygtur",
    "flygutbildningar": "flygutbildning",
    "flygutbildningarna": "flygutbildning",
    "flygutbildningarnas": "flygutbildning",
    "flygutbildningars": "flygutbildning",
    "flygutbildningen": "flygutbildning",
    "flygutbildningens": "flygutbildning",
    "flygutbildnings": "flygutbildning",
    "flygvapenchefen": "flygvapenchef",
    "flygvapenchefens": "flygvapenchef",
    "flygvapenchefer": "flygvapenchef",
    "flygvapencheferna": "flygvapenchef",
    "flygvapenchefernas": "flygvapenchef",
    "flygvapenchefers": "flygvapenchef",
    "flygvapenchefs": "flygvapenchef",
    "flygvapens": "flygvapen",
    "flygvapnen": "flygvapen",
    "flygvapnens": "flygvapen",
    "flygvapnet": "flygvapen",
    "flygvapnets": "flygvapen",
    "flygvägar": "flygväg",
    "flygvägarna": "flygväg",
    "flygvägarnas": "flygväg",
    "flygvägars": "flygväg",
    "flygvägen": "flygväg",
    "flygvägens": "flygväg",
    "flygvägs": "flygväg",
    "flygvärdinnan": "flygvärdinna",
    "flygvärdinnans": "flygvärdinna",
    "flygvärdinnas": "flygvärdinna",
    "flygvärdinne": "flygvärdinna",
    "flygvärdinnor": "flygvärdinna",
    "flygvärdinnorna": "flygvärdinna",
    "flygvärdinnornas": "flygvärdinna",
    "flygvärdinnors": "flygvärdinna",
    "flygödlan": "flygödla",
    "flygödlans": "flygödla",
    "flygödlas": "flygödla",
    "flygödle": "flygödla",
    "flygödlor": "flygödla",
    "flygödlorna": "flygödla",
    "flygödlornas": "flygödla",
    "flygödlors": "flygödla",
    "flyhänta": "flyhänt",
    "flyhäntare": "flyhänt",
    "flyhäntares": "flyhänt",
    "flyhäntas": "flyhänt",
    "flyhäntast": "flyhänt",
    "flyhäntaste": "flyhänt",
    "flyhäntastes": "flyhänt",
    "flyhäntasts": "flyhänt",
    "flyhänte": "flyhänt",
    "flyhäntes": "flyhänt",
    "flyhäntheten": "flyhänthet",
    "flyhänthetens": "flyhänthet",
    "flyhänthets": "flyhänthet",
    "flyhänts": "flyhänt",
    "flykt": "flykta",
    "flyktad": "flykta",
    "flyktade": "flykta",
    "flyktades": "flykta",
    "flyktads": "flykta",
    "flyktande": "flykta",
    "flyktanden": "flyktande",
    "flyktandena": "flyktande",
    "flyktandenas": "flyktande",
    "flyktandens": "flyktande",
    "flyktandes": "flyktande",
    "flyktandet": "flyktande",
    "flyktandets": "flyktande",
    "flyktar": "flykta",
    "flyktas": "flykta",
    "flyktat": "flykta",
    "flyktats": "flykta",
    "flykten": "flykt",
    "flyktens": "flykt",
    "flykter": "flykt",
    "flykterna": "flykt",
    "flykternas": "flykt",
    "flykters": "flykt",
    "flyktförsöken": "flyktförsök",
    "flyktförsökens": "flyktförsök",
    "flyktförsöket": "flyktförsök",
    "flyktförsökets": "flyktförsök",
    "flyktförsöks": "flyktförsök",
    "flyktiga": "flyktig",
    "flyktigare": "flyktig",
    "flyktigares": "flyktig",
    "flyktigas": "flyktig",
    "flyktigast": "flyktig",
    "flyktigaste": "flyktig",
    "flyktigastes": "flyktig",
    "flyktigasts": "flyktig",
    "flyktige": "flyktig",
    "flyktiges": "flyktig",
    "flyktigheten": "flyktighet",
    "flyktighetens": "flyktighet",
    "flyktigheter": "flyktighet",
    "flyktigheterna": "flyktighet",
    "flyktigheternas": "flyktighet",
    "flyktigheters": "flyktighet",
    "flyktighets": "flyktighet",
    "flyktigs": "flyktig",
    "flyktigt": "flyktig",
    "flyktigts": "flyktig",
    "flyktingar": "flykting",
    "flyktingarna": "flykting",
    "flyktingarnas": "flykting",
    "flyktingars": "flykting",
    "flyktingbarnen": "flyktingbarn",
    "flyktingbarnens": "flyktingbarn",
    "flyktingbarnet": "flyktingbarn",
    "flyktingbarnets": "flyktingbarn",
    "flyktingbarns": "flyktingbarn",
    "flyktingen": "flykting",
    "flyktingens": "flykting",
    "flyktingfamiljen": "flyktingfamilj",
    "flyktingfamiljens": "flyktingfamilj",
    "flyktingfamiljer": "flyktingfamilj",
    "flyktingfamiljerna": "flyktingfamilj",
    "flyktingfamiljernas": "flyktingfamilj",
    "flyktingfamiljers": "flyktingfamilj",
    "flyktingfamiljs": "flyktingfamilj",
    "flyktinglägerna": "flyktingläger",
    "flyktinglägernas": "flyktingläger",
    "flyktinglägers": "flyktingläger",
    "flyktinglägren": "flyktingläger",
    "flyktinglägrens": "flyktingläger",
    "flyktinglägret": "flyktingläger",
    "flyktinglägrets": "flyktingläger",
    "flyktingmottagandes": "flyktingmottagande",
    "flyktingmottagandet": "flyktingmottagande",
    "flyktingmottagandets": "flyktingmottagande",
    "flyktingmottagningar": "flyktingmottagning",
    "flyktingmottagningarna": "flyktingmottagning",
    "flyktingmottagningarnas": "flyktingmottagning",
    "flyktingmottagningars": "flyktingmottagning",
    "flyktingmottagningen": "flyktingmottagning",
    "flyktingmottagningens": "flyktingmottagning",
    "flyktingmottagnings": "flyktingmottagning",
    "flyktingpolitiken": "flyktingpolitik",
    "flyktingpolitikens": "flyktingpolitik",
    "flyktingpolitiks": "flyktingpolitik",
    "flyktings": "flykting",
    "flyktmöjligheten": "flyktmöjlighet",
    "flyktmöjlighetens": "flyktmöjlighet",
    "flyktmöjligheter": "flyktmöjlighet",
    "flyktmöjligheterna": "flyktmöjlighet",
    "flyktmöjligheternas": "flyktmöjlighet",
    "flyktmöjligheters": "flyktmöjlighet",
    "flyktmöjlighets": "flyktmöjlighet",
    "flyktrisken": "flyktrisk",
    "flyktriskens": "flyktrisk",
    "flyktrisker": "flyktrisk",
    "flyktriskerna": "flyktrisk",
    "flyktriskernas": "flyktrisk",
    "flyktriskers": "flyktrisk",
    "flyktrisks": "flyktrisk",
    "flykts": "flykt",
    "flyn": "fly",
    "flyna": "fly",
    "flynas": "fly",
    "flyns": "fly",
    "flyr": "fly",
    "flys": "fly",
    "flyt": "flyta",
    "flytande": "flyta",
    "flytanden": "flytande",
    "flytandena": "flytande",
    "flytandenas": "flytande",
    "flytandens": "flytande",
    "flytandes": "flytande",
    "flytandet": "flytande",
    "flytandets": "flytande",
    "flytas": "flyta",
    "flytdock": "flytdocka",
    "flytdockan": "flytdocka",
    "flytdockans": "flytdocka",
    "flytdockas": "flytdocka",
    "flytdocke": "flytdocka",
    "flytdockor": "flytdocka",
    "flytdockorna": "flytdocka",
    "flytdockornas": "flytdocka",
    "flytdockors": "flytdocka",
    "flytdocks": "flytdocka",
    "flyte": "flyta",
    "flyter": "flyta",
    "flytes": "flyta",
    "flytet": "flyt",
    "flytets": "flyt",
    "flythjälpar": "flythjälp",
    "flythjälparna": "flythjälp",
    "flythjälparnas": "flythjälp",
    "flythjälpars": "flythjälp",
    "flythjälpen": "flythjälp",
    "flythjälpens": "flythjälp",
    "flythjälps": "flythjälp",
    "flytjorden": "flytjord",
    "flytjordens": "flytjord",
    "flytjords": "flytjord",
    "flytningar": "flytning",
    "flytningarna": "flytning",
    "flytningarnas": "flytning",
    "flytningars": "flytning",
    "flytningen": "flytning",
    "flytningens": "flytning",
    "flytnings": "flytning",
    "flyts": "flyta",
    "flytsanden": "flytsand",
    "flytsandens": "flytsand",
    "flytsands": "flytsand",
    "flytt": "flytta",
    "flyttad": "flytta",
    "flyttade": "flytta",
    "flyttades": "flytta",
    "flyttads": "flytta",
    "flyttande": "flytta",
    "flyttanden": "flyttande",
    "flyttandena": "flyttande",
    "flyttandenas": "flyttande",
    "flyttandens": "flyttande",
    "flyttandes": "flyttande",
    "flyttandet": "flyttande",
    "flyttandets": "flyttande",
    "flyttar": "flytta",
    "flyttarna": "flytt",
    "flyttarnas": "flytt",
    "flyttars": "flytt",
    "flyttas": "flytta",
    "flyttat": "flytta",
    "flyttats": "flytta",
    "flyttbara": "flyttbar",
    "flyttbarare": "flyttbar",
    "flyttbarares": "flyttbar",
    "flyttbaras": "flyttbar",
    "flyttbarast": "flyttbar",
    "flyttbaraste": "flyttbar",
    "flyttbarastes": "flyttbar",
    "flyttbarasts": "flyttbar",
    "flyttbare": "flyttbar",
    "flyttbares": "flyttbar",
    "flyttbarheten": "flyttbarhet",
    "flyttbarhetens": "flyttbarhet",
    "flyttbarhets": "flyttbarhet",
    "flyttbars": "flyttbar",
    "flyttbart": "flyttbar",
    "flyttbarts": "flyttbar",
    "flyttblocken": "flyttblock",
    "flyttblockens": "flyttblock",
    "flyttblocket": "flyttblock",
    "flyttblockets": "flyttblock",
    "flyttblocks": "flyttblock",
    "flytten": "flytt",
    "flyttens": "flytt",
    "flyttfågeln": "flyttfågel",
    "flyttfågelns": "flyttfågel",
    "flyttfågels": "flyttfågel",
    "flyttfåglar": "flyttfågel",
    "flyttfåglarna": "flyttfågel",
    "flyttfåglarnas": "flyttfågel",
    "flyttfåglars": "flyttfågel",
    "flyttgrötar": "flyttgröt",
    "flyttgrötarna": "flyttgröt",
    "flyttgrötarnas": "flyttgröt",
    "flyttgrötars": "flyttgröt",
    "flyttgröten": "flyttgröt",
    "flyttgrötens": "flyttgröt",
    "flyttgröts": "flyttgröt",
    "flyttkarlar": "flyttkarl",
    "flyttkarlarna": "flyttkarl",
    "flyttkarlarnas": "flyttkarl",
    "flyttkarlars": "flyttkarl",
    "flyttkarlen": "flyttkarl",
    "flyttkarlens": "flyttkarl",
    "flyttkarls": "flyttkarl",
    "flyttkartongen": "flyttkartong",
    "flyttkartongens": "flyttkartong",
    "flyttkartonger": "flyttkartong",
    "flyttkartongerna": "flyttkartong",
    "flyttkartongernas": "flyttkartong",
    "flyttkartongers": "flyttkartong",
    "flyttkartongs": "flyttkartong",
    "flyttlassen": "flyttlass",
    "flyttlassens": "flyttlass",
    "flyttlasset": "flyttlass",
    "flyttlassets": "flyttlass",
    "flyttlasspolitiken": "flyttlasspolitik",
    "flyttlasspolitikens": "flyttlasspolitik",
    "flyttlasspolitiks": "flyttlasspolitik",
    "flyttlåd": "flyttlåda",
    "flyttlådan": "flyttlåda",
    "flyttlådans": "flyttlåda",
    "flyttlådas": "flyttlåda",
    "flyttlåde": "flyttlåda",
    "flyttlådor": "flyttlåda",
    "flyttlådorna": "flyttlåda",
    "flyttlådornas": "flyttlåda",
    "flyttlådors": "flyttlåda",
    "flyttlåds": "flyttlåda",
    "flyttningar": "flyttning",
    "flyttningarna": "flyttning",
    "flyttningarnas": "flyttning",
    "flyttningars": "flyttning",
    "flyttningen": "flyttning",
    "flyttningens": "flyttning",
    "flyttnings": "flyttning",
    "flytträtta": "flytträtt",
    "flytträttare": "flytträtt",
    "flytträttares": "flytträtt",
    "flytträttas": "flytträtt",
    "flytträttast": "flytträtt",
    "flytträttaste": "flytträtt",
    "flytträttastes": "flytträtt",
    "flytträttasts": "flytträtt",
    "flytträtte": "flytträtt",
    "flytträttes": "flytträtt",
    "flytträtts": "flytträtt",
    "flytts": "flytt",
    "flytungade": "flytungad",
    "flytungades": "flytungad",
    "flytungadheten": "flytungadhet",
    "flytungadhetens": "flytungadhet",
    "flytungadhets": "flytungadhet",
    "flytungads": "flytungad",
    "flytungat": "flytungad",
    "flytungats": "flytungad",
    "flytvästar": "flytväst",
    "flytvästarna": "flytväst",
    "flytvästarnas": "flytväst",
    "flytvästars": "flytväst",
    "flytvästen": "flytväst",
    "flytvästens": "flytväst",
    "flytvästs": "flytväst",
    "fläck": "fläcka",
    "fläckad": "fläcka",
    "fläckade": "fläcka",
    "fläckades": "fläcka",
    "fläckads": "fläcka",
    "fläckande": "fläcka",
    "fläckanden": "fläckande",
    "fläckandena": "fläckande",
    "fläckandenas": "fläckande",
    "fläckandens": "fläckande",
    "fläckandes": "fläckande",
    "fläckandet": "fläckande",
    "fläckandets": "fläckande",
    "fläckar": "fläcka",
    "fläckarna": "fläck",
    "fläckarnas": "fläck",
    "fläckars": "fläck",
    "fläckas": "fläcka",
    "fläckat": "fläcka",
    "fläckats": "fläcka",
    "fläckborttagningar": "fläckborttagning",
    "fläckborttagningarna": "fläckborttagning",
    "fläckborttagningarnas": "fläckborttagning",
    "fläckborttagningars": "fläckborttagning",
    "fläckborttagningen": "fläckborttagning",
    "fläckborttagningens": "fläckborttagning",
    "fläckborttagnings": "fläckborttagning",
    "fläckborttagningsmedels": "fläckborttagningsmedel",
    "fläckborttagningsmedlen": "fläckborttagningsmedel",
    "fläckborttagningsmedlens": "fläckborttagningsmedel",
    "fläckborttagningsmedlet": "fläckborttagningsmedel",
    "fläckborttagningsmedlets": "fläckborttagningsmedel",
    "fläcken": "fläck",
    "fläckens": "fläck",
    "fläckfebern": "fläckfeber",
    "fläckfeberns": "fläckfeber",
    "fläckfebers": "fläckfeber",
    "fläckfria": "fläckfri",
    "fläckfriare": "fläckfri",
    "fläckfriares": "fläckfri",
    "fläckfrias": "fläckfri",
    "fläckfriast": "fläckfri",
    "fläckfriaste": "fläckfri",
    "fläckfriastes": "fläckfri",
    "fläckfriasts": "fläckfri",
    "fläckfrie": "fläckfri",
    "fläckfries": "fläckfri",
    "fläckfris": "fläckfri",
    "fläckfritt": "fläckfri",
    "fläckfritts": "fläckfri",
    "fläckiga": "fläckig",
    "fläckigare": "fläckig",
    "fläckigares": "fläckig",
    "fläckigas": "fläckig",
    "fläckigast": "fläckig",
    "fläckigaste": "fläckig",
    "fläckigastes": "fläckig",
    "fläckigasts": "fläckig",
    "fläckige": "fläckig",
    "fläckiges": "fläckig",
    "fläckigheten": "fläckighet",
    "fläckighetens": "fläckighet",
    "fläckighets": "fläckighet",
    "fläckigs": "fläckig",
    "fläckigt": "fläckig",
    "fläckigts": "fläckig",
    "fläcks": "fläck",
    "fläcktyfusen": "fläcktyfus",
    "fläcktyfusens": "fläcktyfus",
    "fläderbären": "fläderbär",
    "fläderbärens": "fläderbär",
    "fläderbäret": "fläderbär",
    "fläderbärets": "fläderbär",
    "fläderbärs": "fläderbär",
    "flädermusen": "flädermus",
    "flädermusens": "flädermus",
    "flädermärgen": "flädermärg",
    "flädermärgens": "flädermärg",
    "flädermärgs": "flädermärg",
    "flädermärgskul": "flädermärgskula",
    "flädermärgskulan": "flädermärgskula",
    "flädermärgskulans": "flädermärgskula",
    "flädermärgskulas": "flädermärgskula",
    "flädermärgskule": "flädermärgskula",
    "flädermärgskulor": "flädermärgskula",
    "flädermärgskulorna": "flädermärgskula",
    "flädermärgskulornas": "flädermärgskula",
    "flädermärgskulors": "flädermärgskula",
    "flädermärgskuls": "flädermärgskula",
    "flädermöss": "flädermus",
    "flädermössen": "flädermus",
    "flädermössens": "flädermus",
    "flädern": "fläder",
    "fläderns": "fläder",
    "fläders": "fläder",
    "flädrar": "fläder",
    "flädrarna": "fläder",
    "flädrarnas": "fläder",
    "flädrars": "fläder",
    "fläk": "fläka",
    "fläkande": "fläka",
    "fläkanden": "fläkande",
    "fläkandena": "fläkande",
    "fläkandenas": "fläkande",
    "fläkandens": "fläkande",
    "fläkandes": "fläkande",
    "fläkandet": "fläkande",
    "fläkandets": "fläkande",
    "fläkas": "fläka",
    "fläker": "fläka",
    "fläkes": "fläka",
    "fläks": "fläka",
    "fläkt": "fläkta",
    "fläkta": "fläka",
    "fläktade": "fläkta",
    "fläktades": "fläkta",
    "fläktande": "fläkta",
    "fläktanden": "fläktande",
    "fläktandena": "fläktande",
    "fläktandenas": "fläktande",
    "fläktandens": "fläktande",
    "fläktandes": "fläktande",
    "fläktandet": "fläktande",
    "fläktandets": "fläktande",
    "fläktar": "fläkta",
    "fläktarna": "fläkt",
    "fläktarnas": "fläkt",
    "fläktars": "fläkt",
    "fläktas": "fläkta",
    "fläktat": "fläkta",
    "fläktats": "fläkta",
    "fläkte": "fläka",
    "fläkten": "fläkt",
    "fläktens": "fläkt",
    "fläktes": "fläka",
    "fläkts": "fläkt",
    "flämt": "flämta",
    "flämtade": "flämta",
    "flämtades": "flämta",
    "flämtande": "flämta",
    "flämtanden": "flämtande",
    "flämtandena": "flämtande",
    "flämtandenas": "flämtande",
    "flämtandens": "flämtande",
    "flämtandes": "flämtande",
    "flämtandet": "flämtande",
    "flämtandets": "flämtande",
    "flämtar": "flämta",
    "flämtas": "flämta",
    "flämtat": "flämta",
    "flämtats": "flämta",
    "fläng": "flänga",
    "flänga": "fläng",
    "flängande": "flänga",
    "flänganden": "flängande",
    "flängandena": "flängande",
    "flängandenas": "flängande",
    "flängandens": "flängande",
    "flängandes": "flängande",
    "flängandet": "flängande",
    "flängandets": "flängande",
    "flängare": "fläng",
    "flängares": "fläng",
    "flängas": "flänga",
    "flängast": "fläng",
    "flängaste": "fläng",
    "flängastes": "fläng",
    "flängasts": "fläng",
    "flängd": "flänga",
    "flängda": "flänga",
    "flängdas": "flänga",
    "flängde": "flänga",
    "flängdes": "flänga",
    "flängds": "flänga",
    "flänge": "fläng",
    "flänger": "flänga",
    "flänges": "flänga",
    "flänget": "fläng",
    "flängets": "fläng",
    "flängheten": "flänghet",
    "flänghetens": "flänghet",
    "flänghets": "flänghet",
    "flängiga": "flängig",
    "flängigare": "flängig",
    "flängigares": "flängig",
    "flängigas": "flängig",
    "flängigast": "flängig",
    "flängigaste": "flängig",
    "flängigastes": "flängig",
    "flängigasts": "flängig",
    "flängige": "flängig",
    "flängiges": "flängig",
    "flängigheten": "flängighet",
    "flängighetens": "flängighet",
    "flängighets": "flängighet",
    "flängigs": "flängig",
    "flängigt": "flängig",
    "flängigts": "flängig",
    "flängs": "flänga",
    "flängt": "flänga",
    "flängts": "flänga",
    "fläns": "flänsa",
    "flänsad": "flänsa",
    "flänsade": "flänsa",
    "flänsades": "flänsa",
    "flänsads": "flänsa",
    "flänsande": "flänsa",
    "flänsanden": "flänsande",
    "flänsandena": "flänsande",
    "flänsandenas": "flänsande",
    "flänsandens": "flänsande",
    "flänsandes": "flänsande",
    "flänsandet": "flänsande",
    "flänsandets": "flänsande",
    "flänsar": "flänsa",
    "flänsarna": "fläns",
    "flänsarnas": "fläns",
    "flänsars": "fläns",
    "flänsas": "flänsa",
    "flänsat": "flänsa",
    "flänsats": "flänsa",
    "flänsen": "fläns",
    "flänsens": "fläns",
    "flärden": "flärd",
    "flärdens": "flärd",
    "flärdfria": "flärdfri",
    "flärdfriare": "flärdfri",
    "flärdfriares": "flärdfri",
    "flärdfrias": "flärdfri",
    "flärdfriast": "flärdfri",
    "flärdfriaste": "flärdfri",
    "flärdfriastes": "flärdfri",
    "flärdfriasts": "flärdfri",
    "flärdfrie": "flärdfri",
    "flärdfries": "flärdfri",
    "flärdfris": "flärdfri",
    "flärdfritt": "flärdfri",
    "flärdfritts": "flärdfri",
    "flärdfulla": "flärdfull",
    "flärdfullare": "flärdfull",
    "flärdfullares": "flärdfull",
    "flärdfullas": "flärdfull",
    "flärdfullast": "flärdfull",
    "flärdfullaste": "flärdfull",
    "flärdfullastes": "flärdfull",
    "flärdfullasts": "flärdfull",
    "flärdfulle": "flärdfull",
    "flärdfulles": "flärdfull",
    "flärdfullheten": "flärdfullhet",
    "flärdfullhetens": "flärdfullhet",
    "flärdfullheter": "flärdfullhet",
    "flärdfullheterna": "flärdfullhet",
    "flärdfullheternas": "flärdfullhet",
    "flärdfullheters": "flärdfullhet",
    "flärdfullhets": "flärdfullhet",
    "flärdfulls": "flärdfull",
    "flärdfullt": "flärdfull",
    "flärdfullts": "flärdfull",
    "flärds": "flärd",
    "flärpan": "flärpa",
    "flärpans": "flärpa",
    "flärpar": "flärp",
    "flärparna": "flärp",
    "flärparnas": "flärp",
    "flärpars": "flärp",
    "flärpas": "flärpa",
    "flärpe": "flärpa",
    "flärpen": "flärp",
    "flärpens": "flärp",
    "flärpor": "flärpa",
    "flärporna": "flärpa",
    "flärpornas": "flärpa",
    "flärpors": "flärpa",
    "flärps": "flärp",
    "fläsket": "fläsk",
    "fläskets": "fläsk",
    "fläskfiléer": "fläskfilé",
    "fläskfiléerna": "fläskfilé",
    "fläskfiléernas": "fläskfilé",
    "fläskfiléers": "fläskfilé",
    "fläskfilén": "fläskfilé",
    "fläskfiléns": "fläskfilé",
    "fläskfilés": "fläskfilé",
    "fläskhar": "fläskhare",
    "fläskharar": "fläskhare",
    "fläskhararna": "fläskhare",
    "fläskhararnas": "fläskhare",
    "fläskharars": "fläskhare",
    "fläskharen": "fläskhare",
    "fläskharens": "fläskhare",
    "fläskhares": "fläskhare",
    "fläskhars": "fläskhare",
    "fläskiga": "fläskig",
    "fläskigare": "fläskig",
    "fläskigares": "fläskig",
    "fläskigas": "fläskig",
    "fläskigast": "fläskig",
    "fläskigaste": "fläskig",
    "fläskigastes": "fläskig",
    "fläskigasts": "fläskig",
    "fläskige": "fläskig",
    "fläskiges": "fläskig",
    "fläskigheten": "fläskighet",
    "fläskighetens": "fläskighet",
    "fläskighets": "fläskighet",
    "fläskigs": "fläskig",
    "fläskigt": "fläskig",
    "fläskigts": "fläskig",
    "fläskkarréer": "fläskkarré",
    "fläskkarréerna": "fläskkarré",
    "fläskkarréernas": "fläskkarré",
    "fläskkarréers": "fläskkarré",
    "fläskkarrén": "fläskkarré",
    "fläskkarréns": "fläskkarré",
    "fläskkarrés": "fläskkarré",
    "fläskkorvar": "fläskkorv",
    "fläskkorvarna": "fläskkorv",
    "fläskkorvarnas": "fläskkorv",
    "fläskkorvars": "fläskkorv",
    "fläskkorven": "fläskkorv",
    "fläskkorvens": "fläskkorv",
    "fläskkorvs": "fläskkorv",
    "fläskkotletten": "fläskkotlett",
    "fläskkotlettens": "fläskkotlett",
    "fläskkotletter": "fläskkotlett",
    "fläskkotletterna": "fläskkotlett",
    "fläskkotletternas": "fläskkotlett",
    "fläskkotletters": "fläskkotlett",
    "fläskkotletts": "fläskkotlett",
    "fläskköttet": "fläskkött",
    "fläskköttets": "fläskkött",
    "fläskkötts": "fläskkött",
    "fläskläggar": "fläsklägg",
    "fläskläggarna": "fläsklägg",
    "fläskläggarnas": "fläsklägg",
    "fläskläggars": "fläsklägg",
    "fläskläggen": "fläsklägg",
    "fläskläggens": "fläsklägg",
    "fläskläggs": "fläsklägg",
    "fläskläppar": "fläskläpp",
    "fläskläpparna": "fläskläpp",
    "fläskläpparnas": "fläskläpp",
    "fläskläppars": "fläskläpp",
    "fläskläppen": "fläskläpp",
    "fläskläppens": "fläskläpp",
    "fläskläpps": "fläskläpp",
    "fläskpannkak": "fläskpannkaka",
    "fläskpannkakan": "fläskpannkaka",
    "fläskpannkakans": "fläskpannkaka",
    "fläskpannkakas": "fläskpannkaka",
    "fläskpannkake": "fläskpannkaka",
    "fläskpannkakor": "fläskpannkaka",
    "fläskpannkakorna": "fläskpannkaka",
    "fläskpannkakornas": "fläskpannkaka",
    "fläskpannkakors": "fläskpannkaka",
    "fläskpannkaks": "fläskpannkaka",
    "fläsks": "fläsk",
    "fläskstycken": "fläskstycke",
    "fläskstyckena": "fläskstycke",
    "fläskstyckenas": "fläskstycke",
    "fläskstyckens": "fläskstycke",
    "fläskstyckes": "fläskstycke",
    "fläskstycket": "fläskstycke",
    "fläskstyckets": "fläskstycke",
    "fläskstycks": "fläskstycke",
    "fläsktärningar": "fläsktärning",
    "fläsktärningarna": "fläsktärning",
    "fläsktärningarnas": "fläsktärning",
    "fläsktärningars": "fläsktärning",
    "fläsktärningen": "fläsktärning",
    "fläsktärningens": "fläsktärning",
    "fläsktärnings": "fläsktärning",
    "fläskängern": "fläskänger",
    "fläskängerns": "fläskänger",
    "fläskängers": "fläskänger",
    "fläskängrar": "fläskänger",
    "fläskängrarna": "fläskänger",
    "fläskängrarnas": "fläskänger",
    "fläskängrars": "fläskänger",
    "flät": "fläta",
    "flätad": "fläta",
    "flätade": "fläta",
    "flätades": "fläta",
    "flätads": "fläta",
    "flätan": "fläta",
    "flätande": "fläta",
    "flätanden": "flätande",
    "flätandena": "flätande",
    "flätandenas": "flätande",
    "flätandens": "flätande",
    "flätandes": "flätande",
    "flätandet": "flätande",
    "flätandets": "flätande",
    "flätans": "fläta",
    "flätar": "fläta",
    "flätas": "fläta",
    "flätat": "fläta",
    "flätats": "fläta",
    "fläte": "fläta",
    "flätor": "fläta",
    "flätorna": "fläta",
    "flätornas": "fläta",
    "flätors": "fläta",
    "fläts": "fläta",
    "flätverken": "flätverk",
    "flätverkens": "flätverk",
    "flätverket": "flätverk",
    "flätverkets": "flätverk",
    "flätverks": "flätverk",
    "flåbusar": "flåbuse",
    "flåbusarna": "flåbuse",
    "flåbusarnas": "flåbuse",
    "flåbusars": "flåbuse",
    "flåbusen": "flåbuse",
    "flåbusens": "flåbuse",
    "flåbuses": "flåbuse",
    "flådd": "flå",
    "flådda": "flå",
    "flåddas": "flå",
    "flådde": "flå",
    "flåddes": "flå",
    "flådds": "flå",
    "flådiga": "flådig",
    "flådigare": "flådig",
    "flådigares": "flådig",
    "flådigas": "flådig",
    "flådigast": "flådig",
    "flådigaste": "flådig",
    "flådigastes": "flådig",
    "flådigasts": "flådig",
    "flådige": "flådig",
    "flådiges": "flådig",
    "flådigs": "flådig",
    "flådigt": "flådig",
    "flådigts": "flådig",
    "flående": "flå",
    "flåenden": "flående",
    "flåendena": "flående",
    "flåendenas": "flående",
    "flåendens": "flående",
    "flåendes": "flående",
    "flåendet": "flående",
    "flåendets": "flående",
    "flåhack": "flåhacka",
    "flåhackad": "flåhacka",
    "flåhackade": "flåhacka",
    "flåhackades": "flåhacka",
    "flåhackads": "flåhacka",
    "flåhackan": "flåhacka",
    "flåhackande": "flåhacka",
    "flåhackanden": "flåhackande",
    "flåhackandena": "flåhackande",
    "flåhackandenas": "flåhackande",
    "flåhackandens": "flåhackande",
    "flåhackandes": "flåhackande",
    "flåhackandet": "flåhackande",
    "flåhackandets": "flåhackande",
    "flåhackans": "flåhacka",
    "flåhackar": "flåhacka",
    "flåhackas": "flåhacka",
    "flåhackat": "flåhacka",
    "flåhackats": "flåhacka",
    "flåhacke": "flåhacka",
    "flåhackor": "flåhacka",
    "flåhackorna": "flåhacka",
    "flåhackornas": "flåhacka",
    "flåhackors": "flåhacka",
    "flåhacks": "flåhacka",
    "flår": "flå",
    "flås": "flåsa",
    "flåsade": "flåsa",
    "flåsades": "flåsa",
    "flåsande": "flåsa",
    "flåsanden": "flåsande",
    "flåsandena": "flåsande",
    "flåsandenas": "flåsande",
    "flåsandens": "flåsande",
    "flåsandes": "flåsande",
    "flåsandet": "flåsande",
    "flåsandets": "flåsande",
    "flåsar": "flåsa",
    "flåsas": "flåsa",
    "flåsat": "flåsa",
    "flåsats": "flåsa",
    "flåset": "flås",
    "flåsets": "flås",
    "flåsiga": "flåsig",
    "flåsigare": "flåsig",
    "flåsigares": "flåsig",
    "flåsigas": "flåsig",
    "flåsigast": "flåsig",
    "flåsigaste": "flåsig",
    "flåsigastes": "flåsig",
    "flåsigasts": "flåsig",
    "flåsige": "flåsig",
    "flåsiges": "flåsig",
    "flåsigs": "flåsig",
    "flåsigt": "flåsig",
    "flåsigts": "flåsig",
    "flåspatoset": "flåspatos",
    "flåspatosets": "flåspatos",
    "flått": "flå",
    "flåtts": "flå",
    "flöd": "flöda",
    "flödade": "flöda",
    "flödades": "flöda",
    "flödande": "flöda",
    "flödanden": "flödande",
    "flödandena": "flödande",
    "flödandenas": "flödande",
    "flödandens": "flödande",
    "flödandes": "flödande",
    "flödandet": "flödande",
    "flödandets": "flödande",
    "flödar": "flöda",
    "flödas": "flöda",
    "flödat": "flöda",
    "flödats": "flöda",
    "flöden": "flöde",
    "flödena": "flöde",
    "flödenas": "flöde",
    "flödens": "flöde",
    "flödes": "flöde",
    "flödesdiagrammen": "flödesdiagram",
    "flödesdiagrammens": "flödesdiagram",
    "flödesdiagrammet": "flödesdiagram",
    "flödesdiagrammets": "flödesdiagram",
    "flödesdiagrams": "flödesdiagram",
    "flödesscheman": "flödesschema",
    "flödesschemana": "flödesschema",
    "flödesschemanas": "flödesschema",
    "flödesschemans": "flödesschema",
    "flödesschemas": "flödesschema",
    "flödesschemat": "flödesschema",
    "flödesschemats": "flödesschema",
    "flödet": "flöde",
    "flödets": "flöde",
    "flög": "flyga",
    "flöge": "flyga",
    "flöges": "flyga",
    "flögs": "flyga",
    "flöjar": "flöj",
    "flöjarna": "flöj",
    "flöjarnas": "flöj",
    "flöjars": "flöj",
    "flöjel": "flöjla",
    "flöjeln": "flöjel",
    "flöjelns": "flöjel",
    "flöjels": "flöjel",
    "flöjen": "flöj",
    "flöjens": "flöj",
    "flöjlad": "flöjla",
    "flöjlade": "flöjla",
    "flöjlades": "flöjla",
    "flöjlads": "flöjla",
    "flöjlande": "flöjla",
    "flöjlanden": "flöjlande",
    "flöjlandena": "flöjlande",
    "flöjlandenas": "flöjlande",
    "flöjlandens": "flöjlande",
    "flöjlandes": "flöjlande",
    "flöjlandet": "flöjlande",
    "flöjlandets": "flöjlande",
    "flöjlar": "flöjla",
    "flöjlarna": "flöjel",
    "flöjlarnas": "flöjel",
    "flöjlars": "flöjel",
    "flöjlas": "flöjla",
    "flöjlat": "flöjla",
    "flöjlats": "flöjla",
    "flöjs": "flöj",
    "flöjt": "flöjta",
    "flöjtad": "flöjta",
    "flöjtade": "flöjta",
    "flöjtades": "flöjta",
    "flöjtads": "flöjta",
    "flöjtande": "flöjta",
    "flöjtanden": "flöjtande",
    "flöjtandena": "flöjtande",
    "flöjtandenas": "flöjtande",
    "flöjtandens": "flöjtande",
    "flöjtandes": "flöjtande",
    "flöjtandet": "flöjtande",
    "flöjtandets": "flöjtande",
    "flöjtar": "flöjta",
    "flöjtas": "flöjta",
    "flöjtat": "flöjta",
    "flöjtats": "flöjta",
    "flöjten": "flöjt",
    "flöjtens": "flöjt",
    "flöjter": "flöjt",
    "flöjterna": "flöjt",
    "flöjternas": "flöjt",
    "flöjters": "flöjt",
    "flöjtisten": "flöjtist",
    "flöjtistens": "flöjtist",
    "flöjtister": "flöjtist",
    "flöjtisterna": "flöjtist",
    "flöjtisternas": "flöjtist",
    "flöjtisters": "flöjtist",
    "flöjtists": "flöjtist",
    "flöjts": "flöjt",
    "flöjttonen": "flöjtton",
    "flöjttonens": "flöjtton",
    "flöjttoner": "flöjtton",
    "flöjttonerna": "flöjtton",
    "flöjttonernas": "flöjtton",
    "flöjttoners": "flöjtton",
    "flöjttons": "flöjtton",
    "flöjttravären": "flöjttravär",
    "flöjttravärens": "flöjttravär",
    "flöjttravärer": "flöjttravär",
    "flöjttravärerna": "flöjttravär",
    "flöjttravärernas": "flöjttravär",
    "flöjttravärers": "flöjttravär",
    "flöjttravärs": "flöjttravär",
    "flört": "flörta",
    "flörtade": "flörta",
    "flörtades": "flörta",
    "flörtande": "flörta",
    "flörtanden": "flörtande",
    "flörtandena": "flörtande",
    "flörtandenas": "flörtande",
    "flörtandens": "flörtande",
    "flörtandes": "flörtande",
    "flörtandet": "flörtande",
    "flörtandets": "flörtande",
    "flörtar": "flörta",
    "flörtas": "flörta",
    "flörtat": "flörta",
    "flörtats": "flörta",
    "flörten": "flört",
    "flörtens": "flört",
    "flörter": "flört",
    "flörterna": "flört",
    "flörternas": "flört",
    "flörters": "flört",
    "flörtiga": "flörtig",
    "flörtigare": "flörtig",
    "flörtigares": "flörtig",
    "flörtigas": "flörtig",
    "flörtigast": "flörtig",
    "flörtigaste": "flörtig",
    "flörtigastes": "flörtig",
    "flörtigasts": "flörtig",
    "flörtige": "flörtig",
    "flörtiges": "flörtig",
    "flörtigheten": "flörtighet",
    "flörtighetens": "flörtighet",
    "flörtighets": "flörtighet",
    "flörtigs": "flörtig",
    "flörtigt": "flörtig",
    "flörtigts": "flörtig",
    "flörtkul": "flörtkula",
    "flörtkulan": "flörtkula",
    "flörtkulans": "flörtkula",
    "flörtkulas": "flörtkula",
    "flörtkule": "flörtkula",
    "flörtkulor": "flörtkula",
    "flörtkulorna": "flörtkula",
    "flörtkulornas": "flörtkula",
    "flörtkulors": "flörtkula",
    "flörtkuls": "flörtkula",
    "flörtlamp": "flörtlampa",
    "flörtlampan": "flörtlampa",
    "flörtlampans": "flörtlampa",
    "flörtlampas": "flörtlampa",
    "flörtlampe": "flörtlampa",
    "flörtlampor": "flörtlampa",
    "flörtlamporna": "flörtlampa",
    "flörtlampornas": "flörtlampa",
    "flörtlampors": "flörtlampa",
    "flörtlamps": "flörtlampa",
    "flörts": "flört",
    "flöt": "flyta",
    "flöte": "flyta",
    "flöten": "flöte",
    "flötena": "flöte",
    "flötenas": "flöte",
    "flötens": "flöte",
    "flötes": "flyta",
    "flötet": "flöte",
    "flötets": "flöte",
    "flöts": "flyta",
    "flötsen": "flöts",
    "flötsens": "flöts",
    "flötser": "flöts",
    "flötserna": "flöts",
    "flötsernas": "flöts",
    "flötsers": "flöts",
    "fnaset": "fnas",
    "fnasets": "fnas",
    "fnasiga": "fnasig",
    "fnasigare": "fnasig",
    "fnasigares": "fnasig",
    "fnasigas": "fnasig",
    "fnasigast": "fnasig",
    "fnasigaste": "fnasig",
    "fnasigastes": "fnasig",
    "fnasigasts": "fnasig",
    "fnasige": "fnasig",
    "fnasiges": "fnasig",
    "fnasigs": "fnasig",
    "fnasigt": "fnasig",
    "fnasigts": "fnasig",
    "fnask": "fnaska",
    "fnaskade": "fnaska",
    "fnaskades": "fnaska",
    "fnaskande": "fnaska",
    "fnaskanden": "fnaskande",
    "fnaskandena": "fnaskande",
    "fnaskandenas": "fnaskande",
    "fnaskandens": "fnaskande",
    "fnaskandes": "fnaskande",
    "fnaskandet": "fnaskande",
    "fnaskandets": "fnaskande",
    "fnaskar": "fnasker",
    "fnaskarna": "fnasker",
    "fnaskarnas": "fnasker",
    "fnaskars": "fnasker",
    "fnaskas": "fnaska",
    "fnaskat": "fnaska",
    "fnaskats": "fnaska",
    "fnasken": "fnask",
    "fnaskens": "fnask",
    "fnaskern": "fnasker",
    "fnaskerns": "fnasker",
    "fnaskers": "fnasker",
    "fnasket": "fnask",
    "fnaskets": "fnask",
    "fnaskrar": "fnasker",
    "fnaskrarna": "fnasker",
    "fnaskrarnas": "fnasker",
    "fnaskrars": "fnasker",
    "fnasks": "fnask",
    "fnatt": "fnatta",
    "fnattade": "fnatta",
    "fnattades": "fnatta",
    "fnattande": "fnatta",
    "fnattanden": "fnattande",
    "fnattandena": "fnattande",
    "fnattandenas": "fnattande",
    "fnattandens": "fnattande",
    "fnattandes": "fnattande",
    "fnattandet": "fnattande",
    "fnattandets": "fnattande",
    "fnattar": "fnatta",
    "fnattas": "fnatta",
    "fnattat": "fnatta",
    "fnattats": "fnatta",
    "fnatten": "fnatt",
    "fnattens": "fnatt",
    "fnatts": "fnatt",
    "fniss": "fnissa",
    "fnissade": "fnissa",
    "fnissades": "fnissa",
    "fnissande": "fnissa",
    "fnissanden": "fnissande",
    "fnissandena": "fnissande",
    "fnissandenas": "fnissande",
    "fnissandens": "fnissande",
    "fnissandes": "fnissande",
    "fnissandet": "fnissande",
    "fnissandets": "fnissande",
    "fnissar": "fnissa",
    "fnissas": "fnissa",
    "fnissat": "fnissa",
    "fnissats": "fnissa",
    "fnissen": "fniss",
    "fnissens": "fniss",
    "fnisset": "fniss",
    "fnissets": "fniss",
    "fnissiga": "fnissig",
    "fnissigare": "fnissig",
    "fnissigares": "fnissig",
    "fnissigas": "fnissig",
    "fnissigast": "fnissig",
    "fnissigaste": "fnissig",
    "fnissigastes": "fnissig",
    "fnissigasts": "fnissig",
    "fnissige": "fnissig",
    "fnissiges": "fnissig",
    "fnissigheten": "fnissighet",
    "fnissighetens": "fnissighet",
    "fnissighets": "fnissighet",
    "fnissigs": "fnissig",
    "fnissigt": "fnissig",
    "fnissigts": "fnissig",
    "fnissningar": "fnissning",
    "fnissningarna": "fnissning",
    "fnissningarnas": "fnissning",
    "fnissningars": "fnissning",
    "fnissningen": "fnissning",
    "fnissningens": "fnissning",
    "fnissnings": "fnissning",
    "fnitter": "fnittra",
    "fnitters": "fnitter",
    "fnittrade": "fnittra",
    "fnittrades": "fnittra",
    "fnittrande": "fnittra",
    "fnittranden": "fnittrande",
    "fnittrandena": "fnittrande",
    "fnittrandenas": "fnittrande",
    "fnittrandens": "fnittrande",
    "fnittrandes": "fnittrande",
    "fnittrandet": "fnittrande",
    "fnittrandets": "fnittrande",
    "fnittrar": "fnittra",
    "fnittras": "fnittra",
    "fnittrat": "fnittra",
    "fnittrats": "fnittra",
    "fnittret": "fnitter",
    "fnittrets": "fnitter",
    "fnittriga": "fnittrig",
    "fnittrigare": "fnittrig",
    "fnittrigares": "fnittrig",
    "fnittrigas": "fnittrig",
    "fnittrigast": "fnittrig",
    "fnittrigaste": "fnittrig",
    "fnittrigastes": "fnittrig",
    "fnittrigasts": "fnittrig",
    "fnittrige": "fnittrig",
    "fnittriges": "fnittrig",
    "fnittrigheten": "fnittrighet",
    "fnittrighetens": "fnittrighet",
    "fnittrighets": "fnittrighet",
    "fnittrigs": "fnittrig",
    "fnittrigt": "fnittrig",
    "fnittrigts": "fnittrig",
    "fnoskiga": "fnoskig",
    "fnoskigare": "fnoskig",
    "fnoskigares": "fnoskig",
    "fnoskigas": "fnoskig",
    "fnoskigast": "fnoskig",
    "fnoskigaste": "fnoskig",
    "fnoskigastes": "fnoskig",
    "fnoskigasts": "fnoskig",
    "fnoskige": "fnoskig",
    "fnoskiges": "fnoskig",
    "fnoskigheten": "fnoskighet",
    "fnoskighetens": "fnoskighet",
    "fnoskigheter": "fnoskighet",
    "fnoskigheterna": "fnoskighet",
    "fnoskigheternas": "fnoskighet",
    "fnoskigheters": "fnoskighet",
    "fnoskighets": "fnoskighet",
    "fnoskigs": "fnoskig",
    "fnoskigt": "fnoskig",
    "fnoskigts": "fnoskig",
    "fnys": "fnysa",
    "fnysande": "fnysa",
    "fnysanden": "fnysande",
    "fnysandena": "fnysande",
    "fnysandenas": "fnysande",
    "fnysandens": "fnysande",
    "fnysandes": "fnysande",
    "fnysandet": "fnysande",
    "fnysandets": "fnysande",
    "fnysas": "fnysa",
    "fnyse": "fnysa",
    "fnyser": "fnysa",
    "fnyses": "fnysa",
    "fnyst": "fnysa",
    "fnyste": "fnysa",
    "fnystes": "fnysa",
    "fnysts": "fnysa",
    "fnös": "fnysa",
    "fnöse": "fnysa",
    "fnöses": "fnysa",
    "fnösk": "fnöske",
    "fnösken": "fnöske",
    "fnöskena": "fnöske",
    "fnöskenas": "fnöske",
    "fnöskens": "fnöske",
    "fnöskes": "fnöske",
    "fnösket": "fnöske",
    "fnöskets": "fnöske",
    "fnösksvampar": "fnösksvamp",
    "fnösksvamparna": "fnösksvamp",
    "fnösksvamparnas": "fnösksvamp",
    "fnösksvampars": "fnösksvamp",
    "fnösksvampen": "fnösksvamp",
    "fnösksvampens": "fnösksvamp",
    "fnösksvamps": "fnösksvamp",
    "fnösktick": "fnöskticka",
    "fnösktickan": "fnöskticka",
    "fnösktickans": "fnöskticka",
    "fnösktickas": "fnöskticka",
    "fnöskticke": "fnöskticka",
    "fnösktickor": "fnöskticka",
    "fnösktickorna": "fnöskticka",
    "fnösktickornas": "fnöskticka",
    "fnösktickors": "fnöskticka",
    "fnöskticks": "fnöskticka",
    "foajéer": "foajé",
    "foajéerna": "foajé",
    "foajéernas": "foajé",
    "foajéers": "foajé",
    "foajén": "foajé",
    "foajéns": "foajé",
    "foajés": "foajé",
    "fobien": "fobi",
    "fobiens": "fobi",
    "fobier": "fobi",
    "fobierna": "fobi",
    "fobiernas": "fobi",
    "fobiers": "fobi",
    "fobin": "fobi",
    "fobins": "fobi",
    "fobis": "fobi",
    "fobiträningar": "fobiträning",
    "fobiträningarna": "fobiträning",
    "fobiträningarnas": "fobiträning",
    "fobiträningars": "fobiträning",
    "fobiträningen": "fobiträning",
    "fobiträningens": "fobiträning",
    "fobitränings": "fobiträning",
    "fock": "focka",
    "fockad": "focka",
    "fockade": "focka",
    "fockades": "focka",
    "fockads": "focka",
    "fockande": "focka",
    "fockanden": "fockande",
    "fockandena": "fockande",
    "fockandenas": "fockande",
    "fockandens": "fockande",
    "fockandes": "fockande",
    "fockandet": "fockande",
    "fockandets": "fockande",
    "fockar": "focka",
    "fockarna": "fock",
    "fockarnas": "fock",
    "fockars": "fock",
    "fockas": "focka",
    "fockat": "focka",
    "fockats": "focka",
    "focken": "fock",
    "fockens": "fock",
    "fockmasten": "fockmast",
    "fockmastens": "fockmast",
    "fockmaster": "fockmast",
    "fockmasterna": "fockmast",
    "fockmasternas": "fockmast",
    "fockmasters": "fockmast",
    "fockmasts": "fockmast",
    "focks": "fock",
    "focusar": "focus",
    "focusarna": "focus",
    "focusarnas": "focus",
    "focusars": "focus",
    "focusen": "focus",
    "focusens": "focus",
    "foder": "fodra",
    "foderbet": "foderbeta",
    "foderbetan": "foderbeta",
    "foderbetans": "foderbeta",
    "foderbetas": "foderbeta",
    "foderbete": "foderbeta",
    "foderbetor": "foderbeta",
    "foderbetorna": "foderbeta",
    "foderbetornas": "foderbeta",
    "foderbetors": "foderbeta",
    "foderbets": "foderbeta",
    "foderbladen": "foderblad",
    "foderbladens": "foderblad",
    "foderbladet": "foderblad",
    "foderbladets": "foderblad",
    "foderblads": "foderblad",
    "foderkak": "foderkaka",
    "foderkakan": "foderkaka",
    "foderkakans": "foderkaka",
    "foderkakas": "foderkaka",
    "foderkake": "foderkaka",
    "foderkakor": "foderkaka",
    "foderkakorna": "foderkaka",
    "foderkakornas": "foderkaka",
    "foderkakors": "foderkaka",
    "foderkaks": "foderkaka",
    "foderlad": "foderlada",
    "foderladan": "foderlada",
    "foderladans": "foderlada",
    "foderladas": "foderlada",
    "foderlade": "foderlada",
    "foderlador": "foderlada",
    "foderladorna": "foderlada",
    "foderladornas": "foderlada",
    "foderladors": "foderlada",
    "foderlads": "foderlada",
    "fodermarken": "fodermark",
    "fodermarkens": "fodermark",
    "fodermarker": "fodermark",
    "fodermarkerna": "fodermark",
    "fodermarkernas": "fodermark",
    "fodermarkers": "fodermark",
    "fodermarks": "fodermark",
    "fodermängden": "fodermängd",
    "fodermängdens": "fodermängd",
    "fodermängder": "fodermängd",
    "fodermängderna": "fodermängd",
    "fodermängdernas": "fodermängd",
    "fodermängders": "fodermängd",
    "fodermängds": "fodermängd",
    "foderna": "foder",
    "fodernas": "foder",
    "foderpås": "foderpåse",
    "foderpåsar": "foderpåse",
    "foderpåsarna": "foderpåse",
    "foderpåsarnas": "foderpåse",
    "foderpåsars": "foderpåse",
    "foderpåsen": "foderpåse",
    "foderpåsens": "foderpåse",
    "foderpåses": "foderpåse",
    "foders": "foder",
    "fodersäden": "fodersäd",
    "fodersädens": "fodersäd",
    "fodersädes": "fodersäd",
    "fodersäds": "fodersäd",
    "fodervärdar": "fodervärd",
    "fodervärdarna": "fodervärd",
    "fodervärdarnas": "fodervärd",
    "fodervärdars": "fodervärd",
    "fodervärden": "fodervärde",
    "fodervärdena": "fodervärde",
    "fodervärdenas": "fodervärde",
    "fodervärdens": "fodervärde",
    "fodervärdes": "fodervärde",
    "fodervärdet": "fodervärde",
    "fodervärdets": "fodervärde",
    "fodervärds": "fodervärd",
    "foderväxten": "foderväxt",
    "foderväxtens": "foderväxt",
    "foderväxter": "foderväxt",
    "foderväxterna": "foderväxt",
    "foderväxternas": "foderväxt",
    "foderväxters": "foderväxt",
    "foderväxts": "foderväxt",
    "fodrad": "fodra",
    "fodrade": "fodra",
    "fodrades": "fodra",
    "fodrads": "fodra",
    "fodralen": "fodral",
    "fodralens": "fodral",
    "fodralet": "fodral",
    "fodralets": "fodral",
    "fodrals": "fodral",
    "fodrande": "fodra",
    "fodranden": "fodrande",
    "fodrandena": "fodrande",
    "fodrandenas": "fodrande",
    "fodrandens": "fodrande",
    "fodrandes": "fodrande",
    "fodrandet": "fodrande",
    "fodrandets": "fodrande",
    "fodrar": "fodra",
    "fodras": "fodra",
    "fodrat": "fodra",
    "fodrats": "fodra",
    "fodren": "foder",
    "fodrens": "foder",
    "fodret": "foder",
    "fodrets": "foder",
    "fogad": "foga",
    "fogade": "foga",
    "fogades": "foga",
    "fogads": "foga",
    "fogande": "foga",
    "foganden": "fogande",
    "fogandena": "fogande",
    "fogandenas": "fogande",
    "fogandens": "fogande",
    "fogandes": "fogande",
    "fogandet": "fogande",
    "fogandets": "fogande",
    "fogar": "foga",
    "fogarna": "fog",
    "fogarnas": "fog",
    "fogars": "fog",
    "fogas": "foga",
    "fogat": "foga",
    "fogats": "foga",
    "fogdar": "fogde",
    "fogdarna": "fogde",
    "fogdarnas": "fogde",
    "fogdars": "fogde",
    "fogden": "fogde",
    "fogdens": "fogde",
    "fogdes": "fogde",
    "foge": "foga",
    "fogen": "fog",
    "fogens": "fog",
    "fogeorden": "fogeord",
    "fogeordens": "fogeord",
    "fogeordet": "fogeord",
    "fogeordets": "fogeord",
    "fogeords": "fogeord",
    "fogliga": "foglig",
    "fogligare": "foglig",
    "fogligares": "foglig",
    "fogligas": "foglig",
    "fogligast": "foglig",
    "fogligaste": "foglig",
    "fogligastes": "foglig",
    "fogligasts": "foglig",
    "foglige": "foglig",
    "fogliges": "foglig",
    "fogligheten": "foglighet",
    "foglighetens": "foglighet",
    "foglighets": "foglighet",
    "fogligs": "foglig",
    "fogligt": "foglig",
    "fogligts": "foglig",
    "fogmassan": "fogmassa",
    "fogmassans": "fogmassa",
    "fogmassas": "fogmassa",
    "fogmasse": "fogmassa",
    "fogmassor": "fogmassa",
    "fogmassorna": "fogmassa",
    "fogmassornas": "fogmassa",
    "fogmassors": "fogmassa",
    "fogs": "fog",
    "fogskummet": "fogskum",
    "fogskummets": "fogskum",
    "fogskums": "fogskum",
    "fogsprut": "fogspruta",
    "fogsprutan": "fogspruta",
    "fogsprutans": "fogspruta",
    "fogsprutas": "fogspruta",
    "fogsprute": "fogspruta",
    "fogsprutor": "fogspruta",
    "fogsprutorna": "fogspruta",
    "fogsprutornas": "fogspruta",
    "fogsprutors": "fogspruta",
    "fogspruts": "fogspruta",
    "fogstruken": "fogstryka",
    "fogstrukens": "fogstryka",
    "fogstruket": "fogstryka",
    "fogstrukets": "fogstryka",
    "fogstrukit": "fogstryka",
    "fogstrukits": "fogstryka",
    "fogstrukna": "fogstryka",
    "fogstruknas": "fogstryka",
    "fogstrukne": "fogstryka",
    "fogstruknes": "fogstryka",
    "fogstryk": "fogstryka",
    "fogstrykande": "fogstryka",
    "fogstrykanden": "fogstrykande",
    "fogstrykandena": "fogstrykande",
    "fogstrykandenas": "fogstrykande",
    "fogstrykandens": "fogstrykande",
    "fogstrykandes": "fogstrykande",
    "fogstrykandet": "fogstrykande",
    "fogstrykandets": "fogstrykande",
    "fogstrykas": "fogstryka",
    "fogstryke": "fogstryka",
    "fogstryker": "fogstryka",
    "fogstrykes": "fogstryka",
    "fogstryks": "fogstryka",
    "fogströk": "fogstryka",
    "fogströke": "fogstryka",
    "fogströkes": "fogstryka",
    "fogströks": "fogstryka",
    "fogsvansar": "fogsvans",
    "fogsvansarna": "fogsvans",
    "fogsvansarnas": "fogsvans",
    "fogsvansars": "fogsvans",
    "fogsvansen": "fogsvans",
    "fogsvansens": "fogsvans",
    "fokala": "fokal",
    "fokalare": "fokal",
    "fokalares": "fokal",
    "fokalas": "fokal",
    "fokalast": "fokal",
    "fokalaste": "fokal",
    "fokalastes": "fokal",
    "fokalasts": "fokal",
    "fokaldistansen": "fokaldistans",
    "fokaldistansens": "fokaldistans",
    "fokaldistanser": "fokaldistans",
    "fokaldistanserna": "fokaldistans",
    "fokaldistansernas": "fokaldistans",
    "fokaldistansers": "fokaldistans",
    "fokale": "fokal",
    "fokales": "fokal",
    "fokalplanen": "fokalplan",
    "fokalplanens": "fokalplan",
    "fokalplanet": "fokalplan",
    "fokalplanets": "fokalplan",
    "fokalplans": "fokalplan",
    "fokals": "fokal",
    "fokalt": "fokal",
    "fokalts": "fokal",
    "fokusar": "fokus",
    "fokusarna": "fokus",
    "fokusarnas": "fokus",
    "fokusars": "fokus",
    "fokusen": "fokus",
    "fokusens": "fokus",
    "fokuserad": "fokusera",
    "fokuserade": "fokusera",
    "fokuserades": "fokusera",
    "fokuserads": "fokusera",
    "fokuserande": "fokusera",
    "fokuseranden": "fokuserande",
    "fokuserandena": "fokuserande",
    "fokuserandenas": "fokuserande",
    "fokuserandens": "fokuserande",
    "fokuserandes": "fokuserande",
    "fokuserandet": "fokuserande",
    "fokuserandets": "fokuserande",
    "fokuserar": "fokusera",
    "fokuseras": "fokusera",
    "fokuserat": "fokusera",
    "fokuserats": "fokusera",
    "fokuserbara": "fokuserbar",
    "fokuserbarare": "fokuserbar",
    "fokuserbarares": "fokuserbar",
    "fokuserbaras": "fokuserbar",
    "fokuserbarast": "fokuserbar",
    "fokuserbaraste": "fokuserbar",
    "fokuserbarastes": "fokuserbar",
    "fokuserbarasts": "fokuserbar",
    "fokuserbare": "fokuserbar",
    "fokuserbares": "fokuserbar",
    "fokuserbarheten": "fokuserbarhet",
    "fokuserbarhetens": "fokuserbarhet",
    "fokuserbarhets": "fokuserbarhet",
    "fokuserbars": "fokuserbar",
    "fokuserbart": "fokuserbar",
    "fokuserbarts": "fokuserbar",
    "fokuseringar": "fokusering",
    "fokuseringarna": "fokusering",
    "fokuseringarnas": "fokusering",
    "fokuseringars": "fokusering",
    "fokuseringen": "fokusering",
    "fokuseringens": "fokusering",
    "fokuserings": "fokusering",
    "foldern": "folder",
    "folderns": "folder",
    "folders": "folder",
    "foldrar": "folder",
    "foldrarna": "folder",
    "foldrarnas": "folder",
    "foldrars": "folder",
    "folianten": "foliant",
    "foliantens": "foliant",
    "folianter": "foliant",
    "folianterna": "foliant",
    "folianternas": "foliant",
    "folianters": "foliant",
    "foliants": "foliant",
    "folien": "folie",
    "foliens": "folie",
    "folier": "folie",
    "folierad": "foliera",
    "folierade": "foliera",
    "folierades": "foliera",
    "folierads": "foliera",
    "folierande": "foliera",
    "folieranden": "folierande",
    "folierandena": "folierande",
    "folierandenas": "folierande",
    "folierandens": "folierande",
    "folierandes": "folierande",
    "folierandet": "folierande",
    "folierandets": "folierande",
    "folierar": "foliera",
    "folieras": "foliera",
    "folierat": "foliera",
    "folierats": "foliera",
    "folierbara": "folierbar",
    "folierbarare": "folierbar",
    "folierbarares": "folierbar",
    "folierbaras": "folierbar",
    "folierbarast": "folierbar",
    "folierbaraste": "folierbar",
    "folierbarastes": "folierbar",
    "folierbarasts": "folierbar",
    "folierbare": "folierbar",
    "folierbares": "folierbar",
    "folierbarheten": "folierbarhet",
    "folierbarhetens": "folierbarhet",
    "folierbarhets": "folierbarhet",
    "folierbars": "folierbar",
    "folierbart": "folierbar",
    "folierbarts": "folierbar",
    "folieringar": "foliering",
    "folieringarna": "foliering",
    "folieringarnas": "foliering",
    "folieringars": "foliering",
    "folieringen": "foliering",
    "folieringens": "foliering",
    "folierings": "foliering",
    "folierna": "folie",
    "foliernas": "folie",
    "foliers": "folie",
    "folies": "folie",
    "foliet": "folie",
    "foliets": "folie",
    "folioformaten": "folioformat",
    "folioformatens": "folioformat",
    "folioformatet": "folioformat",
    "folioformatets": "folioformat",
    "folioformats": "folioformat",
    "folion": "folio",
    "folions": "folio",
    "folios": "folio",
    "folkarméer": "folkarmé",
    "folkarméerna": "folkarmé",
    "folkarméernas": "folkarmé",
    "folkarméers": "folkarmé",
    "folkarmén": "folkarmé",
    "folkarméns": "folkarmé",
    "folkarmés": "folkarmé",
    "folkbiblioteken": "folkbibliotek",
    "folkbibliotekens": "folkbibliotek",
    "folkbiblioteket": "folkbibliotek",
    "folkbibliotekets": "folkbibliotek",
    "folkbiblioteks": "folkbibliotek",
    "folkbildningar": "folkbildning",
    "folkbildningarna": "folkbildning",
    "folkbildningarnas": "folkbildning",
    "folkbildningars": "folkbildning",
    "folkbildningen": "folkbildning",
    "folkbildningens": "folkbildning",
    "folkbildnings": "folkbildning",
    "folkbildningstidskriften": "folkbildningstidskrift",
    "folkbildningstidskriftens": "folkbildningstidskrift",
    "folkbildningstidskrifter": "folkbildningstidskrift",
    "folkbildningstidskrifterna": "folkbildningstidskrift",
    "folkbildningstidskrifternas": "folkbildningstidskrift",
    "folkbildningstidskrifters": "folkbildningstidskrift",
    "folkbildningstidskrifts": "folkbildningstidskrift",
    "folkbokföringar": "folkbokföring",
    "folkbokföringarna": "folkbokföring",
    "folkbokföringarnas": "folkbokföring",
    "folkbokföringars": "folkbokföring",
    "folkbokföringen": "folkbokföring",
    "folkbokföringens": "folkbokföring",
    "folkbokförings": "folkbokföring",
    "folkbåtar": "folkbåt",
    "folkbåtarna": "folkbåt",
    "folkbåtarnas": "folkbåt",
    "folkbåtars": "folkbåt",
    "folkbåten": "folkbåt",
    "folkbåtens": "folkbåt",
    "folkbåts": "folkbåt",
    "folkdansen": "folkdans",
    "folkdansens": "folkdans",
    "folkdanser": "folkdans",
    "folkdanserna": "folkdans",
    "folkdansernas": "folkdans",
    "folkdansers": "folkdans",
    "folkdemokratien": "folkdemokrati",
    "folkdemokratiens": "folkdemokrati",
    "folkdemokratier": "folkdemokrati",
    "folkdemokratierna": "folkdemokrati",
    "folkdemokratiernas": "folkdemokrati",
    "folkdemokratiers": "folkdemokrati",
    "folkdemokratin": "folkdemokrati",
    "folkdemokratins": "folkdemokrati",
    "folkdemokratis": "folkdemokrati",
    "folkdemokratiska": "folkdemokratisk",
    "folkdemokratiskare": "folkdemokratisk",
    "folkdemokratiskares": "folkdemokratisk",
    "folkdemokratiskas": "folkdemokratisk",
    "folkdemokratiskast": "folkdemokratisk",
    "folkdemokratiskaste": "folkdemokratisk",
    "folkdemokratiskastes": "folkdemokratisk",
    "folkdemokratiskasts": "folkdemokratisk",
    "folkdemokratiske": "folkdemokratisk",
    "folkdemokratiskes": "folkdemokratisk",
    "folkdemokratisks": "folkdemokratisk",
    "folkdemokratiskt": "folkdemokratisk",
    "folkdemokratiskts": "folkdemokratisk",
    "folkdikten": "folkdikt",
    "folkdiktens": "folkdikt",
    "folkdikter": "folkdikt",
    "folkdikterna": "folkdikt",
    "folkdikternas": "folkdikt",
    "folkdikters": "folkdikt",
    "folkdiktningar": "folkdiktning",
    "folkdiktningarna": "folkdiktning",
    "folkdiktningarnas": "folkdiktning",
    "folkdiktningars": "folkdiktning",
    "folkdiktningen": "folkdiktning",
    "folkdiktningens": "folkdiktning",
    "folkdiktnings": "folkdiktning",
    "folkdikts": "folkdikt",
    "folkdjupen": "folkdjup",
    "folkdjupens": "folkdjup",
    "folkdjupet": "folkdjup",
    "folkdjupets": "folkdjup",
    "folkdjups": "folkdjup",
    "folkdomstolar": "folkdomstol",
    "folkdomstolarna": "folkdomstol",
    "folkdomstolarnas": "folkdomstol",
    "folkdomstolars": "folkdomstol",
    "folkdomstolen": "folkdomstol",
    "folkdomstolens": "folkdomstol",
    "folkdomstols": "folkdomstol",
    "folkdräkten": "folkdräkt",
    "folkdräktens": "folkdräkt",
    "folkdräkter": "folkdräkt",
    "folkdräkterna": "folkdräkt",
    "folkdräkternas": "folkdräkt",
    "folkdräkters": "folkdräkt",
    "folkdräkts": "folkdräkt",
    "folken": "folk",
    "folkens": "folk",
    "folket": "folk",
    "folkets": "folk",
    "folketymologien": "folketymologi",
    "folketymologiens": "folketymologi",
    "folketymologier": "folketymologi",
    "folketymologierna": "folketymologi",
    "folketymologiernas": "folketymologi",
    "folketymologiers": "folketymologi",
    "folketymologin": "folketymologi",
    "folketymologins": "folketymologi",
    "folketymologis": "folketymologi",
    "folketymologiska": "folketymologisk",
    "folketymologiskare": "folketymologisk",
    "folketymologiskares": "folketymologisk",
    "folketymologiskas": "folketymologisk",
    "folketymologiskast": "folketymologisk",
    "folketymologiskaste": "folketymologisk",
    "folketymologiskastes": "folketymologisk",
    "folketymologiskasts": "folketymologisk",
    "folketymologiske": "folketymologisk",
    "folketymologiskes": "folketymologisk",
    "folketymologisks": "folketymologisk",
    "folketymologiskt": "folketymologisk",
    "folketymologiskts": "folketymologisk",
    "folkfesten": "folkfest",
    "folkfestens": "folkfest",
    "folkfester": "folkfest",
    "folkfesterna": "folkfest",
    "folkfesternas": "folkfest",
    "folkfesters": "folkfest",
    "folkfests": "folkfest",
    "folkfronten": "folkfront",
    "folkfrontens": "folkfront",
    "folkfronter": "folkfront",
    "folkfronterna": "folkfront",
    "folkfronternas": "folkfront",
    "folkfronters": "folkfront",
    "folkfronts": "folkfront",
    "folkföraktet": "folkförakt",
    "folkföraktets": "folkförakt",
    "folkförakts": "folkförakt",
    "folkförsamlingar": "folkförsamling",
    "folkförsamlingarna": "folkförsamling",
    "folkförsamlingarnas": "folkförsamling",
    "folkförsamlingars": "folkförsamling",
    "folkförsamlingen": "folkförsamling",
    "folkförsamlingens": "folkförsamling",
    "folkförsamlings": "folkförsamling",
    "folkgruppen": "folkgrupp",
    "folkgruppens": "folkgrupp",
    "folkgrupper": "folkgrupp",
    "folkgrupperna": "folkgrupp",
    "folkgruppernas": "folkgrupp",
    "folkgruppers": "folkgrupp",
    "folkgrupps": "folkgrupp",
    "folkhemmen": "folkhem",
    "folkhemmens": "folkhem",
    "folkhemmet": "folkhem",
    "folkhemmets": "folkhem",
    "folkhems": "folkhem",
    "folkhemsideologien": "folkhemsideologi",
    "folkhemsideologiens": "folkhemsideologi",
    "folkhemsideologier": "folkhemsideologi",
    "folkhemsideologierna": "folkhemsideologi",
    "folkhemsideologiernas": "folkhemsideologi",
    "folkhemsideologiers": "folkhemsideologi",
    "folkhemsideologin": "folkhemsideologi",
    "folkhemsideologins": "folkhemsideologi",
    "folkhemsideologis": "folkhemsideologi",
    "folkhemsidyllen": "folkhemsidyll",
    "folkhemsidyllens": "folkhemsidyll",
    "folkhemsidyller": "folkhemsidyll",
    "folkhemsidyllerna": "folkhemsidyll",
    "folkhemsidyllernas": "folkhemsidyll",
    "folkhemsidyllers": "folkhemsidyll",
    "folkhemsidylls": "folkhemsidyll",
    "folkhemska": "folkhemsk",
    "folkhemskare": "folkhemsk",
    "folkhemskares": "folkhemsk",
    "folkhemskas": "folkhemsk",
    "folkhemskast": "folkhemsk",
    "folkhemskaste": "folkhemsk",
    "folkhemskastes": "folkhemsk",
    "folkhemskasts": "folkhemsk",
    "folkhemske": "folkhemsk",
    "folkhemskes": "folkhemsk",
    "folkhemsks": "folkhemsk",
    "folkhemskt": "folkhemsk",
    "folkhemskts": "folkhemsk",
    "folkhjältar": "folkhjälte",
    "folkhjältarna": "folkhjälte",
    "folkhjältarnas": "folkhjälte",
    "folkhjältars": "folkhjälte",
    "folkhjälten": "folkhjälte",
    "folkhjältens": "folkhjälte",
    "folkhjältes": "folkhjälte",
    "folkhopar": "folkhop",
    "folkhoparna": "folkhop",
    "folkhoparnas": "folkhop",
    "folkhopars": "folkhop",
    "folkhopen": "folkhop",
    "folkhopens": "folkhop",
    "folkhops": "folkhop",
    "folkhumorn": "folkhumor",
    "folkhumorns": "folkhumor",
    "folkhumors": "folkhumor",
    "folkhälsan": "folkhälsa",
    "folkhälsans": "folkhälsa",
    "folkhälsas": "folkhälsa",
    "folkhälse": "folkhälsa",
    "folkhälso": "folkhälsa",
    "folkhögskolan": "folkhögskola",
    "folkhögskolans": "folkhögskola",
    "folkhögskolas": "folkhögskola",
    "folkhögskole": "folkhögskola",
    "folkhögskolor": "folkhögskola",
    "folkhögskolorna": "folkhögskola",
    "folkhögskolornas": "folkhögskola",
    "folkhögskolors": "folkhögskola",
    "folkilskenheten": "folkilskenhet",
    "folkilskenhetens": "folkilskenhet",
    "folkilskenhets": "folkilskenhet",
    "folkilskens": "folkilsken",
    "folkilsket": "folkilsken",
    "folkilskets": "folkilsken",
    "folkilskna": "folkilsken",
    "folkilsknare": "folkilsken",
    "folkilsknares": "folkilsken",
    "folkilsknas": "folkilsken",
    "folkilsknast": "folkilsken",
    "folkilsknaste": "folkilsken",
    "folkilsknastes": "folkilsken",
    "folkilsknasts": "folkilsken",
    "folkilskne": "folkilsken",
    "folkilsknes": "folkilsken",
    "folkisar": "folkis",
    "folkisarna": "folkis",
    "folkisarnas": "folkis",
    "folkisars": "folkis",
    "folkisen": "folkis",
    "folkisens": "folkis",
    "folkkommissarien": "folkkommissarie",
    "folkkommissariens": "folkkommissarie",
    "folkkommissarier": "folkkommissarie",
    "folkkommissarierna": "folkkommissarie",
    "folkkommissariernas": "folkkommissarie",
    "folkkommissariers": "folkkommissarie",
    "folkkommissaries": "folkkommissarie",
    "folkkommunen": "folkkommun",
    "folkkommunens": "folkkommun",
    "folkkommuner": "folkkommun",
    "folkkommunerna": "folkkommun",
    "folkkommunernas": "folkkommun",
    "folkkommuners": "folkkommun",
    "folkkommuns": "folkkommun",
    "folkkongressen": "folkkongress",
    "folkkongressens": "folkkongress",
    "folkkongresser": "folkkongress",
    "folkkongresserna": "folkkongress",
    "folkkongressernas": "folkkongress",
    "folkkongressers": "folkkongress",
    "folkkonsten": "folkkonst",
    "folkkonstens": "folkkonst",
    "folkkonsts": "folkkonst",
    "folkkära": "folkkär",
    "folkkärare": "folkkär",
    "folkkärares": "folkkär",
    "folkkäras": "folkkär",
    "folkkärast": "folkkär",
    "folkkäraste": "folkkär",
    "folkkärastes": "folkkär",
    "folkkärasts": "folkkär",
    "folkkäre": "folkkär",
    "folkkäres": "folkkär",
    "folkkärs": "folkkär",
    "folkkärt": "folkkär",
    "folkkärts": "folkkär",
    "folklagerna": "folklager",
    "folklagernas": "folklager",
    "folklagers": "folklager",
    "folklagren": "folklager",
    "folklagrens": "folklager",
    "folklagret": "folklager",
    "folklagrets": "folklager",
    "folkledar": "folkledare",
    "folkledaren": "folkledare",
    "folkledarens": "folkledare",
    "folkledares": "folkledare",
    "folkledarna": "folkledare",
    "folkledarnas": "folkledare",
    "folklekar": "folklek",
    "folklekarna": "folklek",
    "folklekarnas": "folklek",
    "folklekars": "folklek",
    "folkleken": "folklek",
    "folklekens": "folklek",
    "folkleks": "folklek",
    "folkliga": "folklig",
    "folkligare": "folklig",
    "folkligares": "folklig",
    "folkligas": "folklig",
    "folkligast": "folklig",
    "folkligaste": "folklig",
    "folkligastes": "folklig",
    "folkligasts": "folklig",
    "folklige": "folklig",
    "folkliges": "folklig",
    "folkligheten": "folklighet",
    "folklighetens": "folklighet",
    "folkligheter": "folklighet",
    "folkligheterna": "folklighet",
    "folkligheternas": "folklighet",
    "folkligheters": "folklighet",
    "folklighets": "folklighet",
    "folkligs": "folklig",
    "folkligt": "folklig",
    "folkligts": "folklig",
    "folklivet": "folkliv",
    "folklivets": "folkliv",
    "folklivs": "folkliv",
    "folklivsforskar": "folklivsforskare",
    "folklivsforskaren": "folklivsforskare",
    "folklivsforskarens": "folklivsforskare",
    "folklivsforskares": "folklivsforskare",
    "folklivsforskarna": "folklivsforskare",
    "folklivsforskarnas": "folklivsforskare",
    "folklivsforskningar": "folklivsforskning",
    "folklivsforskningarna": "folklivsforskning",
    "folklivsforskningarnas": "folklivsforskning",
    "folklivsforskningars": "folklivsforskning",
    "folklivsforskningen": "folklivsforskning",
    "folklivsforskningens": "folklivsforskning",
    "folklivsforsknings": "folklivsforskning",
    "folklivsskildringar": "folklivsskildring",
    "folklivsskildringarna": "folklivsskildring",
    "folklivsskildringarnas": "folklivsskildring",
    "folklivsskildringars": "folklivsskildring",
    "folklivsskildringen": "folklivsskildring",
    "folklivsskildringens": "folklivsskildring",
    "folklivsskildrings": "folklivsskildring",
    "folkloren": "folklore",
    "folklorens": "folklore",
    "folklores": "folklore",
    "folkloristen": "folklorist",
    "folkloristens": "folklorist",
    "folklorister": "folklorist",
    "folkloristerna": "folklorist",
    "folkloristernas": "folklorist",
    "folkloristers": "folklorist",
    "folkloristiken": "folkloristik",
    "folkloristikens": "folkloristik",
    "folkloristiks": "folkloristik",
    "folkloristiska": "folkloristisk",
    "folkloristiskare": "folkloristisk",
    "folkloristiskares": "folkloristisk",
    "folkloristiskas": "folkloristisk",
    "folkloristiskast": "folkloristisk",
    "folkloristiskaste": "folkloristisk",
    "folkloristiskastes": "folkloristisk",
    "folkloristiskasts": "folkloristisk",
    "folkloristiske": "folkloristisk",
    "folkloristiskes": "folkloristisk",
    "folkloristisks": "folkloristisk",
    "folkloristiskt": "folkloristisk",
    "folkloristiskts": "folkloristisk",
    "folklorists": "folklorist",
    "folklustspelen": "folklustspel",
    "folklustspelens": "folklustspel",
    "folklustspelet": "folklustspel",
    "folklustspelets": "folklustspel",
    "folklustspels": "folklustspel",
    "folkmassan": "folkmassa",
    "folkmassans": "folkmassa",
    "folkmassas": "folkmassa",
    "folkmasse": "folkmassa",
    "folkmassor": "folkmassa",
    "folkmassorna": "folkmassa",
    "folkmassornas": "folkmassa",
    "folkmassors": "folkmassa",
    "folkmedicinen": "folkmedicin",
    "folkmedicinens": "folkmedicin",
    "folkmedicins": "folkmedicin",
    "folkmelodien": "folkmelodi",
    "folkmelodiens": "folkmelodi",
    "folkmelodier": "folkmelodi",
    "folkmelodierna": "folkmelodi",
    "folkmelodiernas": "folkmelodi",
    "folkmelodiers": "folkmelodi",
    "folkmelodin": "folkmelodi",
    "folkmelodins": "folkmelodi",
    "folkmelodis": "folkmelodi",
    "folkminnen": "folkminne",
    "folkminnena": "folkminne",
    "folkminnenas": "folkminne",
    "folkminnens": "folkminne",
    "folkminnes": "folkminne",
    "folkminnet": "folkminne",
    "folkminnets": "folkminne",
    "folkmorden": "folkmord",
    "folkmordens": "folkmord",
    "folkmordet": "folkmord",
    "folkmordets": "folkmord",
    "folkmords": "folkmord",
    "folkmordsåtalade": "folkmordsåtalad",
    "folkmordsåtalades": "folkmordsåtalad",
    "folkmordsåtalads": "folkmordsåtalad",
    "folkmordsåtalat": "folkmordsåtalad",
    "folkmordsåtalats": "folkmordsåtalad",
    "folkmusiken": "folkmusik",
    "folkmusikens": "folkmusik",
    "folkmusiks": "folkmusik",
    "folkmängden": "folkmängd",
    "folkmängdens": "folkmängd",
    "folkmängder": "folkmängd",
    "folkmängderna": "folkmängd",
    "folkmängdernas": "folkmängd",
    "folkmängders": "folkmängd",
    "folkmängds": "folkmängd",
    "folkmålen": "folkmål",
    "folkmålens": "folkmål",
    "folkmålet": "folkmål",
    "folkmålets": "folkmål",
    "folkmåls": "folkmål",
    "folknöjen": "folknöje",
    "folknöjena": "folknöje",
    "folknöjenas": "folknöje",
    "folknöjens": "folknöje",
    "folknöjes": "folknöje",
    "folknöjet": "folknöje",
    "folknöjets": "folknöje",
    "folkomröstningar": "folkomröstning",
    "folkomröstningarna": "folkomröstning",
    "folkomröstningarnas": "folkomröstning",
    "folkomröstningars": "folkomröstning",
    "folkomröstningen": "folkomröstning",
    "folkomröstningens": "folkomröstning",
    "folkomröstnings": "folkomröstning",
    "folkopinionen": "folkopinion",
    "folkopinionens": "folkopinion",
    "folkopinioner": "folkopinion",
    "folkopinionerna": "folkopinion",
    "folkopinionernas": "folkopinion",
    "folkopinioners": "folkopinion",
    "folkopinions": "folkopinion",
    "folkparken": "folkpark",
    "folkparkens": "folkpark",
    "folkparker": "folkpark",
    "folkparkerna": "folkpark",
    "folkparkernas": "folkpark",
    "folkparkers": "folkpark",
    "folkparks": "folkpark",
    "folkparksorkestern": "folkparksorkester",
    "folkparksorkesterns": "folkparksorkester",
    "folkparksorkesters": "folkparksorkester",
    "folkparksorkestrar": "folkparksorkester",
    "folkparksorkestrarna": "folkparksorkester",
    "folkparksorkestrarnas": "folkparksorkester",
    "folkparksorkestrars": "folkparksorkester",
    "folkpartier": "folkparti",
    "folkpartierna": "folkparti",
    "folkpartiernas": "folkparti",
    "folkpartiers": "folkparti",
    "folkpartiet": "folkparti",
    "folkpartiets": "folkparti",
    "folkpartis": "folkparti",
    "folkpartisten": "folkpartist",
    "folkpartistens": "folkpartist",
    "folkpartister": "folkpartist",
    "folkpartisterna": "folkpartist",
    "folkpartisternas": "folkpartist",
    "folkpartisters": "folkpartist",
    "folkpartists": "folkpartist",
    "folkpartit": "folkparti",
    "folkpartits": "folkparti",
    "folkpensionen": "folkpension",
    "folkpensionens": "folkpension",
    "folkpensioner": "folkpension",
    "folkpensionerna": "folkpension",
    "folkpensionernas": "folkpension",
    "folkpensioners": "folkpension",
    "folkpensions": "folkpension",
    "folkpensionären": "folkpensionär",
    "folkpensionärens": "folkpensionär",
    "folkpensionärer": "folkpensionär",
    "folkpensionärerna": "folkpensionär",
    "folkpensionärernas": "folkpensionär",
    "folkpensionärers": "folkpensionär",
    "folkpensionärs": "folkpensionär",
    "folkrepresentationen": "folkrepresentation",
    "folkrepresentationens": "folkrepresentation",
    "folkrepresentationer": "folkrepresentation",
    "folkrepresentationerna": "folkrepresentation",
    "folkrepresentationernas": "folkrepresentation",
    "folkrepresentationers": "folkrepresentation",
    "folkrepresentations": "folkrepresentation",
    "folkrepubliken": "folkrepublik",
    "folkrepublikens": "folkrepublik",
    "folkrepubliker": "folkrepublik",
    "folkrepublikerna": "folkrepublik",
    "folkrepublikernas": "folkrepublik",
    "folkrepublikers": "folkrepublik",
    "folkrepubliks": "folkrepublik",
    "folkresningar": "folkresning",
    "folkresningarna": "folkresning",
    "folkresningarnas": "folkresning",
    "folkresningars": "folkresning",
    "folkresningen": "folkresning",
    "folkresningens": "folkresning",
    "folkresnings": "folkresning",
    "folkrika": "folkrik",
    "folkrikare": "folkrik",
    "folkrikares": "folkrik",
    "folkrikas": "folkrik",
    "folkrikast": "folkrik",
    "folkrikaste": "folkrik",
    "folkrikastes": "folkrik",
    "folkrikasts": "folkrik",
    "folkrike": "folkrik",
    "folkrikes": "folkrik",
    "folkrikheten": "folkrikhet",
    "folkrikhetens": "folkrikhet",
    "folkrikhets": "folkrikhet",
    "folkriks": "folkrik",
    "folkrikt": "folkrik",
    "folkrikts": "folkrik",
    "folkräkningar": "folkräkning",
    "folkräkningarna": "folkräkning",
    "folkräkningarnas": "folkräkning",
    "folkräkningars": "folkräkning",
    "folkräkningen": "folkräkning",
    "folkräkningens": "folkräkning",
    "folkräknings": "folkräkning",
    "folkrätten": "folkrätt",
    "folkrättens": "folkrätt",
    "folkrätts": "folkrätt",
    "folkrättsliga": "folkrättslig",
    "folkrättsligare": "folkrättslig",
    "folkrättsligares": "folkrättslig",
    "folkrättsligas": "folkrättslig",
    "folkrättsligast": "folkrättslig",
    "folkrättsligaste": "folkrättslig",
    "folkrättsligastes": "folkrättslig",
    "folkrättsligasts": "folkrättslig",
    "folkrättslige": "folkrättslig",
    "folkrättsliges": "folkrättslig",
    "folkrättsligs": "folkrättslig",
    "folkrättsligt": "folkrättslig",
    "folkrättsligts": "folkrättslig",
    "folkrörelsen": "folkrörelse",
    "folkrörelsens": "folkrörelse",
    "folkrörelser": "folkrörelse",
    "folkrörelserna": "folkrörelse",
    "folkrörelsernas": "folkrörelse",
    "folkrörelsers": "folkrörelse",
    "folkrörelses": "folkrörelse",
    "folks": "folk",
    "folksagan": "folksaga",
    "folksagans": "folksaga",
    "folksagas": "folksaga",
    "folksage": "folksaga",
    "folksago": "folksaga",
    "folksagor": "folksaga",
    "folksagorna": "folksaga",
    "folksagornas": "folksaga",
    "folksagors": "folksaga",
    "folksamlingar": "folksamling",
    "folksamlingarna": "folksamling",
    "folksamlingarnas": "folksamling",
    "folksamlingars": "folksamling",
    "folksamlingen": "folksamling",
    "folksamlingens": "folksamling",
    "folksamlings": "folksamling",
    "folksjukdomar": "folksjukdom",
    "folksjukdomarna": "folksjukdom",
    "folksjukdomarnas": "folksjukdom",
    "folksjukdomars": "folksjukdom",
    "folksjukdomen": "folksjukdom",
    "folksjukdomens": "folksjukdom",
    "folksjukdoms": "folksjukdom",
    "folkskolan": "folkskola",
    "folkskolans": "folkskola",
    "folkskolas": "folkskola",
    "folkskole": "folkskola",
    "folkskollärar": "folkskollärare",
    "folkskolläraren": "folkskollärare",
    "folkskollärarens": "folkskollärare",
    "folkskollärares": "folkskollärare",
    "folkskollärarna": "folkskollärare",
    "folkskollärarnas": "folkskollärare",
    "folkskolor": "folkskola",
    "folkskolorna": "folkskola",
    "folkskolornas": "folkskola",
    "folkskolors": "folkskola",
    "folkskygga": "folkskygg",
    "folkskyggare": "folkskygg",
    "folkskyggares": "folkskygg",
    "folkskyggas": "folkskygg",
    "folkskyggast": "folkskygg",
    "folkskyggaste": "folkskygg",
    "folkskyggastes": "folkskygg",
    "folkskyggasts": "folkskygg",
    "folkskygge": "folkskygg",
    "folkskygges": "folkskygg",
    "folkskyggheten": "folkskygghet",
    "folkskygghetens": "folkskygghet",
    "folkskygghets": "folkskygghet",
    "folkskyggs": "folkskygg",
    "folkskyggt": "folkskygg",
    "folkskyggts": "folkskygg",
    "folkslagen": "folkslag",
    "folkslagens": "folkslag",
    "folkslaget": "folkslag",
    "folkslagets": "folkslag",
    "folkslags": "folkslag",
    "folkspillran": "folkspillra",
    "folkspillrans": "folkspillra",
    "folkspillras": "folkspillra",
    "folkspillre": "folkspillra",
    "folkspillror": "folkspillra",
    "folkspillrorna": "folkspillra",
    "folkspillrornas": "folkspillra",
    "folkspillrors": "folkspillra",
    "folkstammar": "folkstam",
    "folkstammarna": "folkstam",
    "folkstammarnas": "folkstam",
    "folkstammars": "folkstam",
    "folkstammen": "folkstam",
    "folkstammens": "folkstam",
    "folkstams": "folkstam",
    "folkstormar": "folkstorm",
    "folkstormarna": "folkstorm",
    "folkstormarnas": "folkstorm",
    "folkstormars": "folkstorm",
    "folkstormen": "folkstorm",
    "folkstormens": "folkstorm",
    "folkstorms": "folkstorm",
    "folkstyren": "folkstyre",
    "folkstyrena": "folkstyre",
    "folkstyrenas": "folkstyre",
    "folkstyrens": "folkstyre",
    "folkstyres": "folkstyre",
    "folkstyret": "folkstyre",
    "folkstyrets": "folkstyre",
    "folksägenn": "folksägen",
    "folksägenns": "folksägen",
    "folksägens": "folksägen",
    "folksägner": "folksägen",
    "folksägnerna": "folksägen",
    "folksägnernas": "folksägen",
    "folksägners": "folksägen",
    "folksången": "folksång",
    "folksångens": "folksång",
    "folksånger": "folksång",
    "folksångerna": "folksång",
    "folksångernas": "folksång",
    "folksångers": "folksång",
    "folksångs": "folksång",
    "folktandvården": "folktandvård",
    "folktandvårdens": "folktandvård",
    "folktandvårds": "folktandvård",
    "folktingen": "folkting",
    "folktingens": "folkting",
    "folktinget": "folkting",
    "folktingets": "folkting",
    "folktings": "folkting",
    "folktomheten": "folktomhet",
    "folktomhetens": "folktomhet",
    "folktomhets": "folktomhet",
    "folktomma": "folktom",
    "folktommare": "folktom",
    "folktommares": "folktom",
    "folktommas": "folktom",
    "folktommast": "folktom",
    "folktommaste": "folktom",
    "folktommastes": "folktom",
    "folktommasts": "folktom",
    "folktomme": "folktom",
    "folktommes": "folktom",
    "folktoms": "folktom",
    "folktomt": "folktom",
    "folktomts": "folktom",
    "folktonen": "folkton",
    "folktonens": "folkton",
    "folktons": "folkton",
    "folktribunen": "folktribun",
    "folktribunens": "folktribun",
    "folktribuner": "folktribun",
    "folktribunerna": "folktribun",
    "folktribunernas": "folktribun",
    "folktribuners": "folktribun",
    "folktribuns": "folktribun",
    "folktron": "folktro",
    "folktrons": "folktro",
    "folktros": "folktro",
    "folktäta": "folktät",
    "folktätare": "folktät",
    "folktätares": "folktät",
    "folktätas": "folktät",
    "folktätast": "folktät",
    "folktätaste": "folktät",
    "folktätastes": "folktät",
    "folktätasts": "folktät",
    "folktäte": "folktät",
    "folktätes": "folktät",
    "folktätheten": "folktäthet",
    "folktäthetens": "folktäthet",
    "folktätheter": "folktäthet",
    "folktätheterna": "folktäthet",
    "folktätheternas": "folktäthet",
    "folktätheters": "folktäthet",
    "folktäthets": "folktäthet",
    "folktäts": "folktät",
    "folktätt": "folktät",
    "folktätts": "folktät",
    "folkuniversiteten": "folkuniversitet",
    "folkuniversitetens": "folkuniversitet",
    "folkuniversitetet": "folkuniversitet",
    "folkuniversitetets": "folkuniversitet",
    "folkuniversitets": "folkuniversitet",
    "folkvalda": "folkvald",
    "folkvaldare": "folkvald",
    "folkvaldares": "folkvald",
    "folkvaldas": "folkvald",
    "folkvaldast": "folkvald",
    "folkvaldaste": "folkvald",
    "folkvaldastes": "folkvald",
    "folkvaldasts": "folkvald",
    "folkvalde": "folkvald",
    "folkvaldes": "folkvald",
    "folkvalds": "folkvald",
    "folkvalt": "folkvald",
    "folkvalts": "folkvald",
    "folkvandringar": "folkvandring",
    "folkvandringarna": "folkvandring",
    "folkvandringarnas": "folkvandring",
    "folkvandringars": "folkvandring",
    "folkvandringen": "folkvandring",
    "folkvandringens": "folkvandring",
    "folkvandrings": "folkvandring",
    "folkvandringstiden": "folkvandringstid",
    "folkvandringstidens": "folkvandringstid",
    "folkvandringstids": "folkvandringstid",
    "folkvettet": "folkvett",
    "folkvettets": "folkvett",
    "folkvetts": "folkvett",
    "folkvettsexperten": "folkvettsexpert",
    "folkvettsexpertens": "folkvettsexpert",
    "folkvettsexperter": "folkvettsexpert",
    "folkvettsexperterna": "folkvettsexpert",
    "folkvettsexperternas": "folkvettsexpert",
    "folkvettsexperters": "folkvettsexpert",
    "folkvettsexperts": "folkvettsexpert",
    "folkviljan": "folkvilja",
    "folkviljans": "folkvilja",
    "folkviljas": "folkvilja",
    "folkvilje": "folkvilja",
    "folkviljor": "folkvilja",
    "folkviljorna": "folkvilja",
    "folkviljornas": "folkvilja",
    "folkviljors": "folkvilja",
    "folkvis": "folkvisa",
    "folkvisan": "folkvisa",
    "folkvisans": "folkvisa",
    "folkvisas": "folkvisa",
    "folkvise": "folkvisa",
    "folkvisor": "folkvisa",
    "folkvisorna": "folkvisa",
    "folkvisornas": "folkvisa",
    "folkvisors": "folkvisa",
    "folkölen": "folköl",
    "folkölens": "folköl",
    "folkölet": "folköl",
    "folkölets": "folköl",
    "folköls": "folköl",
    "follar": "folle",
    "follarna": "folle",
    "follarnas": "folle",
    "follars": "folle",
    "follen": "folle",
    "follens": "folle",
    "folles": "folle",
    "follikeln": "follikel",
    "follikelns": "follikel",
    "follikels": "follikel",
    "folliklar": "follikel",
    "folliklarna": "follikel",
    "folliklarnas": "follikel",
    "folliklars": "follikel",
    "fondaktien": "fondaktie",
    "fondaktiens": "fondaktie",
    "fondaktier": "fondaktie",
    "fondaktierna": "fondaktie",
    "fondaktiernas": "fondaktie",
    "fondaktiers": "fondaktie",
    "fondakties": "fondaktie",
    "fondbestämmelsen": "fondbestämmelse",
    "fondbestämmelsens": "fondbestämmelse",
    "fondbestämmelser": "fondbestämmelse",
    "fondbestämmelserna": "fondbestämmelse",
    "fondbestämmelsernas": "fondbestämmelse",
    "fondbestämmelsers": "fondbestämmelse",
    "fondbestämmelses": "fondbestämmelse",
    "fondbolagen": "fondbolag",
    "fondbolagens": "fondbolag",
    "fondbolaget": "fondbolag",
    "fondbolagets": "fondbolag",
    "fondbolags": "fondbolag",
    "fondbörsen": "fondbörs",
    "fondbörsens": "fondbörs",
    "fondbörser": "fondbörs",
    "fondbörserna": "fondbörs",
    "fondbörsernas": "fondbörs",
    "fondbörsers": "fondbörs",
    "fondemissionen": "fondemission",
    "fondemissionens": "fondemission",
    "fondemissioner": "fondemission",
    "fondemissionerna": "fondemission",
    "fondemissionernas": "fondemission",
    "fondemissioners": "fondemission",
    "fondemissions": "fondemission",
    "fonden": "fond",
    "fondens": "fond",
    "fonder": "fond",
    "fonderad": "fondera",
    "fonderade": "fondera",
    "fonderades": "fondera",
    "fonderads": "fondera",
    "fonderande": "fondera",
    "fonderanden": "fonderande",
    "fonderandena": "fonderande",
    "fonderandenas": "fonderande",
    "fonderandens": "fonderande",
    "fonderandes": "fonderande",
    "fonderandet": "fonderande",
    "fonderandets": "fonderande",
    "fonderar": "fondera",
    "fonderas": "fondera",
    "fonderat": "fondera",
    "fonderats": "fondera",
    "fonderbara": "fonderbar",
    "fonderbarare": "fonderbar",
    "fonderbarares": "fonderbar",
    "fonderbaras": "fonderbar",
    "fonderbarast": "fonderbar",
    "fonderbaraste": "fonderbar",
    "fonderbarastes": "fonderbar",
    "fonderbarasts": "fonderbar",
    "fonderbare": "fonderbar",
    "fonderbares": "fonderbar",
    "fonderbarheten": "fonderbarhet",
    "fonderbarhetens": "fonderbarhet",
    "fonderbarhets": "fonderbarhet",
    "fonderbars": "fonderbar",
    "fonderbart": "fonderbar",
    "fonderbarts": "fonderbar",
    "fonderingar": "fondering",
    "fonderingarna": "fondering",
    "fonderingarnas": "fondering",
    "fonderingars": "fondering",
    "fonderingen": "fondering",
    "fonderingens": "fondering",
    "fonderings": "fondering",
    "fonderna": "fond",
    "fondernas": "fond",
    "fonders": "fond",
    "fondkommissionären": "fondkommissionär",
    "fondkommissionärens": "fondkommissionär",
    "fondkommissionärer": "fondkommissionär",
    "fondkommissionärerna": "fondkommissionär",
    "fondkommissionärernas": "fondkommissionär",
    "fondkommissionärers": "fondkommissionär",
    "fondkommissionärs": "fondkommissionär",
    "fondmäklar": "fondmäklare",
    "fondmäklaren": "fondmäklare",
    "fondmäklarens": "fondmäklare",
    "fondmäklares": "fondmäklare",
    "fondmäklarna": "fondmäklare",
    "fondmäklarnas": "fondmäklare",
    "fondpapperen": "fondpapper",
    "fondpapperens": "fondpapper",
    "fondpapperet": "fondpapper",
    "fondpapperets": "fondpapper",
    "fondpapperna": "fondpapper",
    "fondpappernas": "fondpapper",
    "fondpappers": "fondpapper",
    "fondpappren": "fondpapper",
    "fondpapprens": "fondpapper",
    "fondpappret": "fondpapper",
    "fondpapprets": "fondpapper",
    "fonds": "fond",
    "fondstämpeln": "fondstämpel",
    "fondstämpelns": "fondstämpel",
    "fondstämpels": "fondstämpel",
    "fondstämplar": "fondstämpel",
    "fondstämplarna": "fondstämpel",
    "fondstämplarnas": "fondstämpel",
    "fondstämplars": "fondstämpel",
    "fondtapeten": "fondtapet",
    "fondtapetens": "fondtapet",
    "fondtapeter": "fondtapet",
    "fondtapeterna": "fondtapet",
    "fondtapeternas": "fondtapet",
    "fondtapeters": "fondtapet",
    "fondtapets": "fondtapet",
    "fonduen": "fondue",
    "fonduens": "fondue",
    "fonduer": "fondue",
    "fonduerna": "fondue",
    "fonduernas": "fondue",
    "fonduers": "fondue",
    "fondues": "fondue",
    "fondyer": "fondy",
    "fondyerna": "fondy",
    "fondyernas": "fondy",
    "fondyers": "fondy",
    "fondyn": "fondy",
    "fondyns": "fondy",
    "fondys": "fondy",
    "fonematiska": "fonematisk",
    "fonematiskare": "fonematisk",
    "fonematiskares": "fonematisk",
    "fonematiskas": "fonematisk",
    "fonematiskast": "fonematisk",
    "fonematiskaste": "fonematisk",
    "fonematiskastes": "fonematisk",
    "fonematiskasts": "fonematisk",
    "fonematiske": "fonematisk",
    "fonematiskes": "fonematisk",
    "fonematisks": "fonematisk",
    "fonematiskt": "fonematisk",
    "fonematiskts": "fonematisk",
    "fonemen": "fonem",
    "fonemens": "fonem",
    "fonemet": "fonem",
    "fonemets": "fonem",
    "fonems": "fonem",
    "fonen": "fon",
    "fonens": "fon",
    "foner": "fon",
    "fonerna": "fon",
    "fonernas": "fon",
    "foners": "fon",
    "fonetiken": "fonetik",
    "fonetikens": "fonetik",
    "fonetikern": "fonetiker",
    "fonetikerna": "fonetiker",
    "fonetikernas": "fonetiker",
    "fonetikerns": "fonetiker",
    "fonetikers": "fonetiker",
    "fonetiks": "fonetik",
    "fonetiska": "fonetisk",
    "fonetiskare": "fonetisk",
    "fonetiskares": "fonetisk",
    "fonetiskas": "fonetisk",
    "fonetiskast": "fonetisk",
    "fonetiskaste": "fonetisk",
    "fonetiskastes": "fonetisk",
    "fonetiskasts": "fonetisk",
    "fonetiske": "fonetisk",
    "fonetiskes": "fonetisk",
    "fonetisks": "fonetisk",
    "fonetiskt": "fonetisk",
    "fonetiskts": "fonetisk",
    "foniatern": "foniater",
    "foniaterns": "foniater",
    "foniaters": "foniater",
    "foniatrer": "foniater",
    "foniatrerna": "foniater",
    "foniatrernas": "foniater",
    "foniatrers": "foniater",
    "foniatrien": "foniatri",
    "foniatriens": "foniatri",
    "foniatriken": "foniatrik",
    "foniatrikens": "foniatrik",
    "foniatrikern": "foniatriker",
    "foniatrikerna": "foniatriker",
    "foniatrikernas": "foniatriker",
    "foniatrikerns": "foniatriker",
    "foniatrikers": "foniatriker",
    "foniatriks": "foniatrik",
    "foniatrin": "foniatri",
    "foniatrins": "foniatri",
    "foniatris": "foniatri",
    "foniatriska": "foniatrisk",
    "foniatriskare": "foniatrisk",
    "foniatriskares": "foniatrisk",
    "foniatriskas": "foniatrisk",
    "foniatriskast": "foniatrisk",
    "foniatriskaste": "foniatrisk",
    "foniatriskastes": "foniatrisk",
    "foniatriskasts": "foniatrisk",
    "foniatriske": "foniatrisk",
    "foniatriskes": "foniatrisk",
    "foniatrisks": "foniatrisk",
    "foniatriskt": "foniatrisk",
    "foniatriskts": "foniatrisk",
    "fonografen": "fonograf",
    "fonografens": "fonograf",
    "fonografer": "fonograf",
    "fonograferna": "fonograf",
    "fonografernas": "fonograf",
    "fonografers": "fonograf",
    "fonografs": "fonograf",
    "fonogrammen": "fonogram",
    "fonogrammens": "fonogram",
    "fonogrammet": "fonogram",
    "fonogrammets": "fonogram",
    "fonograms": "fonogram",
    "fonologien": "fonologi",
    "fonologiens": "fonologi",
    "fonologin": "fonologi",
    "fonologins": "fonologi",
    "fonologis": "fonologi",
    "fonologiska": "fonologisk",
    "fonologiskare": "fonologisk",
    "fonologiskares": "fonologisk",
    "fonologiskas": "fonologisk",
    "fonologiskast": "fonologisk",
    "fonologiskaste": "fonologisk",
    "fonologiskastes": "fonologisk",
    "fonologiskasts": "fonologisk",
    "fonologiske": "fonologisk",
    "fonologiskes": "fonologisk",
    "fonologisks": "fonologisk",
    "fonologiskt": "fonologisk",
    "fonologiskts": "fonologisk",
    "fonoteken": "fonotek",
    "fonotekens": "fonotek",
    "fonoteket": "fonotek",
    "fonotekets": "fonotek",
    "fonoteks": "fonotek",
    "fons": "fon",
    "fontanellen": "fontanell",
    "fontanellens": "fontanell",
    "fontaneller": "fontanell",
    "fontanellerna": "fontanell",
    "fontanellernas": "fontanell",
    "fontanellers": "fontanell",
    "fontanells": "fontanell",
    "fonten": "font",
    "fontens": "font",
    "fonter": "font",
    "fonterna": "font",
    "fonternas": "font",
    "fonters": "font",
    "fonts": "font",
    "fontänen": "fontän",
    "fontänens": "fontän",
    "fontäner": "fontän",
    "fontänerna": "fontän",
    "fontänernas": "fontän",
    "fontäners": "fontän",
    "fontänpumpar": "fontänpump",
    "fontänpumparna": "fontänpump",
    "fontänpumparnas": "fontänpump",
    "fontänpumpars": "fontänpump",
    "fontänpumpen": "fontänpump",
    "fontänpumpens": "fontänpump",
    "fontänpumps": "fontänpump",
    "fontäns": "fontän",
    "for": "fora",
    "fora": "forum",
    "foran": "fora",
    "forana": "forum",
    "foranas": "forum",
    "forans": "fora",
    "foras": "forum",
    "forcerad": "forcera",
    "forcerade": "forcerad",
    "forcerades": "forcerad",
    "forcerads": "forcerad",
    "forcerande": "forcera",
    "forceranden": "forcerande",
    "forcerandena": "forcerande",
    "forcerandenas": "forcerande",
    "forcerandens": "forcerande",
    "forcerandes": "forcerande",
    "forcerandet": "forcerande",
    "forcerandets": "forcerande",
    "forcerar": "forcera",
    "forceras": "forcera",
    "forcerat": "forcerad",
    "forcerats": "forcerad",
    "forcerbara": "forcerbar",
    "forcerbarare": "forcerbar",
    "forcerbarares": "forcerbar",
    "forcerbaras": "forcerbar",
    "forcerbarast": "forcerbar",
    "forcerbaraste": "forcerbar",
    "forcerbarastes": "forcerbar",
    "forcerbarasts": "forcerbar",
    "forcerbare": "forcerbar",
    "forcerbares": "forcerbar",
    "forcerbarheten": "forcerbarhet",
    "forcerbarhetens": "forcerbarhet",
    "forcerbarhets": "forcerbarhet",
    "forcerbars": "forcerbar",
    "forcerbart": "forcerbar",
    "forcerbarts": "forcerbar",
    "forceringar": "forcering",
    "forceringarna": "forcering",
    "forceringarnas": "forcering",
    "forceringars": "forcering",
    "forceringen": "forcering",
    "forceringens": "forcering",
    "forcerings": "forcering",
    "fordonen": "fordon",
    "fordonens": "fordon",
    "fordonet": "fordon",
    "fordonets": "fordon",
    "fordons": "fordon",
    "fordonskolonnen": "fordonskolonn",
    "fordonskolonnens": "fordonskolonn",
    "fordonskolonner": "fordonskolonn",
    "fordonskolonnerna": "fordonskolonn",
    "fordonskolonnernas": "fordonskolonn",
    "fordonskolonners": "fordonskolonn",
    "fordonskolonns": "fordonskolonn",
    "fordonsuppställningar": "fordonsuppställning",
    "fordonsuppställningarna": "fordonsuppställning",
    "fordonsuppställningarnas": "fordonsuppställning",
    "fordonsuppställningars": "fordonsuppställning",
    "fordonsuppställningen": "fordonsuppställning",
    "fordonsuppställningens": "fordonsuppställning",
    "fordonsuppställnings": "fordonsuppställning",
    "fordonsvikten": "fordonsvikt",
    "fordonsviktens": "fordonsvikt",
    "fordonsvikter": "fordonsvikt",
    "fordonsvikterna": "fordonsvikt",
    "fordonsvikternas": "fordonsvikt",
    "fordonsvikters": "fordonsvikt",
    "fordonsvikts": "fordonsvikt",
    "fordrade": "fordra",
    "fordrades": "fordras",
    "fordrande": "fordra",
    "fordranden": "fordrande",
    "fordrandena": "fordrande",
    "fordrandenas": "fordrande",
    "fordrandens": "fordrande",
    "fordrandes": "fordrande",
    "fordrandet": "fordrande",
    "fordrandets": "fordrande",
    "fordrans": "fordran",
    "fordrar": "fordra",
    "fordras": "fordra",
    "fordrat": "fordra",
    "fordrats": "fordras",
    "fordringar": "fordring",
    "fordringarna": "fordring",
    "fordringarnas": "fordring",
    "fordringars": "fordring",
    "fordringen": "fordring",
    "fordringens": "fordring",
    "fordrings": "fordring",
    "fordringsfulla": "fordringsfull",
    "fordringsfullare": "fordringsfull",
    "fordringsfullares": "fordringsfull",
    "fordringsfullas": "fordringsfull",
    "fordringsfullast": "fordringsfull",
    "fordringsfullaste": "fordringsfull",
    "fordringsfullastes": "fordringsfull",
    "fordringsfullasts": "fordringsfull",
    "fordringsfulle": "fordringsfull",
    "fordringsfulles": "fordringsfull",
    "fordringsfullheten": "fordringsfullhet",
    "fordringsfullhetens": "fordringsfullhet",
    "fordringsfullhets": "fordringsfullhet",
    "fordringsfulls": "fordringsfull",
    "fordringsfullt": "fordringsfull",
    "fordringsfullts": "fordringsfull",
    "fordringsägar": "fordringsägare",
    "fordringsägaren": "fordringsägare",
    "fordringsägarens": "fordringsägare",
    "fordringsägares": "fordringsägare",
    "fordringsägarna": "fordringsägare",
    "fordringsägarnas": "fordringsägare",
    "fore": "fora",
    "forecheck": "forechecka",
    "forecheckad": "forechecka",
    "forecheckade": "forechecka",
    "forecheckades": "forechecka",
    "forecheckads": "forechecka",
    "forecheckande": "forechecka",
    "forecheckanden": "forecheckande",
    "forecheckandena": "forecheckande",
    "forecheckandenas": "forecheckande",
    "forecheckandens": "forecheckande",
    "forecheckandes": "forecheckande",
    "forecheckandet": "forecheckande",
    "forecheckandets": "forecheckande",
    "forecheckar": "forechecka",
    "forecheckas": "forechecka",
    "forecheckat": "forechecka",
    "forecheckats": "forechecka",
    "forehanden": "forehand",
    "forehandens": "forehand",
    "forehands": "forehand",
    "forellen": "forell",
    "forellens": "forell",
    "foreller": "forell",
    "forellerna": "forell",
    "forellernas": "forell",
    "forellers": "forell",
    "forells": "forell",
    "forensiska": "forensisk",
    "forensiskas": "forensisk",
    "forensiske": "forensisk",
    "forensiskes": "forensisk",
    "forensisks": "forensisk",
    "forensiskt": "forensisk",
    "forensiskts": "forensisk",
    "fores": "fara",
    "formad": "forma",
    "formade": "forma",
    "formades": "forma",
    "formads": "forma",
    "formaldehyden": "formaldehyd",
    "formaldehydens": "formaldehyd",
    "formaldehyder": "formaldehyd",
    "formaldehyderna": "formaldehyd",
    "formaldehydernas": "formaldehyd",
    "formaldehyders": "formaldehyd",
    "formaldehyds": "formaldehyd",
    "formalinen": "formalin",
    "formalinens": "formalin",
    "formalinet": "formalin",
    "formalinets": "formalin",
    "formalins": "formalin",
    "formaliserad": "formalisera",
    "formaliserade": "formalisera",
    "formaliserades": "formalisera",
    "formaliserads": "formalisera",
    "formaliserande": "formalisera",
    "formaliseranden": "formaliserande",
    "formaliserandena": "formaliserande",
    "formaliserandenas": "formaliserande",
    "formaliserandens": "formaliserande",
    "formaliserandes": "formaliserande",
    "formaliserandet": "formaliserande",
    "formaliserandets": "formaliserande",
    "formaliserar": "formalisera",
    "formaliseras": "formalisera",
    "formaliserat": "formalisera",
    "formaliserats": "formalisera",
    "formaliserbara": "formaliserbar",
    "formaliserbarare": "formaliserbar",
    "formaliserbarares": "formaliserbar",
    "formaliserbaras": "formaliserbar",
    "formaliserbarast": "formaliserbar",
    "formaliserbaraste": "formaliserbar",
    "formaliserbarastes": "formaliserbar",
    "formaliserbarasts": "formaliserbar",
    "formaliserbare": "formaliserbar",
    "formaliserbares": "formaliserbar",
    "formaliserbarheten": "formaliserbarhet",
    "formaliserbarhetens": "formaliserbarhet",
    "formaliserbarhets": "formaliserbarhet",
    "formaliserbars": "formaliserbar",
    "formaliserbart": "formaliserbar",
    "formaliserbarts": "formaliserbar",
    "formaliseringar": "formalisering",
    "formaliseringarna": "formalisering",
    "formaliseringarnas": "formalisering",
    "formaliseringars": "formalisering",
    "formaliseringen": "formalisering",
    "formaliseringens": "formalisering",
    "formaliserings": "formalisering",
    "formalismen": "formalism",
    "formalismens": "formalism",
    "formalismer": "formalism",
    "formalismerna": "formalism",
    "formalismernas": "formalism",
    "formalismers": "formalism",
    "formalisms": "formalism",
    "formalisten": "formalist",
    "formalistens": "formalist",
    "formalister": "formalist",
    "formalisterna": "formalist",
    "formalisternas": "formalist",
    "formalisters": "formalist",
    "formalistiska": "formalistisk",
    "formalistiskas": "formalistisk",
    "formalistiske": "formalistisk",
    "formalistiskes": "formalistisk",
    "formalistisks": "formalistisk",
    "formalistiskt": "formalistisk",
    "formalistiskts": "formalistisk",
    "formalists": "formalist",
    "formaliteten": "formalitet",
    "formalitetens": "formalitet",
    "formaliteter": "formalitet",
    "formaliteterna": "formalitet",
    "formaliteternas": "formalitet",
    "formaliteters": "formalitet",
    "formalitets": "formalitet",
    "formande": "forma",
    "formanden": "formande",
    "formandena": "formande",
    "formandenas": "formande",
    "formandens": "formande",
    "formandes": "formande",
    "formandet": "formande",
    "formandets": "formande",
    "formanten": "formant",
    "formantens": "formant",
    "formanter": "formant",
    "formanterna": "formant",
    "formanternas": "formant",
    "formanters": "formant",
    "formants": "formant",
    "formar": "forma",
    "formarna": "form",
    "formarnas": "form",
    "formars": "form",
    "formas": "forma",
    "format": "forma",
    "formaten": "format",
    "formatens": "format",
    "formatet": "format",
    "formatets": "format",
    "formationen": "formation",
    "formationens": "formation",
    "formationer": "formation",
    "formationerna": "formation",
    "formationernas": "formation",
    "formationers": "formation",
    "formations": "formation",
    "formats": "format",
    "formbakelsen": "formbakelse",
    "formbakelsens": "formbakelse",
    "formbakelser": "formbakelse",
    "formbakelserna": "formbakelse",
    "formbakelsernas": "formbakelse",
    "formbakelsers": "formbakelse",
    "formbakelses": "formbakelse",
    "formbara": "formbar",
    "formbarare": "formbar",
    "formbarares": "formbar",
    "formbaras": "formbar",
    "formbarast": "formbar",
    "formbaraste": "formbar",
    "formbarastes": "formbar",
    "formbarasts": "formbar",
    "formbare": "formbar",
    "formbares": "formbar",
    "formbarheten": "formbarhet",
    "formbarhetens": "formbarhet",
    "formbarhets": "formbarhet",
    "formbars": "formbar",
    "formbart": "formbar",
    "formbarts": "formbar",
    "formbildningar": "formbildning",
    "formbildningarna": "formbildning",
    "formbildningarnas": "formbildning",
    "formbildningars": "formbildning",
    "formbildningen": "formbildning",
    "formbildningens": "formbildning",
    "formbildnings": "formbildning",
    "formbildningsproblemen": "formbildningsproblem",
    "formbildningsproblemens": "formbildningsproblem",
    "formbildningsproblemet": "formbildningsproblem",
    "formbildningsproblemets": "formbildningsproblem",
    "formbildningsproblems": "formbildningsproblem",
    "formbröden": "formbröd",
    "formbrödens": "formbröd",
    "formbrödet": "formbröd",
    "formbrödets": "formbröd",
    "formbröds": "formbröd",
    "formbundenheten": "formbundenhet",
    "formbundenhetens": "formbundenhet",
    "formbundenhets": "formbundenhet",
    "formbundens": "formbunden",
    "formbundet": "formbunden",
    "formbundets": "formbunden",
    "formbundna": "formbunden",
    "formbundnare": "formbunden",
    "formbundnares": "formbunden",
    "formbundnas": "formbunden",
    "formbundnast": "formbunden",
    "formbundnaste": "formbunden",
    "formbundnastes": "formbunden",
    "formbundnasts": "formbunden",
    "formbundne": "formbunden",
    "formbundnes": "formbunden",
    "formelbilar": "formelbil",
    "formelbilarna": "formelbil",
    "formelbilarnas": "formelbil",
    "formelbilars": "formelbil",
    "formelbilen": "formelbil",
    "formelbilens": "formelbil",
    "formelbils": "formelbil",
    "formelenheten": "formelenhet",
    "formelenhetens": "formelenhet",
    "formelenheter": "formelenhet",
    "formelenheterna": "formelenhet",
    "formelenheternas": "formelenhet",
    "formelenheters": "formelenhet",
    "formelenhets": "formelenhet",
    "formella": "formell",
    "formellare": "formell",
    "formellares": "formell",
    "formellas": "formell",
    "formellast": "formell",
    "formellaste": "formell",
    "formellastes": "formell",
    "formellasts": "formell",
    "formelle": "formell",
    "formelles": "formell",
    "formells": "formell",
    "formellt": "formell",
    "formellts": "formell",
    "formeln": "formel",
    "formelns": "formel",
    "formels": "formel",
    "formen": "form",
    "formens": "form",
    "former": "form",
    "formerad": "formera",
    "formerade": "formera",
    "formerades": "formera",
    "formerads": "formera",
    "formerande": "formera",
    "formeranden": "formerande",
    "formerandena": "formerande",
    "formerandenas": "formerande",
    "formerandens": "formerande",
    "formerandes": "formerande",
    "formerandet": "formerande",
    "formerandets": "formerande",
    "formerar": "formera",
    "formeras": "formera",
    "formerat": "formera",
    "formerats": "formera",
    "formerbara": "formerbar",
    "formerbarare": "formerbar",
    "formerbarares": "formerbar",
    "formerbaras": "formerbar",
    "formerbarast": "formerbar",
    "formerbaraste": "formerbar",
    "formerbarastes": "formerbar",
    "formerbarasts": "formerbar",
    "formerbare": "formerbar",
    "formerbares": "formerbar",
    "formerbarheten": "formerbarhet",
    "formerbarhetens": "formerbarhet",
    "formerbarhets": "formerbarhet",
    "formerbars": "formerbar",
    "formerbart": "formerbar",
    "formerbarts": "formerbar",
    "formeringar": "formering",
    "formeringarna": "formering",
    "formeringarnas": "formering",
    "formeringars": "formering",
    "formeringen": "formering",
    "formeringens": "formering",
    "formerings": "formering",
    "formerna": "form",
    "formernas": "form",
    "formers": "form",
    "formfranskan": "formfranska",
    "formfranskana": "formfranska",
    "formfranskanas": "formfranska",
    "formfranskans": "formfranska",
    "formfranskas": "formfranska",
    "formfranskat": "formfranska",
    "formfranskats": "formfranska",
    "formfranskor": "formfranska",
    "formfranskorna": "formfranska",
    "formfranskornas": "formfranska",
    "formfranskors": "formfranska",
    "formfrågan": "formfråga",
    "formfrågans": "formfråga",
    "formfrågas": "formfråga",
    "formfråge": "formfråga",
    "formfrågor": "formfråga",
    "formfrågorna": "formfråga",
    "formfrågornas": "formfråga",
    "formfrågors": "formfråga",
    "formfulländade": "formfulländad",
    "formfulländades": "formfulländad",
    "formfulländads": "formfulländad",
    "formfulländat": "formfulländad",
    "formfulländats": "formfulländad",
    "formfulländningar": "formfulländning",
    "formfulländningarna": "formfulländning",
    "formfulländningarnas": "formfulländning",
    "formfulländningars": "formfulländning",
    "formfulländningen": "formfulländning",
    "formfulländningens": "formfulländning",
    "formfulländnings": "formfulländning",
    "formgav": "formge",
    "formgavs": "formge",
    "formgeende": "formge",
    "formgeendes": "formge",
    "formger": "formge",
    "formges": "formge",
    "formgett": "formge",
    "formgetts": "formge",
    "formgiv": "formge",
    "formgiva": "formge",
    "formgivande": "formge",
    "formgivanden": "formgivande",
    "formgivandena": "formgivande",
    "formgivandenas": "formgivande",
    "formgivandens": "formgivande",
    "formgivandes": "formgivande",
    "formgivandet": "formgivande",
    "formgivandets": "formgivande",
    "formgivar": "formgivare",
    "formgivaren": "formgivare",
    "formgivarens": "formgivare",
    "formgivares": "formgivare",
    "formgivarna": "formgivare",
    "formgivarnas": "formgivare",
    "formgivas": "formge",
    "formgive": "formge",
    "formgiven": "formge",
    "formgivens": "formge",
    "formgiver": "formge",
    "formgives": "formge",
    "formgivet": "formge",
    "formgivets": "formge",
    "formgivit": "formge",
    "formgivits": "formge",
    "formgivna": "formge",
    "formgivnas": "formge",
    "formgivne": "formge",
    "formgivnes": "formge",
    "formgivningar": "formgivning",
    "formgivningarna": "formgivning",
    "formgivningarnas": "formgivning",
    "formgivningars": "formgivning",
    "formgivningen": "formgivning",
    "formgivningens": "formgivning",
    "formgivnings": "formgivning",
    "formgivs": "formge",
    "formgjut": "formgjuta",
    "formgjutande": "formgjuta",
    "formgjutanden": "formgjutande",
    "formgjutandena": "formgjutande",
    "formgjutandenas": "formgjutande",
    "formgjutandens": "formgjutande",
    "formgjutandes": "formgjutande",
    "formgjutandet": "formgjutande",
    "formgjutandets": "formgjutande",
    "formgjutas": "formgjuta",
    "formgjute": "formgjuta",
    "formgjuten": "formgjuta",
    "formgjutens": "formgjuta",
    "formgjuter": "formgjuta",
    "formgjutes": "formgjuta",
    "formgjutet": "formgjuta",
    "formgjutets": "formgjuta",
    "formgjutit": "formgjuta",
    "formgjutits": "formgjuta",
    "formgjutna": "formgjuta",
    "formgjutnas": "formgjuta",
    "formgjutne": "formgjuta",
    "formgjutnes": "formgjuta",
    "formgjuts": "formgjuta",
    "formgodset": "formgods",
    "formgodsets": "formgods",
    "formgåve": "formge",
    "formgåves": "formge",
    "formgöt": "formgjuta",
    "formgöte": "formgjuta",
    "formgötes": "formgjuta",
    "formgöts": "formgjuta",
    "formidabels": "formidabel",
    "formidabelt": "formidabel",
    "formidabelts": "formidabel",
    "formidabla": "formidabel",
    "formidablare": "formidabel",
    "formidablares": "formidabel",
    "formidablas": "formidabel",
    "formidablast": "formidabel",
    "formidablaste": "formidabel",
    "formidablastes": "formidabel",
    "formidablasts": "formidabel",
    "formidable": "formidabel",
    "formidables": "formidabel",
    "formkurv": "formkurva",
    "formkurvan": "formkurva",
    "formkurvans": "formkurva",
    "formkurvas": "formkurva",
    "formkurve": "formkurva",
    "formkurvor": "formkurva",
    "formkurvorna": "formkurva",
    "formkurvornas": "formkurva",
    "formkurvors": "formkurva",
    "formkurvs": "formkurva",
    "formler": "formel",
    "formlerna": "formel",
    "formlernas": "formel",
    "formlers": "formel",
    "formliga": "formlig",
    "formligare": "formlig",
    "formligares": "formlig",
    "formligas": "formlig",
    "formligast": "formlig",
    "formligaste": "formlig",
    "formligastes": "formlig",
    "formligasts": "formlig",
    "formlige": "formlig",
    "formliges": "formlig",
    "formligs": "formlig",
    "formligt": "formlig",
    "formligts": "formlig",
    "formläran": "formlära",
    "formlärans": "formlära",
    "formläras": "formlära",
    "formläre": "formlära",
    "formläro": "formlära",
    "formläror": "formlära",
    "formlärorna": "formlära",
    "formlärornas": "formlära",
    "formlärors": "formlära",
    "formlösa": "formlös",
    "formlösare": "formlös",
    "formlösares": "formlös",
    "formlösas": "formlös",
    "formlösast": "formlös",
    "formlösaste": "formlös",
    "formlösastes": "formlös",
    "formlösasts": "formlös",
    "formlöse": "formlös",
    "formlöses": "formlös",
    "formlösheten": "formlöshet",
    "formlöshetens": "formlöshet",
    "formlöshets": "formlöshet",
    "formlöst": "formlös",
    "formlösts": "formlös",
    "formmässiga": "formmässig",
    "formmässigare": "formmässig",
    "formmässigares": "formmässig",
    "formmässigas": "formmässig",
    "formmässigast": "formmässig",
    "formmässigaste": "formmässig",
    "formmässigastes": "formmässig",
    "formmässigasts": "formmässig",
    "formmässige": "formmässig",
    "formmässiges": "formmässig",
    "formmässigheten": "formmässighet",
    "formmässighetens": "formmässighet",
    "formmässighets": "formmässighet",
    "formmässigs": "formmässig",
    "formmässigt": "formmässig",
    "formmässigts": "formmässig",
    "formorden": "formord",
    "formordens": "formord",
    "formordet": "formord",
    "formordets": "formord",
    "formords": "formord",
    "formpress": "formpressa",
    "formpressad": "formpressa",
    "formpressade": "formpressa",
    "formpressades": "formpressa",
    "formpressads": "formpressa",
    "formpressande": "formpressa",
    "formpressanden": "formpressande",
    "formpressandena": "formpressande",
    "formpressandenas": "formpressande",
    "formpressandens": "formpressande",
    "formpressandes": "formpressande",
    "formpressandet": "formpressande",
    "formpressandets": "formpressande",
    "formpressar": "formpressa",
    "formpressas": "formpressa",
    "formpressat": "formpressa",
    "formpressats": "formpressa",
    "formpressningar": "formpressning",
    "formpressningarna": "formpressning",
    "formpressningarnas": "formpressning",
    "formpressningars": "formpressning",
    "formpressningen": "formpressning",
    "formpressningens": "formpressning",
    "formpressnings": "formpressning",
    "formrika": "formrik",
    "formrikare": "formrik",
    "formrikares": "formrik",
    "formrikas": "formrik",
    "formrikast": "formrik",
    "formrikaste": "formrik",
    "formrikastes": "formrik",
    "formrikasts": "formrik",
    "formrike": "formrik",
    "formrikedomar": "formrikedom",
    "formrikedomarna": "formrikedom",
    "formrikedomarnas": "formrikedom",
    "formrikedomars": "formrikedom",
    "formrikedomen": "formrikedom",
    "formrikedomens": "formrikedom",
    "formrikedoms": "formrikedom",
    "formrikes": "formrik",
    "formrikheten": "formrikhet",
    "formrikhetens": "formrikhet",
    "formrikhets": "formrikhet",
    "formriks": "formrik",
    "formrikt": "formrik",
    "formrikts": "formrik",
    "forms": "form",
    "formsaken": "formsak",
    "formsakens": "formsak",
    "formsaker": "formsak",
    "formsakerna": "formsak",
    "formsakernas": "formsak",
    "formsakers": "formsak",
    "formsaks": "formsak",
    "formsanden": "formsand",
    "formsandens": "formsand",
    "formsands": "formsand",
    "formspelen": "formspel",
    "formspelens": "formspel",
    "formspelet": "formspel",
    "formspelets": "formspel",
    "formspels": "formspel",
    "formspråken": "formspråk",
    "formspråkens": "formspråk",
    "formspråket": "formspråk",
    "formspråkets": "formspråk",
    "formspråks": "formspråk",
    "formstarka": "formstark",
    "formstarkare": "formstark",
    "formstarkares": "formstark",
    "formstarkas": "formstark",
    "formstarkast": "formstark",
    "formstarkaste": "formstark",
    "formstarkastes": "formstark",
    "formstarkasts": "formstark",
    "formstarke": "formstark",
    "formstarkes": "formstark",
    "formstarks": "formstark",
    "formstarkt": "formstark",
    "formstarkts": "formstark",
    "formsvack": "formsvacka",
    "formsvackan": "formsvacka",
    "formsvackans": "formsvacka",
    "formsvackas": "formsvacka",
    "formsvacke": "formsvacka",
    "formsvackor": "formsvacka",
    "formsvackorna": "formsvacka",
    "formsvackornas": "formsvacka",
    "formsvackors": "formsvacka",
    "formsvacks": "formsvacka",
    "formulan": "formula",
    "formulans": "formula",
    "formulas": "formula",
    "formulerad": "formulera",
    "formulerade": "formulera",
    "formulerades": "formulera",
    "formulerads": "formulera",
    "formulerande": "formulera",
    "formuleranden": "formulerande",
    "formulerandena": "formulerande",
    "formulerandenas": "formulerande",
    "formulerandens": "formulerande",
    "formulerandes": "formulerande",
    "formulerandet": "formulerande",
    "formulerandets": "formulerande",
    "formulerar": "formulera",
    "formuleras": "formulera",
    "formulerat": "formulera",
    "formulerats": "formulera",
    "formulerbara": "formulerbar",
    "formulerbarare": "formulerbar",
    "formulerbarares": "formulerbar",
    "formulerbaras": "formulerbar",
    "formulerbarast": "formulerbar",
    "formulerbaraste": "formulerbar",
    "formulerbarastes": "formulerbar",
    "formulerbarasts": "formulerbar",
    "formulerbare": "formulerbar",
    "formulerbares": "formulerbar",
    "formulerbarheten": "formulerbarhet",
    "formulerbarhetens": "formulerbarhet",
    "formulerbarhets": "formulerbarhet",
    "formulerbars": "formulerbar",
    "formulerbart": "formulerbar",
    "formulerbarts": "formulerbar",
    "formuleringar": "formulering",
    "formuleringarna": "formulering",
    "formuleringarnas": "formulering",
    "formuleringars": "formulering",
    "formuleringen": "formulering",
    "formuleringens": "formulering",
    "formulerings": "formulering",
    "formulären": "formulär",
    "formulärens": "formulär",
    "formuläret": "formulär",
    "formulärets": "formulär",
    "formulärs": "formulär",
    "forna": "forn",
    "fornare": "forn",
    "fornares": "forn",
    "fornas": "forn",
    "fornast": "forn",
    "fornaste": "forn",
    "fornastes": "forn",
    "fornasts": "forn",
    "fornborgar": "fornborg",
    "fornborgarna": "fornborg",
    "fornborgarnas": "fornborg",
    "fornborgars": "fornborg",
    "fornborgen": "fornborg",
    "fornborgens": "fornborg",
    "fornborgs": "fornborg",
    "forne": "forn",
    "fornegyptisk": "fornegyptiska",
    "fornegyptiska": "fornegyptisk",
    "fornegyptiskan": "fornegyptiska",
    "fornegyptiskans": "fornegyptiska",
    "fornegyptiskare": "fornegyptisk",
    "fornegyptiskares": "fornegyptisk",
    "fornegyptiskas": "fornegyptiska",
    "fornegyptiskast": "fornegyptisk",
    "fornegyptiskaste": "fornegyptisk",
    "fornegyptiskastes": "fornegyptisk",
    "fornegyptiskasts": "fornegyptisk",
    "fornegyptiske": "fornegyptisk",
    "fornegyptiskes": "fornegyptisk",
    "fornegyptisks": "fornegyptisk",
    "fornegyptiskt": "fornegyptisk",
    "fornegyptiskts": "fornegyptisk",
    "fornes": "forn",
    "fornfolken": "fornfolk",
    "fornfolkens": "fornfolk",
    "fornfolket": "fornfolk",
    "fornfolkets": "fornfolk",
    "fornfolks": "fornfolk",
    "fornfynden": "fornfynd",
    "fornfyndens": "fornfynd",
    "fornfyndet": "fornfynd",
    "fornfyndets": "fornfynd",
    "fornfynds": "fornfynd",
    "forngrekiska": "forngrekisk",
    "forngrekiskare": "forngrekisk",
    "forngrekiskares": "forngrekisk",
    "forngrekiskas": "forngrekisk",
    "forngrekiskast": "forngrekisk",
    "forngrekiskaste": "forngrekisk",
    "forngrekiskastes": "forngrekisk",
    "forngrekiskasts": "forngrekisk",
    "forngrekiske": "forngrekisk",
    "forngrekiskes": "forngrekisk",
    "forngrekisks": "forngrekisk",
    "forngrekiskt": "forngrekisk",
    "forngrekiskts": "forngrekisk",
    "fornheten": "fornhet",
    "fornhetens": "fornhet",
    "fornhets": "fornhet",
    "fornisländska": "fornisländsk",
    "fornisländskare": "fornisländsk",
    "fornisländskares": "fornisländsk",
    "fornisländskas": "fornisländsk",
    "fornisländskast": "fornisländsk",
    "fornisländskaste": "fornisländsk",
    "fornisländskastes": "fornisländsk",
    "fornisländskasts": "fornisländsk",
    "fornisländske": "fornisländsk",
    "fornisländskes": "fornisländsk",
    "fornisländsks": "fornisländsk",
    "fornisländskt": "fornisländsk",
    "fornisländskts": "fornisländsk",
    "fornitalienska": "fornitaliensk",
    "fornitalienskare": "fornitaliensk",
    "fornitalienskares": "fornitaliensk",
    "fornitalienskas": "fornitaliensk",
    "fornitalienskast": "fornitaliensk",
    "fornitalienskaste": "fornitaliensk",
    "fornitalienskastes": "fornitaliensk",
    "fornitalienskasts": "fornitaliensk",
    "fornitalienske": "fornitaliensk",
    "fornitalienskes": "fornitaliensk",
    "fornitaliensks": "fornitaliensk",
    "fornitalienskt": "fornitaliensk",
    "fornitalienskts": "fornitaliensk",
    "fornkeltiska": "fornkeltisk",
    "fornkeltiskare": "fornkeltisk",
    "fornkeltiskares": "fornkeltisk",
    "fornkeltiskas": "fornkeltisk",
    "fornkeltiskast": "fornkeltisk",
    "fornkeltiskaste": "fornkeltisk",
    "fornkeltiskastes": "fornkeltisk",
    "fornkeltiskasts": "fornkeltisk",
    "fornkeltiske": "fornkeltisk",
    "fornkeltiskes": "fornkeltisk",
    "fornkeltisks": "fornkeltisk",
    "fornkeltiskt": "fornkeltisk",
    "fornkeltiskts": "fornkeltisk",
    "fornkunskapen": "fornkunskap",
    "fornkunskapens": "fornkunskap",
    "fornkunskaps": "fornkunskap",
    "fornlämningar": "fornlämning",
    "fornlämningarna": "fornlämning",
    "fornlämningarnas": "fornlämning",
    "fornlämningars": "fornlämning",
    "fornlämningen": "fornlämning",
    "fornlämningens": "fornlämning",
    "fornlämnings": "fornlämning",
    "fornminnen": "fornminne",
    "fornminnena": "fornminne",
    "fornminnenas": "fornminne",
    "fornminnens": "fornminne",
    "fornminnes": "fornminne",
    "fornminnessamlingar": "fornminnessamling",
    "fornminnessamlingarna": "fornminnessamling",
    "fornminnessamlingarnas": "fornminnessamling",
    "fornminnessamlingars": "fornminnessamling",
    "fornminnessamlingen": "fornminnessamling",
    "fornminnessamlingens": "fornminnessamling",
    "fornminnessamlings": "fornminnessamling",
    "fornminnesskyltar": "fornminnesskylt",
    "fornminnesskyltarna": "fornminnesskylt",
    "fornminnesskyltarnas": "fornminnesskylt",
    "fornminnesskyltars": "fornminnesskylt",
    "fornminnesskylten": "fornminnesskylt",
    "fornminnesskyltens": "fornminnesskylt",
    "fornminnesskylts": "fornminnesskylt",
    "fornminnet": "fornminne",
    "fornminnets": "fornminne",
    "fornnordiska": "fornnordisk",
    "fornnordiskare": "fornnordisk",
    "fornnordiskares": "fornnordisk",
    "fornnordiskas": "fornnordisk",
    "fornnordiskast": "fornnordisk",
    "fornnordiskaste": "fornnordisk",
    "fornnordiskastes": "fornnordisk",
    "fornnordiskasts": "fornnordisk",
    "fornnordiske": "fornnordisk",
    "fornnordiskes": "fornnordisk",
    "fornnordisks": "fornnordisk",
    "fornnordiskt": "fornnordisk",
    "fornnordiskts": "fornnordisk",
    "fornromerska": "fornromersk",
    "fornromerskare": "fornromersk",
    "fornromerskares": "fornromersk",
    "fornromerskas": "fornromersk",
    "fornromerskast": "fornromersk",
    "fornromerskaste": "fornromersk",
    "fornromerskastes": "fornromersk",
    "fornromerskasts": "fornromersk",
    "fornromerske": "fornromersk",
    "fornromerskes": "fornromersk",
    "fornromersks": "fornromersk",
    "fornromerskt": "fornromersk",
    "fornromerskts": "fornromersk",
    "forns": "forn",
    "fornsvenska": "fornsvensk",
    "fornsvenskare": "fornsvensk",
    "fornsvenskares": "fornsvensk",
    "fornsvenskas": "fornsvensk",
    "fornsvenskast": "fornsvensk",
    "fornsvenskaste": "fornsvensk",
    "fornsvenskastes": "fornsvensk",
    "fornsvenskasts": "fornsvensk",
    "fornsvenske": "fornsvensk",
    "fornsvenskes": "fornsvensk",
    "fornsvensks": "fornsvensk",
    "fornsvenskt": "fornsvensk",
    "fornsvenskts": "fornsvensk",
    "fornt": "forn",
    "forntiden": "forntid",
    "forntidens": "forntid",
    "forntider": "forntid",
    "forntiderna": "forntid",
    "forntidernas": "forntid",
    "forntiders": "forntid",
    "forntids": "forntid",
    "fornts": "forn",
    "fornyrdislaget": "fornyrdislag",
    "fornyrdislagets": "fornyrdislag",
    "fornyrdislags": "fornyrdislag",
    "foror": "fora",
    "fororna": "fora",
    "forornas": "fora",
    "forors": "fora",
    "fors": "forsa",
    "forsade": "forsa",
    "forsades": "forsa",
    "forsande": "forsa",
    "forsanden": "forsande",
    "forsandena": "forsande",
    "forsandenas": "forsande",
    "forsandens": "forsande",
    "forsandes": "forsande",
    "forsandet": "forsande",
    "forsandets": "forsande",
    "forsar": "forsa",
    "forsarna": "fors",
    "forsarnas": "fors",
    "forsars": "fors",
    "forsas": "forsa",
    "forsat": "forsa",
    "forsats": "forsa",
    "forsen": "fors",
    "forsens": "fors",
    "forshuvuden": "forshuvud",
    "forshuvudena": "forshuvud",
    "forshuvudenas": "forshuvud",
    "forshuvudens": "forshuvud",
    "forshuvudet": "forshuvud",
    "forshuvudets": "forshuvud",
    "forshuvuds": "forshuvud",
    "forsk": "forska",
    "forskade": "forska",
    "forskades": "forska",
    "forskande": "forska",
    "forskanden": "forskande",
    "forskandena": "forskande",
    "forskandenas": "forskande",
    "forskandens": "forskande",
    "forskandes": "forskande",
    "forskandet": "forskande",
    "forskandets": "forskande",
    "forskar": "forskare",
    "forskarassistenten": "forskarassistent",
    "forskarassistentens": "forskarassistent",
    "forskarassistenter": "forskarassistent",
    "forskarassistenterna": "forskarassistent",
    "forskarassistenternas": "forskarassistent",
    "forskarassistenters": "forskarassistent",
    "forskarassistents": "forskarassistent",
    "forskaren": "forskare",
    "forskarens": "forskare",
    "forskares": "forskare",
    "forskargruppen": "forskargrupp",
    "forskargruppens": "forskargrupp",
    "forskargrupper": "forskargrupp",
    "forskargrupperna": "forskargrupp",
    "forskargruppernas": "forskargrupp",
    "forskargruppers": "forskargrupp",
    "forskargrupps": "forskargrupp",
    "forskarkonspirationen": "forskarkonspiration",
    "forskarkonspirationens": "forskarkonspiration",
    "forskarkonspirationer": "forskarkonspiration",
    "forskarkonspirationerna": "forskarkonspiration",
    "forskarkonspirationernas": "forskarkonspiration",
    "forskarkonspirationers": "forskarkonspiration",
    "forskarkonspirations": "forskarkonspiration",
    "forskarlagen": "forskarlag",
    "forskarlagens": "forskarlag",
    "forskarlaget": "forskarlag",
    "forskarlagets": "forskarlag",
    "forskarlags": "forskarlag",
    "forskarledigheten": "forskarledighet",
    "forskarledighetens": "forskarledighet",
    "forskarledigheter": "forskarledighet",
    "forskarledigheterna": "forskarledighet",
    "forskarledigheternas": "forskarledighet",
    "forskarledigheters": "forskarledighet",
    "forskarledighets": "forskarledighet",
    "forskarmässiga": "forskarmässig",
    "forskarmässigare": "forskarmässig",
    "forskarmässigares": "forskarmässig",
    "forskarmässigas": "forskarmässig",
    "forskarmässigast": "forskarmässig",
    "forskarmässigaste": "forskarmässig",
    "forskarmässigastes": "forskarmässig",
    "forskarmässigasts": "forskarmässig",
    "forskarmässige": "forskarmässig",
    "forskarmässiges": "forskarmässig",
    "forskarmässigs": "forskarmässig",
    "forskarmässigt": "forskarmässig",
    "forskarmässigts": "forskarmässig",
    "forskarna": "forskare",
    "forskarnas": "forskare",
    "forskarutbildningar": "forskarutbildning",
    "forskarutbildningarna": "forskarutbildning",
    "forskarutbildningarnas": "forskarutbildning",
    "forskarutbildningars": "forskarutbildning",
    "forskarutbildningen": "forskarutbildning",
    "forskarutbildningens": "forskarutbildning",
    "forskarutbildnings": "forskarutbildning",
    "forskarvärlden": "forskarvärld",
    "forskarvärldens": "forskarvärld",
    "forskarvärlds": "forskarvärld",
    "forskas": "forska",
    "forskat": "forska",
    "forskats": "forska",
    "forskningar": "forskning",
    "forskningarna": "forskning",
    "forskningarnas": "forskning",
    "forskningars": "forskning",
    "forskningen": "forskning",
    "forskningens": "forskning",
    "forsknings": "forskning",
    "forskningsarbeten": "forskningsarbete",
    "forskningsarbetena": "forskningsarbete",
    "forskningsarbetenas": "forskningsarbete",
    "forskningsarbetens": "forskningsarbete",
    "forskningsarbetes": "forskningsarbete",
    "forskningsarbetet": "forskningsarbete",
    "forskningsarbetets": "forskningsarbete",
    "forskningsarbets": "forskningsarbete",
    "forskningscenters": "forskningscenter",
    "forskningscentrer": "forskningscenter",
    "forskningscentrerna": "forskningscenter",
    "forskningscentrernas": "forskningscenter",
    "forskningscentrers": "forskningscenter",
    "forskningscentret": "forskningscenter",
    "forskningscentrets": "forskningscenter",
    "forskningsfartygen": "forskningsfartyg",
    "forskningsfartygens": "forskningsfartyg",
    "forskningsfartyget": "forskningsfartyg",
    "forskningsfartygets": "forskningsfartyg",
    "forskningsfartygs": "forskningsfartyg",
    "forskningsfinansieringar": "forskningsfinansiering",
    "forskningsfinansieringarna": "forskningsfinansiering",
    "forskningsfinansieringarnas": "forskningsfinansiering",
    "forskningsfinansieringars": "forskningsfinansiering",
    "forskningsfinansieringen": "forskningsfinansiering",
    "forskningsfinansieringens": "forskningsfinansiering",
    "forskningsfinansierings": "forskningsfinansiering",
    "forskningsframstegen": "forskningsframsteg",
    "forskningsframstegens": "forskningsframsteg",
    "forskningsframsteget": "forskningsframsteg",
    "forskningsframstegets": "forskningsframsteg",
    "forskningsframstegs": "forskningsframsteg",
    "forskningsfälten": "forskningsfält",
    "forskningsfältens": "forskningsfält",
    "forskningsfältet": "forskningsfält",
    "forskningsfältets": "forskningsfält",
    "forskningsfälts": "forskningsfält",
    "forskningsfärden": "forskningsfärd",
    "forskningsfärdens": "forskningsfärd",
    "forskningsfärder": "forskningsfärd",
    "forskningsfärderna": "forskningsfärd",
    "forskningsfärdernas": "forskningsfärd",
    "forskningsfärders": "forskningsfärd",
    "forskningsfärds": "forskningsfärd",
    "forskningsfäst": "forskningsfäste",
    "forskningsfästen": "forskningsfäste",
    "forskningsfästena": "forskningsfäste",
    "forskningsfästenas": "forskningsfäste",
    "forskningsfästens": "forskningsfäste",
    "forskningsfästes": "forskningsfäste",
    "forskningsfästet": "forskningsfäste",
    "forskningsfästets": "forskningsfäste",
    "forskningsingenjören": "forskningsingenjör",
    "forskningsingenjörens": "forskningsingenjör",
    "forskningsingenjörer": "forskningsingenjör",
    "forskningsingenjörerna": "forskningsingenjör",
    "forskningsingenjörernas": "forskningsingenjör",
    "forskningsingenjörers": "forskningsingenjör",
    "forskningsingenjörn": "forskningsingenjör",
    "forskningsingenjörns": "forskningsingenjör",
    "forskningsingenjörs": "forskningsingenjör",
    "forskningsinriktningar": "forskningsinriktning",
    "forskningsinriktningarna": "forskningsinriktning",
    "forskningsinriktningarnas": "forskningsinriktning",
    "forskningsinriktningars": "forskningsinriktning",
    "forskningsinriktningen": "forskningsinriktning",
    "forskningsinriktningens": "forskningsinriktning",
    "forskningsinriktnings": "forskningsinriktning",
    "forskningsinsatsen": "forskningsinsats",
    "forskningsinsatsens": "forskningsinsats",
    "forskningsinsatser": "forskningsinsats",
    "forskningsinsatserna": "forskningsinsats",
    "forskningsinsatsernas": "forskningsinsats",
    "forskningsinsatsers": "forskningsinsats",
    "forskningsinstituten": "forskningsinstitut",
    "forskningsinstitutens": "forskningsinstitut",
    "forskningsinstitutet": "forskningsinstitut",
    "forskningsinstitutets": "forskningsinstitut",
    "forskningsinstituts": "forskningsinstitut",
    "forskningskompetensen": "forskningskompetens",
    "forskningskompetensens": "forskningskompetens",
    "forskningskompetenser": "forskningskompetens",
    "forskningskompetenserna": "forskningskompetens",
    "forskningskompetensernas": "forskningskompetens",
    "forskningskompetensers": "forskningskompetens",
    "forskningslaboratorie": "forskningslaboratorium",
    "forskningslaboratorier": "forskningslaboratorium",
    "forskningslaboratorierna": "forskningslaboratorium",
    "forskningslaboratoriernas": "forskningslaboratorium",
    "forskningslaboratoriers": "forskningslaboratorium",
    "forskningslaboratoriet": "forskningslaboratorium",
    "forskningslaboratoriets": "forskningslaboratorium",
    "forskningslaboratoriums": "forskningslaboratorium",
    "forskningsmiljöer": "forskningsmiljö",
    "forskningsmiljöerna": "forskningsmiljö",
    "forskningsmiljöernas": "forskningsmiljö",
    "forskningsmiljöers": "forskningsmiljö",
    "forskningsmiljön": "forskningsmiljö",
    "forskningsmiljöns": "forskningsmiljö",
    "forskningsmiljös": "forskningsmiljö",
    "forskningsmässiga": "forskningsmässig",
    "forskningsmässigare": "forskningsmässig",
    "forskningsmässigares": "forskningsmässig",
    "forskningsmässigas": "forskningsmässig",
    "forskningsmässigast": "forskningsmässig",
    "forskningsmässigaste": "forskningsmässig",
    "forskningsmässigastes": "forskningsmässig",
    "forskningsmässigasts": "forskningsmässig",
    "forskningsmässige": "forskningsmässig",
    "forskningsmässiges": "forskningsmässig",
    "forskningsmässigs": "forskningsmässig",
    "forskningsmässigt": "forskningsmässig",
    "forskningsmässigts": "forskningsmässig",
    "forskningsområden": "forskningsområde",
    "forskningsområdena": "forskningsområde",
    "forskningsområdenas": "forskningsområde",
    "forskningsområdens": "forskningsområde",
    "forskningsområdes": "forskningsområde",
    "forskningsområdet": "forskningsområde",
    "forskningsområdets": "forskningsområde",
    "forskningsorganisationen": "forskningsorganisation",
    "forskningsorganisationens": "forskningsorganisation",
    "forskningsorganisationer": "forskningsorganisation",
    "forskningsorganisationerna": "forskningsorganisation",
    "forskningsorganisationernas": "forskningsorganisation",
    "forskningsorganisationers": "forskningsorganisation",
    "forskningsorganisations": "forskningsorganisation",
    "forskningspolitiken": "forskningspolitik",
    "forskningspolitikens": "forskningspolitik",
    "forskningspolitiks": "forskningspolitik",
    "forskningspolitiska": "forskningspolitisk",
    "forskningspolitiskas": "forskningspolitisk",
    "forskningspolitiske": "forskningspolitisk",
    "forskningspolitiskes": "forskningspolitisk",
    "forskningspolitisks": "forskningspolitisk",
    "forskningspolitiskt": "forskningspolitisk",
    "forskningspolitiskts": "forskningspolitisk",
    "forskningsprojekten": "forskningsprojekt",
    "forskningsprojektens": "forskningsprojekt",
    "forskningsprojektet": "forskningsprojekt",
    "forskningsprojektets": "forskningsprojekt",
    "forskningsprojekts": "forskningsprojekt",
    "forskningsresanden": "forskningsresande",
    "forskningsresandena": "forskningsresande",
    "forskningsresandenas": "forskningsresande",
    "forskningsresandens": "forskningsresande",
    "forskningsresandes": "forskningsresande",
    "forskningsresultaten": "forskningsresultat",
    "forskningsresultatens": "forskningsresultat",
    "forskningsresultatet": "forskningsresultat",
    "forskningsresultatets": "forskningsresultat",
    "forskningsresultats": "forskningsresultat",
    "forskningsråden": "forskningsråd",
    "forskningsrådens": "forskningsråd",
    "forskningsrådet": "forskningsråd",
    "forskningsrådets": "forskningsråd",
    "forskningsråds": "forskningsråd",
    "forskningsrönen": "forskningsrön",
    "forskningsrönens": "forskningsrön",
    "forskningsrönet": "forskningsrön",
    "forskningsrönets": "forskningsrön",
    "forskningsröns": "forskningsrön",
    "forskningsstationen": "forskningsstation",
    "forskningsstationens": "forskningsstation",
    "forskningsstationer": "forskningsstation",
    "forskningsstationerna": "forskningsstation",
    "forskningsstationernas": "forskningsstation",
    "forskningsstationers": "forskningsstation",
    "forskningsstations": "forskningsstation",
    "forskningssyften": "forskningssyfte",
    "forskningssyftena": "forskningssyfte",
    "forskningssyftenas": "forskningssyfte",
    "forskningssyftens": "forskningssyfte",
    "forskningssyftes": "forskningssyfte",
    "forskningssyftet": "forskningssyfte",
    "forskningssyftets": "forskningssyfte",
    "forskningssyfts": "forskningssyfte",
    "forslad": "forsla",
    "forslade": "forsla",
    "forslades": "forsla",
    "forslads": "forsla",
    "forslande": "forsla",
    "forslanden": "forslande",
    "forslandena": "forslande",
    "forslandenas": "forslande",
    "forslandens": "forslande",
    "forslandes": "forslande",
    "forslandet": "forslande",
    "forslandets": "forslande",
    "forslar": "forsla",
    "forslas": "forsla",
    "forslat": "forsla",
    "forslats": "forsla",
    "forsränningar": "forsränning",
    "forsränningarna": "forsränning",
    "forsränningarnas": "forsränning",
    "forsränningars": "forsränning",
    "forsränningen": "forsränning",
    "forsränningens": "forsränning",
    "forsrännings": "forsränning",
    "forstväsendet": "forstväsen",
    "forstväsendets": "forstväsen",
    "forstväsenet": "forstväsen",
    "forstväsenets": "forstväsen",
    "forstväsens": "forstväsen",
    "forsythi": "forsythia",
    "forsythian": "forsythia",
    "forsythians": "forsythia",
    "forsythias": "forsythia",
    "forsythie": "forsythia",
    "forsythior": "forsythia",
    "forsythiorna": "forsythia",
    "forsythiornas": "forsythia",
    "forsythiors": "forsythia",
    "forsythis": "forsythia",
    "fortare": "fort",
    "fortast": "fort",
    "fortbestod": "fortbestå",
    "fortbestode": "fortbestå",
    "fortbestodes": "fortbestå",
    "fortbestods": "fortbestå",
    "fortbestående": "fortbestå",
    "fortbeståenden": "fortbestående",
    "fortbeståendena": "fortbestående",
    "fortbeståendenas": "fortbestående",
    "fortbeståendens": "fortbestående",
    "fortbeståendes": "fortbestående",
    "fortbeståendet": "fortbestående",
    "fortbeståendets": "fortbestående",
    "fortbeståndet": "fortbestånd",
    "fortbeståndets": "fortbestånd",
    "fortbestånds": "fortbestånd",
    "fortbestår": "fortbestå",
    "fortbestås": "fortbestå",
    "fortbestått": "fortbestå",
    "fortbeståtts": "fortbestå",
    "fortbildningar": "fortbildning",
    "fortbildningarna": "fortbildning",
    "fortbildningarnas": "fortbildning",
    "fortbildningars": "fortbildning",
    "fortbildningen": "fortbildning",
    "fortbildningens": "fortbildning",
    "fortbildnings": "fortbildning",
    "forteln": "fortel",
    "fortelns": "fortel",
    "fortels": "fortel",
    "forten": "forte",
    "fortena": "forte",
    "fortenas": "forte",
    "fortens": "forte",
    "fortepianon": "fortepiano",
    "fortepianona": "fortepiano",
    "fortepianonas": "fortepiano",
    "fortepianons": "fortepiano",
    "fortepianos": "fortepiano",
    "fortepianot": "fortepiano",
    "fortepianots": "fortepiano",
    "fortes": "forte",
    "fortet": "forte",
    "fortets": "forte",
    "fortfar": "fortfara",
    "fortfarande": "fortfara",
    "fortfaranden": "fortfarande",
    "fortfarandena": "fortfarande",
    "fortfarandenas": "fortfarande",
    "fortfarandens": "fortfarande",
    "fortfarandes": "fortfarande",
    "fortfarandet": "fortfarande",
    "fortfarandets": "fortfarande",
    "fortfaras": "fortfara",
    "fortfare": "fortfara",
    "fortfares": "fortfara",
    "fortfarit": "fortfara",
    "fortfarits": "fortfara",
    "fortfars": "fortfara",
    "fortfor": "fortfara",
    "fortfore": "fortfara",
    "fortfores": "fortfara",
    "fortfors": "fortfara",
    "fortfärdiga": "fortfärdig",
    "fortfärdigare": "fortfärdig",
    "fortfärdigares": "fortfärdig",
    "fortfärdigas": "fortfärdig",
    "fortfärdigast": "fortfärdig",
    "fortfärdigaste": "fortfärdig",
    "fortfärdigastes": "fortfärdig",
    "fortfärdigasts": "fortfärdig",
    "fortfärdige": "fortfärdig",
    "fortfärdiges": "fortfärdig",
    "fortfärdigs": "fortfärdig",
    "fortfärdigt": "fortfärdig",
    "fortfärdigts": "fortfärdig",
    "fortgick": "fortgå",
    "fortgicks": "fortgå",
    "fortginge": "fortgå",
    "fortginges": "fortgå",
    "fortgående": "fortgå",
    "fortgåenden": "fortgående",
    "fortgåendena": "fortgående",
    "fortgåendenas": "fortgående",
    "fortgåendens": "fortgående",
    "fortgåendes": "fortgående",
    "fortgåendet": "fortgående",
    "fortgåendets": "fortgående",
    "fortgår": "fortgå",
    "fortgås": "fortgå",
    "fortgått": "fortgå",
    "fortgåtts": "fortgå",
    "fortifikationen": "fortifikation",
    "fortifikationens": "fortifikation",
    "fortifikationer": "fortifikation",
    "fortifikationerna": "fortifikation",
    "fortifikationernas": "fortifikation",
    "fortifikationers": "fortifikation",
    "fortifikations": "fortifikation",
    "fortifikationsförvaltningar": "fortifikationsförvaltning",
    "fortifikationsförvaltningarna": "fortifikationsförvaltning",
    "fortifikationsförvaltningarnas": "fortifikationsförvaltning",
    "fortifikationsförvaltningars": "fortifikationsförvaltning",
    "fortifikationsförvaltningen": "fortifikationsförvaltning",
    "fortifikationsförvaltningens": "fortifikationsförvaltning",
    "fortifikationsförvaltnings": "fortifikationsförvaltning",
    "fortifikationskåren": "fortifikationskår",
    "fortifikationskårens": "fortifikationskår",
    "fortifikationskårer": "fortifikationskår",
    "fortifikationskårerna": "fortifikationskår",
    "fortifikationskårernas": "fortifikationskår",
    "fortifikationskårers": "fortifikationskår",
    "fortifikationskårs": "fortifikationskår",
    "fortissimon": "fortissimo",
    "fortissimona": "fortissimo",
    "fortissimonas": "fortissimo",
    "fortissimons": "fortissimo",
    "fortissimos": "fortissimo",
    "fortissimot": "fortissimo",
    "fortissimots": "fortissimo",
    "fortkomsten": "fortkomst",
    "fortkomstens": "fortkomst",
    "fortkomster": "fortkomst",
    "fortkomsterna": "fortkomst",
    "fortkomsternas": "fortkomst",
    "fortkomsters": "fortkomst",
    "fortkomsts": "fortkomst",
    "fortkörningar": "fortkörning",
    "fortkörningarna": "fortkörning",
    "fortkörningarnas": "fortkörning",
    "fortkörningars": "fortkörning",
    "fortkörningen": "fortkörning",
    "fortkörningens": "fortkörning",
    "fortkörnings": "fortkörning",
    "fortlar": "fortel",
    "fortlarna": "fortel",
    "fortlarnas": "fortel",
    "fortlars": "fortel",
    "fortlev": "fortleva",
    "fortlevande": "fortleva",
    "fortlevanden": "fortlevande",
    "fortlevandena": "fortlevande",
    "fortlevandenas": "fortlevande",
    "fortlevandens": "fortlevande",
    "fortlevandes": "fortlevande",
    "fortlevandet": "fortlevande",
    "fortlevandets": "fortlevande",
    "fortlevas": "fortleva",
    "fortlevat": "fortleva",
    "fortlevats": "fortleva",
    "fortlevd": "fortleva",
    "fortlevda": "fortleva",
    "fortlevdas": "fortleva",
    "fortlevde": "fortleva",
    "fortlevdes": "fortleva",
    "fortlevds": "fortleva",
    "fortlever": "fortleva",
    "fortleves": "fortleva",
    "fortlevs": "fortleva",
    "fortlevt": "fortleva",
    "fortlevts": "fortleva",
    "fortlöp": "fortlöpa",
    "fortlöpande": "fortlöpa",
    "fortlöpanden": "fortlöpande",
    "fortlöpandena": "fortlöpande",
    "fortlöpandenas": "fortlöpande",
    "fortlöpandens": "fortlöpande",
    "fortlöpandes": "fortlöpande",
    "fortlöpandet": "fortlöpande",
    "fortlöpandets": "fortlöpande",
    "fortlöpas": "fortlöpa",
    "fortlöper": "fortlöpa",
    "fortlöpes": "fortlöpa",
    "fortlöps": "fortlöpa",
    "fortlöpt": "fortlöpa",
    "fortlöpte": "fortlöpa",
    "fortlöptes": "fortlöpa",
    "fortlöpts": "fortlöpa",
    "fortplantningar": "fortplantning",
    "fortplantningarna": "fortplantning",
    "fortplantningarnas": "fortplantning",
    "fortplantningars": "fortplantning",
    "fortplantningen": "fortplantning",
    "fortplantningens": "fortplantning",
    "fortplantnings": "fortplantning",
    "fortplantningsdriften": "fortplantningsdrift",
    "fortplantningsdriftens": "fortplantningsdrift",
    "fortplantningsdrifter": "fortplantningsdrift",
    "fortplantningsdrifterna": "fortplantningsdrift",
    "fortplantningsdrifternas": "fortplantningsdrift",
    "fortplantningsdrifters": "fortplantningsdrift",
    "fortplantningsdrifts": "fortplantningsdrift",
    "fortplantningsförmågan": "fortplantningsförmåga",
    "fortplantningsförmågans": "fortplantningsförmåga",
    "fortplantningsförmågas": "fortplantningsförmåga",
    "fortplantningsförmåge": "fortplantningsförmåga",
    "fortplantningsförmågor": "fortplantningsförmåga",
    "fortplantningsförmågorna": "fortplantningsförmåga",
    "fortplantningsförmågornas": "fortplantningsförmåga",
    "fortplantningsförmågors": "fortplantningsförmåga",
    "fortplantningsmässiga": "fortplantningsmässig",
    "fortplantningsmässigare": "fortplantningsmässig",
    "fortplantningsmässigares": "fortplantningsmässig",
    "fortplantningsmässigas": "fortplantningsmässig",
    "fortplantningsmässigast": "fortplantningsmässig",
    "fortplantningsmässigaste": "fortplantningsmässig",
    "fortplantningsmässigastes": "fortplantningsmässig",
    "fortplantningsmässigasts": "fortplantningsmässig",
    "fortplantningsmässige": "fortplantningsmässig",
    "fortplantningsmässiges": "fortplantningsmässig",
    "fortplantningsmässigs": "fortplantningsmässig",
    "fortplantningsmässigt": "fortplantningsmässig",
    "fortplantningsmässigts": "fortplantningsmässig",
    "fortplantningsorganen": "fortplantningsorgan",
    "fortplantningsorganens": "fortplantningsorgan",
    "fortplantningsorganet": "fortplantningsorgan",
    "fortplantningsorganets": "fortplantningsorgan",
    "fortplantningsorgans": "fortplantningsorgan",
    "fortrans": "fortran",
    "forts": "fort",
    "fortsatt": "fortsätta",
    "fortsatta": "fortsätta",
    "fortsattas": "fortsätta",
    "fortsatte": "fortsätta",
    "fortsattes": "fortsätta",
    "fortsatts": "fortsätta",
    "fortskaffningsmedels": "fortskaffningsmedel",
    "fortskaffningsmedlen": "fortskaffningsmedel",
    "fortskaffningsmedlens": "fortskaffningsmedel",
    "fortskaffningsmedlet": "fortskaffningsmedel",
    "fortskaffningsmedlets": "fortskaffningsmedel",
    "fortskred": "fortskrida",
    "fortskreds": "fortskrida",
    "fortskrid": "fortskrida",
    "fortskridande": "fortskrida",
    "fortskridanden": "fortskridande",
    "fortskridandena": "fortskridande",
    "fortskridandenas": "fortskridande",
    "fortskridandens": "fortskridande",
    "fortskridandes": "fortskridande",
    "fortskridandet": "fortskridande",
    "fortskridandets": "fortskridande",
    "fortskridas": "fortskrida",
    "fortskride": "fortskrida",
    "fortskriden": "fortskrida",
    "fortskridens": "fortskrida",
    "fortskrider": "fortskrida",
    "fortskrides": "fortskrida",
    "fortskridet": "fortskrida",
    "fortskridets": "fortskrida",
    "fortskridit": "fortskrida",
    "fortskridits": "fortskrida",
    "fortskridna": "fortskrida",
    "fortskridnas": "fortskrida",
    "fortskridne": "fortskrida",
    "fortskridnes": "fortskrida",
    "fortskrids": "fortskrida",
    "fortsätt": "fortsätta",
    "fortsättande": "fortsätta",
    "fortsättanden": "fortsättande",
    "fortsättandena": "fortsättande",
    "fortsättandenas": "fortsättande",
    "fortsättandens": "fortsättande",
    "fortsättandes": "fortsättande",
    "fortsättandet": "fortsättande",
    "fortsättandets": "fortsättande",
    "fortsättas": "fortsätta",
    "fortsätter": "fortsätta",
    "fortsättes": "fortsätta",
    "fortsättningar": "fortsättning",
    "fortsättningarna": "fortsättning",
    "fortsättningarnas": "fortsättning",
    "fortsättningars": "fortsättning",
    "fortsättningen": "fortsättning",
    "fortsättningens": "fortsättning",
    "fortsättnings": "fortsättning",
    "fortsättningskriget": "fortsättningskrig",
    "fortsättningskrigets": "fortsättningskrig",
    "fortsättningskrigs": "fortsättningskrig",
    "fortsättningsskolan": "fortsättningsskola",
    "fortsättningsskolans": "fortsättningsskola",
    "fortsättningsskolas": "fortsättningsskola",
    "fortsättningsskole": "fortsättningsskola",
    "fortsättningsskolor": "fortsättningsskola",
    "fortsättningsskolorna": "fortsättningsskola",
    "fortsättningsskolornas": "fortsättningsskola",
    "fortsättningsskolors": "fortsättningsskola",
    "fortsätts": "fortsätta",
    "fortvaron": "fortvaro",
    "fortvarons": "fortvaro",
    "fortvaros": "fortvaro",
    "forumen": "forum",
    "forumens": "forum",
    "forumet": "forum",
    "forumets": "forum",
    "forums": "forum",
    "forumtidningar": "forumtidning",
    "forumtidningarna": "forumtidning",
    "forumtidningarnas": "forumtidning",
    "forumtidningars": "forumtidning",
    "forumtidningen": "forumtidning",
    "forumtidningens": "forumtidning",
    "forumtidnings": "forumtidning",
    "forwardar": "forward",
    "forwardarna": "forward",
    "forwardarnas": "forward",
    "forwardars": "forward",
    "forwarden": "forward",
    "forwardens": "forward",
    "forwards": "forward",
    "forwardsarna": "forward",
    "forwardsarnas": "forward",
    "forwardsen": "forward",
    "forwardsens": "forward",
    "fosfaten": "fosfat",
    "fosfatens": "fosfat",
    "fosfater": "fosfat",
    "fosfaterad": "fosfatera",
    "fosfaterade": "fosfatera",
    "fosfaterades": "fosfatera",
    "fosfaterads": "fosfatera",
    "fosfaterande": "fosfatera",
    "fosfateranden": "fosfaterande",
    "fosfaterandena": "fosfaterande",
    "fosfaterandenas": "fosfaterande",
    "fosfaterandens": "fosfaterande",
    "fosfaterandes": "fosfaterande",
    "fosfaterandet": "fosfaterande",
    "fosfaterandets": "fosfaterande",
    "fosfaterar": "fosfatera",
    "fosfateras": "fosfatera",
    "fosfaterat": "fosfatera",
    "fosfaterats": "fosfatera",
    "fosfaterbara": "fosfaterbar",
    "fosfaterbarare": "fosfaterbar",
    "fosfaterbarares": "fosfaterbar",
    "fosfaterbaras": "fosfaterbar",
    "fosfaterbarast": "fosfaterbar",
    "fosfaterbaraste": "fosfaterbar",
    "fosfaterbarastes": "fosfaterbar",
    "fosfaterbarasts": "fosfaterbar",
    "fosfaterbare": "fosfaterbar",
    "fosfaterbares": "fosfaterbar",
    "fosfaterbarheten": "fosfaterbarhet",
    "fosfaterbarhetens": "fosfaterbarhet",
    "fosfaterbarhets": "fosfaterbarhet",
    "fosfaterbars": "fosfaterbar",
    "fosfaterbart": "fosfaterbar",
    "fosfaterbarts": "fosfaterbar",
    "fosfateringar": "fosfatering",
    "fosfateringarna": "fosfatering",
    "fosfateringarnas": "fosfatering",
    "fosfateringars": "fosfatering",
    "fosfateringen": "fosfatering",
    "fosfateringens": "fosfatering",
    "fosfaterings": "fosfatering",
    "fosfaterna": "fosfat",
    "fosfaternas": "fosfat",
    "fosfaters": "fosfat",
    "fosfatet": "fosfat",
    "fosfatets": "fosfat",
    "fosfats": "fosfat",
    "fosforescensen": "fosforescens",
    "fosforescensens": "fosforescens",
    "fosforescenta": "fosforescent",
    "fosforescentare": "fosforescent",
    "fosforescentares": "fosforescent",
    "fosforescentas": "fosforescent",
    "fosforescentast": "fosforescent",
    "fosforescentaste": "fosforescent",
    "fosforescentastes": "fosforescent",
    "fosforescentasts": "fosforescent",
    "fosforescente": "fosforescent",
    "fosforescentes": "fosforescent",
    "fosforescents": "fosforescent",
    "fosforescerade": "fosforescera",
    "fosforescerades": "fosforescera",
    "fosforescerande": "fosforescera",
    "fosforesceranden": "fosforescerande",
    "fosforescerandena": "fosforescerande",
    "fosforescerandenas": "fosforescerande",
    "fosforescerandens": "fosforescerande",
    "fosforescerandes": "fosforescerande",
    "fosforescerandet": "fosforescerande",
    "fosforescerandets": "fosforescerande",
    "fosforescerar": "fosforescera",
    "fosforesceras": "fosforescera",
    "fosforescerat": "fosforescera",
    "fosforescerats": "fosforescera",
    "fosforesceringar": "fosforescering",
    "fosforesceringarna": "fosforescering",
    "fosforesceringarnas": "fosforescering",
    "fosforesceringars": "fosforescering",
    "fosforesceringen": "fosforescering",
    "fosforesceringens": "fosforescering",
    "fosforescerings": "fosforescering",
    "fosforiten": "fosforit",
    "fosforitens": "fosforit",
    "fosforiter": "fosforit",
    "fosforiterna": "fosforit",
    "fosforiternas": "fosforit",
    "fosforiters": "fosforit",
    "fosforits": "fosforit",
    "fosforn": "fosfor",
    "fosforns": "fosfor",
    "fosfors": "fosfor",
    "fosforsyracellen": "fosforsyracell",
    "fosforsyracellens": "fosforsyracell",
    "fosforsyraceller": "fosforsyracell",
    "fosforsyracellerna": "fosforsyracell",
    "fosforsyracellernas": "fosforsyracell",
    "fosforsyracellers": "fosforsyracell",
    "fosforsyracells": "fosforsyracell",
    "fosforsyran": "fosforsyra",
    "fosforsyrans": "fosforsyra",
    "fosforsyras": "fosforsyra",
    "fosforsyre": "fosforsyra",
    "fosforsyror": "fosforsyra",
    "fosforsyrorna": "fosforsyra",
    "fosforsyrornas": "fosforsyra",
    "fosforsyrors": "fosforsyra",
    "fosgenen": "fosgen",
    "fosgenens": "fosgen",
    "fosgens": "fosgen",
    "fossila": "fossil",
    "fossilare": "fossil",
    "fossilares": "fossil",
    "fossilas": "fossil",
    "fossilast": "fossil",
    "fossilaste": "fossil",
    "fossilastes": "fossil",
    "fossilasts": "fossil",
    "fossilbränslen": "fossilbränsle",
    "fossilbränslena": "fossilbränsle",
    "fossilbränslenas": "fossilbränsle",
    "fossilbränslens": "fossilbränsle",
    "fossilbränsles": "fossilbränsle",
    "fossilbränslet": "fossilbränsle",
    "fossilbränslets": "fossilbränsle",
    "fossile": "fossil",
    "fossilen": "fossil",
    "fossilens": "fossil",
    "fossiler": "fossil",
    "fossilerna": "fossil",
    "fossilernas": "fossil",
    "fossilers": "fossil",
    "fossiles": "fossil",
    "fossilet": "fossil",
    "fossilets": "fossil",
    "fossilfria": "fossilfri",
    "fossilfriare": "fossilfri",
    "fossilfriares": "fossilfri",
    "fossilfrias": "fossilfri",
    "fossilfriast": "fossilfri",
    "fossilfriaste": "fossilfri",
    "fossilfriastes": "fossilfri",
    "fossilfriasts": "fossilfri",
    "fossilfrie": "fossilfri",
    "fossilfries": "fossilfri",
    "fossilfris": "fossilfri",
    "fossilfritt": "fossilfri",
    "fossilfritts": "fossilfri",
    "fossilfynden": "fossilfynd",
    "fossilfyndens": "fossilfynd",
    "fossilfyndet": "fossilfynd",
    "fossilfyndets": "fossilfynd",
    "fossilfynds": "fossilfynd",
    "fossilisationen": "fossilisation",
    "fossilisationens": "fossilisation",
    "fossilisationer": "fossilisation",
    "fossilisationerna": "fossilisation",
    "fossilisationernas": "fossilisation",
    "fossilisationers": "fossilisation",
    "fossilisations": "fossilisation",
    "fossiliserad": "fossilisera",
    "fossiliserade": "fossilisera",
    "fossiliserades": "fossilisera",
    "fossiliserads": "fossilisera",
    "fossiliserande": "fossilisera",
    "fossiliseranden": "fossiliserande",
    "fossiliserandena": "fossiliserande",
    "fossiliserandenas": "fossiliserande",
    "fossiliserandens": "fossiliserande",
    "fossiliserandes": "fossiliserande",
    "fossiliserandet": "fossiliserande",
    "fossiliserandets": "fossiliserande",
    "fossiliserar": "fossilisera",
    "fossiliseras": "fossilisera",
    "fossiliserat": "fossilisera",
    "fossiliserats": "fossilisera",
    "fossiliserbara": "fossiliserbar",
    "fossiliserbarare": "fossiliserbar",
    "fossiliserbarares": "fossiliserbar",
    "fossiliserbaras": "fossiliserbar",
    "fossiliserbarast": "fossiliserbar",
    "fossiliserbaraste": "fossiliserbar",
    "fossiliserbarastes": "fossiliserbar",
    "fossiliserbarasts": "fossiliserbar",
    "fossiliserbare": "fossiliserbar",
    "fossiliserbares": "fossiliserbar",
    "fossiliserbarheten": "fossiliserbarhet",
    "fossiliserbarhetens": "fossiliserbarhet",
    "fossiliserbarhets": "fossiliserbarhet",
    "fossiliserbars": "fossiliserbar",
    "fossiliserbart": "fossiliserbar",
    "fossiliserbarts": "fossiliserbar",
    "fossiliseringar": "fossilisering",
    "fossiliseringarna": "fossilisering",
    "fossiliseringarnas": "fossilisering",
    "fossiliseringars": "fossilisering",
    "fossiliseringen": "fossilisering",
    "fossiliseringens": "fossilisering",
    "fossiliserings": "fossilisering",
    "fossilletar": "fossilletare",
    "fossilletaren": "fossilletare",
    "fossilletarens": "fossilletare",
    "fossilletares": "fossilletare",
    "fossilletarexpeditionen": "fossilletarexpedition",
    "fossilletarexpeditionens": "fossilletarexpedition",
    "fossilletarexpeditioner": "fossilletarexpedition",
    "fossilletarexpeditionerna": "fossilletarexpedition",
    "fossilletarexpeditionernas": "fossilletarexpedition",
    "fossilletarexpeditioners": "fossilletarexpedition",
    "fossilletarexpeditions": "fossilletarexpedition",
    "fossilletarna": "fossilletare",
    "fossilletarnas": "fossilletare",
    "fossilminskningar": "fossilminskning",
    "fossilminskningarna": "fossilminskning",
    "fossilminskningarnas": "fossilminskning",
    "fossilminskningars": "fossilminskning",
    "fossilminskningen": "fossilminskning",
    "fossilminskningens": "fossilminskning",
    "fossilminsknings": "fossilminskning",
    "fossils": "fossil",
    "fossilsamlingar": "fossilsamling",
    "fossilsamlingarna": "fossilsamling",
    "fossilsamlingarnas": "fossilsamling",
    "fossilsamlingars": "fossilsamling",
    "fossilsamlingen": "fossilsamling",
    "fossilsamlingens": "fossilsamling",
    "fossilsamlings": "fossilsamling",
    "fossilt": "fossil",
    "fossilts": "fossil",
    "fossingar": "fossing",
    "fossingarna": "fossing",
    "fossingarnas": "fossing",
    "fossingars": "fossing",
    "fossingen": "fossing",
    "fossingens": "fossing",
    "fossings": "fossing",
    "fostbrödralagen": "fostbrödralag",
    "fostbrödralagens": "fostbrödralag",
    "fostbrödralaget": "fostbrödralag",
    "fostbrödralagets": "fostbrödralag",
    "fostbrödralags": "fostbrödralag",
    "foster": "fostra",
    "fosterbarnen": "fosterbarn",
    "fosterbarnens": "fosterbarn",
    "fosterbarnet": "fosterbarn",
    "fosterbarnets": "fosterbarn",
    "fosterbarns": "fosterbarn",
    "fosterfördrivningar": "fosterfördrivning",
    "fosterfördrivningarna": "fosterfördrivning",
    "fosterfördrivningarnas": "fosterfördrivning",
    "fosterfördrivningars": "fosterfördrivning",
    "fosterfördrivningen": "fosterfördrivning",
    "fosterfördrivningens": "fosterfördrivning",
    "fosterfördrivnings": "fosterfördrivning",
    "fosterföräldern": "fosterförälder",
    "fosterförälderns": "fosterförälder",
    "fosterförälders": "fosterförälder",
    "fosterföräldrar": "fosterförälder",
    "fosterföräldrarna": "fosterförälder",
    "fosterföräldrarnas": "fosterförälder",
    "fosterföräldrars": "fosterförälder",
    "fosterhemmen": "fosterhem",
    "fosterhemmens": "fosterhem",
    "fosterhemmet": "fosterhem",
    "fosterhemmets": "fosterhem",
    "fosterhems": "fosterhem",
    "fosterhinnan": "fosterhinna",
    "fosterhinnans": "fosterhinna",
    "fosterhinnas": "fosterhinna",
    "fosterhinne": "fosterhinna",
    "fosterhinnor": "fosterhinna",
    "fosterhinnorna": "fosterhinna",
    "fosterhinnornas": "fosterhinna",
    "fosterhinnors": "fosterhinna",
    "fosterjorden": "fosterjord",
    "fosterjordens": "fosterjord",
    "fosterjords": "fosterjord",
    "fosterlandet": "fosterland",
    "fosterlandets": "fosterland",
    "fosterlands": "fosterland",
    "fosterlandssinnade": "fosterlandssinnad",
    "fosterlandssinnades": "fosterlandssinnad",
    "fosterlandssinnads": "fosterlandssinnad",
    "fosterlandssinnat": "fosterlandssinnad",
    "fosterlandssinnats": "fosterlandssinnad",
    "fosterljuden": "fosterljud",
    "fosterljudens": "fosterljud",
    "fosterljudet": "fosterljud",
    "fosterljudets": "fosterljud",
    "fosterljuds": "fosterljud",
    "fosterlägen": "fosterläge",
    "fosterlägena": "fosterläge",
    "fosterlägenas": "fosterläge",
    "fosterlägens": "fosterläge",
    "fosterläges": "fosterläge",
    "fosterläget": "fosterläge",
    "fosterlägets": "fosterläge",
    "fosterländer": "fosterland",
    "fosterländerna": "fosterland",
    "fosterländernas": "fosterland",
    "fosterländers": "fosterland",
    "fosterländska": "fosterländsk",
    "fosterländskare": "fosterländsk",
    "fosterländskares": "fosterländsk",
    "fosterländskas": "fosterländsk",
    "fosterländskast": "fosterländsk",
    "fosterländskaste": "fosterländsk",
    "fosterländskastes": "fosterländsk",
    "fosterländskasts": "fosterländsk",
    "fosterländske": "fosterländsk",
    "fosterländskes": "fosterländsk",
    "fosterländsks": "fosterländsk",
    "fosterländskt": "fosterländsk",
    "fosterländskts": "fosterländsk",
    "fosterna": "foster",
    "fosternas": "foster",
    "fosters": "foster",
    "fosterskadan": "fosterskada",
    "fosterskadans": "fosterskada",
    "fosterskadas": "fosterskada",
    "fosterskade": "fosterskada",
    "fosterskador": "fosterskada",
    "fosterskadorna": "fosterskada",
    "fosterskadornas": "fosterskada",
    "fosterskadors": "fosterskada",
    "fostertesten": "fostertest",
    "fostertestens": "fostertest",
    "fostertester": "fostertest",
    "fostertesterna": "fostertest",
    "fostertesternas": "fostertest",
    "fostertesters": "fostertest",
    "fostertestet": "fostertest",
    "fostertestets": "fostertest",
    "fostertests": "fostertest",
    "fosterutvecklingar": "fosterutveckling",
    "fosterutvecklingarna": "fosterutveckling",
    "fosterutvecklingarnas": "fosterutveckling",
    "fosterutvecklingars": "fosterutveckling",
    "fosterutvecklingen": "fosterutveckling",
    "fosterutvecklingens": "fosterutveckling",
    "fosterutvecklings": "fosterutveckling",
    "fostervattens": "fostervatten",
    "fostervattnen": "fostervatten",
    "fostervattnens": "fostervatten",
    "fostervattnet": "fostervatten",
    "fostervattnets": "fostervatten",
    "fostrad": "fostra",
    "fostrade": "fostra",
    "fostrades": "fostra",
    "fostrads": "fostra",
    "fostrande": "fostra",
    "fostranden": "fostrande",
    "fostrandena": "fostrande",
    "fostrandenas": "fostrande",
    "fostrandens": "fostrande",
    "fostrandes": "fostrande",
    "fostrandet": "fostrande",
    "fostrandets": "fostrande",
    "fostrans": "fostran",
    "fostrar": "fostrare",
    "fostraren": "fostrare",
    "fostrarens": "fostrare",
    "fostrares": "fostrare",
    "fostrarna": "fostrare",
    "fostrarnas": "fostrare",
    "fostras": "fostra",
    "fostrat": "fostra",
    "fostrats": "fostra",
    "fostren": "foster",
    "fostrens": "foster",
    "fostret": "foster",
    "fostrets": "foster",
    "fot": "fota",
    "fotabjälles": "fotabjälle",
    "fotabjället": "fotabjälle",
    "fotabjällets": "fotabjälle",
    "fotad": "fota",
    "fotade": "fota",
    "fotades": "fota",
    "fotads": "fota",
    "fotande": "fota",
    "fotanden": "fotande",
    "fotandena": "fotande",
    "fotandenas": "fotande",
    "fotandens": "fotande",
    "fotandes": "fotande",
    "fotandet": "fotande",
    "fotandets": "fotande",
    "fotar": "fota",
    "fotarbeten": "fotarbete",
    "fotarbetena": "fotarbete",
    "fotarbetenas": "fotarbete",
    "fotarbetens": "fotarbete",
    "fotarbetes": "fotarbete",
    "fotarbetet": "fotarbete",
    "fotarbetets": "fotarbete",
    "fotarbets": "fotarbete",
    "fotas": "fota",
    "fotat": "fota",
    "fotats": "fota",
    "fotavtrycken": "fotavtryck",
    "fotavtryckens": "fotavtryck",
    "fotavtrycket": "fotavtryck",
    "fotavtryckets": "fotavtryck",
    "fotavtrycks": "fotavtryck",
    "fotbaden": "fotbad",
    "fotbadens": "fotbad",
    "fotbadet": "fotbad",
    "fotbadets": "fotbad",
    "fotbads": "fotbad",
    "fotbjudningar": "fotbjudning",
    "fotbjudningarna": "fotbjudning",
    "fotbjudningarnas": "fotbjudning",
    "fotbjudningars": "fotbjudning",
    "fotbjudningen": "fotbjudning",
    "fotbjudningens": "fotbjudning",
    "fotbjudnings": "fotbjudning",
    "fotbladen": "fotblad",
    "fotbladens": "fotblad",
    "fotbladet": "fotblad",
    "fotbladets": "fotblad",
    "fotblads": "fotblad",
    "fotbojan": "fotboja",
    "fotbojans": "fotboja",
    "fotbojas": "fotboja",
    "fotboje": "fotboja",
    "fotbojor": "fotboja",
    "fotbojorna": "fotboja",
    "fotbojornas": "fotboja",
    "fotbojors": "fotboja",
    "fotbollar": "fotboll",
    "fotbollarna": "fotboll",
    "fotbollarnas": "fotboll",
    "fotbollars": "fotboll",
    "fotbollen": "fotboll",
    "fotbollens": "fotboll",
    "fotbollförbunden": "fotbollförbund",
    "fotbollförbundens": "fotbollförbund",
    "fotbollförbundet": "fotbollförbund",
    "fotbollförbundets": "fotbollförbund",
    "fotbollförbunds": "fotbollförbund",
    "fotbolls": "fotboll",
    "fotbollsbråken": "fotbollsbråk",
    "fotbollsbråkens": "fotbollsbråk",
    "fotbollsbråket": "fotbollsbråk",
    "fotbollsbråkets": "fotbollsbråk",
    "fotbollsbråks": "fotbollsbråk",
    "fotbollsdominerade": "fotbollsdominerad",
    "fotbollsdominerades": "fotbollsdominerad",
    "fotbollsdominerads": "fotbollsdominerad",
    "fotbollsdominerat": "fotbollsdominerad",
    "fotbollsdominerats": "fotbollsdominerad",
    "fotbollsexperten": "fotbollsexpert",
    "fotbollsexpertens": "fotbollsexpert",
    "fotbollsexperter": "fotbollsexpert",
    "fotbollsexperterna": "fotbollsexpert",
    "fotbollsexperternas": "fotbollsexpert",
    "fotbollsexperters": "fotbollsexpert",
    "fotbollsexperts": "fotbollsexpert",
    "fotbollsfebern": "fotbollsfeber",
    "fotbollsfeberns": "fotbollsfeber",
    "fotbollsfebers": "fotbollsfeber",
    "fotbollsförbunden": "fotbollsförbund",
    "fotbollsförbundens": "fotbollsförbund",
    "fotbollsförbundet": "fotbollsförbund",
    "fotbollsförbundets": "fotbollsförbund",
    "fotbollsförbunds": "fotbollsförbund",
    "fotbollshuliganen": "fotbollshuligan",
    "fotbollshuliganens": "fotbollshuligan",
    "fotbollshuliganer": "fotbollshuligan",
    "fotbollshuliganerna": "fotbollshuligan",
    "fotbollshuliganernas": "fotbollshuligan",
    "fotbollshuliganers": "fotbollshuligan",
    "fotbollshuligans": "fotbollshuligan",
    "fotbollskedjan": "fotbollskedja",
    "fotbollskedjans": "fotbollskedja",
    "fotbollskedjas": "fotbollskedja",
    "fotbollskedje": "fotbollskedja",
    "fotbollskedjor": "fotbollskedja",
    "fotbollskedjorna": "fotbollskedja",
    "fotbollskedjornas": "fotbollskedja",
    "fotbollskedjors": "fotbollskedja",
    "fotbollskrigen": "fotbollskrig",
    "fotbollskrigens": "fotbollskrig",
    "fotbollskriget": "fotbollskrig",
    "fotbollskrigets": "fotbollskrig",
    "fotbollskrigs": "fotbollskrig",
    "fotbollslagen": "fotbollslag",
    "fotbollslagens": "fotbollslag",
    "fotbollslaget": "fotbollslag",
    "fotbollslagets": "fotbollslag",
    "fotbollslags": "fotbollslag",
    "fotbollsledar": "fotbollsledare",
    "fotbollsledaren": "fotbollsledare",
    "fotbollsledarens": "fotbollsledare",
    "fotbollsledares": "fotbollsledare",
    "fotbollsledarna": "fotbollsledare",
    "fotbollsledarnas": "fotbollsledare",
    "fotbollsläktar": "fotbollsläktare",
    "fotbollsläktaren": "fotbollsläktare",
    "fotbollsläktarens": "fotbollsläktare",
    "fotbollsläktares": "fotbollsläktare",
    "fotbollsläktarna": "fotbollsläktare",
    "fotbollsläktarnas": "fotbollsläktare",
    "fotbollsmatchen": "fotbollsmatch",
    "fotbollsmatchens": "fotbollsmatch",
    "fotbollsmatcher": "fotbollsmatch",
    "fotbollsmatcherna": "fotbollsmatch",
    "fotbollsmatchernas": "fotbollsmatch",
    "fotbollsmatchers": "fotbollsmatch",
    "fotbollsmatchs": "fotbollsmatch",
    "fotbollsmässiga": "fotbollsmässig",
    "fotbollsmässigare": "fotbollsmässig",
    "fotbollsmässigares": "fotbollsmässig",
    "fotbollsmässigas": "fotbollsmässig",
    "fotbollsmässigast": "fotbollsmässig",
    "fotbollsmässigaste": "fotbollsmässig",
    "fotbollsmässigastes": "fotbollsmässig",
    "fotbollsmässigasts": "fotbollsmässig",
    "fotbollsmässige": "fotbollsmässig",
    "fotbollsmässiges": "fotbollsmässig",
    "fotbollsmässigs": "fotbollsmässig",
    "fotbollsmässigt": "fotbollsmässig",
    "fotbollsmässigts": "fotbollsmässig",
    "fotbollsmålen": "fotbollsmål",
    "fotbollsmålens": "fotbollsmål",
    "fotbollsmålet": "fotbollsmål",
    "fotbollsmålets": "fotbollsmål",
    "fotbollsmåls": "fotbollsmål",
    "fotbollsplanen": "fotbollsplan",
    "fotbollsplanens": "fotbollsplan",
    "fotbollsplaner": "fotbollsplan",
    "fotbollsplanerna": "fotbollsplan",
    "fotbollsplanernas": "fotbollsplan",
    "fotbollsplaners": "fotbollsplan",
    "fotbollsplans": "fotbollsplan",
    "fotbollsspelar": "fotbollsspelare",
    "fotbollsspelaren": "fotbollsspelare",
    "fotbollsspelarens": "fotbollsspelare",
    "fotbollsspelares": "fotbollsspelare",
    "fotbollsspelarna": "fotbollsspelare",
    "fotbollsspelarnas": "fotbollsspelare",
    "fotbollsstjärnan": "fotbollsstjärna",
    "fotbollsstjärnans": "fotbollsstjärna",
    "fotbollsstjärnas": "fotbollsstjärna",
    "fotbollsstjärne": "fotbollsstjärna",
    "fotbollsstjärnor": "fotbollsstjärna",
    "fotbollsstjärnorna": "fotbollsstjärna",
    "fotbollsstjärnornas": "fotbollsstjärna",
    "fotbollsstjärnors": "fotbollsstjärna",
    "fotbollstipsen": "fotbollstips",
    "fotbollstipsens": "fotbollstips",
    "fotbollstipset": "fotbollstips",
    "fotbollstipsets": "fotbollstips",
    "fotbollstutan": "fotbollstuta",
    "fotbollstutans": "fotbollstuta",
    "fotbollstutas": "fotbollstuta",
    "fotbollstute": "fotbollstuta",
    "fotbollstutor": "fotbollstuta",
    "fotbollstutorna": "fotbollstuta",
    "fotbollstutornas": "fotbollstuta",
    "fotbollstutors": "fotbollstuta",
    "fotbromsar": "fotbroms",
    "fotbromsarna": "fotbroms",
    "fotbromsarnas": "fotbroms",
    "fotbromsars": "fotbroms",
    "fotbromsen": "fotbroms",
    "fotbromsens": "fotbroms",
    "foten": "fot",
    "fotens": "fot",
    "fotfelen": "fotfel",
    "fotfelens": "fotfel",
    "fotfelet": "fotfel",
    "fotfelets": "fotfel",
    "fotfels": "fotfel",
    "fotfolket": "fotfolk",
    "fotfolkets": "fotfolk",
    "fotfolks": "fotfolk",
    "fotfästes": "fotfäste",
    "fotfästet": "fotfäste",
    "fotfästets": "fotfäste",
    "fotgängar": "fotgängare",
    "fotgängaren": "fotgängare",
    "fotgängarens": "fotgängare",
    "fotgängares": "fotgängare",
    "fotgängarna": "fotgängare",
    "fotgängarnas": "fotgängare",
    "fotinon": "fotino",
    "fotinons": "fotino",
    "fotinor": "fotino",
    "fotinorna": "fotino",
    "fotinornas": "fotino",
    "fotinors": "fotino",
    "fotinos": "fotino",
    "fotinosen": "fotino",
    "fotinosens": "fotino",
    "fotknölar": "fotknöl",
    "fotknölarna": "fotknöl",
    "fotknölarnas": "fotknöl",
    "fotknölars": "fotknöl",
    "fotknölen": "fotknöl",
    "fotknölens": "fotknöl",
    "fotknöls": "fotknöl",
    "fotleden": "fotled",
    "fotledens": "fotled",
    "fotleder": "fotled",
    "fotlederna": "fotled",
    "fotledernas": "fotled",
    "fotleders": "fotled",
    "fotleds": "fotled",
    "fotnoten": "fotnot",
    "fotnotens": "fotnot",
    "fotnoter": "fotnot",
    "fotnoterna": "fotnot",
    "fotnoternas": "fotnot",
    "fotnoters": "fotnot",
    "fotnots": "fotnot",
    "fotnötter": "fotnot",
    "fotnötterna": "fotnot",
    "fotnötternas": "fotnot",
    "fotnötters": "fotnot",
    "fotoaffären": "fotoaffär",
    "fotoaffärens": "fotoaffär",
    "fotoaffärer": "fotoaffär",
    "fotoaffärerna": "fotoaffär",
    "fotoaffärernas": "fotoaffär",
    "fotoaffärers": "fotoaffär",
    "fotoaffärs": "fotoaffär",
    "fotoateljéer": "fotoateljé",
    "fotoateljéerna": "fotoateljé",
    "fotoateljéernas": "fotoateljé",
    "fotoateljéers": "fotoateljé",
    "fotoateljén": "fotoateljé",
    "fotoateljéns": "fotoateljé",
    "fotoateljés": "fotoateljé",
    "fotoautomaten": "fotoautomat",
    "fotoautomatens": "fotoautomat",
    "fotoautomater": "fotoautomat",
    "fotoautomaterna": "fotoautomat",
    "fotoautomaternas": "fotoautomat",
    "fotoautomaters": "fotoautomat",
    "fotoautomats": "fotoautomat",
    "fotoblixtar": "fotoblixt",
    "fotoblixtarna": "fotoblixt",
    "fotoblixtarnas": "fotoblixt",
    "fotoblixtars": "fotoblixt",
    "fotoblixten": "fotoblixt",
    "fotoblixtens": "fotoblixt",
    "fotoblixts": "fotoblixt",
    "fotocellen": "fotocell",
    "fotocellens": "fotocell",
    "fotoceller": "fotocell",
    "fotocellerna": "fotocell",
    "fotocellernas": "fotocell",
    "fotocellers": "fotocell",
    "fotocells": "fotocell",
    "fotoelektriciteten": "fotoelektricitet",
    "fotoelektricitetens": "fotoelektricitet",
    "fotoelektriciteter": "fotoelektricitet",
    "fotoelektriciteterna": "fotoelektricitet",
    "fotoelektriciteternas": "fotoelektricitet",
    "fotoelektriciteters": "fotoelektricitet",
    "fotoelektricitets": "fotoelektricitet",
    "fotoelektriska": "fotoelektrisk",
    "fotoelektriskare": "fotoelektrisk",
    "fotoelektriskares": "fotoelektrisk",
    "fotoelektriskas": "fotoelektrisk",
    "fotoelektriskast": "fotoelektrisk",
    "fotoelektriskaste": "fotoelektrisk",
    "fotoelektriskastes": "fotoelektrisk",
    "fotoelektriskasts": "fotoelektrisk",
    "fotoelektriske": "fotoelektrisk",
    "fotoelektriskes": "fotoelektrisk",
    "fotoelektrisks": "fotoelektrisk",
    "fotoelektriskt": "fotoelektrisk",
    "fotoelektriskts": "fotoelektrisk",
    "fotogendunkar": "fotogendunk",
    "fotogendunkarna": "fotogendunk",
    "fotogendunkarnas": "fotogendunk",
    "fotogendunkars": "fotogendunk",
    "fotogendunken": "fotogendunk",
    "fotogendunkens": "fotogendunk",
    "fotogendunks": "fotogendunk",
    "fotogenen": "fotogen",
    "fotogenens": "fotogen",
    "fotogenet": "fotogen",
    "fotogenets": "fotogen",
    "fotogeniska": "fotogenisk",
    "fotogeniskare": "fotogenisk",
    "fotogeniskares": "fotogenisk",
    "fotogeniskas": "fotogenisk",
    "fotogeniskast": "fotogenisk",
    "fotogeniskaste": "fotogenisk",
    "fotogeniskastes": "fotogenisk",
    "fotogeniskasts": "fotogenisk",
    "fotogeniske": "fotogenisk",
    "fotogeniskes": "fotogenisk",
    "fotogenisks": "fotogenisk",
    "fotogeniskt": "fotogenisk",
    "fotogeniskts": "fotogenisk",
    "fotogenköken": "fotogenkök",
    "fotogenkökens": "fotogenkök",
    "fotogenköket": "fotogenkök",
    "fotogenkökets": "fotogenkök",
    "fotogenköks": "fotogenkök",
    "fotogens": "fotogen",
    "fotografen": "fotograf",
    "fotografens": "fotograf",
    "fotografer": "fotograf",
    "fotograferad": "fotografera",
    "fotograferade": "fotografera",
    "fotograferades": "fotografera",
    "fotograferads": "fotografera",
    "fotograferande": "fotografera",
    "fotograferanden": "fotograferande",
    "fotograferandena": "fotograferande",
    "fotograferandenas": "fotograferande",
    "fotograferandens": "fotograferande",
    "fotograferandes": "fotograferande",
    "fotograferandet": "fotograferande",
    "fotograferandets": "fotograferande",
    "fotograferar": "fotografera",
    "fotograferas": "fotografera",
    "fotograferat": "fotografera",
    "fotograferats": "fotografera",
    "fotograferbara": "fotograferbar",
    "fotograferbarare": "fotograferbar",
    "fotograferbarares": "fotograferbar",
    "fotograferbaras": "fotograferbar",
    "fotograferbarast": "fotograferbar",
    "fotograferbaraste": "fotograferbar",
    "fotograferbarastes": "fotograferbar",
    "fotograferbarasts": "fotograferbar",
    "fotograferbare": "fotograferbar",
    "fotograferbares": "fotograferbar",
    "fotograferbarheten": "fotograferbarhet",
    "fotograferbarhetens": "fotograferbarhet",
    "fotograferbarhets": "fotograferbarhet",
    "fotograferbars": "fotograferbar",
    "fotograferbart": "fotograferbar",
    "fotograferbarts": "fotograferbar",
    "fotograferingar": "fotografering",
    "fotograferingarna": "fotografering",
    "fotograferingarnas": "fotografering",
    "fotograferingars": "fotografering",
    "fotograferingen": "fotografering",
    "fotograferingens": "fotografering",
    "fotograferings": "fotografering",
    "fotograferna": "fotograf",
    "fotografernas": "fotograf",
    "fotografers": "fotograf",
    "fotografier": "fotografi",
    "fotografierna": "fotografi",
    "fotografiernas": "fotografi",
    "fotografiers": "fotografi",
    "fotografiet": "fotografi",
    "fotografiets": "fotografi",
    "fotografiken": "fotografik",
    "fotografikens": "fotografik",
    "fotografiks": "fotografik",
    "fotografiplåtar": "fotografiplåt",
    "fotografiplåtarna": "fotografiplåt",
    "fotografiplåtarnas": "fotografiplåt",
    "fotografiplåtars": "fotografiplåt",
    "fotografiplåten": "fotografiplåt",
    "fotografiplåtens": "fotografiplåt",
    "fotografiplåts": "fotografiplåt",
    "fotografis": "fotografi",
    "fotografiska": "fotografisk",
    "fotografiskare": "fotografisk",
    "fotografiskares": "fotografisk",
    "fotografiskas": "fotografisk",
    "fotografiskast": "fotografisk",
    "fotografiskaste": "fotografisk",
    "fotografiskastes": "fotografisk",
    "fotografiskasts": "fotografisk",
    "fotografiske": "fotografisk",
    "fotografiskes": "fotografisk",
    "fotografisks": "fotografisk",
    "fotografiskt": "fotografisk",
    "fotografiskts": "fotografisk",
    "fotografit": "fotografi",
    "fotografits": "fotografi",
    "fotografs": "fotograf",
    "fotogrammen": "fotogram",
    "fotogrammens": "fotogram",
    "fotogrammet": "fotogram",
    "fotogrammetrien": "fotogrammetri",
    "fotogrammetriens": "fotogrammetri",
    "fotogrammetrin": "fotogrammetri",
    "fotogrammetrins": "fotogrammetri",
    "fotogrammetris": "fotogrammetri",
    "fotogrammetriska": "fotogrammetrisk",
    "fotogrammetriskare": "fotogrammetrisk",
    "fotogrammetriskares": "fotogrammetrisk",
    "fotogrammetriskas": "fotogrammetrisk",
    "fotogrammetriskast": "fotogrammetrisk",
    "fotogrammetriskaste": "fotogrammetrisk",
    "fotogrammetriskastes": "fotogrammetrisk",
    "fotogrammetriskasts": "fotogrammetrisk",
    "fotogrammetriske": "fotogrammetrisk",
    "fotogrammetriskes": "fotogrammetrisk",
    "fotogrammetrisks": "fotogrammetrisk",
    "fotogrammetriskt": "fotogrammetrisk",
    "fotogrammetriskts": "fotogrammetrisk",
    "fotogrammets": "fotogram",
    "fotograms": "fotogram",
    "fotogravyren": "fotogravyr",
    "fotogravyrens": "fotogravyr",
    "fotogravyrer": "fotogravyr",
    "fotogravyrerna": "fotogravyr",
    "fotogravyrernas": "fotogravyr",
    "fotogravyrers": "fotogravyr",
    "fotogravyrs": "fotogravyr",
    "fotohandlar": "fotohandlare",
    "fotohandlaren": "fotohandlare",
    "fotohandlarens": "fotohandlare",
    "fotohandlares": "fotohandlare",
    "fotohandlarna": "fotohandlare",
    "fotohandlarnas": "fotohandlare",
    "fotokart": "fotokarta",
    "fotokartan": "fotokarta",
    "fotokartans": "fotokarta",
    "fotokartas": "fotokarta",
    "fotokarte": "fotokarta",
    "fotokartor": "fotokarta",
    "fotokartorna": "fotokarta",
    "fotokartornas": "fotokarta",
    "fotokartors": "fotokarta",
    "fotokarts": "fotokarta",
    "fotokemien": "fotokemi",
    "fotokemiens": "fotokemi",
    "fotokemin": "fotokemi",
    "fotokemins": "fotokemi",
    "fotokemis": "fotokemi",
    "fotokemiska": "fotokemisk",
    "fotokemiskare": "fotokemisk",
    "fotokemiskares": "fotokemisk",
    "fotokemiskas": "fotokemisk",
    "fotokemiskast": "fotokemisk",
    "fotokemiskaste": "fotokemisk",
    "fotokemiskastes": "fotokemisk",
    "fotokemiskasts": "fotokemisk",
    "fotokemiske": "fotokemisk",
    "fotokemiskes": "fotokemisk",
    "fotokemisks": "fotokemisk",
    "fotokemiskt": "fotokemisk",
    "fotokemiskts": "fotokemisk",
    "fotokopian": "fotokopia",
    "fotokopians": "fotokopia",
    "fotokopias": "fotokopia",
    "fotokopie": "fotokopia",
    "fotokopierad": "fotokopiera",
    "fotokopierade": "fotokopiera",
    "fotokopierades": "fotokopiera",
    "fotokopierads": "fotokopiera",
    "fotokopierande": "fotokopiera",
    "fotokopieranden": "fotokopierande",
    "fotokopierandena": "fotokopierande",
    "fotokopierandenas": "fotokopierande",
    "fotokopierandens": "fotokopierande",
    "fotokopierandes": "fotokopierande",
    "fotokopierandet": "fotokopierande",
    "fotokopierandets": "fotokopierande",
    "fotokopierar": "fotokopiera",
    "fotokopieras": "fotokopiera",
    "fotokopierat": "fotokopiera",
    "fotokopierats": "fotokopiera",
    "fotokopierbara": "fotokopierbar",
    "fotokopierbarare": "fotokopierbar",
    "fotokopierbarares": "fotokopierbar",
    "fotokopierbaras": "fotokopierbar",
    "fotokopierbarast": "fotokopierbar",
    "fotokopierbaraste": "fotokopierbar",
    "fotokopierbarastes": "fotokopierbar",
    "fotokopierbarasts": "fotokopierbar",
    "fotokopierbare": "fotokopierbar",
    "fotokopierbares": "fotokopierbar",
    "fotokopierbarheten": "fotokopierbarhet",
    "fotokopierbarhetens": "fotokopierbarhet",
    "fotokopierbarhets": "fotokopierbarhet",
    "fotokopierbars": "fotokopierbar",
    "fotokopierbart": "fotokopierbar",
    "fotokopierbarts": "fotokopierbar",
    "fotokopieringar": "fotokopiering",
    "fotokopieringarna": "fotokopiering",
    "fotokopieringarnas": "fotokopiering",
    "fotokopieringars": "fotokopiering",
    "fotokopieringen": "fotokopiering",
    "fotokopieringens": "fotokopiering",
    "fotokopierings": "fotokopiering",
    "fotokopior": "fotokopia",
    "fotokopiorna": "fotokopia",
    "fotokopiornas": "fotokopia",
    "fotokopiors": "fotokopia",
    "fotometern": "fotometer",
    "fotometerns": "fotometer",
    "fotometers": "fotometer",
    "fotometrar": "fotometer",
    "fotometrarna": "fotometer",
    "fotometrarnas": "fotometer",
    "fotometrars": "fotometer",
    "fotometrien": "fotometri",
    "fotometriens": "fotometri",
    "fotometrin": "fotometri",
    "fotometrins": "fotometri",
    "fotometris": "fotometri",
    "fotomodellen": "fotomodell",
    "fotomodellens": "fotomodell",
    "fotomodeller": "fotomodell",
    "fotomodellerna": "fotomodell",
    "fotomodellernas": "fotomodell",
    "fotomodellers": "fotomodell",
    "fotomodells": "fotomodell",
    "fotomontagen": "fotomontage",
    "fotomontagens": "fotomontage",
    "fotomontages": "fotomontage",
    "fotomontaget": "fotomontage",
    "fotomontagets": "fotomontage",
    "foton": "foto",
    "fotona": "foto",
    "fotonas": "foto",
    "fotonen": "foton",
    "fotonens": "foton",
    "fotoner": "foton",
    "fotonerna": "foton",
    "fotonernas": "foton",
    "fotoners": "foton",
    "fotons": "foton",
    "fotoprisen": "fotopris",
    "fotoprisens": "fotopris",
    "fotopriser": "fotopris",
    "fotopriserna": "fotopris",
    "fotoprisernas": "fotopris",
    "fotoprisers": "fotopris",
    "fotopriset": "fotopris",
    "fotoprisets": "fotopris",
    "fotoresistorer": "fotoresistor",
    "fotoresistorerna": "fotoresistor",
    "fotoresistorernas": "fotoresistor",
    "fotoresistorers": "fotoresistor",
    "fotoresistorn": "fotoresistor",
    "fotoresistorns": "fotoresistor",
    "fotoresistors": "fotoresistor",
    "fotos": "foto",
    "fotostatkopian": "fotostatkopia",
    "fotostatkopians": "fotostatkopia",
    "fotostatkopias": "fotostatkopia",
    "fotostatkopie": "fotostatkopia",
    "fotostatkopierad": "fotostatkopiera",
    "fotostatkopierade": "fotostatkopiera",
    "fotostatkopierades": "fotostatkopiera",
    "fotostatkopierads": "fotostatkopiera",
    "fotostatkopierande": "fotostatkopiera",
    "fotostatkopieranden": "fotostatkopierande",
    "fotostatkopierandena": "fotostatkopierande",
    "fotostatkopierandenas": "fotostatkopierande",
    "fotostatkopierandens": "fotostatkopierande",
    "fotostatkopierandes": "fotostatkopierande",
    "fotostatkopierandet": "fotostatkopierande",
    "fotostatkopierandets": "fotostatkopierande",
    "fotostatkopierar": "fotostatkopiera",
    "fotostatkopieras": "fotostatkopiera",
    "fotostatkopierat": "fotostatkopiera",
    "fotostatkopierats": "fotostatkopiera",
    "fotostatkopierbara": "fotostatkopierbar",
    "fotostatkopierbarare": "fotostatkopierbar",
    "fotostatkopierbarares": "fotostatkopierbar",
    "fotostatkopierbaras": "fotostatkopierbar",
    "fotostatkopierbarast": "fotostatkopierbar",
    "fotostatkopierbaraste": "fotostatkopierbar",
    "fotostatkopierbarastes": "fotostatkopierbar",
    "fotostatkopierbarasts": "fotostatkopierbar",
    "fotostatkopierbare": "fotostatkopierbar",
    "fotostatkopierbares": "fotostatkopierbar",
    "fotostatkopierbarheten": "fotostatkopierbarhet",
    "fotostatkopierbarhetens": "fotostatkopierbarhet",
    "fotostatkopierbarhets": "fotostatkopierbarhet",
    "fotostatkopierbars": "fotostatkopierbar",
    "fotostatkopierbart": "fotostatkopierbar",
    "fotostatkopierbarts": "fotostatkopierbar",
    "fotostatkopieringar": "fotostatkopiering",
    "fotostatkopieringarna": "fotostatkopiering",
    "fotostatkopieringarnas": "fotostatkopiering",
    "fotostatkopieringars": "fotostatkopiering",
    "fotostatkopieringen": "fotostatkopiering",
    "fotostatkopieringens": "fotostatkopiering",
    "fotostatkopierings": "fotostatkopiering",
    "fotostatkopior": "fotostatkopia",
    "fotostatkopiorna": "fotostatkopia",
    "fotostatkopiornas": "fotostatkopia",
    "fotostatkopiors": "fotostatkopia",
    "fotosyntesen": "fotosyntes",
    "fotosyntesens": "fotosyntes",
    "fotosynteser": "fotosyntes",
    "fotosynteserna": "fotosyntes",
    "fotosyntesernas": "fotosyntes",
    "fotosyntesers": "fotosyntes",
    "fotosättningar": "fotosättning",
    "fotosättningarna": "fotosättning",
    "fotosättningarnas": "fotosättning",
    "fotosättningars": "fotosättning",
    "fotosättningen": "fotosättning",
    "fotosättningens": "fotosättning",
    "fotosättnings": "fotosättning",
    "fotot": "foto",
    "fotots": "foto",
    "fotpedalen": "fotpedal",
    "fotpedalens": "fotpedal",
    "fotpedaler": "fotpedal",
    "fotpedalerna": "fotpedal",
    "fotpedalernas": "fotpedal",
    "fotpedalers": "fotpedal",
    "fotpedals": "fotpedal",
    "fotplatt": "fotplatta",
    "fotplattan": "fotplatta",
    "fotplattans": "fotplatta",
    "fotplattas": "fotplatta",
    "fotplatte": "fotplatta",
    "fotplattor": "fotplatta",
    "fotplattorna": "fotplatta",
    "fotplattornas": "fotplatta",
    "fotplattors": "fotplatta",
    "fotplatts": "fotplatta",
    "fotriktiga": "fotriktig",
    "fotriktigare": "fotriktig",
    "fotriktigares": "fotriktig",
    "fotriktigas": "fotriktig",
    "fotriktigast": "fotriktig",
    "fotriktigaste": "fotriktig",
    "fotriktigastes": "fotriktig",
    "fotriktigasts": "fotriktig",
    "fotriktige": "fotriktig",
    "fotriktiges": "fotriktig",
    "fotriktigheten": "fotriktighet",
    "fotriktighetens": "fotriktighet",
    "fotriktighets": "fotriktighet",
    "fotriktigs": "fotriktig",
    "fotriktigt": "fotriktig",
    "fotriktigts": "fotriktig",
    "fots": "fot",
    "fotsackar": "fotsack",
    "fotsackarna": "fotsack",
    "fotsackarnas": "fotsack",
    "fotsackars": "fotsack",
    "fotsacken": "fotsack",
    "fotsackens": "fotsack",
    "fotsacks": "fotsack",
    "fotsida": "fotsid",
    "fotsidare": "fotsid",
    "fotsidares": "fotsid",
    "fotsidas": "fotsid",
    "fotsidast": "fotsid",
    "fotsidaste": "fotsid",
    "fotsidastes": "fotsid",
    "fotsidasts": "fotsid",
    "fotside": "fotsid",
    "fotsides": "fotsid",
    "fotsids": "fotsid",
    "fotsitt": "fotsid",
    "fotsitts": "fotsid",
    "fotskadan": "fotskada",
    "fotskadans": "fotskada",
    "fotskadas": "fotskada",
    "fotskade": "fotskada",
    "fotskador": "fotskada",
    "fotskadorna": "fotskada",
    "fotskadornas": "fotskada",
    "fotskadors": "fotskada",
    "fotskrap": "fotskrapa",
    "fotskrapan": "fotskrapa",
    "fotskrapans": "fotskrapa",
    "fotskrapas": "fotskrapa",
    "fotskrape": "fotskrapa",
    "fotskrapor": "fotskrapa",
    "fotskraporna": "fotskrapa",
    "fotskrapornas": "fotskrapa",
    "fotskrapors": "fotskrapa",
    "fotskraps": "fotskrapa",
    "fotspåren": "fotspår",
    "fotspårens": "fotspår",
    "fotspåret": "fotspår",
    "fotspårets": "fotspår",
    "fotspårs": "fotspår",
    "fotstegen": "fotsteg",
    "fotstegens": "fotsteg",
    "fotsteget": "fotsteg",
    "fotstegets": "fotsteg",
    "fotstegs": "fotsteg",
    "fotstöden": "fotstöd",
    "fotstödens": "fotstöd",
    "fotstödet": "fotstöd",
    "fotstödets": "fotstöd",
    "fotstöds": "fotstöd",
    "fotsul": "fotsula",
    "fotsulan": "fotsula",
    "fotsulans": "fotsula",
    "fotsulas": "fotsula",
    "fotsule": "fotsula",
    "fotsulor": "fotsula",
    "fotsulorna": "fotsula",
    "fotsulornas": "fotsula",
    "fotsulors": "fotsula",
    "fotsuls": "fotsula",
    "fotsvetten": "fotsvett",
    "fotsvettens": "fotsvett",
    "fotsvetts": "fotsvett",
    "fotvalven": "fotvalv",
    "fotvalvens": "fotvalv",
    "fotvalvet": "fotvalv",
    "fotvalvets": "fotvalv",
    "fotvalvs": "fotvalv",
    "fotvandrade": "fotvandra",
    "fotvandrades": "fotvandra",
    "fotvandrande": "fotvandra",
    "fotvandranden": "fotvandrande",
    "fotvandrandena": "fotvandrande",
    "fotvandrandenas": "fotvandrande",
    "fotvandrandens": "fotvandrande",
    "fotvandrandes": "fotvandrande",
    "fotvandrandet": "fotvandrande",
    "fotvandrandets": "fotvandrande",
    "fotvandrar": "fotvandra",
    "fotvandras": "fotvandra",
    "fotvandrat": "fotvandra",
    "fotvandrats": "fotvandra",
    "fotvandringar": "fotvandring",
    "fotvandringarna": "fotvandring",
    "fotvandringarnas": "fotvandring",
    "fotvandringars": "fotvandring",
    "fotvandringen": "fotvandring",
    "fotvandringens": "fotvandring",
    "fotvandrings": "fotvandring",
    "fotvänliga": "fotvänlig",
    "fotvänligare": "fotvänlig",
    "fotvänligares": "fotvänlig",
    "fotvänligas": "fotvänlig",
    "fotvänligast": "fotvänlig",
    "fotvänligaste": "fotvänlig",
    "fotvänligastes": "fotvänlig",
    "fotvänligasts": "fotvänlig",
    "fotvänlige": "fotvänlig",
    "fotvänliges": "fotvänlig",
    "fotvänligheten": "fotvänlighet",
    "fotvänlighetens": "fotvänlighet",
    "fotvänlighets": "fotvänlighet",
    "fotvänligs": "fotvänlig",
    "fotvänligt": "fotvänlig",
    "fotvänligts": "fotvänlig",
    "fotvården": "fotvård",
    "fotvårdens": "fotvård",
    "fotvårds": "fotvård",
    "fotvårt": "fotvårta",
    "fotvårtan": "fotvårta",
    "fotvårtans": "fotvårta",
    "fotvårtas": "fotvårta",
    "fotvårte": "fotvårta",
    "fotvårtor": "fotvårta",
    "fotvårtorna": "fotvårta",
    "fotvårtornas": "fotvårta",
    "fotvårtors": "fotvårta",
    "fotvårts": "fotvårta",
    "fotänd": "fotända",
    "fotändan": "fotända",
    "fotändans": "fotända",
    "fotändar": "fotände",
    "fotändarna": "fotände",
    "fotändarnas": "fotände",
    "fotändars": "fotände",
    "fotändas": "fotända",
    "fotände": "fotända",
    "fotänden": "fotände",
    "fotändens": "fotände",
    "fotändes": "fotände",
    "fotändor": "fotända",
    "fotändorna": "fotända",
    "fotändornas": "fotända",
    "fotändors": "fotända",
    "fotänds": "fotända",
    "foularden": "foulard",
    "foulardens": "foulard",
    "foulards": "foulard",
    "foulen": "foul",
    "foulens": "foul",
    "fouler": "foul",
    "foulerna": "foul",
    "foulernas": "foul",
    "foulers": "foul",
    "fouls": "foul",
    "foxterriern": "foxterrier",
    "foxterrierna": "foxterrier",
    "foxterriernas": "foxterrier",
    "foxterrierns": "foxterrier",
    "foxterriers": "foxterrier",
    "foxtrotar": "foxtrot",
    "foxtrotarna": "foxtrot",
    "foxtrotarnas": "foxtrot",
    "foxtrotars": "foxtrot",
    "foxtroten": "foxtrot",
    "foxtrotens": "foxtrot",
    "foxtroter": "foxtrot",
    "foxtroterna": "foxtrot",
    "foxtroternas": "foxtrot",
    "foxtroters": "foxtrot",
    "foxtrots": "foxtrot",
    "foxtrottakten": "foxtrottakt",
    "foxtrottaktens": "foxtrottakt",
    "foxtrottakts": "foxtrottakt",
    "foxtrottar": "foxtrott",
    "foxtrottarna": "foxtrott",
    "foxtrottarnas": "foxtrott",
    "foxtrottars": "foxtrott",
    "foxtrotten": "foxtrott",
    "foxtrottens": "foxtrott",
    "foxtrotter": "foxtrott",
    "foxtrotterna": "foxtrott",
    "foxtrotternas": "foxtrott",
    "foxtrotters": "foxtrott",
    "foxtrotts": "foxtrott",
    "foyerer": "foyer",
    "foyererna": "foyer",
    "foyerernas": "foyer",
    "foyerers": "foyer",
    "foyern": "foyer",
    "foyerns": "foyer",
    "foyers": "foyer",
    "fp-s": "fp",
    "fps": "fp",
    "frackar": "frack",
    "frackarna": "frack",
    "frackarnas": "frack",
    "frackars": "frack",
    "fracken": "frack",
    "frackens": "frack",
    "fracks": "frack",
    "fradgade": "fradga",
    "fradgades": "fradga",
    "fradgan": "fradga",
    "fradgande": "fradga",
    "fradganden": "fradgande",
    "fradgandena": "fradgande",
    "fradgandenas": "fradgande",
    "fradgandens": "fradgande",
    "fradgandes": "fradgande",
    "fradgandet": "fradgande",
    "fradgandets": "fradgande",
    "fradgans": "fradga",
    "fradgar": "fradga",
    "fradgas": "fradga",
    "fradgat": "fradga",
    "fradgats": "fradga",
    "fradgiga": "fradgig",
    "fradgigare": "fradgig",
    "fradgigares": "fradgig",
    "fradgigas": "fradgig",
    "fradgigast": "fradgig",
    "fradgigaste": "fradgig",
    "fradgigastes": "fradgig",
    "fradgigasts": "fradgig",
    "fradgige": "fradgig",
    "fradgiges": "fradgig",
    "fradgigs": "fradgig",
    "fradgigt": "fradgig",
    "fradgigts": "fradgig",
    "fragila": "fragil",
    "fragilare": "fragil",
    "fragilares": "fragil",
    "fragilas": "fragil",
    "fragilast": "fragil",
    "fragilaste": "fragil",
    "fragilastes": "fragil",
    "fragilasts": "fragil",
    "fragile": "fragil",
    "fragiles": "fragil",
    "fragils": "fragil",
    "fragilt": "fragil",
    "fragilts": "fragil",
    "fragmentariska": "fragmentarisk",
    "fragmentariskare": "fragmentarisk",
    "fragmentariskares": "fragmentarisk",
    "fragmentariskas": "fragmentarisk",
    "fragmentariskast": "fragmentarisk",
    "fragmentariskaste": "fragmentarisk",
    "fragmentariskastes": "fragmentarisk",
    "fragmentariskasts": "fragmentarisk",
    "fragmentariske": "fragmentarisk",
    "fragmentariskes": "fragmentarisk",
    "fragmentarisks": "fragmentarisk",
    "fragmentariskt": "fragmentarisk",
    "fragmentariskts": "fragmentarisk",
    "fragmenten": "fragment",
    "fragmentens": "fragment",
    "fragmenterad": "fragmentera",
    "fragmenterade": "fragmentera",
    "fragmenterades": "fragmentera",
    "fragmenterads": "fragmentera",
    "fragmenterande": "fragmentera",
    "fragmenteranden": "fragmenterande",
    "fragmenterandena": "fragmenterande",
    "fragmenterandenas": "fragmenterande",
    "fragmenterandens": "fragmenterande",
    "fragmenterandes": "fragmenterande",
    "fragmenterandet": "fragmenterande",
    "fragmenterandets": "fragmenterande",
    "fragmenterar": "fragmentera",
    "fragmenteras": "fragmentera",
    "fragmenterat": "fragmentera",
    "fragmenterats": "fragmentera",
    "fragmenterbara": "fragmenterbar",
    "fragmenterbarare": "fragmenterbar",
    "fragmenterbarares": "fragmenterbar",
    "fragmenterbaras": "fragmenterbar",
    "fragmenterbarast": "fragmenterbar",
    "fragmenterbaraste": "fragmenterbar",
    "fragmenterbarastes": "fragmenterbar",
    "fragmenterbarasts": "fragmenterbar",
    "fragmenterbare": "fragmenterbar",
    "fragmenterbares": "fragmenterbar",
    "fragmenterbarheten": "fragmenterbarhet",
    "fragmenterbarhetens": "fragmenterbarhet",
    "fragmenterbarhets": "fragmenterbarhet",
    "fragmenterbars": "fragmenterbar",
    "fragmenterbart": "fragmenterbar",
    "fragmenterbarts": "fragmenterbar",
    "fragmenteringen": "fragmentering",
    "fragmenteringens": "fragmentering",
    "fragmenterings": "fragmentering",
    "fragmentet": "fragment",
    "fragmentets": "fragment",
    "fragmentiseringen": "fragmentisering",
    "fragmentiseringens": "fragmentisering",
    "fragmentiserings": "fragmentisering",
    "fragments": "fragment",
    "frakt": "frakta",
    "fraktad": "frakta",
    "fraktade": "frakta",
    "fraktades": "frakta",
    "fraktads": "frakta",
    "fraktala": "fraktal",
    "fraktalare": "fraktal",
    "fraktalares": "fraktal",
    "fraktalas": "fraktal",
    "fraktalast": "fraktal",
    "fraktalaste": "fraktal",
    "fraktalastes": "fraktal",
    "fraktalasts": "fraktal",
    "fraktale": "fraktal",
    "fraktales": "fraktal",
    "fraktals": "fraktal",
    "fraktalt": "fraktal",
    "fraktalts": "fraktal",
    "fraktande": "frakta",
    "fraktanden": "fraktande",
    "fraktandena": "fraktande",
    "fraktandenas": "fraktande",
    "fraktandens": "fraktande",
    "fraktandes": "fraktande",
    "fraktandet": "fraktande",
    "fraktandets": "fraktande",
    "fraktar": "frakta",
    "fraktas": "frakta",
    "fraktat": "frakta",
    "fraktats": "frakta",
    "fraktavtalen": "fraktavtal",
    "fraktavtalens": "fraktavtal",
    "fraktavtalet": "fraktavtal",
    "fraktavtalets": "fraktavtal",
    "fraktavtals": "fraktavtal",
    "fraktbolagen": "fraktbolag",
    "fraktbolagens": "fraktbolag",
    "fraktbolaget": "fraktbolag",
    "fraktbolagets": "fraktbolag",
    "fraktbolags": "fraktbolag",
    "frakten": "frakt",
    "fraktens": "frakt",
    "frakter": "frakt",
    "frakterna": "frakt",
    "frakternas": "frakt",
    "frakters": "frakt",
    "fraktgodset": "fraktgods",
    "fraktgodsets": "fraktgods",
    "fraktionen": "fraktion",
    "fraktionens": "fraktion",
    "fraktioner": "fraktion",
    "fraktionerad": "fraktionera",
    "fraktionerade": "fraktionera",
    "fraktionerades": "fraktionera",
    "fraktionerads": "fraktionera",
    "fraktionerande": "fraktionera",
    "fraktioneranden": "fraktionerande",
    "fraktionerandena": "fraktionerande",
    "fraktionerandenas": "fraktionerande",
    "fraktionerandens": "fraktionerande",
    "fraktionerandes": "fraktionerande",
    "fraktionerandet": "fraktionerande",
    "fraktionerandets": "fraktionerande",
    "fraktionerar": "fraktionera",
    "fraktioneras": "fraktionera",
    "fraktionerat": "fraktionera",
    "fraktionerats": "fraktionera",
    "fraktionerbara": "fraktionerbar",
    "fraktionerbarare": "fraktionerbar",
    "fraktionerbarares": "fraktionerbar",
    "fraktionerbaras": "fraktionerbar",
    "fraktionerbarast": "fraktionerbar",
    "fraktionerbaraste": "fraktionerbar",
    "fraktionerbarastes": "fraktionerbar",
    "fraktionerbarasts": "fraktionerbar",
    "fraktionerbare": "fraktionerbar",
    "fraktionerbares": "fraktionerbar",
    "fraktionerbarheten": "fraktionerbarhet",
    "fraktionerbarhetens": "fraktionerbarhet",
    "fraktionerbarhets": "fraktionerbarhet",
    "fraktionerbars": "fraktionerbar",
    "fraktionerbart": "fraktionerbar",
    "fraktionerbarts": "fraktionerbar",
    "fraktioneringar": "fraktionering",
    "fraktioneringarna": "fraktionering",
    "fraktioneringarnas": "fraktionering",
    "fraktioneringars": "fraktionering",
    "fraktioneringen": "fraktionering",
    "fraktioneringens": "fraktionering",
    "fraktionerings": "fraktionering",
    "fraktionerna": "fraktion",
    "fraktionernas": "fraktion",
    "fraktioners": "fraktion",
    "fraktions": "fraktion",
    "frakts": "frakt",
    "fraktsatsen": "fraktsats",
    "fraktsatsens": "fraktsats",
    "fraktsatser": "fraktsats",
    "fraktsatserna": "fraktsats",
    "fraktsatsernas": "fraktsats",
    "fraktsatsers": "fraktsats",
    "fraktsedeln": "fraktsedel",
    "fraktsedelns": "fraktsedel",
    "fraktsedels": "fraktsedel",
    "fraktsedlar": "fraktsedel",
    "fraktsedlarna": "fraktsedel",
    "fraktsedlarnas": "fraktsedel",
    "fraktsedlars": "fraktsedel",
    "frakturen": "fraktur",
    "frakturens": "fraktur",
    "frakturer": "fraktur",
    "frakturerna": "fraktur",
    "frakturernas": "fraktur",
    "frakturers": "fraktur",
    "frakturs": "fraktur",
    "frall": "fralla",
    "frallan": "fralla",
    "frallans": "fralla",
    "frallas": "fralla",
    "fralle": "fralla",
    "frallor": "fralla",
    "frallorna": "fralla",
    "frallornas": "fralla",
    "frallors": "fralla",
    "fralls": "fralla",
    "framavl": "framavla",
    "framavlade": "framavla",
    "framavlades": "framavla",
    "framavlande": "framavla",
    "framavlanden": "framavlande",
    "framavlandena": "framavlande",
    "framavlandenas": "framavlande",
    "framavlandens": "framavlande",
    "framavlandes": "framavlande",
    "framavlandet": "framavlande",
    "framavlandets": "framavlande",
    "framavlar": "framavla",
    "framavlas": "framavla",
    "framavlat": "framavla",
    "framavlats": "framavla",
    "framaxeln": "framaxel",
    "framaxelns": "framaxel",
    "framaxels": "framaxel",
    "framaxlar": "framaxel",
    "framaxlarna": "framaxel",
    "framaxlarnas": "framaxel",
    "framaxlars": "framaxel",
    "frambar": "frambära",
    "frambars": "frambära",
    "frambenen": "framben",
    "frambenens": "framben",
    "frambenet": "framben",
    "frambenets": "framben",
    "frambens": "framben",
    "frambesvor": "frambesvärja",
    "frambesvors": "frambesvärja",
    "frambesvure": "frambesvärja",
    "frambesvuren": "frambesvärja",
    "frambesvurens": "frambesvärja",
    "frambesvures": "frambesvärja",
    "frambesvuret": "frambesvärja",
    "frambesvurets": "frambesvärja",
    "frambesvurit": "frambesvärja",
    "frambesvurits": "frambesvärja",
    "frambesvurna": "frambesvärja",
    "frambesvurnas": "frambesvärja",
    "frambesvurne": "frambesvärja",
    "frambesvurnes": "frambesvärja",
    "frambesvär": "frambesvärja",
    "frambesvära": "frambesvärja",
    "frambesvärande": "frambesvärja",
    "frambesvärandes": "frambesvärja",
    "frambesväras": "frambesvärja",
    "frambesvärj": "frambesvärja",
    "frambesvärjande": "frambesvärja",
    "frambesvärjanden": "frambesvärjande",
    "frambesvärjandena": "frambesvärjande",
    "frambesvärjandenas": "frambesvärjande",
    "frambesvärjandens": "frambesvärjande",
    "frambesvärjandes": "frambesvärjande",
    "frambesvärjandet": "frambesvärjande",
    "frambesvärjandets": "frambesvärjande",
    "frambesvärjas": "frambesvärja",
    "frambesvärjd": "frambesvärja",
    "frambesvärjda": "frambesvärja",
    "frambesvärjdas": "frambesvärja",
    "frambesvärjde": "frambesvärja",
    "frambesvärjdes": "frambesvärja",
    "frambesvärjds": "frambesvärja",
    "frambesvärje": "frambesvärja",
    "frambesvärjer": "frambesvärja",
    "frambesvärjes": "frambesvärja",
    "frambesvärjs": "frambesvärja",
    "frambesvärjt": "frambesvärja",
    "frambesvärjts": "frambesvärja",
    "frambragt": "frambringa",
    "frambragte": "frambringa",
    "frambragtes": "frambringa",
    "frambragts": "frambringa",
    "frambring": "frambringa",
    "frambringad": "frambringa",
    "frambringade": "frambringa",
    "frambringades": "frambringa",
    "frambringads": "frambringa",
    "frambringande": "frambringa",
    "frambringanden": "frambringande",
    "frambringandena": "frambringande",
    "frambringandenas": "frambringande",
    "frambringandens": "frambringande",
    "frambringandes": "frambringande",
    "frambringandet": "frambringande",
    "frambringandets": "frambringande",
    "frambringar": "frambringa",
    "frambringas": "frambringa",
    "frambringat": "frambringa",
    "frambringats": "frambringa",
    "frambruten": "frambryta",
    "frambrutens": "frambryta",
    "frambrutet": "frambryta",
    "frambrutets": "frambryta",
    "frambrutit": "frambryta",
    "frambrutits": "frambryta",
    "frambrutna": "frambryta",
    "frambrutnas": "frambryta",
    "frambrutne": "frambryta",
    "frambrutnes": "frambryta",
    "frambryt": "frambryta",
    "frambrytande": "frambryta",
    "frambrytanden": "frambrytande",
    "frambrytandena": "frambrytande",
    "frambrytandenas": "frambrytande",
    "frambrytandens": "frambrytande",
    "frambrytandes": "frambrytande",
    "frambrytandet": "frambrytande",
    "frambrytandets": "frambrytande",
    "frambrytas": "frambryta",
    "frambryte": "frambryta",
    "frambryter": "frambryta",
    "frambrytes": "frambryta",
    "frambryts": "frambryta",
    "frambröt": "frambryta",
    "frambröte": "frambryta",
    "frambrötes": "frambryta",
    "frambröts": "frambryta",
    "frambure": "frambära",
    "framburen": "frambära",
    "framburens": "frambära",
    "frambures": "frambära",
    "framburet": "frambära",
    "framburets": "frambära",
    "framburit": "frambära",
    "framburits": "frambära",
    "framburna": "frambära",
    "framburnas": "frambära",
    "framburne": "frambära",
    "framburnes": "frambära",
    "frambär": "frambära",
    "frambärande": "frambära",
    "frambäranden": "frambärande",
    "frambärandena": "frambärande",
    "frambärandenas": "frambärande",
    "frambärandens": "frambärande",
    "frambärandes": "frambärande",
    "frambärandet": "frambärande",
    "frambärandets": "frambärande",
    "frambäras": "frambära",
    "frambäre": "frambära",
    "frambäres": "frambära",
    "frambärs": "frambära",
    "framdelar": "framdel",
    "framdelarna": "framdel",
    "framdelarnas": "framdel",
    "framdelars": "framdel",
    "framdelen": "framdel",
    "framdelens": "framdel",
    "framdels": "framdel",
    "framdrev": "framdriva",
    "framdrevs": "framdriva",
    "framdriv": "framdriva",
    "framdrivande": "framdriva",
    "framdrivanden": "framdrivande",
    "framdrivandena": "framdrivande",
    "framdrivandenas": "framdrivande",
    "framdrivandens": "framdrivande",
    "framdrivandes": "framdrivande",
    "framdrivandet": "framdrivande",
    "framdrivandets": "framdrivande",
    "framdrivas": "framdriva",
    "framdrive": "framdriva",
    "framdriven": "framdriva",
    "framdrivens": "framdriva",
    "framdriver": "framdriva",
    "framdrives": "framdriva",
    "framdrivet": "framdriva",
    "framdrivets": "framdriva",
    "framdrivit": "framdriva",
    "framdrivits": "framdriva",
    "framdrivna": "framdriva",
    "framdrivnas": "framdriva",
    "framdrivne": "framdriva",
    "framdrivnes": "framdriva",
    "framdrivs": "framdriva",
    "framfallen": "framfall",
    "framfallens": "framfall",
    "framfallet": "framfall",
    "framfallets": "framfall",
    "framfalls": "framfall",
    "framfar": "framfara",
    "framfarande": "framfara",
    "framfaranden": "framfarande",
    "framfarandena": "framfarande",
    "framfarandenas": "framfarande",
    "framfarandens": "framfarande",
    "framfarandes": "framfarande",
    "framfarandet": "framfarande",
    "framfarandets": "framfarande",
    "framfaras": "framfara",
    "framfare": "framfara",
    "framfaren": "framfara",
    "framfarens": "framfara",
    "framfares": "framfara",
    "framfaret": "framfara",
    "framfarets": "framfara",
    "framfarit": "framfara",
    "framfarits": "framfara",
    "framfarna": "framfara",
    "framfarnas": "framfara",
    "framfarne": "framfara",
    "framfarnes": "framfara",
    "framfars": "framfara",
    "framfarten": "framfart",
    "framfartens": "framfart",
    "framfarts": "framfart",
    "framfick": "framficka",
    "framfickan": "framficka",
    "framfickans": "framficka",
    "framfickas": "framficka",
    "framficke": "framficka",
    "framfickor": "framficka",
    "framfickorna": "framficka",
    "framfickornas": "framficka",
    "framfickors": "framficka",
    "framficks": "framficka",
    "framflytt": "framflytta",
    "framflyttad": "framflytta",
    "framflyttade": "framflytta",
    "framflyttades": "framflytta",
    "framflyttads": "framflytta",
    "framflyttande": "framflytta",
    "framflyttanden": "framflyttande",
    "framflyttandena": "framflyttande",
    "framflyttandenas": "framflyttande",
    "framflyttandens": "framflyttande",
    "framflyttandes": "framflyttande",
    "framflyttandet": "framflyttande",
    "framflyttandets": "framflyttande",
    "framflyttar": "framflytta",
    "framflyttas": "framflytta",
    "framflyttat": "framflytta",
    "framflyttats": "framflytta",
    "framfor": "framfara",
    "framfore": "framfara",
    "framfores": "framfara",
    "framfors": "framfara",
    "framfoten": "framfot",
    "framfotens": "framfot",
    "framfots": "framfot",
    "framfusiga": "framfusig",
    "framfusigare": "framfusig",
    "framfusigares": "framfusig",
    "framfusigas": "framfusig",
    "framfusigast": "framfusig",
    "framfusigaste": "framfusig",
    "framfusigastes": "framfusig",
    "framfusigasts": "framfusig",
    "framfusige": "framfusig",
    "framfusiges": "framfusig",
    "framfusigheten": "framfusighet",
    "framfusighetens": "framfusighet",
    "framfusighets": "framfusighet",
    "framfusigs": "framfusig",
    "framfusigt": "framfusig",
    "framfusigts": "framfusig",
    "framfärden": "framfärd",
    "framfärdens": "framfärd",
    "framfärder": "framfärd",
    "framfärderna": "framfärd",
    "framfärdernas": "framfärd",
    "framfärders": "framfärd",
    "framfärds": "framfärd",
    "framföd": "framföda",
    "framfödande": "framföda",
    "framfödanden": "framfödande",
    "framfödandena": "framfödande",
    "framfödandenas": "framfödande",
    "framfödandens": "framfödande",
    "framfödandes": "framfödande",
    "framfödandet": "framfödande",
    "framfödandets": "framfödande",
    "framfödas": "framföda",
    "framfödd": "framföda",
    "framfödda": "framföda",
    "framföddas": "framföda",
    "framfödde": "framföda",
    "framföddes": "framföda",
    "framfödds": "framföda",
    "framföder": "framföda",
    "framfödes": "framföda",
    "framföds": "framföda",
    "framför": "framföra",
    "framförande": "framföra",
    "framföranden": "framförande",
    "framförandena": "framförande",
    "framförandenas": "framförande",
    "framförandens": "framförande",
    "framförandes": "framförande",
    "framförandet": "framförande",
    "framförandets": "framförande",
    "framföras": "framföra",
    "framförd": "framföra",
    "framförda": "framföra",
    "framfördas": "framföra",
    "framförde": "framföra",
    "framfördes": "framföra",
    "framförds": "framföra",
    "framföres": "framföra",
    "framförhållningar": "framförhållning",
    "framförhållningarna": "framförhållning",
    "framförhållningarnas": "framförhållning",
    "framförhållningars": "framförhållning",
    "framförhållningen": "framförhållning",
    "framförhållningens": "framförhållning",
    "framförhållnings": "framförhållning",
    "framförs": "framföra",
    "framfört": "framföra",
    "framförts": "framföra",
    "framfött": "framföda",
    "framfötter": "framfot",
    "framfötterna": "framfot",
    "framfötternas": "framfot",
    "framfötters": "framfot",
    "framfötts": "framföda",
    "framgaffeln": "framgaffel",
    "framgaffelns": "framgaffel",
    "framgaffels": "framgaffel",
    "framgafflar": "framgaffel",
    "framgafflarna": "framgaffel",
    "framgafflarnas": "framgaffel",
    "framgafflars": "framgaffel",
    "framgick": "framgå",
    "framgicks": "framgå",
    "framginge": "framgå",
    "framginges": "framgå",
    "framgående": "framgå",
    "framgåenden": "framgående",
    "framgåendena": "framgående",
    "framgåendenas": "framgående",
    "framgåendens": "framgående",
    "framgåendes": "framgående",
    "framgåendet": "framgående",
    "framgåendets": "framgående",
    "framgångar": "framgång",
    "framgångarna": "framgång",
    "framgångarnas": "framgång",
    "framgångars": "framgång",
    "framgånge": "framgå",
    "framgången": "framgång",
    "framgångens": "framgång",
    "framgånges": "framgå",
    "framgånget": "framgå",
    "framgångets": "framgå",
    "framgångna": "framgå",
    "framgångnas": "framgå",
    "framgångne": "framgå",
    "framgångnes": "framgå",
    "framgångs": "framgång",
    "framgångshistorian": "framgångshistoria",
    "framgångshistorians": "framgångshistoria",
    "framgångshistorias": "framgångshistoria",
    "framgångshistorien": "framgångshistoria",
    "framgångshistoriens": "framgångshistoria",
    "framgångshistorier": "framgångshistoria",
    "framgångshistorierna": "framgångshistoria",
    "framgångshistoriernas": "framgångshistoria",
    "framgångshistoriers": "framgångshistoria",
    "framgångskoncepten": "framgångskoncept",
    "framgångskonceptens": "framgångskoncept",
    "framgångskonceptet": "framgångskoncept",
    "framgångskonceptets": "framgångskoncept",
    "framgångskoncepts": "framgångskoncept",
    "framgångsrecepten": "framgångsrecept",
    "framgångsreceptens": "framgångsrecept",
    "framgångsreceptet": "framgångsrecept",
    "framgångsreceptets": "framgångsrecept",
    "framgångsrecepts": "framgångsrecept",
    "framgångsrika": "framgångsrik",
    "framgångsrikare": "framgångsrik",
    "framgångsrikares": "framgångsrik",
    "framgångsrikas": "framgångsrik",
    "framgångsrikast": "framgångsrik",
    "framgångsrikaste": "framgångsrik",
    "framgångsrikastes": "framgångsrik",
    "framgångsrikasts": "framgångsrik",
    "framgångsrike": "framgångsrik",
    "framgångsrikes": "framgångsrik",
    "framgångsrikheten": "framgångsrikhet",
    "framgångsrikhetens": "framgångsrikhet",
    "framgångsrikhets": "framgångsrikhet",
    "framgångsriks": "framgångsrik",
    "framgångsrikt": "framgångsrik",
    "framgångsrikts": "framgångsrik",
    "framgår": "framgå",
    "framgås": "framgå",
    "framgått": "framgå",
    "framgåtts": "framgå",
    "framhjulen": "framhjul",
    "framhjulens": "framhjul",
    "framhjulet": "framhjul",
    "framhjulets": "framhjul",
    "framhjuls": "framhjul",
    "framhjulsdrivens": "framhjulsdriven",
    "framhjulsdrivet": "framhjulsdriven",
    "framhjulsdrivets": "framhjulsdriven",
    "framhjulsdrivna": "framhjulsdriven",
    "framhjulsdrivnare": "framhjulsdriven",
    "framhjulsdrivnares": "framhjulsdriven",
    "framhjulsdrivnas": "framhjulsdriven",
    "framhjulsdrivnast": "framhjulsdriven",
    "framhjulsdrivnaste": "framhjulsdriven",
    "framhjulsdrivnastes": "framhjulsdriven",
    "framhjulsdrivnasts": "framhjulsdriven",
    "framhjulsdrivne": "framhjulsdriven",
    "framhjulsdrivnes": "framhjulsdriven",
    "framhärdade": "framhärda",
    "framhärdades": "framhärda",
    "framhärdande": "framhärda",
    "framhärdanden": "framhärdande",
    "framhärdandena": "framhärdande",
    "framhärdandenas": "framhärdande",
    "framhärdandens": "framhärdande",
    "framhärdandes": "framhärdande",
    "framhärdandet": "framhärdande",
    "framhärdandets": "framhärdande",
    "framhärdar": "framhärda",
    "framhärdas": "framhärda",
    "framhärdat": "framhärda",
    "framhärdats": "framhärda",
    "framhäv": "framhäva",
    "framhävande": "framhäva",
    "framhävanden": "framhävande",
    "framhävandena": "framhävande",
    "framhävandenas": "framhävande",
    "framhävandens": "framhävande",
    "framhävandes": "framhävande",
    "framhävandet": "framhävande",
    "framhävandets": "framhävande",
    "framhävas": "framhäva",
    "framhävd": "framhäva",
    "framhävda": "framhäva",
    "framhävdas": "framhäva",
    "framhävde": "framhäva",
    "framhävdes": "framhäva",
    "framhävds": "framhäva",
    "framhäver": "framhäva",
    "framhäves": "framhäva",
    "framhävs": "framhäva",
    "framhävt": "framhäva",
    "framhävts": "framhäva",
    "framhåll": "framhålla",
    "framhållande": "framhålla",
    "framhållanden": "framhållande",
    "framhållandena": "framhållande",
    "framhållandenas": "framhållande",
    "framhållandens": "framhållande",
    "framhållandes": "framhållande",
    "framhållandet": "framhållande",
    "framhållandets": "framhållande",
    "framhållas": "framhålla",
    "framhålle": "framhålla",
    "framhållen": "framhålla",
    "framhållens": "framhålla",
    "framhåller": "framhålla",
    "framhålles": "framhålla",
    "framhållet": "framhålla",
    "framhållets": "framhålla",
    "framhållit": "framhålla",
    "framhållits": "framhålla",
    "framhållna": "framhålla",
    "framhållnas": "framhålla",
    "framhållne": "framhålla",
    "framhållnes": "framhålla",
    "framhålls": "framhålla",
    "framhöll": "framhålla",
    "framhölle": "framhålla",
    "framhölles": "framhålla",
    "framhölls": "framhålla",
    "framimproviserade": "framimproviserad",
    "framimproviserades": "framimproviserad",
    "framimproviserads": "framimproviserad",
    "framimproviserat": "framimproviserad",
    "framimproviserats": "framimproviserad",
    "framkall": "framkalla",
    "framkallad": "framkalla",
    "framkallade": "framkalla",
    "framkallades": "framkalla",
    "framkallads": "framkalla",
    "framkallande": "framkalla",
    "framkallanden": "framkallande",
    "framkallandena": "framkallande",
    "framkallandenas": "framkallande",
    "framkallandens": "framkallande",
    "framkallandes": "framkallande",
    "framkallandet": "framkallande",
    "framkallandets": "framkallande",
    "framkallar": "framkallare",
    "framkallaren": "framkallare",
    "framkallarens": "framkallare",
    "framkallares": "framkallare",
    "framkallarna": "framkallare",
    "framkallarnas": "framkallare",
    "framkallas": "framkalla",
    "framkallat": "framkalla",
    "framkallats": "framkalla",
    "framkallningar": "framkallning",
    "framkallningarna": "framkallning",
    "framkallningarnas": "framkallning",
    "framkallningars": "framkallning",
    "framkallningen": "framkallning",
    "framkallningens": "framkallning",
    "framkallnings": "framkallning",
    "framkallningsapparaten": "framkallningsapparat",
    "framkallningsapparatens": "framkallningsapparat",
    "framkallningsapparater": "framkallningsapparat",
    "framkallningsapparaterna": "framkallningsapparat",
    "framkallningsapparaternas": "framkallningsapparat",
    "framkallningsapparaters": "framkallningsapparat",
    "framkallningsapparats": "framkallningsapparat",
    "framkanten": "framkant",
    "framkantens": "framkant",
    "framkanter": "framkant",
    "framkanterna": "framkant",
    "framkanternas": "framkant",
    "framkanters": "framkant",
    "framkants": "framkant",
    "framkast": "framkasta",
    "framkastad": "framkasta",
    "framkastade": "framkasta",
    "framkastades": "framkasta",
    "framkastads": "framkasta",
    "framkastande": "framkasta",
    "framkastanden": "framkastande",
    "framkastandena": "framkastande",
    "framkastandenas": "framkastande",
    "framkastandens": "framkastande",
    "framkastandes": "framkastande",
    "framkastandet": "framkastande",
    "framkastandets": "framkastande",
    "framkastar": "framkasta",
    "framkastas": "framkasta",
    "framkastat": "framkasta",
    "framkastats": "framkasta",
    "framkom": "framkomma",
    "framkomet": "framkomma",
    "framkomets": "framkomma",
    "framkomliga": "framkomlig",
    "framkomligare": "framkomlig",
    "framkomligares": "framkomlig",
    "framkomligas": "framkomlig",
    "framkomligast": "framkomlig",
    "framkomligaste": "framkomlig",
    "framkomligastes": "framkomlig",
    "framkomligasts": "framkomlig",
    "framkomlige": "framkomlig",
    "framkomliges": "framkomlig",
    "framkomligheten": "framkomlighet",
    "framkomlighetens": "framkomlighet",
    "framkomligheter": "framkomlighet",
    "framkomligheterna": "framkomlighet",
    "framkomligheternas": "framkomlighet",
    "framkomligheters": "framkomlighet",
    "framkomlighets": "framkomlighet",
    "framkomligs": "framkomlig",
    "framkomligt": "framkomlig",
    "framkomligts": "framkomlig",
    "framkommande": "framkomma",
    "framkommanden": "framkommande",
    "framkommandena": "framkommande",
    "framkommandenas": "framkommande",
    "framkommandens": "framkommande",
    "framkommandes": "framkommande",
    "framkommandet": "framkommande",
    "framkommandets": "framkommande",
    "framkommas": "framkomma",
    "framkomme": "framkomma",
    "framkommen": "framkomma",
    "framkommens": "framkomma",
    "framkommer": "framkomma",
    "framkommes": "framkomma",
    "framkommit": "framkomma",
    "framkommits": "framkomma",
    "framkomna": "framkomma",
    "framkomnas": "framkomma",
    "framkomne": "framkomma",
    "framkomnes": "framkomma",
    "framkoms": "framkomma",
    "framkomsten": "framkomst",
    "framkomstens": "framkomst",
    "framkomsts": "framkomst",
    "framkörningar": "framkörning",
    "framkörningarna": "framkörning",
    "framkörningarnas": "framkörning",
    "framkörningars": "framkörning",
    "framkörningen": "framkörning",
    "framkörningens": "framkörning",
    "framkörnings": "framkörning",
    "framla": "framlägga",
    "framladdar": "framladdare",
    "framladdaren": "framladdare",
    "framladdarens": "framladdare",
    "framladdares": "framladdare",
    "framladdarna": "framladdare",
    "framladdarnas": "framladdare",
    "framladdningar": "framladdning",
    "framladdningarna": "framladdning",
    "framladdningarnas": "framladdning",
    "framladdningars": "framladdning",
    "framladdningen": "framladdning",
    "framladdningens": "framladdning",
    "framladdnings": "framladdning",
    "framlade": "framlägga",
    "framlades": "framlägga",
    "framlagd": "framlägga",
    "framlagda": "framlägga",
    "framlagdas": "framlägga",
    "framlagde": "framlägga",
    "framlagdes": "framlägga",
    "framlagds": "framlägga",
    "framlagt": "framlägga",
    "framlagts": "framlägga",
    "framlas": "framlägga",
    "framled": "framlida",
    "framleds": "framlida",
    "framlev": "framleva",
    "framlevande": "framleva",
    "framlevanden": "framlevande",
    "framlevandena": "framlevande",
    "framlevandenas": "framlevande",
    "framlevandens": "framlevande",
    "framlevandes": "framlevande",
    "framlevandet": "framlevande",
    "framlevandets": "framlevande",
    "framlevas": "framleva",
    "framlevat": "framleva",
    "framlevats": "framleva",
    "framlevd": "framleva",
    "framlevda": "framleva",
    "framlevdas": "framleva",
    "framlevde": "framleva",
    "framlevdes": "framleva",
    "framlevds": "framleva",
    "framlever": "framleva",
    "framleves": "framleva",
    "framlevs": "framleva",
    "framlevt": "framleva",
    "framlevts": "framleva",
    "framlid": "framlida",
    "framlidande": "framlida",
    "framlidanden": "framlidande",
    "framlidandena": "framlidande",
    "framlidandenas": "framlidande",
    "framlidandens": "framlidande",
    "framlidandes": "framlidande",
    "framlidandet": "framlidande",
    "framlidandets": "framlidande",
    "framlidas": "framlida",
    "framlide": "framlida",
    "framliden": "framlida",
    "framlidens": "framliden",
    "framlider": "framlida",
    "framlides": "framlida",
    "framlidet": "framliden",
    "framlidets": "framliden",
    "framlidit": "framlida",
    "framlidits": "framlida",
    "framlidna": "framliden",
    "framlidnare": "framliden",
    "framlidnares": "framliden",
    "framlidnas": "framliden",
    "framlidnast": "framliden",
    "framlidnaste": "framliden",
    "framlidnastes": "framliden",
    "framlidnasts": "framliden",
    "framlidne": "framliden",
    "framlidnes": "framliden",
    "framlids": "framlida",
    "framloben": "framlob",
    "framlobens": "framlob",
    "framlober": "framlob",
    "framloberna": "framlob",
    "framlobernas": "framlob",
    "framlobers": "framlob",
    "framlobs": "framlob",
    "framlägg": "framlägga",
    "framläggande": "framlägga",
    "framlägganden": "framläggande",
    "framläggandena": "framläggande",
    "framläggandenas": "framläggande",
    "framläggandens": "framläggande",
    "framläggandes": "framläggande",
    "framläggandet": "framläggande",
    "framläggandets": "framläggande",
    "framläggas": "framlägga",
    "framlägger": "framlägga",
    "framlägges": "framlägga",
    "framläggs": "framlägga",
    "framman": "frammana",
    "frammanad": "frammana",
    "frammanade": "frammana",
    "frammanades": "frammana",
    "frammanads": "frammana",
    "frammanande": "frammana",
    "frammananden": "frammanande",
    "frammanandena": "frammanande",
    "frammanandenas": "frammanande",
    "frammanandens": "frammanande",
    "frammanandes": "frammanande",
    "frammanandet": "frammanande",
    "frammanandets": "frammanande",
    "frammanar": "frammana",
    "frammanas": "frammana",
    "frammanat": "frammana",
    "frammanats": "frammana",
    "frammarschen": "frammarsch",
    "frammarschens": "frammarsch",
    "frammarscher": "frammarsch",
    "frammarscherna": "frammarsch",
    "frammarschernas": "frammarsch",
    "frammarschers": "frammarsch",
    "frammarschs": "frammarsch",
    "frammatad": "frammata",
    "frammatade": "frammata",
    "frammatades": "frammata",
    "frammatads": "frammata",
    "frammatande": "frammata",
    "frammatanden": "frammatande",
    "frammatandena": "frammatande",
    "frammatandenas": "frammatande",
    "frammatandens": "frammatande",
    "frammatandes": "frammatande",
    "frammatandet": "frammatande",
    "frammatandets": "frammatande",
    "frammatar": "frammata",
    "frammatas": "frammata",
    "frammatat": "frammata",
    "frammatats": "frammata",
    "frammatningar": "frammatning",
    "frammatningarna": "frammatning",
    "frammatningarnas": "frammatning",
    "frammatningars": "frammatning",
    "frammatningen": "frammatning",
    "frammatningens": "frammatning",
    "frammatnings": "frammatning",
    "framorkestrerade": "framorkestrerad",
    "framorkestrerades": "framorkestrerad",
    "framorkestrerads": "framorkestrerad",
    "framorkestrerat": "framorkestrerad",
    "framorkestrerats": "framorkestrerad",
    "frampress": "frampressa",
    "frampressad": "frampressa",
    "frampressade": "frampressa",
    "frampressades": "frampressa",
    "frampressads": "frampressa",
    "frampressande": "frampressa",
    "frampressandes": "frampressa",
    "frampressar": "frampressa",
    "frampressas": "frampressa",
    "frampressat": "frampressa",
    "frampressats": "frampressa",
    "framryckningar": "framryckning",
    "framryckningarna": "framryckning",
    "framryckningarnas": "framryckning",
    "framryckningars": "framryckning",
    "framryckningen": "framryckning",
    "framryckningens": "framryckning",
    "framrycknings": "framryckning",
    "framsade": "framsäga",
    "framsades": "framsäga",
    "framsagd": "framsäga",
    "framsagda": "framsäga",
    "framsagdas": "framsäga",
    "framsagde": "framsäga",
    "framsagdes": "framsäga",
    "framsagds": "framsäga",
    "framsagt": "framsäga",
    "framsagts": "framsäga",
    "framsidan": "framsida",
    "framsidans": "framsida",
    "framsidas": "framsida",
    "framside": "framsida",
    "framsides": "framsida",
    "framsidor": "framsida",
    "framsidorna": "framsida",
    "framsidornas": "framsida",
    "framsidors": "framsida",
    "framskjut": "framskjuta",
    "framskjutande": "framskjuta",
    "framskjutanden": "framskjutande",
    "framskjutandena": "framskjutande",
    "framskjutandenas": "framskjutande",
    "framskjutandens": "framskjutande",
    "framskjutandes": "framskjutande",
    "framskjutandet": "framskjutande",
    "framskjutandets": "framskjutande",
    "framskjutas": "framskjuta",
    "framskjute": "framskjuta",
    "framskjuten": "framskjuta",
    "framskjutens": "framskjuten",
    "framskjuter": "framskjuta",
    "framskjutes": "framskjuta",
    "framskjutet": "framskjuten",
    "framskjutets": "framskjuten",
    "framskjutit": "framskjuta",
    "framskjutits": "framskjuta",
    "framskjutna": "framskjuten",
    "framskjutnare": "framskjuten",
    "framskjutnares": "framskjuten",
    "framskjutnas": "framskjuten",
    "framskjutnast": "framskjuten",
    "framskjutnaste": "framskjuten",
    "framskjutnastes": "framskjuten",
    "framskjutnasts": "framskjuten",
    "framskjutne": "framskjuten",
    "framskjutnes": "framskjuten",
    "framskjuts": "framskjuta",
    "framskred": "framskrida",
    "framskreds": "framskrida",
    "framskrid": "framskrida",
    "framskridande": "framskrida",
    "framskridanden": "framskridande",
    "framskridandena": "framskridande",
    "framskridandenas": "framskridande",
    "framskridandens": "framskridande",
    "framskridandes": "framskridande",
    "framskridandet": "framskridande",
    "framskridandets": "framskridande",
    "framskridas": "framskrida",
    "framskride": "framskrida",
    "framskriden": "framskrida",
    "framskridens": "framskriden",
    "framskrider": "framskrida",
    "framskrides": "framskrida",
    "framskridet": "framskriden",
    "framskridets": "framskriden",
    "framskridit": "framskrida",
    "framskridits": "framskrida",
    "framskridna": "framskriden",
    "framskridnare": "framskriden",
    "framskridnares": "framskriden",
    "framskridnas": "framskriden",
    "framskridnast": "framskriden",
    "framskridnaste": "framskriden",
    "framskridnastes": "framskriden",
    "framskridnasts": "framskriden",
    "framskridne": "framskriden",
    "framskridnes": "framskriden",
    "framskrids": "framskrida",
    "framskymt": "framskymta",
    "framskymtad": "framskymta",
    "framskymtade": "framskymta",
    "framskymtades": "framskymta",
    "framskymtads": "framskymta",
    "framskymtande": "framskymta",
    "framskymtanden": "framskymtande",
    "framskymtandena": "framskymtande",
    "framskymtandenas": "framskymtande",
    "framskymtandens": "framskymtande",
    "framskymtandes": "framskymtande",
    "framskymtandet": "framskymtande",
    "framskymtandets": "framskymtande",
    "framskymtar": "framskymta",
    "framskymtas": "framskymta",
    "framskymtat": "framskymta",
    "framskymtats": "framskymta",
    "framsköt": "framskjuta",
    "framsköte": "framskjuta",
    "framskötes": "framskjuta",
    "framsköts": "framskjuta",
    "framspelar": "framspelare",
    "framspelaren": "framspelare",
    "framspelarens": "framspelare",
    "framspelares": "framspelare",
    "framspelarna": "framspelare",
    "framspelarnas": "framspelare",
    "framspelningar": "framspelning",
    "framspelningarna": "framspelning",
    "framspelningarnas": "framspelning",
    "framspelningars": "framspelning",
    "framspelningen": "framspelning",
    "framspelningens": "framspelning",
    "framspelnings": "framspelning",
    "framstammar": "framstam",
    "framstammarna": "framstam",
    "framstammarnas": "framstam",
    "framstammars": "framstam",
    "framstammen": "framstam",
    "framstammens": "framstam",
    "framstams": "framstam",
    "framstegen": "framsteg",
    "framstegens": "framsteg",
    "framsteget": "framsteg",
    "framstegets": "framsteg",
    "framstegs": "framsteg",
    "framstegsandan": "framstegsanda",
    "framstegsandans": "framstegsanda",
    "framstegsandas": "framstegsanda",
    "framstegspartier": "framstegsparti",
    "framstegspartierna": "framstegsparti",
    "framstegspartiernas": "framstegsparti",
    "framstegspartiers": "framstegsparti",
    "framstegspartiet": "framstegsparti",
    "framstegspartiets": "framstegsparti",
    "framstegspartis": "framstegsparti",
    "framstegspartit": "framstegsparti",
    "framstegspartits": "framstegsparti",
    "framstegsvänliga": "framstegsvänlig",
    "framstegsvänligare": "framstegsvänlig",
    "framstegsvänligares": "framstegsvänlig",
    "framstegsvänligas": "framstegsvänlig",
    "framstegsvänligast": "framstegsvänlig",
    "framstegsvänligaste": "framstegsvänlig",
    "framstegsvänligastes": "framstegsvänlig",
    "framstegsvänligasts": "framstegsvänlig",
    "framstegsvänlige": "framstegsvänlig",
    "framstegsvänliges": "framstegsvänlig",
    "framstegsvänligheten": "framstegsvänlighet",
    "framstegsvänlighetens": "framstegsvänlighet",
    "framstegsvänlighets": "framstegsvänlighet",
    "framstegsvänligs": "framstegsvänlig",
    "framstegsvänligt": "framstegsvänlig",
    "framstegsvänligts": "framstegsvänlig",
    "framstod": "framstå",
    "framstode": "framstå",
    "framstodes": "framstå",
    "framstods": "framstå",
    "framstycken": "framstycke",
    "framstyckena": "framstycke",
    "framstyckenas": "framstycke",
    "framstyckens": "framstycke",
    "framstyckes": "framstycke",
    "framstycket": "framstycke",
    "framstyckets": "framstycke",
    "framstycks": "framstycke",
    "framställ": "framställa",
    "framställande": "framställa",
    "framställanden": "framställande",
    "framställandena": "framställande",
    "framställandenas": "framställande",
    "framställandens": "framställande",
    "framställandes": "framställande",
    "framställandet": "framställande",
    "framställandets": "framställande",
    "framställans": "framställan",
    "framställas": "framställa",
    "framställd": "framställa",
    "framställda": "framställa",
    "framställdas": "framställa",
    "framställde": "framställa",
    "framställdes": "framställa",
    "framställds": "framställa",
    "framställer": "framställa",
    "framställes": "framställa",
    "framställningar": "framställning",
    "framställningarna": "framställning",
    "framställningarnas": "framställning",
    "framställningars": "framställning",
    "framställningen": "framställning",
    "framställningens": "framställning",
    "framställnings": "framställning",
    "framställs": "framställa",
    "framställt": "framställa",
    "framställts": "framställa",
    "framstående": "framstå",
    "framståenden": "framstående",
    "framståendena": "framstående",
    "framståendenas": "framstående",
    "framståendens": "framstående",
    "framståendes": "framstående",
    "framståendet": "framstående",
    "framståendets": "framstående",
    "framstår": "framstå",
    "framstås": "framstå",
    "framstått": "framstå",
    "framståtts": "framstå",
    "framstötar": "framstöt",
    "framstötarna": "framstöt",
    "framstötarnas": "framstöt",
    "framstötars": "framstöt",
    "framstöten": "framstöt",
    "framstötens": "framstöt",
    "framstöts": "framstöt",
    "framsynta": "framsynt",
    "framsyntare": "framsynt",
    "framsyntares": "framsynt",
    "framsyntas": "framsynt",
    "framsyntast": "framsynt",
    "framsyntaste": "framsynt",
    "framsyntastes": "framsynt",
    "framsyntasts": "framsynt",
    "framsynte": "framsynt",
    "framsyntes": "framsynt",
    "framsyntheten": "framsynthet",
    "framsynthetens": "framsynthet",
    "framsynthets": "framsynthet",
    "framsynts": "framsynt",
    "framsäg": "framsäga",
    "framsägande": "framsäga",
    "framsäganden": "framsägande",
    "framsägandena": "framsägande",
    "framsägandenas": "framsägande",
    "framsägandens": "framsägande",
    "framsägandes": "framsägande",
    "framsägandet": "framsägande",
    "framsägandets": "framsägande",
    "framsägas": "framsäga",
    "framsäger": "framsäga",
    "framsäges": "framsäga",
    "framsägs": "framsäga",
    "framsäten": "framsäte",
    "framsätena": "framsäte",
    "framsätenas": "framsäte",
    "framsätens": "framsäte",
    "framsätes": "framsäte",
    "framsätet": "framsäte",
    "framsätets": "framsäte",
    "framtanden": "framtand",
    "framtandens": "framtand",
    "framtands": "framtand",
    "framtiden": "framtid",
    "framtidens": "framtid",
    "framtider": "framtid",
    "framtiderna": "framtid",
    "framtidernas": "framtid",
    "framtiders": "framtid",
    "framtids": "framtid",
    "framtidsforskar": "framtidsforskare",
    "framtidsforskaren": "framtidsforskare",
    "framtidsforskarens": "framtidsforskare",
    "framtidsforskares": "framtidsforskare",
    "framtidsforskarna": "framtidsforskare",
    "framtidsforskarnas": "framtidsforskare",
    "framtidsforskningar": "framtidsforskning",
    "framtidsforskningarna": "framtidsforskning",
    "framtidsforskningarnas": "framtidsforskning",
    "framtidsforskningars": "framtidsforskning",
    "framtidsforskningen": "framtidsforskning",
    "framtidsforskningens": "framtidsforskning",
    "framtidsforsknings": "framtidsforskning",
    "framtidsfrågan": "framtidsfråga",
    "framtidsfrågans": "framtidsfråga",
    "framtidsfrågas": "framtidsfråga",
    "framtidsfråge": "framtidsfråga",
    "framtidsfrågor": "framtidsfråga",
    "framtidsfrågorna": "framtidsfråga",
    "framtidsfrågornas": "framtidsfråga",
    "framtidsfrågors": "framtidsfråga",
    "framtidsinriktade": "framtidsinriktad",
    "framtidsinriktades": "framtidsinriktad",
    "framtidsinriktads": "framtidsinriktad",
    "framtidsinriktat": "framtidsinriktad",
    "framtidsinriktats": "framtidsinriktad",
    "framtidskalkylen": "framtidskalkyl",
    "framtidskalkylens": "framtidskalkyl",
    "framtidskalkyler": "framtidskalkyl",
    "framtidskalkylerna": "framtidskalkyl",
    "framtidskalkylernas": "framtidskalkyl",
    "framtidskalkylers": "framtidskalkyl",
    "framtidskalkyls": "framtidskalkyl",
    "framtidslöften": "framtidslöfte",
    "framtidslöftena": "framtidslöfte",
    "framtidslöftenas": "framtidslöfte",
    "framtidslöftens": "framtidslöfte",
    "framtidslöftes": "framtidslöfte",
    "framtidslöftet": "framtidslöfte",
    "framtidslöftets": "framtidslöfte",
    "framtidsmannen": "framtidsman",
    "framtidsmannens": "framtidsman",
    "framtidsmans": "framtidsman",
    "framtidsmän": "framtidsman",
    "framtidsmännen": "framtidsman",
    "framtidsmännens": "framtidsman",
    "framtidsmäns": "framtidsman",
    "framtidssatsningar": "framtidssatsning",
    "framtidssatsningarna": "framtidssatsning",
    "framtidssatsningarnas": "framtidssatsning",
    "framtidssatsningars": "framtidssatsning",
    "framtidssatsningen": "framtidssatsning",
    "framtidssatsningens": "framtidssatsning",
    "framtidssatsnings": "framtidssatsning",
    "framtidstron": "framtidstro",
    "framtidstrons": "framtidstro",
    "framtidstros": "framtidstro",
    "framtidsutsikten": "framtidsutsikt",
    "framtidsutsiktens": "framtidsutsikt",
    "framtidsutsikter": "framtidsutsikt",
    "framtidsutsikterna": "framtidsutsikter",
    "framtidsutsikternas": "framtidsutsikter",
    "framtidsutsikters": "framtidsutsikter",
    "framtidsutsikts": "framtidsutsikter",
    "framtidsversionen": "framtidsversion",
    "framtidsversionens": "framtidsversion",
    "framtidsversioner": "framtidsversion",
    "framtidsversionerna": "framtidsversion",
    "framtidsversionernas": "framtidsversion",
    "framtidsversioners": "framtidsversion",
    "framtidsversions": "framtidsversion",
    "framtidsvisionen": "framtidsvision",
    "framtidsvisionens": "framtidsvision",
    "framtidsvisioner": "framtidsvision",
    "framtidsvisionerna": "framtidsvision",
    "framtidsvisionernas": "framtidsvision",
    "framtidsvisioners": "framtidsvision",
    "framtidsvisions": "framtidsvision",
    "framtidsvyer": "framtidsvy",
    "framtidsvyerna": "framtidsvy",
    "framtidsvyernas": "framtidsvy",
    "framtidsvyers": "framtidsvy",
    "framtidsvyn": "framtidsvy",
    "framtidsvyns": "framtidsvy",
    "framtidsvys": "framtidsvy",
    "framtonade": "framtona",
    "framtonades": "framtona",
    "framtonande": "framtona",
    "framtonanden": "framtonande",
    "framtonandena": "framtonande",
    "framtonandenas": "framtonande",
    "framtonandens": "framtonande",
    "framtonandes": "framtonande",
    "framtonandet": "framtonande",
    "framtonandets": "framtonande",
    "framtonar": "framtona",
    "framtonas": "framtona",
    "framtonat": "framtona",
    "framtonats": "framtona",
    "framtoningar": "framtoning",
    "framtoningarna": "framtoning",
    "framtoningarnas": "framtoning",
    "framtoningars": "framtoning",
    "framtoningen": "framtoning",
    "framtoningens": "framtoning",
    "framtonings": "framtoning",
    "framträd": "framträda",
    "framträdande": "framträda",
    "framträdanden": "framträdande",
    "framträdandena": "framträdande",
    "framträdandenas": "framträdande",
    "framträdandens": "framträdande",
    "framträdandes": "framträdande",
    "framträdandet": "framträdande",
    "framträdandets": "framträdande",
    "framträdas": "framträda",
    "framträdd": "framträda",
    "framträdda": "framträda",
    "framträddas": "framträda",
    "framträdde": "framträda",
    "framträddes": "framträda",
    "framträdds": "framträda",
    "framträder": "framträda",
    "framträdes": "framträda",
    "framträds": "framträda",
    "framträng": "framtränga",
    "framträngande": "framtränga",
    "framträngandes": "framträngande",
    "framträngandet": "framträngande",
    "framträngandets": "framträngande",
    "framträngas": "framtränga",
    "framträngd": "framtränga",
    "framträngda": "framtränga",
    "framträngdas": "framtränga",
    "framträngde": "framtränga",
    "framträngdes": "framtränga",
    "framträngds": "framtränga",
    "framtränger": "framtränga",
    "framtränges": "framtränga",
    "framträngs": "framtränga",
    "framträngt": "framtränga",
    "framträngts": "framtränga",
    "framträtt": "framträda",
    "framträtts": "framträda",
    "framtunga": "framtung",
    "framtungare": "framtung",
    "framtungares": "framtung",
    "framtungas": "framtung",
    "framtungast": "framtung",
    "framtungaste": "framtung",
    "framtungastes": "framtung",
    "framtungasts": "framtung",
    "framtunge": "framtung",
    "framtunges": "framtung",
    "framtungheten": "framtunghet",
    "framtunghetens": "framtunghet",
    "framtunghets": "framtunghet",
    "framtungs": "framtung",
    "framtungt": "framtung",
    "framtungts": "framtung",
    "framtving": "framtvinga",
    "framtvingad": "framtvinga",
    "framtvingade": "framtvinga",
    "framtvingades": "framtvinga",
    "framtvingads": "framtvinga",
    "framtvingande": "framtvinga",
    "framtvinganden": "framtvingande",
    "framtvingandena": "framtvingande",
    "framtvingandenas": "framtvingande",
    "framtvingandens": "framtvingande",
    "framtvingandes": "framtvingande",
    "framtvingandet": "framtvingande",
    "framtvingandets": "framtvingande",
    "framtvingar": "framtvinga",
    "framtvingas": "framtvinga",
    "framtvingat": "framtvinga",
    "framtvingats": "framtvinga",
    "framtvinge": "framtvinga",
    "framtvinges": "framtvinga",
    "framtvunge": "framtvinga",
    "framtvungen": "framtvinga",
    "framtvungens": "framtvinga",
    "framtvunges": "framtvinga",
    "framtvunget": "framtvinga",
    "framtvungets": "framtvinga",
    "framtvungit": "framtvinga",
    "framtvungits": "framtvinga",
    "framtvungna": "framtvinga",
    "framtvungnas": "framtvinga",
    "framtvungne": "framtvinga",
    "framtvungnes": "framtvinga",
    "framtänder": "framtand",
    "framtänderna": "framtand",
    "framtändernas": "framtand",
    "framtänders": "framtand",
    "framvagnar": "framvagn",
    "framvagnarna": "framvagn",
    "framvagnarnas": "framvagn",
    "framvagnars": "framvagn",
    "framvagnen": "framvagn",
    "framvagnens": "framvagn",
    "framvagns": "framvagn",
    "framvisad": "framvisa",
    "framvisade": "framvisa",
    "framvisades": "framvisa",
    "framvisads": "framvisa",
    "framvisande": "framvisa",
    "framvisanden": "framvisande",
    "framvisandena": "framvisande",
    "framvisandenas": "framvisande",
    "framvisandens": "framvisande",
    "framvisandes": "framvisande",
    "framvisandet": "framvisande",
    "framvisandets": "framvisande",
    "framvisar": "framvisa",
    "framvisas": "framvisa",
    "framvisat": "framvisa",
    "framvisats": "framvisa",
    "framvuxe": "framväxa",
    "framvuxen": "framväxa",
    "framvuxens": "framväxa",
    "framvuxet": "framväxa",
    "framvuxets": "framväxa",
    "framvuxit": "framväxa",
    "framvuxna": "framväxa",
    "framvuxnas": "framväxa",
    "framvuxne": "framväxa",
    "framvuxnes": "framväxa",
    "framväx": "framväxa",
    "framväxande": "framväxa",
    "framväxanden": "framväxande",
    "framväxandena": "framväxande",
    "framväxandenas": "framväxande",
    "framväxandens": "framväxande",
    "framväxandes": "framväxande",
    "framväxandet": "framväxande",
    "framväxandets": "framväxande",
    "framväxe": "framväxa",
    "framväxer": "framväxa",
    "framväxt": "framväxa",
    "framväxte": "framväxa",
    "framväxten": "framväxt",
    "framväxtens": "framväxt",
    "framväxts": "framväxt",
    "framänd": "framända",
    "framändan": "framända",
    "framändans": "framända",
    "framändar": "framände",
    "framändarna": "framände",
    "framändarnas": "framände",
    "framändars": "framände",
    "framändas": "framända",
    "framände": "framända",
    "framänden": "framände",
    "framändens": "framände",
    "framändes": "framände",
    "framändor": "framända",
    "framändorna": "framända",
    "framändornas": "framända",
    "framändors": "framända",
    "framänds": "framända",
    "framåtandan": "framåtanda",
    "framåtandans": "framåtanda",
    "framåtandas": "framåtanda",
    "framåtriktade": "framåtriktad",
    "framåtriktades": "framåtriktad",
    "framåtriktads": "framåtriktad",
    "framåtriktat": "framåtriktad",
    "framåtriktats": "framåtriktad",
    "framåtskridandes": "framåtskridande",
    "framåtskridandet": "framåtskridande",
    "framåtskridandets": "framåtskridande",
    "francen": "franc",
    "francens": "franc",
    "franchisingen": "franchising",
    "franchisingens": "franchising",
    "franchisings": "franchising",
    "franciet": "francium",
    "franciets": "francium",
    "franciskanen": "franciskan",
    "franciskanens": "franciskan",
    "franciskaner": "franciskan",
    "franciskanerklosterna": "franciskanerkloster",
    "franciskanerklosternas": "franciskanerkloster",
    "franciskanerklosters": "franciskanerkloster",
    "franciskanerklostren": "franciskanerkloster",
    "franciskanerklostrens": "franciskanerkloster",
    "franciskanerklostret": "franciskanerkloster",
    "franciskanerklostrets": "franciskanerkloster",
    "franciskanermunkar": "franciskanermunk",
    "franciskanermunkarna": "franciskanermunk",
    "franciskanermunkarnas": "franciskanermunk",
    "franciskanermunkars": "franciskanermunk",
    "franciskanermunken": "franciskanermunk",
    "franciskanermunkens": "franciskanermunk",
    "franciskanermunks": "franciskanermunk",
    "franciskanerna": "franciskan",
    "franciskanernas": "franciskan",
    "franciskanerordens": "franciskanerorden",
    "franciskanerordnar": "franciskanerorden",
    "franciskanerordnarna": "franciskanerorden",
    "franciskanerordnarnas": "franciskanerorden",
    "franciskanerordnars": "franciskanerorden",
    "franciskanerordnen": "franciskanerorden",
    "franciskanerordnens": "franciskanerorden",
    "franciskaners": "franciskan",
    "franciskanordens": "franciskanorden",
    "franciskanordnar": "franciskanorden",
    "franciskanordnarna": "franciskanorden",
    "franciskanordnarnas": "franciskanorden",
    "franciskanordnars": "franciskanorden",
    "franciskanordnen": "franciskanorden",
    "franciskanordnens": "franciskanorden",
    "franciskans": "franciskan",
    "franciumet": "francium",
    "franciumets": "francium",
    "franciums": "francium",
    "francs": "franc",
    "francsen": "franc",
    "francsens": "franc",
    "frangulabarken": "frangulabark",
    "frangulabarkens": "frangulabark",
    "frangulabarks": "frangulabark",
    "franka": "frank",
    "frankare": "frank",
    "frankares": "frank",
    "frankas": "frank",
    "frankast": "frank",
    "frankaste": "frank",
    "frankastes": "frank",
    "frankasts": "frank",
    "franke": "frank",
    "franken": "frank",
    "frankens": "frank",
    "franker": "frank",
    "frankerad": "frankera",
    "frankerade": "frankera",
    "frankerades": "frankera",
    "frankerads": "frankera",
    "frankerande": "frankera",
    "frankeranden": "frankerande",
    "frankerandena": "frankerande",
    "frankerandenas": "frankerande",
    "frankerandens": "frankerande",
    "frankerandes": "frankerande",
    "frankerandet": "frankerande",
    "frankerandets": "frankerande",
    "frankerar": "frankera",
    "frankeras": "frankera",
    "frankerat": "frankera",
    "frankerats": "frankera",
    "frankerbara": "frankerbar",
    "frankerbarare": "frankerbar",
    "frankerbarares": "frankerbar",
    "frankerbaras": "frankerbar",
    "frankerbarast": "frankerbar",
    "frankerbaraste": "frankerbar",
    "frankerbarastes": "frankerbar",
    "frankerbarasts": "frankerbar",
    "frankerbare": "frankerbar",
    "frankerbares": "frankerbar",
    "frankerbarheten": "frankerbarhet",
    "frankerbarhetens": "frankerbarhet",
    "frankerbarhets": "frankerbarhet",
    "frankerbars": "frankerbar",
    "frankerbart": "frankerbar",
    "frankerbarts": "frankerbar",
    "frankeringar": "frankering",
    "frankeringarna": "frankering",
    "frankeringarnas": "frankering",
    "frankeringars": "frankering",
    "frankeringen": "frankering",
    "frankeringens": "frankering",
    "frankerings": "frankering",
    "frankerna": "frank",
    "frankernas": "frank",
    "frankers": "frank",
    "frankes": "frank",
    "frankheten": "frankhet",
    "frankhetens": "frankhet",
    "frankhets": "frankhet",
    "frankisten": "frankist",
    "frankistens": "frankist",
    "frankister": "frankist",
    "frankisterna": "frankist",
    "frankisternas": "frankist",
    "frankisters": "frankist",
    "frankists": "frankist",
    "frankostämpeln": "frankostämpel",
    "frankostämpelns": "frankostämpel",
    "frankostämpels": "frankostämpel",
    "frankostämplar": "frankostämpel",
    "frankostämplarna": "frankostämpel",
    "frankostämplarnas": "frankostämpel",
    "frankostämplars": "frankostämpel",
    "frankoteckens": "frankotecken",
    "frankotecknen": "frankotecken",
    "frankotecknens": "frankotecken",
    "frankotecknet": "frankotecken",
    "frankotecknets": "frankotecken",
    "frankt": "frank",
    "frankts": "frank",
    "frans": "fransa",
    "fransad": "fransa",
    "fransade": "fransad",
    "fransades": "fransad",
    "fransads": "fransad",
    "fransande": "fransa",
    "fransanden": "fransande",
    "fransandena": "fransande",
    "fransandenas": "fransande",
    "fransandens": "fransande",
    "fransandes": "fransande",
    "fransandet": "fransande",
    "fransandets": "fransande",
    "fransar": "fransa",
    "fransarna": "frans",
    "fransarnas": "frans",
    "fransars": "frans",
    "fransas": "fransa",
    "fransat": "fransad",
    "fransats": "fransad",
    "fransen": "frans",
    "fransens": "frans",
    "fransiga": "fransig",
    "fransigare": "fransig",
    "fransigares": "fransig",
    "fransigas": "fransig",
    "fransigast": "fransig",
    "fransigaste": "fransig",
    "fransigastes": "fransig",
    "fransigasts": "fransig",
    "fransige": "fransig",
    "fransiges": "fransig",
    "fransigheten": "fransighet",
    "fransighetens": "fransighet",
    "fransighets": "fransighet",
    "fransigs": "fransig",
    "fransigt": "fransig",
    "fransigts": "fransig",
    "fransk": "franska",
    "franska": "fransk",
    "franskan": "franska",
    "franskana": "franska",
    "franskanas": "franska",
    "franskans": "franska",
    "franskare": "fransk",
    "franskares": "fransk",
    "franskas": "franska",
    "franskast": "fransk",
    "franskaste": "fransk",
    "franskastes": "fransk",
    "franskasts": "fransk",
    "franskat": "franska",
    "franskats": "franska",
    "franskbröden": "franskbröd",
    "franskbrödens": "franskbröd",
    "franskbrödet": "franskbröd",
    "franskbrödets": "franskbröd",
    "franskbröds": "franskbröd",
    "franske": "fransk",
    "franskes": "fransk",
    "franskheten": "franskhet",
    "franskhetens": "franskhet",
    "franskhets": "franskhet",
    "franskklassicismen": "franskklassicism",
    "franskklassicismens": "franskklassicism",
    "franskklassicismer": "franskklassicism",
    "franskklassicismerna": "franskklassicism",
    "franskklassicismernas": "franskklassicism",
    "franskklassicismers": "franskklassicism",
    "franskklassicisms": "franskklassicism",
    "franskklassicistiska": "franskklassicistisk",
    "franskklassicistiskas": "franskklassicistisk",
    "franskklassicistiske": "franskklassicistisk",
    "franskklassicistiskes": "franskklassicistisk",
    "franskklassicistisks": "franskklassicistisk",
    "franskklassicistiskt": "franskklassicistisk",
    "franskklassicistiskts": "franskklassicistisk",
    "franskklassiska": "franskklassisk",
    "franskklassiskare": "franskklassisk",
    "franskklassiskares": "franskklassisk",
    "franskklassiskas": "franskklassisk",
    "franskklassiskast": "franskklassisk",
    "franskklassiskaste": "franskklassisk",
    "franskklassiskastes": "franskklassisk",
    "franskklassiskasts": "franskklassisk",
    "franskklassiske": "franskklassisk",
    "franskklassiskes": "franskklassisk",
    "franskklassisks": "franskklassisk",
    "franskklassiskt": "franskklassisk",
    "franskklassiskts": "franskklassisk",
    "franskkursen": "franskkurs",
    "franskkursens": "franskkurs",
    "franskkurser": "franskkurs",
    "franskkurserna": "franskkurs",
    "franskkursernas": "franskkurs",
    "franskkursers": "franskkurs",
    "fransklektionen": "fransklektion",
    "fransklektionens": "fransklektion",
    "fransklektioner": "fransklektion",
    "fransklektionerna": "fransklektion",
    "fransklektionernas": "fransklektion",
    "fransklektioners": "fransklektion",
    "fransklektions": "fransklektion",
    "fransklärar": "fransklärare",
    "franskläraren": "fransklärare",
    "fransklärarens": "fransklärare",
    "fransklärares": "fransklärare",
    "fransklärarna": "fransklärare",
    "fransklärarnas": "fransklärare",
    "franskor": "franska",
    "franskorna": "franska",
    "franskornas": "franska",
    "franskors": "franska",
    "fransks": "fransk",
    "franskspråkiga": "franskspråkig",
    "franskspråkigas": "franskspråkig",
    "franskspråkige": "franskspråkig",
    "franskspråkiges": "franskspråkig",
    "franskspråkigheten": "franskspråkighet",
    "franskspråkighetens": "franskspråkighet",
    "franskspråkighets": "franskspråkighet",
    "franskspråkigs": "franskspråkig",
    "franskspråkigt": "franskspråkig",
    "franskspråkigts": "franskspråkig",
    "franskstyrde": "franskstyrd",
    "franskstyrdes": "franskstyrd",
    "franskstyrds": "franskstyrd",
    "franskstyrt": "franskstyrd",
    "franskstyrts": "franskstyrd",
    "franskt": "fransk",
    "franskts": "fransk",
    "franskundervisningen": "franskundervisning",
    "franskundervisningens": "franskundervisning",
    "franskundervisnings": "franskundervisning",
    "fransmannen": "fransman",
    "fransmannens": "fransman",
    "fransmans": "fransman",
    "fransmän": "fransman",
    "fransmännen": "fransman",
    "fransmännens": "fransman",
    "fransmäns": "fransman",
    "fransosen": "fransos",
    "fransosens": "fransos",
    "fransoser": "fransos",
    "fransoserna": "fransos",
    "fransosernas": "fransos",
    "fransosers": "fransos",
    "fransyskan": "fransyska",
    "fransyskans": "fransyska",
    "fransyskas": "fransyska",
    "fransyske": "fransyska",
    "fransyskor": "fransyska",
    "fransyskorna": "fransyska",
    "fransyskornas": "fransyska",
    "fransyskors": "fransyska",
    "fransäsen": "fransäs",
    "fransäsens": "fransäs",
    "fransäser": "fransäs",
    "fransäserna": "fransäs",
    "fransäsernas": "fransäs",
    "fransäsers": "fransäs",
    "frappanta": "frappant",
    "frappantare": "frappant",
    "frappantares": "frappant",
    "frappantas": "frappant",
    "frappantast": "frappant",
    "frappantaste": "frappant",
    "frappantastes": "frappant",
    "frappantasts": "frappant",
    "frappante": "frappant",
    "frappantes": "frappant",
    "frappants": "frappant",
    "frapperad": "frappera",
    "frapperade": "frappera",
    "frapperades": "frappera",
    "frapperads": "frappera",
    "frapperande": "frappera",
    "frapperanden": "frapperande",
    "frapperandena": "frapperande",
    "frapperandenas": "frapperande",
    "frapperandens": "frapperande",
    "frapperandes": "frapperande",
    "frapperandet": "frapperande",
    "frapperandets": "frapperande",
    "frapperar": "frappera",
    "frapperas": "frappera",
    "frapperat": "frappera",
    "frapperats": "frappera",
    "frapperingar": "frappering",
    "frapperingarna": "frappering",
    "frapperingarnas": "frappering",
    "frapperingars": "frappering",
    "frapperingen": "frappering",
    "frapperingens": "frappering",
    "frapperings": "frappering",
    "frasade": "frasa",
    "frasades": "frasa",
    "frasande": "frasa",
    "frasanden": "frasande",
    "frasandena": "frasande",
    "frasandenas": "frasande",
    "frasandens": "frasande",
    "frasandes": "frasande",
    "frasandet": "frasande",
    "frasandets": "frasande",
    "frasar": "frasa",
    "frasas": "frasa",
    "frasat": "frasa",
    "frasats": "frasa",
    "frasen": "fras",
    "frasens": "fras",
    "fraseologien": "fraseologi",
    "fraseologiens": "fraseologi",
    "fraseologin": "fraseologi",
    "fraseologins": "fraseologi",
    "fraseologis": "fraseologi",
    "fraseologiska": "fraseologisk",
    "fraseologiskare": "fraseologisk",
    "fraseologiskares": "fraseologisk",
    "fraseologiskas": "fraseologisk",
    "fraseologiskast": "fraseologisk",
    "fraseologiskaste": "fraseologisk",
    "fraseologiskastes": "fraseologisk",
    "fraseologiskasts": "fraseologisk",
    "fraseologiske": "fraseologisk",
    "fraseologiskes": "fraseologisk",
    "fraseologisks": "fraseologisk",
    "fraseologiskt": "fraseologisk",
    "fraseologiskts": "fraseologisk",
    "fraser": "fras",
    "fraserad": "frasera",
    "fraserade": "frasera",
    "fraserades": "frasera",
    "fraserads": "frasera",
    "fraserande": "frasera",
    "fraseranden": "fraserande",
    "fraserandena": "fraserande",
    "fraserandenas": "fraserande",
    "fraserandens": "fraserande",
    "fraserandes": "fraserande",
    "fraserandet": "fraserande",
    "fraserandets": "fraserande",
    "fraserar": "frasera",
    "fraseras": "frasera",
    "fraserat": "frasera",
    "fraserats": "frasera",
    "fraserbara": "fraserbar",
    "fraserbarare": "fraserbar",
    "fraserbarares": "fraserbar",
    "fraserbaras": "fraserbar",
    "fraserbarast": "fraserbar",
    "fraserbaraste": "fraserbar",
    "fraserbarastes": "fraserbar",
    "fraserbarasts": "fraserbar",
    "fraserbare": "fraserbar",
    "fraserbares": "fraserbar",
    "fraserbarheten": "fraserbarhet",
    "fraserbarhetens": "fraserbarhet",
    "fraserbarhets": "fraserbarhet",
    "fraserbars": "fraserbar",
    "fraserbart": "fraserbar",
    "fraserbarts": "fraserbar",
    "fraseringar": "frasering",
    "fraseringarna": "frasering",
    "fraseringarnas": "frasering",
    "fraseringars": "frasering",
    "fraseringen": "frasering",
    "fraseringens": "frasering",
    "fraserings": "frasering",
    "fraserna": "fras",
    "frasernas": "fras",
    "frasers": "fras",
    "fraset": "fras",
    "frasets": "fras",
    "frasiga": "frasig",
    "frasigare": "frasig",
    "frasigares": "frasig",
    "frasigas": "frasig",
    "frasigast": "frasig",
    "frasigaste": "frasig",
    "frasigastes": "frasig",
    "frasigasts": "frasig",
    "frasige": "frasig",
    "frasiges": "frasig",
    "frasigs": "frasig",
    "frasigt": "frasig",
    "frasigts": "frasig",
    "frasliberala": "frasliberal",
    "frasliberalare": "frasliberal",
    "frasliberalares": "frasliberal",
    "frasliberalas": "frasliberal",
    "frasliberalast": "frasliberal",
    "frasliberalaste": "frasliberal",
    "frasliberalastes": "frasliberal",
    "frasliberalasts": "frasliberal",
    "frasliberale": "frasliberal",
    "frasliberalen": "frasliberal",
    "frasliberalens": "frasliberal",
    "frasliberaler": "frasliberal",
    "frasliberalerna": "frasliberal",
    "frasliberalernas": "frasliberal",
    "frasliberalers": "frasliberal",
    "frasliberales": "frasliberal",
    "frasliberals": "frasliberal",
    "frasliberalt": "frasliberal",
    "frasliberalts": "frasliberal",
    "frasmakar": "frasmakare",
    "frasmakaren": "frasmakare",
    "frasmakarens": "frasmakare",
    "frasmakares": "frasmakare",
    "frasmakarna": "frasmakare",
    "frasmakarnas": "frasmakare",
    "frasmakerier": "frasmakeri",
    "frasmakerierna": "frasmakeri",
    "frasmakeriernas": "frasmakeri",
    "frasmakeriers": "frasmakeri",
    "frasmakeriet": "frasmakeri",
    "frasmakeriets": "frasmakeri",
    "frasmakeris": "frasmakeri",
    "frasmakerit": "frasmakeri",
    "frasmakerits": "frasmakeri",
    "frasnäten": "frasnät",
    "frasnätens": "frasnät",
    "frasnätet": "frasnät",
    "frasnätets": "frasnät",
    "frasnäts": "frasnät",
    "frasradikala": "frasradikal",
    "frasradikalare": "frasradikal",
    "frasradikalares": "frasradikal",
    "frasradikalas": "frasradikal",
    "frasradikalast": "frasradikal",
    "frasradikalaste": "frasradikal",
    "frasradikalastes": "frasradikal",
    "frasradikalasts": "frasradikal",
    "frasradikale": "frasradikal",
    "frasradikalen": "frasradikal",
    "frasradikalens": "frasradikal",
    "frasradikaler": "frasradikal",
    "frasradikalerna": "frasradikal",
    "frasradikalernas": "frasradikal",
    "frasradikalers": "frasradikal",
    "frasradikales": "frasradikal",
    "frasradikals": "frasradikal",
    "frasradikalt": "frasradikal",
    "frasradikalts": "frasradikal",
    "frasvåffel": "frasvåffla",
    "frasvåfflan": "frasvåffla",
    "frasvåfflans": "frasvåffla",
    "frasvåfflas": "frasvåffla",
    "frasvåffle": "frasvåffla",
    "frasvåfflor": "frasvåffla",
    "frasvåfflorna": "frasvåffla",
    "frasvåfflornas": "frasvåffla",
    "frasvåfflors": "frasvåffla",
    "fraterniserade": "fraternisera",
    "fraterniserades": "fraternisera",
    "fraterniserande": "fraternisera",
    "fraterniseranden": "fraterniserande",
    "fraterniserandena": "fraterniserande",
    "fraterniserandenas": "fraterniserande",
    "fraterniserandens": "fraterniserande",
    "fraterniserandes": "fraterniserande",
    "fraterniserandet": "fraterniserande",
    "fraterniserandets": "fraterniserande",
    "fraterniserar": "fraternisera",
    "fraterniseras": "fraternisera",
    "fraterniserat": "fraternisera",
    "fraterniserats": "fraternisera",
    "fraterniseringar": "fraternisering",
    "fraterniseringarna": "fraternisering",
    "fraterniseringarnas": "fraternisering",
    "fraterniseringars": "fraternisering",
    "fraterniseringen": "fraternisering",
    "fraterniseringens": "fraternisering",
    "fraterniserings": "fraternisering",
    "fratet": "frat",
    "fratets": "frat",
    "frats": "frat",
    "freakar": "freak",
    "freakarna": "freak",
    "freakarnas": "freak",
    "freakars": "freak",
    "freaken": "freak",
    "freakens": "freak",
    "freaks": "freak",
    "fred": "freda",
    "fredad": "freda",
    "fredade": "freda",
    "fredades": "freda",
    "fredads": "freda",
    "fredagar": "fredag",
    "fredagarna": "fredag",
    "fredagarnas": "fredag",
    "fredagars": "fredag",
    "fredageftermiddagar": "fredageftermiddag",
    "fredageftermiddagarna": "fredageftermiddag",
    "fredageftermiddagarnas": "fredageftermiddag",
    "fredageftermiddagars": "fredageftermiddag",
    "fredageftermiddagen": "fredageftermiddag",
    "fredageftermiddagens": "fredageftermiddag",
    "fredageftermiddags": "fredageftermiddag",
    "fredagen": "fredag",
    "fredagens": "fredag",
    "fredagkvällar": "fredagkväll",
    "fredagkvällarna": "fredagkväll",
    "fredagkvällarnas": "fredagkväll",
    "fredagkvällars": "fredagkväll",
    "fredagkvällen": "fredagkväll",
    "fredagkvällens": "fredagkväll",
    "fredagkvälls": "fredagkväll",
    "fredagmorgnar": "fredagmorgon",
    "fredagmorgnarna": "fredagmorgon",
    "fredagmorgnarnas": "fredagmorgon",
    "fredagmorgnars": "fredagmorgon",
    "fredagmorgonen": "fredagmorgon",
    "fredagmorgonens": "fredagmorgon",
    "fredagmorgons": "fredagmorgon",
    "fredagmornar": "fredagmorgon",
    "fredagmornarna": "fredagmorgon",
    "fredagmornarnas": "fredagmorgon",
    "fredagmornars": "fredagmorgon",
    "fredags": "fredag",
    "fredagsbönen": "fredagsbön",
    "fredagsbönens": "fredagsbön",
    "fredagsböner": "fredagsbön",
    "fredagsbönerna": "fredagsbön",
    "fredagsbönernas": "fredagsbön",
    "fredagsböners": "fredagsbön",
    "fredagsböns": "fredagsbön",
    "fredagsbörsen": "fredagsbörs",
    "fredagsbörsens": "fredagsbörs",
    "fredagsbörser": "fredagsbörs",
    "fredagsbörserna": "fredagsbörs",
    "fredagsbörsernas": "fredagsbörs",
    "fredagsbörsers": "fredagsbörs",
    "fredagseftermiddagar": "fredagseftermiddag",
    "fredagseftermiddagarna": "fredagseftermiddag",
    "fredagseftermiddagarnas": "fredagseftermiddag",
    "fredagseftermiddagars": "fredagseftermiddag",
    "fredagseftermiddagen": "fredagseftermiddag",
    "fredagseftermiddagens": "fredagseftermiddag",
    "fredagseftermiddags": "fredagseftermiddag",
    "fredagskvällar": "fredagskväll",
    "fredagskvällarna": "fredagskväll",
    "fredagskvällarnas": "fredagskväll",
    "fredagskvällars": "fredagskväll",
    "fredagskvällen": "fredagskväll",
    "fredagskvällens": "fredagskväll",
    "fredagskvälls": "fredagskväll",
    "fredagsmiddagar": "fredagsmiddag",
    "fredagsmiddagarna": "fredagsmiddag",
    "fredagsmiddagarnas": "fredagsmiddag",
    "fredagsmiddagars": "fredagsmiddag",
    "fredagsmiddagen": "fredagsmiddag",
    "fredagsmiddagens": "fredagsmiddag",
    "fredagsmiddags": "fredagsmiddag",
    "fredagsmorgnar": "fredagsmorgon",
    "fredagsmorgnarna": "fredagsmorgon",
    "fredagsmorgnarnas": "fredagsmorgon",
    "fredagsmorgnars": "fredagsmorgon",
    "fredagsmorgonen": "fredagsmorgon",
    "fredagsmorgonens": "fredagsmorgon",
    "fredagsmorgons": "fredagsmorgon",
    "fredagsmornar": "fredagsmorgon",
    "fredagsmornarna": "fredagsmorgon",
    "fredagsmornarnas": "fredagsmorgon",
    "fredagsmornars": "fredagsmorgon",
    "fredagsmysen": "fredagsmys",
    "fredagsmysens": "fredagsmys",
    "fredagsmyset": "fredagsmys",
    "fredagsmysets": "fredagsmys",
    "fredande": "freda",
    "fredanden": "fredande",
    "fredandena": "fredande",
    "fredandenas": "fredande",
    "fredandens": "fredande",
    "fredandes": "fredande",
    "fredandet": "fredande",
    "fredandets": "fredande",
    "fredar": "freda",
    "fredas": "freda",
    "fredat": "freda",
    "fredats": "freda",
    "freden": "fred",
    "fredens": "fred",
    "freder": "fred",
    "frederna": "fred",
    "fredernas": "fred",
    "freders": "fred",
    "fredliga": "fredlig",
    "fredligare": "fredlig",
    "fredligares": "fredlig",
    "fredligas": "fredlig",
    "fredligast": "fredlig",
    "fredligaste": "fredlig",
    "fredligastes": "fredlig",
    "fredligasts": "fredlig",
    "fredlige": "fredlig",
    "fredliges": "fredlig",
    "fredligheten": "fredlighet",
    "fredlighetens": "fredlighet",
    "fredlighets": "fredlighet",
    "fredligs": "fredlig",
    "fredligt": "fredlig",
    "fredligts": "fredlig",
    "fredlösa": "fredlös",
    "fredlösare": "fredlös",
    "fredlösares": "fredlös",
    "fredlösas": "fredlös",
    "fredlösast": "fredlös",
    "fredlösaste": "fredlös",
    "fredlösastes": "fredlös",
    "fredlösasts": "fredlös",
    "fredlöse": "fredlös",
    "fredlöses": "fredlös",
    "fredlösheten": "fredlöshet",
    "fredlöshetens": "fredlöshet",
    "fredlöshets": "fredlöshet",
    "fredlöst": "fredlös",
    "fredlösts": "fredlös",
    "freds": "fred",
    "fredsaktivisten": "fredsaktivist",
    "fredsaktivistens": "fredsaktivist",
    "fredsaktivister": "fredsaktivist",
    "fredsaktivisterna": "fredsaktivist",
    "fredsaktivisternas": "fredsaktivist",
    "fredsaktivisters": "fredsaktivist",
    "fredsaktivists": "fredsaktivist",
    "fredsavtalen": "fredsavtal",
    "fredsavtalens": "fredsavtal",
    "fredsavtalet": "fredsavtal",
    "fredsavtalets": "fredsavtal",
    "fredsavtals": "fredsavtal",
    "fredsdomar": "fredsdomare",
    "fredsdomaren": "fredsdomare",
    "fredsdomarens": "fredsdomare",
    "fredsdomares": "fredsdomare",
    "fredsdomarna": "fredsdomare",
    "fredsdomarnas": "fredsdomare",
    "fredsdomstolar": "fredsdomstol",
    "fredsdomstolarna": "fredsdomstol",
    "fredsdomstolarnas": "fredsdomstol",
    "fredsdomstolars": "fredsdomstol",
    "fredsdomstolen": "fredsdomstol",
    "fredsdomstolens": "fredsdomstol",
    "fredsdomstols": "fredsdomstol",
    "fredsduv": "fredsduva",
    "fredsduvan": "fredsduva",
    "fredsduvans": "fredsduva",
    "fredsduvas": "fredsduva",
    "fredsduve": "fredsduva",
    "fredsduvor": "fredsduva",
    "fredsduvorna": "fredsduva",
    "fredsduvornas": "fredsduva",
    "fredsduvors": "fredsduva",
    "fredsduvs": "fredsduva",
    "fredsforskningar": "fredsforskning",
    "fredsforskningarna": "fredsforskning",
    "fredsforskningarnas": "fredsforskning",
    "fredsforskningars": "fredsforskning",
    "fredsforskningen": "fredsforskning",
    "fredsforskningens": "fredsforskning",
    "fredsforsknings": "fredsforskning",
    "fredsfördragen": "fredsfördrag",
    "fredsfördragens": "fredsfördrag",
    "fredsfördraget": "fredsfördrag",
    "fredsfördragets": "fredsfördrag",
    "fredsfördrags": "fredsfördrag",
    "fredsförhandlingar": "fredsförhandling",
    "fredsförhandlingarna": "fredsförhandling",
    "fredsförhandlingarnas": "fredsförhandling",
    "fredsförhandlingars": "fredsförhandling",
    "fredsförhandlingen": "fredsförhandling",
    "fredsförhandlingens": "fredsförhandling",
    "fredsförhandlings": "fredsförhandling",
    "fredskonferensen": "fredskonferens",
    "fredskonferensens": "fredskonferens",
    "fredskonferenser": "fredskonferens",
    "fredskonferenserna": "fredskonferens",
    "fredskonferensernas": "fredskonferens",
    "fredskonferensers": "fredskonferens",
    "fredskåren": "fredskår",
    "fredskårens": "fredskår",
    "fredskårer": "fredskår",
    "fredskårerna": "fredskår",
    "fredskårernas": "fredskår",
    "fredskårers": "fredskår",
    "fredskårs": "fredskår",
    "fredsmäklar": "fredsmäklare",
    "fredsmäklaren": "fredsmäklare",
    "fredsmäklarens": "fredsmäklare",
    "fredsmäklares": "fredsmäklare",
    "fredsmäklarna": "fredsmäklare",
    "fredsmäklarnas": "fredsmäklare",
    "fredspip": "fredspipa",
    "fredspipan": "fredspipa",
    "fredspipans": "fredspipa",
    "fredspipas": "fredspipa",
    "fredspipe": "fredspipa",
    "fredspipor": "fredspipa",
    "fredspiporna": "fredspipa",
    "fredspipornas": "fredspipa",
    "fredspipors": "fredspipa",
    "fredspips": "fredspipa",
    "fredsplikten": "fredsplikt",
    "fredspliktens": "fredsplikt",
    "fredsplikts": "fredsplikt",
    "fredsprisen": "fredspris",
    "fredsprisens": "fredspris",
    "fredspriser": "fredspris",
    "fredspriserna": "fredspris",
    "fredsprisernas": "fredspris",
    "fredsprisers": "fredspris",
    "fredspriset": "fredspris",
    "fredsprisets": "fredspris",
    "fredspristagar": "fredspristagare",
    "fredspristagaren": "fredspristagare",
    "fredspristagarens": "fredspristagare",
    "fredspristagares": "fredspristagare",
    "fredspristagarna": "fredspristagare",
    "fredspristagarnas": "fredspristagare",
    "fredsprisvalen": "fredsprisval",
    "fredsprisvalens": "fredsprisval",
    "fredsprisvalet": "fredsprisval",
    "fredsprisvalets": "fredsprisval",
    "fredsprisvals": "fredsprisval",
    "fredsrörelsen": "fredsrörelse",
    "fredsrörelsens": "fredsrörelse",
    "fredsrörelser": "fredsrörelse",
    "fredsrörelserna": "fredsrörelse",
    "fredsrörelsernas": "fredsrörelse",
    "fredsrörelsers": "fredsrörelse",
    "fredsrörelses": "fredsrörelse",
    "fredssamtalen": "fredssamtal",
    "fredssamtalens": "fredssamtal",
    "fredssamtalet": "fredssamtal",
    "fredssamtalets": "fredssamtal",
    "fredssamtals": "fredssamtal",
    "fredssluten": "fredsslut",
    "fredsslutens": "fredsslut",
    "fredsslutet": "fredsslut",
    "fredsslutets": "fredsslut",
    "fredssluts": "fredsslut",
    "fredssträvanden": "fredssträvande",
    "fredssträvandena": "fredssträvande",
    "fredssträvandenas": "fredssträvande",
    "fredssträvandens": "fredssträvande",
    "fredssträvandes": "fredssträvande",
    "fredssträvandet": "fredssträvande",
    "fredssträvandets": "fredssträvande",
    "fredssträvans": "fredssträvan",
    "fredstiden": "fredstid",
    "fredstidens": "fredstid",
    "fredstider": "fredstid",
    "fredstiderna": "fredstid",
    "fredstidernas": "fredstid",
    "fredstiders": "fredstid",
    "fredstids": "fredstid",
    "free-stylen": "free-style",
    "free-stylens": "free-style",
    "free-styles": "free-style",
    "free-stylesarna": "free-style",
    "free-stylesarnas": "free-style",
    "free-stylesen": "free-style",
    "free-stylesens": "free-style",
    "freestylen": "freestyle",
    "freestylens": "freestyle",
    "freestyles": "freestyle",
    "freestylesarna": "freestyle",
    "freestylesarnas": "freestyle",
    "freestylesen": "freestyle",
    "freestylesens": "freestyle",
    "fregatten": "fregatt",
    "fregattens": "fregatt",
    "fregatter": "fregatt",
    "fregatterna": "fregatt",
    "fregatternas": "fregatt",
    "fregatters": "fregatt",
    "fregattfågeln": "fregattfågel",
    "fregattfågelns": "fregattfågel",
    "fregattfågels": "fregattfågel",
    "fregattfåglar": "fregattfågel",
    "fregattfåglarna": "fregattfågel",
    "fregattfåglarnas": "fregattfågel",
    "fregattfåglars": "fregattfågel",
    "fregatts": "fregatt",
    "frejdade": "frejdad",
    "frejdades": "frejdad",
    "frejdads": "frejdad",
    "frejdat": "frejdad",
    "frejdats": "frejdad",
    "frejden": "frejd",
    "frejdens": "frejd",
    "frejdiga": "frejdig",
    "frejdigare": "frejdig",
    "frejdigares": "frejdig",
    "frejdigas": "frejdig",
    "frejdigast": "frejdig",
    "frejdigaste": "frejdig",
    "frejdigastes": "frejdig",
    "frejdigasts": "frejdig",
    "frejdige": "frejdig",
    "frejdiges": "frejdig",
    "frejdigheten": "frejdighet",
    "frejdighetens": "frejdighet",
    "frejdighets": "frejdighet",
    "frejdigs": "frejdig",
    "frejdigt": "frejdig",
    "frejdigts": "frejdig",
    "frejds": "frejd",
    "frekvensbanden": "frekvensband",
    "frekvensbandens": "frekvensband",
    "frekvensbandet": "frekvensband",
    "frekvensbandets": "frekvensband",
    "frekvensbands": "frekvensband",
    "frekvensen": "frekvens",
    "frekvensens": "frekvens",
    "frekvenser": "frekvens",
    "frekvenserna": "frekvens",
    "frekvensernas": "frekvens",
    "frekvensers": "frekvens",
    "frekvensmodulerad": "frekvensmodulera",
    "frekvensmodulerade": "frekvensmodulera",
    "frekvensmodulerades": "frekvensmodulera",
    "frekvensmodulerads": "frekvensmodulera",
    "frekvensmodulerande": "frekvensmodulera",
    "frekvensmoduleranden": "frekvensmodulerande",
    "frekvensmodulerandena": "frekvensmodulerande",
    "frekvensmodulerandenas": "frekvensmodulerande",
    "frekvensmodulerandens": "frekvensmodulerande",
    "frekvensmodulerandes": "frekvensmodulerande",
    "frekvensmodulerandet": "frekvensmodulerande",
    "frekvensmodulerandets": "frekvensmodulerande",
    "frekvensmodulerar": "frekvensmodulera",
    "frekvensmoduleras": "frekvensmodulera",
    "frekvensmodulerat": "frekvensmodulera",
    "frekvensmodulerats": "frekvensmodulera",
    "frekvensmodulerbara": "frekvensmodulerbar",
    "frekvensmodulerbarare": "frekvensmodulerbar",
    "frekvensmodulerbarares": "frekvensmodulerbar",
    "frekvensmodulerbaras": "frekvensmodulerbar",
    "frekvensmodulerbarast": "frekvensmodulerbar",
    "frekvensmodulerbaraste": "frekvensmodulerbar",
    "frekvensmodulerbarastes": "frekvensmodulerbar",
    "frekvensmodulerbarasts": "frekvensmodulerbar",
    "frekvensmodulerbare": "frekvensmodulerbar",
    "frekvensmodulerbares": "frekvensmodulerbar",
    "frekvensmodulerbarheten": "frekvensmodulerbarhet",
    "frekvensmodulerbarhetens": "frekvensmodulerbarhet",
    "frekvensmodulerbarhets": "frekvensmodulerbarhet",
    "frekvensmodulerbars": "frekvensmodulerbar",
    "frekvensmodulerbart": "frekvensmodulerbar",
    "frekvensmodulerbarts": "frekvensmodulerbar",
    "frekvensmoduleringar": "frekvensmodulering",
    "frekvensmoduleringarna": "frekvensmodulering",
    "frekvensmoduleringarnas": "frekvensmodulering",
    "frekvensmoduleringars": "frekvensmodulering",
    "frekvensmoduleringen": "frekvensmodulering",
    "frekvensmoduleringens": "frekvensmodulering",
    "frekvensmodulerings": "frekvensmodulering",
    "frekvensområden": "frekvensområde",
    "frekvensområdena": "frekvensområde",
    "frekvensområdenas": "frekvensområde",
    "frekvensområdens": "frekvensområde",
    "frekvensområdes": "frekvensområde",
    "frekvensområdet": "frekvensområde",
    "frekvensområdets": "frekvensområde",
    "frekventa": "frekvent",
    "frekventare": "frekvent",
    "frekventares": "frekvent",
    "frekventas": "frekvent",
    "frekventast": "frekvent",
    "frekventaste": "frekvent",
    "frekventastes": "frekvent",
    "frekventasts": "frekvent",
    "frekvente": "frekvent",
    "frekventerad": "frekventera",
    "frekventerade": "frekventera",
    "frekventerades": "frekventera",
    "frekventerads": "frekventera",
    "frekventerande": "frekventera",
    "frekventeranden": "frekventerande",
    "frekventerandena": "frekventerande",
    "frekventerandenas": "frekventerande",
    "frekventerandens": "frekventerande",
    "frekventerandes": "frekventerande",
    "frekventerandet": "frekventerande",
    "frekventerandets": "frekventerande",
    "frekventerar": "frekventera",
    "frekventeras": "frekventera",
    "frekventerat": "frekventera",
    "frekventerats": "frekventera",
    "frekventerbara": "frekventerbar",
    "frekventerbarare": "frekventerbar",
    "frekventerbarares": "frekventerbar",
    "frekventerbaras": "frekventerbar",
    "frekventerbarast": "frekventerbar",
    "frekventerbaraste": "frekventerbar",
    "frekventerbarastes": "frekventerbar",
    "frekventerbarasts": "frekventerbar",
    "frekventerbare": "frekventerbar",
    "frekventerbares": "frekventerbar",
    "frekventerbarheten": "frekventerbarhet",
    "frekventerbarhetens": "frekventerbarhet",
    "frekventerbarhets": "frekventerbarhet",
    "frekventerbars": "frekventerbar",
    "frekventerbart": "frekventerbar",
    "frekventerbarts": "frekventerbar",
    "frekventeringar": "frekventering",
    "frekventeringarna": "frekventering",
    "frekventeringarnas": "frekventering",
    "frekventeringars": "frekventering",
    "frekventeringen": "frekventering",
    "frekventeringens": "frekventering",
    "frekventerings": "frekventering",
    "frekventes": "frekvent",
    "frekvents": "frekvent",
    "frenesien": "frenesi",
    "frenesiens": "frenesi",
    "frenesin": "frenesi",
    "frenesins": "frenesi",
    "frenesis": "frenesi",
    "frenetiska": "frenetisk",
    "frenetiskare": "frenetisk",
    "frenetiskares": "frenetisk",
    "frenetiskas": "frenetisk",
    "frenetiskast": "frenetisk",
    "frenetiskaste": "frenetisk",
    "frenetiskastes": "frenetisk",
    "frenetiskasts": "frenetisk",
    "frenetiske": "frenetisk",
    "frenetiskes": "frenetisk",
    "frenetisks": "frenetisk",
    "frenetiskt": "frenetisk",
    "frenetiskts": "frenetisk",
    "frenologien": "frenologi",
    "frenologiens": "frenologi",
    "frenologin": "frenologi",
    "frenologins": "frenologi",
    "frenologis": "frenologi",
    "frenologiska": "frenologisk",
    "frenologiskare": "frenologisk",
    "frenologiskares": "frenologisk",
    "frenologiskas": "frenologisk",
    "frenologiskast": "frenologisk",
    "frenologiskaste": "frenologisk",
    "frenologiskastes": "frenologisk",
    "frenologiskasts": "frenologisk",
    "frenologiske": "frenologisk",
    "frenologiskes": "frenologisk",
    "frenologisks": "frenologisk",
    "frenologiskt": "frenologisk",
    "frenologiskts": "frenologisk",
    "freonen": "freon",
    "freonens": "freon",
    "freoner": "freon",
    "freonerna": "freon",
    "freonernas": "freon",
    "freoners": "freon",
    "freons": "freon",
    "fresi": "fresia",
    "fresian": "fresia",
    "fresians": "fresia",
    "fresias": "fresia",
    "fresie": "fresia",
    "fresior": "fresia",
    "fresiorna": "fresia",
    "fresiornas": "fresia",
    "fresiors": "fresia",
    "fresis": "fresia",
    "fresken": "fresk",
    "freskens": "fresk",
    "fresker": "fresk",
    "freskerna": "fresk",
    "freskernas": "fresk",
    "freskers": "fresk",
    "freskomålningar": "freskomålning",
    "freskomålningarna": "freskomålning",
    "freskomålningarnas": "freskomålning",
    "freskomålningars": "freskomålning",
    "freskomålningen": "freskomålning",
    "freskomålningens": "freskomålning",
    "freskomålnings": "freskomålning",
    "fresks": "fresk",
    "frest": "fresta",
    "frestad": "fresta",
    "frestade": "frestad",
    "frestades": "frestad",
    "frestads": "frestad",
    "frestande": "fresta",
    "frestanden": "frestande",
    "frestandena": "frestande",
    "frestandenas": "frestande",
    "frestandens": "frestande",
    "frestandes": "frestande",
    "frestandet": "frestande",
    "frestandets": "frestande",
    "frestar": "frestare",
    "frestaren": "frestare",
    "frestarens": "frestare",
    "frestares": "frestare",
    "frestarna": "frestare",
    "frestarnas": "frestare",
    "frestas": "fresta",
    "frestat": "frestad",
    "frestats": "frestad",
    "frestelsen": "frestelse",
    "frestelsens": "frestelse",
    "frestelser": "frestelse",
    "frestelserna": "frestelse",
    "frestelsernas": "frestelse",
    "frestelsers": "frestelse",
    "frestelses": "frestelse",
    "fri": "fria",
    "fria": "fri",
    "friad": "fria",
    "friade": "fria",
    "friades": "fria",
    "friads": "fria",
    "friande": "fria",
    "frianden": "friande",
    "friandena": "friande",
    "friandenas": "friande",
    "friandens": "friande",
    "friandes": "friande",
    "friandet": "friande",
    "friandets": "friande",
    "friar": "friare",
    "friare": "fri",
    "friaren": "friare",
    "friarens": "friare",
    "friares": "friare",
    "friarna": "friare",
    "friarnas": "friare",
    "frias": "fria",
    "friast": "fri",
    "friaste": "fri",
    "friastes": "fri",
    "friasts": "fri",
    "friat": "fria",
    "friats": "fria",
    "fribiljetten": "fribiljett",
    "fribiljettens": "fribiljett",
    "fribiljetter": "fribiljett",
    "fribiljetterna": "fribiljett",
    "fribiljetternas": "fribiljett",
    "fribiljetters": "fribiljett",
    "fribiljetts": "fribiljett",
    "fribladiga": "fribladig",
    "fribladigare": "fribladig",
    "fribladigares": "fribladig",
    "fribladigas": "fribladig",
    "fribladigast": "fribladig",
    "fribladigaste": "fribladig",
    "fribladigastes": "fribladig",
    "fribladigasts": "fribladig",
    "fribladige": "fribladig",
    "fribladiges": "fribladig",
    "fribladigs": "fribladig",
    "fribladigt": "fribladig",
    "fribladigts": "fribladig",
    "fribond": "fribonde",
    "fribonden": "fribonde",
    "fribondens": "fribonde",
    "fribondes": "fribonde",
    "fribonds": "fribonde",
    "friborden": "fribord",
    "fribordens": "fribord",
    "fribordet": "fribord",
    "fribordets": "fribord",
    "fribords": "fribord",
    "friborens": "friboren",
    "friboret": "friboren",
    "friborets": "friboren",
    "friborna": "friboren",
    "fribornare": "friboren",
    "fribornares": "friboren",
    "fribornas": "friboren",
    "fribornast": "friboren",
    "fribornaste": "friboren",
    "fribornastes": "friboren",
    "fribornasts": "friboren",
    "friborne": "friboren",
    "fribornes": "friboren",
    "fribreven": "fribrev",
    "fribrevens": "fribrev",
    "fribrevet": "fribrev",
    "fribrevets": "fribrev",
    "fribrevs": "fribrev",
    "fribrottar": "fribrottare",
    "fribrottaren": "fribrottare",
    "fribrottarens": "fribrottare",
    "fribrottares": "fribrottare",
    "fribrottarna": "fribrottare",
    "fribrottarnas": "fribrottare",
    "fribrottningar": "fribrottning",
    "fribrottningarna": "fribrottning",
    "fribrottningarnas": "fribrottning",
    "fribrottningars": "fribrottning",
    "fribrottningen": "fribrottning",
    "fribrottningens": "fribrottning",
    "fribrottnings": "fribrottning",
    "fribytar": "fribytare",
    "fribytaren": "fribytare",
    "fribytarens": "fribytare",
    "fribytares": "fribytare",
    "fribytarna": "fribytare",
    "fribytarnas": "fribytare",
    "fribyterier": "fribyteri",
    "fribyterierna": "fribyteri",
    "fribyteriernas": "fribyteri",
    "fribyteriers": "fribyteri",
    "fribyteriet": "fribyteri",
    "fribyteriets": "fribyteri",
    "fribyteris": "fribyteri",
    "fribyterit": "fribyteri",
    "fribyterits": "fribyteri",
    "fribönder": "fribonde",
    "fribönderna": "fribonde",
    "friböndernas": "fribonde",
    "fribönders": "fribonde",
    "fridagar": "fridag",
    "fridagarna": "fridag",
    "fridagarnas": "fridag",
    "fridagars": "fridag",
    "fridagen": "fridag",
    "fridagens": "fridag",
    "fridags": "fridag",
    "friden": "frid",
    "fridens": "frid",
    "frider": "frid",
    "friderna": "frid",
    "fridernas": "frid",
    "friders": "frid",
    "fridfulla": "fridfull",
    "fridfullare": "fridfull",
    "fridfullares": "fridfull",
    "fridfullas": "fridfull",
    "fridfullast": "fridfull",
    "fridfullaste": "fridfull",
    "fridfullastes": "fridfull",
    "fridfullasts": "fridfull",
    "fridfulle": "fridfull",
    "fridfulles": "fridfull",
    "fridfullheten": "fridfullhet",
    "fridfullhetens": "fridfullhet",
    "fridfullhets": "fridfullhet",
    "fridfulls": "fridfull",
    "fridfullt": "fridfull",
    "fridfullts": "fridfull",
    "fridlys": "fridlysa",
    "fridlysande": "fridlysa",
    "fridlysanden": "fridlysande",
    "fridlysandena": "fridlysande",
    "fridlysandenas": "fridlysande",
    "fridlysandens": "fridlysande",
    "fridlysandes": "fridlysande",
    "fridlysandet": "fridlysande",
    "fridlysandets": "fridlysande",
    "fridlysas": "fridlysa",
    "fridlyser": "fridlysa",
    "fridlyses": "fridlysa",
    "fridlysningar": "fridlysning",
    "fridlysningarna": "fridlysning",
    "fridlysningarnas": "fridlysning",
    "fridlysningars": "fridlysning",
    "fridlysningen": "fridlysning",
    "fridlysningens": "fridlysning",
    "fridlysnings": "fridlysning",
    "fridlyst": "fridlysa",
    "fridlysta": "fridlysa",
    "fridlystas": "fridlysa",
    "fridlyste": "fridlysa",
    "fridlystes": "fridlysa",
    "fridlysts": "fridlysa",
    "frids": "frid",
    "fridsamheten": "fridsamhet",
    "fridsamhetens": "fridsamhet",
    "fridsamhets": "fridsamhet",
    "fridsamma": "fridsam",
    "fridsammare": "fridsam",
    "fridsammares": "fridsam",
    "fridsammas": "fridsam",
    "fridsammast": "fridsam",
    "fridsammaste": "fridsam",
    "fridsammastes": "fridsam",
    "fridsammasts": "fridsam",
    "fridsamme": "fridsam",
    "fridsammes": "fridsam",
    "fridsams": "fridsam",
    "fridsamt": "fridsam",
    "fridsamts": "fridsam",
    "fridskränkningar": "fridskränkning",
    "fridskränkningarna": "fridskränkning",
    "fridskränkningarnas": "fridskränkning",
    "fridskränkningars": "fridskränkning",
    "fridskränkningen": "fridskränkning",
    "fridskränkningens": "fridskränkning",
    "fridskränknings": "fridskränkning",
    "frie": "fri",
    "frierier": "frieri",
    "frierierna": "frieri",
    "frieriernas": "frieri",
    "frieriers": "frieri",
    "frieriet": "frieri",
    "frieriets": "frieri",
    "frieris": "frieri",
    "frierit": "frieri",
    "frierits": "frieri",
    "fries": "fri",
    "friexemplaren": "friexemplar",
    "friexemplarens": "friexemplar",
    "friexemplaret": "friexemplar",
    "friexemplarets": "friexemplar",
    "friexemplars": "friexemplar",
    "frifräsar": "frifräsare",
    "frifräsaren": "frifräsare",
    "frifräsarens": "frifräsare",
    "frifräsares": "frifräsare",
    "frifräsarna": "frifräsare",
    "frifräsarnas": "frifräsare",
    "frifräsiga": "frifräsig",
    "frifräsigare": "frifräsig",
    "frifräsigares": "frifräsig",
    "frifräsigas": "frifräsig",
    "frifräsigast": "frifräsig",
    "frifräsigaste": "frifräsig",
    "frifräsigastes": "frifräsig",
    "frifräsigasts": "frifräsig",
    "frifräsige": "frifräsig",
    "frifräsiges": "frifräsig",
    "frifräsigheten": "frifräsighet",
    "frifräsighetens": "frifräsighet",
    "frifräsighets": "frifräsighet",
    "frifräsigs": "frifräsig",
    "frifräsigt": "frifräsig",
    "frifräsigts": "frifräsig",
    "frigav": "frige",
    "frigavs": "frige",
    "frigeende": "frige",
    "frigeendes": "frige",
    "friger": "frige",
    "friges": "frige",
    "frigett": "frige",
    "frigetts": "frige",
    "friggebodar": "friggebod",
    "friggebodarna": "friggebod",
    "friggebodarnas": "friggebod",
    "friggebodars": "friggebod",
    "friggeboden": "friggebod",
    "friggebodens": "friggebod",
    "friggebods": "friggebod",
    "frigida": "frigid",
    "frigidare": "frigid",
    "frigidares": "frigid",
    "frigidas": "frigid",
    "frigidast": "frigid",
    "frigidaste": "frigid",
    "frigidastes": "frigid",
    "frigidasts": "frigid",
    "frigide": "frigid",
    "frigides": "frigid",
    "frigiditeten": "frigiditet",
    "frigiditetens": "frigiditet",
    "frigiditeter": "frigiditet",
    "frigiditeterna": "frigiditet",
    "frigiditeternas": "frigiditet",
    "frigiditeters": "frigiditet",
    "frigiditets": "frigiditet",
    "frigids": "frigid",
    "frigiv": "frige",
    "frigiva": "frige",
    "frigivande": "frige",
    "frigivanden": "frigivande",
    "frigivandena": "frigivande",
    "frigivandenas": "frigivande",
    "frigivandens": "frigivande",
    "frigivandes": "frigivande",
    "frigivandet": "frigivande",
    "frigivandets": "frigivande",
    "frigivas": "frige",
    "frigive": "frige",
    "frigiven": "frige",
    "frigivens": "frige",
    "frigiver": "frige",
    "frigives": "frige",
    "frigivet": "frige",
    "frigivets": "frige",
    "frigivit": "frige",
    "frigivits": "frige",
    "frigivna": "frige",
    "frigivnas": "frige",
    "frigivne": "frige",
    "frigivnes": "frige",
    "frigivningar": "frigivning",
    "frigivningarna": "frigivning",
    "frigivningarnas": "frigivning",
    "frigivningars": "frigivning",
    "frigivningen": "frigivning",
    "frigivningens": "frigivning",
    "frigivnings": "frigivning",
    "frigivs": "frige",
    "frigjord": "frigöra",
    "frigjorda": "frigöra",
    "frigjordare": "frigjord",
    "frigjordares": "frigjord",
    "frigjordas": "frigöra",
    "frigjordast": "frigjord",
    "frigjordaste": "frigjord",
    "frigjordastes": "frigjord",
    "frigjordasts": "frigjord",
    "frigjorde": "frigöra",
    "frigjordes": "frigöra",
    "frigjordheten": "frigjordhet",
    "frigjordhetens": "frigjordhet",
    "frigjordheter": "frigjordhet",
    "frigjordheterna": "frigjordhet",
    "frigjordheternas": "frigjordhet",
    "frigjordheters": "frigjordhet",
    "frigjordhets": "frigjordhet",
    "frigjords": "frigöra",
    "frigjort": "frigöra",
    "frigjorts": "frigöra",
    "frigången": "frigång",
    "frigångens": "frigång",
    "frigångs": "frigång",
    "frigåve": "frige",
    "frigåves": "frige",
    "frigör": "frigöra",
    "frigörande": "frigöra",
    "frigöranden": "frigörande",
    "frigörandena": "frigörande",
    "frigörandenas": "frigörande",
    "frigörandens": "frigörande",
    "frigörandes": "frigörande",
    "frigörandet": "frigörande",
    "frigörandets": "frigörande",
    "frigöras": "frigöra",
    "frigörelsen": "frigörelse",
    "frigörelsens": "frigörelse",
    "frigörelses": "frigörelse",
    "frigöres": "frigöra",
    "frigörs": "frigöra",
    "frihamnar": "frihamn",
    "frihamnarna": "frihamn",
    "frihamnarnas": "frihamn",
    "frihamnars": "frihamn",
    "frihamnen": "frihamn",
    "frihamnens": "frihamn",
    "frihamns": "frihamn",
    "frihandeln": "frihandel",
    "frihandelns": "frihandel",
    "frihandels": "frihandel",
    "frihandelsområden": "frihandelsområde",
    "frihandelsområdena": "frihandelsområde",
    "frihandelsområdenas": "frihandelsområde",
    "frihandelsområdens": "frihandelsområde",
    "frihandelsområdes": "frihandelsområde",
    "frihandelsområdet": "frihandelsområde",
    "frihandelsområdets": "frihandelsområde",
    "frihandsteckningar": "frihandsteckning",
    "frihandsteckningarna": "frihandsteckning",
    "frihandsteckningarnas": "frihandsteckning",
    "frihandsteckningars": "frihandsteckning",
    "frihandsteckningen": "frihandsteckning",
    "frihandsteckningens": "frihandsteckning",
    "frihandstecknings": "frihandsteckning",
    "friherrar": "friherre",
    "friherrarna": "friherre",
    "friherrarnas": "friherre",
    "friherrars": "friherre",
    "friherren": "friherre",
    "friherrens": "friherre",
    "friherres": "friherre",
    "friheten": "frihet",
    "frihetens": "frihet",
    "friheter": "frihet",
    "friheterna": "frihet",
    "friheternas": "frihet",
    "friheters": "frihet",
    "frihetliga": "frihetlig",
    "frihetligare": "frihetlig",
    "frihetligares": "frihetlig",
    "frihetligas": "frihetlig",
    "frihetligast": "frihetlig",
    "frihetligaste": "frihetlig",
    "frihetligastes": "frihetlig",
    "frihetligasts": "frihetlig",
    "frihetlige": "frihetlig",
    "frihetliges": "frihetlig",
    "frihetligheten": "frihetlighet",
    "frihetlighetens": "frihetlighet",
    "frihetlighets": "frihetlighet",
    "frihetligs": "frihetlig",
    "frihetligt": "frihetlig",
    "frihetligts": "frihetlig",
    "frihets": "frihet",
    "frihetsberövad": "frihetsberöva",
    "frihetsberövade": "frihetsberöva",
    "frihetsberövades": "frihetsberöva",
    "frihetsberövads": "frihetsberöva",
    "frihetsberövande": "frihetsberöva",
    "frihetsberövanden": "frihetsberövande",
    "frihetsberövandena": "frihetsberövande",
    "frihetsberövandenas": "frihetsberövande",
    "frihetsberövandens": "frihetsberövande",
    "frihetsberövandes": "frihetsberövande",
    "frihetsberövandet": "frihetsberövande",
    "frihetsberövandets": "frihetsberövande",
    "frihetsberövar": "frihetsberöva",
    "frihetsberövas": "frihetsberöva",
    "frihetsberövat": "frihetsberöva",
    "frihetsberövats": "frihetsberöva",
    "frihetsgraden": "frihetsgrad",
    "frihetsgradens": "frihetsgrad",
    "frihetsgrader": "frihetsgrad",
    "frihetsgraderna": "frihetsgrad",
    "frihetsgradernas": "frihetsgrad",
    "frihetsgraders": "frihetsgrad",
    "frihetsgrads": "frihetsgrad",
    "frihetshjältar": "frihetshjälte",
    "frihetshjältarna": "frihetshjälte",
    "frihetshjältarnas": "frihetshjälte",
    "frihetshjältars": "frihetshjälte",
    "frihetshjälten": "frihetshjälte",
    "frihetshjältens": "frihetshjälte",
    "frihetshjältes": "frihetshjälte",
    "frihetskampen": "frihetskamp",
    "frihetskampens": "frihetskamp",
    "frihetskamper": "frihetskamp",
    "frihetskamperna": "frihetskamp",
    "frihetskampernas": "frihetskamp",
    "frihetskampers": "frihetskamp",
    "frihetskamps": "frihetskamp",
    "frihetskrigen": "frihetskrig",
    "frihetskrigens": "frihetskrig",
    "frihetskriget": "frihetskrig",
    "frihetskrigets": "frihetskrig",
    "frihetskrigs": "frihetskrig",
    "frihetsstraffen": "frihetsstraff",
    "frihetsstraffens": "frihetsstraff",
    "frihetsstraffet": "frihetsstraff",
    "frihetsstraffets": "frihetsstraff",
    "frihetsstraffs": "frihetsstraff",
    "frihetssymbolen": "frihetssymbol",
    "frihetssymbolens": "frihetssymbol",
    "frihetssymboler": "frihetssymbol",
    "frihetssymbolerna": "frihetssymbol",
    "frihetssymbolernas": "frihetssymbol",
    "frihetssymbolers": "frihetssymbol",
    "frihetssymbols": "frihetssymbol",
    "frihetstiden": "frihetstid",
    "frihetstidens": "frihetstid",
    "frihetstids": "frihetstid",
    "frihjulen": "frihjul",
    "frihjulens": "frihjul",
    "frihjulet": "frihjul",
    "frihjulets": "frihjul",
    "frihjuls": "frihjul",
    "friholtar": "friholt",
    "friholtarna": "friholt",
    "friholtarnas": "friholt",
    "friholtars": "friholt",
    "friholten": "friholt",
    "friholtens": "friholt",
    "friholtet": "friholt",
    "friholtets": "friholt",
    "friholts": "friholt",
    "frihultar": "frihult",
    "frihultarna": "frihult",
    "frihultarnas": "frihult",
    "frihultars": "frihult",
    "frihulten": "frihult",
    "frihultens": "frihult",
    "frihultet": "frihult",
    "frihultets": "frihult",
    "frihults": "frihult",
    "friidrottar": "friidrottare",
    "friidrottaren": "friidrottare",
    "friidrottarens": "friidrottare",
    "friidrottares": "friidrottare",
    "friidrottarna": "friidrottare",
    "friidrottarnas": "friidrottare",
    "friidrotten": "friidrott",
    "friidrottens": "friidrott",
    "friidrotter": "friidrott",
    "friidrotterna": "friidrott",
    "friidrotternas": "friidrott",
    "friidrotters": "friidrott",
    "friidrotts": "friidrott",
    "friidrottslandslagen": "friidrottslandslag",
    "friidrottslandslagens": "friidrottslandslag",
    "friidrottslandslaget": "friidrottslandslag",
    "friidrottslandslagets": "friidrottslandslag",
    "friidrottslandslags": "friidrottslandslag",
    "frikadellen": "frikadell",
    "frikadellens": "frikadell",
    "frikadeller": "frikadell",
    "frikadellerna": "frikadell",
    "frikadellernas": "frikadell",
    "frikadellers": "frikadell",
    "frikadells": "frikadell",
    "frikall": "frikalla",
    "frikallad": "frikalla",
    "frikallade": "frikalla",
    "frikallades": "frikalla",
    "frikallads": "frikalla",
    "frikallande": "frikalla",
    "frikallanden": "frikallande",
    "frikallandena": "frikallande",
    "frikallandenas": "frikallande",
    "frikallandens": "frikallande",
    "frikallandes": "frikallande",
    "frikallandet": "frikallande",
    "frikallandets": "frikallande",
    "frikallar": "frikalla",
    "frikallas": "frikalla",
    "frikallat": "frikalla",
    "frikallats": "frikalla",
    "frikasséer": "frikassé",
    "frikasséerna": "frikassé",
    "frikasséernas": "frikassé",
    "frikasséers": "frikassé",
    "frikassén": "frikassé",
    "frikasséns": "frikassé",
    "frikassés": "frikassé",
    "frikasten": "frikast",
    "frikastens": "frikast",
    "frikastet": "frikast",
    "frikastets": "frikast",
    "frikasts": "frikast",
    "frikativ": "frikativa",
    "frikativa": "frikativ",
    "frikativan": "frikativa",
    "frikativans": "frikativa",
    "frikativare": "frikativ",
    "frikativares": "frikativ",
    "frikativas": "frikativa",
    "frikativast": "frikativ",
    "frikativaste": "frikativ",
    "frikativastes": "frikativ",
    "frikativasts": "frikativ",
    "frikative": "frikativa",
    "frikatives": "frikativ",
    "frikativor": "frikativa",
    "frikativorna": "frikativa",
    "frikativornas": "frikativa",
    "frikativors": "frikativa",
    "frikativs": "frikativa",
    "frikativt": "frikativ",
    "frikativts": "frikativ",
    "frikopplad": "frikoppla",
    "frikopplade": "frikoppla",
    "frikopplades": "frikoppla",
    "frikopplads": "frikoppla",
    "frikopplande": "frikoppla",
    "frikopplanden": "frikopplande",
    "frikopplandena": "frikopplande",
    "frikopplandenas": "frikopplande",
    "frikopplandens": "frikopplande",
    "frikopplandes": "frikopplande",
    "frikopplandet": "frikopplande",
    "frikopplandets": "frikopplande",
    "frikopplar": "frikoppla",
    "frikopplas": "frikoppla",
    "frikopplat": "frikoppla",
    "frikopplats": "frikoppla",
    "frikopplingar": "frikoppling",
    "frikopplingarna": "frikoppling",
    "frikopplingarnas": "frikoppling",
    "frikopplingars": "frikoppling",
    "frikopplingen": "frikoppling",
    "frikopplingens": "frikoppling",
    "frikopplings": "frikoppling",
    "frikorten": "frikort",
    "frikortens": "frikort",
    "frikortet": "frikort",
    "frikortets": "frikort",
    "frikorts": "frikort",
    "frikostiga": "frikostig",
    "frikostigare": "frikostig",
    "frikostigares": "frikostig",
    "frikostigas": "frikostig",
    "frikostigast": "frikostig",
    "frikostigaste": "frikostig",
    "frikostigastes": "frikostig",
    "frikostigasts": "frikostig",
    "frikostige": "frikostig",
    "frikostiges": "frikostig",
    "frikostigheten": "frikostighet",
    "frikostighetens": "frikostighet",
    "frikostighets": "frikostighet",
    "frikostigs": "frikostig",
    "frikostigt": "frikostig",
    "frikostigts": "frikostig",
    "frikretsar": "frikrets",
    "frikretsarna": "frikrets",
    "frikretsarnas": "frikrets",
    "frikretsars": "frikrets",
    "frikretsen": "frikrets",
    "frikretsens": "frikrets",
    "friktionen": "friktion",
    "friktionens": "friktion",
    "friktioner": "friktion",
    "friktionerna": "friktion",
    "friktionernas": "friktion",
    "friktioners": "friktion",
    "friktions": "friktion",
    "friktionsfria": "friktionsfri",
    "friktionsfriare": "friktionsfri",
    "friktionsfriares": "friktionsfri",
    "friktionsfrias": "friktionsfri",
    "friktionsfriast": "friktionsfri",
    "friktionsfriaste": "friktionsfri",
    "friktionsfriastes": "friktionsfri",
    "friktionsfriasts": "friktionsfri",
    "friktionsfrie": "friktionsfri",
    "friktionsfries": "friktionsfri",
    "friktionsfris": "friktionsfri",
    "friktionsfritt": "friktionsfri",
    "friktionsfritts": "friktionsfri",
    "friktionskoefficienten": "friktionskoefficient",
    "friktionskoefficientens": "friktionskoefficient",
    "friktionskoefficienter": "friktionskoefficient",
    "friktionskoefficienterna": "friktionskoefficient",
    "friktionskoefficienternas": "friktionskoefficient",
    "friktionskoefficienters": "friktionskoefficient",
    "friktionskoefficients": "friktionskoefficient",
    "friktionstalen": "friktionstal",
    "friktionstalens": "friktionstal",
    "friktionstalet": "friktionstal",
    "friktionstalets": "friktionstal",
    "friktionstals": "friktionstal",
    "friktionsvärmen": "friktionsvärme",
    "friktionsvärmens": "friktionsvärme",
    "friktionsvärmes": "friktionsvärme",
    "friktionsvärmet": "friktionsvärme",
    "friktionsvärmets": "friktionsvärme",
    "friktionsväxlingen": "friktionsväxling",
    "friktionsväxlingens": "friktionsväxling",
    "friktionsväxlings": "friktionsväxling",
    "frikyrk": "frikyrka",
    "frikyrkan": "frikyrka",
    "frikyrkans": "frikyrka",
    "frikyrkas": "frikyrka",
    "frikyrke": "frikyrka",
    "frikyrkliga": "frikyrklig",
    "frikyrkligare": "frikyrklig",
    "frikyrkligares": "frikyrklig",
    "frikyrkligas": "frikyrklig",
    "frikyrkligast": "frikyrklig",
    "frikyrkligaste": "frikyrklig",
    "frikyrkligastes": "frikyrklig",
    "frikyrkligasts": "frikyrklig",
    "frikyrklige": "frikyrklig",
    "frikyrkliges": "frikyrklig",
    "frikyrkligheten": "frikyrklighet",
    "frikyrklighetens": "frikyrklighet",
    "frikyrkligheter": "frikyrklighet",
    "frikyrkligheterna": "frikyrklighet",
    "frikyrkligheternas": "frikyrklighet",
    "frikyrkligheters": "frikyrklighet",
    "frikyrklighets": "frikyrklighet",
    "frikyrkligs": "frikyrklig",
    "frikyrkligt": "frikyrklig",
    "frikyrkligts": "frikyrklig",
    "frikyrko": "frikyrka",
    "frikyrkoförsamlingar": "frikyrkoförsamling",
    "frikyrkoförsamlingarna": "frikyrkoförsamling",
    "frikyrkoförsamlingarnas": "frikyrkoförsamling",
    "frikyrkoförsamlingars": "frikyrkoförsamling",
    "frikyrkoförsamlingen": "frikyrkoförsamling",
    "frikyrkoförsamlingens": "frikyrkoförsamling",
    "frikyrkoförsamlings": "frikyrkoförsamling",
    "frikyrkor": "frikyrka",
    "frikyrkorna": "frikyrka",
    "frikyrkornas": "frikyrka",
    "frikyrkors": "frikyrka",
    "frikyrks": "frikyrka",
    "frikänd": "frikänna",
    "frikända": "frikänna",
    "frikändas": "frikänna",
    "frikände": "frikänna",
    "frikändes": "frikänna",
    "frikänds": "frikänna",
    "frikänn": "frikänna",
    "frikännande": "frikänna",
    "frikännanden": "frikännande",
    "frikännandena": "frikännande",
    "frikännandenas": "frikännande",
    "frikännandens": "frikännande",
    "frikännandes": "frikännande",
    "frikännandet": "frikännande",
    "frikännandets": "frikännande",
    "frikännas": "frikänna",
    "frikänner": "frikänna",
    "frikännes": "frikänna",
    "frikänns": "frikänna",
    "frikänt": "frikänna",
    "frikänts": "frikänna",
    "frikåren": "frikår",
    "frikårens": "frikår",
    "frikårer": "frikår",
    "frikårerna": "frikår",
    "frikårernas": "frikår",
    "frikårers": "frikår",
    "frikårs": "frikår",
    "friköp": "friköpa",
    "friköpande": "friköpa",
    "friköpanden": "friköpande",
    "friköpandena": "friköpande",
    "friköpandenas": "friköpande",
    "friköpandens": "friköpande",
    "friköpandes": "friköpande",
    "friköpandet": "friköpande",
    "friköpandets": "friköpande",
    "friköpas": "friköpa",
    "friköpen": "friköp",
    "friköpens": "friköp",
    "friköper": "friköpa",
    "friköpes": "friköpa",
    "friköpet": "friköp",
    "friköpets": "friköp",
    "friköps": "friköpa",
    "friköpt": "friköpa",
    "friköpta": "friköpa",
    "friköptas": "friköpa",
    "friköpte": "friköpa",
    "friköptes": "friköpa",
    "friköpts": "friköpa",
    "frila": "frilägga",
    "frilade": "frilägga",
    "frilades": "frilägga",
    "frilagd": "frilägga",
    "frilagda": "frilägga",
    "frilagdas": "frilägga",
    "frilagde": "frilägga",
    "frilagdes": "frilägga",
    "frilagds": "frilägga",
    "frilagt": "frilägga",
    "frilagts": "frilägga",
    "frilanden": "friland",
    "frilandens": "friland",
    "frilandet": "friland",
    "frilandets": "friland",
    "frilands": "friland",
    "frilansade": "frilansa",
    "frilansades": "frilansa",
    "frilansande": "frilansa",
    "frilansanden": "frilansande",
    "frilansandena": "frilansande",
    "frilansandenas": "frilansande",
    "frilansandens": "frilansande",
    "frilansandes": "frilansande",
    "frilansandet": "frilansande",
    "frilansandets": "frilansande",
    "frilansar": "frilansare",
    "frilansaren": "frilansare",
    "frilansarens": "frilansare",
    "frilansares": "frilansare",
    "frilansarna": "frilansare",
    "frilansarnas": "frilansare",
    "frilansars": "frilans",
    "frilansas": "frilansa",
    "frilansat": "frilansa",
    "frilansats": "frilansa",
    "frilansen": "frilans",
    "frilansens": "frilans",
    "frilansjournalisten": "frilansjournalist",
    "frilansjournalistens": "frilansjournalist",
    "frilansjournalister": "frilansjournalist",
    "frilansjournalisterna": "frilansjournalist",
    "frilansjournalisternas": "frilansjournalist",
    "frilansjournalisters": "frilansjournalist",
    "frilansjournalists": "frilansjournalist",
    "frilansskribenten": "frilansskribent",
    "frilansskribentens": "frilansskribent",
    "frilansskribenter": "frilansskribent",
    "frilansskribenterna": "frilansskribent",
    "frilansskribenternas": "frilansskribent",
    "frilansskribenters": "frilansskribent",
    "frilansskribents": "frilansskribent",
    "frilansskådespelar": "frilansskådespelare",
    "frilansskådespelaren": "frilansskådespelare",
    "frilansskådespelarens": "frilansskådespelare",
    "frilansskådespelares": "frilansskådespelare",
    "frilansskådespelarna": "frilansskådespelare",
    "frilansskådespelarnas": "frilansskådespelare",
    "frilanstillvaron": "frilanstillvaro",
    "frilanstillvarons": "frilanstillvaro",
    "frilanstillvaros": "frilanstillvaro",
    "frilansvillkoren": "frilansvillkor",
    "frilansvillkorens": "frilansvillkor",
    "frilansvillkoret": "frilansvillkor",
    "frilansvillkorets": "frilansvillkor",
    "frilansvillkors": "frilansvillkor",
    "frilas": "frilägga",
    "frilistad": "frilista",
    "frilistade": "frilista",
    "frilistades": "frilista",
    "frilistads": "frilista",
    "frilistan": "frilista",
    "frilistande": "frilista",
    "frilistanden": "frilistande",
    "frilistandena": "frilistande",
    "frilistandenas": "frilistande",
    "frilistandens": "frilistande",
    "frilistandes": "frilistande",
    "frilistandet": "frilistande",
    "frilistandets": "frilistande",
    "frilistans": "frilista",
    "frilistar": "frilista",
    "frilistas": "frilista",
    "frilistat": "frilista",
    "frilistats": "frilista",
    "friliste": "frilista",
    "frilistor": "frilista",
    "frilistorna": "frilista",
    "frilistornas": "frilista",
    "frilistors": "frilista",
    "frill": "frilla",
    "frillan": "frilla",
    "frillans": "frilla",
    "frillas": "frilla",
    "frille": "frilla",
    "frillor": "frilla",
    "frillorna": "frilla",
    "frillornas": "frilla",
    "frillors": "frilla",
    "frills": "frilla",
    "friluftsbaden": "friluftsbad",
    "friluftsbadens": "friluftsbad",
    "friluftsbadet": "friluftsbad",
    "friluftsbadets": "friluftsbad",
    "friluftsbads": "friluftsbad",
    "friluftsdagar": "friluftsdag",
    "friluftsdagarna": "friluftsdag",
    "friluftsdagarnas": "friluftsdag",
    "friluftsdagars": "friluftsdag",
    "friluftsdagen": "friluftsdag",
    "friluftsdagens": "friluftsdag",
    "friluftsdags": "friluftsdag",
    "friluftshållet": "friluftshåll",
    "friluftshållets": "friluftshåll",
    "friluftshålls": "friluftshåll",
    "friluftsintressen": "friluftsintresse",
    "friluftsintressena": "friluftsintresse",
    "friluftsintressenas": "friluftsintresse",
    "friluftsintressens": "friluftsintresse",
    "friluftsintresses": "friluftsintresse",
    "friluftsintresset": "friluftsintresse",
    "friluftsintressets": "friluftsintresse",
    "friluftslivet": "friluftsliv",
    "friluftslivets": "friluftsliv",
    "friluftslivs": "friluftsliv",
    "friluftsmiljöer": "friluftsmiljö",
    "friluftsmiljöerna": "friluftsmiljö",
    "friluftsmiljöernas": "friluftsmiljö",
    "friluftsmiljöers": "friluftsmiljö",
    "friluftsmiljön": "friluftsmiljö",
    "friluftsmiljöns": "friluftsmiljö",
    "friluftsmiljös": "friluftsmiljö",
    "friluftsmuseer": "friluftsmuseum",
    "friluftsmuseerna": "friluftsmuseum",
    "friluftsmuseernas": "friluftsmuseum",
    "friluftsmuseers": "friluftsmuseum",
    "friluftsmuseet": "friluftsmuseum",
    "friluftsmuseets": "friluftsmuseum",
    "friluftsmusei": "friluftsmuseum",
    "friluftsmuseums": "friluftsmuseum",
    "friluftsområden": "friluftsområde",
    "friluftsområdena": "friluftsområde",
    "friluftsområdenas": "friluftsområde",
    "friluftsområdens": "friluftsområde",
    "friluftsområdes": "friluftsområde",
    "friluftsområdet": "friluftsområde",
    "friluftsområdets": "friluftsområde",
    "friluftsskogar": "friluftsskog",
    "friluftsskogarna": "friluftsskog",
    "friluftsskogarnas": "friluftsskog",
    "friluftsskogars": "friluftsskog",
    "friluftsskogen": "friluftsskog",
    "friluftsskogens": "friluftsskog",
    "friluftsskogs": "friluftsskog",
    "friluftsvanan": "friluftsvana",
    "friluftsvanans": "friluftsvana",
    "friluftsvanas": "friluftsvana",
    "friluftsvane": "friluftsvana",
    "friluftsvanor": "friluftsvana",
    "friluftsvanorna": "friluftsvana",
    "friluftsvanornas": "friluftsvana",
    "friluftsvanors": "friluftsvana",
    "friluftsändamålen": "friluftsändamål",
    "friluftsändamålens": "friluftsändamål",
    "friluftsändamålet": "friluftsändamål",
    "friluftsändamålets": "friluftsändamål",
    "friluftsändamåls": "friluftsändamål",
    "frilägen": "friläge",
    "frilägena": "friläge",
    "frilägenas": "friläge",
    "frilägens": "friläge",
    "friläges": "friläge",
    "friläget": "friläge",
    "frilägets": "friläge",
    "frilägg": "frilägga",
    "friläggande": "frilägga",
    "frilägganden": "friläggande",
    "friläggandena": "friläggande",
    "friläggandenas": "friläggande",
    "friläggandens": "friläggande",
    "friläggandes": "friläggande",
    "friläggandet": "friläggande",
    "friläggandets": "friläggande",
    "friläggas": "frilägga",
    "frilägger": "frilägga",
    "frilägges": "frilägga",
    "friläggs": "frilägga",
    "frimickeln": "frimickel",
    "frimickelns": "frimickel",
    "frimickels": "frimickel",
    "frimicklar": "frimickel",
    "frimicklarna": "frimickel",
    "frimicklarnas": "frimickel",
    "frimicklars": "frimickel",
    "frimodiga": "frimodig",
    "frimodigare": "frimodig",
    "frimodigares": "frimodig",
    "frimodigas": "frimodig",
    "frimodigast": "frimodig",
    "frimodigaste": "frimodig",
    "frimodigastes": "frimodig",
    "frimodigasts": "frimodig",
    "frimodige": "frimodig",
    "frimodiges": "frimodig",
    "frimodigheten": "frimodighet",
    "frimodighetens": "frimodighet",
    "frimodighets": "frimodighet",
    "frimodigs": "frimodig",
    "frimodigt": "frimodig",
    "frimodigts": "frimodig",
    "frimurar": "frimurare",
    "frimuraren": "frimurare",
    "frimurarens": "frimurare",
    "frimurares": "frimurare",
    "frimurarlogen": "frimurarloge",
    "frimurarlogens": "frimurarloge",
    "frimurarloger": "frimurarloge",
    "frimurarlogerna": "frimurarloge",
    "frimurarlogernas": "frimurarloge",
    "frimurarlogers": "frimurarloge",
    "frimurarloges": "frimurarloge",
    "frimurarna": "frimurare",
    "frimurarnas": "frimurare",
    "frimurarordens": "frimurarorden",
    "frimurarordnar": "frimurarorden",
    "frimurarordnarna": "frimurarorden",
    "frimurarordnarnas": "frimurarorden",
    "frimurarordnars": "frimurarorden",
    "frimurarordnen": "frimurarorden",
    "frimurarordnens": "frimurarorden",
    "frimureriet": "frimureri",
    "frimureriets": "frimureri",
    "frimureris": "frimureri",
    "frimurerit": "frimureri",
    "frimurerits": "frimureri",
    "frimärk": "frimärka",
    "frimärkande": "frimärka",
    "frimärkanden": "frimärkande",
    "frimärkandena": "frimärkande",
    "frimärkandenas": "frimärkande",
    "frimärkandens": "frimärkande",
    "frimärkandes": "frimärkande",
    "frimärkandet": "frimärkande",
    "frimärkandets": "frimärkande",
    "frimärkas": "frimärka",
    "frimärken": "frimärke",
    "frimärkena": "frimärke",
    "frimärkenas": "frimärke",
    "frimärkens": "frimärke",
    "frimärker": "frimärka",
    "frimärkes": "frimärke",
    "frimärket": "frimärke",
    "frimärkets": "frimärke",
    "frimärks": "frimärke",
    "frimärkssamlingar": "frimärkssamling",
    "frimärkssamlingarna": "frimärkssamling",
    "frimärkssamlingarnas": "frimärkssamling",
    "frimärkssamlingars": "frimärkssamling",
    "frimärkssamlingen": "frimärkssamling",
    "frimärkssamlingens": "frimärkssamling",
    "frimärkssamlings": "frimärkssamling",
    "frimärkt": "frimärka",
    "frimärkta": "frimärka",
    "frimärktas": "frimärka",
    "frimärkte": "frimärka",
    "frimärktes": "frimärka",
    "frimärkts": "frimärka",
    "fripassagerar": "fripassagerare",
    "fripassageraren": "fripassagerare",
    "fripassagerarens": "fripassagerare",
    "fripassagerares": "fripassagerare",
    "fripassagerarna": "fripassagerare",
    "fripassagerarnas": "fripassagerare",
    "friplåtar": "friplåt",
    "friplåtarna": "friplåt",
    "friplåtarnas": "friplåt",
    "friplåtars": "friplåt",
    "friplåten": "friplåt",
    "friplåtens": "friplåt",
    "friplåts": "friplåt",
    "frireligiösa": "frireligiös",
    "frireligiösare": "frireligiös",
    "frireligiösares": "frireligiös",
    "frireligiösas": "frireligiös",
    "frireligiösast": "frireligiös",
    "frireligiösaste": "frireligiös",
    "frireligiösastes": "frireligiös",
    "frireligiösasts": "frireligiös",
    "frireligiöse": "frireligiös",
    "frireligiöses": "frireligiös",
    "frireligiöst": "frireligiös",
    "frireligiösts": "frireligiös",
    "fris": "fri",
    "frisatt": "frisätta",
    "frisatta": "frisätta",
    "frisattas": "frisätta",
    "frisatte": "frisätta",
    "frisattes": "frisätta",
    "frisatts": "frisätta",
    "frisbeear": "frisbee",
    "frisbeearna": "frisbee",
    "frisbeearnas": "frisbee",
    "frisbeears": "frisbee",
    "frisbeen": "frisbee",
    "frisbeens": "frisbee",
    "frisbees": "frisbee",
    "frisedeln": "frisedel",
    "frisedelns": "frisedel",
    "frisedels": "frisedel",
    "frisedlar": "frisedel",
    "frisedlarna": "frisedel",
    "frisedlarnas": "frisedel",
    "frisedlars": "frisedel",
    "frisen": "fris",
    "frisens": "fris",
    "friser": "frisera",
    "friserad": "frisera",
    "friserade": "frisera",
    "friserades": "frisera",
    "friserads": "frisera",
    "friserande": "frisera",
    "friseranden": "friserande",
    "friserandena": "friserande",
    "friserandenas": "friserande",
    "friserandens": "friserande",
    "friserandes": "friserande",
    "friserandet": "friserande",
    "friserandets": "friserande",
    "friserar": "frisera",
    "friseras": "frisera",
    "friserat": "frisera",
    "friserats": "frisera",
    "friserbara": "friserbar",
    "friserbarare": "friserbar",
    "friserbarares": "friserbar",
    "friserbaras": "friserbar",
    "friserbarast": "friserbar",
    "friserbaraste": "friserbar",
    "friserbarastes": "friserbar",
    "friserbarasts": "friserbar",
    "friserbare": "friserbar",
    "friserbares": "friserbar",
    "friserbarheten": "friserbarhet",
    "friserbarhetens": "friserbarhet",
    "friserbarhets": "friserbarhet",
    "friserbars": "friserbar",
    "friserbart": "friserbar",
    "friserbarts": "friserbar",
    "friserna": "fris",
    "frisernas": "fris",
    "frisers": "fris",
    "frisersalongen": "frisersalong",
    "frisersalongens": "frisersalong",
    "frisersalonger": "frisersalong",
    "frisersalongerna": "frisersalong",
    "frisersalongernas": "frisersalong",
    "frisersalongers": "frisersalong",
    "frisersalongs": "frisersalong",
    "frisimmet": "frisim",
    "frisimmets": "frisim",
    "frisims": "frisim",
    "frisinnade": "frisinnad",
    "frisinnades": "frisinnad",
    "frisinnads": "frisinnad",
    "frisinnat": "frisinnad",
    "frisinnats": "frisinnad",
    "frisinnes": "frisinne",
    "frisinnet": "frisinne",
    "frisinnets": "frisinne",
    "frisisk": "frisiska",
    "frisiska": "frisisk",
    "frisiskan": "frisiska",
    "frisiskans": "frisiska",
    "frisiskare": "frisisk",
    "frisiskares": "frisisk",
    "frisiskas": "frisiska",
    "frisiskast": "frisisk",
    "frisiskaste": "frisisk",
    "frisiskastes": "frisisk",
    "frisiskasts": "frisisk",
    "frisiske": "frisiska",
    "frisiskes": "frisisk",
    "frisiskor": "frisiska",
    "frisiskorna": "frisiska",
    "frisiskornas": "frisiska",
    "frisiskors": "frisiska",
    "frisisks": "frisisk",
    "frisiskt": "frisisk",
    "frisiskts": "frisisk",
    "friska": "frisk",
    "friskade": "friska",
    "friskades": "friska",
    "friskande": "friska",
    "friskanden": "friskande",
    "friskandena": "friskande",
    "friskandenas": "friskande",
    "friskandens": "friskande",
    "friskandes": "friskande",
    "friskandet": "friskande",
    "friskandets": "friskande",
    "friskanmäl": "friskanmäla",
    "friskanmälande": "friskanmäla",
    "friskanmälanden": "friskanmälande",
    "friskanmälandena": "friskanmälande",
    "friskanmälandenas": "friskanmälande",
    "friskanmälandens": "friskanmälande",
    "friskanmälandes": "friskanmälande",
    "friskanmälandet": "friskanmälande",
    "friskanmälandets": "friskanmälande",
    "friskanmälas": "friskanmäla",
    "friskanmäld": "friskanmäla",
    "friskanmälda": "friskanmäla",
    "friskanmäldas": "friskanmäla",
    "friskanmälde": "friskanmäla",
    "friskanmäldes": "friskanmäla",
    "friskanmälds": "friskanmäla",
    "friskanmäler": "friskanmäla",
    "friskanmäles": "friskanmäla",
    "friskanmäls": "friskanmäla",
    "friskanmält": "friskanmäla",
    "friskanmälts": "friskanmäla",
    "friskar": "friska",
    "friskare": "frisk",
    "friskares": "frisk",
    "friskas": "friska",
    "friskast": "frisk",
    "friskaste": "frisk",
    "friskastes": "frisk",
    "friskasts": "frisk",
    "friskat": "friska",
    "friskats": "friska",
    "friske": "frisk",
    "friskes": "frisk",
    "friskförklarad": "friskförklara",
    "friskförklarade": "friskförklara",
    "friskförklarades": "friskförklara",
    "friskförklarads": "friskförklara",
    "friskförklarande": "friskförklara",
    "friskförklaranden": "friskförklarande",
    "friskförklarandena": "friskförklarande",
    "friskförklarandenas": "friskförklarande",
    "friskförklarandens": "friskförklarande",
    "friskförklarandes": "friskförklarande",
    "friskförklarandet": "friskförklarande",
    "friskförklarandets": "friskförklarande",
    "friskförklarar": "friskförklara",
    "friskförklaras": "friskförklara",
    "friskförklarat": "friskförklara",
    "friskförklarats": "friskförklara",
    "friskheten": "friskhet",
    "friskhetens": "friskhet",
    "friskhets": "friskhet",
    "friskintygen": "friskintyg",
    "friskintygens": "friskintyg",
    "friskintyget": "friskintyg",
    "friskintygets": "friskintyg",
    "friskintygs": "friskintyg",
    "friskluften": "friskluft",
    "friskluftens": "friskluft",
    "frisklufts": "friskluft",
    "friskluftsintagen": "friskluftsintag",
    "friskluftsintagens": "friskluftsintag",
    "friskluftsintaget": "friskluftsintag",
    "friskluftsintagets": "friskluftsintag",
    "friskluftsintags": "friskluftsintag",
    "friskluftsventilationen": "friskluftsventilation",
    "friskluftsventilationens": "friskluftsventilation",
    "friskluftsventilations": "friskluftsventilation",
    "friskrivens": "friskriven",
    "friskrivet": "friskriven",
    "friskrivets": "friskriven",
    "friskrivna": "friskriven",
    "friskrivnare": "friskriven",
    "friskrivnares": "friskriven",
    "friskrivnas": "friskriven",
    "friskrivnast": "friskriven",
    "friskrivnaste": "friskriven",
    "friskrivnastes": "friskriven",
    "friskrivnasts": "friskriven",
    "friskrivne": "friskriven",
    "friskrivnes": "friskriven",
    "friskrivningar": "friskrivning",
    "friskrivningarna": "friskrivning",
    "friskrivningarnas": "friskrivning",
    "friskrivningars": "friskrivning",
    "friskrivningen": "friskrivning",
    "friskrivningens": "friskrivning",
    "friskrivnings": "friskrivning",
    "frisks": "frisk",
    "friskskrev": "friskskriva",
    "friskskrevs": "friskskriva",
    "friskskriv": "friskskriva",
    "friskskrivande": "friskskriva",
    "friskskrivanden": "friskskrivande",
    "friskskrivandena": "friskskrivande",
    "friskskrivandenas": "friskskrivande",
    "friskskrivandens": "friskskrivande",
    "friskskrivandes": "friskskrivande",
    "friskskrivandet": "friskskrivande",
    "friskskrivandets": "friskskrivande",
    "friskskrivas": "friskskriva",
    "friskskrive": "friskskriva",
    "friskskriven": "friskskriva",
    "friskskrivens": "friskskriva",
    "friskskriver": "friskskriva",
    "friskskrives": "friskskriva",
    "friskskrivet": "friskskriva",
    "friskskrivets": "friskskriva",
    "friskskrivit": "friskskriva",
    "friskskrivits": "friskskriva",
    "friskskrivna": "friskskriva",
    "friskskrivnas": "friskskriva",
    "friskskrivne": "friskskriva",
    "friskskrivnes": "friskskriva",
    "friskskrivs": "friskskriva",
    "frisksportade": "frisksporta",
    "frisksportades": "frisksporta",
    "frisksportande": "frisksporta",
    "frisksportanden": "frisksportande",
    "frisksportandena": "frisksportande",
    "frisksportandenas": "frisksportande",
    "frisksportandens": "frisksportande",
    "frisksportandes": "frisksportande",
    "frisksportandet": "frisksportande",
    "frisksportandets": "frisksportande",
    "frisksportar": "frisksportare",
    "frisksportaren": "frisksportare",
    "frisksportarens": "frisksportare",
    "frisksportares": "frisksportare",
    "frisksportarna": "frisksportare",
    "frisksportarnas": "frisksportare",
    "frisksportas": "frisksporta",
    "frisksportat": "frisksporta",
    "frisksportats": "frisksporta",
    "frisksporten": "frisksport",
    "frisksportens": "frisksport",
    "frisksports": "frisksport",
    "friskt": "frisk",
    "friskts": "frisk",
    "friskusar": "friskus",
    "friskusarna": "friskus",
    "friskusarnas": "friskus",
    "friskusars": "friskus",
    "friskusen": "friskus",
    "friskusens": "friskus",
    "friskvården": "friskvård",
    "friskvårdens": "friskvård",
    "friskvårds": "friskvård",
    "frislagen": "frislag",
    "frislagens": "frislag",
    "frislaget": "frislag",
    "frislagets": "frislag",
    "frislags": "frislag",
    "frisläpp": "frisläppa",
    "frisläppande": "frisläppa",
    "frisläppanden": "frisläppande",
    "frisläppandena": "frisläppande",
    "frisläppandenas": "frisläppande",
    "frisläppandens": "frisläppande",
    "frisläppandes": "frisläppande",
    "frisläppandet": "frisläppande",
    "frisläppandets": "frisläppande",
    "frisläppas": "frisläppa",
    "frisläpper": "frisläppa",
    "frisläppes": "frisläppa",
    "frisläpps": "frisläppa",
    "frisläppt": "frisläppa",
    "frisläppta": "frisläppa",
    "frisläpptas": "frisläppa",
    "frisläppte": "frisläppa",
    "frisläpptes": "frisläppa",
    "frisläppts": "frisläppa",
    "frisparkar": "frispark",
    "frisparkarna": "frispark",
    "frisparkarnas": "frispark",
    "frisparkars": "frispark",
    "frisparken": "frispark",
    "frisparkens": "frispark",
    "frisparks": "frispark",
    "frispel": "frispela",
    "frispelad": "frispela",
    "frispelade": "frispela",
    "frispelades": "frispela",
    "frispelads": "frispela",
    "frispelande": "frispela",
    "frispelanden": "frispelande",
    "frispelandena": "frispelande",
    "frispelandenas": "frispelande",
    "frispelandens": "frispelande",
    "frispelandes": "frispelande",
    "frispelandet": "frispelande",
    "frispelandets": "frispelande",
    "frispelar": "frispela",
    "frispelas": "frispela",
    "frispelat": "frispela",
    "frispelats": "frispela",
    "frispråkiga": "frispråkig",
    "frispråkigare": "frispråkig",
    "frispråkigares": "frispråkig",
    "frispråkigas": "frispråkig",
    "frispråkigast": "frispråkig",
    "frispråkigaste": "frispråkig",
    "frispråkigastes": "frispråkig",
    "frispråkigasts": "frispråkig",
    "frispråkige": "frispråkig",
    "frispråkiges": "frispråkig",
    "frispråkigheten": "frispråkighet",
    "frispråkighetens": "frispråkighet",
    "frispråkigheter": "frispråkighet",
    "frispråkigheterna": "frispråkighet",
    "frispråkigheternas": "frispråkighet",
    "frispråkigheters": "frispråkighet",
    "frispråkighets": "frispråkighet",
    "frispråkigs": "frispråkig",
    "frispråkigt": "frispråkig",
    "frispråkigts": "frispråkig",
    "friss": "frissa",
    "frissan": "frissa",
    "frissans": "frissa",
    "frissas": "frissa",
    "frisse": "frissa",
    "frissor": "frissa",
    "frissorna": "frissa",
    "frissornas": "frissa",
    "frissors": "frissa",
    "fristaden": "fristad",
    "fristadens": "fristad",
    "fristads": "fristad",
    "fristan": "fristad",
    "fristans": "fristad",
    "fristaten": "fristat",
    "fristatens": "fristat",
    "fristater": "fristat",
    "fristaterna": "fristat",
    "fristaternas": "fristat",
    "fristaters": "fristat",
    "fristats": "fristat",
    "fristen": "frist",
    "fristens": "frist",
    "frister": "frist",
    "fristerna": "frist",
    "fristernas": "frist",
    "fristers": "frist",
    "fristilen": "fristil",
    "fristilens": "fristil",
    "fristils": "fristil",
    "frists": "frist",
    "fristäder": "fristad",
    "fristäderna": "fristad",
    "fristädernas": "fristad",
    "fristäders": "fristad",
    "friställ": "friställa",
    "friställande": "friställa",
    "friställanden": "friställande",
    "friställandena": "friställande",
    "friställandenas": "friställande",
    "friställandens": "friställande",
    "friställandes": "friställande",
    "friställandet": "friställande",
    "friställandets": "friställande",
    "friställas": "friställa",
    "friställd": "friställa",
    "friställda": "friställa",
    "friställdas": "friställa",
    "friställde": "friställa",
    "friställdes": "friställa",
    "friställds": "friställa",
    "friställer": "friställa",
    "friställes": "friställa",
    "friställs": "friställa",
    "friställt": "friställa",
    "friställts": "friställa",
    "frisyren": "frisyr",
    "frisyrens": "frisyr",
    "frisyrer": "frisyr",
    "frisyrerna": "frisyr",
    "frisyrernas": "frisyr",
    "frisyrers": "frisyr",
    "frisyrgeléer": "frisyrgelé",
    "frisyrgeléerna": "frisyrgelé",
    "frisyrgeléernas": "frisyrgelé",
    "frisyrgeléers": "frisyrgelé",
    "frisyrgeléet": "frisyrgelé",
    "frisyrgeléets": "frisyrgelé",
    "frisyrgelén": "frisyrgelé",
    "frisyrgeléns": "frisyrgelé",
    "frisyrgelés": "frisyrgelé",
    "frisyrgelét": "frisyrgelé",
    "frisyrgeléts": "frisyrgelé",
    "frisyrs": "frisyr",
    "frisätt": "frisätta",
    "frisättande": "frisätta",
    "frisättanden": "frisättande",
    "frisättandena": "frisättande",
    "frisättandenas": "frisättande",
    "frisättandens": "frisättande",
    "frisättandes": "frisättande",
    "frisättandet": "frisättande",
    "frisättandets": "frisättande",
    "frisättas": "frisätta",
    "frisätter": "frisätta",
    "frisättes": "frisätta",
    "frisätts": "frisätta",
    "frisöreleven": "frisörelev",
    "frisörelevens": "frisörelev",
    "frisörelever": "frisörelev",
    "frisöreleverna": "frisörelev",
    "frisörelevernas": "frisörelev",
    "frisörelevers": "frisörelev",
    "frisörelevs": "frisörelev",
    "frisören": "frisör",
    "frisörens": "frisör",
    "frisörer": "frisör",
    "frisörerna": "frisör",
    "frisörernas": "frisör",
    "frisörers": "frisör",
    "frisörn": "frisör",
    "frisörns": "frisör",
    "frisörs": "frisör",
    "frisörsalongen": "frisörsalong",
    "frisörsalongens": "frisörsalong",
    "frisörsalonger": "frisörsalong",
    "frisörsalongerna": "frisörsalong",
    "frisörsalongernas": "frisörsalong",
    "frisörsalongers": "frisörsalong",
    "frisörsalongs": "frisörsalong",
    "frisörskan": "frisörska",
    "frisörskans": "frisörska",
    "frisörskas": "frisörska",
    "frisörske": "frisörska",
    "frisörskor": "frisörska",
    "frisörskorna": "frisörska",
    "frisörskornas": "frisörska",
    "frisörskors": "frisörska",
    "frisörstolar": "frisörstol",
    "frisörstolarna": "frisörstol",
    "frisörstolarnas": "frisörstol",
    "frisörstolars": "frisörstol",
    "frisörstolen": "frisörstol",
    "frisörstolens": "frisörstol",
    "frisörstols": "frisörstol",
    "fritag": "frita",
    "fritaga": "frita",
    "fritagande": "frita",
    "fritaganden": "fritagande",
    "fritagandena": "fritagande",
    "fritagandenas": "fritagande",
    "fritagandens": "fritagande",
    "fritagandes": "fritagande",
    "fritagandet": "fritagande",
    "fritagandets": "fritagande",
    "fritagas": "frita",
    "fritage": "frita",
    "fritagen": "frita",
    "fritagens": "frita",
    "fritager": "frita",
    "fritages": "frita",
    "fritaget": "frita",
    "fritagets": "frita",
    "fritagit": "frita",
    "fritagits": "frita",
    "fritagna": "frita",
    "fritagnas": "frita",
    "fritagne": "frita",
    "fritagnes": "frita",
    "fritagningar": "fritagning",
    "fritagningarna": "fritagning",
    "fritagningarnas": "fritagning",
    "fritagningars": "fritagning",
    "fritagningen": "fritagning",
    "fritagningens": "fritagning",
    "fritagnings": "fritagning",
    "fritagningsförsöken": "fritagningsförsök",
    "fritagningsförsökens": "fritagningsförsök",
    "fritagningsförsöket": "fritagningsförsök",
    "fritagningsförsökets": "fritagningsförsök",
    "fritagningsförsöks": "fritagningsförsök",
    "fritags": "frita",
    "fritar": "frita",
    "fritas": "frita",
    "friterad": "fritera",
    "friterade": "fritera",
    "friterades": "fritera",
    "friterads": "fritera",
    "friterande": "fritera",
    "friteranden": "friterande",
    "friterandena": "friterande",
    "friterandenas": "friterande",
    "friterandens": "friterande",
    "friterandes": "friterande",
    "friterandet": "friterande",
    "friterandets": "friterande",
    "friterar": "fritera",
    "friteras": "fritera",
    "friterat": "fritera",
    "friterats": "fritera",
    "friterbara": "friterbar",
    "friterbarare": "friterbar",
    "friterbarares": "friterbar",
    "friterbaras": "friterbar",
    "friterbarast": "friterbar",
    "friterbaraste": "friterbar",
    "friterbarastes": "friterbar",
    "friterbarasts": "friterbar",
    "friterbare": "friterbar",
    "friterbares": "friterbar",
    "friterbarheten": "friterbarhet",
    "friterbarhetens": "friterbarhet",
    "friterbarhets": "friterbarhet",
    "friterbars": "friterbar",
    "friterbart": "friterbar",
    "friterbarts": "friterbar",
    "friteringar": "fritering",
    "friteringarna": "fritering",
    "friteringarnas": "fritering",
    "friteringars": "fritering",
    "friteringen": "fritering",
    "friteringens": "fritering",
    "friterings": "fritering",
    "fritiden": "fritid",
    "fritidens": "fritid",
    "fritids": "fritid",
    "fritidsaktiviteten": "fritidsaktivitet",
    "fritidsaktivitetens": "fritidsaktivitet",
    "fritidsaktiviteter": "fritidsaktivitet",
    "fritidsaktiviteterna": "fritidsaktivitet",
    "fritidsaktiviteternas": "fritidsaktivitet",
    "fritidsaktiviteters": "fritidsaktivitet",
    "fritidsaktivitets": "fritidsaktivitet",
    "fritidsbebyggelsen": "fritidsbebyggelse",
    "fritidsbebyggelsens": "fritidsbebyggelse",
    "fritidsbebyggelser": "fritidsbebyggelse",
    "fritidsbebyggelserna": "fritidsbebyggelse",
    "fritidsbebyggelsernas": "fritidsbebyggelse",
    "fritidsbebyggelsers": "fritidsbebyggelse",
    "fritidsbebyggelses": "fritidsbebyggelse",
    "fritidsbyar": "fritidsby",
    "fritidsbyarna": "fritidsby",
    "fritidsbyarnas": "fritidsby",
    "fritidsbyars": "fritidsby",
    "fritidsbyn": "fritidsby",
    "fritidsbyns": "fritidsby",
    "fritidsbys": "fritidsby",
    "fritidsbåtar": "fritidsbåt",
    "fritidsbåtarna": "fritidsbåt",
    "fritidsbåtarnas": "fritidsbåt",
    "fritidsbåtars": "fritidsbåt",
    "fritidsbåten": "fritidsbåt",
    "fritidsbåtens": "fritidsbåt",
    "fritidsbåts": "fritidsbåt",
    "fritidsförvaltningar": "fritidsförvaltning",
    "fritidsförvaltningarna": "fritidsförvaltning",
    "fritidsförvaltningarnas": "fritidsförvaltning",
    "fritidsförvaltningars": "fritidsförvaltning",
    "fritidsförvaltningen": "fritidsförvaltning",
    "fritidsförvaltningens": "fritidsförvaltning",
    "fritidsförvaltnings": "fritidsförvaltning",
    "fritidsgårdar": "fritidsgård",
    "fritidsgårdarna": "fritidsgård",
    "fritidsgårdarnas": "fritidsgård",
    "fritidsgårdars": "fritidsgård",
    "fritidsgården": "fritidsgård",
    "fritidsgårdens": "fritidsgård",
    "fritidsgårds": "fritidsgård",
    "fritidshemmen": "fritidshem",
    "fritidshemmens": "fritidshem",
    "fritidshemmet": "fritidshem",
    "fritidshemmets": "fritidshem",
    "fritidshems": "fritidshem",
    "fritidshusen": "fritidshus",
    "fritidshusens": "fritidshus",
    "fritidshuset": "fritidshus",
    "fritidshusets": "fritidshus",
    "fritidshusägar": "fritidshusägare",
    "fritidshusägaren": "fritidshusägare",
    "fritidshusägarens": "fritidshusägare",
    "fritidshusägares": "fritidshusägare",
    "fritidshusägarna": "fritidshusägare",
    "fritidshusägarnas": "fritidshusägare",
    "fritidsledar": "fritidsledare",
    "fritidsledaren": "fritidsledare",
    "fritidsledarens": "fritidsledare",
    "fritidsledares": "fritidsledare",
    "fritidsledarna": "fritidsledare",
    "fritidsledarnas": "fritidsledare",
    "fritidslokalen": "fritidslokal",
    "fritidslokalens": "fritidslokal",
    "fritidslokaler": "fritidslokal",
    "fritidslokalerna": "fritidslokal",
    "fritidslokalernas": "fritidslokal",
    "fritidslokalers": "fritidslokal",
    "fritidslokals": "fritidslokal",
    "fritidsnämnden": "fritidsnämnd",
    "fritidsnämndens": "fritidsnämnd",
    "fritidsnämnder": "fritidsnämnd",
    "fritidsnämnderna": "fritidsnämnd",
    "fritidsnämndernas": "fritidsnämnd",
    "fritidsnämnders": "fritidsnämnd",
    "fritidsnämnds": "fritidsnämnd",
    "fritidsområden": "fritidsområde",
    "fritidsområdena": "fritidsområde",
    "fritidsområdenas": "fritidsområde",
    "fritidsområdens": "fritidsområde",
    "fritidsområdes": "fritidsområde",
    "fritidsområdet": "fritidsområde",
    "fritidsområdets": "fritidsområde",
    "fritidspedagogen": "fritidspedagog",
    "fritidspedagogens": "fritidspedagog",
    "fritidspedagoger": "fritidspedagog",
    "fritidspedagogerna": "fritidspedagog",
    "fritidspedagogernas": "fritidspedagog",
    "fritidspedagogers": "fritidspedagog",
    "fritidspedagogs": "fritidspedagog",
    "fritidspolitiken": "fritidspolitik",
    "fritidspolitikens": "fritidspolitik",
    "fritidspolitikern": "fritidspolitiker",
    "fritidspolitikerna": "fritidspolitiker",
    "fritidspolitikernas": "fritidspolitiker",
    "fritidspolitikerns": "fritidspolitiker",
    "fritidspolitikers": "fritidspolitiker",
    "fritidspolitiks": "fritidspolitik",
    "fritidspolitiska": "fritidspolitisk",
    "fritidspolitiskas": "fritidspolitisk",
    "fritidspolitiske": "fritidspolitisk",
    "fritidspolitiskes": "fritidspolitisk",
    "fritidspolitisks": "fritidspolitisk",
    "fritidspolitiskt": "fritidspolitisk",
    "fritidspolitiskts": "fritidspolitisk",
    "fritidsproblemen": "fritidsproblem",
    "fritidsproblemens": "fritidsproblem",
    "fritidsproblemet": "fritidsproblem",
    "fritidsproblemets": "fritidsproblem",
    "fritidsproblems": "fritidsproblem",
    "fritidsstugan": "fritidsstuga",
    "fritidsstugans": "fritidsstuga",
    "fritidsstugas": "fritidsstuga",
    "fritidsstuge": "fritidsstuga",
    "fritidsstugor": "fritidsstuga",
    "fritidsstugorna": "fritidsstuga",
    "fritidsstugornas": "fritidsstuga",
    "fritidsstugors": "fritidsstuga",
    "fritidsstugu": "fritidsstuga",
    "fritidssysselsättningar": "fritidssysselsättning",
    "fritidssysselsättningarna": "fritidssysselsättning",
    "fritidssysselsättningarnas": "fritidssysselsättning",
    "fritidssysselsättningars": "fritidssysselsättning",
    "fritidssysselsättningen": "fritidssysselsättning",
    "fritidssysselsättningens": "fritidssysselsättning",
    "fritidssysselsättnings": "fritidssysselsättning",
    "fritisen": "fritis",
    "fritisens": "fritis",
    "fritiset": "fritis",
    "fritisets": "fritis",
    "fritog": "frita",
    "fritoge": "frita",
    "fritoges": "frita",
    "fritogs": "frita",
    "fritt": "fri",
    "fritts": "fri",
    "frityren": "frityr",
    "frityrens": "frityr",
    "frityrer": "frityr",
    "frityrerna": "frityr",
    "frityrernas": "frityr",
    "frityrers": "frityr",
    "frityrs": "frityr",
    "fritänkar": "fritänkare",
    "fritänkaren": "fritänkare",
    "fritänkarens": "fritänkare",
    "fritänkares": "fritänkare",
    "fritänkarna": "fritänkare",
    "fritänkarnas": "fritänkare",
    "fritänkeriet": "fritänkeri",
    "fritänkeriets": "fritänkeri",
    "fritänkeris": "fritänkeri",
    "fritänkerit": "fritänkeri",
    "fritänkerits": "fritänkeri",
    "frivakten": "frivakt",
    "frivaktens": "frivakt",
    "frivakter": "frivakt",
    "frivakterna": "frivakt",
    "frivakternas": "frivakt",
    "frivakters": "frivakt",
    "frivakts": "frivakt",
    "frivilliga": "frivillig",
    "frivilligare": "frivillig",
    "frivilligares": "frivillig",
    "frivilligas": "frivillig",
    "frivilligast": "frivillig",
    "frivilligaste": "frivillig",
    "frivilligastes": "frivillig",
    "frivilligasts": "frivillig",
    "frivillige": "frivillig",
    "frivilliges": "frivillig",
    "frivilligheten": "frivillighet",
    "frivillighetens": "frivillighet",
    "frivilligheter": "frivillighet",
    "frivilligheterna": "frivillighet",
    "frivilligheternas": "frivillighet",
    "frivilligheters": "frivillighet",
    "frivillighets": "frivillighet",
    "frivilligorganisationen": "frivilligorganisation",
    "frivilligorganisationens": "frivilligorganisation",
    "frivilligorganisationer": "frivilligorganisation",
    "frivilligorganisationerna": "frivilligorganisation",
    "frivilligorganisationernas": "frivilligorganisation",
    "frivilligorganisationers": "frivilligorganisation",
    "frivilligorganisations": "frivilligorganisation",
    "frivilligs": "frivillig",
    "frivilligt": "frivillig",
    "frivilligts": "frivillig",
    "frivola": "frivol",
    "frivolare": "frivol",
    "frivolares": "frivol",
    "frivolas": "frivol",
    "frivolast": "frivol",
    "frivolaste": "frivol",
    "frivolastes": "frivol",
    "frivolasts": "frivol",
    "frivole": "frivol",
    "frivoles": "frivol",
    "frivoliteten": "frivolitet",
    "frivolitetens": "frivolitet",
    "frivoliteter": "frivolitet",
    "frivoliteterna": "frivolitet",
    "frivoliteternas": "frivolitet",
    "frivoliteters": "frivolitet",
    "frivolitets": "frivolitet",
    "frivols": "frivol",
    "frivolt": "frivol",
    "frivolten": "frivolt",
    "frivoltens": "frivolt",
    "frivolter": "frivolt",
    "frivolterna": "frivolt",
    "frivolternas": "frivolt",
    "frivolters": "frivolt",
    "frivolts": "frivolt",
    "frivården": "frivård",
    "frivårdens": "frivård",
    "frivårds": "frivård",
    "frizonen": "frizon",
    "frizonens": "frizon",
    "frizoner": "frizon",
    "frizonerna": "frizon",
    "frizonernas": "frizon",
    "frizoners": "frizon",
    "frizons": "frizon",
    "friåkningar": "friåkning",
    "friåkningarna": "friåkning",
    "friåkningarnas": "friåkning",
    "friåkningars": "friåkning",
    "friåkningen": "friåkning",
    "friåkningens": "friåkning",
    "friåknings": "friåkning",
    "friåren": "friår",
    "friårens": "friår",
    "friåret": "friår",
    "friårets": "friår",
    "friårs": "friår",
    "frodades": "frodas",
    "frodats": "frodas",
    "frodiga": "frodig",
    "frodigare": "frodig",
    "frodigares": "frodig",
    "frodigas": "frodig",
    "frodigast": "frodig",
    "frodigaste": "frodig",
    "frodigastes": "frodig",
    "frodigasts": "frodig",
    "frodige": "frodig",
    "frodiges": "frodig",
    "frodigheten": "frodighet",
    "frodighetens": "frodighet",
    "frodighets": "frodighet",
    "frodigs": "frodig",
    "frodigt": "frodig",
    "frodigts": "frodig",
    "fromagen": "fromage",
    "fromagens": "fromage",
    "fromager": "fromage",
    "fromagerna": "fromage",
    "fromagernas": "fromage",
    "fromagers": "fromage",
    "fromages": "fromage",
    "fromheten": "fromhet",
    "fromhetens": "fromhet",
    "fromheter": "fromhet",
    "fromheterna": "fromhet",
    "fromheternas": "fromhet",
    "fromheters": "fromhet",
    "fromhets": "fromhet",
    "fromhetsivern": "fromhetsiver",
    "fromhetsiverns": "fromhetsiver",
    "fromhetsivers": "fromhetsiver",
    "fromlade": "fromla",
    "fromlades": "fromla",
    "fromlande": "fromla",
    "fromlanden": "fromlande",
    "fromlandena": "fromlande",
    "fromlandenas": "fromlande",
    "fromlandens": "fromlande",
    "fromlandes": "fromlande",
    "fromlandet": "fromlande",
    "fromlandets": "fromlande",
    "fromlar": "fromla",
    "fromlas": "fromla",
    "fromlat": "fromla",
    "fromlats": "fromla",
    "fromleriet": "fromleri",
    "fromleriets": "fromleri",
    "fromleris": "fromleri",
    "fromlerit": "fromleri",
    "fromlerits": "fromleri",
    "fromma": "from",
    "frommare": "from",
    "frommares": "from",
    "frommas": "from",
    "frommast": "from",
    "frommaste": "from",
    "frommastes": "from",
    "frommasts": "from",
    "fromme": "from",
    "frommel": "fromla",
    "frommes": "from",
    "froms": "from",
    "fromsinta": "fromsint",
    "fromsintare": "fromsint",
    "fromsintares": "fromsint",
    "fromsintas": "fromsint",
    "fromsintast": "fromsint",
    "fromsintaste": "fromsint",
    "fromsintastes": "fromsint",
    "fromsintasts": "fromsint",
    "fromsinte": "fromsint",
    "fromsintes": "fromsint",
    "fromsintheten": "fromsinthet",
    "fromsinthetens": "fromsinthet",
    "fromsinthets": "fromsinthet",
    "fromsints": "fromsint",
    "fromt": "from",
    "fromts": "from",
    "fronderad": "frondera",
    "fronderade": "frondera",
    "fronderades": "frondera",
    "fronderads": "frondera",
    "fronderande": "frondera",
    "fronderanden": "fronderande",
    "fronderandena": "fronderande",
    "fronderandenas": "fronderande",
    "fronderandens": "fronderande",
    "fronderandes": "fronderande",
    "fronderandet": "fronderande",
    "fronderandets": "fronderande",
    "fronderar": "frondera",
    "fronderas": "frondera",
    "fronderat": "frondera",
    "fronderats": "frondera",
    "fronderbara": "fronderbar",
    "fronderbarare": "fronderbar",
    "fronderbarares": "fronderbar",
    "fronderbaras": "fronderbar",
    "fronderbarast": "fronderbar",
    "fronderbaraste": "fronderbar",
    "fronderbarastes": "fronderbar",
    "fronderbarasts": "fronderbar",
    "fronderbare": "fronderbar",
    "fronderbares": "fronderbar",
    "fronderbarheten": "fronderbarhet",
    "fronderbarhetens": "fronderbarhet",
    "fronderbarhets": "fronderbarhet",
    "fronderbars": "fronderbar",
    "fronderbart": "fronderbar",
    "fronderbarts": "fronderbar",
    "fronderingar": "frondering",
    "fronderingarna": "frondering",
    "fronderingarnas": "frondering",
    "fronderingars": "frondering",
    "fronderingen": "frondering",
    "fronderingens": "frondering",
    "fronderings": "frondering",
    "frondören": "frondör",
    "frondörens": "frondör",
    "frondörer": "frondör",
    "frondörerna": "frondör",
    "frondörernas": "frondör",
    "frondörers": "frondör",
    "frondörs": "frondör",
    "frontad": "fronta",
    "frontade": "fronta",
    "frontades": "fronta",
    "frontads": "fronta",
    "frontala": "frontal",
    "frontalangreppen": "frontalangrepp",
    "frontalangreppens": "frontalangrepp",
    "frontalangreppet": "frontalangrepp",
    "frontalangreppets": "frontalangrepp",
    "frontalangrepps": "frontalangrepp",
    "frontalare": "frontal",
    "frontalares": "frontal",
    "frontalas": "frontal",
    "frontalast": "frontal",
    "frontalaste": "frontal",
    "frontalastes": "frontal",
    "frontalasts": "frontal",
    "frontale": "frontal",
    "frontales": "frontal",
    "frontalkrockar": "frontalkrock",
    "frontalkrockarna": "frontalkrock",
    "frontalkrockarnas": "frontalkrock",
    "frontalkrockars": "frontalkrock",
    "frontalkrocken": "frontalkrock",
    "frontalkrockens": "frontalkrock",
    "frontalkrocks": "frontalkrock",
    "frontalloben": "frontallob",
    "frontallobens": "frontallob",
    "frontallober": "frontallob",
    "frontalloberna": "frontallob",
    "frontallobernas": "frontallob",
    "frontallobers": "frontallob",
    "frontallobs": "frontallob",
    "frontallobsstörningar": "frontallobsstörning",
    "frontallobsstörningarna": "frontallobsstörning",
    "frontallobsstörningarnas": "frontallobsstörning",
    "frontallobsstörningars": "frontallobsstörning",
    "frontallobsstörningen": "frontallobsstörning",
    "frontallobsstörningens": "frontallobsstörning",
    "frontallobsstörnings": "frontallobsstörning",
    "frontals": "frontal",
    "frontalt": "frontal",
    "frontalts": "frontal",
    "frontande": "fronta",
    "frontanden": "frontande",
    "frontandena": "frontande",
    "frontandenas": "frontande",
    "frontandens": "frontande",
    "frontandes": "frontande",
    "frontandet": "frontande",
    "frontandets": "frontande",
    "frontar": "fronta",
    "frontas": "fronta",
    "frontat": "fronta",
    "frontats": "fronta",
    "frontavsnitten": "frontavsnitt",
    "frontavsnittens": "frontavsnitt",
    "frontavsnittet": "frontavsnitt",
    "frontavsnittets": "frontavsnitt",
    "frontavsnitts": "frontavsnitt",
    "frontbildningar": "frontbildning",
    "frontbildningarna": "frontbildning",
    "frontbildningarnas": "frontbildning",
    "frontbildningars": "frontbildning",
    "frontbildningen": "frontbildning",
    "frontbildningens": "frontbildning",
    "frontbildnings": "frontbildning",
    "fronten": "front",
    "frontens": "front",
    "fronter": "front",
    "fronterna": "front",
    "fronternas": "front",
    "fronters": "front",
    "frontespisen": "frontespis",
    "frontespisens": "frontespis",
    "frontespiser": "frontespis",
    "frontespiserna": "frontespis",
    "frontespisernas": "frontespis",
    "frontespisers": "frontespis",
    "frontförbindelsen": "frontförbindelse",
    "frontförbindelsens": "frontförbindelse",
    "frontförbindelser": "frontförbindelse",
    "frontförbindelserna": "frontförbindelse",
    "frontförbindelsernas": "frontförbindelse",
    "frontförbindelsers": "frontförbindelse",
    "frontförbindelses": "frontförbindelse",
    "frontlinjen": "frontlinje",
    "frontlinjens": "frontlinje",
    "frontlinjer": "frontlinje",
    "frontlinjerna": "frontlinje",
    "frontlinjernas": "frontlinje",
    "frontlinjers": "frontlinje",
    "frontlinjes": "frontlinje",
    "frontmatade": "frontmatad",
    "frontmatades": "frontmatad",
    "frontmatads": "frontmatad",
    "frontmatat": "frontmatad",
    "frontmatats": "frontmatad",
    "frontnederbörden": "frontnederbörd",
    "frontnederbördens": "frontnederbörd",
    "frontnederbörds": "frontnederbörd",
    "frontonen": "fronton",
    "frontonens": "fronton",
    "frontoner": "fronton",
    "frontonerna": "fronton",
    "frontonernas": "fronton",
    "frontoners": "fronton",
    "frontongen": "frontong",
    "frontongens": "frontong",
    "frontonger": "frontong",
    "frontongerna": "frontong",
    "frontongernas": "frontong",
    "frontongers": "frontong",
    "frontongs": "frontong",
    "frontons": "fronton",
    "fronts": "front",
    "frontsoldaten": "frontsoldat",
    "frontsoldatens": "frontsoldat",
    "frontsoldater": "frontsoldat",
    "frontsoldaterna": "frontsoldat",
    "frontsoldaternas": "frontsoldat",
    "frontsoldaters": "frontsoldat",
    "frontsoldats": "frontsoldat",
    "fronttjänstgöringar": "fronttjänstgöring",
    "fronttjänstgöringarna": "fronttjänstgöring",
    "fronttjänstgöringarnas": "fronttjänstgöring",
    "fronttjänstgöringars": "fronttjänstgöring",
    "fronttjänstgöringen": "fronttjänstgöring",
    "fronttjänstgöringens": "fronttjänstgöring",
    "fronttjänstgörings": "fronttjänstgöring",
    "frontzonen": "frontzon",
    "frontzonens": "frontzon",
    "frontzoner": "frontzon",
    "frontzonerna": "frontzon",
    "frontzonernas": "frontzon",
    "frontzoners": "frontzon",
    "frontzons": "frontzon",
    "froschen": "frosch",
    "froschens": "frosch",
    "froscher": "frosch",
    "froscherna": "frosch",
    "froschernas": "frosch",
    "froschers": "frosch",
    "froschs": "frosch",
    "fross": "frossa",
    "frossade": "frossa",
    "frossades": "frossa",
    "frossan": "frossa",
    "frossande": "frossa",
    "frossanden": "frossande",
    "frossandena": "frossande",
    "frossandenas": "frossande",
    "frossandens": "frossande",
    "frossandes": "frossande",
    "frossandet": "frossande",
    "frossandets": "frossande",
    "frossans": "frossa",
    "frossar": "frossare",
    "frossaren": "frossare",
    "frossarens": "frossare",
    "frossares": "frossare",
    "frossarna": "frossare",
    "frossarnas": "frossare",
    "frossas": "frossa",
    "frossat": "frossa",
    "frossats": "frossa",
    "frossbrytningar": "frossbrytning",
    "frossbrytningarna": "frossbrytning",
    "frossbrytningarnas": "frossbrytning",
    "frossbrytningars": "frossbrytning",
    "frossbrytningen": "frossbrytning",
    "frossbrytningens": "frossbrytning",
    "frossbrytnings": "frossbrytning",
    "frosse": "frossa",
    "frosseriet": "frosseri",
    "frosseriets": "frosseri",
    "frosseris": "frosseri",
    "frosserit": "frosseri",
    "frosserits": "frosseri",
    "frossor": "frossa",
    "frossorna": "frossa",
    "frossornas": "frossa",
    "frossors": "frossa",
    "frostbitens": "frostbiten",
    "frostbitet": "frostbiten",
    "frostbitets": "frostbiten",
    "frostbitna": "frostbiten",
    "frostbitnare": "frostbiten",
    "frostbitnares": "frostbiten",
    "frostbitnas": "frostbiten",
    "frostbitnast": "frostbiten",
    "frostbitnaste": "frostbiten",
    "frostbitnastes": "frostbiten",
    "frostbitnasts": "frostbiten",
    "frostbitne": "frostbiten",
    "frostbitnes": "frostbiten",
    "frostdim": "frostdimma",
    "frostdimman": "frostdimma",
    "frostdimmans": "frostdimma",
    "frostdimmas": "frostdimma",
    "frostdimme": "frostdimma",
    "frostdimmor": "frostdimma",
    "frostdimmorna": "frostdimma",
    "frostdimmornas": "frostdimma",
    "frostdimmors": "frostdimma",
    "frostdims": "frostdimma",
    "frosten": "frost",
    "frostens": "frost",
    "frostfjärilar": "frostfjäril",
    "frostfjärilarna": "frostfjäril",
    "frostfjärilarnas": "frostfjäril",
    "frostfjärilars": "frostfjäril",
    "frostfjärilen": "frostfjäril",
    "frostfjärilens": "frostfjäril",
    "frostfjäriln": "frostfjäril",
    "frostfjärilns": "frostfjäril",
    "frostfjärils": "frostfjäril",
    "frostfria": "frostfri",
    "frostfriare": "frostfri",
    "frostfriares": "frostfri",
    "frostfrias": "frostfri",
    "frostfriast": "frostfri",
    "frostfriaste": "frostfri",
    "frostfriastes": "frostfri",
    "frostfriasts": "frostfri",
    "frostfrie": "frostfri",
    "frostfries": "frostfri",
    "frostfris": "frostfri",
    "frostfritt": "frostfri",
    "frostfritts": "frostfri",
    "frosthärdiga": "frosthärdig",
    "frosthärdigare": "frosthärdig",
    "frosthärdigares": "frosthärdig",
    "frosthärdigas": "frosthärdig",
    "frosthärdigast": "frosthärdig",
    "frosthärdigaste": "frosthärdig",
    "frosthärdigastes": "frosthärdig",
    "frosthärdigasts": "frosthärdig",
    "frosthärdige": "frosthärdig",
    "frosthärdiges": "frosthärdig",
    "frosthärdigheten": "frosthärdighet",
    "frosthärdighetens": "frosthärdighet",
    "frosthärdigheter": "frosthärdighet",
    "frosthärdigheterna": "frosthärdighet",
    "frosthärdigheternas": "frosthärdighet",
    "frosthärdigheters": "frosthärdighet",
    "frosthärdighets": "frosthärdighet",
    "frosthärdigs": "frosthärdig",
    "frosthärdigt": "frosthärdig",
    "frosthärdigts": "frosthärdig",
    "frostiga": "frostig",
    "frostigare": "frostig",
    "frostigares": "frostig",
    "frostigas": "frostig",
    "frostigast": "frostig",
    "frostigaste": "frostig",
    "frostigastes": "frostig",
    "frostigasts": "frostig",
    "frostige": "frostig",
    "frostiges": "frostig",
    "frostigheten": "frostighet",
    "frostighetens": "frostighet",
    "frostighets": "frostighet",
    "frostigs": "frostig",
    "frostigt": "frostig",
    "frostigts": "frostig",
    "frostkänsliga": "frostkänslig",
    "frostkänsligare": "frostkänslig",
    "frostkänsligares": "frostkänslig",
    "frostkänsligas": "frostkänslig",
    "frostkänsligast": "frostkänslig",
    "frostkänsligaste": "frostkänslig",
    "frostkänsligastes": "frostkänslig",
    "frostkänsligasts": "frostkänslig",
    "frostkänslige": "frostkänslig",
    "frostkänsliges": "frostkänslig",
    "frostkänsligheten": "frostkänslighet",
    "frostkänslighetens": "frostkänslighet",
    "frostkänsligheter": "frostkänslighet",
    "frostkänsligheterna": "frostkänslighet",
    "frostkänsligheternas": "frostkänslighet",
    "frostkänsligheters": "frostkänslighet",
    "frostkänslighets": "frostkänslighet",
    "frostkänsligs": "frostkänslig",
    "frostkänsligt": "frostkänslig",
    "frostkänsligts": "frostkänslig",
    "frostnatn": "frostnatt",
    "frostnatns": "frostnatt",
    "frostnatten": "frostnatt",
    "frostnattens": "frostnatt",
    "frostnatts": "frostnatt",
    "frostnätter": "frostnatt",
    "frostnätterna": "frostnatt",
    "frostnätternas": "frostnatt",
    "frostnätters": "frostnatt",
    "frosts": "frost",
    "frostskadan": "frostskada",
    "frostskadans": "frostskada",
    "frostskadas": "frostskada",
    "frostskade": "frostskada",
    "frostskador": "frostskada",
    "frostskadorna": "frostskada",
    "frostskadornas": "frostskada",
    "frostskadors": "frostskada",
    "frostskyddsvätskan": "frostskyddsvätska",
    "frostskyddsvätskans": "frostskyddsvätska",
    "frostskyddsvätskas": "frostskyddsvätska",
    "frostskyddsvätske": "frostskyddsvätska",
    "frostskyddsvätskor": "frostskyddsvätska",
    "frostskyddsvätskorna": "frostskyddsvätska",
    "frostskyddsvätskornas": "frostskyddsvätska",
    "frostskyddsvätskors": "frostskyddsvätska",
    "frostsprängningar": "frostsprängning",
    "frostsprängningarna": "frostsprängning",
    "frostsprängningarnas": "frostsprängning",
    "frostsprängningars": "frostsprängning",
    "frostsprängningen": "frostsprängning",
    "frostsprängningens": "frostsprängning",
    "frostsprängnings": "frostsprängning",
    "frosttåliga": "frosttålig",
    "frosttåligare": "frosttålig",
    "frosttåligares": "frosttålig",
    "frosttåligas": "frosttålig",
    "frosttåligast": "frosttålig",
    "frosttåligaste": "frosttålig",
    "frosttåligastes": "frosttålig",
    "frosttåligasts": "frosttålig",
    "frosttålige": "frosttålig",
    "frosttåliges": "frosttålig",
    "frosttåligheten": "frosttålighet",
    "frosttålighetens": "frosttålighet",
    "frosttålighets": "frosttålighet",
    "frosttåligs": "frosttålig",
    "frosttåligt": "frosttålig",
    "frosttåligts": "frosttålig",
    "frostverkans": "frostverkan",
    "frotterad": "frottera",
    "frotterade": "frottera",
    "frotterades": "frottera",
    "frotterads": "frottera",
    "frotterande": "frottera",
    "frotteranden": "frotterande",
    "frotterandena": "frotterande",
    "frotterandenas": "frotterande",
    "frotterandens": "frotterande",
    "frotterandes": "frotterande",
    "frotterandet": "frotterande",
    "frotterandets": "frotterande",
    "frotterar": "frottera",
    "frotteras": "frottera",
    "frotterat": "frottera",
    "frotterats": "frottera",
    "frotterbara": "frotterbar",
    "frotterbarare": "frotterbar",
    "frotterbarares": "frotterbar",
    "frotterbaras": "frotterbar",
    "frotterbarast": "frotterbar",
    "frotterbaraste": "frotterbar",
    "frotterbarastes": "frotterbar",
    "frotterbarasts": "frotterbar",
    "frotterbare": "frotterbar",
    "frotterbares": "frotterbar",
    "frotterbarheten": "frotterbarhet",
    "frotterbarhetens": "frotterbarhet",
    "frotterbarhets": "frotterbarhet",
    "frotterbars": "frotterbar",
    "frotterbart": "frotterbar",
    "frotterbarts": "frotterbar",
    "frotteringar": "frottering",
    "frotteringarna": "frottering",
    "frotteringarnas": "frottering",
    "frotteringars": "frottering",
    "frotteringen": "frottering",
    "frotteringens": "frottering",
    "frotterings": "frottering",
    "frottéer": "frotté",
    "frottéerna": "frotté",
    "frottéernas": "frotté",
    "frottéers": "frotté",
    "frottéhanddukar": "frottéhandduk",
    "frottéhanddukarna": "frottéhandduk",
    "frottéhanddukarnas": "frottéhandduk",
    "frottéhanddukars": "frottéhandduk",
    "frottéhandduken": "frottéhandduk",
    "frottéhanddukens": "frottéhandduk",
    "frottéhandduks": "frottéhandduk",
    "frottén": "frotté",
    "frotténs": "frotté",
    "frottés": "frotté",
    "fruar": "fru",
    "fruarna": "fru",
    "fruarnas": "fru",
    "fruars": "fru",
    "frug": "fruga",
    "frugala": "frugal",
    "frugalare": "frugal",
    "frugalares": "frugal",
    "frugalas": "frugal",
    "frugalast": "frugal",
    "frugalaste": "frugal",
    "frugalastes": "frugal",
    "frugalasts": "frugal",
    "frugale": "frugal",
    "frugales": "frugal",
    "frugals": "frugal",
    "frugalt": "frugal",
    "frugalts": "frugal",
    "frugan": "fruga",
    "frugans": "fruga",
    "frugas": "fruga",
    "fruge": "fruga",
    "frugor": "fruga",
    "frugorna": "fruga",
    "frugornas": "fruga",
    "frugors": "fruga",
    "frugs": "fruga",
    "frukostar": "frukost",
    "frukostarna": "frukost",
    "frukostarnas": "frukost",
    "frukostars": "frukost",
    "frukostborden": "frukostbord",
    "frukostbordens": "frukostbord",
    "frukostbordet": "frukostbord",
    "frukostbordets": "frukostbord",
    "frukostbords": "frukostbord",
    "frukostbrick": "frukostbricka",
    "frukostbrickan": "frukostbricka",
    "frukostbrickans": "frukostbricka",
    "frukostbrickas": "frukostbricka",
    "frukostbricke": "frukostbricka",
    "frukostbrickor": "frukostbricka",
    "frukostbrickorna": "frukostbricka",
    "frukostbrickornas": "frukostbricka",
    "frukostbrickors": "frukostbricka",
    "frukostbricks": "frukostbricka",
    "frukosten": "frukost",
    "frukostens": "frukost",
    "frukosterade": "frukostera",
    "frukosterades": "frukostera",
    "frukosterande": "frukostera",
    "frukosteranden": "frukosterande",
    "frukosterandena": "frukosterande",
    "frukosterandenas": "frukosterande",
    "frukosterandens": "frukosterande",
    "frukosterandes": "frukosterande",
    "frukosterandet": "frukosterande",
    "frukosterandets": "frukosterande",
    "frukosterar": "frukostera",
    "frukosteras": "frukostera",
    "frukosterat": "frukostera",
    "frukosterats": "frukostera",
    "frukosteringar": "frukostering",
    "frukosteringarna": "frukostering",
    "frukosteringarnas": "frukostering",
    "frukosteringars": "frukostering",
    "frukosteringen": "frukostering",
    "frukosteringens": "frukostering",
    "frukosterings": "frukostering",
    "frukostmiddagar": "frukostmiddag",
    "frukostmiddagarna": "frukostmiddag",
    "frukostmiddagarnas": "frukostmiddag",
    "frukostmiddagars": "frukostmiddag",
    "frukostmiddagen": "frukostmiddag",
    "frukostmiddagens": "frukostmiddag",
    "frukostmiddags": "frukostmiddag",
    "frukostrasten": "frukostrast",
    "frukostrastens": "frukostrast",
    "frukostraster": "frukostrast",
    "frukostrasterna": "frukostrast",
    "frukostrasternas": "frukostrast",
    "frukostrasters": "frukostrast",
    "frukostrasts": "frukostrast",
    "frukosts": "frukost",
    "frukostäggen": "frukostägg",
    "frukostäggens": "frukostägg",
    "frukostägget": "frukostägg",
    "frukostäggets": "frukostägg",
    "frukostäggs": "frukostägg",
    "frukt": "frukta",
    "fruktad": "frukta",
    "fruktade": "frukta",
    "fruktades": "frukta",
    "fruktads": "frukta",
    "fruktaffären": "fruktaffär",
    "fruktaffärens": "fruktaffär",
    "fruktaffärer": "fruktaffär",
    "fruktaffärerna": "fruktaffär",
    "fruktaffärernas": "fruktaffär",
    "fruktaffärers": "fruktaffär",
    "fruktaffärs": "fruktaffär",
    "fruktande": "frukta",
    "fruktanden": "fruktande",
    "fruktandena": "fruktande",
    "fruktandenas": "fruktande",
    "fruktandens": "fruktande",
    "fruktandes": "fruktande",
    "fruktandet": "fruktande",
    "fruktandets": "fruktande",
    "fruktans": "fruktan",
    "fruktansvärda": "fruktansvärd",
    "fruktansvärdare": "fruktansvärd",
    "fruktansvärdares": "fruktansvärd",
    "fruktansvärdas": "fruktansvärd",
    "fruktansvärdast": "fruktansvärd",
    "fruktansvärdaste": "fruktansvärd",
    "fruktansvärdastes": "fruktansvärd",
    "fruktansvärdasts": "fruktansvärd",
    "fruktansvärde": "fruktansvärd",
    "fruktansvärdes": "fruktansvärd",
    "fruktansvärdheten": "fruktansvärdhet",
    "fruktansvärdhetens": "fruktansvärdhet",
    "fruktansvärdhets": "fruktansvärdhet",
    "fruktansvärds": "fruktansvärd",
    "fruktansvärt": "fruktansvärd",
    "fruktansvärts": "fruktansvärd",
    "fruktar": "frukta",
    "fruktas": "frukta",
    "fruktat": "frukta",
    "fruktats": "frukta",
    "fruktbara": "fruktbar",
    "fruktbarare": "fruktbar",
    "fruktbarares": "fruktbar",
    "fruktbaras": "fruktbar",
    "fruktbarast": "fruktbar",
    "fruktbaraste": "fruktbar",
    "fruktbarastes": "fruktbar",
    "fruktbarasts": "fruktbar",
    "fruktbare": "fruktbar",
    "fruktbares": "fruktbar",
    "fruktbarheten": "fruktbarhet",
    "fruktbarhetens": "fruktbarhet",
    "fruktbarheter": "fruktbarhet",
    "fruktbarheterna": "fruktbarhet",
    "fruktbarheternas": "fruktbarhet",
    "fruktbarheters": "fruktbarhet",
    "fruktbarhets": "fruktbarhet",
    "fruktbarhetsgudar": "fruktbarhetsgud",
    "fruktbarhetsgudarna": "fruktbarhetsgud",
    "fruktbarhetsgudarnas": "fruktbarhetsgud",
    "fruktbarhetsgudars": "fruktbarhetsgud",
    "fruktbarhetsguden": "fruktbarhetsgud",
    "fruktbarhetsgudens": "fruktbarhetsgud",
    "fruktbarhetsguds": "fruktbarhetsgud",
    "fruktbars": "fruktbar",
    "fruktbart": "fruktbar",
    "fruktbarts": "fruktbar",
    "frukten": "frukt",
    "fruktens": "frukt",
    "frukter": "frukt",
    "frukterna": "frukt",
    "frukternas": "frukt",
    "frukters": "frukt",
    "fruktiga": "fruktig",
    "fruktigare": "fruktig",
    "fruktigares": "fruktig",
    "fruktigas": "fruktig",
    "fruktigast": "fruktig",
    "fruktigaste": "fruktig",
    "fruktigastes": "fruktig",
    "fruktigasts": "fruktig",
    "fruktige": "fruktig",
    "fruktiges": "fruktig",
    "fruktigheten": "fruktighet",
    "fruktighetens": "fruktighet",
    "fruktighets": "fruktighet",
    "fruktigs": "fruktig",
    "fruktigt": "fruktig",
    "fruktigts": "fruktig",
    "fruktknivar": "fruktkniv",
    "fruktknivarna": "fruktkniv",
    "fruktknivarnas": "fruktkniv",
    "fruktknivars": "fruktkniv",
    "fruktkniven": "fruktkniv",
    "fruktknivens": "fruktkniv",
    "fruktknivs": "fruktkniv",
    "fruktkompotten": "fruktkompott",
    "fruktkompottens": "fruktkompott",
    "fruktkompotter": "fruktkompott",
    "fruktkompotterna": "fruktkompott",
    "fruktkompotternas": "fruktkompott",
    "fruktkompotters": "fruktkompott",
    "fruktkompotts": "fruktkompott",
    "fruktkorgar": "fruktkorg",
    "fruktkorgarna": "fruktkorg",
    "fruktkorgarnas": "fruktkorg",
    "fruktkorgars": "fruktkorg",
    "fruktkorgen": "fruktkorg",
    "fruktkorgens": "fruktkorg",
    "fruktkorgs": "fruktkorg",
    "fruktkärn": "fruktkärna",
    "fruktkärnan": "fruktkärna",
    "fruktkärnans": "fruktkärna",
    "fruktkärnas": "fruktkärna",
    "fruktkärne": "fruktkärna",
    "fruktkärnor": "fruktkärna",
    "fruktkärnorna": "fruktkärna",
    "fruktkärnornas": "fruktkärna",
    "fruktkärnors": "fruktkärna",
    "fruktkärns": "fruktkärna",
    "fruktköttet": "fruktkött",
    "fruktköttets": "fruktkött",
    "fruktkötts": "fruktkött",
    "fruktlösa": "fruktlös",
    "fruktlösare": "fruktlös",
    "fruktlösares": "fruktlös",
    "fruktlösas": "fruktlös",
    "fruktlösast": "fruktlös",
    "fruktlösaste": "fruktlös",
    "fruktlösastes": "fruktlös",
    "fruktlösasts": "fruktlös",
    "fruktlöse": "fruktlös",
    "fruktlöses": "fruktlös",
    "fruktlösheten": "fruktlöshet",
    "fruktlöshetens": "fruktlöshet",
    "fruktlöshets": "fruktlöshet",
    "fruktlöst": "fruktlös",
    "fruktlösts": "fruktlös",
    "fruktodlar": "fruktodlare",
    "fruktodlaren": "fruktodlare",
    "fruktodlarens": "fruktodlare",
    "fruktodlares": "fruktodlare",
    "fruktodlarna": "fruktodlare",
    "fruktodlarnas": "fruktodlare",
    "fruktodlingar": "fruktodling",
    "fruktodlingarna": "fruktodling",
    "fruktodlingarnas": "fruktodling",
    "fruktodlingars": "fruktodling",
    "fruktodlingen": "fruktodling",
    "fruktodlingens": "fruktodling",
    "fruktodlings": "fruktodling",
    "fruktosen": "fruktos",
    "fruktosens": "fruktos",
    "fruktplockar": "fruktplockare",
    "fruktplockaren": "fruktplockare",
    "fruktplockarens": "fruktplockare",
    "fruktplockares": "fruktplockare",
    "fruktplockarna": "fruktplockare",
    "fruktplockarnas": "fruktplockare",
    "fruktpås": "fruktpåse",
    "fruktpåsar": "fruktpåse",
    "fruktpåsarna": "fruktpåse",
    "fruktpåsarnas": "fruktpåse",
    "fruktpåsars": "fruktpåse",
    "fruktpåsen": "fruktpåse",
    "fruktpåsens": "fruktpåse",
    "fruktpåses": "fruktpåse",
    "frukts": "frukt",
    "fruktsalladen": "fruktsallad",
    "fruktsalladens": "fruktsallad",
    "fruktsallader": "fruktsallad",
    "fruktsalladerna": "fruktsallad",
    "fruktsalladernas": "fruktsallad",
    "fruktsalladers": "fruktsallad",
    "fruktsallads": "fruktsallad",
    "fruktsaltet": "fruktsalt",
    "fruktsaltets": "fruktsalt",
    "fruktsalts": "fruktsalt",
    "fruktsamheten": "fruktsamhet",
    "fruktsamhetens": "fruktsamhet",
    "fruktsamhets": "fruktsamhet",
    "fruktsamma": "fruktsam",
    "fruktsammare": "fruktsam",
    "fruktsammares": "fruktsam",
    "fruktsammas": "fruktsam",
    "fruktsammast": "fruktsam",
    "fruktsammaste": "fruktsam",
    "fruktsammastes": "fruktsam",
    "fruktsammasts": "fruktsam",
    "fruktsamme": "fruktsam",
    "fruktsammes": "fruktsam",
    "fruktsams": "fruktsam",
    "fruktsamt": "fruktsam",
    "fruktsamts": "fruktsam",
    "fruktskorven": "fruktskorv",
    "fruktskorvens": "fruktskorv",
    "fruktskorvs": "fruktskorv",
    "fruktsockers": "fruktsocker",
    "fruktsockret": "fruktsocker",
    "fruktsockrets": "fruktsocker",
    "fruktsporr": "fruktsporre",
    "fruktsporrar": "fruktsporre",
    "fruktsporrarna": "fruktsporre",
    "fruktsporrarnas": "fruktsporre",
    "fruktsporrars": "fruktsporre",
    "fruktsporren": "fruktsporre",
    "fruktsporrens": "fruktsporre",
    "fruktsporres": "fruktsporre",
    "fruktsporrs": "fruktsporre",
    "fruktträden": "fruktträd",
    "fruktträdens": "fruktträd",
    "fruktträdet": "fruktträd",
    "fruktträdets": "fruktträd",
    "fruktträdgårdar": "fruktträdgård",
    "fruktträdgårdarna": "fruktträdgård",
    "fruktträdgårdarnas": "fruktträdgård",
    "fruktträdgårdars": "fruktträdgård",
    "fruktträdgården": "fruktträdgård",
    "fruktträdgårdens": "fruktträdgård",
    "fruktträdgårds": "fruktträdgård",
    "fruktträds": "fruktträd",
    "fruktträn": "fruktträd",
    "fruktträna": "fruktträd",
    "frukttränas": "fruktträd",
    "fruktträns": "fruktträd",
    "fruktveden": "fruktved",
    "fruktvedens": "fruktved",
    "fruktveds": "fruktved",
    "fruktväggar": "fruktvägg",
    "fruktväggarna": "fruktvägg",
    "fruktväggarnas": "fruktvägg",
    "fruktväggars": "fruktvägg",
    "fruktväggen": "fruktvägg",
    "fruktväggens": "fruktvägg",
    "fruktväggs": "fruktvägg",
    "fruktämnen": "fruktämne",
    "fruktämnena": "fruktämne",
    "fruktämnenas": "fruktämne",
    "fruktämnens": "fruktämne",
    "fruktämnes": "fruktämne",
    "fruktämnet": "fruktämne",
    "fruktämnets": "fruktämne",
    "frun": "fru",
    "fruns": "fru",
    "fruntimmerna": "fruntimmer",
    "fruntimmernas": "fruntimmer",
    "fruntimmers": "fruntimmer",
    "fruntimmerskarlar": "fruntimmerskarl",
    "fruntimmerskarlarna": "fruntimmerskarl",
    "fruntimmerskarlarnas": "fruntimmerskarl",
    "fruntimmerskarlars": "fruntimmerskarl",
    "fruntimmerskarlen": "fruntimmerskarl",
    "fruntimmerskarlens": "fruntimmerskarl",
    "fruntimmerskarls": "fruntimmerskarl",
    "fruntimmersveckan": "fruntimmersvecka",
    "fruntimmersveckans": "fruntimmersvecka",
    "fruntimmersveckas": "fruntimmersvecka",
    "fruntimren": "fruntimmer",
    "fruntimrens": "fruntimmer",
    "fruntimret": "fruntimmer",
    "fruntimrets": "fruntimmer",
    "frus": "frusa",
    "frusade": "frusa",
    "frusades": "frusa",
    "frusande": "frusa",
    "frusanden": "frusande",
    "frusandena": "frusande",
    "frusandenas": "frusande",
    "frusandens": "frusande",
    "frusandes": "frusande",
    "frusandet": "frusande",
    "frusandets": "frusande",
    "frusar": "frusa",
    "frusas": "frusa",
    "frusat": "frusa",
    "frusats": "frusa",
    "fruse": "frysa",
    "frusen": "frysa",
    "frusenheten": "frusenhet",
    "frusenhetens": "frusenhet",
    "frusenhets": "frusenhet",
    "frusens": "frysa",
    "fruses": "frysa",
    "fruset": "frysa",
    "frusets": "frysa",
    "frusit": "frysa",
    "frusits": "frysa",
    "frusna": "frysa",
    "frusnare": "frusen",
    "frusnares": "frusen",
    "frusnas": "frysa",
    "frusnast": "frusen",
    "frusnaste": "frusen",
    "frusnastes": "frusen",
    "frusnasts": "frusen",
    "frusne": "frysa",
    "frusnes": "frysa",
    "frust": "frusta",
    "frustade": "frusta",
    "frustades": "frusta",
    "frustande": "frusta",
    "frustanden": "frustande",
    "frustandena": "frustande",
    "frustandenas": "frustande",
    "frustandens": "frustande",
    "frustandes": "frustande",
    "frustandet": "frustande",
    "frustandets": "frustande",
    "frustar": "frusta",
    "frustas": "frusta",
    "frustat": "frusta",
    "frustats": "frusta",
    "frustrationen": "frustration",
    "frustrationens": "frustration",
    "frustrationer": "frustration",
    "frustrationerna": "frustration",
    "frustrationernas": "frustration",
    "frustrationers": "frustration",
    "frustrations": "frustration",
    "frustrerad": "frustrera",
    "frustrerade": "frustrerad",
    "frustrerades": "frustrerad",
    "frustrerads": "frustrerad",
    "frustrerande": "frustrera",
    "frustreranden": "frustrerande",
    "frustrerandena": "frustrerande",
    "frustrerandenas": "frustrerande",
    "frustrerandens": "frustrerande",
    "frustrerandes": "frustrerande",
    "frustrerandet": "frustrerande",
    "frustrerandets": "frustrerande",
    "frustrerar": "frustrera",
    "frustreras": "frustrera",
    "frustrerat": "frustrerad",
    "frustrerats": "frustrerad",
    "frustrerbara": "frustrerbar",
    "frustrerbarare": "frustrerbar",
    "frustrerbarares": "frustrerbar",
    "frustrerbaras": "frustrerbar",
    "frustrerbarast": "frustrerbar",
    "frustrerbaraste": "frustrerbar",
    "frustrerbarastes": "frustrerbar",
    "frustrerbarasts": "frustrerbar",
    "frustrerbare": "frustrerbar",
    "frustrerbares": "frustrerbar",
    "frustrerbarheten": "frustrerbarhet",
    "frustrerbarhetens": "frustrerbarhet",
    "frustrerbarhets": "frustrerbarhet",
    "frustrerbars": "frustrerbar",
    "frustrerbart": "frustrerbar",
    "frustrerbarts": "frustrerbar",
    "frustreringar": "frustrering",
    "frustreringarna": "frustrering",
    "frustreringarnas": "frustrering",
    "frustreringars": "frustrering",
    "frustreringen": "frustrering",
    "frustreringens": "frustrering",
    "frustrerings": "frustrering",
    "fryn": "fryna",
    "frynande": "fryna",
    "frynanden": "frynande",
    "frynandena": "frynande",
    "frynandenas": "frynande",
    "frynandens": "frynande",
    "frynandes": "frynande",
    "frynandet": "frynande",
    "frynandets": "frynande",
    "frynas": "fryna",
    "fryner": "fryna",
    "frynes": "fryna",
    "fryns": "fryna",
    "frynt": "fryna",
    "frynte": "fryna",
    "fryntes": "fryna",
    "fryntliga": "fryntlig",
    "fryntligare": "fryntlig",
    "fryntligares": "fryntlig",
    "fryntligas": "fryntlig",
    "fryntligast": "fryntlig",
    "fryntligaste": "fryntlig",
    "fryntligastes": "fryntlig",
    "fryntligasts": "fryntlig",
    "fryntlige": "fryntlig",
    "fryntliges": "fryntlig",
    "fryntligheten": "fryntlighet",
    "fryntlighetens": "fryntlighet",
    "fryntligheter": "fryntlighet",
    "fryntligheterna": "fryntlighet",
    "fryntligheternas": "fryntlighet",
    "fryntligheters": "fryntlighet",
    "fryntlighets": "fryntlighet",
    "fryntligs": "fryntlig",
    "fryntligt": "fryntlig",
    "fryntligts": "fryntlig",
    "frynts": "fryna",
    "frys": "frysa",
    "frysande": "frysa",
    "frysanden": "frysande",
    "frysandena": "frysande",
    "frysandenas": "frysande",
    "frysandens": "frysande",
    "frysandes": "frysande",
    "frysandet": "frysande",
    "frysandets": "frysande",
    "frysar": "frys",
    "frysarna": "frys",
    "frysarnas": "frys",
    "frysars": "frys",
    "frysas": "frysa",
    "frysboxar": "frysbox",
    "frysboxarna": "frysbox",
    "frysboxarnas": "frysbox",
    "frysboxars": "frysbox",
    "frysboxen": "frysbox",
    "frysboxens": "frysbox",
    "frysdiskar": "frysdisk",
    "frysdiskarna": "frysdisk",
    "frysdiskarnas": "frysdisk",
    "frysdiskars": "frysdisk",
    "frysdisken": "frysdisk",
    "frysdiskens": "frysdisk",
    "frysdisks": "frysdisk",
    "fryse": "frysa",
    "frysen": "frys",
    "frysens": "frys",
    "fryser": "frysa",
    "fryserier": "fryseri",
    "fryserierna": "fryseri",
    "fryseriernas": "fryseri",
    "fryseriers": "fryseri",
    "fryseriet": "fryseri",
    "fryseriets": "fryseri",
    "fryseris": "fryseri",
    "fryserit": "fryseri",
    "fryserits": "fryseri",
    "fryses": "frysa",
    "frysfacken": "frysfack",
    "frysfackens": "frysfack",
    "frysfacket": "frysfack",
    "frysfackets": "frysfack",
    "frysfacks": "frysfack",
    "frysförpackningar": "frysförpackning",
    "frysförpackningarna": "frysförpackning",
    "frysförpackningarnas": "frysförpackning",
    "frysförpackningars": "frysförpackning",
    "frysförpackningen": "frysförpackning",
    "frysförpackningens": "frysförpackning",
    "frysförpacknings": "frysförpackning",
    "frysförsöken": "frysförsök",
    "frysförsökens": "frysförsök",
    "frysförsöket": "frysförsök",
    "frysförsökets": "frysförsök",
    "frysförsöks": "frysförsök",
    "fryspunkten": "fryspunkt",
    "fryspunktens": "fryspunkt",
    "fryspunkter": "fryspunkt",
    "fryspunkterna": "fryspunkt",
    "fryspunkternas": "fryspunkt",
    "fryspunkters": "fryspunkt",
    "fryspunkts": "fryspunkt",
    "fryst": "frysa",
    "frysta": "fryst",
    "frystare": "fryst",
    "frystares": "fryst",
    "frystas": "fryst",
    "frystast": "fryst",
    "frystaste": "fryst",
    "frystastes": "fryst",
    "frystasts": "fryst",
    "fryste": "fryst",
    "frystejpen": "frystejp",
    "frystejpens": "frystejp",
    "frystejps": "frystejp",
    "frystes": "fryst",
    "frystest": "frystesta",
    "frystestad": "frystesta",
    "frystestade": "frystesta",
    "frystestades": "frystesta",
    "frystestads": "frystesta",
    "frystestande": "frystesta",
    "frystestanden": "frystestande",
    "frystestandena": "frystestande",
    "frystestandenas": "frystestande",
    "frystestandens": "frystestande",
    "frystestandes": "frystestande",
    "frystestandet": "frystestande",
    "frystestandets": "frystestande",
    "frystestar": "frystesta",
    "frystestas": "frystesta",
    "frystestat": "frystesta",
    "frystestats": "frystesta",
    "frystesten": "frystest",
    "frystestens": "frystest",
    "frystester": "frystest",
    "frystesterna": "frystest",
    "frystesternas": "frystest",
    "frystesters": "frystest",
    "frystestet": "frystest",
    "frystestets": "frystest",
    "frystests": "frystest",
    "frystork": "frystorka",
    "frystorkad": "frystorka",
    "frystorkade": "frystorka",
    "frystorkades": "frystorka",
    "frystorkads": "frystorka",
    "frystorkande": "frystorka",
    "frystorkanden": "frystorkande",
    "frystorkandena": "frystorkande",
    "frystorkandenas": "frystorkande",
    "frystorkandens": "frystorkande",
    "frystorkandes": "frystorkande",
    "frystorkandet": "frystorkande",
    "frystorkandets": "frystorkande",
    "frystorkar": "frystorka",
    "frystorkas": "frystorka",
    "frystorkat": "frystorka",
    "frystorkats": "frystorka",
    "frysts": "fryst",
    "fryståliga": "frystålig",
    "fryståligare": "frystålig",
    "fryståligares": "frystålig",
    "fryståligas": "frystålig",
    "fryståligast": "frystålig",
    "fryståligaste": "frystålig",
    "fryståligastes": "frystålig",
    "fryståligasts": "frystålig",
    "frystålige": "frystålig",
    "fryståliges": "frystålig",
    "fryståligheten": "frystålighet",
    "frystålighetens": "frystålighet",
    "frystålighets": "frystålighet",
    "fryståligs": "frystålig",
    "fryståligt": "frystålig",
    "fryståligts": "frystålig",
    "fräcka": "fräck",
    "fräckare": "fräck",
    "fräckares": "fräck",
    "fräckas": "fräck",
    "fräckast": "fräck",
    "fräckaste": "fräck",
    "fräckastes": "fräck",
    "fräckasts": "fräck",
    "fräcke": "fräck",
    "fräckes": "fräck",
    "fräckheten": "fräckhet",
    "fräckhetens": "fräckhet",
    "fräckheter": "fräckhet",
    "fräckheterna": "fräckhet",
    "fräckheternas": "fräckhet",
    "fräckheters": "fräckhet",
    "fräckhets": "fräckhet",
    "fräckisar": "fräckis",
    "fräckisarna": "fräckis",
    "fräckisarnas": "fräckis",
    "fräckisars": "fräckis",
    "fräckisen": "fräckis",
    "fräckisens": "fräckis",
    "fräcks": "fräck",
    "fräckt": "fräck",
    "fräckts": "fräck",
    "fräkenn": "fräken",
    "fräkenns": "fräken",
    "fräkens": "fräken",
    "fräknar": "fräkne",
    "fräknarna": "fräkne",
    "fräknarnas": "fräkne",
    "fräknars": "fräkne",
    "fräknen": "fräkne",
    "fräknens": "fräkne",
    "fräknes": "fräkne",
    "fräkniga": "fräknig",
    "fräknigare": "fräknig",
    "fräknigares": "fräknig",
    "fräknigas": "fräknig",
    "fräknigast": "fräknig",
    "fräknigaste": "fräknig",
    "fräknigastes": "fräknig",
    "fräknigasts": "fräknig",
    "fräknige": "fräknig",
    "fräkniges": "fräknig",
    "fräknigheten": "fräknighet",
    "fräknighetens": "fräknighet",
    "fräknighets": "fräknighet",
    "fräknigs": "fräknig",
    "fräknigt": "fräknig",
    "fräknigts": "fräknig",
    "fräls": "frälsa",
    "frälsande": "frälsa",
    "frälsanden": "frälsande",
    "frälsandena": "frälsande",
    "frälsandenas": "frälsande",
    "frälsandens": "frälsande",
    "frälsandes": "frälsande",
    "frälsandet": "frälsande",
    "frälsandets": "frälsande",
    "frälsar": "frälsare",
    "frälsaren": "frälsare",
    "frälsarens": "frälsare",
    "frälsares": "frälsare",
    "frälsarkransar": "frälsarkrans",
    "frälsarkransarna": "frälsarkrans",
    "frälsarkransarnas": "frälsarkrans",
    "frälsarkransars": "frälsarkrans",
    "frälsarkransen": "frälsarkrans",
    "frälsarkransens": "frälsarkrans",
    "frälsarna": "frälsare",
    "frälsarnas": "frälsare",
    "frälsas": "frälsa",
    "frälsebond": "frälsebonde",
    "frälsebonden": "frälsebonde",
    "frälsebondens": "frälsebonde",
    "frälsebondes": "frälsebonde",
    "frälsebonds": "frälsebonde",
    "frälsebönder": "frälsebonde",
    "frälsebönderna": "frälsebonde",
    "frälseböndernas": "frälsebonde",
    "frälsebönders": "frälsebonde",
    "frälsejordar": "frälsejord",
    "frälsejordarna": "frälsejord",
    "frälsejordarnas": "frälsejord",
    "frälsejordars": "frälsejord",
    "frälsejorden": "frälsejord",
    "frälsejordens": "frälsejord",
    "frälsejords": "frälsejord",
    "frälser": "frälsa",
    "frälses": "frälse",
    "frälset": "frälse",
    "frälsets": "frälse",
    "frälsningar": "frälsning",
    "frälsningarna": "frälsning",
    "frälsningarnas": "frälsning",
    "frälsningars": "frälsning",
    "frälsningen": "frälsning",
    "frälsningens": "frälsning",
    "frälsnings": "frälsning",
    "frälsningsmöten": "frälsningsmöte",
    "frälsningsmötena": "frälsningsmöte",
    "frälsningsmötenas": "frälsningsmöte",
    "frälsningsmötens": "frälsningsmöte",
    "frälsningsmötes": "frälsningsmöte",
    "frälsningsmötet": "frälsningsmöte",
    "frälsningsmötets": "frälsningsmöte",
    "frälsningssoldaten": "frälsningssoldat",
    "frälsningssoldatens": "frälsningssoldat",
    "frälsningssoldater": "frälsningssoldat",
    "frälsningssoldaterna": "frälsningssoldat",
    "frälsningssoldaternas": "frälsningssoldat",
    "frälsningssoldaters": "frälsningssoldat",
    "frälsningssoldats": "frälsningssoldat",
    "frälst": "frälsa",
    "frälsta": "frälst",
    "frälstare": "frälst",
    "frälstares": "frälst",
    "frälstas": "frälst",
    "frälstast": "frälst",
    "frälstaste": "frälst",
    "frälstastes": "frälst",
    "frälstasts": "frälst",
    "frälste": "frälst",
    "frälstes": "frälst",
    "frälstheten": "frälsthet",
    "frälsthetens": "frälsthet",
    "frälsthets": "frälsthet",
    "frälsts": "frälst",
    "främjad": "främja",
    "främjade": "främja",
    "främjades": "främja",
    "främjads": "främja",
    "främjande": "främja",
    "främjanden": "främjande",
    "främjandena": "främjande",
    "främjandenas": "främjande",
    "främjandens": "främjande",
    "främjandes": "främjande",
    "främjandet": "främjande",
    "främjandets": "främjande",
    "främjar": "främja",
    "främjas": "främja",
    "främjat": "främja",
    "främjats": "främja",
    "främlingar": "främling",
    "främlingarna": "främling",
    "främlingarnas": "främling",
    "främlingars": "främling",
    "främlingen": "främling",
    "främlingens": "främling",
    "främlings": "främling",
    "främlingsfientliga": "främlingsfientlig",
    "främlingsfientligare": "främlingsfientlig",
    "främlingsfientligares": "främlingsfientlig",
    "främlingsfientligas": "främlingsfientlig",
    "främlingsfientligast": "främlingsfientlig",
    "främlingsfientligaste": "främlingsfientlig",
    "främlingsfientligastes": "främlingsfientlig",
    "främlingsfientligasts": "främlingsfientlig",
    "främlingsfientlige": "främlingsfientlig",
    "främlingsfientliges": "främlingsfientlig",
    "främlingsfientligheten": "främlingsfientlighet",
    "främlingsfientlighetens": "främlingsfientlighet",
    "främlingsfientlighets": "främlingsfientlighet",
    "främlingsfientligs": "främlingsfientlig",
    "främlingsfientligt": "främlingsfientlig",
    "främlingsfientligts": "främlingsfientlig",
    "främlingshatet": "främlingshat",
    "främlingshatets": "främlingshat",
    "främlingshats": "främlingshat",
    "främlingskapet": "främlingskap",
    "främlingskapets": "främlingskap",
    "främlingskaps": "främlingskap",
    "främlingslegionen": "främlingslegion",
    "främlingslegionens": "främlingslegion",
    "främlingslegioner": "främlingslegion",
    "främlingslegionerna": "främlingslegion",
    "främlingslegionernas": "främlingslegion",
    "främlingslegioners": "främlingslegion",
    "främlingslegions": "främlingslegion",
    "främlingslegionären": "främlingslegionär",
    "främlingslegionärens": "främlingslegionär",
    "främlingslegionärer": "främlingslegionär",
    "främlingslegionärerna": "främlingslegionär",
    "främlingslegionärernas": "främlingslegionär",
    "främlingslegionärers": "främlingslegionär",
    "främlingslegionärs": "främlingslegionär",
    "främlingspassen": "främlingspass",
    "främlingspassens": "främlingspass",
    "främlingspasset": "främlingspass",
    "främlingspassets": "främlingspass",
    "främmanden": "främmande",
    "främmandena": "främmande",
    "främmandenas": "främmande",
    "främmandens": "främmande",
    "främmandes": "främmande",
    "främmandet": "främmande",
    "främmandets": "främmande",
    "främsta": "främst",
    "främstas": "främst",
    "främste": "främst",
    "främstes": "främst",
    "främsts": "främst",
    "fräna": "frän",
    "fränare": "frän",
    "fränares": "frän",
    "fränas": "frän",
    "fränast": "frän",
    "fränaste": "frän",
    "fränastes": "frän",
    "fränasts": "frän",
    "fränden": "frände",
    "frändens": "frände",
    "fränder": "frände",
    "fränderna": "frände",
    "frändernas": "frände",
    "fränders": "frände",
    "frändes": "frände",
    "frändskapen": "frändskap",
    "frändskapens": "frändskap",
    "frändskaper": "frändskap",
    "frändskaperna": "frändskap",
    "frändskapernas": "frändskap",
    "frändskapers": "frändskap",
    "frändskaps": "frändskap",
    "fräne": "frän",
    "fränes": "frän",
    "fränheten": "fränhet",
    "fränhetens": "fränhet",
    "fränhets": "fränhet",
    "fränk": "fränka",
    "fränkan": "fränka",
    "fränkans": "fränka",
    "fränkas": "fränka",
    "fränke": "fränka",
    "fränkor": "fränka",
    "fränkorna": "fränka",
    "fränkornas": "fränka",
    "fränkors": "fränka",
    "fränks": "fränka",
    "fräns": "frän",
    "fränt": "frän",
    "fränts": "frän",
    "fräs": "fräsa",
    "fräsande": "fräsa",
    "fräsanden": "fräsande",
    "fräsandena": "fräsande",
    "fräsandenas": "fräsande",
    "fräsandens": "fräsande",
    "fräsandes": "fräsande",
    "fräsandet": "fräsande",
    "fräsandets": "fräsande",
    "fräsar": "fräs",
    "fräsarna": "fräs",
    "fräsarnas": "fräs",
    "fräsars": "fräs",
    "fräsas": "fräsa",
    "fräscha": "fräsch",
    "fräschare": "fräsch",
    "fräschares": "fräsch",
    "fräschas": "fräsch",
    "fräschast": "fräsch",
    "fräschaste": "fräsch",
    "fräschastes": "fräsch",
    "fräschasts": "fräsch",
    "fräsche": "fräsch",
    "fräsches": "fräsch",
    "fräschheten": "fräschhet",
    "fräschhetens": "fräschhet",
    "fräschhets": "fräschhet",
    "fräschs": "fräsch",
    "fräscht": "fräsch",
    "fräschts": "fräsch",
    "fräschören": "fräschör",
    "fräschörens": "fräschör",
    "fräschörs": "fräschör",
    "fräsen": "fräs",
    "fräsens": "fräs",
    "fräser": "fräsa",
    "fräses": "fräsa",
    "fräset": "fräs",
    "fräsets": "fräs",
    "fräsiga": "fräsig",
    "fräsigare": "fräsig",
    "fräsigares": "fräsig",
    "fräsigas": "fräsig",
    "fräsigast": "fräsig",
    "fräsigaste": "fräsig",
    "fräsigastes": "fräsig",
    "fräsigasts": "fräsig",
    "fräsige": "fräsig",
    "fräsiges": "fräsig",
    "fräsigs": "fräsig",
    "fräsigt": "fräsig",
    "fräsigts": "fräsig",
    "fräsmaskinen": "fräsmaskin",
    "fräsmaskinens": "fräsmaskin",
    "fräsmaskiner": "fräsmaskin",
    "fräsmaskinerna": "fräsmaskin",
    "fräsmaskinernas": "fräsmaskin",
    "fräsmaskiners": "fräsmaskin",
    "fräsmaskins": "fräsmaskin",
    "frässtålen": "frässtål",
    "frässtålens": "frässtål",
    "frässtålet": "frässtål",
    "frässtålets": "frässtål",
    "fräsståls": "frässtål",
    "fräst": "fräsa",
    "frästa": "fräsa",
    "frästas": "fräsa",
    "fräste": "fräsa",
    "frästes": "fräsa",
    "frästs": "fräsa",
    "frät": "fräta",
    "frätan": "fräta",
    "frätande": "fräta",
    "frätanden": "frätande",
    "frätandena": "frätande",
    "frätandenas": "frätande",
    "frätandens": "frätande",
    "frätandes": "frätande",
    "frätandet": "frätande",
    "frätandets": "frätande",
    "frätans": "fräta",
    "frätas": "fräta",
    "fräte": "fräta",
    "fräter": "fräta",
    "frätes": "fräta",
    "frätor": "fräta",
    "frätorna": "fräta",
    "frätornas": "fräta",
    "frätors": "fräta",
    "fräts": "fräta",
    "frätskadan": "frätskada",
    "frätskadans": "frätskada",
    "frätskadas": "frätskada",
    "frätskade": "frätskada",
    "frätskador": "frätskada",
    "frätskadorna": "frätskada",
    "frätskadornas": "frätskada",
    "frätskadors": "frätskada",
    "frätt": "fräta",
    "frätta": "fräta",
    "frättas": "fräta",
    "frätte": "fräta",
    "frättes": "fräta",
    "frätts": "fräta",
    "frågad": "fråga",
    "frågade": "fråga",
    "frågades": "fråga",
    "frågads": "fråga",
    "frågan": "fråga",
    "frågande": "fråga",
    "fråganden": "frågande",
    "frågandena": "frågande",
    "frågandenas": "frågande",
    "frågandens": "frågande",
    "frågandes": "frågande",
    "frågandet": "frågande",
    "frågandets": "frågande",
    "frågans": "fråga",
    "frågar": "fråga",
    "frågas": "fråga",
    "frågat": "fråga",
    "frågats": "fråga",
    "fråge": "fråga",
    "frågeformen": "frågeform",
    "frågeformens": "frågeform",
    "frågeformer": "frågeform",
    "frågeformerna": "frågeform",
    "frågeformernas": "frågeform",
    "frågeformers": "frågeform",
    "frågeforms": "frågeform",
    "frågeformulären": "frågeformulär",
    "frågeformulärens": "frågeformulär",
    "frågeformuläret": "frågeformulär",
    "frågeformulärets": "frågeformulär",
    "frågeformulärs": "frågeformulär",
    "frågementaliteten": "frågementalitet",
    "frågementalitetens": "frågementalitet",
    "frågementaliteter": "frågementalitet",
    "frågementaliteterna": "frågementalitet",
    "frågementaliteternas": "frågementalitet",
    "frågementaliteters": "frågementalitet",
    "frågementalitets": "frågementalitet",
    "frågeorden": "frågeord",
    "frågeordens": "frågeord",
    "frågeordet": "frågeord",
    "frågeordets": "frågeord",
    "frågeords": "frågeord",
    "frågesatsen": "frågesats",
    "frågesatsens": "frågesats",
    "frågesatser": "frågesats",
    "frågesatserna": "frågesats",
    "frågesatsernas": "frågesats",
    "frågesatsers": "frågesats",
    "frågespalten": "frågespalt",
    "frågespaltens": "frågespalt",
    "frågespalter": "frågespalt",
    "frågespalterna": "frågespalt",
    "frågespalternas": "frågespalt",
    "frågespalters": "frågespalt",
    "frågespalts": "frågespalt",
    "frågesporten": "frågesport",
    "frågesportens": "frågesport",
    "frågesporter": "frågesport",
    "frågesporterna": "frågesport",
    "frågesporternas": "frågesport",
    "frågesporters": "frågesport",
    "frågesports": "frågesport",
    "frågestunden": "frågestund",
    "frågestundens": "frågestund",
    "frågestunder": "frågestund",
    "frågestunderna": "frågestund",
    "frågestundernas": "frågestund",
    "frågestunders": "frågestund",
    "frågestunds": "frågestund",
    "frågeställar": "frågeställare",
    "frågeställaren": "frågeställare",
    "frågeställarens": "frågeställare",
    "frågeställares": "frågeställare",
    "frågeställarna": "frågeställare",
    "frågeställarnas": "frågeställare",
    "frågeställningar": "frågeställning",
    "frågeställningarna": "frågeställning",
    "frågeställningarnas": "frågeställning",
    "frågeställningars": "frågeställning",
    "frågeställningen": "frågeställning",
    "frågeställningens": "frågeställning",
    "frågeställnings": "frågeställning",
    "frågeteckens": "frågetecken",
    "frågetecknen": "frågetecken",
    "frågetecknens": "frågetecken",
    "frågetecknet": "frågetecken",
    "frågetecknets": "frågetecken",
    "frågetesten": "frågetest",
    "frågetestens": "frågetest",
    "frågetester": "frågetest",
    "frågetesterna": "frågetest",
    "frågetesternas": "frågetest",
    "frågetesters": "frågetest",
    "frågetestet": "frågetest",
    "frågetestets": "frågetest",
    "frågetests": "frågetest",
    "frågetävlingar": "frågetävling",
    "frågetävlingarna": "frågetävling",
    "frågetävlingarnas": "frågetävling",
    "frågetävlingars": "frågetävling",
    "frågetävlingen": "frågetävling",
    "frågetävlingens": "frågetävling",
    "frågetävlings": "frågetävling",
    "frågor": "fråga",
    "frågorna": "fråga",
    "frågornas": "fråga",
    "frågors": "fråga",
    "frågvisa": "frågvis",
    "frågvisare": "frågvis",
    "frågvisares": "frågvis",
    "frågvisas": "frågvis",
    "frågvisast": "frågvis",
    "frågvisaste": "frågvis",
    "frågvisastes": "frågvis",
    "frågvisasts": "frågvis",
    "frågvise": "frågvis",
    "frågvises": "frågvis",
    "frågvisheten": "frågvishet",
    "frågvishetens": "frågvishet",
    "frågvishets": "frågvishet",
    "frågvist": "frågvis",
    "frågvists": "frågvis",
    "fråndöm": "fråndöma",
    "fråndömande": "fråndöma",
    "fråndömanden": "fråndömande",
    "fråndömandena": "fråndömande",
    "fråndömandenas": "fråndömande",
    "fråndömandens": "fråndömande",
    "fråndömandes": "fråndömande",
    "fråndömandet": "fråndömande",
    "fråndömandets": "fråndömande",
    "fråndömas": "fråndöma",
    "fråndömd": "fråndöma",
    "fråndömda": "fråndöma",
    "fråndömdas": "fråndöma",
    "fråndömde": "fråndöma",
    "fråndömdes": "fråndöma",
    "fråndömds": "fråndöma",
    "fråndömer": "fråndöma",
    "fråndöms": "fråndöma",
    "fråndömt": "fråndöma",
    "fråndömts": "fråndöma",
    "frånfällen": "frånfälle",
    "frånfällena": "frånfälle",
    "frånfällenas": "frånfälle",
    "frånfällens": "frånfälle",
    "frånfälles": "frånfälle",
    "frånfället": "frånfälle",
    "frånfällets": "frånfälle",
    "frånfälls": "frånfälle",
    "frångick": "frångå",
    "frångicks": "frångå",
    "frånginge": "frångå",
    "frånginges": "frångå",
    "frångående": "frångå",
    "frångåenden": "frångående",
    "frångåendena": "frångående",
    "frångåendenas": "frångående",
    "frångåendens": "frångående",
    "frångåendes": "frångående",
    "frångåendet": "frångående",
    "frångåendets": "frångående",
    "frångår": "frångå",
    "frångås": "frångå",
    "frångått": "frångå",
    "frångåtts": "frångå",
    "frånkänd": "frånkänna",
    "frånkända": "frånkänna",
    "frånkändas": "frånkänna",
    "frånkände": "frånkänna",
    "frånkändes": "frånkänna",
    "frånkänds": "frånkänna",
    "frånkänn": "frånkänna",
    "frånkännande": "frånkänna",
    "frånkännanden": "frånkännande",
    "frånkännandena": "frånkännande",
    "frånkännandenas": "frånkännande",
    "frånkännandens": "frånkännande",
    "frånkännandes": "frånkännande",
    "frånkännandet": "frånkännande",
    "frånkännandets": "frånkännande",
    "frånkännas": "frånkänna",
    "frånkänner": "frånkänna",
    "frånkännes": "frånkänna",
    "frånkänns": "frånkänna",
    "frånkänt": "frånkänna",
    "frånkänts": "frånkänna",
    "frånkörde": "frånkörd",
    "frånkördes": "frånkörd",
    "frånkörds": "frånkörd",
    "frånkört": "frånkörd",
    "frånkörts": "frånkörd",
    "frånlandsvindar": "frånlandsvind",
    "frånlandsvindarna": "frånlandsvind",
    "frånlandsvindarnas": "frånlandsvind",
    "frånlandsvindars": "frånlandsvind",
    "frånlandsvinden": "frånlandsvind",
    "frånlandsvindens": "frånlandsvind",
    "frånlandsvinds": "frånlandsvind",
    "frånräknad": "frånräkna",
    "frånräknade": "frånräkna",
    "frånräknades": "frånräkna",
    "frånräknads": "frånräkna",
    "frånräknande": "frånräkna",
    "frånräknanden": "frånräknande",
    "frånräknandena": "frånräknande",
    "frånräknandenas": "frånräknande",
    "frånräknandens": "frånräknande",
    "frånräknandes": "frånräknande",
    "frånräknandet": "frånräknande",
    "frånräknandets": "frånräknande",
    "frånräknar": "frånräkna",
    "frånräknas": "frånräkna",
    "frånräknat": "frånräkna",
    "frånräknats": "frånräkna",
    "frånsedd": "frånse",
    "frånsedda": "frånse",
    "frånseddas": "frånse",
    "frånsedde": "frånse",
    "frånseddes": "frånse",
    "frånsedds": "frånse",
    "frånseende": "frånse",
    "frånseenden": "frånseende",
    "frånseendena": "frånseende",
    "frånseendenas": "frånseende",
    "frånseendens": "frånseende",
    "frånseendes": "frånseende",
    "frånseendet": "frånseende",
    "frånseendets": "frånseende",
    "frånser": "frånse",
    "frånses": "frånse",
    "frånsett": "frånse",
    "frånsetts": "frånse",
    "frånsidan": "frånsida",
    "frånsidans": "frånsida",
    "frånsidas": "frånsida",
    "frånside": "frånsida",
    "frånsides": "frånsida",
    "frånsidor": "frånsida",
    "frånsidorna": "frånsida",
    "frånsidornas": "frånsida",
    "frånsidors": "frånsida",
    "frånskilda": "frånskild",
    "frånskildare": "frånskild",
    "frånskildares": "frånskild",
    "frånskildas": "frånskild",
    "frånskildast": "frånskild",
    "frånskildaste": "frånskild",
    "frånskildastes": "frånskild",
    "frånskildasts": "frånskild",
    "frånskilde": "frånskild",
    "frånskildes": "frånskild",
    "frånskilds": "frånskild",
    "frånskiljar": "frånskiljare",
    "frånskiljaren": "frånskiljare",
    "frånskiljarens": "frånskiljare",
    "frånskiljares": "frånskiljare",
    "frånskiljarna": "frånskiljare",
    "frånskiljarnas": "frånskiljare",
    "frånskilt": "frånskild",
    "frånskilts": "frånskild",
    "frånspel": "frånspela",
    "frånspelad": "frånspela",
    "frånspelade": "frånspela",
    "frånspelades": "frånspela",
    "frånspelads": "frånspela",
    "frånspelande": "frånspela",
    "frånspelanden": "frånspelande",
    "frånspelandena": "frånspelande",
    "frånspelandenas": "frånspelande",
    "frånspelandens": "frånspelande",
    "frånspelandes": "frånspelande",
    "frånspelandet": "frånspelande",
    "frånspelandets": "frånspelande",
    "frånspelar": "frånspela",
    "frånspelas": "frånspela",
    "frånspelat": "frånspela",
    "frånspelats": "frånspela",
    "frånsåg": "frånse",
    "frånsåge": "frånse",
    "frånsåges": "frånse",
    "frånsågs": "frånse",
    "fråntag": "frånta",
    "fråntaga": "frånta",
    "fråntagande": "frånta",
    "fråntaganden": "fråntagande",
    "fråntagandena": "fråntagande",
    "fråntagandenas": "fråntagande",
    "fråntagandens": "fråntagande",
    "fråntagandes": "fråntagande",
    "fråntagandet": "fråntagande",
    "fråntagandets": "fråntagande",
    "fråntagas": "frånta",
    "fråntage": "frånta",
    "fråntagen": "frånta",
    "fråntagens": "frånta",
    "fråntager": "frånta",
    "fråntages": "frånta",
    "fråntaget": "frånta",
    "fråntagets": "frånta",
    "fråntagit": "frånta",
    "fråntagits": "frånta",
    "fråntagna": "frånta",
    "fråntagnas": "frånta",
    "fråntagne": "frånta",
    "fråntagnes": "frånta",
    "fråntags": "frånta",
    "fråntar": "frånta",
    "fråntas": "frånta",
    "fråntog": "frånta",
    "fråntoge": "frånta",
    "fråntoges": "frånta",
    "fråntogs": "frånta",
    "frånträd": "frånträda",
    "frånträdande": "frånträda",
    "frånträdanden": "frånträdande",
    "frånträdandena": "frånträdande",
    "frånträdandenas": "frånträdande",
    "frånträdandens": "frånträdande",
    "frånträdandes": "frånträdande",
    "frånträdandet": "frånträdande",
    "frånträdandets": "frånträdande",
    "frånträdas": "frånträda",
    "frånträdd": "frånträda",
    "frånträdda": "frånträda",
    "frånträddas": "frånträda",
    "frånträdde": "frånträda",
    "frånträddes": "frånträda",
    "frånträdds": "frånträda",
    "frånträder": "frånträda",
    "frånträdes": "frånträde",
    "frånträdet": "frånträde",
    "frånträdets": "frånträde",
    "frånträds": "frånträda",
    "frånträtt": "frånträda",
    "frånträtts": "frånträda",
    "frånvaron": "frånvaro",
    "frånvarons": "frånvaro",
    "frånvaros": "frånvaro",
    "frånåkta": "frånåkt",
    "frånåktas": "frånåkt",
    "frånåkte": "frånåkt",
    "frånåktes": "frånåkt",
    "frånåkts": "frånåkt",
    "fröade": "fröa",
    "fröades": "fröa",
    "fröande": "fröa",
    "fröanden": "fröande",
    "fröandena": "fröande",
    "fröandenas": "fröande",
    "fröandens": "fröande",
    "fröandes": "fröande",
    "fröandet": "fröande",
    "fröandets": "fröande",
    "fröar": "fröa",
    "fröas": "fröa",
    "fröat": "fröa",
    "fröats": "fröa",
    "fröen": "frö",
    "fröens": "frö",
    "fröer": "frö",
    "fröerna": "frö",
    "fröernas": "frö",
    "fröers": "frö",
    "fröet": "frö",
    "fröets": "frö",
    "fröfäst": "fröfäste",
    "fröfästen": "fröfäste",
    "fröfästena": "fröfäste",
    "fröfästenas": "fröfäste",
    "fröfästens": "fröfäste",
    "fröfästes": "fröfäste",
    "fröfästet": "fröfäste",
    "fröfästets": "fröfäste",
    "frögömmen": "frögömme",
    "frögömmena": "frögömme",
    "frögömmenas": "frögömme",
    "frögömmens": "frögömme",
    "frögömmes": "frögömme",
    "frögömmet": "frögömme",
    "frögömmets": "frögömme",
    "frögöms": "frögömme",
    "fröhusen": "fröhus",
    "fröhusens": "fröhus",
    "fröhuset": "fröhus",
    "fröhusets": "fröhus",
    "fröjd": "fröjda",
    "fröjdade": "fröjda",
    "fröjdades": "fröjdas",
    "fröjdande": "fröjda",
    "fröjdanden": "fröjdande",
    "fröjdandena": "fröjdande",
    "fröjdandenas": "fröjdande",
    "fröjdandens": "fröjdande",
    "fröjdandes": "fröjdande",
    "fröjdandet": "fröjdande",
    "fröjdandets": "fröjdande",
    "fröjdar": "fröjda",
    "fröjdas": "fröjda",
    "fröjdat": "fröjda",
    "fröjdats": "fröjdas",
    "fröjde": "fröjd",
    "fröjdefulla": "fröjdefull",
    "fröjdefullare": "fröjdefull",
    "fröjdefullares": "fröjdefull",
    "fröjdefullas": "fröjdefull",
    "fröjdefullast": "fröjdefull",
    "fröjdefullaste": "fröjdefull",
    "fröjdefullastes": "fröjdefull",
    "fröjdefullasts": "fröjdefull",
    "fröjdefulle": "fröjdefull",
    "fröjdefulles": "fröjdefull",
    "fröjdefullheten": "fröjdefullhet",
    "fröjdefullhetens": "fröjdefullhet",
    "fröjdefullhets": "fröjdefullhet",
    "fröjdefulls": "fröjdefull",
    "fröjdefullt": "fröjdefull",
    "fröjdefullts": "fröjdefull",
    "fröjden": "fröjd",
    "fröjdens": "fröjd",
    "fröjder": "fröjd",
    "fröjderna": "fröjd",
    "fröjdernas": "fröjd",
    "fröjders": "fröjd",
    "fröjds": "fröjd",
    "frökens": "fröken",
    "frökenspelet": "frökenspel",
    "frökenspelets": "frökenspel",
    "frökenspels": "frökenspel",
    "fröknar": "fröken",
    "fröknarna": "fröken",
    "fröknarnas": "fröken",
    "fröknars": "fröken",
    "fröknen": "fröken",
    "fröknens": "fröken",
    "frömjölet": "frömjöl",
    "frömjölets": "frömjöl",
    "frömjöls": "frömjöl",
    "frön": "frö",
    "fröna": "frö",
    "frönas": "frö",
    "fröns": "frö",
    "fröodlingar": "fröodling",
    "fröodlingarna": "fröodling",
    "fröodlingarnas": "fröodling",
    "fröodlingars": "fröodling",
    "fröodlingen": "fröodling",
    "fröodlingens": "fröodling",
    "fröodlings": "fröodling",
    "fröplant": "fröplanta",
    "fröplantagen": "fröplantage",
    "fröplantagens": "fröplantage",
    "fröplantager": "fröplantage",
    "fröplantagerna": "fröplantage",
    "fröplantagernas": "fröplantage",
    "fröplantagers": "fröplantage",
    "fröplantages": "fröplantage",
    "fröplantan": "fröplanta",
    "fröplantans": "fröplanta",
    "fröplantas": "fröplanta",
    "fröplante": "fröplanta",
    "fröplantor": "fröplanta",
    "fröplantorna": "fröplanta",
    "fröplantornas": "fröplanta",
    "fröplantors": "fröplanta",
    "fröplants": "fröplanta",
    "frös": "frysa",
    "fröse": "frysa",
    "fröses": "frysa",
    "fröskalen": "fröskal",
    "fröskalens": "fröskal",
    "fröskalet": "fröskal",
    "fröskalets": "fröskal",
    "fröskals": "fröskal",
    "fröt": "frö",
    "frötallar": "frötall",
    "frötallarna": "frötall",
    "frötallarnas": "frötall",
    "frötallars": "frötall",
    "frötallen": "frötall",
    "frötallens": "frötall",
    "frötalls": "frötall",
    "fröträden": "fröträd",
    "fröträdens": "fröträd",
    "fröträdet": "fröträd",
    "fröträdets": "fröträd",
    "fröträds": "fröträd",
    "fröts": "frö",
    "frövit": "frövita",
    "frövitan": "frövita",
    "frövitans": "frövita",
    "frövitas": "frövita",
    "frövite": "frövita",
    "frövitor": "frövita",
    "frövitorna": "frövita",
    "frövitornas": "frövita",
    "frövitors": "frövita",
    "frövits": "frövita",
    "fröväxten": "fröväxt",
    "fröväxtens": "fröväxt",
    "fröväxter": "fröväxt",
    "fröväxterna": "fröväxt",
    "fröväxternas": "fröväxt",
    "fröväxters": "fröväxt",
    "fröväxts": "fröväxt",
    "fröämnen": "fröämne",
    "fröämnena": "fröämne",
    "fröämnenas": "fröämne",
    "fröämnens": "fröämne",
    "fröämnes": "fröämne",
    "fröämnet": "fröämne",
    "fröämnets": "fröämne",
    "ftalsyran": "ftalsyra",
    "ftalsyrans": "ftalsyra",
    "ftalsyras": "ftalsyra",
    "ftalsyre": "ftalsyra",
    "ftalsyror": "ftalsyra",
    "ftalsyrorna": "ftalsyra",
    "ftalsyrornas": "ftalsyra",
    "ftalsyrors": "ftalsyra",
    "fubbet": "fubb",
    "fubbets": "fubb",
    "fubbs": "fubb",
    "fuchsi": "fuchsia",
    "fuchsian": "fuchsia",
    "fuchsians": "fuchsia",
    "fuchsias": "fuchsia",
    "fuchsie": "fuchsia",
    "fuchsior": "fuchsia",
    "fuchsiorna": "fuchsia",
    "fuchsiornas": "fuchsia",
    "fuchsiors": "fuchsia",
    "fuchsis": "fuchsia",
    "fuffensen": "fuffens",
    "fuffensens": "fuffens",
    "fuffenset": "fuffens",
    "fuffensets": "fuffens",
    "fuffnsen": "fuffens",
    "fuffnsens": "fuffens",
    "fuffnset": "fuffens",
    "fuffnsets": "fuffens",
    "fug": "fuga",
    "fugan": "fuga",
    "fugans": "fuga",
    "fugas": "fuga",
    "fuge": "fuga",
    "fugerade": "fugerad",
    "fugerades": "fugerad",
    "fugerads": "fugerad",
    "fugerat": "fugerad",
    "fugerats": "fugerad",
    "fugor": "fuga",
    "fugorna": "fuga",
    "fugornas": "fuga",
    "fugors": "fuga",
    "fugs": "fuga",
    "fugun": "fugu",
    "fuguns": "fugu",
    "fugus": "fugu",
    "fuksinen": "fuksin",
    "fuksinens": "fuksin",
    "fuksinet": "fuksin",
    "fuksinets": "fuksin",
    "fuksins": "fuksin",
    "fukt": "fukta",
    "fuktad": "fukta",
    "fuktade": "fukta",
    "fuktades": "fukta",
    "fuktads": "fukta",
    "fuktande": "fukta",
    "fuktanden": "fuktande",
    "fuktandena": "fuktande",
    "fuktandenas": "fuktande",
    "fuktandens": "fuktande",
    "fuktandes": "fuktande",
    "fuktandet": "fuktande",
    "fuktandets": "fuktande",
    "fuktar": "fukta",
    "fuktas": "fukta",
    "fuktat": "fukta",
    "fuktats": "fukta",
    "fukten": "fukt",
    "fuktens": "fukt",
    "fuktfläckar": "fuktfläck",
    "fuktfläckarna": "fuktfläck",
    "fuktfläckarnas": "fuktfläck",
    "fuktfläckars": "fuktfläck",
    "fuktfläcken": "fuktfläck",
    "fuktfläckens": "fuktfläck",
    "fuktfläcks": "fuktfläck",
    "fukthala": "fukthal",
    "fukthalare": "fukthal",
    "fukthalares": "fukthal",
    "fukthalas": "fukthal",
    "fukthalast": "fukthal",
    "fukthalaste": "fukthal",
    "fukthalastes": "fukthal",
    "fukthalasts": "fukthal",
    "fukthale": "fukthal",
    "fukthales": "fukthal",
    "fukthals": "fukthal",
    "fukthalt": "fukthal",
    "fukthalts": "fukthal",
    "fuktiga": "fuktig",
    "fuktigare": "fuktig",
    "fuktigares": "fuktig",
    "fuktigas": "fuktig",
    "fuktigast": "fuktig",
    "fuktigaste": "fuktig",
    "fuktigastes": "fuktig",
    "fuktigasts": "fuktig",
    "fuktige": "fuktig",
    "fuktiges": "fuktig",
    "fuktigheten": "fuktighet",
    "fuktighetens": "fuktighet",
    "fuktigheter": "fuktighet",
    "fuktigheterna": "fuktighet",
    "fuktigheternas": "fuktighet",
    "fuktigheters": "fuktighet",
    "fuktighets": "fuktighet",
    "fuktigs": "fuktig",
    "fuktigt": "fuktig",
    "fuktigts": "fuktig",
    "fukts": "fukt",
    "fuktskadan": "fuktskada",
    "fuktskadans": "fuktskada",
    "fuktskadas": "fuktskada",
    "fuktskade": "fuktskada",
    "fuktskador": "fuktskada",
    "fuktskadorna": "fuktskada",
    "fuktskadornas": "fuktskada",
    "fuktskadors": "fuktskada",
    "fuktteknikern": "fukttekniker",
    "fuktteknikerna": "fukttekniker",
    "fuktteknikernas": "fukttekniker",
    "fuktteknikerns": "fukttekniker",
    "fuktteknikers": "fukttekniker",
    "fula": "ful",
    "fular": "ful",
    "fulare": "ful",
    "fulares": "ful",
    "fularna": "ful",
    "fularnas": "ful",
    "fulars": "ful",
    "fulas": "ful",
    "fulast": "ful",
    "fulaste": "ful",
    "fulastes": "ful",
    "fulasts": "ful",
    "fule": "ful",
    "fulen": "ful",
    "fulens": "ful",
    "fules": "ful",
    "fulheten": "fulhet",
    "fulhetens": "fulhet",
    "fulheter": "fulhet",
    "fulheterna": "fulhet",
    "fulheternas": "fulhet",
    "fulheters": "fulhet",
    "fulhets": "fulhet",
    "fulingar": "fuling",
    "fulingarna": "fuling",
    "fulingarnas": "fuling",
    "fulingars": "fuling",
    "fulingen": "fuling",
    "fulingens": "fuling",
    "fulings": "fuling",
    "fulla": "full",
    "fullare": "full",
    "fullares": "full",
    "fullas": "full",
    "fullast": "full",
    "fullastade": "fullastad",
    "fullastades": "fullastad",
    "fullastads": "fullastad",
    "fullastat": "fullastad",
    "fullastats": "fullastad",
    "fullaste": "full",
    "fullastes": "full",
    "fullasts": "full",
    "fullbloden": "fullblod",
    "fullblodens": "fullblod",
    "fullblodet": "fullblod",
    "fullblodets": "fullblod",
    "fullblods": "fullblod",
    "fullblodsindianen": "fullblodsindian",
    "fullblodsindianens": "fullblodsindian",
    "fullblodsindianer": "fullblodsindian",
    "fullblodsindianerna": "fullblodsindian",
    "fullblodsindianernas": "fullblodsindian",
    "fullblodsindianers": "fullblodsindian",
    "fullblodsindians": "fullblodsindian",
    "fullblodsproffsen": "fullblodsproffs",
    "fullblodsproffsens": "fullblodsproffs",
    "fullblodsproffset": "fullblodsproffs",
    "fullblodsproffsets": "fullblodsproffs",
    "fullbokade": "fullbokad",
    "fullbokades": "fullbokad",
    "fullbokads": "fullbokad",
    "fullbokat": "fullbokad",
    "fullbokats": "fullbokad",
    "fullbord": "fullborda",
    "fullbordad": "fullborda",
    "fullbordade": "fullborda",
    "fullbordades": "fullborda",
    "fullbordads": "fullborda",
    "fullbordande": "fullborda",
    "fullbordanden": "fullbordande",
    "fullbordandena": "fullbordande",
    "fullbordandenas": "fullbordande",
    "fullbordandens": "fullbordande",
    "fullbordandes": "fullbordande",
    "fullbordandet": "fullbordande",
    "fullbordandets": "fullbordande",
    "fullbordans": "fullbordan",
    "fullbordar": "fullborda",
    "fullbordas": "fullborda",
    "fullbordat": "fullborda",
    "fullbordats": "fullborda",
    "fulle": "full",
    "fulles": "full",
    "fullfjädrade": "fullfjädrad",
    "fullfjädrades": "fullfjädrad",
    "fullfjädrads": "fullfjädrad",
    "fullfjädrat": "fullfjädrad",
    "fullfjädrats": "fullfjädrad",
    "fullfölj": "fullfölja",
    "fullföljande": "fullfölja",
    "fullföljanden": "fullföljande",
    "fullföljandena": "fullföljande",
    "fullföljandenas": "fullföljande",
    "fullföljandens": "fullföljande",
    "fullföljandes": "fullföljande",
    "fullföljandet": "fullföljande",
    "fullföljandets": "fullföljande",
    "fullföljas": "fullfölja",
    "fullföljd": "fullfölja",
    "fullföljda": "fullfölja",
    "fullföljdas": "fullfölja",
    "fullföljde": "fullfölja",
    "fullföljden": "fullföljd",
    "fullföljdens": "fullföljd",
    "fullföljdes": "fullfölja",
    "fullföljds": "fullföljd",
    "fullföljer": "fullfölja",
    "fullföljes": "fullfölja",
    "fullföljs": "fullfölja",
    "fullföljt": "fullfölja",
    "fullföljts": "fullfölja",
    "fullgjord": "fullgöra",
    "fullgjorda": "fullgöra",
    "fullgjordas": "fullgöra",
    "fullgjorde": "fullgöra",
    "fullgjordes": "fullgöra",
    "fullgjords": "fullgöra",
    "fullgjort": "fullgöra",
    "fullgjorts": "fullgöra",
    "fullgoda": "fullgod",
    "fullgodare": "fullgod",
    "fullgodares": "fullgod",
    "fullgodas": "fullgod",
    "fullgodast": "fullgod",
    "fullgodaste": "fullgod",
    "fullgodastes": "fullgod",
    "fullgodasts": "fullgod",
    "fullgode": "fullgod",
    "fullgodes": "fullgod",
    "fullgodheten": "fullgodhet",
    "fullgodhetens": "fullgodhet",
    "fullgodhets": "fullgodhet",
    "fullgods": "fullgod",
    "fullgott": "fullgod",
    "fullgotts": "fullgod",
    "fullgångenheten": "fullgångenhet",
    "fullgångenhetens": "fullgångenhet",
    "fullgångenhets": "fullgångenhet",
    "fullgångens": "fullgången",
    "fullgånget": "fullgången",
    "fullgångets": "fullgången",
    "fullgångna": "fullgången",
    "fullgångnare": "fullgången",
    "fullgångnares": "fullgången",
    "fullgångnas": "fullgången",
    "fullgångnast": "fullgången",
    "fullgångnaste": "fullgången",
    "fullgångnastes": "fullgången",
    "fullgångnasts": "fullgången",
    "fullgångne": "fullgången",
    "fullgångnes": "fullgången",
    "fullgör": "fullgöra",
    "fullgörande": "fullgöra",
    "fullgöranden": "fullgörande",
    "fullgörandena": "fullgörande",
    "fullgörandenas": "fullgörande",
    "fullgörandens": "fullgörande",
    "fullgörandes": "fullgörande",
    "fullgörandet": "fullgörande",
    "fullgörandets": "fullgörande",
    "fullgöras": "fullgöra",
    "fullgörelsetalans": "fullgörelsetalan",
    "fullgöres": "fullgöra",
    "fullgörs": "fullgöra",
    "fullheten": "fullhet",
    "fullhetens": "fullhet",
    "fullhets": "fullhet",
    "fullklistrade": "fullklistrad",
    "fullklistrades": "fullklistrad",
    "fullklistrads": "fullklistrad",
    "fullklistrat": "fullklistrad",
    "fullklistrats": "fullklistrad",
    "fullkomliga": "fullkomlig",
    "fullkomligare": "fullkomlig",
    "fullkomligares": "fullkomlig",
    "fullkomligas": "fullkomlig",
    "fullkomligast": "fullkomlig",
    "fullkomligaste": "fullkomlig",
    "fullkomligastes": "fullkomlig",
    "fullkomligasts": "fullkomlig",
    "fullkomlige": "fullkomlig",
    "fullkomliges": "fullkomlig",
    "fullkomligheten": "fullkomlighet",
    "fullkomlighetens": "fullkomlighet",
    "fullkomligheter": "fullkomlighet",
    "fullkomligheterna": "fullkomlighet",
    "fullkomligheternas": "fullkomlighet",
    "fullkomligheters": "fullkomlighet",
    "fullkomlighets": "fullkomlighet",
    "fullkomligs": "fullkomlig",
    "fullkomligt": "fullkomlig",
    "fullkomligts": "fullkomlig",
    "fullkomn": "fullkomna",
    "fullkomnad": "fullkomna",
    "fullkomnade": "fullkomna",
    "fullkomnades": "fullkomna",
    "fullkomnads": "fullkomna",
    "fullkomnande": "fullkomna",
    "fullkomnanden": "fullkomnande",
    "fullkomnandena": "fullkomnande",
    "fullkomnandenas": "fullkomnande",
    "fullkomnandens": "fullkomnande",
    "fullkomnandes": "fullkomnande",
    "fullkomnandet": "fullkomnande",
    "fullkomnandets": "fullkomnande",
    "fullkomnar": "fullkomna",
    "fullkomnas": "fullkomna",
    "fullkomnat": "fullkomna",
    "fullkomnats": "fullkomna",
    "fullkomningar": "fullkomning",
    "fullkomningarna": "fullkomning",
    "fullkomningarnas": "fullkomning",
    "fullkomningars": "fullkomning",
    "fullkomningen": "fullkomning",
    "fullkomningens": "fullkomning",
    "fullkomnings": "fullkomning",
    "fullkornet": "fullkorn",
    "fullkornets": "fullkorn",
    "fullkorns": "fullkorn",
    "fullkornsbröden": "fullkornsbröd",
    "fullkornsbrödens": "fullkornsbröd",
    "fullkornsbrödet": "fullkornsbröd",
    "fullkornsbrödets": "fullkornsbröd",
    "fullkornsbröds": "fullkornsbröd",
    "fullkornsmjölet": "fullkornsmjöl",
    "fullkornsmjölets": "fullkornsmjöl",
    "fullkornsmjöls": "fullkornsmjöl",
    "fullmakten": "fullmakt",
    "fullmaktens": "fullmakt",
    "fullmakter": "fullmakt",
    "fullmakterna": "fullmakt",
    "fullmakternas": "fullmakt",
    "fullmakters": "fullmakt",
    "fullmakts": "fullmakt",
    "fullmaktslagar": "fullmaktslag",
    "fullmaktslagarna": "fullmaktslag",
    "fullmaktslagarnas": "fullmaktslag",
    "fullmaktslagars": "fullmaktslag",
    "fullmaktslagen": "fullmaktslag",
    "fullmaktslagens": "fullmaktslag",
    "fullmaktslags": "fullmaktslag",
    "fullmatade": "fullmatad",
    "fullmatades": "fullmatad",
    "fullmatads": "fullmatad",
    "fullmatat": "fullmatad",
    "fullmatats": "fullmatad",
    "fullmogenheten": "fullmogenhet",
    "fullmogenhetens": "fullmogenhet",
    "fullmogenhets": "fullmogenhet",
    "fullmogens": "fullmogen",
    "fullmoget": "fullmogen",
    "fullmogets": "fullmogen",
    "fullmogna": "fullmogen",
    "fullmognare": "fullmogen",
    "fullmognares": "fullmogen",
    "fullmognas": "fullmogen",
    "fullmognast": "fullmogen",
    "fullmognaste": "fullmogen",
    "fullmognastes": "fullmogen",
    "fullmognasts": "fullmogen",
    "fullmogne": "fullmogen",
    "fullmognes": "fullmogen",
    "fullmäktige": "fullmäktig",
    "fullmäktigen": "fullmäktig",
    "fullmäktigena": "fullmäktig",
    "fullmäktigenas": "fullmäktig",
    "fullmäktigens": "fullmäktig",
    "fullmäktiges": "fullmäktig",
    "fullmäktigs": "fullmäktig",
    "fullmån": "fullmåne",
    "fullmånar": "fullmåne",
    "fullmånarna": "fullmåne",
    "fullmånarnas": "fullmåne",
    "fullmånars": "fullmåne",
    "fullmånen": "fullmåne",
    "fullmånens": "fullmåne",
    "fullmånes": "fullmåne",
    "fullmåns": "fullmåne",
    "fullproppade": "fullproppad",
    "fullproppades": "fullproppad",
    "fullproppads": "fullproppad",
    "fullproppat": "fullproppad",
    "fullproppats": "fullproppad",
    "fullriggade": "fullriggad",
    "fullriggades": "fullriggad",
    "fullriggads": "fullriggad",
    "fullriggar": "fullriggare",
    "fullriggaren": "fullriggare",
    "fullriggarens": "fullriggare",
    "fullriggares": "fullriggare",
    "fullriggarna": "fullriggare",
    "fullriggarnas": "fullriggare",
    "fullriggat": "fullriggad",
    "fullriggats": "fullriggad",
    "fulls": "full",
    "fullsatta": "fullsatt",
    "fullsattare": "fullsatt",
    "fullsattares": "fullsatt",
    "fullsattas": "fullsatt",
    "fullsattast": "fullsatt",
    "fullsattaste": "fullsatt",
    "fullsattastes": "fullsatt",
    "fullsattasts": "fullsatt",
    "fullsatte": "fullsatt",
    "fullsattes": "fullsatt",
    "fullsatts": "fullsatt",
    "fullskaliga": "fullskalig",
    "fullskaligare": "fullskalig",
    "fullskaligares": "fullskalig",
    "fullskaligas": "fullskalig",
    "fullskaligast": "fullskalig",
    "fullskaligaste": "fullskalig",
    "fullskaligastes": "fullskalig",
    "fullskaligasts": "fullskalig",
    "fullskalige": "fullskalig",
    "fullskaliges": "fullskalig",
    "fullskaligheten": "fullskalighet",
    "fullskalighetens": "fullskalighet",
    "fullskalighets": "fullskalighet",
    "fullskaligs": "fullskalig",
    "fullskaligt": "fullskalig",
    "fullskaligts": "fullskalig",
    "fullspikade": "fullspikad",
    "fullspikades": "fullspikad",
    "fullspikads": "fullspikad",
    "fullspikat": "fullspikad",
    "fullspikats": "fullspikad",
    "fullspäckade": "fullspäckad",
    "fullspäckades": "fullspäckad",
    "fullspäckads": "fullspäckad",
    "fullspäckat": "fullspäckad",
    "fullspäckats": "fullspäckad",
    "fullstaplade": "fullstaplad",
    "fullstaplades": "fullstaplad",
    "fullstaplads": "fullstaplad",
    "fullstaplat": "fullstaplad",
    "fullstaplats": "fullstaplad",
    "fullstämmiga": "fullstämmig",
    "fullstämmigare": "fullstämmig",
    "fullstämmigares": "fullstämmig",
    "fullstämmigas": "fullstämmig",
    "fullstämmigast": "fullstämmig",
    "fullstämmigaste": "fullstämmig",
    "fullstämmigastes": "fullstämmig",
    "fullstämmigasts": "fullstämmig",
    "fullstämmige": "fullstämmig",
    "fullstämmiges": "fullstämmig",
    "fullstämmigheten": "fullstämmighet",
    "fullstämmighetens": "fullstämmighet",
    "fullstämmighets": "fullstämmighet",
    "fullstämmigs": "fullstämmig",
    "fullstämmigt": "fullstämmig",
    "fullstämmigts": "fullstämmig",
    "fullständig": "fullständiga",
    "fullständiga": "fullständig",
    "fullständigad": "fullständiga",
    "fullständigade": "fullständiga",
    "fullständigades": "fullständiga",
    "fullständigads": "fullständiga",
    "fullständigande": "fullständiga",
    "fullständiganden": "fullständigande",
    "fullständigandena": "fullständigande",
    "fullständigandenas": "fullständigande",
    "fullständigandens": "fullständigande",
    "fullständigandes": "fullständigande",
    "fullständigandet": "fullständigande",
    "fullständigandets": "fullständigande",
    "fullständigar": "fullständiga",
    "fullständigare": "fullständig",
    "fullständigares": "fullständig",
    "fullständigas": "fullständiga",
    "fullständigast": "fullständig",
    "fullständigaste": "fullständig",
    "fullständigastes": "fullständig",
    "fullständigasts": "fullständig",
    "fullständigat": "fullständiga",
    "fullständigats": "fullständiga",
    "fullständige": "fullständig",
    "fullständiges": "fullständig",
    "fullständigheten": "fullständighet",
    "fullständighetens": "fullständighet",
    "fullständigheter": "fullständighet",
    "fullständigheterna": "fullständighet",
    "fullständigheternas": "fullständighet",
    "fullständigheters": "fullständighet",
    "fullständighets": "fullständighet",
    "fullständigs": "fullständig",
    "fullständigt": "fullständig",
    "fullständigts": "fullständig",
    "fullt": "full",
    "fulltaliga": "fulltalig",
    "fulltaligare": "fulltalig",
    "fulltaligares": "fulltalig",
    "fulltaligas": "fulltalig",
    "fulltaligast": "fulltalig",
    "fulltaligaste": "fulltalig",
    "fulltaligastes": "fulltalig",
    "fulltaligasts": "fulltalig",
    "fulltalige": "fulltalig",
    "fulltaliges": "fulltalig",
    "fulltaligheten": "fulltalighet",
    "fulltalighetens": "fulltalighet",
    "fulltalighets": "fulltalighet",
    "fulltaligs": "fulltalig",
    "fulltaligt": "fulltalig",
    "fulltaligts": "fulltalig",
    "fulltecknade": "fulltecknad",
    "fulltecknades": "fulltecknad",
    "fulltecknads": "fulltecknad",
    "fulltecknat": "fulltecknad",
    "fulltecknats": "fulltecknad",
    "fulltoniga": "fulltonig",
    "fulltonigare": "fulltonig",
    "fulltonigares": "fulltonig",
    "fulltonigas": "fulltonig",
    "fulltonigast": "fulltonig",
    "fulltonigaste": "fulltonig",
    "fulltonigastes": "fulltonig",
    "fulltonigasts": "fulltonig",
    "fulltonige": "fulltonig",
    "fulltoniges": "fulltonig",
    "fulltonigheten": "fulltonighet",
    "fulltonighetens": "fulltonighet",
    "fulltonighets": "fulltonighet",
    "fulltonigs": "fulltonig",
    "fulltonigt": "fulltonig",
    "fulltonigts": "fulltonig",
    "fullträffar": "fullträff",
    "fullträffarna": "fullträff",
    "fullträffarnas": "fullträff",
    "fullträffars": "fullträff",
    "fullträffen": "fullträff",
    "fullträffens": "fullträff",
    "fullträffs": "fullträff",
    "fulltränade": "fulltränad",
    "fulltränades": "fulltränad",
    "fulltränads": "fulltränad",
    "fulltränat": "fulltränad",
    "fulltränats": "fulltränad",
    "fullts": "full",
    "fullvuxenheten": "fullvuxenhet",
    "fullvuxenhetens": "fullvuxenhet",
    "fullvuxenhets": "fullvuxenhet",
    "fullvuxens": "fullvuxen",
    "fullvuxet": "fullvuxen",
    "fullvuxets": "fullvuxen",
    "fullvuxna": "fullvuxen",
    "fullvuxnare": "fullvuxen",
    "fullvuxnares": "fullvuxen",
    "fullvuxnas": "fullvuxen",
    "fullvuxnast": "fullvuxen",
    "fullvuxnaste": "fullvuxen",
    "fullvuxnastes": "fullvuxen",
    "fullvuxnasts": "fullvuxen",
    "fullvuxne": "fullvuxen",
    "fullvuxnes": "fullvuxen",
    "fullväpnade": "fullväpnad",
    "fullväpnades": "fullväpnad",
    "fullväpnads": "fullväpnad",
    "fullväpnat": "fullväpnad",
    "fullväpnats": "fullväpnad",
    "fullvärdesförsäkringar": "fullvärdesförsäkring",
    "fullvärdesförsäkringarna": "fullvärdesförsäkring",
    "fullvärdesförsäkringarnas": "fullvärdesförsäkring",
    "fullvärdesförsäkringars": "fullvärdesförsäkring",
    "fullvärdesförsäkringen": "fullvärdesförsäkring",
    "fullvärdesförsäkringens": "fullvärdesförsäkring",
    "fullvärdesförsäkrings": "fullvärdesförsäkring",
    "fullvärdiga": "fullvärdig",
    "fullvärdigare": "fullvärdig",
    "fullvärdigares": "fullvärdig",
    "fullvärdigas": "fullvärdig",
    "fullvärdigast": "fullvärdig",
    "fullvärdigaste": "fullvärdig",
    "fullvärdigastes": "fullvärdig",
    "fullvärdigasts": "fullvärdig",
    "fullvärdige": "fullvärdig",
    "fullvärdiges": "fullvärdig",
    "fullvärdigheten": "fullvärdighet",
    "fullvärdighetens": "fullvärdighet",
    "fullvärdighets": "fullvärdighet",
    "fullvärdigs": "fullvärdig",
    "fullvärdigt": "fullvärdig",
    "fullvärdigts": "fullvärdig",
    "fulländ": "fullända",
    "fulländad": "fullända",
    "fulländade": "fulländad",
    "fulländades": "fulländad",
    "fulländads": "fulländad",
    "fulländande": "fullända",
    "fulländanden": "fulländande",
    "fulländandena": "fulländande",
    "fulländandenas": "fulländande",
    "fulländandens": "fulländande",
    "fulländandes": "fulländande",
    "fulländandet": "fulländande",
    "fulländandets": "fulländande",
    "fulländar": "fullända",
    "fulländas": "fullända",
    "fulländat": "fulländad",
    "fulländats": "fulländad",
    "fulländningar": "fulländning",
    "fulländningarna": "fulländning",
    "fulländningarnas": "fulländning",
    "fulländningars": "fulländning",
    "fulländningen": "fulländning",
    "fulländningens": "fulländning",
    "fulländnings": "fulländning",
    "fullödiga": "fullödig",
    "fullödigare": "fullödig",
    "fullödigares": "fullödig",
    "fullödigas": "fullödig",
    "fullödigast": "fullödig",
    "fullödigaste": "fullödig",
    "fullödigastes": "fullödig",
    "fullödigasts": "fullödig",
    "fullödige": "fullödig",
    "fullödiges": "fullödig",
    "fullödigheten": "fullödighet",
    "fullödighetens": "fullödighet",
    "fullödigheter": "fullödighet",
    "fullödigheterna": "fullödighet",
    "fullödigheternas": "fullödighet",
    "fullödigheters": "fullödighet",
    "fullödighets": "fullödighet",
    "fullödigs": "fullödig",
    "fullödigt": "fullödig",
    "fullödigts": "fullödig",
    "fuls": "ful",
    "fulsnygga": "fulsnygg",
    "fulsnyggare": "fulsnygg",
    "fulsnyggares": "fulsnygg",
    "fulsnyggas": "fulsnygg",
    "fulsnyggast": "fulsnygg",
    "fulsnyggaste": "fulsnygg",
    "fulsnyggastes": "fulsnygg",
    "fulsnyggasts": "fulsnygg",
    "fulsnygge": "fulsnygg",
    "fulsnygges": "fulsnygg",
    "fulsnyggheten": "fulsnygghet",
    "fulsnygghetens": "fulsnygghet",
    "fulsnygghets": "fulsnygghet",
    "fulsnyggs": "fulsnygg",
    "fulsnyggt": "fulsnygg",
    "fulsnyggts": "fulsnygg",
    "fult": "ful",
    "fults": "ful",
    "fumlade": "fumla",
    "fumlades": "fumla",
    "fumlande": "fumla",
    "fumlanden": "fumlande",
    "fumlandena": "fumlande",
    "fumlandenas": "fumlande",
    "fumlandens": "fumlande",
    "fumlandes": "fumlande",
    "fumlandet": "fumlande",
    "fumlandets": "fumlande",
    "fumlar": "fumla",
    "fumlas": "fumla",
    "fumlat": "fumla",
    "fumlats": "fumla",
    "fumliga": "fumlig",
    "fumligare": "fumlig",
    "fumligares": "fumlig",
    "fumligas": "fumlig",
    "fumligast": "fumlig",
    "fumligaste": "fumlig",
    "fumligastes": "fumlig",
    "fumligasts": "fumlig",
    "fumlige": "fumlig",
    "fumliges": "fumlig",
    "fumligheten": "fumlighet",
    "fumlighetens": "fumlighet",
    "fumligheter": "fumlighet",
    "fumligheterna": "fumlighet",
    "fumligheternas": "fumlighet",
    "fumligheters": "fumlighet",
    "fumlighets": "fumlighet",
    "fumligs": "fumlig",
    "fumligt": "fumlig",
    "fumligts": "fumlig",
    "fummel": "fumla",
    "fundamentala": "fundamental",
    "fundamentalare": "fundamental",
    "fundamentalares": "fundamental",
    "fundamentalas": "fundamental",
    "fundamentalast": "fundamental",
    "fundamentalaste": "fundamental",
    "fundamentalastes": "fundamental",
    "fundamentalasts": "fundamental",
    "fundamentale": "fundamental",
    "fundamentales": "fundamental",
    "fundamentalismen": "fundamentalism",
    "fundamentalismens": "fundamentalism",
    "fundamentalismer": "fundamentalism",
    "fundamentalismerna": "fundamentalism",
    "fundamentalismernas": "fundamentalism",
    "fundamentalismers": "fundamentalism",
    "fundamentalisms": "fundamentalism",
    "fundamentalisten": "fundamentalist",
    "fundamentalistens": "fundamentalist",
    "fundamentalister": "fundamentalist",
    "fundamentalisterna": "fundamentalist",
    "fundamentalisternas": "fundamentalist",
    "fundamentalisters": "fundamentalist",
    "fundamentalistiska": "fundamentalistisk",
    "fundamentalistiskare": "fundamentalistisk",
    "fundamentalistiskares": "fundamentalistisk",
    "fundamentalistiskas": "fundamentalistisk",
    "fundamentalistiskast": "fundamentalistisk",
    "fundamentalistiskaste": "fundamentalistisk",
    "fundamentalistiskastes": "fundamentalistisk",
    "fundamentalistiskasts": "fundamentalistisk",
    "fundamentalistiske": "fundamentalistisk",
    "fundamentalistiskes": "fundamentalistisk",
    "fundamentalistisks": "fundamentalistisk",
    "fundamentalistiskt": "fundamentalistisk",
    "fundamentalistiskts": "fundamentalistisk",
    "fundamentalists": "fundamentalist",
    "fundamentals": "fundamental",
    "fundamentalt": "fundamental",
    "fundamentalts": "fundamental",
    "fundamenten": "fundament",
    "fundamentens": "fundament",
    "fundamentet": "fundament",
    "fundamentets": "fundament",
    "fundaments": "fundament",
    "funderade": "fundera",
    "funderades": "fundera",
    "funderande": "fundera",
    "funderanden": "funderande",
    "funderandena": "funderande",
    "funderandenas": "funderande",
    "funderandens": "funderande",
    "funderandes": "funderande",
    "funderandet": "funderande",
    "funderandets": "funderande",
    "funderar": "funderare",
    "funderaren": "funderare",
    "funderarens": "funderare",
    "funderares": "funderare",
    "funderarna": "funderare",
    "funderarnas": "funderare",
    "funderas": "fundera",
    "funderat": "fundera",
    "funderats": "fundera",
    "funderingar": "fundering",
    "funderingarna": "fundering",
    "funderingarnas": "fundering",
    "funderingars": "fundering",
    "funderingen": "fundering",
    "funderingens": "fundering",
    "funderings": "fundering",
    "funderna": "funder",
    "fundernas": "funder",
    "funders": "funder",
    "fundersamheten": "fundersamhet",
    "fundersamhetens": "fundersamhet",
    "fundersamhets": "fundersamhet",
    "fundersamma": "fundersam",
    "fundersammare": "fundersam",
    "fundersammares": "fundersam",
    "fundersammas": "fundersam",
    "fundersammast": "fundersam",
    "fundersammaste": "fundersam",
    "fundersammastes": "fundersam",
    "fundersammasts": "fundersam",
    "fundersamme": "fundersam",
    "fundersammes": "fundersam",
    "fundersams": "fundersam",
    "fundersamt": "fundersam",
    "fundersamts": "fundersam",
    "fungerade": "fungera",
    "fungerades": "fungera",
    "fungerande": "fungera",
    "fungeranden": "fungerande",
    "fungerandena": "fungerande",
    "fungerandenas": "fungerande",
    "fungerandens": "fungerande",
    "fungerandes": "fungerande",
    "fungerandet": "fungerande",
    "fungerandets": "fungerande",
    "fungerar": "fungera",
    "fungeras": "fungera",
    "fungerat": "fungera",
    "fungerats": "fungera",
    "funk": "funka",
    "funkade": "funka",
    "funkades": "funka",
    "funkande": "funka",
    "funkanden": "funkande",
    "funkandena": "funkande",
    "funkandenas": "funkande",
    "funkandens": "funkande",
    "funkandes": "funkande",
    "funkandet": "funkande",
    "funkandets": "funkande",
    "funkar": "funka",
    "funkas": "funka",
    "funkat": "funka",
    "funkats": "funka",
    "funken": "funk",
    "funkens": "funk",
    "funkisen": "funkis",
    "funkisens": "funkis",
    "funks": "funk",
    "funktionalismen": "funktionalism",
    "funktionalismens": "funktionalism",
    "funktionalismer": "funktionalism",
    "funktionalismerna": "funktionalism",
    "funktionalismernas": "funktionalism",
    "funktionalismers": "funktionalism",
    "funktionalisms": "funktionalism",
    "funktionalisten": "funktionalist",
    "funktionalistens": "funktionalist",
    "funktionalister": "funktionalist",
    "funktionalisterna": "funktionalist",
    "funktionalisternas": "funktionalist",
    "funktionalisters": "funktionalist",
    "funktionalistiska": "funktionalistisk",
    "funktionalistiskare": "funktionalistisk",
    "funktionalistiskares": "funktionalistisk",
    "funktionalistiskas": "funktionalistisk",
    "funktionalistiskast": "funktionalistisk",
    "funktionalistiskaste": "funktionalistisk",
    "funktionalistiskastes": "funktionalistisk",
    "funktionalistiskasts": "funktionalistisk",
    "funktionalistiske": "funktionalistisk",
    "funktionalistiskes": "funktionalistisk",
    "funktionalistisks": "funktionalistisk",
    "funktionalistiskt": "funktionalistisk",
    "funktionalistiskts": "funktionalistisk",
    "funktionalists": "funktionalist",
    "funktionella": "funktionell",
    "funktionellare": "funktionell",
    "funktionellares": "funktionell",
    "funktionellas": "funktionell",
    "funktionellast": "funktionell",
    "funktionellaste": "funktionell",
    "funktionellastes": "funktionell",
    "funktionellasts": "funktionell",
    "funktionelle": "funktionell",
    "funktionelles": "funktionell",
    "funktionells": "funktionell",
    "funktionellt": "funktionell",
    "funktionellts": "funktionell",
    "funktionen": "funktion",
    "funktionens": "funktion",
    "funktioner": "funktion",
    "funktionerade": "funktionera",
    "funktionerades": "funktionera",
    "funktionerande": "funktionera",
    "funktioneranden": "funktionerande",
    "funktionerandena": "funktionerande",
    "funktionerandenas": "funktionerande",
    "funktionerandens": "funktionerande",
    "funktionerandes": "funktionerande",
    "funktionerandet": "funktionerande",
    "funktionerandets": "funktionerande",
    "funktionerar": "funktionera",
    "funktioneras": "funktionera",
    "funktionerat": "funktionera",
    "funktionerats": "funktionera",
    "funktioneringar": "funktionering",
    "funktioneringarna": "funktionering",
    "funktioneringarnas": "funktionering",
    "funktioneringars": "funktionering",
    "funktioneringen": "funktionering",
    "funktioneringens": "funktionering",
    "funktionerings": "funktionering",
    "funktionerna": "funktion",
    "funktionernas": "funktion",
    "funktioners": "funktion",
    "funktions": "funktion",
    "funktionsdugliga": "funktionsduglig",
    "funktionsdugligare": "funktionsduglig",
    "funktionsdugligares": "funktionsduglig",
    "funktionsdugligas": "funktionsduglig",
    "funktionsdugligast": "funktionsduglig",
    "funktionsdugligaste": "funktionsduglig",
    "funktionsdugligastes": "funktionsduglig",
    "funktionsdugligasts": "funktionsduglig",
    "funktionsduglige": "funktionsduglig",
    "funktionsdugliges": "funktionsduglig",
    "funktionsdugligheten": "funktionsduglighet",
    "funktionsduglighetens": "funktionsduglighet",
    "funktionsduglighets": "funktionsduglighet",
    "funktionsdugligs": "funktionsduglig",
    "funktionsdugligt": "funktionsduglig",
    "funktionsdugligts": "funktionsduglig",
    "funktionshinderna": "funktionshinder",
    "funktionshindernas": "funktionshinder",
    "funktionshinders": "funktionshinder",
    "funktionshindrade": "funktionshindrad",
    "funktionshindrades": "funktionshindrad",
    "funktionshindrads": "funktionshindrad",
    "funktionshindrat": "funktionshindrad",
    "funktionshindrats": "funktionshindrad",
    "funktionshindren": "funktionshinder",
    "funktionshindrens": "funktionshinder",
    "funktionshindret": "funktionshinder",
    "funktionshindrets": "funktionshinder",
    "funktionsmässiga": "funktionsmässig",
    "funktionsmässigare": "funktionsmässig",
    "funktionsmässigares": "funktionsmässig",
    "funktionsmässigas": "funktionsmässig",
    "funktionsmässigast": "funktionsmässig",
    "funktionsmässigaste": "funktionsmässig",
    "funktionsmässigastes": "funktionsmässig",
    "funktionsmässigasts": "funktionsmässig",
    "funktionsmässige": "funktionsmässig",
    "funktionsmässiges": "funktionsmässig",
    "funktionsmässigs": "funktionsmässig",
    "funktionsmässigt": "funktionsmässig",
    "funktionsmässigts": "funktionsmässig",
    "funktionsodugliga": "funktionsoduglig",
    "funktionsodugligare": "funktionsoduglig",
    "funktionsodugligares": "funktionsoduglig",
    "funktionsodugligas": "funktionsoduglig",
    "funktionsodugligast": "funktionsoduglig",
    "funktionsodugligaste": "funktionsoduglig",
    "funktionsodugligastes": "funktionsoduglig",
    "funktionsodugligasts": "funktionsoduglig",
    "funktionsoduglige": "funktionsoduglig",
    "funktionsodugliges": "funktionsoduglig",
    "funktionsodugligheten": "funktionsoduglighet",
    "funktionsoduglighetens": "funktionsoduglighet",
    "funktionsoduglighets": "funktionsoduglighet",
    "funktionsodugligs": "funktionsoduglig",
    "funktionsodugligt": "funktionsoduglig",
    "funktionsodugligts": "funktionsoduglig",
    "funktionssätten": "funktionssätt",
    "funktionssättens": "funktionssätt",
    "funktionssättet": "funktionssätt",
    "funktionssättets": "funktionssätt",
    "funktionssätts": "funktionssätt",
    "funktionsvärden": "funktionsvärde",
    "funktionsvärdena": "funktionsvärde",
    "funktionsvärdenas": "funktionsvärde",
    "funktionsvärdens": "funktionsvärde",
    "funktionsvärdes": "funktionsvärde",
    "funktionsvärdet": "funktionsvärde",
    "funktionsvärdets": "funktionsvärde",
    "funktionären": "funktionär",
    "funktionärens": "funktionär",
    "funktionärer": "funktionär",
    "funktionärerna": "funktionär",
    "funktionärernas": "funktionär",
    "funktionärers": "funktionär",
    "funktionärs": "funktionär",
    "funna": "finna",
    "funnas": "finna",
    "funne": "finna",
    "funnen": "finna",
    "funnens": "finna",
    "funnes": "finna",
    "funnet": "finna",
    "funnets": "finna",
    "funnit": "finna",
    "funnits": "finnas",
    "funtade": "funtad",
    "funtades": "funtad",
    "funtads": "funtad",
    "funtat": "funtad",
    "funtats": "funtad",
    "fur": "fura",
    "furages": "furage",
    "furaget": "furage",
    "furagets": "furage",
    "furan": "fura",
    "furanet": "furan",
    "furanets": "furan",
    "furans": "furan",
    "furas": "fura",
    "fure": "fura",
    "furen": "fur",
    "furens": "fur",
    "furien": "furie",
    "furiens": "furie",
    "furier": "furie",
    "furierna": "furie",
    "furiernas": "furie",
    "furiers": "furie",
    "furies": "furie",
    "furioson": "furioso",
    "furiosona": "furioso",
    "furiosonas": "furioso",
    "furiosons": "furioso",
    "furiosos": "furioso",
    "furiosot": "furioso",
    "furiosots": "furioso",
    "furiren": "furir",
    "furirens": "furir",
    "furirer": "furir",
    "furirerna": "furir",
    "furirernas": "furir",
    "furirers": "furir",
    "furirs": "furir",
    "furnerad": "furnera",
    "furnerade": "furnera",
    "furnerades": "furnera",
    "furnerads": "furnera",
    "furnerande": "furnera",
    "furneranden": "furnerande",
    "furnerandena": "furnerande",
    "furnerandenas": "furnerande",
    "furnerandens": "furnerande",
    "furnerandes": "furnerande",
    "furnerandet": "furnerande",
    "furnerandets": "furnerande",
    "furnerar": "furnera",
    "furneras": "furnera",
    "furnerat": "furnera",
    "furnerats": "furnera",
    "furnerbara": "furnerbar",
    "furnerbarare": "furnerbar",
    "furnerbarares": "furnerbar",
    "furnerbaras": "furnerbar",
    "furnerbarast": "furnerbar",
    "furnerbaraste": "furnerbar",
    "furnerbarastes": "furnerbar",
    "furnerbarasts": "furnerbar",
    "furnerbare": "furnerbar",
    "furnerbares": "furnerbar",
    "furnerbarheten": "furnerbarhet",
    "furnerbarhetens": "furnerbarhet",
    "furnerbarhets": "furnerbarhet",
    "furnerbars": "furnerbar",
    "furnerbart": "furnerbar",
    "furnerbarts": "furnerbar",
    "furneringar": "furnering",
    "furneringarna": "furnering",
    "furneringarnas": "furnering",
    "furneringars": "furnering",
    "furneringen": "furnering",
    "furneringens": "furnering",
    "furnerings": "furnering",
    "furnissören": "furnissör",
    "furnissörens": "furnissör",
    "furnissörer": "furnissör",
    "furnissörerna": "furnissör",
    "furnissörernas": "furnissör",
    "furnissörers": "furnissör",
    "furnissörs": "furnissör",
    "furor": "fura",
    "furoren": "furore",
    "furorens": "furore",
    "furores": "furore",
    "furorna": "fura",
    "furornas": "fura",
    "furors": "furor",
    "furs": "fura",
    "furstar": "furste",
    "furstarna": "furste",
    "furstarnas": "furste",
    "furstars": "furste",
    "furstbiskopar": "furstbiskop",
    "furstbiskoparna": "furstbiskop",
    "furstbiskoparnas": "furstbiskop",
    "furstbiskopars": "furstbiskop",
    "furstbiskopen": "furstbiskop",
    "furstbiskopens": "furstbiskop",
    "furstbiskops": "furstbiskop",
    "fursten": "furste",
    "furstendömen": "furstendöme",
    "furstendömena": "furstendöme",
    "furstendömenas": "furstendöme",
    "furstendömens": "furstendöme",
    "furstendömes": "furstendöme",
    "furstendömet": "furstendöme",
    "furstendömets": "furstendöme",
    "furstens": "furste",
    "furstes": "furste",
    "fursteätten": "fursteätt",
    "fursteättens": "fursteätt",
    "fursteätter": "fursteätt",
    "fursteätterna": "fursteätt",
    "fursteätternas": "fursteätt",
    "fursteätters": "fursteätt",
    "fursteätts": "fursteätt",
    "furstliga": "furstlig",
    "furstligare": "furstlig",
    "furstligares": "furstlig",
    "furstligas": "furstlig",
    "furstligast": "furstlig",
    "furstligaste": "furstlig",
    "furstligastes": "furstlig",
    "furstligasts": "furstlig",
    "furstlige": "furstlig",
    "furstliges": "furstlig",
    "furstligheten": "furstlighet",
    "furstlighetens": "furstlighet",
    "furstligheter": "furstlighet",
    "furstligheterna": "furstlighet",
    "furstligheternas": "furstlighet",
    "furstligheters": "furstlighet",
    "furstlighets": "furstlighet",
    "furstligs": "furstlig",
    "furstligt": "furstlig",
    "furstligts": "furstlig",
    "fursts": "furst",
    "furugolven": "furugolv",
    "furugolvens": "furugolv",
    "furugolvet": "furugolv",
    "furugolvets": "furugolv",
    "furugolvs": "furugolv",
    "furun": "furu",
    "furunkeln": "furunkel",
    "furunkelns": "furunkel",
    "furunkels": "furunkel",
    "furunklar": "furunkel",
    "furunklarna": "furunkel",
    "furunklarnas": "furunkel",
    "furunklars": "furunkel",
    "furuns": "furu",
    "furuplank": "furuplanka",
    "furuplankan": "furuplanka",
    "furuplankans": "furuplanka",
    "furuplankas": "furuplanka",
    "furuplanke": "furuplanka",
    "furuplankor": "furuplanka",
    "furuplankorna": "furuplanka",
    "furuplankornas": "furuplanka",
    "furuplankors": "furuplanka",
    "furuplanks": "furuplanka",
    "furus": "furu",
    "furut": "furu",
    "furuts": "furu",
    "fusionen": "fusion",
    "fusionens": "fusion",
    "fusioner": "fusion",
    "fusionerad": "fusionera",
    "fusionerade": "fusionera",
    "fusionerades": "fusionera",
    "fusionerads": "fusionera",
    "fusionerande": "fusionera",
    "fusioneranden": "fusionerande",
    "fusionerandena": "fusionerande",
    "fusionerandenas": "fusionerande",
    "fusionerandens": "fusionerande",
    "fusionerandes": "fusionerande",
    "fusionerandet": "fusionerande",
    "fusionerandets": "fusionerande",
    "fusionerar": "fusionera",
    "fusioneras": "fusionera",
    "fusionerat": "fusionera",
    "fusionerats": "fusionera",
    "fusionerbara": "fusionerbar",
    "fusionerbarare": "fusionerbar",
    "fusionerbarares": "fusionerbar",
    "fusionerbaras": "fusionerbar",
    "fusionerbarast": "fusionerbar",
    "fusionerbaraste": "fusionerbar",
    "fusionerbarastes": "fusionerbar",
    "fusionerbarasts": "fusionerbar",
    "fusionerbare": "fusionerbar",
    "fusionerbares": "fusionerbar",
    "fusionerbarheten": "fusionerbarhet",
    "fusionerbarhetens": "fusionerbarhet",
    "fusionerbarhets": "fusionerbarhet",
    "fusionerbars": "fusionerbar",
    "fusionerbart": "fusionerbar",
    "fusionerbarts": "fusionerbar",
    "fusioneringar": "fusionering",
    "fusioneringarna": "fusionering",
    "fusioneringarnas": "fusionering",
    "fusioneringars": "fusionering",
    "fusioneringen": "fusionering",
    "fusioneringens": "fusionering",
    "fusionerings": "fusionering",
    "fusionerna": "fusion",
    "fusionernas": "fusion",
    "fusioners": "fusion",
    "fusions": "fusion",
    "fusk": "fuska",
    "fuskade": "fuska",
    "fuskades": "fuska",
    "fuskande": "fuska",
    "fuskanden": "fuskande",
    "fuskandena": "fuskande",
    "fuskandenas": "fuskande",
    "fuskandens": "fuskande",
    "fuskandes": "fuskande",
    "fuskandet": "fuskande",
    "fuskandets": "fuskande",
    "fuskar": "fuskare",
    "fuskaren": "fuskare",
    "fuskarens": "fuskare",
    "fuskares": "fuskare",
    "fuskarna": "fuskare",
    "fuskarnas": "fuskare",
    "fuskas": "fuska",
    "fuskat": "fuska",
    "fuskats": "fuska",
    "fuskbyggar": "fuskbyggare",
    "fuskbyggaren": "fuskbyggare",
    "fuskbyggarens": "fuskbyggare",
    "fuskbyggares": "fuskbyggare",
    "fuskbyggarna": "fuskbyggare",
    "fuskbyggarnas": "fuskbyggare",
    "fuskbyggen": "fuskbygge",
    "fuskbyggena": "fuskbygge",
    "fuskbyggenas": "fuskbygge",
    "fuskbyggens": "fuskbygge",
    "fuskbygges": "fuskbygge",
    "fuskbygget": "fuskbygge",
    "fuskbyggets": "fuskbygge",
    "fusket": "fusk",
    "fuskets": "fusk",
    "fuskflygningar": "fuskflygning",
    "fuskflygningarna": "fuskflygning",
    "fuskflygningarnas": "fuskflygning",
    "fuskflygningars": "fuskflygning",
    "fuskflygningen": "fuskflygning",
    "fuskflygningens": "fuskflygning",
    "fuskflygnings": "fuskflygning",
    "fusklappar": "fusklapp",
    "fusklapparna": "fusklapp",
    "fusklapparnas": "fusklapp",
    "fusklappars": "fusklapp",
    "fusklappen": "fusklapp",
    "fusklappens": "fusklapp",
    "fusklapps": "fusklapp",
    "fuskpälsar": "fuskpäls",
    "fuskpälsarna": "fuskpäls",
    "fuskpälsarnas": "fuskpäls",
    "fuskpälsars": "fuskpäls",
    "fuskpälsen": "fuskpäls",
    "fuskpälsens": "fuskpäls",
    "fusks": "fusk",
    "fuskverken": "fuskverk",
    "fuskverkens": "fuskverk",
    "fuskverket": "fuskverk",
    "fuskverkets": "fuskverk",
    "fuskverks": "fuskverk",
    "futharken": "futhark",
    "futharkens": "futhark",
    "futharker": "futhark",
    "futharkerna": "futhark",
    "futharkernas": "futhark",
    "futharkers": "futhark",
    "futharks": "futhark",
    "futila": "futil",
    "futilare": "futil",
    "futilares": "futil",
    "futilas": "futil",
    "futilast": "futil",
    "futilaste": "futil",
    "futilastes": "futil",
    "futilasts": "futil",
    "futile": "futil",
    "futiles": "futil",
    "futiliteten": "futilitet",
    "futilitetens": "futilitet",
    "futiliteter": "futilitet",
    "futiliteterna": "futilitet",
    "futiliteternas": "futilitet",
    "futiliteters": "futilitet",
    "futilitets": "futilitet",
    "futils": "futil",
    "futilt": "futil",
    "futilts": "futil",
    "futt": "futta",
    "futtade": "futta",
    "futtades": "futta",
    "futtande": "futta",
    "futtanden": "futtande",
    "futtandena": "futtande",
    "futtandenas": "futtande",
    "futtandens": "futtande",
    "futtandes": "futtande",
    "futtandet": "futtande",
    "futtandets": "futtande",
    "futtar": "futta",
    "futtarna": "futt",
    "futtarnas": "futt",
    "futtars": "futt",
    "futtas": "futta",
    "futtat": "futta",
    "futtats": "futta",
    "futten": "futt",
    "futtens": "futt",
    "futtiga": "futtig",
    "futtigare": "futtig",
    "futtigares": "futtig",
    "futtigas": "futtig",
    "futtigast": "futtig",
    "futtigaste": "futtig",
    "futtigastes": "futtig",
    "futtigasts": "futtig",
    "futtige": "futtig",
    "futtiges": "futtig",
    "futtigheten": "futtighet",
    "futtighetens": "futtighet",
    "futtigheter": "futtighet",
    "futtigheterna": "futtighet",
    "futtigheternas": "futtighet",
    "futtigheters": "futtighet",
    "futtighets": "futtighet",
    "futtigs": "futtig",
    "futtigt": "futtig",
    "futtigts": "futtig",
    "futts": "futt",
    "futurala": "futural",
    "futuralare": "futural",
    "futuralares": "futural",
    "futuralas": "futural",
    "futuralast": "futural",
    "futuralaste": "futural",
    "futuralastes": "futural",
    "futuralasts": "futural",
    "futurale": "futural",
    "futurales": "futural",
    "futurals": "futural",
    "futuralt": "futural",
    "futuralts": "futural",
    "futurer": "futurum",
    "futurerna": "futurum",
    "futurernas": "futurum",
    "futurers": "futurum",
    "futurismen": "futurism",
    "futurismens": "futurism",
    "futurismer": "futurism",
    "futurismerna": "futurism",
    "futurismernas": "futurism",
    "futurismers": "futurism",
    "futurisms": "futurism",
    "futuristen": "futurist",
    "futuristens": "futurist",
    "futurister": "futurist",
    "futuristerna": "futurist",
    "futuristernas": "futurist",
    "futuristers": "futurist",
    "futuristiska": "futuristisk",
    "futuristiskare": "futuristisk",
    "futuristiskares": "futuristisk",
    "futuristiskas": "futuristisk",
    "futuristiskast": "futuristisk",
    "futuristiskaste": "futuristisk",
    "futuristiskastes": "futuristisk",
    "futuristiskasts": "futuristisk",
    "futuristiske": "futuristisk",
    "futuristiskes": "futuristisk",
    "futuristisks": "futuristisk",
    "futuristiskt": "futuristisk",
    "futuristiskts": "futuristisk",
    "futurists": "futurist",
    "futurologen": "futurolog",
    "futurologens": "futurolog",
    "futurologer": "futurolog",
    "futurologerna": "futurolog",
    "futurologernas": "futurolog",
    "futurologers": "futurolog",
    "futurologien": "futurologi",
    "futurologiens": "futurologi",
    "futurologin": "futurologi",
    "futurologins": "futurologi",
    "futurologis": "futurologi",
    "futurologiska": "futurologisk",
    "futurologiskare": "futurologisk",
    "futurologiskares": "futurologisk",
    "futurologiskas": "futurologisk",
    "futurologiskast": "futurologisk",
    "futurologiskaste": "futurologisk",
    "futurologiskastes": "futurologisk",
    "futurologiskasts": "futurologisk",
    "futurologiske": "futurologisk",
    "futurologiskes": "futurologisk",
    "futurologisks": "futurologisk",
    "futurologiskt": "futurologisk",
    "futurologiskts": "futurologisk",
    "futurologs": "futurolog",
    "futurumet": "futurum",
    "futurumets": "futurum",
    "futurums": "futurum",
    "fuxar": "fux",
    "fuxarna": "fux",
    "fuxarnas": "fux",
    "fuxars": "fux",
    "fuxen": "fux",
    "fuxens": "fux",
    "fylgian": "fylgia",
    "fylgians": "fylgia",
    "fylgias": "fylgia",
    "fylgie": "fylgia",
    "fylgior": "fylgia",
    "fylgiorna": "fylgia",
    "fylgiornas": "fylgia",
    "fylgiors": "fylgia",
    "fylgjan": "fylgja",
    "fylgjans": "fylgja",
    "fylgjas": "fylgja",
    "fylgje": "fylgja",
    "fylgjor": "fylgja",
    "fylgjorna": "fylgja",
    "fylgjornas": "fylgja",
    "fylgjors": "fylgja",
    "fylkad": "fylka",
    "fylkade": "fylka",
    "fylkades": "fylkas",
    "fylkads": "fylka",
    "fylkande": "fylka",
    "fylkanden": "fylkande",
    "fylkandena": "fylkande",
    "fylkandenas": "fylkande",
    "fylkandens": "fylkande",
    "fylkandes": "fylkande",
    "fylkandet": "fylkande",
    "fylkandets": "fylkande",
    "fylkar": "fylka",
    "fylkas": "fylka",
    "fylkat": "fylka",
    "fylkats": "fylkas",
    "fylken": "fylke",
    "fylkena": "fylke",
    "fylkenas": "fylke",
    "fylkens": "fylke",
    "fylkes": "fylke",
    "fylket": "fylke",
    "fylkets": "fylke",
    "fylkingar": "fylking",
    "fylkingarna": "fylking",
    "fylkingarnas": "fylking",
    "fylkingars": "fylking",
    "fylkingen": "fylking",
    "fylkingens": "fylking",
    "fylkings": "fylking",
    "fylks": "fylke",
    "fyll": "fylla",
    "fyllan": "fylla",
    "fyllande": "fylla",
    "fyllanden": "fyllande",
    "fyllandena": "fyllande",
    "fyllandenas": "fyllande",
    "fyllandens": "fyllande",
    "fyllandes": "fyllande",
    "fyllandet": "fyllande",
    "fyllandets": "fyllande",
    "fyllans": "fylla",
    "fyllas": "fylla",
    "fyllbultar": "fyllbult",
    "fyllbultarna": "fyllbult",
    "fyllbultarnas": "fyllbult",
    "fyllbultars": "fyllbult",
    "fyllbulten": "fyllbult",
    "fyllbultens": "fyllbult",
    "fyllbults": "fyllbult",
    "fylld": "fylla",
    "fyllda": "fylld",
    "fylldare": "fylld",
    "fylldares": "fylld",
    "fylldas": "fylld",
    "fylldast": "fylld",
    "fylldaste": "fylld",
    "fylldastes": "fylld",
    "fylldasts": "fylld",
    "fyllde": "fylld",
    "fylldes": "fylld",
    "fylldillen": "fylldille",
    "fylldillens": "fylldille",
    "fylldilles": "fylldille",
    "fylldillet": "fylldille",
    "fylldillets": "fylldille",
    "fyllds": "fylld",
    "fylle": "fylla",
    "fyllebråken": "fyllebråk",
    "fyllebråkens": "fyllebråk",
    "fyllebråket": "fyllebråk",
    "fyllebråkets": "fyllebråk",
    "fyllebråks": "fyllebråk",
    "fyller": "fylla",
    "fylleriet": "fylleri",
    "fylleriets": "fylleri",
    "fylleriförseelsen": "fylleriförseelse",
    "fylleriförseelsens": "fylleriförseelse",
    "fylleriförseelser": "fylleriförseelse",
    "fylleriförseelserna": "fylleriförseelse",
    "fylleriförseelsernas": "fylleriförseelse",
    "fylleriförseelsers": "fylleriförseelse",
    "fylleriförseelses": "fylleriförseelse",
    "fylleris": "fylleri",
    "fylleristen": "fyllerist",
    "fylleristens": "fyllerist",
    "fyllerister": "fyllerist",
    "fylleristerna": "fyllerist",
    "fylleristernas": "fyllerist",
    "fylleristers": "fyllerist",
    "fyllerists": "fyllerist",
    "fyllerit": "fylleri",
    "fyllerits": "fylleri",
    "fylles": "fylla",
    "fylleslagen": "fylleslag",
    "fylleslagens": "fylleslag",
    "fylleslaget": "fylleslag",
    "fylleslagets": "fylleslag",
    "fylleslags": "fylleslag",
    "fylliga": "fyllig",
    "fylligare": "fyllig",
    "fylligares": "fyllig",
    "fylligas": "fyllig",
    "fylligast": "fyllig",
    "fylligaste": "fyllig",
    "fylligastes": "fyllig",
    "fylligasts": "fyllig",
    "fyllige": "fyllig",
    "fylliges": "fyllig",
    "fylligheten": "fyllighet",
    "fyllighetens": "fyllighet",
    "fyllighets": "fyllighet",
    "fylligs": "fyllig",
    "fylligt": "fyllig",
    "fylligts": "fyllig",
    "fyllkaj": "fyllkaja",
    "fyllkajan": "fyllkaja",
    "fyllkajans": "fyllkaja",
    "fyllkajas": "fyllkaja",
    "fyllkaje": "fyllkaja",
    "fyllkajor": "fyllkaja",
    "fyllkajorna": "fyllkaja",
    "fyllkajornas": "fyllkaja",
    "fyllkajors": "fyllkaja",
    "fyllkajs": "fyllkaja",
    "fyllnade": "fyllna",
    "fyllnaden": "fyllnad",
    "fyllnadens": "fyllnad",
    "fyllnader": "fyllnad",
    "fyllnaderna": "fyllnad",
    "fyllnadernas": "fyllnad",
    "fyllnaders": "fyllnad",
    "fyllnades": "fyllna",
    "fyllnads": "fyllnad",
    "fyllnadstjänstgöringar": "fyllnadstjänstgöring",
    "fyllnadstjänstgöringarna": "fyllnadstjänstgöring",
    "fyllnadstjänstgöringarnas": "fyllnadstjänstgöring",
    "fyllnadstjänstgöringars": "fyllnadstjänstgöring",
    "fyllnadstjänstgöringen": "fyllnadstjänstgöring",
    "fyllnadstjänstgöringens": "fyllnadstjänstgöring",
    "fyllnadstjänstgörings": "fyllnadstjänstgöring",
    "fyllnadsvalen": "fyllnadsval",
    "fyllnadsvalens": "fyllnadsval",
    "fyllnadsvalet": "fyllnadsval",
    "fyllnadsvalets": "fyllnadsval",
    "fyllnadsvals": "fyllnadsval",
    "fyllnande": "fyllna",
    "fyllnanden": "fyllnande",
    "fyllnandena": "fyllnande",
    "fyllnandenas": "fyllnande",
    "fyllnandens": "fyllnande",
    "fyllnandes": "fyllnande",
    "fyllnandet": "fyllnande",
    "fyllnandets": "fyllnande",
    "fyllnar": "fyllna",
    "fyllnas": "fyllna",
    "fyllnat": "fyllna",
    "fyllnats": "fyllna",
    "fyllningar": "fyllning",
    "fyllningarna": "fyllning",
    "fyllningarnas": "fyllning",
    "fyllningars": "fyllning",
    "fyllningen": "fyllning",
    "fyllningens": "fyllning",
    "fyllnings": "fyllning",
    "fyllon": "fyllo",
    "fyllona": "fyllo",
    "fyllonas": "fyllo",
    "fyllons": "fyllo",
    "fyllor": "fylla",
    "fyllorna": "fylla",
    "fyllornas": "fylla",
    "fyllors": "fylla",
    "fyllos": "fyllo",
    "fyllot": "fyllo",
    "fyllots": "fyllo",
    "fylls": "fylla",
    "fyllt": "fylld",
    "fyllts": "fylld",
    "fylogenetiska": "fylogenetisk",
    "fylogenetiskare": "fylogenetisk",
    "fylogenetiskares": "fylogenetisk",
    "fylogenetiskas": "fylogenetisk",
    "fylogenetiskast": "fylogenetisk",
    "fylogenetiskaste": "fylogenetisk",
    "fylogenetiskastes": "fylogenetisk",
    "fylogenetiskasts": "fylogenetisk",
    "fylogenetiske": "fylogenetisk",
    "fylogenetiskes": "fylogenetisk",
    "fylogenetisks": "fylogenetisk",
    "fylogenetiskt": "fylogenetisk",
    "fylogenetiskts": "fylogenetisk",
    "fylogenien": "fylogeni",
    "fylogeniens": "fylogeni",
    "fylogenin": "fylogeni",
    "fylogenins": "fylogeni",
    "fylogenis": "fylogeni",
    "fynd": "fynda",
    "fyndad": "fynda",
    "fyndade": "fynda",
    "fyndades": "fynda",
    "fyndads": "fynda",
    "fyndande": "fynda",
    "fyndanden": "fyndande",
    "fyndandena": "fyndande",
    "fyndandenas": "fyndande",
    "fyndandens": "fyndande",
    "fyndandes": "fyndande",
    "fyndandet": "fyndande",
    "fyndandets": "fyndande",
    "fyndar": "fynda",
    "fyndas": "fynda",
    "fyndat": "fynda",
    "fyndats": "fynda",
    "fynden": "fynd",
    "fyndens": "fynd",
    "fyndet": "fynd",
    "fyndets": "fynd",
    "fyndgruv": "fyndgruva",
    "fyndgruvan": "fyndgruva",
    "fyndgruvans": "fyndgruva",
    "fyndgruvas": "fyndgruva",
    "fyndgruve": "fyndgruva",
    "fyndgruvor": "fyndgruva",
    "fyndgruvorna": "fyndgruva",
    "fyndgruvornas": "fyndgruva",
    "fyndgruvors": "fyndgruva",
    "fyndgruvs": "fyndgruva",
    "fyndiga": "fyndig",
    "fyndigare": "fyndig",
    "fyndigares": "fyndig",
    "fyndigas": "fyndig",
    "fyndigast": "fyndig",
    "fyndigaste": "fyndig",
    "fyndigastes": "fyndig",
    "fyndigasts": "fyndig",
    "fyndige": "fyndig",
    "fyndiges": "fyndig",
    "fyndigheten": "fyndighet",
    "fyndighetens": "fyndighet",
    "fyndigheter": "fyndighet",
    "fyndigheterna": "fyndighet",
    "fyndigheternas": "fyndighet",
    "fyndigheters": "fyndighet",
    "fyndighets": "fyndighet",
    "fyndigs": "fyndig",
    "fyndigt": "fyndig",
    "fyndigts": "fyndig",
    "fyndorten": "fyndort",
    "fyndortens": "fyndort",
    "fyndorter": "fyndort",
    "fyndorterna": "fyndort",
    "fyndorternas": "fyndort",
    "fyndorters": "fyndort",
    "fyndorts": "fyndort",
    "fyndplatsen": "fyndplats",
    "fyndplatsens": "fyndplats",
    "fyndplatser": "fyndplats",
    "fyndplatserna": "fyndplats",
    "fyndplatsernas": "fyndplats",
    "fyndplatsers": "fyndplats",
    "fyndprisen": "fyndpris",
    "fyndprisens": "fyndpris",
    "fyndpriser": "fyndpris",
    "fyndpriserna": "fyndpris",
    "fyndprisernas": "fyndpris",
    "fyndprisers": "fyndpris",
    "fyndpriset": "fyndpris",
    "fyndprisets": "fyndpris",
    "fynds": "fynd",
    "fyran": "fyra",
    "fyrans": "fyra",
    "fyraprocentsspärren": "fyraprocentsspärr",
    "fyraprocentsspärrens": "fyraprocentsspärr",
    "fyraprocentsspärrs": "fyraprocentsspärr",
    "fyrar": "fyr",
    "fyrarna": "fyr",
    "fyrarnas": "fyr",
    "fyrars": "fyr",
    "fyrarummar": "fyrarummare",
    "fyrarummaren": "fyrarummare",
    "fyrarummarens": "fyrarummare",
    "fyrarummares": "fyrarummare",
    "fyrarummarna": "fyrarummare",
    "fyrarummarnas": "fyrarummare",
    "fyrarumslägenheten": "fyrarumslägenhet",
    "fyrarumslägenhetens": "fyrarumslägenhet",
    "fyrarumslägenheter": "fyrarumslägenhet",
    "fyrarumslägenheterna": "fyrarumslägenhet",
    "fyrarumslägenheternas": "fyrarumslägenhet",
    "fyrarumslägenheters": "fyrarumslägenhet",
    "fyrarumslägenhets": "fyrarumslägenhet",
    "fyras": "fyra",
    "fyrasnårets": "fyrasnåret",
    "fyratimmarsflygningar": "fyratimmarsflygning",
    "fyratimmarsflygningarna": "fyratimmarsflygning",
    "fyratimmarsflygningarnas": "fyratimmarsflygning",
    "fyratimmarsflygningars": "fyratimmarsflygning",
    "fyratimmarsflygningen": "fyratimmarsflygning",
    "fyratimmarsflygningens": "fyratimmarsflygning",
    "fyratimmarsflygnings": "fyratimmarsflygning",
    "fyraåriga": "fyraårig",
    "fyraårigas": "fyraårig",
    "fyraårige": "fyraårig",
    "fyraåriges": "fyraårig",
    "fyraårigs": "fyraårig",
    "fyraårigt": "fyraårig",
    "fyraårigts": "fyraårig",
    "fyraåringar": "fyraåring",
    "fyraåringarna": "fyraåring",
    "fyraåringarnas": "fyraåring",
    "fyraåringars": "fyraåring",
    "fyraåringen": "fyraåring",
    "fyraåringens": "fyraåring",
    "fyraårings": "fyraåring",
    "fyrbackslinjen": "fyrbackslinje",
    "fyrbackslinjens": "fyrbackslinje",
    "fyrbackslinjer": "fyrbackslinje",
    "fyrbackslinjerna": "fyrbackslinje",
    "fyrbackslinjernas": "fyrbackslinje",
    "fyrbackslinjers": "fyrbackslinje",
    "fyrbackslinjes": "fyrbackslinje",
    "fyrbenta": "fyrbent",
    "fyrbentare": "fyrbent",
    "fyrbentares": "fyrbent",
    "fyrbentas": "fyrbent",
    "fyrbentast": "fyrbent",
    "fyrbentaste": "fyrbent",
    "fyrbentastes": "fyrbent",
    "fyrbentasts": "fyrbent",
    "fyrbente": "fyrbent",
    "fyrbentes": "fyrbent",
    "fyrbents": "fyrbent",
    "fyrbåkar": "fyrbåk",
    "fyrbåkarna": "fyrbåk",
    "fyrbåkarnas": "fyrbåk",
    "fyrbåkars": "fyrbåk",
    "fyrbåken": "fyrbåk",
    "fyrbåkens": "fyrbåk",
    "fyrbåks": "fyrbåk",
    "fyrcylindriga": "fyrcylindrig",
    "fyrcylindrigare": "fyrcylindrig",
    "fyrcylindrigares": "fyrcylindrig",
    "fyrcylindrigas": "fyrcylindrig",
    "fyrcylindrigast": "fyrcylindrig",
    "fyrcylindrigaste": "fyrcylindrig",
    "fyrcylindrigastes": "fyrcylindrig",
    "fyrcylindrigasts": "fyrcylindrig",
    "fyrcylindrige": "fyrcylindrig",
    "fyrcylindriges": "fyrcylindrig",
    "fyrcylindrigs": "fyrcylindrig",
    "fyrcylindrigt": "fyrcylindrig",
    "fyrcylindrigts": "fyrcylindrig",
    "fyrdubbels": "fyrdubbel",
    "fyrdubbelt": "fyrdubbel",
    "fyrdubbelts": "fyrdubbel",
    "fyrdubbla": "fyrdubbel",
    "fyrdubblare": "fyrdubbel",
    "fyrdubblares": "fyrdubbel",
    "fyrdubblas": "fyrdubbel",
    "fyrdubblast": "fyrdubbel",
    "fyrdubblaste": "fyrdubbel",
    "fyrdubblastes": "fyrdubbel",
    "fyrdubblasts": "fyrdubbel",
    "fyrdubble": "fyrdubbel",
    "fyrdubbles": "fyrdubbel",
    "fyren": "fyr",
    "fyrens": "fyr",
    "fyrfaldiga": "fyrfaldig",
    "fyrfaldigare": "fyrfaldig",
    "fyrfaldigares": "fyrfaldig",
    "fyrfaldigas": "fyrfaldig",
    "fyrfaldigast": "fyrfaldig",
    "fyrfaldigaste": "fyrfaldig",
    "fyrfaldigastes": "fyrfaldig",
    "fyrfaldigasts": "fyrfaldig",
    "fyrfaldige": "fyrfaldig",
    "fyrfaldiges": "fyrfaldig",
    "fyrfaldigs": "fyrfaldig",
    "fyrfaldigt": "fyrfaldig",
    "fyrfaldigts": "fyrfaldig",
    "fyrfotade": "fyrfotad",
    "fyrfotades": "fyrfotad",
    "fyrfotadjuren": "fyrfotadjur",
    "fyrfotadjurens": "fyrfotadjur",
    "fyrfotadjuret": "fyrfotadjur",
    "fyrfotadjurets": "fyrfotadjur",
    "fyrfotadjurs": "fyrfotadjur",
    "fyrfotads": "fyrfotad",
    "fyrfotat": "fyrfotad",
    "fyrfotats": "fyrfotad",
    "fyrfotingar": "fyrfoting",
    "fyrfotingarna": "fyrfoting",
    "fyrfotingarnas": "fyrfoting",
    "fyrfotingars": "fyrfoting",
    "fyrfotingen": "fyrfoting",
    "fyrfotingens": "fyrfoting",
    "fyrfotings": "fyrfoting",
    "fyrfärgade": "fyrfärgad",
    "fyrfärgades": "fyrfärgad",
    "fyrfärgads": "fyrfärgad",
    "fyrfärgat": "fyrfärgad",
    "fyrfärgats": "fyrfärgad",
    "fyrfärgstrycken": "fyrfärgstryck",
    "fyrfärgstryckens": "fyrfärgstryck",
    "fyrfärgstrycket": "fyrfärgstryck",
    "fyrfärgstryckets": "fyrfärgstryck",
    "fyrfärgstrycks": "fyrfärgstryck",
    "fyrhandssättningar": "fyrhandssättning",
    "fyrhandssättningarna": "fyrhandssättning",
    "fyrhandssättningarnas": "fyrhandssättning",
    "fyrhandssättningars": "fyrhandssättning",
    "fyrhandssättningen": "fyrhandssättning",
    "fyrhandssättningens": "fyrhandssättning",
    "fyrhandssättnings": "fyrhandssättning",
    "fyrhjuliga": "fyrhjulig",
    "fyrhjuligare": "fyrhjulig",
    "fyrhjuligares": "fyrhjulig",
    "fyrhjuligas": "fyrhjulig",
    "fyrhjuligast": "fyrhjulig",
    "fyrhjuligaste": "fyrhjulig",
    "fyrhjuligastes": "fyrhjulig",
    "fyrhjuligasts": "fyrhjulig",
    "fyrhjulige": "fyrhjulig",
    "fyrhjuliges": "fyrhjulig",
    "fyrhjuligheten": "fyrhjulighet",
    "fyrhjulighetens": "fyrhjulighet",
    "fyrhjulighets": "fyrhjulighet",
    "fyrhjuligs": "fyrhjulig",
    "fyrhjuligt": "fyrhjulig",
    "fyrhjuligts": "fyrhjulig",
    "fyrhjulingar": "fyrhjuling",
    "fyrhjulingarna": "fyrhjuling",
    "fyrhjulingarnas": "fyrhjuling",
    "fyrhjulingars": "fyrhjuling",
    "fyrhjulingen": "fyrhjuling",
    "fyrhjulingens": "fyrhjuling",
    "fyrhjulings": "fyrhjuling",
    "fyrhändiga": "fyrhändig",
    "fyrhändigare": "fyrhändig",
    "fyrhändigares": "fyrhändig",
    "fyrhändigas": "fyrhändig",
    "fyrhändigast": "fyrhändig",
    "fyrhändigaste": "fyrhändig",
    "fyrhändigastes": "fyrhändig",
    "fyrhändigasts": "fyrhändig",
    "fyrhändige": "fyrhändig",
    "fyrhändiges": "fyrhändig",
    "fyrhändigs": "fyrhändig",
    "fyrhändigt": "fyrhändig",
    "fyrhändigts": "fyrhändig",
    "fyrhörningar": "fyrhörning",
    "fyrhörningarna": "fyrhörning",
    "fyrhörningarnas": "fyrhörning",
    "fyrhörningars": "fyrhörning",
    "fyrhörningen": "fyrhörning",
    "fyrhörningens": "fyrhörning",
    "fyrhörnings": "fyrhörning",
    "fyrkanten": "fyrkant",
    "fyrkantens": "fyrkant",
    "fyrkanter": "fyrkant",
    "fyrkanterna": "fyrkant",
    "fyrkanternas": "fyrkant",
    "fyrkanters": "fyrkant",
    "fyrkantiga": "fyrkantig",
    "fyrkantigare": "fyrkantig",
    "fyrkantigares": "fyrkantig",
    "fyrkantigas": "fyrkantig",
    "fyrkantigast": "fyrkantig",
    "fyrkantigaste": "fyrkantig",
    "fyrkantigastes": "fyrkantig",
    "fyrkantigasts": "fyrkantig",
    "fyrkantige": "fyrkantig",
    "fyrkantiges": "fyrkantig",
    "fyrkantigheten": "fyrkantighet",
    "fyrkantighetens": "fyrkantighet",
    "fyrkantigheter": "fyrkantighet",
    "fyrkantigheterna": "fyrkantighet",
    "fyrkantigheternas": "fyrkantighet",
    "fyrkantigheters": "fyrkantighet",
    "fyrkantighets": "fyrkantighet",
    "fyrkantigs": "fyrkantig",
    "fyrkantigt": "fyrkantig",
    "fyrkantigts": "fyrkantig",
    "fyrkants": "fyrkant",
    "fyrkar": "fyrk",
    "fyrkaraktären": "fyrkaraktär",
    "fyrkaraktärens": "fyrkaraktär",
    "fyrkaraktärer": "fyrkaraktär",
    "fyrkaraktärerna": "fyrkaraktär",
    "fyrkaraktärernas": "fyrkaraktär",
    "fyrkaraktärers": "fyrkaraktär",
    "fyrkaraktärs": "fyrkaraktär",
    "fyrkarna": "fyrk",
    "fyrkarnas": "fyrk",
    "fyrkars": "fyrk",
    "fyrken": "fyrk",
    "fyrkens": "fyrk",
    "fyrklövern": "fyrklöver",
    "fyrklöverns": "fyrklöver",
    "fyrklövers": "fyrklöver",
    "fyrks": "fyrk",
    "fyrlingar": "fyrling",
    "fyrlingarna": "fyrling",
    "fyrlingarnas": "fyrling",
    "fyrlingars": "fyrling",
    "fyrlingen": "fyrling",
    "fyrlingens": "fyrling",
    "fyrlings": "fyrling",
    "fyrljusen": "fyrljus",
    "fyrljusens": "fyrljus",
    "fyrljuset": "fyrljus",
    "fyrljusets": "fyrljus",
    "fyrmotoriga": "fyrmotorig",
    "fyrmotorigare": "fyrmotorig",
    "fyrmotorigares": "fyrmotorig",
    "fyrmotorigas": "fyrmotorig",
    "fyrmotorigast": "fyrmotorig",
    "fyrmotorigaste": "fyrmotorig",
    "fyrmotorigastes": "fyrmotorig",
    "fyrmotorigasts": "fyrmotorig",
    "fyrmotorige": "fyrmotorig",
    "fyrmotoriges": "fyrmotorig",
    "fyrmotorigs": "fyrmotorig",
    "fyrmotorigt": "fyrmotorig",
    "fyrmotorigts": "fyrmotorig",
    "fyrmänningar": "fyrmänning",
    "fyrmänningarna": "fyrmänning",
    "fyrmänningarnas": "fyrmänning",
    "fyrmänningars": "fyrmänning",
    "fyrmänningen": "fyrmänning",
    "fyrmänningens": "fyrmänning",
    "fyrmännings": "fyrmänning",
    "fyropen": "fyrop",
    "fyropens": "fyrop",
    "fyropet": "fyrop",
    "fyropets": "fyrop",
    "fyrops": "fyrop",
    "fyror": "fyra",
    "fyrorna": "fyra",
    "fyrornas": "fyra",
    "fyrors": "fyra",
    "fyrrummar": "fyrrummare",
    "fyrrummaren": "fyrrummare",
    "fyrrummarens": "fyrrummare",
    "fyrrummares": "fyrrummare",
    "fyrrummarna": "fyrrummare",
    "fyrrummarnas": "fyrrummare",
    "fyrrumslägenheten": "fyrrumslägenhet",
    "fyrrumslägenhetens": "fyrrumslägenhet",
    "fyrrumslägenheter": "fyrrumslägenhet",
    "fyrrumslägenheterna": "fyrrumslägenhet",
    "fyrrumslägenheternas": "fyrrumslägenhet",
    "fyrrumslägenheters": "fyrrumslägenhet",
    "fyrrumslägenhets": "fyrrumslägenhet",
    "fyrs": "fyr",
    "fyrsidingar": "fyrsiding",
    "fyrsidingarna": "fyrsiding",
    "fyrsidingarnas": "fyrsiding",
    "fyrsidingars": "fyrsiding",
    "fyrsidingen": "fyrsiding",
    "fyrsidingens": "fyrsiding",
    "fyrsidings": "fyrsiding",
    "fyrsiffriga": "fyrsiffrig",
    "fyrsiffrigare": "fyrsiffrig",
    "fyrsiffrigares": "fyrsiffrig",
    "fyrsiffrigas": "fyrsiffrig",
    "fyrsiffrigast": "fyrsiffrig",
    "fyrsiffrigaste": "fyrsiffrig",
    "fyrsiffrigastes": "fyrsiffrig",
    "fyrsiffrigasts": "fyrsiffrig",
    "fyrsiffrige": "fyrsiffrig",
    "fyrsiffriges": "fyrsiffrig",
    "fyrsiffrigs": "fyrsiffrig",
    "fyrsiffrigt": "fyrsiffrig",
    "fyrsiffrigts": "fyrsiffrig",
    "fyrsitsiga": "fyrsitsig",
    "fyrsitsigare": "fyrsitsig",
    "fyrsitsigares": "fyrsitsig",
    "fyrsitsigas": "fyrsitsig",
    "fyrsitsigast": "fyrsitsig",
    "fyrsitsigaste": "fyrsitsig",
    "fyrsitsigastes": "fyrsitsig",
    "fyrsitsigasts": "fyrsitsig",
    "fyrsitsige": "fyrsitsig",
    "fyrsitsiges": "fyrsitsig",
    "fyrsitsigs": "fyrsitsig",
    "fyrsitsigt": "fyrsitsig",
    "fyrsitsigts": "fyrsitsig",
    "fyrskaftade": "fyrskaftad",
    "fyrskaftades": "fyrskaftad",
    "fyrskaftads": "fyrskaftad",
    "fyrskaftat": "fyrskaftad",
    "fyrskaftats": "fyrskaftad",
    "fyrskafts": "fyrskaft",
    "fyrskeppen": "fyrskepp",
    "fyrskeppens": "fyrskepp",
    "fyrskeppet": "fyrskepp",
    "fyrskeppets": "fyrskepp",
    "fyrskepps": "fyrskepp",
    "fyrspannen": "fyrspann",
    "fyrspannens": "fyrspann",
    "fyrspannet": "fyrspann",
    "fyrspannets": "fyrspann",
    "fyrspanns": "fyrspann",
    "fyrsprångs": "fyrsprång",
    "fyrstjärniga": "fyrstjärnig",
    "fyrstjärnigas": "fyrstjärnig",
    "fyrstjärnige": "fyrstjärnig",
    "fyrstjärniges": "fyrstjärnig",
    "fyrstjärnigs": "fyrstjärnig",
    "fyrstjärnigt": "fyrstjärnig",
    "fyrstjärnigts": "fyrstjärnig",
    "fyrtaktar": "fyrtaktare",
    "fyrtaktaren": "fyrtaktare",
    "fyrtaktarens": "fyrtaktare",
    "fyrtaktares": "fyrtaktare",
    "fyrtaktarna": "fyrtaktare",
    "fyrtaktarnas": "fyrtaktare",
    "fyrtaktsmotorer": "fyrtaktsmotor",
    "fyrtaktsmotorerna": "fyrtaktsmotor",
    "fyrtaktsmotorernas": "fyrtaktsmotor",
    "fyrtaktsmotorers": "fyrtaktsmotor",
    "fyrtaktsmotorn": "fyrtaktsmotor",
    "fyrtaktsmotorns": "fyrtaktsmotor",
    "fyrtaktsmotors": "fyrtaktsmotor",
    "fyrtalen": "fyrtal",
    "fyrtalens": "fyrtal",
    "fyrtalet": "fyrtal",
    "fyrtalets": "fyrtal",
    "fyrtals": "fyrtal",
    "fyrtionde": "fyrtio",
    "fyrtiondes": "fyrtio",
    "fyrtios": "fyrtio",
    "fyrtiotalet": "fyrtiotal",
    "fyrtiotalets": "fyrtiotal",
    "fyrtiotalismen": "fyrtiotalism",
    "fyrtiotalismens": "fyrtiotalism",
    "fyrtiotalismer": "fyrtiotalism",
    "fyrtiotalismerna": "fyrtiotalism",
    "fyrtiotalismernas": "fyrtiotalism",
    "fyrtiotalismers": "fyrtiotalism",
    "fyrtiotalisms": "fyrtiotalism",
    "fyrtiotalisten": "fyrtiotalist",
    "fyrtiotalistens": "fyrtiotalist",
    "fyrtiotalister": "fyrtiotalist",
    "fyrtiotalisterna": "fyrtiotalist",
    "fyrtiotalisternas": "fyrtiotalist",
    "fyrtiotalisters": "fyrtiotalist",
    "fyrtiotalistiska": "fyrtiotalistisk",
    "fyrtiotalistiskas": "fyrtiotalistisk",
    "fyrtiotalistiske": "fyrtiotalistisk",
    "fyrtiotalistiskes": "fyrtiotalistisk",
    "fyrtiotalistisks": "fyrtiotalistisk",
    "fyrtiotalistiskt": "fyrtiotalistisk",
    "fyrtiotalistiskts": "fyrtiotalistisk",
    "fyrtiotalists": "fyrtiotalist",
    "fyrtiotals": "fyrtiotal",
    "fyrtiotimmarsveck": "fyrtiotimmarsvecka",
    "fyrtiotimmarsveckan": "fyrtiotimmarsvecka",
    "fyrtiotimmarsveckans": "fyrtiotimmarsvecka",
    "fyrtiotimmarsveckas": "fyrtiotimmarsvecka",
    "fyrtiotimmarsvecke": "fyrtiotimmarsvecka",
    "fyrtiotimmarsvecko": "fyrtiotimmarsvecka",
    "fyrtiotimmarsveckor": "fyrtiotimmarsvecka",
    "fyrtiotimmarsveckorna": "fyrtiotimmarsvecka",
    "fyrtiotimmarsveckornas": "fyrtiotimmarsvecka",
    "fyrtiotimmarsveckors": "fyrtiotimmarsvecka",
    "fyrtiotimmarsvecks": "fyrtiotimmarsvecka",
    "fyrtioåringar": "fyrtioåring",
    "fyrtioåringarna": "fyrtioåring",
    "fyrtioåringarnas": "fyrtioåring",
    "fyrtioåringars": "fyrtioåring",
    "fyrtioåringen": "fyrtioåring",
    "fyrtioåringens": "fyrtioåring",
    "fyrtioårings": "fyrtioåring",
    "fyrtioårskrisen": "fyrtioårskris",
    "fyrtioårskrisens": "fyrtioårskris",
    "fyrtioårskriser": "fyrtioårskris",
    "fyrtioårskriserna": "fyrtioårskris",
    "fyrtioårskrisernas": "fyrtioårskris",
    "fyrtioårskrisers": "fyrtioårskris",
    "fyrtitalet": "fyrtital",
    "fyrtitalets": "fyrtital",
    "fyrtitalismen": "fyrtitalism",
    "fyrtitalismens": "fyrtitalism",
    "fyrtitalismer": "fyrtitalism",
    "fyrtitalismerna": "fyrtitalism",
    "fyrtitalismernas": "fyrtitalism",
    "fyrtitalismers": "fyrtitalism",
    "fyrtitalisms": "fyrtitalism",
    "fyrtitalisten": "fyrtitalist",
    "fyrtitalistens": "fyrtitalist",
    "fyrtitalister": "fyrtitalist",
    "fyrtitalisterna": "fyrtitalist",
    "fyrtitalisternas": "fyrtitalist",
    "fyrtitalisters": "fyrtitalist",
    "fyrtitalists": "fyrtitalist",
    "fyrtitals": "fyrtital",
    "fyrtitimmarsveck": "fyrtitimmarsvecka",
    "fyrtitimmarsveckan": "fyrtitimmarsvecka",
    "fyrtitimmarsveckans": "fyrtitimmarsvecka",
    "fyrtitimmarsveckas": "fyrtitimmarsvecka",
    "fyrtitimmarsvecke": "fyrtitimmarsvecka",
    "fyrtitimmarsvecko": "fyrtitimmarsvecka",
    "fyrtitimmarsveckor": "fyrtitimmarsvecka",
    "fyrtitimmarsveckorna": "fyrtitimmarsvecka",
    "fyrtitimmarsveckornas": "fyrtitimmarsvecka",
    "fyrtitimmarsveckors": "fyrtitimmarsvecka",
    "fyrtitimmarsvecks": "fyrtitimmarsvecka",
    "fyrtiåringar": "fyrtiåring",
    "fyrtiåringarna": "fyrtiåring",
    "fyrtiåringarnas": "fyrtiåring",
    "fyrtiåringars": "fyrtiåring",
    "fyrtiåringen": "fyrtiåring",
    "fyrtiåringens": "fyrtiåring",
    "fyrtiårings": "fyrtiåring",
    "fyrtiårskrisen": "fyrtiårskris",
    "fyrtiårskrisens": "fyrtiårskris",
    "fyrtiårskriser": "fyrtiårskris",
    "fyrtiårskriserna": "fyrtiårskris",
    "fyrtiårskrisernas": "fyrtiårskris",
    "fyrtiårskrisers": "fyrtiårskris",
    "fyrtornen": "fyrtorn",
    "fyrtornens": "fyrtorn",
    "fyrtornet": "fyrtorn",
    "fyrtornets": "fyrtorn",
    "fyrtorns": "fyrtorn",
    "fyrtumsspikar": "fyrtumsspik",
    "fyrtumsspikarna": "fyrtumsspik",
    "fyrtumsspikarnas": "fyrtumsspik",
    "fyrtumsspikars": "fyrtumsspik",
    "fyrtumsspiken": "fyrtumsspik",
    "fyrtumsspikens": "fyrtumsspik",
    "fyrtumsspiks": "fyrtumsspik",
    "fyrvaktar": "fyrvaktare",
    "fyrvaktaren": "fyrvaktare",
    "fyrvaktarens": "fyrvaktare",
    "fyrvaktares": "fyrvaktare",
    "fyrvaktarna": "fyrvaktare",
    "fyrvaktarnas": "fyrvaktare",
    "fyrverkar": "fyrverkare",
    "fyrverkaren": "fyrverkare",
    "fyrverkarens": "fyrverkare",
    "fyrverkares": "fyrverkare",
    "fyrverkarna": "fyrverkare",
    "fyrverkarnas": "fyrverkare",
    "fyrverkerier": "fyrverkeri",
    "fyrverkerierna": "fyrverkeri",
    "fyrverkeriernas": "fyrverkeri",
    "fyrverkeriers": "fyrverkeri",
    "fyrverkeriet": "fyrverkeri",
    "fyrverkeriets": "fyrverkeri",
    "fyrverkeripjäsen": "fyrverkeripjäs",
    "fyrverkeripjäsens": "fyrverkeripjäs",
    "fyrverkeripjäser": "fyrverkeripjäs",
    "fyrverkeripjäserna": "fyrverkeripjäs",
    "fyrverkeripjäsernas": "fyrverkeripjäs",
    "fyrverkeripjäsers": "fyrverkeripjäs",
    "fyrverkeris": "fyrverkeri",
    "fyrverkerit": "fyrverkeri",
    "fyrverkerits": "fyrverkeri",
    "fyrväldiga": "fyrväldig",
    "fyrväldigare": "fyrväldig",
    "fyrväldigares": "fyrväldig",
    "fyrväldigas": "fyrväldig",
    "fyrväldigast": "fyrväldig",
    "fyrväldigaste": "fyrväldig",
    "fyrväldigastes": "fyrväldig",
    "fyrväldigasts": "fyrväldig",
    "fyrväldige": "fyrväldig",
    "fyrväldiges": "fyrväldig",
    "fyrväldigs": "fyrväldig",
    "fyrväldigt": "fyrväldig",
    "fyrväldigts": "fyrväldig",
    "fyrväpplingar": "fyrväppling",
    "fyrväpplingarna": "fyrväppling",
    "fyrväpplingarnas": "fyrväppling",
    "fyrväpplingars": "fyrväppling",
    "fyrväpplingen": "fyrväppling",
    "fyrväpplingens": "fyrväppling",
    "fyrväpplings": "fyrväppling",
    "fyrväxlade": "fyrväxlad",
    "fyrväxlades": "fyrväxlad",
    "fyrväxlads": "fyrväxlad",
    "fyrväxlat": "fyrväxlad",
    "fyrväxlats": "fyrväxlad",
    "fysikaliska": "fysikalisk",
    "fysikaliskare": "fysikalisk",
    "fysikaliskares": "fysikalisk",
    "fysikaliskas": "fysikalisk",
    "fysikaliskast": "fysikalisk",
    "fysikaliskaste": "fysikalisk",
    "fysikaliskastes": "fysikalisk",
    "fysikaliskasts": "fysikalisk",
    "fysikaliske": "fysikalisk",
    "fysikaliskes": "fysikalisk",
    "fysikalisks": "fysikalisk",
    "fysikaliskt": "fysikalisk",
    "fysikaliskts": "fysikalisk",
    "fysiken": "fysik",
    "fysikens": "fysik",
    "fysikern": "fysiker",
    "fysikerna": "fysiker",
    "fysikernas": "fysiker",
    "fysikerns": "fysiker",
    "fysikers": "fysiker",
    "fysikforskar": "fysikforskare",
    "fysikforskaren": "fysikforskare",
    "fysikforskarens": "fysikforskare",
    "fysikforskares": "fysikforskare",
    "fysikforskarna": "fysikforskare",
    "fysikforskarnas": "fysikforskare",
    "fysikforskningar": "fysikforskning",
    "fysikforskningarna": "fysikforskning",
    "fysikforskningarnas": "fysikforskning",
    "fysikforskningars": "fysikforskning",
    "fysikforskningen": "fysikforskning",
    "fysikforskningens": "fysikforskning",
    "fysikforsknings": "fysikforskning",
    "fysiklärar": "fysiklärare",
    "fysikläraren": "fysiklärare",
    "fysiklärarens": "fysiklärare",
    "fysiklärares": "fysiklärare",
    "fysiklärarna": "fysiklärare",
    "fysiklärarnas": "fysiklärare",
    "fysiks": "fysik",
    "fysikvetenskapen": "fysikvetenskap",
    "fysikvetenskapens": "fysikvetenskap",
    "fysikvetenskaper": "fysikvetenskap",
    "fysikvetenskaperna": "fysikvetenskap",
    "fysikvetenskapernas": "fysikvetenskap",
    "fysikvetenskapers": "fysikvetenskap",
    "fysikvetenskaps": "fysikvetenskap",
    "fysiljerad": "fysiljera",
    "fysiljerade": "fysiljera",
    "fysiljerades": "fysiljera",
    "fysiljerads": "fysiljera",
    "fysiljerande": "fysiljera",
    "fysiljeranden": "fysiljerande",
    "fysiljerandena": "fysiljerande",
    "fysiljerandenas": "fysiljerande",
    "fysiljerandens": "fysiljerande",
    "fysiljerandes": "fysiljerande",
    "fysiljerandet": "fysiljerande",
    "fysiljerandets": "fysiljerande",
    "fysiljerar": "fysiljera",
    "fysiljeras": "fysiljera",
    "fysiljerat": "fysiljera",
    "fysiljerats": "fysiljera",
    "fysiljerbara": "fysiljerbar",
    "fysiljerbarare": "fysiljerbar",
    "fysiljerbarares": "fysiljerbar",
    "fysiljerbaras": "fysiljerbar",
    "fysiljerbarast": "fysiljerbar",
    "fysiljerbaraste": "fysiljerbar",
    "fysiljerbarastes": "fysiljerbar",
    "fysiljerbarasts": "fysiljerbar",
    "fysiljerbare": "fysiljerbar",
    "fysiljerbares": "fysiljerbar",
    "fysiljerbarheten": "fysiljerbarhet",
    "fysiljerbarhetens": "fysiljerbarhet",
    "fysiljerbarhets": "fysiljerbarhet",
    "fysiljerbars": "fysiljerbar",
    "fysiljerbart": "fysiljerbar",
    "fysiljerbarts": "fysiljerbar",
    "fysiljeringar": "fysiljering",
    "fysiljeringarna": "fysiljering",
    "fysiljeringarnas": "fysiljering",
    "fysiljeringars": "fysiljering",
    "fysiljeringen": "fysiljering",
    "fysiljeringens": "fysiljering",
    "fysiljerings": "fysiljering",
    "fysiokraten": "fysiokrat",
    "fysiokratens": "fysiokrat",
    "fysiokrater": "fysiokrat",
    "fysiokraterna": "fysiokrat",
    "fysiokraternas": "fysiokrat",
    "fysiokraters": "fysiokrat",
    "fysiokratiska": "fysiokratisk",
    "fysiokratiskare": "fysiokratisk",
    "fysiokratiskares": "fysiokratisk",
    "fysiokratiskas": "fysiokratisk",
    "fysiokratiskast": "fysiokratisk",
    "fysiokratiskaste": "fysiokratisk",
    "fysiokratiskastes": "fysiokratisk",
    "fysiokratiskasts": "fysiokratisk",
    "fysiokratiske": "fysiokratisk",
    "fysiokratiskes": "fysiokratisk",
    "fysiokratisks": "fysiokratisk",
    "fysiokratiskt": "fysiokratisk",
    "fysiokratiskts": "fysiokratisk",
    "fysiokratismen": "fysiokratism",
    "fysiokratismens": "fysiokratism",
    "fysiokratismer": "fysiokratism",
    "fysiokratismerna": "fysiokratism",
    "fysiokratismernas": "fysiokratism",
    "fysiokratismers": "fysiokratism",
    "fysiokratisms": "fysiokratism",
    "fysiokrats": "fysiokrat",
    "fysiologen": "fysiolog",
    "fysiologens": "fysiolog",
    "fysiologer": "fysiolog",
    "fysiologerna": "fysiolog",
    "fysiologernas": "fysiolog",
    "fysiologers": "fysiolog",
    "fysiologien": "fysiologi",
    "fysiologiens": "fysiologi",
    "fysiologin": "fysiologi",
    "fysiologins": "fysiologi",
    "fysiologis": "fysiologi",
    "fysiologiska": "fysiologisk",
    "fysiologiskare": "fysiologisk",
    "fysiologiskares": "fysiologisk",
    "fysiologiskas": "fysiologisk",
    "fysiologiskast": "fysiologisk",
    "fysiologiskaste": "fysiologisk",
    "fysiologiskastes": "fysiologisk",
    "fysiologiskasts": "fysiologisk",
    "fysiologiske": "fysiologisk",
    "fysiologiskes": "fysiologisk",
    "fysiologisks": "fysiologisk",
    "fysiologiskt": "fysiologisk",
    "fysiologiskts": "fysiologisk",
    "fysiologs": "fysiolog",
    "fysionomien": "fysionomi",
    "fysionomiens": "fysionomi",
    "fysionomier": "fysionomi",
    "fysionomierna": "fysionomi",
    "fysionomiernas": "fysionomi",
    "fysionomiers": "fysionomi",
    "fysionomin": "fysionomi",
    "fysionomins": "fysionomi",
    "fysionomis": "fysionomi",
    "fysiska": "fysisk",
    "fysiskare": "fysisk",
    "fysiskares": "fysisk",
    "fysiskas": "fysisk",
    "fysiskast": "fysisk",
    "fysiskaste": "fysisk",
    "fysiskastes": "fysisk",
    "fysiskasts": "fysisk",
    "fysiske": "fysisk",
    "fysiskes": "fysisk",
    "fysisks": "fysisk",
    "fysiskt": "fysisk",
    "fysiskts": "fysisk",
    "fytotronen": "fytotron",
    "fytotronens": "fytotron",
    "fytotroner": "fytotron",
    "fytotronerna": "fytotron",
    "fytotronernas": "fytotron",
    "fytotroners": "fytotron",
    "fytotrons": "fytotron",
    "fäaktiga": "fäaktig",
    "fäaktigare": "fäaktig",
    "fäaktigares": "fäaktig",
    "fäaktigas": "fäaktig",
    "fäaktigast": "fäaktig",
    "fäaktigaste": "fäaktig",
    "fäaktigastes": "fäaktig",
    "fäaktigasts": "fäaktig",
    "fäaktige": "fäaktig",
    "fäaktiges": "fäaktig",
    "fäaktigheten": "fäaktighet",
    "fäaktighetens": "fäaktighet",
    "fäaktighets": "fäaktighet",
    "fäaktigs": "fäaktig",
    "fäaktigt": "fäaktig",
    "fäaktigts": "fäaktig",
    "fäblessen": "fäbless",
    "fäblessens": "fäbless",
    "fäblesser": "fäbless",
    "fäblesserna": "fäbless",
    "fäblessernas": "fäbless",
    "fäblessers": "fäbless",
    "fäbodar": "fäbod",
    "fäbodarna": "fäbod",
    "fäbodarnas": "fäbod",
    "fäbodars": "fäbod",
    "fäboden": "fäbod",
    "fäbodens": "fäbod",
    "fäbods": "fäbod",
    "fäbodvallar": "fäbodvall",
    "fäbodvallarna": "fäbodvall",
    "fäbodvallarnas": "fäbodvall",
    "fäbodvallars": "fäbodvall",
    "fäbodvallen": "fäbodvall",
    "fäbodvallens": "fäbodvall",
    "fäbodvalls": "fäbodvall",
    "fäder": "far",
    "fäderna": "far",
    "fädernas": "far",
    "fädernes": "fäderne",
    "fäderneslandet": "fädernesland",
    "fäderneslandets": "fädernesland",
    "fäderneslands": "fädernesland",
    "fädernesländer": "fädernesland",
    "fädernesländerna": "fädernesland",
    "fädernesländernas": "fädernesland",
    "fädernesländers": "fädernesland",
    "fädernet": "fäderne",
    "fädernets": "fäderne",
    "fäders": "far",
    "fäet": "fä",
    "fäets": "fä",
    "fägat": "fägata",
    "fägatan": "fägata",
    "fägatans": "fägata",
    "fägatas": "fägata",
    "fägate": "fägata",
    "fägator": "fägata",
    "fägatorna": "fägata",
    "fägatornas": "fägata",
    "fägators": "fägata",
    "fägats": "fägata",
    "fägn": "fägna",
    "fägnad": "fägna",
    "fägnade": "fägna",
    "fägnaden": "fägnad",
    "fägnadens": "fägnad",
    "fägnader": "fägnad",
    "fägnaderna": "fägnad",
    "fägnadernas": "fägnad",
    "fägnaders": "fägnad",
    "fägnades": "fägnas",
    "fägnads": "fägnad",
    "fägnande": "fägna",
    "fägnanden": "fägnande",
    "fägnandena": "fägnande",
    "fägnandenas": "fägnande",
    "fägnandens": "fägnande",
    "fägnandes": "fägnande",
    "fägnandet": "fägnande",
    "fägnandets": "fägnande",
    "fägnar": "fägna",
    "fägnas": "fägna",
    "fägnat": "fägna",
    "fägnats": "fägnas",
    "fägnesamma": "fägnesam",
    "fägnesammare": "fägnesam",
    "fägnesammares": "fägnesam",
    "fägnesammas": "fägnesam",
    "fägnesammast": "fägnesam",
    "fägnesammaste": "fägnesam",
    "fägnesammastes": "fägnesam",
    "fägnesammasts": "fägnesam",
    "fägnesamme": "fägnesam",
    "fägnesammes": "fägnesam",
    "fägnesams": "fägnesam",
    "fägnesamt": "fägnesam",
    "fägnesamts": "fägnesam",
    "fägringar": "fägring",
    "fägringarna": "fägring",
    "fägringarnas": "fägring",
    "fägringars": "fägring",
    "fägringen": "fägring",
    "fägringens": "fägring",
    "fägrings": "fägring",
    "fähundar": "fähund",
    "fähundarna": "fähund",
    "fähundarnas": "fähund",
    "fähundars": "fähund",
    "fähunden": "fähund",
    "fähundens": "fähund",
    "fähunds": "fähund",
    "fähusen": "fähus",
    "fähusens": "fähus",
    "fähuset": "fähus",
    "fähusets": "fähus",
    "fäkt": "fäkta",
    "fäktade": "fäkta",
    "fäktades": "fäkta",
    "fäktande": "fäkta",
    "fäktanden": "fäktande",
    "fäktandena": "fäktande",
    "fäktandenas": "fäktande",
    "fäktandens": "fäktande",
    "fäktandes": "fäktande",
    "fäktandet": "fäktande",
    "fäktandets": "fäktande",
    "fäktar": "fäktare",
    "fäktaren": "fäktare",
    "fäktarens": "fäktare",
    "fäktares": "fäktare",
    "fäktarna": "fäktare",
    "fäktarnas": "fäktare",
    "fäktas": "fäkta",
    "fäktat": "fäkta",
    "fäktats": "fäkta",
    "fäktningar": "fäktning",
    "fäktningarna": "fäktning",
    "fäktningarnas": "fäktning",
    "fäktningars": "fäktning",
    "fäktningen": "fäktning",
    "fäktningens": "fäktning",
    "fäktnings": "fäktning",
    "fäktningsmatchen": "fäktningsmatch",
    "fäktningsmatchens": "fäktningsmatch",
    "fäktningsmatcher": "fäktningsmatch",
    "fäktningsmatcherna": "fäktningsmatch",
    "fäktningsmatchernas": "fäktningsmatch",
    "fäktningsmatchers": "fäktningsmatch",
    "fäktningsmatchs": "fäktningsmatch",
    "fälben": "fälb",
    "fälbens": "fälb",
    "fälbs": "fälb",
    "fälgar": "fälg",
    "fälgarna": "fälg",
    "fälgarnas": "fälg",
    "fälgars": "fälg",
    "fälgborst": "fälgborste",
    "fälgborstar": "fälgborste",
    "fälgborstarna": "fälgborste",
    "fälgborstarnas": "fälgborste",
    "fälgborstars": "fälgborste",
    "fälgborsten": "fälgborste",
    "fälgborstens": "fälgborste",
    "fälgborstes": "fälgborste",
    "fälgen": "fälg",
    "fälgens": "fälg",
    "fälgkorsen": "fälgkors",
    "fälgkorsens": "fälgkors",
    "fälgkorset": "fälgkors",
    "fälgkorsets": "fälgkors",
    "fälgrengöringen": "fälgrengöring",
    "fälgrengöringens": "fälgrengöring",
    "fälgrengörings": "fälgrengöring",
    "fälgs": "fälg",
    "fälgtvätten": "fälgtvätt",
    "fälgtvättens": "fälgtvätt",
    "fälgtvätts": "fälgtvätt",
    "fäll": "fälla",
    "fällan": "fälla",
    "fällande": "fälla",
    "fällanden": "fällande",
    "fällandena": "fällande",
    "fällandenas": "fällande",
    "fällandens": "fällande",
    "fällandes": "fällande",
    "fällandet": "fällande",
    "fällandets": "fällande",
    "fällans": "fälla",
    "fällar": "fäll",
    "fällarna": "fäll",
    "fällarnas": "fäll",
    "fällars": "fäll",
    "fällas": "fälla",
    "fällbara": "fällbar",
    "fällbarare": "fällbar",
    "fällbarares": "fällbar",
    "fällbaras": "fällbar",
    "fällbarast": "fällbar",
    "fällbaraste": "fällbar",
    "fällbarastes": "fällbar",
    "fällbarasts": "fällbar",
    "fällbare": "fällbar",
    "fällbares": "fällbar",
    "fällbarheten": "fällbarhet",
    "fällbarhetens": "fällbarhet",
    "fällbarhets": "fällbarhet",
    "fällbars": "fällbar",
    "fällbart": "fällbar",
    "fällbarts": "fällbar",
    "fälld": "fälla",
    "fällda": "fälla",
    "fälldas": "fälla",
    "fällde": "fälla",
    "fälldes": "fälla",
    "fällds": "fälla",
    "fälle": "fälla",
    "fällen": "fäll",
    "fällens": "fäll",
    "fäller": "fälla",
    "fälles": "fälla",
    "fällkilar": "fällkil",
    "fällkilarna": "fällkil",
    "fällkilarnas": "fällkil",
    "fällkilars": "fällkil",
    "fällkilen": "fällkil",
    "fällkilens": "fällkil",
    "fällkils": "fällkil",
    "fällknivar": "fällkniv",
    "fällknivarna": "fällkniv",
    "fällknivarnas": "fällkniv",
    "fällknivars": "fällkniv",
    "fällkniven": "fällkniv",
    "fällknivens": "fällkniv",
    "fällknivs": "fällkniv",
    "fällkölar": "fällköl",
    "fällkölarna": "fällköl",
    "fällkölarnas": "fällköl",
    "fällkölars": "fällköl",
    "fällkölen": "fällköl",
    "fällkölens": "fällköl",
    "fällköls": "fällköl",
    "fällningar": "fällning",
    "fällningarna": "fällning",
    "fällningarnas": "fällning",
    "fällningars": "fällning",
    "fällningen": "fällning",
    "fällningens": "fällning",
    "fällnings": "fällning",
    "fällor": "fälla",
    "fällorna": "fälla",
    "fällornas": "fälla",
    "fällors": "fälla",
    "fälls": "fälla",
    "fällstolar": "fällstol",
    "fällstolarna": "fällstol",
    "fällstolarnas": "fällstol",
    "fällstolars": "fällstol",
    "fällstolen": "fällstol",
    "fällstolens": "fällstol",
    "fällstols": "fällstol",
    "fällt": "fälla",
    "fällts": "fälla",
    "fältarbeten": "fältarbete",
    "fältarbetena": "fältarbete",
    "fältarbetenas": "fältarbete",
    "fältarbetens": "fältarbete",
    "fältarbetes": "fältarbete",
    "fältarbetet": "fältarbete",
    "fältarbetets": "fältarbete",
    "fältarbets": "fältarbete",
    "fältarméer": "fältarmé",
    "fältarméerna": "fältarmé",
    "fältarméernas": "fältarmé",
    "fältarméers": "fältarmé",
    "fältarmén": "fältarmé",
    "fältarméns": "fältarmé",
    "fältarmés": "fältarmé",
    "fältartilleriet": "fältartilleri",
    "fältartilleriets": "fältartilleri",
    "fältartilleris": "fältartilleri",
    "fältartillerit": "fältartilleri",
    "fältartillerits": "fältartilleri",
    "fältassistenten": "fältassistent",
    "fältassistentens": "fältassistent",
    "fältassistenter": "fältassistent",
    "fältassistenterna": "fältassistent",
    "fältassistenternas": "fältassistent",
    "fältassistenters": "fältassistent",
    "fältassistents": "fältassistent",
    "fältbegravningar": "fältbegravning",
    "fältbegravningarna": "fältbegravning",
    "fältbegravningarnas": "fältbegravning",
    "fältbegravningars": "fältbegravning",
    "fältbegravningen": "fältbegravning",
    "fältbegravningens": "fältbegravning",
    "fältbegravnings": "fältbegravning",
    "fältbiologen": "fältbiolog",
    "fältbiologens": "fältbiolog",
    "fältbiologer": "fältbiolog",
    "fältbiologerna": "fältbiolog",
    "fältbiologernas": "fältbiolog",
    "fältbiologers": "fältbiolog",
    "fältbiologien": "fältbiologi",
    "fältbiologiens": "fältbiologi",
    "fältbiologin": "fältbiologi",
    "fältbiologins": "fältbiologi",
    "fältbiologis": "fältbiologi",
    "fältbiologs": "fältbiolog",
    "fälten": "fält",
    "fältens": "fält",
    "fältet": "fält",
    "fältets": "fält",
    "fältflask": "fältflaska",
    "fältflaskan": "fältflaska",
    "fältflaskans": "fältflaska",
    "fältflaskas": "fältflaska",
    "fältflaske": "fältflaska",
    "fältflaskor": "fältflaska",
    "fältflaskorna": "fältflaska",
    "fältflaskornas": "fältflaska",
    "fältflaskors": "fältflaska",
    "fältflygar": "fältflygare",
    "fältflygaren": "fältflygare",
    "fältflygarens": "fältflygare",
    "fältflygares": "fältflygare",
    "fältflygarna": "fältflygare",
    "fältflygarnas": "fältflygare",
    "fältförsöken": "fältförsök",
    "fältförsökens": "fältförsök",
    "fältförsöket": "fältförsök",
    "fältförsökets": "fältförsök",
    "fältförsöks": "fältförsök",
    "fältgråa": "fältgrå",
    "fältgråare": "fältgrå",
    "fältgråares": "fältgrå",
    "fältgråas": "fältgrå",
    "fältgråast": "fältgrå",
    "fältgråaste": "fältgrå",
    "fältgråastes": "fältgrå",
    "fältgråasts": "fältgrå",
    "fältgråe": "fältgrå",
    "fältgråes": "fältgrå",
    "fältgrås": "fältgrå",
    "fältgrått": "fältgrå",
    "fältgråtts": "fältgrå",
    "fälthar": "fälthare",
    "fältharar": "fälthare",
    "fälthararna": "fälthare",
    "fälthararnas": "fälthare",
    "fältharars": "fälthare",
    "fältharen": "fälthare",
    "fältharens": "fälthare",
    "fälthares": "fälthare",
    "fälthars": "fälthare",
    "fältherrar": "fältherre",
    "fältherrarna": "fältherre",
    "fältherrarnas": "fältherre",
    "fältherrars": "fältherre",
    "fältherren": "fältherre",
    "fältherrens": "fältherre",
    "fältherres": "fältherre",
    "fälthönsen": "fälthöns",
    "fälthönsens": "fälthöns",
    "fälthönset": "fälthöns",
    "fälthönsets": "fälthöns",
    "fältjägar": "fältjägare",
    "fältjägaren": "fältjägare",
    "fältjägarens": "fältjägare",
    "fältjägares": "fältjägare",
    "fältjägarna": "fältjägare",
    "fältjägarnas": "fältjägare",
    "fältkikar": "fältkikare",
    "fältkikaren": "fältkikare",
    "fältkikarens": "fältkikare",
    "fältkikares": "fältkikare",
    "fältkikarna": "fältkikare",
    "fältkikarnas": "fältkikare",
    "fältmarskalkar": "fältmarskalk",
    "fältmarskalkarna": "fältmarskalk",
    "fältmarskalkarnas": "fältmarskalk",
    "fältmarskalkars": "fältmarskalk",
    "fältmarskalken": "fältmarskalk",
    "fältmarskalkens": "fältmarskalk",
    "fältmarskalks": "fältmarskalk",
    "fältmässiga": "fältmässig",
    "fältmässigare": "fältmässig",
    "fältmässigares": "fältmässig",
    "fältmässigas": "fältmässig",
    "fältmässigast": "fältmässig",
    "fältmässigaste": "fältmässig",
    "fältmässigastes": "fältmässig",
    "fältmässigasts": "fältmässig",
    "fältmässige": "fältmässig",
    "fältmässiges": "fältmässig",
    "fältmässigheten": "fältmässighet",
    "fältmässighetens": "fältmässighet",
    "fältmässighets": "fältmässighet",
    "fältmässigs": "fältmässig",
    "fältmässigt": "fältmässig",
    "fältmässigts": "fältmässig",
    "fältmätningar": "fältmätning",
    "fältmätningarna": "fältmätning",
    "fältmätningarnas": "fältmätning",
    "fältmätningars": "fältmätning",
    "fältmätningen": "fältmätning",
    "fältmätningens": "fältmätning",
    "fältmätnings": "fältmätning",
    "fältpostcensuren": "fältpostcensur",
    "fältpostcensurens": "fältpostcensur",
    "fältpostcensurs": "fältpostcensur",
    "fältposten": "fältpost",
    "fältpostens": "fältpost",
    "fältposts": "fältpost",
    "fältprästen": "fältpräst",
    "fältprästens": "fältpräst",
    "fältpräster": "fältpräst",
    "fältprästerna": "fältpräst",
    "fältprästernas": "fältpräst",
    "fältprästers": "fältpräst",
    "fältprästs": "fältpräst",
    "fältropen": "fältrop",
    "fältropens": "fältrop",
    "fältropet": "fältrop",
    "fältropets": "fältrop",
    "fältrops": "fältrop",
    "fälts": "fält",
    "fältsjukhusen": "fältsjukhus",
    "fältsjukhusens": "fältsjukhus",
    "fältsjukhuset": "fältsjukhus",
    "fältsjukhusets": "fältsjukhus",
    "fältskyttes": "fältskytte",
    "fältskyttet": "fältskytte",
    "fältskyttets": "fältskytte",
    "fältskären": "fältskär",
    "fältskärens": "fältskär",
    "fältskärer": "fältskär",
    "fältskärerna": "fältskär",
    "fältskärernas": "fältskär",
    "fältskärers": "fältskär",
    "fältskärn": "fältskär",
    "fältskärns": "fältskär",
    "fältskärs": "fältskär",
    "fältslagen": "fältslag",
    "fältslagens": "fältslag",
    "fältslaget": "fältslag",
    "fältslagets": "fältslag",
    "fältslags": "fältslag",
    "fältspaten": "fältspat",
    "fältspatens": "fältspat",
    "fältspater": "fältspat",
    "fältspaterna": "fältspat",
    "fältspaternas": "fältspat",
    "fältspaters": "fältspat",
    "fältspats": "fältspat",
    "fältstudie": "fältstudium",
    "fältstudier": "fältstudium",
    "fältstudierna": "fältstudium",
    "fältstudiernas": "fältstudium",
    "fältstudiers": "fältstudium",
    "fältstudiet": "fältstudium",
    "fältstudiets": "fältstudium",
    "fältstudiums": "fältstudium",
    "fältstyrkan": "fältstyrka",
    "fältstyrkans": "fältstyrka",
    "fältstyrkas": "fältstyrka",
    "fältstyrke": "fältstyrka",
    "fältstyrkor": "fältstyrka",
    "fältstyrkorna": "fältstyrka",
    "fältstyrkornas": "fältstyrka",
    "fältstyrkors": "fältstyrka",
    "fältteckens": "fälttecken",
    "fälttecknen": "fälttecken",
    "fälttecknens": "fälttecken",
    "fälttecknet": "fälttecken",
    "fälttecknets": "fälttecken",
    "fälttjänsten": "fälttjänst",
    "fälttjänstens": "fälttjänst",
    "fälttjänstgöringar": "fälttjänstgöring",
    "fälttjänstgöringarna": "fälttjänstgöring",
    "fälttjänstgöringarnas": "fälttjänstgöring",
    "fälttjänstgöringars": "fälttjänstgöring",
    "fälttjänstgöringen": "fälttjänstgöring",
    "fälttjänstgöringens": "fälttjänstgöring",
    "fälttjänstgörings": "fälttjänstgöring",
    "fälttjänsts": "fälttjänst",
    "fälttjänstövningar": "fälttjänstövning",
    "fälttjänstövningarna": "fälttjänstövning",
    "fälttjänstövningarnas": "fälttjänstövning",
    "fälttjänstövningars": "fälttjänstövning",
    "fälttjänstövningen": "fälttjänstövning",
    "fälttjänstövningens": "fälttjänstövning",
    "fälttjänstövnings": "fälttjänstövning",
    "fälttävlans": "fälttävlan",
    "fälttävlningar": "fälttävlan",
    "fälttävlningarna": "fälttävlan",
    "fälttävlningarnas": "fälttävlan",
    "fälttävlningars": "fälttävlan",
    "fälttågen": "fälttåg",
    "fälttågens": "fälttåg",
    "fälttåget": "fälttåg",
    "fälttågets": "fälttåg",
    "fälttågs": "fälttåg",
    "fälttågsplane": "fälttågsplan",
    "fälttågsplanen": "fälttågsplan",
    "fälttågsplanens": "fälttågsplan",
    "fälttågsplaner": "fälttågsplan",
    "fälttågsplanerna": "fälttågsplan",
    "fälttågsplanernas": "fälttågsplan",
    "fälttågsplaners": "fälttågsplan",
    "fälttågsplans": "fälttågsplan",
    "fältuniformen": "fältuniform",
    "fältuniformens": "fältuniform",
    "fältuniformer": "fältuniform",
    "fältuniformerna": "fältuniform",
    "fältuniformernas": "fältuniform",
    "fältuniformers": "fältuniform",
    "fältuniforms": "fältuniform",
    "fän": "fä",
    "fäna": "fä",
    "fänaden": "fänad",
    "fänadens": "fänad",
    "fänader": "fänad",
    "fänaderna": "fänad",
    "fänadernas": "fänad",
    "fänaders": "fänad",
    "fänads": "fänad",
    "fänas": "fä",
    "fängelsecellen": "fängelsecell",
    "fängelsecellens": "fängelsecell",
    "fängelseceller": "fängelsecell",
    "fängelsecellerna": "fängelsecell",
    "fängelsecellernas": "fängelsecell",
    "fängelsecellers": "fängelsecell",
    "fängelsecells": "fängelsecell",
    "fängelsechefen": "fängelsechef",
    "fängelsechefens": "fängelsechef",
    "fängelsechefer": "fängelsechef",
    "fängelsecheferna": "fängelsechef",
    "fängelsechefernas": "fängelsechef",
    "fängelsechefers": "fängelsechef",
    "fängelsechefs": "fängelsechef",
    "fängelsedomar": "fängelsedom",
    "fängelsedomarna": "fängelsedom",
    "fängelsedomarnas": "fängelsedom",
    "fängelsedomars": "fängelsedom",
    "fängelsedomen": "fängelsedom",
    "fängelsedomens": "fängelsedom",
    "fängelsedoms": "fängelsedom",
    "fängelsedömde": "fängelsedömd",
    "fängelsedömdes": "fängelsedömd",
    "fängelsedömds": "fängelsedömd",
    "fängelsedömt": "fängelsedömd",
    "fängelsedömts": "fängelsedömd",
    "fängelseförhållanden": "fängelseförhållande",
    "fängelseförhållandena": "fängelseförhållande",
    "fängelseförhållandenas": "fängelseförhållande",
    "fängelseförhållandens": "fängelseförhållande",
    "fängelseförhållandes": "fängelseförhållande",
    "fängelseförhållandet": "fängelseförhållande",
    "fängelseförhållandets": "fängelseförhållande",
    "fängelsekunden": "fängelsekund",
    "fängelsekundens": "fängelsekund",
    "fängelsekunder": "fängelsekund",
    "fängelsekunderna": "fängelsekund",
    "fängelsekundernas": "fängelsekund",
    "fängelsekunders": "fängelsekund",
    "fängelsekunds": "fängelsekund",
    "fängelser": "fängelse",
    "fängelserna": "fängelse",
    "fängelsernas": "fängelse",
    "fängelsers": "fängelse",
    "fängelses": "fängelse",
    "fängelsestraffen": "fängelsestraff",
    "fängelsestraffens": "fängelsestraff",
    "fängelsestraffet": "fängelsestraff",
    "fängelsestraffets": "fängelsestraff",
    "fängelsestraffs": "fängelsestraff",
    "fängelset": "fängelse",
    "fängelsets": "fängelse",
    "fänghålen": "fänghål",
    "fänghålens": "fänghål",
    "fänghålet": "fänghål",
    "fänghålets": "fänghål",
    "fänghåls": "fänghål",
    "fängsels": "fängsel",
    "fängslad": "fängsla",
    "fängslade": "fängsla",
    "fängslades": "fängsla",
    "fängslads": "fängsla",
    "fängslande": "fängsla",
    "fängslanden": "fängslande",
    "fängslandena": "fängslande",
    "fängslandenas": "fängslande",
    "fängslandens": "fängslande",
    "fängslandes": "fängslande",
    "fängslandet": "fängslande",
    "fängslandets": "fängslande",
    "fängslar": "fängsla",
    "fängslas": "fängsla",
    "fängslat": "fängsla",
    "fängslats": "fängsla",
    "fängslen": "fängsel",
    "fängslens": "fängsel",
    "fängslet": "fängsel",
    "fängslets": "fängsel",
    "fänkålen": "fänkål",
    "fänkålens": "fänkål",
    "fänkåls": "fänkål",
    "fänrikar": "fänrik",
    "fänrikarna": "fänrik",
    "fänrikarnas": "fänrik",
    "fänrikars": "fänrik",
    "fänriken": "fänrik",
    "fänrikens": "fänrik",
    "fänriks": "fänrik",
    "fäns": "fä",
    "färdades": "färdas",
    "färdats": "färdas",
    "färdbevisen": "färdbevis",
    "färdbevisens": "färdbevis",
    "färdbeviset": "färdbevis",
    "färdbevisets": "färdbevis",
    "färdbiljetten": "färdbiljett",
    "färdbiljettens": "färdbiljett",
    "färdbiljetter": "färdbiljett",
    "färdbiljetterna": "färdbiljett",
    "färdbiljetternas": "färdbiljett",
    "färdbiljetters": "färdbiljett",
    "färdbiljetts": "färdbiljett",
    "färden": "färd",
    "färdens": "färd",
    "färder": "färd",
    "färderna": "färd",
    "färdernas": "färd",
    "färders": "färd",
    "färdiga": "färdig",
    "färdigare": "färdig",
    "färdigares": "färdig",
    "färdigas": "färdig",
    "färdigast": "färdig",
    "färdigaste": "färdig",
    "färdigastes": "färdig",
    "färdigasts": "färdig",
    "färdigbildade": "färdigbildad",
    "färdigbildades": "färdigbildad",
    "färdigbildads": "färdigbildad",
    "färdigbildat": "färdigbildad",
    "färdigbildats": "färdigbildad",
    "färdige": "färdig",
    "färdiges": "färdig",
    "färdigheten": "färdighet",
    "färdighetens": "färdighet",
    "färdigheter": "färdighet",
    "färdigheterna": "färdighet",
    "färdigheternas": "färdighet",
    "färdigheters": "färdighet",
    "färdighets": "färdighet",
    "färdighetsträningar": "färdighetsträning",
    "färdighetsträningarna": "färdighetsträning",
    "färdighetsträningarnas": "färdighetsträning",
    "färdighetsträningars": "färdighetsträning",
    "färdighetsträningen": "färdighetsträning",
    "färdighetsträningens": "färdighetsträning",
    "färdighetstränings": "färdighetsträning",
    "färdighetsämnen": "färdighetsämne",
    "färdighetsämnena": "färdighetsämne",
    "färdighetsämnenas": "färdighetsämne",
    "färdighetsämnens": "färdighetsämne",
    "färdighetsämnes": "färdighetsämne",
    "färdighetsämnet": "färdighetsämne",
    "färdighetsämnets": "färdighetsämne",
    "färdigkämpade": "färdigkämpad",
    "färdigkämpades": "färdigkämpad",
    "färdigkämpads": "färdigkämpad",
    "färdigkämpat": "färdigkämpad",
    "färdigkämpats": "färdigkämpad",
    "färdiglagade": "färdiglagad",
    "färdiglagades": "färdiglagad",
    "färdiglagads": "färdiglagad",
    "färdiglagat": "färdiglagad",
    "färdiglagats": "färdiglagad",
    "färdigmaten": "färdigmat",
    "färdigmatens": "färdigmat",
    "färdigmats": "färdigmat",
    "färdigs": "färdig",
    "färdigskulpterade": "färdigskulpterad",
    "färdigskulpterades": "färdigskulpterad",
    "färdigskulpterads": "färdigskulpterad",
    "färdigskulpterat": "färdigskulpterad",
    "färdigskulpterats": "färdigskulpterad",
    "färdigställ": "färdigställa",
    "färdigställande": "färdigställa",
    "färdigställanden": "färdigställande",
    "färdigställandena": "färdigställande",
    "färdigställandenas": "färdigställande",
    "färdigställandens": "färdigställande",
    "färdigställandes": "färdigställande",
    "färdigställandet": "färdigställande",
    "färdigställandets": "färdigställande",
    "färdigställas": "färdigställa",
    "färdigställd": "färdigställa",
    "färdigställda": "färdigställa",
    "färdigställdas": "färdigställa",
    "färdigställde": "färdigställa",
    "färdigställdes": "färdigställa",
    "färdigställds": "färdigställa",
    "färdigställer": "färdigställa",
    "färdigställes": "färdigställa",
    "färdigställs": "färdigställa",
    "färdigställt": "färdigställa",
    "färdigställts": "färdigställa",
    "färdigt": "färdig",
    "färdigts": "färdig",
    "färdigutbildade": "färdigutbildad",
    "färdigutbildades": "färdigutbildad",
    "färdigutbildads": "färdigutbildad",
    "färdigutbildat": "färdigutbildad",
    "färdigutbildats": "färdigutbildad",
    "färdigutvecklade": "färdigutvecklad",
    "färdigutvecklades": "färdigutvecklad",
    "färdigutvecklads": "färdigutvecklad",
    "färdigutvecklat": "färdigutvecklad",
    "färdigutvecklats": "färdigutvecklad",
    "färdknäppar": "färdknäpp",
    "färdknäpparna": "färdknäpp",
    "färdknäpparnas": "färdknäpp",
    "färdknäppars": "färdknäpp",
    "färdknäppen": "färdknäpp",
    "färdknäppens": "färdknäpp",
    "färdknäpps": "färdknäpp",
    "färdkosten": "färdkost",
    "färdkostens": "färdkost",
    "färdkosts": "färdkost",
    "färdledar": "färdledare",
    "färdledaren": "färdledare",
    "färdledarens": "färdledare",
    "färdledares": "färdledare",
    "färdledarna": "färdledare",
    "färdledarnas": "färdledare",
    "färdleden": "färdled",
    "färdledens": "färdled",
    "färdleder": "färdled",
    "färdlederna": "färdled",
    "färdledernas": "färdled",
    "färdleders": "färdled",
    "färdleds": "färdled",
    "färdmedels": "färdmedel",
    "färdmedlen": "färdmedel",
    "färdmedlens": "färdmedel",
    "färdmedlet": "färdmedel",
    "färdmedlets": "färdmedel",
    "färdriktningar": "färdriktning",
    "färdriktningarna": "färdriktning",
    "färdriktningarnas": "färdriktning",
    "färdriktningars": "färdriktning",
    "färdriktningen": "färdriktning",
    "färdriktningens": "färdriktning",
    "färdriktnings": "färdriktning",
    "färds": "färd",
    "färdskrivar": "färdskrivare",
    "färdskrivaren": "färdskrivare",
    "färdskrivarens": "färdskrivare",
    "färdskrivares": "färdskrivare",
    "färdskrivarna": "färdskrivare",
    "färdskrivarnas": "färdskrivare",
    "färdtjänsten": "färdtjänst",
    "färdtjänstens": "färdtjänst",
    "färdtjänsts": "färdtjänst",
    "färdvägar": "färdväg",
    "färdvägarna": "färdväg",
    "färdvägarnas": "färdväg",
    "färdvägars": "färdväg",
    "färdvägen": "färdväg",
    "färdvägens": "färdväg",
    "färdvägs": "färdväg",
    "färg": "färga",
    "färg-TV-s": "färg-TV",
    "färg-TV:s": "färg-TV",
    "färg-TVs": "färg-TV",
    "färgad": "färga",
    "färgade": "färgad",
    "färgades": "färgad",
    "färgads": "färgad",
    "färgande": "färga",
    "färganden": "färgande",
    "färgandena": "färgande",
    "färgandenas": "färgande",
    "färgandens": "färgande",
    "färgandes": "färgande",
    "färgandet": "färgande",
    "färgandets": "färgande",
    "färgar": "färga",
    "färgas": "färga",
    "färgat": "färgad",
    "färgats": "färgad",
    "färgbaden": "färgbad",
    "färgbadens": "färgbad",
    "färgbadet": "färgbad",
    "färgbadets": "färgbad",
    "färgbads": "färgbad",
    "färgbanden": "färgband",
    "färgbandens": "färgband",
    "färgbandet": "färgband",
    "färgbandets": "färgband",
    "färgbands": "färgband",
    "färgbeständiga": "färgbeständig",
    "färgbeständigare": "färgbeständig",
    "färgbeständigares": "färgbeständig",
    "färgbeständigas": "färgbeständig",
    "färgbeständigast": "färgbeständig",
    "färgbeständigaste": "färgbeständig",
    "färgbeständigastes": "färgbeständig",
    "färgbeständigasts": "färgbeständig",
    "färgbeständige": "färgbeständig",
    "färgbeständiges": "färgbeständig",
    "färgbeständigheten": "färgbeständighet",
    "färgbeständighetens": "färgbeständighet",
    "färgbeständighets": "färgbeständighet",
    "färgbeständigs": "färgbeständig",
    "färgbeständigt": "färgbeständig",
    "färgbeständigts": "färgbeständig",
    "färgbilden": "färgbild",
    "färgbildens": "färgbild",
    "färgbilder": "färgbild",
    "färgbilderna": "färgbild",
    "färgbildernas": "färgbild",
    "färgbilders": "färgbild",
    "färgbilds": "färgbild",
    "färgblandningar": "färgblandning",
    "färgblandningarna": "färgblandning",
    "färgblandningarnas": "färgblandning",
    "färgblandningars": "färgblandning",
    "färgblandningen": "färgblandning",
    "färgblandningens": "färgblandning",
    "färgblandnings": "färgblandning",
    "färgblinda": "färgblind",
    "färgblindare": "färgblind",
    "färgblindares": "färgblind",
    "färgblindas": "färgblind",
    "färgblindast": "färgblind",
    "färgblindaste": "färgblind",
    "färgblindastes": "färgblind",
    "färgblindasts": "färgblind",
    "färgblinde": "färgblind",
    "färgblindes": "färgblind",
    "färgblindheten": "färgblindhet",
    "färgblindhetens": "färgblindhet",
    "färgblindhets": "färgblindhet",
    "färgblinds": "färgblind",
    "färgblint": "färgblind",
    "färgblints": "färgblind",
    "färgborttagningen": "färgborttagning",
    "färgborttagningens": "färgborttagning",
    "färgborttagnings": "färgborttagning",
    "färgdelade": "färgdelad",
    "färgdelades": "färgdelad",
    "färgdelads": "färgdelad",
    "färgdelat": "färgdelad",
    "färgdelats": "färgdelad",
    "färgen": "färg",
    "färgens": "färg",
    "färger": "färg",
    "färgerier": "färgeri",
    "färgerierna": "färgeri",
    "färgeriernas": "färgeri",
    "färgeriers": "färgeri",
    "färgeriet": "färgeri",
    "färgeriets": "färgeri",
    "färgeris": "färgeri",
    "färgerit": "färgeri",
    "färgerits": "färgeri",
    "färgerna": "färg",
    "färgernas": "färg",
    "färgers": "färg",
    "färgfilmen": "färgfilm",
    "färgfilmens": "färgfilm",
    "färgfilmer": "färgfilm",
    "färgfilmerna": "färgfilm",
    "färgfilmernas": "färgfilm",
    "färgfilmers": "färgfilm",
    "färgfilms": "färgfilm",
    "färgfilterna": "färgfilter",
    "färgfilternas": "färgfilter",
    "färgfilters": "färgfilter",
    "färgfiltren": "färgfilter",
    "färgfiltrens": "färgfilter",
    "färgfiltret": "färgfilter",
    "färgfiltrets": "färgfilter",
    "färgfläckar": "färgfläck",
    "färgfläckarna": "färgfläck",
    "färgfläckarnas": "färgfläck",
    "färgfläckars": "färgfläck",
    "färgfläcken": "färgfläck",
    "färgfläckens": "färgfläck",
    "färgfläcks": "färgfläck",
    "färgförändringar": "färgförändring",
    "färgförändringarna": "färgförändring",
    "färgförändringarnas": "färgförändring",
    "färgförändringars": "färgförändring",
    "färgförändringen": "färgförändring",
    "färgförändringens": "färgförändring",
    "färgförändrings": "färgförändring",
    "färgglada": "färgglad",
    "färggladare": "färgglad",
    "färggladares": "färgglad",
    "färggladas": "färgglad",
    "färggladast": "färgglad",
    "färggladaste": "färgglad",
    "färggladastes": "färgglad",
    "färggladasts": "färgglad",
    "färgglade": "färgglad",
    "färgglades": "färgglad",
    "färgglads": "färgglad",
    "färgglansen": "färgglans",
    "färgglansens": "färgglans",
    "färgglatt": "färgglad",
    "färgglatts": "färgglad",
    "färggranna": "färggrann",
    "färggrannare": "färggrann",
    "färggrannares": "färggrann",
    "färggrannas": "färggrann",
    "färggrannast": "färggrann",
    "färggrannaste": "färggrann",
    "färggrannastes": "färggrann",
    "färggrannasts": "färggrann",
    "färggranne": "färggrann",
    "färggrannes": "färggrann",
    "färggrannheten": "färggrannhet",
    "färggrannhetens": "färggrannhet",
    "färggrannhets": "färggrannhet",
    "färggranns": "färggrann",
    "färggrant": "färggrann",
    "färggrants": "färggrann",
    "färghandeln": "färghandel",
    "färghandelns": "färghandel",
    "färghandels": "färghandel",
    "färghandlar": "färghandel",
    "färghandlarna": "färghandel",
    "färghandlarnas": "färghandel",
    "färghandlars": "färghandel",
    "färgklickar": "färgklick",
    "färgklickarna": "färgklick",
    "färgklickarnas": "färgklick",
    "färgklickars": "färgklick",
    "färgklicken": "färgklick",
    "färgklickens": "färgklick",
    "färgklicks": "färgklick",
    "färgkonstansen": "färgkonstans",
    "färgkonstansens": "färgkonstans",
    "färgkontrasten": "färgkontrast",
    "färgkontrastens": "färgkontrast",
    "färgkontraster": "färgkontrast",
    "färgkontrasterna": "färgkontrast",
    "färgkontrasternas": "färgkontrast",
    "färgkontrasters": "färgkontrast",
    "färgkontrasts": "färgkontrast",
    "färgkrit": "färgkrita",
    "färgkritan": "färgkrita",
    "färgkritans": "färgkrita",
    "färgkritas": "färgkrita",
    "färgkrite": "färgkrita",
    "färgkritor": "färgkrita",
    "färgkritorna": "färgkrita",
    "färgkritornas": "färgkrita",
    "färgkritors": "färgkrita",
    "färgkrits": "färgkrita",
    "färgkänsliga": "färgkänslig",
    "färgkänsligare": "färgkänslig",
    "färgkänsligares": "färgkänslig",
    "färgkänsligas": "färgkänslig",
    "färgkänsligast": "färgkänslig",
    "färgkänsligaste": "färgkänslig",
    "färgkänsligastes": "färgkänslig",
    "färgkänsligasts": "färgkänslig",
    "färgkänslige": "färgkänslig",
    "färgkänsliges": "färgkänslig",
    "färgkänsligheten": "färgkänslighet",
    "färgkänslighetens": "färgkänslighet",
    "färgkänsligheter": "färgkänslighet",
    "färgkänsligheterna": "färgkänslighet",
    "färgkänsligheternas": "färgkänslighet",
    "färgkänsligheters": "färgkänslighet",
    "färgkänslighets": "färgkänslighet",
    "färgkänsligs": "färgkänslig",
    "färgkänsligt": "färgkänslig",
    "färgkänsligts": "färgkänslig",
    "färgla": "färglägga",
    "färglade": "färglägga",
    "färglades": "färglägga",
    "färglagd": "färglägga",
    "färglagda": "färglägga",
    "färglagdas": "färglägga",
    "färglagde": "färglägga",
    "färglagdes": "färglägga",
    "färglagds": "färglägga",
    "färglagt": "färglägga",
    "färglagts": "färglägga",
    "färglas": "färglägga",
    "färglitografien": "färglitografi",
    "färglitografiens": "färglitografi",
    "färglitografier": "färglitografi",
    "färglitografierna": "färglitografi",
    "färglitografiernas": "färglitografi",
    "färglitografiers": "färglitografi",
    "färglitografin": "färglitografi",
    "färglitografins": "färglitografi",
    "färglitografis": "färglitografi",
    "färglägg": "färglägga",
    "färgläggande": "färglägga",
    "färglägganden": "färgläggande",
    "färgläggandena": "färgläggande",
    "färgläggandenas": "färgläggande",
    "färgläggandens": "färgläggande",
    "färgläggandes": "färgläggande",
    "färgläggandet": "färgläggande",
    "färgläggandets": "färgläggande",
    "färgläggas": "färglägga",
    "färglägger": "färglägga",
    "färglägges": "färglägga",
    "färgläggs": "färglägga",
    "färglåd": "färglåda",
    "färglådan": "färglåda",
    "färglådans": "färglåda",
    "färglådas": "färglåda",
    "färglåde": "färglåda",
    "färglådor": "färglåda",
    "färglådorna": "färglåda",
    "färglådornas": "färglåda",
    "färglådors": "färglåda",
    "färglåds": "färglåda",
    "färglösa": "färglös",
    "färglösare": "färglös",
    "färglösares": "färglös",
    "färglösas": "färglös",
    "färglösast": "färglös",
    "färglösaste": "färglös",
    "färglösastes": "färglös",
    "färglösasts": "färglös",
    "färglöse": "färglös",
    "färglöses": "färglös",
    "färglösheten": "färglöshet",
    "färglöshetens": "färglöshet",
    "färglöshets": "färglöshet",
    "färglöst": "färglös",
    "färglösts": "färglös",
    "färgmässiga": "färgmässig",
    "färgmässigare": "färgmässig",
    "färgmässigares": "färgmässig",
    "färgmässigas": "färgmässig",
    "färgmässigast": "färgmässig",
    "färgmässigaste": "färgmässig",
    "färgmässigastes": "färgmässig",
    "färgmässigasts": "färgmässig",
    "färgmässige": "färgmässig",
    "färgmässiges": "färgmässig",
    "färgmässigs": "färgmässig",
    "färgmässigt": "färgmässig",
    "färgmässigts": "färgmässig",
    "färgmönsterna": "färgmönster",
    "färgmönsternas": "färgmönster",
    "färgmönsters": "färgmönster",
    "färgmönstren": "färgmönster",
    "färgmönstrens": "färgmönster",
    "färgmönstret": "färgmönster",
    "färgmönstrets": "färgmönster",
    "färgningar": "färgning",
    "färgningarna": "färgning",
    "färgningarnas": "färgning",
    "färgningars": "färgning",
    "färgningen": "färgning",
    "färgningens": "färgning",
    "färgnings": "färgning",
    "färgpenn": "färgpenna",
    "färgpennan": "färgpenna",
    "färgpennans": "färgpenna",
    "färgpennas": "färgpenna",
    "färgpenne": "färgpenna",
    "färgpennor": "färgpenna",
    "färgpennorna": "färgpenna",
    "färgpennornas": "färgpenna",
    "färgpennors": "färgpenna",
    "färgpenns": "färgpenna",
    "färgpigmenten": "färgpigment",
    "färgpigmentens": "färgpigment",
    "färgpigmentet": "färgpigment",
    "färgpigmentets": "färgpigment",
    "färgpigments": "färgpigment",
    "färgprakten": "färgprakt",
    "färgpraktens": "färgprakt",
    "färgprakts": "färgprakt",
    "färgreproduktionen": "färgreproduktion",
    "färgreproduktionens": "färgreproduktion",
    "färgreproduktioner": "färgreproduktion",
    "färgreproduktionerna": "färgreproduktion",
    "färgreproduktionernas": "färgreproduktion",
    "färgreproduktioners": "färgreproduktion",
    "färgreproduktions": "färgreproduktion",
    "färgrika": "färgrik",
    "färgrikare": "färgrik",
    "färgrikares": "färgrik",
    "färgrikas": "färgrik",
    "färgrikast": "färgrik",
    "färgrikaste": "färgrik",
    "färgrikastes": "färgrik",
    "färgrikasts": "färgrik",
    "färgrike": "färgrik",
    "färgrikes": "färgrik",
    "färgrikheten": "färgrikhet",
    "färgrikhetens": "färgrikhet",
    "färgrikhets": "färgrikhet",
    "färgriks": "färgrik",
    "färgrikt": "färgrik",
    "färgrikts": "färgrik",
    "färgrivningar": "färgrivning",
    "färgrivningarna": "färgrivning",
    "färgrivningarnas": "färgrivning",
    "färgrivningars": "färgrivning",
    "färgrivningen": "färgrivning",
    "färgrivningens": "färgrivning",
    "färgrivnings": "färgrivning",
    "färgs": "färg",
    "färgseendes": "färgseende",
    "färgseendet": "färgseende",
    "färgseendets": "färgseende",
    "färgsinnes": "färgsinne",
    "färgsinnet": "färgsinne",
    "färgsinnets": "färgsinne",
    "färgskal": "färgskala",
    "färgskalan": "färgskala",
    "färgskalans": "färgskala",
    "färgskalas": "färgskala",
    "färgskale": "färgskala",
    "färgskallen": "färgskalle",
    "färgskallens": "färgskalle",
    "färgskalles": "färgskalle",
    "färgskalor": "färgskala",
    "färgskalorna": "färgskala",
    "färgskalornas": "färgskala",
    "färgskalors": "färgskala",
    "färgskals": "färgskala",
    "färgskrapan": "färgskrapa",
    "färgskrapans": "färgskrapa",
    "färgskrapas": "färgskrapa",
    "färgskrape": "färgskrapa",
    "färgskrapor": "färgskrapa",
    "färgskraporna": "färgskrapa",
    "färgskrapornas": "färgskrapa",
    "färgskrapors": "färgskrapa",
    "färgspektra": "färgspektrum",
    "färgspektrana": "färgspektrum",
    "färgspektranas": "färgspektrum",
    "färgspektras": "färgspektrum",
    "färgspektrena": "färgspektrum",
    "färgspektrenas": "färgspektrum",
    "färgspektrer": "färgspektrum",
    "färgspektrers": "färgspektrum",
    "färgspektret": "färgspektrum",
    "färgspektrets": "färgspektrum",
    "färgspektrumen": "färgspektrum",
    "färgspektrumens": "färgspektrum",
    "färgspektrumet": "färgspektrum",
    "färgspektrumets": "färgspektrum",
    "färgspektrums": "färgspektrum",
    "färgspelen": "färgspel",
    "färgspelens": "färgspel",
    "färgspelet": "färgspel",
    "färgspelets": "färgspel",
    "färgspels": "färgspel",
    "färgspridningar": "färgspridning",
    "färgspridningarna": "färgspridning",
    "färgspridningarnas": "färgspridning",
    "färgspridningars": "färgspridning",
    "färgspridningen": "färgspridning",
    "färgspridningens": "färgspridning",
    "färgspridnings": "färgspridning",
    "färgsprutan": "färgspruta",
    "färgsprutans": "färgspruta",
    "färgsprutas": "färgspruta",
    "färgsprute": "färgspruta",
    "färgsprutningen": "färgsprutning",
    "färgsprutningens": "färgsprutning",
    "färgsprutnings": "färgsprutning",
    "färgsprutor": "färgspruta",
    "färgsprutorna": "färgspruta",
    "färgsprutornas": "färgspruta",
    "färgsprutors": "färgspruta",
    "färgsprutpistolen": "färgsprutpistol",
    "färgsprutpistolens": "färgsprutpistol",
    "färgsprutpistoler": "färgsprutpistol",
    "färgsprutpistolerna": "färgsprutpistol",
    "färgsprutpistolernas": "färgsprutpistol",
    "färgsprutpistolers": "färgsprutpistol",
    "färgsprutpistols": "färgsprutpistol",
    "färgstarka": "färgstark",
    "färgstarkare": "färgstark",
    "färgstarkares": "färgstark",
    "färgstarkas": "färgstark",
    "färgstarkast": "färgstark",
    "färgstarkaste": "färgstark",
    "färgstarkastes": "färgstark",
    "färgstarkasts": "färgstark",
    "färgstarke": "färgstark",
    "färgstarkes": "färgstark",
    "färgstarkheten": "färgstarkhet",
    "färgstarkhetens": "färgstarkhet",
    "färgstarkhets": "färgstarkhet",
    "färgstarks": "färgstark",
    "färgstarkt": "färgstark",
    "färgstarkts": "färgstark",
    "färgstoffen": "färgstoff",
    "färgstoffens": "färgstoff",
    "färgstoffer": "färgstoff",
    "färgstofferna": "färgstoff",
    "färgstoffernas": "färgstoff",
    "färgstoffers": "färgstoff",
    "färgstoffs": "färgstoff",
    "färgsättningar": "färgsättning",
    "färgsättningarna": "färgsättning",
    "färgsättningarnas": "färgsättning",
    "färgsättningars": "färgsättning",
    "färgsättningen": "färgsättning",
    "färgsättningens": "färgsättning",
    "färgsättnings": "färgsättning",
    "färgtemperaturen": "färgtemperatur",
    "färgtemperaturens": "färgtemperatur",
    "färgtemperaturer": "färgtemperatur",
    "färgtemperaturerna": "färgtemperatur",
    "färgtemperaturernas": "färgtemperatur",
    "färgtemperaturers": "färgtemperatur",
    "färgtemperaturs": "färgtemperatur",
    "färgtevear": "färgteve",
    "färgtevearna": "färgteve",
    "färgtevearnas": "färgteve",
    "färgtevears": "färgteve",
    "färgteven": "färgteve",
    "färgtevena": "färgteve",
    "färgtevenas": "färgteve",
    "färgtevens": "färgteve",
    "färgteves": "färgteve",
    "färgtonen": "färgton",
    "färgtonens": "färgton",
    "färgtoner": "färgton",
    "färgtonerna": "färgton",
    "färgtonernas": "färgton",
    "färgtoners": "färgton",
    "färgtons": "färgton",
    "färgtrycken": "färgtryck",
    "färgtryckens": "färgtryck",
    "färgtrycket": "färgtryck",
    "färgtryckets": "färgtryck",
    "färgtrycks": "färgtryck",
    "färgämnen": "färgämne",
    "färgämnena": "färgämne",
    "färgämnenas": "färgämne",
    "färgämnens": "färgämne",
    "färgämnes": "färgämne",
    "färgämnet": "färgämne",
    "färgämnets": "färgämne",
    "färingar": "färing",
    "färingarna": "färing",
    "färingarnas": "färing",
    "färingars": "färing",
    "färingen": "färing",
    "färingens": "färing",
    "färings": "färing",
    "färj": "färja",
    "färjad": "färja",
    "färjade": "färja",
    "färjades": "färja",
    "färjads": "färja",
    "färjan": "färja",
    "färjande": "färja",
    "färjanden": "färjande",
    "färjandena": "färjande",
    "färjandenas": "färjande",
    "färjandens": "färjande",
    "färjandes": "färjande",
    "färjandet": "färjande",
    "färjandets": "färjande",
    "färjans": "färja",
    "färjar": "färja",
    "färjas": "färja",
    "färjat": "färja",
    "färjats": "färja",
    "färje": "färja",
    "färjeankomsten": "färjeankomst",
    "färjeankomstens": "färjeankomst",
    "färjeankomster": "färjeankomst",
    "färjeankomsterna": "färjeankomst",
    "färjeankomsternas": "färjeankomst",
    "färjeankomsters": "färjeankomst",
    "färjeankomsts": "färjeankomst",
    "färjeavgångar": "färjeavgång",
    "färjeavgångarna": "färjeavgång",
    "färjeavgångarnas": "färjeavgång",
    "färjeavgångars": "färjeavgång",
    "färjeavgången": "färjeavgång",
    "färjeavgångens": "färjeavgång",
    "färjeavgångs": "färjeavgång",
    "färjelägen": "färjeläge",
    "färjelägena": "färjeläge",
    "färjelägenas": "färjeläge",
    "färjelägenheten": "färjelägenhet",
    "färjelägenhetens": "färjelägenhet",
    "färjelägenheter": "färjelägenhet",
    "färjelägenheterna": "färjelägenhet",
    "färjelägenheternas": "färjelägenhet",
    "färjelägenheters": "färjelägenhet",
    "färjelägenhets": "färjelägenhet",
    "färjelägens": "färjeläge",
    "färjeläges": "färjeläge",
    "färjeläget": "färjeläge",
    "färjelägets": "färjeläge",
    "färjeolyck": "färjeolycka",
    "färjeolyckan": "färjeolycka",
    "färjeolyckans": "färjeolycka",
    "färjeolyckas": "färjeolycka",
    "färjeolycke": "färjeolycka",
    "färjeolyckor": "färjeolycka",
    "färjeolyckorna": "färjeolycka",
    "färjeolyckornas": "färjeolycka",
    "färjeolyckors": "färjeolycka",
    "färjeolycks": "färjeolycka",
    "färjepassagerar": "färjepassagerare",
    "färjepassageraren": "färjepassagerare",
    "färjepassagerarens": "färjepassagerare",
    "färjepassagerares": "färjepassagerare",
    "färjepassagerarna": "färjepassagerare",
    "färjepassagerarnas": "färjepassagerare",
    "färjeterminalen": "färjeterminal",
    "färjeterminalens": "färjeterminal",
    "färjeterminaler": "färjeterminal",
    "färjeterminalerna": "färjeterminal",
    "färjeterminalernas": "färjeterminal",
    "färjeterminalers": "färjeterminal",
    "färjeterminals": "färjeterminal",
    "färjetidtabellen": "färjetidtabell",
    "färjetidtabellens": "färjetidtabell",
    "färjetidtabeller": "färjetidtabell",
    "färjetidtabellerna": "färjetidtabell",
    "färjetidtabellernas": "färjetidtabell",
    "färjetidtabellers": "färjetidtabell",
    "färjetidtabells": "färjetidtabell",
    "färjetrafiken": "färjetrafik",
    "färjetrafikens": "färjetrafik",
    "färjetrafiks": "färjetrafik",
    "färjetransporten": "färjetransport",
    "färjetransportens": "färjetransport",
    "färjetransporter": "färjetransport",
    "färjetransporterna": "färjetransport",
    "färjetransporternas": "färjetransport",
    "färjetransporters": "färjetransport",
    "färjetransports": "färjetransport",
    "färjeturen": "färjetur",
    "färjeturens": "färjetur",
    "färjeturer": "färjetur",
    "färjeturerna": "färjetur",
    "färjeturernas": "färjetur",
    "färjeturers": "färjetur",
    "färjeturs": "färjetur",
    "färjor": "färja",
    "färjorna": "färja",
    "färjornas": "färja",
    "färjors": "färja",
    "färl": "färla",
    "färlan": "färla",
    "färlans": "färla",
    "färlas": "färla",
    "färle": "färla",
    "färlor": "färla",
    "färlorna": "färla",
    "färlornas": "färla",
    "färlors": "färla",
    "färls": "färla",
    "färma": "färm",
    "färmare": "färm",
    "färmares": "färm",
    "färmas": "färm",
    "färmast": "färm",
    "färmaste": "färm",
    "färmastes": "färm",
    "färmasts": "färm",
    "färme": "färm",
    "färmes": "färm",
    "färmiteten": "färmitet",
    "färmitetens": "färmitet",
    "färmiteter": "färmitet",
    "färmiteterna": "färmitet",
    "färmiteternas": "färmitet",
    "färmiteters": "färmitet",
    "färmitets": "färmitet",
    "färms": "färm",
    "färmt": "färm",
    "färmts": "färm",
    "färn": "färna",
    "färnan": "färna",
    "färnans": "färna",
    "färnas": "färna",
    "färnbocken": "färnbock",
    "färnbockens": "färnbock",
    "färnbocks": "färnbock",
    "färne": "färna",
    "färnor": "färna",
    "färnorna": "färna",
    "färnornas": "färna",
    "färnors": "färna",
    "färns": "färna",
    "färre": "få",
    "färres": "få",
    "färsen": "färs",
    "färsens": "färs",
    "färser": "färs",
    "färserad": "färsera",
    "färserade": "färsera",
    "färserades": "färsera",
    "färserads": "färsera",
    "färserande": "färsera",
    "färseranden": "färserande",
    "färserandena": "färserande",
    "färserandenas": "färserande",
    "färserandens": "färserande",
    "färserandes": "färserande",
    "färserandet": "färserande",
    "färserandets": "färserande",
    "färserar": "färsera",
    "färseras": "färsera",
    "färserat": "färsera",
    "färserats": "färsera",
    "färserbara": "färserbar",
    "färserbarare": "färserbar",
    "färserbarares": "färserbar",
    "färserbaras": "färserbar",
    "färserbarast": "färserbar",
    "färserbaraste": "färserbar",
    "färserbarastes": "färserbar",
    "färserbarasts": "färserbar",
    "färserbare": "färserbar",
    "färserbares": "färserbar",
    "färserbarheten": "färserbarhet",
    "färserbarhetens": "färserbarhet",
    "färserbarhets": "färserbarhet",
    "färserbars": "färserbar",
    "färserbart": "färserbar",
    "färserbarts": "färserbar",
    "färseringar": "färsering",
    "färseringarna": "färsering",
    "färseringarnas": "färsering",
    "färseringars": "färsering",
    "färseringen": "färsering",
    "färseringens": "färsering",
    "färserings": "färsering",
    "färserna": "färs",
    "färsernas": "färs",
    "färsers": "färs",
    "färska": "färsk",
    "färskad": "färska",
    "färskade": "färska",
    "färskades": "färska",
    "färskads": "färska",
    "färskande": "färska",
    "färskanden": "färskande",
    "färskandena": "färskande",
    "färskandenas": "färskande",
    "färskandens": "färskande",
    "färskandes": "färskande",
    "färskandet": "färskande",
    "färskandets": "färskande",
    "färskar": "färska",
    "färskare": "färsk",
    "färskares": "färsk",
    "färskas": "färska",
    "färskast": "färsk",
    "färskaste": "färsk",
    "färskastes": "färsk",
    "färskasts": "färsk",
    "färskat": "färska",
    "färskats": "färska",
    "färske": "färsk",
    "färskes": "färsk",
    "färskheten": "färskhet",
    "färskhetens": "färskhet",
    "färskhets": "färskhet",
    "färskmalmen": "färskmalm",
    "färskmalmens": "färskmalm",
    "färskmalmer": "färskmalm",
    "färskmalmerna": "färskmalm",
    "färskmalmernas": "färskmalm",
    "färskmalmers": "färskmalm",
    "färskmalms": "färskmalm",
    "färskmaten": "färskmat",
    "färskmatens": "färskmat",
    "färskmats": "färskmat",
    "färskningar": "färskning",
    "färskningarna": "färskning",
    "färskningarnas": "färskning",
    "färskningars": "färskning",
    "färskningen": "färskning",
    "färskningens": "färskning",
    "färsknings": "färskning",
    "färskpotatisar": "färskpotatis",
    "färskpotatisarna": "färskpotatis",
    "färskpotatisarnas": "färskpotatis",
    "färskpotatisars": "färskpotatis",
    "färskpotatisen": "färskpotatis",
    "färskpotatisens": "färskpotatis",
    "färskpressade": "färskpressad",
    "färskpressades": "färskpressad",
    "färskpressads": "färskpressad",
    "färskpressat": "färskpressad",
    "färskpressats": "färskpressad",
    "färsks": "färsk",
    "färsksmides": "färsksmide",
    "färsksmidet": "färsksmide",
    "färsksmidets": "färsksmide",
    "färskt": "färsk",
    "färskts": "färsk",
    "färskvar": "färskvara",
    "färskvaran": "färskvara",
    "färskvarans": "färskvara",
    "färskvaras": "färskvara",
    "färskvare": "färskvara",
    "färskvaror": "färskvara",
    "färskvarorna": "färskvara",
    "färskvarornas": "färskvara",
    "färskvarors": "färskvara",
    "färskvars": "färskvara",
    "färskvarudiskar": "färskvarudisk",
    "färskvarudiskarna": "färskvarudisk",
    "färskvarudiskarnas": "färskvarudisk",
    "färskvarudiskars": "färskvarudisk",
    "färskvarudisken": "färskvarudisk",
    "färskvarudiskens": "färskvarudisk",
    "färskvarudisks": "färskvarudisk",
    "färskvattens": "färskvatten",
    "färskvattnen": "färskvatten",
    "färskvattnens": "färskvatten",
    "färskvattnet": "färskvatten",
    "färskvattnets": "färskvatten",
    "färst": "få",
    "färsta": "få",
    "färstas": "få",
    "färste": "få",
    "färstes": "få",
    "färsts": "få",
    "färöingar": "färöing",
    "färöingarna": "färöing",
    "färöingarnas": "färöing",
    "färöingars": "färöing",
    "färöingen": "färöing",
    "färöingens": "färöing",
    "färöings": "färöing",
    "färöisk": "färöiska",
    "färöiska": "färöisk",
    "färöiskan": "färöiska",
    "färöiskans": "färöiska",
    "färöiskare": "färöisk",
    "färöiskares": "färöisk",
    "färöiskas": "färöiska",
    "färöiskast": "färöisk",
    "färöiskaste": "färöisk",
    "färöiskastes": "färöisk",
    "färöiskasts": "färöisk",
    "färöiske": "färöiska",
    "färöiskes": "färöisk",
    "färöiskor": "färöiska",
    "färöiskorna": "färöiska",
    "färöiskornas": "färöiska",
    "färöiskors": "färöiska",
    "färöisks": "färöisk",
    "färöiskt": "färöisk",
    "färöiskts": "färöisk",
    "fäs": "fä",
    "fäst": "fästa",
    "fästa": "fäst",
    "fästade": "fästad",
    "fästades": "fästad",
    "fästads": "fästad",
    "fästande": "fästa",
    "fästanden": "fästande",
    "fästandena": "fästande",
    "fästandenas": "fästande",
    "fästandens": "fästande",
    "fästandes": "fästande",
    "fästandet": "fästande",
    "fästandets": "fästande",
    "fästanordningar": "fästanordning",
    "fästanordningarna": "fästanordning",
    "fästanordningarnas": "fästanordning",
    "fästanordningars": "fästanordning",
    "fästanordningen": "fästanordning",
    "fästanordningens": "fästanordning",
    "fästanordnings": "fästanordning",
    "fästas": "fästa",
    "fästat": "fästad",
    "fästats": "fästad",
    "fäste": "fästa",
    "fästeet": "fäste",
    "fästeets": "fäste",
    "fästen": "fäste",
    "fästena": "fäste",
    "fästenas": "fäste",
    "fästens": "fäste",
    "fäster": "fästa",
    "fästes": "fäste",
    "fästet": "fäste",
    "fästets": "fäste",
    "fästfolket": "fästfolk",
    "fästfolkets": "fästfolk",
    "fästfolks": "fästfolk",
    "fästingar": "fästing",
    "fästingarna": "fästing",
    "fästingarnas": "fästing",
    "fästingars": "fästing",
    "fästingen": "fästing",
    "fästingens": "fästing",
    "fästings": "fästing",
    "fästjärnen": "fästjärn",
    "fästjärnens": "fästjärn",
    "fästjärnet": "fästjärn",
    "fästjärnets": "fästjärn",
    "fästjärns": "fästjärn",
    "fästkrokar": "fästkrok",
    "fästkrokarna": "fästkrok",
    "fästkrokarnas": "fästkrok",
    "fästkrokars": "fästkrok",
    "fästkroken": "fästkrok",
    "fästkrokens": "fästkrok",
    "fästkroks": "fästkrok",
    "fästmannen": "fästman",
    "fästmannens": "fästman",
    "fästmans": "fästman",
    "fästmanssoff": "fästmanssoffa",
    "fästmanssoffan": "fästmanssoffa",
    "fästmanssoffans": "fästmanssoffa",
    "fästmanssoffas": "fästmanssoffa",
    "fästmanssoffe": "fästmanssoffa",
    "fästmanssoffor": "fästmanssoffa",
    "fästmanssofforna": "fästmanssoffa",
    "fästmanssoffornas": "fästmanssoffa",
    "fästmanssoffors": "fästmanssoffa",
    "fästmanssoffs": "fästmanssoffa",
    "fästmän": "fästman",
    "fästmännen": "fästman",
    "fästmännens": "fästman",
    "fästmäns": "fästman",
    "fästmön": "fästmö",
    "fästmöns": "fästmö",
    "fästmör": "fästmö",
    "fästmörna": "fästmö",
    "fästmörnas": "fästmö",
    "fästmörs": "fästmö",
    "fästmös": "fästmö",
    "fästningar": "fästning",
    "fästningarna": "fästning",
    "fästningarnas": "fästning",
    "fästningars": "fästning",
    "fästningen": "fästning",
    "fästningens": "fästning",
    "fästnings": "fästning",
    "fästningsmurar": "fästningsmur",
    "fästningsmurarna": "fästningsmur",
    "fästningsmurarnas": "fästningsmur",
    "fästningsmurars": "fästningsmur",
    "fästningsmuren": "fästningsmur",
    "fästningsmurens": "fästningsmur",
    "fästningsmurs": "fästningsmur",
    "fästningsvallar": "fästningsvall",
    "fästningsvallarna": "fästningsvall",
    "fästningsvallarnas": "fästningsvall",
    "fästningsvallars": "fästningsvall",
    "fästningsvallen": "fästningsvall",
    "fästningsvallens": "fästningsvall",
    "fästningsvalls": "fästningsvall",
    "fästplatt": "fästplatta",
    "fästplattan": "fästplatta",
    "fästplattans": "fästplatta",
    "fästplattas": "fästplatta",
    "fästplatte": "fästplatta",
    "fästplattor": "fästplatta",
    "fästplattorna": "fästplatta",
    "fästplattornas": "fästplatta",
    "fästplattors": "fästplatta",
    "fästplatts": "fästplatta",
    "fästpunkten": "fästpunkt",
    "fästpunktens": "fästpunkt",
    "fästpunkter": "fästpunkt",
    "fästpunkterna": "fästpunkt",
    "fästpunkternas": "fästpunkt",
    "fästpunkters": "fästpunkt",
    "fästpunkts": "fästpunkt",
    "fästs": "fästa",
    "fästskruvar": "fästskruv",
    "fästskruvarna": "fästskruv",
    "fästskruvarnas": "fästskruv",
    "fästskruvars": "fästskruv",
    "fästskruven": "fästskruv",
    "fästskruvens": "fästskruv",
    "fästskruvs": "fästskruv",
    "fäsören": "fäsör",
    "fäsörens": "fäsör",
    "fäsörer": "fäsör",
    "fäsörerna": "fäsör",
    "fäsörernas": "fäsör",
    "fäsörers": "fäsör",
    "fäsörs": "fäsör",
    "fät": "fä",
    "fäts": "fä",
    "fåe": "få",
    "fående": "få",
    "fåenden": "fående",
    "fåendena": "fående",
    "fåendenas": "fående",
    "fåendens": "fående",
    "fåendes": "fående",
    "fåendet": "fående",
    "fåendets": "fående",
    "fåes": "få",
    "fåfänga": "fåfäng",
    "fåfängan": "fåfänga",
    "fåfängans": "fåfänga",
    "fåfängare": "fåfäng",
    "fåfängares": "fåfäng",
    "fåfängas": "fåfänga",
    "fåfängast": "fåfäng",
    "fåfängaste": "fåfäng",
    "fåfängastes": "fåfäng",
    "fåfängasts": "fåfäng",
    "fåfänge": "fåfäng",
    "fåfänges": "fåfäng",
    "fåfängheten": "fåfänghet",
    "fåfänghetens": "fåfänghet",
    "fåfänghets": "fåfänghet",
    "fåfängliga": "fåfänglig",
    "fåfängligare": "fåfänglig",
    "fåfängligares": "fåfänglig",
    "fåfängligas": "fåfänglig",
    "fåfängligast": "fåfänglig",
    "fåfängligaste": "fåfänglig",
    "fåfängligastes": "fåfänglig",
    "fåfängligasts": "fåfänglig",
    "fåfänglige": "fåfänglig",
    "fåfängliges": "fåfänglig",
    "fåfängligheten": "fåfänglighet",
    "fåfänglighetens": "fåfänglighet",
    "fåfängligheter": "fåfänglighet",
    "fåfängligheterna": "fåfänglighet",
    "fåfängligheternas": "fåfänglighet",
    "fåfängligheters": "fåfänglighet",
    "fåfänglighets": "fåfänglighet",
    "fåfängligs": "fåfänglig",
    "fåfängligt": "fåfänglig",
    "fåfängligts": "fåfänglig",
    "fåfängs": "fåfäng",
    "fåfängt": "fåfäng",
    "fåfängts": "fåfäng",
    "fågelbaden": "fågelbad",
    "fågelbadens": "fågelbad",
    "fågelbadet": "fågelbad",
    "fågelbadets": "fågelbad",
    "fågelbads": "fågelbad",
    "fågelboen": "fågelbo",
    "fågelboens": "fågelbo",
    "fågelboet": "fågelbo",
    "fågelboets": "fågelbo",
    "fågelbon": "fågelbo",
    "fågelbona": "fågelbo",
    "fågelbonas": "fågelbo",
    "fågelbons": "fågelbo",
    "fågelborden": "fågelbord",
    "fågelbordens": "fågelbord",
    "fågelbordet": "fågelbord",
    "fågelbordets": "fågelbord",
    "fågelbords": "fågelbord",
    "fågelbos": "fågelbo",
    "fågelbot": "fågelbo",
    "fågelbots": "fågelbo",
    "fågelburar": "fågelbur",
    "fågelburarna": "fågelbur",
    "fågelburarnas": "fågelbur",
    "fågelburars": "fågelbur",
    "fågelburen": "fågelbur",
    "fågelburens": "fågelbur",
    "fågelburs": "fågelbur",
    "fågelbären": "fågelbär",
    "fågelbärens": "fågelbär",
    "fågelbäret": "fågelbär",
    "fågelbärets": "fågelbär",
    "fågelbärs": "fågelbär",
    "fågeldunen": "fågeldun",
    "fågeldunens": "fågeldun",
    "fågeldunet": "fågeldun",
    "fågeldunets": "fågeldun",
    "fågelduns": "fågeldun",
    "fågelfjädern": "fågelfjäder",
    "fågelfjäderns": "fågelfjäder",
    "fågelfjäders": "fågelfjäder",
    "fågelfjädrar": "fågelfjäder",
    "fågelfjädrarna": "fågelfjäder",
    "fågelfjädrarnas": "fågelfjäder",
    "fågelfjädrars": "fågelfjäder",
    "fågelfoten": "fågelfot",
    "fågelfotens": "fågelfot",
    "fågelfots": "fågelfot",
    "fågelfria": "fågelfri",
    "fågelfriare": "fågelfri",
    "fågelfriares": "fågelfri",
    "fågelfrias": "fågelfri",
    "fågelfriast": "fågelfri",
    "fågelfriaste": "fågelfri",
    "fågelfriastes": "fågelfri",
    "fågelfriasts": "fågelfri",
    "fågelfrie": "fågelfri",
    "fågelfries": "fågelfri",
    "fågelfris": "fågelfri",
    "fågelfritt": "fågelfri",
    "fågelfritts": "fågelfri",
    "fågelfängen": "fågelfänge",
    "fågelfängena": "fågelfänge",
    "fågelfängenas": "fågelfänge",
    "fågelfängens": "fågelfänge",
    "fågelfänges": "fågelfänge",
    "fågelfänget": "fågelfänge",
    "fågelfängets": "fågelfänge",
    "fågelfängs": "fågelfänge",
    "fågelfötter": "fågelfot",
    "fågelfötterna": "fågelfot",
    "fågelfötternas": "fågelfot",
    "fågelfötters": "fågelfot",
    "fågelholkar": "fågelholk",
    "fågelholkarna": "fågelholk",
    "fågelholkarnas": "fågelholk",
    "fågelholkars": "fågelholk",
    "fågelholken": "fågelholk",
    "fågelholkens": "fågelholk",
    "fågelholks": "fågelholk",
    "fågelhundar": "fågelhund",
    "fågelhundarna": "fågelhund",
    "fågelhundarnas": "fågelhund",
    "fågelhundars": "fågelhund",
    "fågelhunden": "fågelhund",
    "fågelhundens": "fågelhund",
    "fågelhunds": "fågelhund",
    "fågelinfluensan": "fågelinfluensa",
    "fågelinfluensans": "fågelinfluensa",
    "fågelinfluensas": "fågelinfluensa",
    "fågelinfluensor": "fågelinfluensa",
    "fågelinfluensorna": "fågelinfluensa",
    "fågelinfluensornas": "fågelinfluensa",
    "fågelinfluensors": "fågelinfluensa",
    "fågeljakten": "fågeljakt",
    "fågeljaktens": "fågeljakt",
    "fågeljakter": "fågeljakt",
    "fågeljakterna": "fågeljakt",
    "fågeljakternas": "fågeljakt",
    "fågeljakters": "fågeljakt",
    "fågeljakts": "fågeljakt",
    "fågelkunniga": "fågelkunnig",
    "fågelkunnigare": "fågelkunnig",
    "fågelkunnigares": "fågelkunnig",
    "fågelkunnigas": "fågelkunnig",
    "fågelkunnigast": "fågelkunnig",
    "fågelkunnigaste": "fågelkunnig",
    "fågelkunnigastes": "fågelkunnig",
    "fågelkunnigasts": "fågelkunnig",
    "fågelkunnige": "fågelkunnig",
    "fågelkunniges": "fågelkunnig",
    "fågelkunnigheten": "fågelkunnighet",
    "fågelkunnighetens": "fågelkunnighet",
    "fågelkunnighets": "fågelkunnighet",
    "fågelkunnigs": "fågelkunnig",
    "fågelkunnigt": "fågelkunnig",
    "fågelkunnigts": "fågelkunnig",
    "fågelmatar": "fågelmatare",
    "fågelmataren": "fågelmatare",
    "fågelmatarens": "fågelmatare",
    "fågelmatares": "fågelmatare",
    "fågelmatarna": "fågelmatare",
    "fågelmatarnas": "fågelmatare",
    "fågelmaten": "fågelmat",
    "fågelmatens": "fågelmat",
    "fågelmats": "fågelmat",
    "fågeln": "fågel",
    "fågelns": "fågel",
    "fågelperspektiven": "fågelperspektiv",
    "fågelperspektivens": "fågelperspektiv",
    "fågelperspektivet": "fågelperspektiv",
    "fågelperspektivets": "fågelperspektiv",
    "fågelperspektivs": "fågelperspektiv",
    "fågels": "fågel",
    "fågelskräm": "fågelskrämma",
    "fågelskrämman": "fågelskrämma",
    "fågelskrämmans": "fågelskrämma",
    "fågelskrämmas": "fågelskrämma",
    "fågelskrämme": "fågelskrämma",
    "fågelskrämmor": "fågelskrämma",
    "fågelskrämmorna": "fågelskrämma",
    "fågelskrämmornas": "fågelskrämma",
    "fågelskrämmors": "fågelskrämma",
    "fågelskräms": "fågelskrämma",
    "fågelskådar": "fågelskådare",
    "fågelskådaren": "fågelskådare",
    "fågelskådarens": "fågelskådare",
    "fågelskådares": "fågelskådare",
    "fågelskådarna": "fågelskådare",
    "fågelskådarnas": "fågelskådare",
    "fågelskådningar": "fågelskådning",
    "fågelskådningarna": "fågelskådning",
    "fågelskådningarnas": "fågelskådning",
    "fågelskådningars": "fågelskådning",
    "fågelskådningen": "fågelskådning",
    "fågelskådningens": "fågelskådning",
    "fågelskådnings": "fågelskådning",
    "fågelsnar": "fågelsnara",
    "fågelsnaran": "fågelsnara",
    "fågelsnarans": "fågelsnara",
    "fågelsnaras": "fågelsnara",
    "fågelsnare": "fågelsnara",
    "fågelsnaror": "fågelsnara",
    "fågelsnarorna": "fågelsnara",
    "fågelsnarornas": "fågelsnara",
    "fågelsnarors": "fågelsnara",
    "fågelsnars": "fågelsnara",
    "fågelsträcken": "fågelsträck",
    "fågelsträckens": "fågelsträck",
    "fågelsträcket": "fågelsträck",
    "fågelsträckets": "fågelsträck",
    "fågelsträcks": "fågelsträck",
    "fågelsången": "fågelsång",
    "fågelsångens": "fågelsång",
    "fågelsångs": "fågelsång",
    "fågelträcken": "fågelträck",
    "fågelträckens": "fågelträck",
    "fågelträcks": "fågelträck",
    "fågelungar": "fågelunge",
    "fågelungarna": "fågelunge",
    "fågelungarnas": "fågelunge",
    "fågelungars": "fågelunge",
    "fågelungen": "fågelunge",
    "fågelungens": "fågelunge",
    "fågelunges": "fågelunge",
    "fågelving": "fågelvinge",
    "fågelvingar": "fågelvinge",
    "fågelvingarna": "fågelvinge",
    "fågelvingarnas": "fågelvinge",
    "fågelvingars": "fågelvinge",
    "fågelvingen": "fågelvinge",
    "fågelvingens": "fågelvinge",
    "fågelvinges": "fågelvinge",
    "fågelvings": "fågelvinge",
    "fågelvägens": "fågelvägen",
    "fågeläggen": "fågelägg",
    "fågeläggens": "fågelägg",
    "fågelägget": "fågelägg",
    "fågeläggets": "fågelägg",
    "fågeläggs": "fågelägg",
    "fåglalåten": "fåglalåt",
    "fåglalåtens": "fåglalåt",
    "fåglalåts": "fåglalåt",
    "fåglar": "fågel",
    "fåglarna": "fågel",
    "fåglarnas": "fågel",
    "fåglars": "fågel",
    "fåkunniga": "fåkunnig",
    "fåkunnigare": "fåkunnig",
    "fåkunnigares": "fåkunnig",
    "fåkunnigas": "fåkunnig",
    "fåkunnigast": "fåkunnig",
    "fåkunnigaste": "fåkunnig",
    "fåkunnigastes": "fåkunnig",
    "fåkunnigasts": "fåkunnig",
    "fåkunnige": "fåkunnig",
    "fåkunniges": "fåkunnig",
    "fåkunnigheten": "fåkunnighet",
    "fåkunnighetens": "fåkunnighet",
    "fåkunnighets": "fåkunnighet",
    "fåkunnigs": "fåkunnig",
    "fåkunnigt": "fåkunnig",
    "fåkunnigts": "fåkunnig",
    "fål": "fåle",
    "fålar": "fåle",
    "fålarna": "fåle",
    "fålarnas": "fåle",
    "fålars": "fåle",
    "fålen": "fåle",
    "fålens": "fåle",
    "fåles": "fåle",
    "fåll": "fålla",
    "fållad": "fålla",
    "fållade": "fålla",
    "fållades": "fålla",
    "fållads": "fålla",
    "fållan": "fålla",
    "fållande": "fålla",
    "fållanden": "fållande",
    "fållandena": "fållande",
    "fållandenas": "fållande",
    "fållandens": "fållande",
    "fållandes": "fållande",
    "fållandet": "fållande",
    "fållandets": "fållande",
    "fållans": "fålla",
    "fållar": "fålla",
    "fållarna": "fåll",
    "fållarnas": "fåll",
    "fållars": "fåll",
    "fållas": "fålla",
    "fållat": "fålla",
    "fållats": "fålla",
    "fållbänkar": "fållbänk",
    "fållbänkarna": "fållbänk",
    "fållbänkarnas": "fållbänk",
    "fållbänkars": "fållbänk",
    "fållbänken": "fållbänk",
    "fållbänkens": "fållbänk",
    "fållbänks": "fållbänk",
    "fålle": "fålla",
    "fållen": "fåll",
    "fållens": "fåll",
    "fållor": "fålla",
    "fållorna": "fålla",
    "fållornas": "fålla",
    "fållors": "fålla",
    "fålls": "fålla",
    "fåls": "fåle",
    "fåmansföretagen": "fåmansföretag",
    "fåmansföretagens": "fåmansföretag",
    "fåmansföretaget": "fåmansföretag",
    "fåmansföretagets": "fåmansföretag",
    "fåmansföretags": "fåmansföretag",
    "fåmälda": "fåmäld",
    "fåmäldare": "fåmäld",
    "fåmäldares": "fåmäld",
    "fåmäldas": "fåmäld",
    "fåmäldast": "fåmäld",
    "fåmäldaste": "fåmäld",
    "fåmäldastes": "fåmäld",
    "fåmäldasts": "fåmäld",
    "fåmälde": "fåmäld",
    "fåmäldes": "fåmäld",
    "fåmäldheten": "fåmäldhet",
    "fåmäldhetens": "fåmäldhet",
    "fåmäldhets": "fåmäldhet",
    "fåmälds": "fåmäld",
    "fåmält": "fåmäld",
    "fåmälta": "fåmält",
    "fåmältare": "fåmält",
    "fåmältares": "fåmält",
    "fåmältas": "fåmält",
    "fåmältast": "fåmält",
    "fåmältaste": "fåmält",
    "fåmältastes": "fåmält",
    "fåmältasts": "fåmält",
    "fåmälte": "fåmält",
    "fåmältes": "fåmält",
    "fåmälts": "fåmält",
    "fånar": "fåne",
    "fånarna": "fåne",
    "fånarnas": "fåne",
    "fånars": "fåne",
    "fånen": "fåne",
    "fånens": "fåne",
    "fånerier": "fåneri",
    "fånerierna": "fåneri",
    "fåneriernas": "fåneri",
    "fåneriers": "fåneri",
    "fåneriet": "fåneri",
    "fåneriets": "fåneri",
    "fåneris": "fåneri",
    "fånerit": "fåneri",
    "fånerits": "fåneri",
    "fånes": "fåne",
    "fånet": "fån",
    "fånets": "fån",
    "fång": "fånge",
    "fångad": "fånga",
    "fångade": "fånga",
    "fångades": "fånga",
    "fångads": "fånga",
    "fångande": "fånga",
    "fånganden": "fångande",
    "fångandena": "fångande",
    "fångandenas": "fångande",
    "fångandens": "fångande",
    "fångandes": "fångande",
    "fångandet": "fångande",
    "fångandets": "fångande",
    "fångar": "fånge",
    "fångarna": "fånge",
    "fångarnas": "fånge",
    "fångars": "fånge",
    "fångas": "fånga",
    "fångat": "fånga",
    "fångats": "fånga",
    "fången": "fånge",
    "fångens": "fången",
    "fångenskapen": "fångenskap",
    "fångenskapens": "fångenskap",
    "fångenskaps": "fångenskap",
    "fånges": "fånge",
    "fångeshandlingar": "fångeshandling",
    "fångeshandlingarna": "fångeshandling",
    "fångeshandlingarnas": "fångeshandling",
    "fångeshandlingars": "fångeshandling",
    "fångeshandlingen": "fångeshandling",
    "fångeshandlingens": "fångeshandling",
    "fångeshandlings": "fångeshandling",
    "fångesmannen": "fångesman",
    "fångesmannens": "fångesman",
    "fångesmans": "fångesman",
    "fångesmän": "fångesman",
    "fångesmännen": "fångesman",
    "fångesmännens": "fångesman",
    "fångesmäns": "fångesman",
    "fånget": "fången",
    "fångets": "fången",
    "fånglin": "fånglina",
    "fånglinan": "fånglina",
    "fånglinans": "fånglina",
    "fånglinas": "fånglina",
    "fångline": "fånglina",
    "fånglinor": "fånglina",
    "fånglinorna": "fånglina",
    "fånglinornas": "fånglina",
    "fånglinors": "fånglina",
    "fånglins": "fånglina",
    "fånglägerna": "fångläger",
    "fånglägernas": "fångläger",
    "fånglägers": "fångläger",
    "fånglägren": "fångläger",
    "fånglägrens": "fångläger",
    "fånglägret": "fångläger",
    "fånglägrets": "fångläger",
    "fångna": "fången",
    "fångnare": "fången",
    "fångnares": "fången",
    "fångnas": "fången",
    "fångnast": "fången",
    "fångnaste": "fången",
    "fångnastes": "fången",
    "fångnasts": "fången",
    "fångne": "fången",
    "fångnes": "fången",
    "fångs": "fånge",
    "fångstanordningar": "fångstanordning",
    "fångstanordningarna": "fångstanordning",
    "fångstanordningarnas": "fångstanordning",
    "fångstanordningars": "fångstanordning",
    "fångstanordningen": "fångstanordning",
    "fångstanordningens": "fångstanordning",
    "fångstanordnings": "fångstanordning",
    "fångsten": "fångst",
    "fångstens": "fångst",
    "fångster": "fångst",
    "fångsterna": "fångst",
    "fångsternas": "fångst",
    "fångsters": "fångst",
    "fångstfolken": "fångstfolk",
    "fångstfolkens": "fångstfolk",
    "fångstfolket": "fångstfolk",
    "fångstfolkets": "fångstfolk",
    "fångstfolks": "fångstfolk",
    "fångstgropar": "fångstgrop",
    "fångstgroparna": "fångstgrop",
    "fångstgroparnas": "fångstgrop",
    "fångstgropars": "fångstgrop",
    "fångstgropen": "fångstgrop",
    "fångstgropens": "fångstgrop",
    "fångstgrops": "fångstgrop",
    "fångstkrokar": "fångstkrok",
    "fångstkrokarna": "fångstkrok",
    "fångstkrokarnas": "fångstkrok",
    "fångstkrokars": "fångstkrok",
    "fångstkroken": "fångstkrok",
    "fångstkrokens": "fångstkrok",
    "fångstkroks": "fångstkrok",
    "fångstkulturen": "fångstkultur",
    "fångstkulturens": "fångstkultur",
    "fångstkulturer": "fångstkultur",
    "fångstkulturerna": "fångstkultur",
    "fångstkulturernas": "fångstkultur",
    "fångstkulturers": "fångstkultur",
    "fångstkulturs": "fångstkultur",
    "fångstplatsen": "fångstplats",
    "fångstplatsens": "fångstplats",
    "fångstplatser": "fångstplats",
    "fångstplatserna": "fångstplats",
    "fångstplatsernas": "fångstplats",
    "fångstplatsers": "fångstplats",
    "fångstredskapen": "fångstredskap",
    "fångstredskapens": "fångstredskap",
    "fångstredskapet": "fångstredskap",
    "fångstredskapets": "fångstredskap",
    "fångstredskaps": "fångstredskap",
    "fångsts": "fångst",
    "fångstsamhällen": "fångstsamhälle",
    "fångstsamhällena": "fångstsamhälle",
    "fångstsamhällenas": "fångstsamhälle",
    "fångstsamhällens": "fångstsamhälle",
    "fångstsamhälles": "fångstsamhälle",
    "fångstsamhället": "fångstsamhälle",
    "fångstsamhällets": "fångstsamhälle",
    "fångstsamhälls": "fångstsamhälle",
    "fångupproren": "fånguppror",
    "fångupprorens": "fånguppror",
    "fångupproret": "fånguppror",
    "fångupprorets": "fånguppror",
    "fångupprors": "fånguppror",
    "fångutväxlingar": "fångutväxling",
    "fångutväxlingarna": "fångutväxling",
    "fångutväxlingarnas": "fångutväxling",
    "fångutväxlingars": "fångutväxling",
    "fångutväxlingen": "fångutväxling",
    "fångutväxlingens": "fångutväxling",
    "fångutväxlings": "fångutväxling",
    "fångvaktar": "fångvaktare",
    "fångvaktaren": "fångvaktare",
    "fångvaktarens": "fångvaktare",
    "fångvaktares": "fångvaktare",
    "fångvaktarna": "fångvaktare",
    "fångvaktarnas": "fångvaktare",
    "fångvården": "fångvård",
    "fångvårdens": "fångvård",
    "fångvårds": "fångvård",
    "fångvårdsanstalten": "fångvårdsanstalt",
    "fångvårdsanstaltens": "fångvårdsanstalt",
    "fångvårdsanstalter": "fångvårdsanstalt",
    "fångvårdsanstalterna": "fångvårdsanstalt",
    "fångvårdsanstalternas": "fångvårdsanstalt",
    "fångvårdsanstalters": "fångvårdsanstalt",
    "fångvårdsanstalts": "fångvårdsanstalt",
    "fåniga": "fånig",
    "fånigare": "fånig",
    "fånigares": "fånig",
    "fånigas": "fånig",
    "fånigast": "fånig",
    "fånigaste": "fånig",
    "fånigastes": "fånig",
    "fånigasts": "fånig",
    "fånige": "fånig",
    "fåniges": "fånig",
    "fånigheten": "fånighet",
    "fånighetens": "fånighet",
    "fånigheter": "fånighet",
    "fånigheterna": "fånighet",
    "fånigheternas": "fånighet",
    "fånigheters": "fånighet",
    "fånighets": "fånighet",
    "fånigs": "fånig",
    "fånigt": "fånig",
    "fånigts": "fånig",
    "fåns": "fån",
    "fånskrattade": "fånskratta",
    "fånskrattades": "fånskratta",
    "fånskrattande": "fånskratta",
    "fånskrattanden": "fånskrattande",
    "fånskrattandena": "fånskrattande",
    "fånskrattandenas": "fånskrattande",
    "fånskrattandens": "fånskrattande",
    "fånskrattandes": "fånskrattande",
    "fånskrattandet": "fånskrattande",
    "fånskrattandets": "fånskrattande",
    "fånskrattar": "fånskratta",
    "fånskrattas": "fånskratta",
    "fånskrattat": "fånskratta",
    "fånskrattats": "fånskratta",
    "fånskratten": "fånskratt",
    "fånskrattens": "fånskratt",
    "fånskrattet": "fånskratt",
    "fånskrattets": "fånskratt",
    "fånskratts": "fånskratt",
    "fåntrattar": "fåntratt",
    "fåntrattarna": "fåntratt",
    "fåntrattarnas": "fåntratt",
    "fåntrattars": "fåntratt",
    "fåntratten": "fåntratt",
    "fåntrattens": "fåntratt",
    "fåntratts": "fåntratt",
    "fåordiga": "fåordig",
    "fåordigare": "fåordig",
    "fåordigares": "fåordig",
    "fåordigas": "fåordig",
    "fåordigast": "fåordig",
    "fåordigaste": "fåordig",
    "fåordigastes": "fåordig",
    "fåordigasts": "fåordig",
    "fåordige": "fåordig",
    "fåordiges": "fåordig",
    "fåordigheten": "fåordighet",
    "fåordighetens": "fåordighet",
    "fåordighets": "fåordighet",
    "fåordigs": "fåordig",
    "fåordigt": "fåordig",
    "fåordigts": "fåordig",
    "får": "fåra",
    "fårad": "fåra",
    "fårade": "fåra",
    "fårades": "fåra",
    "fårads": "fåra",
    "fåraherda": "fåraherde",
    "fåraherdar": "fåraherde",
    "fåraherdarna": "fåraherde",
    "fåraherdarnas": "fåraherde",
    "fåraherdars": "fåraherde",
    "fåraherden": "fåraherde",
    "fåraherdens": "fåraherde",
    "fåraherdes": "fåraherde",
    "fåraktiga": "fåraktig",
    "fåraktigare": "fåraktig",
    "fåraktigares": "fåraktig",
    "fåraktigas": "fåraktig",
    "fåraktigast": "fåraktig",
    "fåraktigaste": "fåraktig",
    "fåraktigastes": "fåraktig",
    "fåraktigasts": "fåraktig",
    "fåraktige": "fåraktig",
    "fåraktiges": "fåraktig",
    "fåraktigheten": "fåraktighet",
    "fåraktighetens": "fåraktighet",
    "fåraktighets": "fåraktighet",
    "fåraktigs": "fåraktig",
    "fåraktigt": "fåraktig",
    "fåraktigts": "fåraktig",
    "fåran": "fåra",
    "fårande": "fåra",
    "fåranden": "fårande",
    "fårandena": "fårande",
    "fårandenas": "fårande",
    "fårandens": "fårande",
    "fårandes": "fårande",
    "fårandet": "fårande",
    "fårandets": "fårande",
    "fårans": "fåra",
    "fårar": "fåra",
    "fåras": "fåra",
    "fårat": "fåra",
    "fårats": "fåra",
    "fåraveln": "fåravel",
    "fåravelns": "fåravel",
    "fåravels": "fåravel",
    "fårbogsärmar": "fårbogsärm",
    "fårbogsärmarna": "fårbogsärm",
    "fårbogsärmarnas": "fårbogsärm",
    "fårbogsärmars": "fårbogsärm",
    "fårbogsärmen": "fårbogsärm",
    "fårbogsärmens": "fårbogsärm",
    "fårbogsärms": "fårbogsärm",
    "fåre": "fåra",
    "fåren": "får",
    "fårens": "får",
    "fåret": "får",
    "fårets": "får",
    "fårfiolen": "fårfiol",
    "fårfiolens": "fårfiol",
    "fårfioler": "fårfiol",
    "fårfiolerna": "fårfiol",
    "fårfiolernas": "fårfiol",
    "fårfiolers": "fårfiol",
    "fårfiols": "fårfiol",
    "fårhjordar": "fårhjord",
    "fårhjordarna": "fårhjord",
    "fårhjordarnas": "fårhjord",
    "fårhjordars": "fårhjord",
    "fårhjorden": "fårhjord",
    "fårhjordens": "fårhjord",
    "fårhjords": "fårhjord",
    "fårhundar": "fårhund",
    "fårhundarna": "fårhund",
    "fårhundarnas": "fårhund",
    "fårhundars": "fårhund",
    "fårhunden": "fårhund",
    "fårhundens": "fårhund",
    "fårhunds": "fårhund",
    "fårköttet": "fårkött",
    "fårköttets": "fårkött",
    "fårkötts": "fårkött",
    "fåror": "fåra",
    "fårorna": "fåra",
    "fårornas": "fåra",
    "fårors": "fåra",
    "fårostar": "fårost",
    "fårostarna": "fårost",
    "fårostarnas": "fårost",
    "fårostars": "fårost",
    "fårosten": "fårost",
    "fårostens": "fårost",
    "fårosts": "fårost",
    "fårs": "fåra",
    "fårskall": "fårskalle",
    "fårskallar": "fårskalle",
    "fårskallarna": "fårskalle",
    "fårskallarnas": "fårskalle",
    "fårskallars": "fårskalle",
    "fårskallen": "fårskalle",
    "fårskallens": "fårskalle",
    "fårskalles": "fårskalle",
    "fårskalls": "fårskalle",
    "fårskinnen": "fårskinn",
    "fårskinnens": "fårskinn",
    "fårskinnet": "fårskinn",
    "fårskinnets": "fårskinn",
    "fårskinns": "fårskinn",
    "fårsvingeln": "fårsvingel",
    "fårsvingelns": "fårsvingel",
    "fårsvingels": "fårsvingel",
    "fårtick": "fårticka",
    "fårtickan": "fårticka",
    "fårtickans": "fårticka",
    "fårtickas": "fårticka",
    "fårticke": "fårticka",
    "fårtickor": "fårticka",
    "fårtickorna": "fårticka",
    "fårtickornas": "fårticka",
    "fårtickors": "fårticka",
    "fårticks": "fårticka",
    "fårullen": "fårull",
    "fårullens": "fårull",
    "fårulls": "fårull",
    "fås": "få",
    "fåtalen": "fåtal",
    "fåtalens": "fåtal",
    "fåtalet": "fåtal",
    "fåtalets": "fåtal",
    "fåtaliga": "fåtalig",
    "fåtaligare": "fåtalig",
    "fåtaligares": "fåtalig",
    "fåtaligas": "fåtalig",
    "fåtaligast": "fåtalig",
    "fåtaligaste": "fåtalig",
    "fåtaligastes": "fåtalig",
    "fåtaligasts": "fåtalig",
    "fåtalige": "fåtalig",
    "fåtaliges": "fåtalig",
    "fåtaligheten": "fåtalighet",
    "fåtalighetens": "fåtalighet",
    "fåtalighets": "fåtalighet",
    "fåtaligs": "fåtalig",
    "fåtaligt": "fåtalig",
    "fåtaligts": "fåtalig",
    "fåtals": "fåtal",
    "fåten": "fåt",
    "fåtens": "fåt",
    "fåter": "fåt",
    "fåterna": "fåt",
    "fåternas": "fåt",
    "fåters": "fåt",
    "fåts": "fåt",
    "fått": "få",
    "fåtts": "få",
    "fåtöljen": "fåtölj",
    "fåtöljens": "fåtölj",
    "fåtöljer": "fåtölj",
    "fåtöljerna": "fåtölj",
    "fåtöljernas": "fåtölj",
    "fåtöljers": "fåtölj",
    "fåtöljs": "fåtölj",
    "fåvitska": "fåvitsk",
    "fåvitskare": "fåvitsk",
    "fåvitskares": "fåvitsk",
    "fåvitskas": "fåvitsk",
    "fåvitskast": "fåvitsk",
    "fåvitskaste": "fåvitsk",
    "fåvitskastes": "fåvitsk",
    "fåvitskasts": "fåvitsk",
    "fåvitske": "fåvitsk",
    "fåvitskes": "fåvitsk",
    "fåvitsks": "fåvitsk",
    "fåvitskt": "fåvitsk",
    "fåvitskts": "fåvitsk",
    "föd": "föda",
    "födan": "föda",
    "födande": "föda",
    "födanden": "födande",
    "födandena": "födande",
    "födandenas": "födande",
    "födandens": "födande",
    "födandes": "födande",
    "födandet": "födande",
    "födandets": "födande",
    "födans": "föda",
    "födas": "föda",
    "född": "föda",
    "födda": "född",
    "föddare": "född",
    "föddares": "född",
    "föddas": "född",
    "föddast": "född",
    "föddaste": "född",
    "föddastes": "född",
    "föddasts": "född",
    "födde": "född",
    "föddes": "född",
    "födds": "född",
    "födelseattesten": "födelseattest",
    "födelseattestens": "födelseattest",
    "födelseattester": "födelseattest",
    "födelseattesterna": "födelseattest",
    "födelseattesternas": "födelseattest",
    "födelseattesters": "födelseattest",
    "födelseattests": "födelseattest",
    "födelsedagar": "födelsedag",
    "födelsedagarna": "födelsedag",
    "födelsedagarnas": "födelsedag",
    "födelsedagars": "födelsedag",
    "födelsedagen": "födelsedag",
    "födelsedagens": "födelsedag",
    "födelsedags": "födelsedag",
    "födelsedagsbarnen": "födelsedagsbarn",
    "födelsedagsbarnens": "födelsedagsbarn",
    "födelsedagsbarnet": "födelsedagsbarn",
    "födelsedagsbarnets": "födelsedagsbarn",
    "födelsedagsbarns": "födelsedagsbarn",
    "födelsedagsfesten": "födelsedagsfest",
    "födelsedagsfestens": "födelsedagsfest",
    "födelsedagsfester": "födelsedagsfest",
    "födelsedagsfesterna": "födelsedagsfest",
    "födelsedagsfesternas": "födelsedagsfest",
    "födelsedagsfesters": "födelsedagsfest",
    "födelsedagsfests": "födelsedagsfest",
    "födelsedagsmiddagar": "födelsedagsmiddag",
    "födelsedagsmiddagarna": "födelsedagsmiddag",
    "födelsedagsmiddagarnas": "födelsedagsmiddag",
    "födelsedagsmiddagars": "födelsedagsmiddag",
    "födelsedagsmiddagen": "födelsedagsmiddag",
    "födelsedagsmiddagens": "födelsedagsmiddag",
    "födelsedagsmiddags": "födelsedagsmiddag",
    "födelsedagstårt": "födelsedagstårta",
    "födelsedagstårtan": "födelsedagstårta",
    "födelsedagstårtans": "födelsedagstårta",
    "födelsedagstårtas": "födelsedagstårta",
    "födelsedagstårte": "födelsedagstårta",
    "födelsedagstårtor": "födelsedagstårta",
    "födelsedagstårtorna": "födelsedagstårta",
    "födelsedagstårtornas": "födelsedagstårta",
    "födelsedagstårtors": "födelsedagstårta",
    "födelsedagstårts": "födelsedagstårta",
    "födelsehemmen": "födelsehem",
    "födelsehemmens": "födelsehem",
    "födelsehemmet": "födelsehem",
    "födelsehemmets": "födelsehem",
    "födelsehems": "födelsehem",
    "födelsekontrollen": "födelsekontroll",
    "födelsekontrollens": "födelsekontroll",
    "födelsekontroller": "födelsekontroll",
    "födelsekontrollerna": "födelsekontroll",
    "födelsekontrollernas": "födelsekontroll",
    "födelsekontrollers": "födelsekontroll",
    "födelsekontrolls": "födelsekontroll",
    "födelsemärken": "födelsemärke",
    "födelsemärkena": "födelsemärke",
    "födelsemärkenas": "födelsemärke",
    "födelsemärkens": "födelsemärke",
    "födelsemärkes": "födelsemärke",
    "födelsemärket": "födelsemärke",
    "födelsemärkets": "födelsemärke",
    "födelsen": "födelse",
    "födelsens": "födelse",
    "födelsenummerna": "födelsenummer",
    "födelsenummernas": "födelsenummer",
    "födelsenummers": "födelsenummer",
    "födelsenumren": "födelsenummer",
    "födelsenumrens": "födelsenummer",
    "födelsenumret": "födelsenummer",
    "födelsenumrets": "födelsenummer",
    "födelser": "födelse",
    "födelserna": "födelse",
    "födelsernas": "födelse",
    "födelsers": "födelse",
    "födelses": "födelse",
    "födelsestaden": "födelsestad",
    "födelsestadens": "födelsestad",
    "födelsestads": "födelsestad",
    "födelsestan": "födelsestad",
    "födelsestans": "födelsestad",
    "födelsestäder": "födelsestad",
    "födelsestäderna": "födelsestad",
    "födelsestädernas": "födelsestad",
    "födelsestäders": "födelsestad",
    "födelsetalen": "födelsetal",
    "födelsetalens": "födelsetal",
    "födelsetalet": "födelsetal",
    "födelsetalets": "födelsetal",
    "födelsetals": "födelsetal",
    "föder": "föda",
    "födes": "föda",
    "födgenier": "födgeni",
    "födgenierna": "födgeni",
    "födgeniernas": "födgeni",
    "födgeniers": "födgeni",
    "födgeniet": "födgeni",
    "födgeniets": "födgeni",
    "födgenis": "födgeni",
    "födkrokar": "födkrok",
    "födkrokarna": "födkrok",
    "födkrokarnas": "födkrok",
    "födkrokars": "födkrok",
    "födkroken": "födkrok",
    "födkrokens": "födkrok",
    "födkroks": "födkrok",
    "födoorganismen": "födoorganism",
    "födoorganismens": "födoorganism",
    "födoorganismer": "födoorganism",
    "födoorganismerna": "födoorganism",
    "födoorganismernas": "födoorganism",
    "födoorganismers": "födoorganism",
    "födoorganisms": "födoorganism",
    "födopartikeln": "födopartikel",
    "födopartikelns": "födopartikel",
    "födopartikels": "födopartikel",
    "födopartiklar": "födopartikel",
    "födopartiklarna": "födopartikel",
    "födopartiklarnas": "födopartikel",
    "födopartiklars": "födopartikel",
    "födoråden": "födoråd",
    "födorådens": "födoråd",
    "födorådet": "födoråd",
    "födorådets": "födoråd",
    "födoråds": "födoråd",
    "födoämnen": "födoämne",
    "födoämnena": "födoämne",
    "födoämnenas": "födoämne",
    "födoämnens": "födoämne",
    "födoämnes": "födoämne",
    "födoämnet": "födoämne",
    "födoämnets": "födoämne",
    "föds": "föda",
    "födseln": "födsel",
    "födselns": "födsel",
    "födsels": "födsel",
    "födslar": "födsel",
    "födslarna": "födsel",
    "födslarnas": "födsel",
    "födslars": "födsel",
    "födslorätten": "födslorätt",
    "födslorättens": "födslorätt",
    "födslorätter": "födslorätt",
    "födslorätterna": "födslorätt",
    "födslorätternas": "födslorätt",
    "födslorätters": "födslorätt",
    "födslorätts": "födslorätt",
    "födsloskrien": "födsloskri",
    "födsloskriens": "födsloskri",
    "födsloskriet": "födsloskri",
    "födsloskriets": "födsloskri",
    "födsloskrin": "födsloskri",
    "födsloskrina": "födsloskri",
    "födsloskrinas": "födsloskri",
    "födsloskrins": "födsloskri",
    "födsloskris": "födsloskri",
    "födsloskrit": "födsloskri",
    "födsloskrits": "födsloskri",
    "födslovärkar": "födslovärk",
    "födslovärkarna": "födslovärk",
    "födslovärkarnas": "födslovärk",
    "födslovärkars": "födslovärk",
    "födslovärken": "födslovärk",
    "födslovärkens": "födslovärk",
    "födslovärks": "födslovärk",
    "födslovånd": "födslovånda",
    "födslovåndan": "födslovånda",
    "födslovåndans": "födslovånda",
    "födslovåndas": "födslovånda",
    "födslovånde": "födslovånda",
    "födslovåndor": "födslovånda",
    "födslovåndorna": "födslovånda",
    "födslovåndornas": "födslovånda",
    "födslovåndors": "födslovånda",
    "födslovånds": "födslovånda",
    "fögderier": "fögderi",
    "fögderierna": "fögderi",
    "fögderiernas": "fögderi",
    "fögderiers": "fögderi",
    "fögderiet": "fögderi",
    "fögderiets": "fögderi",
    "fögderiförvaltningar": "fögderiförvaltning",
    "fögderiförvaltningarna": "fögderiförvaltning",
    "fögderiförvaltningarnas": "fögderiförvaltning",
    "fögderiförvaltningars": "fögderiförvaltning",
    "fögderiförvaltningen": "fögderiförvaltning",
    "fögderiförvaltningens": "fögderiförvaltning",
    "fögderiförvaltnings": "fögderiförvaltning",
    "fögderis": "fögderi",
    "fögderit": "fögderi",
    "fögderits": "fögderi",
    "föhnen": "föhn",
    "föhnens": "föhn",
    "föhns": "föhn",
    "fölade": "föla",
    "fölades": "föla",
    "fölande": "föla",
    "fölanden": "fölande",
    "fölandena": "fölande",
    "fölandenas": "fölande",
    "fölandens": "fölande",
    "fölandes": "fölande",
    "fölandet": "fölande",
    "fölandets": "fölande",
    "fölar": "föla",
    "fölas": "föla",
    "fölat": "föla",
    "fölats": "föla",
    "fölen": "föl",
    "fölens": "föl",
    "fölet": "föl",
    "fölets": "föl",
    "följ": "följa",
    "följande": "följa",
    "följanden": "följande",
    "följandena": "följande",
    "följandenas": "följande",
    "följandens": "följande",
    "följandes": "följande",
    "följandet": "följande",
    "följandets": "följande",
    "följas": "följa",
    "följd": "följa",
    "följda": "följa",
    "följdas": "följa",
    "följde": "följa",
    "följden": "följd",
    "följdenliga": "följdenlig",
    "följdenligare": "följdenlig",
    "följdenligares": "följdenlig",
    "följdenligas": "följdenlig",
    "följdenligast": "följdenlig",
    "följdenligaste": "följdenlig",
    "följdenligastes": "följdenlig",
    "följdenligasts": "följdenlig",
    "följdenlige": "följdenlig",
    "följdenliges": "följdenlig",
    "följdenligheten": "följdenlighet",
    "följdenlighetens": "följdenlighet",
    "följdenlighets": "följdenlighet",
    "följdenligs": "följdenlig",
    "följdenligt": "följdenlig",
    "följdenligts": "följdenlig",
    "följdens": "följd",
    "följder": "följd",
    "följderna": "följd",
    "följdernas": "följd",
    "följders": "följd",
    "följdes": "följa",
    "följdfrågan": "följdfråga",
    "följdfrågans": "följdfråga",
    "följdfrågas": "följdfråga",
    "följdfråge": "följdfråga",
    "följdfrågor": "följdfråga",
    "följdfrågorna": "följdfråga",
    "följdfrågornas": "följdfråga",
    "följdfrågors": "följdfråga",
    "följdproblemen": "följdproblem",
    "följdproblemens": "följdproblem",
    "följdproblemet": "följdproblem",
    "följdproblemets": "följdproblem",
    "följdproblems": "följdproblem",
    "följdriktiga": "följdriktig",
    "följdriktigare": "följdriktig",
    "följdriktigares": "följdriktig",
    "följdriktigas": "följdriktig",
    "följdriktigast": "följdriktig",
    "följdriktigaste": "följdriktig",
    "följdriktigastes": "följdriktig",
    "följdriktigasts": "följdriktig",
    "följdriktige": "följdriktig",
    "följdriktiges": "följdriktig",
    "följdriktigheten": "följdriktighet",
    "följdriktighetens": "följdriktighet",
    "följdriktighets": "följdriktighet",
    "följdriktigs": "följdriktig",
    "följdriktigt": "följdriktig",
    "följdriktigts": "följdriktig",
    "följds": "följd",
    "följdsatsen": "följdsats",
    "följdsatsens": "följdsats",
    "följdsatser": "följdsats",
    "följdsatserna": "följdsats",
    "följdsatsernas": "följdsats",
    "följdsatsers": "följdsats",
    "följdverkningar": "följdverkning",
    "följdverkningarna": "följdverkning",
    "följdverkningarnas": "följdverkning",
    "följdverkningars": "följdverkning",
    "följdverkningen": "följdverkning",
    "följdverkningens": "följdverkning",
    "följdverknings": "följdverkning",
    "följebilar": "följebil",
    "följebilarna": "följebil",
    "följebilarnas": "följebil",
    "följebilars": "följebil",
    "följebilen": "följebil",
    "följebilens": "följebil",
    "följebils": "följebil",
    "följebreven": "följebrev",
    "följebrevens": "följebrev",
    "följebrevet": "följebrev",
    "följebrevets": "följebrev",
    "följebrevs": "följebrev",
    "följen": "följe",
    "följena": "följe",
    "följenas": "följe",
    "följens": "följe",
    "följer": "följa",
    "följes": "följe",
    "följesedeln": "följesedel",
    "följesedelns": "följesedel",
    "följesedels": "följesedel",
    "följesedlar": "följesedel",
    "följesedlarna": "följesedel",
    "följesedlarnas": "följesedel",
    "följesedlars": "följesedel",
    "följeslagar": "följeslagare",
    "följeslagaren": "följeslagare",
    "följeslagarens": "följeslagare",
    "följeslagares": "följeslagare",
    "följeslagarinnan": "följeslagarinna",
    "följeslagarinnans": "följeslagarinna",
    "följeslagarinnas": "följeslagarinna",
    "följeslagarinne": "följeslagarinna",
    "följeslagarinnor": "följeslagarinna",
    "följeslagarinnorna": "följeslagarinna",
    "följeslagarinnornas": "följeslagarinna",
    "följeslagarinnors": "följeslagarinna",
    "följeslagarna": "följeslagare",
    "följeslagarnas": "följeslagare",
    "följet": "följe",
    "följetongen": "följetong",
    "följetongens": "följetong",
    "följetonger": "följetong",
    "följetongerna": "följetong",
    "följetongernas": "följetong",
    "följetongers": "följetong",
    "följetongs": "följetong",
    "följetongsmässiga": "följetongsmässig",
    "följetongsmässigare": "följetongsmässig",
    "följetongsmässigares": "följetongsmässig",
    "följetongsmässigas": "följetongsmässig",
    "följetongsmässigast": "följetongsmässig",
    "följetongsmässigaste": "följetongsmässig",
    "följetongsmässigastes": "följetongsmässig",
    "följetongsmässigasts": "följetongsmässig",
    "följetongsmässige": "följetongsmässig",
    "följetongsmässiges": "följetongsmässig",
    "följetongsmässigs": "följetongsmässig",
    "följetongsmässigt": "följetongsmässig",
    "följetongsmässigts": "följetongsmässig",
    "följets": "följe",
    "följs": "följe",
    "följsamheten": "följsamhet",
    "följsamhetens": "följsamhet",
    "följsamheter": "följsamhet",
    "följsamheterna": "följsamhet",
    "följsamheternas": "följsamhet",
    "följsamheters": "följsamhet",
    "följsamhets": "följsamhet",
    "följsamma": "följsam",
    "följsammare": "följsam",
    "följsammares": "följsam",
    "följsammas": "följsam",
    "följsammast": "följsam",
    "följsammaste": "följsam",
    "följsammastes": "följsam",
    "följsammasts": "följsam",
    "följsamme": "följsam",
    "följsammes": "följsam",
    "följsams": "följsam",
    "följsamt": "följsam",
    "följsamts": "följsam",
    "följt": "följa",
    "följts": "följa",
    "föll": "falla",
    "fölle": "falla",
    "fölles": "falla",
    "fölls": "falla",
    "föls": "föl",
    "fölstoet": "fölsto",
    "fölstoets": "fölsto",
    "fölston": "fölsto",
    "fölstona": "fölsto",
    "fölstonas": "fölsto",
    "fölstons": "fölsto",
    "fölstos": "fölsto",
    "fölstot": "fölsto",
    "fölstots": "fölsto",
    "fön": "föna",
    "fönad": "föna",
    "fönade": "föna",
    "fönades": "föna",
    "fönads": "föna",
    "fönande": "föna",
    "fönanden": "fönande",
    "fönandena": "fönande",
    "fönandenas": "fönande",
    "fönandens": "fönande",
    "fönandes": "fönande",
    "fönandet": "fönande",
    "fönandets": "fönande",
    "fönar": "föna",
    "fönarna": "fön",
    "fönarnas": "fön",
    "fönars": "fön",
    "fönas": "föna",
    "fönat": "föna",
    "fönats": "föna",
    "fönen": "fön",
    "fönens": "fön",
    "föner": "fön",
    "fönerna": "fön",
    "fönernas": "fön",
    "föners": "fön",
    "föns": "fön",
    "fönsterbeslagen": "fönsterbeslag",
    "fönsterbeslagens": "fönsterbeslag",
    "fönsterbeslaget": "fönsterbeslag",
    "fönsterbeslagets": "fönsterbeslag",
    "fönsterbeslags": "fönsterbeslag",
    "fönsterblecken": "fönsterbleck",
    "fönsterbleckens": "fönsterbleck",
    "fönsterblecket": "fönsterbleck",
    "fönsterbleckets": "fönsterbleck",
    "fönsterblecks": "fönsterbleck",
    "fönsterborden": "fönsterbord",
    "fönsterbordens": "fönsterbord",
    "fönsterbordet": "fönsterbord",
    "fönsterbordets": "fönsterbord",
    "fönsterbords": "fönsterbord",
    "fönsterbräd": "fönsterbräda",
    "fönsterbrädan": "fönsterbräda",
    "fönsterbrädans": "fönsterbräda",
    "fönsterbrädas": "fönsterbräda",
    "fönsterbräde": "fönsterbräda",
    "fönsterbräden": "fönsterbräde",
    "fönsterbrädena": "fönsterbräde",
    "fönsterbrädenas": "fönsterbräde",
    "fönsterbrädens": "fönsterbräde",
    "fönsterbrädes": "fönsterbräde",
    "fönsterbrädet": "fönsterbräde",
    "fönsterbrädets": "fönsterbräde",
    "fönsterbrädor": "fönsterbräda",
    "fönsterbrädorna": "fönsterbräda",
    "fönsterbrädornas": "fönsterbräda",
    "fönsterbrädors": "fönsterbräda",
    "fönsterbräds": "fönsterbräda",
    "fönsterbänkar": "fönsterbänk",
    "fönsterbänkarna": "fönsterbänk",
    "fönsterbänkarnas": "fönsterbänk",
    "fönsterbänkars": "fönsterbänk",
    "fönsterbänken": "fönsterbänk",
    "fönsterbänkens": "fönsterbänk",
    "fönsterbänks": "fönsterbänk",
    "fönsterbåg": "fönsterbåge",
    "fönsterbågar": "fönsterbåge",
    "fönsterbågarna": "fönsterbåge",
    "fönsterbågarnas": "fönsterbåge",
    "fönsterbågars": "fönsterbåge",
    "fönsterbågen": "fönsterbåge",
    "fönsterbågens": "fönsterbåge",
    "fönsterbåges": "fönsterbåge",
    "fönsterbågs": "fönsterbåge",
    "fönsterfärgen": "fönsterfärg",
    "fönsterfärgens": "fönsterfärg",
    "fönsterfärger": "fönsterfärg",
    "fönsterfärgerna": "fönsterfärg",
    "fönsterfärgernas": "fönsterfärg",
    "fönsterfärgers": "fönsterfärg",
    "fönsterfärgs": "fönsterfärg",
    "fönsterglasen": "fönsterglas",
    "fönsterglasens": "fönsterglas",
    "fönsterglaset": "fönsterglas",
    "fönsterglasets": "fönsterglas",
    "fönstergluggar": "fönsterglugg",
    "fönstergluggarna": "fönsterglugg",
    "fönstergluggarnas": "fönsterglugg",
    "fönstergluggars": "fönsterglugg",
    "fönstergluggen": "fönsterglugg",
    "fönstergluggens": "fönsterglugg",
    "fönstergluggs": "fönsterglugg",
    "fönsterkarmar": "fönsterkarm",
    "fönsterkarmarna": "fönsterkarm",
    "fönsterkarmarnas": "fönsterkarm",
    "fönsterkarmars": "fönsterkarm",
    "fönsterkarmen": "fönsterkarm",
    "fönsterkarmens": "fönsterkarm",
    "fönsterkarms": "fönsterkarm",
    "fönsterkitten": "fönsterkitt",
    "fönsterkittens": "fönsterkitt",
    "fönsterkittet": "fönsterkitt",
    "fönsterkittets": "fönsterkitt",
    "fönsterkitts": "fönsterkitt",
    "fönsterkuverten": "fönsterkuvert",
    "fönsterkuvertens": "fönsterkuvert",
    "fönsterkuvertet": "fönsterkuvert",
    "fönsterkuvertets": "fönsterkuvert",
    "fönsterkuverts": "fönsterkuvert",
    "fönsterluck": "fönsterlucka",
    "fönsterluckan": "fönsterlucka",
    "fönsterluckans": "fönsterlucka",
    "fönsterluckas": "fönsterlucka",
    "fönsterlucke": "fönsterlucka",
    "fönsterluckor": "fönsterlucka",
    "fönsterluckorna": "fönsterlucka",
    "fönsterluckornas": "fönsterlucka",
    "fönsterluckors": "fönsterlucka",
    "fönsterlucks": "fönsterlucka",
    "fönsterluften": "fönsterluft",
    "fönsterluftens": "fönsterluft",
    "fönsterlufter": "fönsterluft",
    "fönsterlufterna": "fönsterluft",
    "fönsterlufternas": "fönsterluft",
    "fönsterlufters": "fönsterluft",
    "fönsterlufts": "fönsterluft",
    "fönsterna": "fönster",
    "fönsternas": "fönster",
    "fönsternischen": "fönsternisch",
    "fönsternischens": "fönsternisch",
    "fönsternischer": "fönsternisch",
    "fönsternischerna": "fönsternisch",
    "fönsternischernas": "fönsternisch",
    "fönsternischers": "fönsternisch",
    "fönsternischs": "fönsternisch",
    "fönsterplatsen": "fönsterplats",
    "fönsterplatsens": "fönsterplats",
    "fönsterplatser": "fönsterplats",
    "fönsterplatserna": "fönsterplats",
    "fönsterplatsernas": "fönsterplats",
    "fönsterplatsers": "fönsterplats",
    "fönsterputsar": "fönsterputsare",
    "fönsterputsaren": "fönsterputsare",
    "fönsterputsarens": "fönsterputsare",
    "fönsterputsares": "fönsterputsare",
    "fönsterputsarna": "fönsterputsare",
    "fönsterputsarnas": "fönsterputsare",
    "fönsterputsdukar": "fönsterputsduk",
    "fönsterputsdukarna": "fönsterputsduk",
    "fönsterputsdukarnas": "fönsterputsduk",
    "fönsterputsdukars": "fönsterputsduk",
    "fönsterputsduken": "fönsterputsduk",
    "fönsterputsdukens": "fönsterputsduk",
    "fönsterputsduks": "fönsterputsduk",
    "fönsterrutan": "fönsterruta",
    "fönsterrutans": "fönsterruta",
    "fönsterrutas": "fönsterruta",
    "fönsterrute": "fönsterruta",
    "fönsterrutor": "fönsterruta",
    "fönsterrutorna": "fönsterruta",
    "fönsterrutornas": "fönsterruta",
    "fönsterrutors": "fönsterruta",
    "fönsters": "fönster",
    "fönstersmygar": "fönstersmyg",
    "fönstersmygarna": "fönstersmyg",
    "fönstersmygarnas": "fönstersmyg",
    "fönstersmygars": "fönstersmyg",
    "fönstersmygen": "fönstersmyg",
    "fönstersmygens": "fönstersmyg",
    "fönstersmygs": "fönstersmyg",
    "fönsterstolp": "fönsterstolpe",
    "fönsterstolpar": "fönsterstolpe",
    "fönsterstolparna": "fönsterstolpe",
    "fönsterstolparnas": "fönsterstolpe",
    "fönsterstolpars": "fönsterstolpe",
    "fönsterstolpen": "fönsterstolpe",
    "fönsterstolpens": "fönsterstolpe",
    "fönsterstolpes": "fönsterstolpe",
    "fönsterstolps": "fönsterstolpe",
    "fönstertittar": "fönstertittare",
    "fönstertittaren": "fönstertittare",
    "fönstertittarens": "fönstertittare",
    "fönstertittares": "fönstertittare",
    "fönstertittarna": "fönstertittare",
    "fönstertittarnas": "fönstertittare",
    "fönstren": "fönster",
    "fönstrens": "fönster",
    "fönstret": "fönster",
    "fönstrets": "fönster",
    "för": "föra",
    "förakt": "förakta",
    "föraktad": "förakta",
    "föraktade": "förakta",
    "föraktades": "förakta",
    "föraktads": "förakta",
    "föraktande": "förakta",
    "föraktanden": "föraktande",
    "föraktandena": "föraktande",
    "föraktandenas": "föraktande",
    "föraktandens": "föraktande",
    "föraktandes": "föraktande",
    "föraktandet": "föraktande",
    "föraktandets": "föraktande",
    "föraktar": "förakta",
    "föraktas": "förakta",
    "föraktat": "förakta",
    "föraktats": "förakta",
    "föraktet": "förakt",
    "föraktets": "förakt",
    "föraktfulla": "föraktfull",
    "föraktfullare": "föraktfull",
    "föraktfullares": "föraktfull",
    "föraktfullas": "föraktfull",
    "föraktfullast": "föraktfull",
    "föraktfullaste": "föraktfull",
    "föraktfullastes": "föraktfull",
    "föraktfullasts": "föraktfull",
    "föraktfulle": "föraktfull",
    "föraktfulles": "föraktfull",
    "föraktfullheten": "föraktfullhet",
    "föraktfullhetens": "föraktfullhet",
    "föraktfullheter": "föraktfullhet",
    "föraktfullheterna": "föraktfullhet",
    "föraktfullheternas": "föraktfullhet",
    "föraktfullheters": "föraktfullhet",
    "föraktfullhets": "föraktfullhet",
    "föraktfulls": "föraktfull",
    "föraktfullt": "föraktfull",
    "föraktfullts": "föraktfull",
    "föraktliga": "föraktlig",
    "föraktligare": "föraktlig",
    "föraktligares": "föraktlig",
    "föraktligas": "föraktlig",
    "föraktligast": "föraktlig",
    "föraktligaste": "föraktlig",
    "föraktligastes": "föraktlig",
    "föraktligasts": "föraktlig",
    "föraktlige": "föraktlig",
    "föraktliges": "föraktlig",
    "föraktligheten": "föraktlighet",
    "föraktlighetens": "föraktlighet",
    "föraktligheter": "föraktlighet",
    "föraktligheterna": "föraktlighet",
    "föraktligheternas": "föraktlighet",
    "föraktligheters": "föraktlighet",
    "föraktlighets": "föraktlighet",
    "föraktligs": "föraktlig",
    "föraktligt": "föraktlig",
    "föraktligts": "föraktlig",
    "förakts": "förakt",
    "förallmänlig": "förallmänliga",
    "förallmänligad": "förallmänliga",
    "förallmänligade": "förallmänliga",
    "förallmänligades": "förallmänliga",
    "förallmänligads": "förallmänliga",
    "förallmänligande": "förallmänliga",
    "förallmänliganden": "förallmänligande",
    "förallmänligandena": "förallmänligande",
    "förallmänligandenas": "förallmänligande",
    "förallmänligandens": "förallmänligande",
    "förallmänligandes": "förallmänligande",
    "förallmänligandet": "förallmänligande",
    "förallmänligandets": "förallmänligande",
    "förallmänligar": "förallmänliga",
    "förallmänligas": "förallmänliga",
    "förallmänligat": "förallmänliga",
    "förallmänligats": "förallmänliga",
    "förande": "föra",
    "föranden": "förande",
    "förandena": "förande",
    "förandenas": "förande",
    "förandens": "förande",
    "förandes": "förande",
    "förandet": "förande",
    "förandets": "förande",
    "förandlig": "förandliga",
    "förandligad": "förandliga",
    "förandligade": "förandligad",
    "förandligades": "förandligad",
    "förandligads": "förandligad",
    "förandligande": "förandliga",
    "förandliganden": "förandligande",
    "förandligandena": "förandligande",
    "förandligandenas": "förandligande",
    "förandligandens": "förandligande",
    "förandligandes": "förandligande",
    "förandligandet": "förandligande",
    "förandligandets": "förandligande",
    "förandligar": "förandliga",
    "förandligas": "förandliga",
    "förandligat": "förandligad",
    "förandligats": "förandligad",
    "föraningar": "föraning",
    "föraningarna": "föraning",
    "föraningarnas": "föraning",
    "föraningars": "föraning",
    "föraningen": "föraning",
    "föraningens": "föraning",
    "föranings": "föraning",
    "förankrad": "förankra",
    "förankrade": "förankra",
    "förankrades": "förankra",
    "förankrads": "förankra",
    "förankrande": "förankra",
    "förankranden": "förankrande",
    "förankrandena": "förankrande",
    "förankrandenas": "förankrande",
    "förankrandens": "förankrande",
    "förankrandes": "förankrande",
    "förankrandet": "förankrande",
    "förankrandets": "förankrande",
    "förankrar": "förankra",
    "förankras": "förankra",
    "förankrat": "förankra",
    "förankrats": "förankra",
    "förankringar": "förankring",
    "förankringarna": "förankring",
    "förankringarnas": "förankring",
    "förankringars": "förankring",
    "förankringen": "förankring",
    "förankringens": "förankring",
    "förankrings": "förankring",
    "föranled": "föranleda",
    "föranledande": "föranleda",
    "föranledanden": "föranledande",
    "föranledandena": "föranledande",
    "föranledandenas": "föranledande",
    "föranledandens": "föranledande",
    "föranledandes": "föranledande",
    "föranledandet": "föranledande",
    "föranledandets": "föranledande",
    "föranledas": "föranleda",
    "föranledd": "föranleda",
    "föranledda": "föranleda",
    "föranleddas": "föranleda",
    "föranledde": "föranleda",
    "föranleddes": "föranleda",
    "föranledds": "föranleda",
    "föranleder": "föranleda",
    "föranledes": "föranleda",
    "föranleds": "föranleda",
    "föranlett": "föranleda",
    "föranletts": "föranleda",
    "föranlåtens": "föranlåten",
    "föranlåtet": "föranlåten",
    "föranlåtets": "föranlåten",
    "föranlåtna": "föranlåten",
    "föranlåtnas": "föranlåten",
    "föranlåtne": "föranlåten",
    "föranlåtnes": "föranlåten",
    "föranmäl": "föranmäla",
    "föranmälande": "föranmäla",
    "föranmälanden": "föranmälande",
    "föranmälandena": "föranmälande",
    "föranmälandenas": "föranmälande",
    "föranmälandens": "föranmälande",
    "föranmälandes": "föranmälande",
    "föranmälandet": "föranmälande",
    "föranmälandets": "föranmälande",
    "föranmälans": "föranmälan",
    "föranmälas": "föranmäla",
    "föranmäld": "föranmäla",
    "föranmälda": "föranmäla",
    "föranmäldas": "föranmäla",
    "föranmälde": "föranmäla",
    "föranmäldes": "föranmäla",
    "föranmälds": "föranmäla",
    "föranmäler": "föranmäla",
    "föranmäles": "föranmäla",
    "föranmälningar": "föranmälning",
    "föranmälningarna": "föranmälning",
    "föranmälningarnas": "föranmälning",
    "föranmälningars": "föranmälning",
    "föranmälningen": "föranmälning",
    "föranmälningens": "föranmälning",
    "föranmälnings": "föranmälning",
    "föranmäls": "föranmäla",
    "föranmält": "föranmäla",
    "föranmälts": "föranmäla",
    "förannonserad": "förannonsera",
    "förannonserade": "förannonsera",
    "förannonserades": "förannonsera",
    "förannonserads": "förannonsera",
    "förannonserande": "förannonsera",
    "förannonseranden": "förannonserande",
    "förannonserandena": "förannonserande",
    "förannonserandenas": "förannonserande",
    "förannonserandens": "förannonserande",
    "förannonserandes": "förannonserande",
    "förannonserandet": "förannonserande",
    "förannonserandets": "förannonserande",
    "förannonserar": "förannonsera",
    "förannonseras": "förannonsera",
    "förannonserat": "förannonsera",
    "förannonserats": "förannonsera",
    "förannonserbara": "förannonserbar",
    "förannonserbarare": "förannonserbar",
    "förannonserbarares": "förannonserbar",
    "förannonserbaras": "förannonserbar",
    "förannonserbarast": "förannonserbar",
    "förannonserbaraste": "förannonserbar",
    "förannonserbarastes": "förannonserbar",
    "förannonserbarasts": "förannonserbar",
    "förannonserbare": "förannonserbar",
    "förannonserbares": "förannonserbar",
    "förannonserbarheten": "förannonserbarhet",
    "förannonserbarhetens": "förannonserbarhet",
    "förannonserbarhets": "förannonserbarhet",
    "förannonserbars": "förannonserbar",
    "förannonserbart": "förannonserbar",
    "förannonserbarts": "förannonserbar",
    "förannonseringar": "förannonsering",
    "förannonseringarna": "förannonsering",
    "förannonseringarnas": "förannonsering",
    "förannonseringars": "förannonsering",
    "förannonseringen": "förannonsering",
    "förannonseringens": "förannonsering",
    "förannonserings": "förannonsering",
    "föranstalt": "föranstalta",
    "föranstaltad": "föranstalta",
    "föranstaltade": "föranstalta",
    "föranstaltades": "föranstalta",
    "föranstaltads": "föranstalta",
    "föranstaltande": "föranstalta",
    "föranstaltanden": "föranstaltande",
    "föranstaltandena": "föranstaltande",
    "föranstaltandenas": "föranstaltande",
    "föranstaltandens": "föranstaltande",
    "föranstaltandes": "föranstaltande",
    "föranstaltandet": "föranstaltande",
    "föranstaltandets": "föranstaltande",
    "föranstaltans": "föranstaltan",
    "föranstaltar": "föranstalta",
    "föranstaltas": "föranstalta",
    "föranstaltat": "föranstalta",
    "föranstaltats": "föranstalta",
    "föranstaltningar": "föranstaltning",
    "föranstaltningarna": "föranstaltning",
    "föranstaltningarnas": "föranstaltning",
    "föranstaltningars": "föranstaltning",
    "föranstaltningen": "föranstaltning",
    "föranstaltningens": "föranstaltning",
    "föranstaltnings": "föranstaltning",
    "förar": "förare",
    "förarbeten": "förarbete",
    "förarbetena": "förarbete",
    "förarbetenas": "förarbete",
    "förarbetens": "förarbete",
    "förarbetes": "förarbete",
    "förarbetet": "förarbete",
    "förarbetets": "förarbete",
    "förarbets": "förarbete",
    "föraren": "förare",
    "förarens": "förare",
    "förares": "förare",
    "förarg": "förarga",
    "förargad": "förarga",
    "förargade": "förargad",
    "förargades": "förargas",
    "förargads": "förargad",
    "förargande": "förarga",
    "förarganden": "förargande",
    "förargandena": "förargande",
    "förargandenas": "förargande",
    "förargandens": "förargande",
    "förargandes": "förargande",
    "förargandet": "förargande",
    "förargandets": "förargande",
    "förargar": "förarga",
    "förargas": "förarga",
    "förargat": "förargad",
    "förargats": "förargas",
    "förargelseklipp": "förargelseklippa",
    "förargelseklippan": "förargelseklippa",
    "förargelseklippans": "förargelseklippa",
    "förargelseklippas": "förargelseklippa",
    "förargelseklippe": "förargelseklippa",
    "förargelseklippor": "förargelseklippa",
    "förargelseklipporna": "förargelseklippa",
    "förargelseklippornas": "förargelseklippa",
    "förargelseklippors": "förargelseklippa",
    "förargelseklipps": "förargelseklippa",
    "förargelsen": "förargelse",
    "förargelsens": "förargelse",
    "förargelses": "förargelse",
    "förargliga": "förarglig",
    "förargligare": "förarglig",
    "förargligares": "förarglig",
    "förargligas": "förarglig",
    "förargligast": "förarglig",
    "förargligaste": "förarglig",
    "förargligastes": "förarglig",
    "förargligasts": "förarglig",
    "förarglige": "förarglig",
    "förargliges": "förarglig",
    "förargligheten": "förarglighet",
    "förarglighetens": "förarglighet",
    "förargligheter": "förarglighet",
    "förargligheterna": "förarglighet",
    "förargligheternas": "förarglighet",
    "förargligheters": "förarglighet",
    "förarglighets": "förarglighet",
    "förargligs": "förarglig",
    "förargligt": "förarglig",
    "förargligts": "förarglig",
    "förarhytten": "förarhytt",
    "förarhyttens": "förarhytt",
    "förarhytter": "förarhytt",
    "förarhytterna": "förarhytt",
    "förarhytternas": "förarhytt",
    "förarhytters": "förarhytt",
    "förarhytts": "förarhytt",
    "förarkabinen": "förarkabin",
    "förarkabinens": "förarkabin",
    "förarkabiner": "förarkabin",
    "förarkabinerna": "förarkabin",
    "förarkabinernas": "förarkabin",
    "förarkabiners": "förarkabin",
    "förarkabins": "förarkabin",
    "förarlösa": "förarlös",
    "förarlösare": "förarlös",
    "förarlösares": "förarlös",
    "förarlösas": "förarlös",
    "förarlösast": "förarlös",
    "förarlösaste": "förarlös",
    "förarlösastes": "förarlös",
    "förarlösasts": "förarlös",
    "förarlöse": "förarlös",
    "förarlöses": "förarlös",
    "förarlöst": "förarlös",
    "förarlösts": "förarlös",
    "förarna": "förare",
    "förarnas": "förare",
    "förarplatsen": "förarplats",
    "förarplatsens": "förarplats",
    "förarplatser": "förarplats",
    "förarplatserna": "förarplats",
    "förarplatsernas": "förarplats",
    "förarplatsers": "förarplats",
    "förarrutan": "förarruta",
    "förarrutans": "förarruta",
    "förarrutas": "förarruta",
    "förarrute": "förarruta",
    "förarrutor": "förarruta",
    "förarrutorna": "förarruta",
    "förarrutornas": "förarruta",
    "förarrutors": "förarruta",
    "förars": "för",
    "förarsitsar": "förarsits",
    "förarsitsarna": "förarsits",
    "förarsitsarnas": "förarsits",
    "förarsitsars": "förarsits",
    "förarsitsen": "förarsits",
    "förarsitsens": "förarsits",
    "föras": "föra",
    "förband": "förbinda",
    "förbanden": "förband",
    "förbandens": "förband",
    "förbandet": "förband",
    "förbandets": "förband",
    "förbands": "förbinda",
    "förbandslåd": "förbandslåda",
    "förbandslådan": "förbandslåda",
    "förbandslådans": "förbandslåda",
    "förbandslådas": "förbandslåda",
    "förbandslåde": "förbandslåda",
    "förbandslådor": "förbandslåda",
    "förbandslådorna": "förbandslåda",
    "förbandslådornas": "förbandslåda",
    "förbandslådors": "förbandslåda",
    "förbandslåds": "förbandslåda",
    "förbandsplatsen": "förbandsplats",
    "förbandsplatsens": "förbandsplats",
    "förbandsplatser": "förbandsplats",
    "förbandsplatserna": "förbandsplats",
    "förbandsplatsernas": "förbandsplats",
    "förbandsplatsers": "förbandsplats",
    "förbann": "förbanna",
    "förbannad": "förbanna",
    "förbannade": "förbannad",
    "förbannades": "förbannad",
    "förbannads": "förbannad",
    "förbannande": "förbanna",
    "förbannanden": "förbannande",
    "förbannandena": "förbannande",
    "förbannandenas": "förbannande",
    "förbannandens": "förbannande",
    "förbannandes": "förbannande",
    "förbannandet": "förbannande",
    "förbannandets": "förbannande",
    "förbannar": "förbanna",
    "förbannas": "förbanna",
    "förbannat": "förbannad",
    "förbannats": "förbannad",
    "förbannelsen": "förbannelse",
    "förbannelsens": "förbannelse",
    "förbannelser": "förbannelse",
    "förbannelserna": "förbannelse",
    "förbannelsernas": "förbannelse",
    "förbannelsers": "förbannelse",
    "förbannelses": "förbannelse",
    "förbarmandes": "förbarmande",
    "förbarmandet": "förbarmande",
    "förbarmandets": "förbarmande",
    "förbaskade": "förbaskad",
    "förbaskades": "förbaskad",
    "förbaskads": "förbaskad",
    "förbaskat": "förbaskad",
    "förbaskats": "förbaskad",
    "förbehandlingar": "förbehandling",
    "förbehandlingarna": "förbehandling",
    "förbehandlingarnas": "förbehandling",
    "förbehandlingars": "förbehandling",
    "förbehandlingen": "förbehandling",
    "förbehandlingens": "förbehandling",
    "förbehandlings": "förbehandling",
    "förbehåll": "förbehålla",
    "förbehållande": "förbehålla",
    "förbehållanden": "förbehållande",
    "förbehållandena": "förbehållande",
    "förbehållandenas": "förbehållande",
    "förbehållandens": "förbehållande",
    "förbehållandes": "förbehållande",
    "förbehållandet": "förbehållande",
    "förbehållandets": "förbehållande",
    "förbehållas": "förbehålla",
    "förbehålle": "förbehålla",
    "förbehållen": "förbehålla",
    "förbehållens": "förbehålla",
    "förbehåller": "förbehålla",
    "förbehålles": "förbehålla",
    "förbehållet": "förbehålla",
    "förbehållets": "förbehålla",
    "förbehållit": "förbehålla",
    "förbehållits": "förbehålla",
    "förbehållna": "förbehålla",
    "förbehållnas": "förbehålla",
    "förbehållne": "förbehålla",
    "förbehållnes": "förbehålla",
    "förbehålls": "förbehålla",
    "förbehållsamheten": "förbehållsamhet",
    "förbehållsamhetens": "förbehållsamhet",
    "förbehållsamheter": "förbehållsamhet",
    "förbehållsamheterna": "förbehållsamhet",
    "förbehållsamheternas": "förbehållsamhet",
    "förbehållsamheters": "förbehållsamhet",
    "förbehållsamhets": "förbehållsamhet",
    "förbehållsamma": "förbehållsam",
    "förbehållsammare": "förbehållsam",
    "förbehållsammares": "förbehållsam",
    "förbehållsammas": "förbehållsam",
    "förbehållsammast": "förbehållsam",
    "förbehållsammaste": "förbehållsam",
    "förbehållsammastes": "förbehållsam",
    "förbehållsammasts": "förbehållsam",
    "förbehållsamme": "förbehållsam",
    "förbehållsammes": "förbehållsam",
    "förbehållsams": "förbehållsam",
    "förbehållsamt": "förbehållsam",
    "förbehållsamts": "förbehållsam",
    "förbehållslösa": "förbehållslös",
    "förbehållslösare": "förbehållslös",
    "förbehållslösares": "förbehållslös",
    "förbehållslösas": "förbehållslös",
    "förbehållslösast": "förbehållslös",
    "förbehållslösaste": "förbehållslös",
    "förbehållslösastes": "förbehållslös",
    "förbehållslösasts": "förbehållslös",
    "förbehållslöse": "förbehållslös",
    "förbehållslöses": "förbehållslös",
    "förbehållslösheten": "förbehållslöshet",
    "förbehållslöshetens": "förbehållslöshet",
    "förbehållslöshets": "förbehållslöshet",
    "förbehållslöst": "förbehållslös",
    "förbehållslösts": "förbehållslös",
    "förbehöll": "förbehålla",
    "förbehölle": "förbehålla",
    "förbehölles": "förbehålla",
    "förbehölls": "förbehålla",
    "förbenade": "förbenad",
    "förbenades": "förbenad",
    "förbenads": "förbenad",
    "förbenat": "förbenad",
    "förbenats": "förbenad",
    "förbered": "förbereda",
    "förberedande": "förbereda",
    "förberedanden": "förberedande",
    "förberedandena": "förberedande",
    "förberedandenas": "förberedande",
    "förberedandens": "förberedande",
    "förberedandes": "förberedande",
    "förberedandet": "förberedande",
    "förberedandets": "förberedande",
    "förberedas": "förbereda",
    "förberedd": "förbereda",
    "förberedda": "förberedd",
    "förbereddare": "förberedd",
    "förbereddares": "förberedd",
    "förbereddas": "förberedd",
    "förbereddast": "förberedd",
    "förbereddaste": "förberedd",
    "förbereddastes": "förberedd",
    "förbereddasts": "förberedd",
    "förberedde": "förberedd",
    "förbereddes": "förberedd",
    "förberedds": "förberedd",
    "förberedelsen": "förberedelse",
    "förberedelsens": "förberedelse",
    "förberedelser": "förberedelse",
    "förberedelserna": "förberedelse",
    "förberedelsernas": "förberedelse",
    "förberedelsers": "förberedelse",
    "förberedelses": "förberedelse",
    "förbereder": "förbereda",
    "förberedes": "förbereda",
    "förbereds": "förbereda",
    "förberett": "förberedd",
    "förberetts": "förberedd",
    "förbergen": "förberg",
    "förbergens": "förberg",
    "förberget": "förberg",
    "förbergets": "förberg",
    "förbergs": "förberg",
    "förbid": "förbida",
    "förbidad": "förbida",
    "förbidade": "förbida",
    "förbidades": "förbida",
    "förbidads": "förbida",
    "förbidande": "förbida",
    "förbidanden": "förbidande",
    "förbidandena": "förbidande",
    "förbidandenas": "förbidande",
    "förbidandens": "förbidande",
    "förbidandes": "förbidande",
    "förbidandet": "förbidande",
    "förbidandets": "förbidande",
    "förbidans": "förbidan",
    "förbidar": "förbida",
    "förbidas": "förbida",
    "förbidat": "förbida",
    "förbidats": "förbida",
    "förbifarten": "förbifart",
    "förbifartens": "förbifart",
    "förbifarter": "förbifart",
    "förbifarterna": "förbifart",
    "förbifarternas": "förbifart",
    "förbifarters": "förbifart",
    "förbifarts": "förbifart",
    "förbifartsleden": "förbifartsled",
    "förbifartsledens": "förbifartsled",
    "förbifartsleder": "förbifartsled",
    "förbifartslederna": "förbifartsled",
    "förbifartsledernas": "förbifartsled",
    "förbifartsleders": "förbifartsled",
    "förbifartsleds": "förbifartsled",
    "förbigick": "förbigå",
    "förbigicks": "förbigå",
    "förbiginge": "förbigå",
    "förbiginges": "förbigå",
    "förbigående": "förbigå",
    "förbigåenden": "förbigående",
    "förbigåendena": "förbigående",
    "förbigåendenas": "förbigående",
    "förbigåendens": "förbigående",
    "förbigåendes": "förbigående",
    "förbigåendet": "förbigående",
    "förbigåendets": "förbigående",
    "förbigånge": "förbigå",
    "förbigången": "förbigå",
    "förbigångens": "förbigången",
    "förbigånges": "förbigå",
    "förbigånget": "förbigången",
    "förbigångets": "förbigången",
    "förbigångna": "förbigången",
    "förbigångnare": "förbigången",
    "förbigångnares": "förbigången",
    "förbigångnas": "förbigången",
    "förbigångnast": "förbigången",
    "förbigångnaste": "förbigången",
    "förbigångnastes": "förbigången",
    "förbigångnasts": "förbigången",
    "förbigångne": "förbigången",
    "förbigångnes": "förbigången",
    "förbigår": "förbigå",
    "förbigås": "förbigå",
    "förbigått": "förbigå",
    "förbigåtts": "förbigå",
    "förbillig": "förbilliga",
    "förbilligad": "förbilliga",
    "förbilligade": "förbilliga",
    "förbilligades": "förbilliga",
    "förbilligads": "förbilliga",
    "förbilligande": "förbilliga",
    "förbilliganden": "förbilligande",
    "förbilligandena": "förbilligande",
    "förbilligandenas": "förbilligande",
    "förbilligandens": "förbilligande",
    "förbilligandes": "förbilligande",
    "förbilligandet": "förbilligande",
    "förbilligandets": "förbilligande",
    "förbilligar": "förbilliga",
    "förbilligas": "förbilliga",
    "förbilligat": "förbilliga",
    "förbilligats": "förbilliga",
    "förbind": "förbinda",
    "förbindande": "förbinda",
    "förbindanden": "förbindande",
    "förbindandena": "förbindande",
    "förbindandenas": "förbindande",
    "förbindandens": "förbindande",
    "förbindandes": "förbindande",
    "förbindandet": "förbindande",
    "förbindandets": "förbindande",
    "förbindas": "förbinda",
    "förbinde": "förbinda",
    "förbindelsearbeten": "förbindelsearbete",
    "förbindelsearbetena": "förbindelsearbete",
    "förbindelsearbetenas": "förbindelsearbete",
    "förbindelsearbetens": "förbindelsearbete",
    "förbindelsearbetes": "förbindelsearbete",
    "förbindelsearbetet": "förbindelsearbete",
    "förbindelsearbetets": "förbindelsearbete",
    "förbindelsearbets": "förbindelsearbete",
    "förbindelsegångar": "förbindelsegång",
    "förbindelsegångarna": "förbindelsegång",
    "förbindelsegångarnas": "förbindelsegång",
    "förbindelsegångars": "förbindelsegång",
    "förbindelsegången": "förbindelsegång",
    "förbindelsegångens": "förbindelsegång",
    "förbindelsegångs": "förbindelsegång",
    "förbindelseleden": "förbindelseled",
    "förbindelseledens": "förbindelseled",
    "förbindelseleder": "förbindelseled",
    "förbindelselederna": "förbindelseled",
    "förbindelseledernas": "förbindelseled",
    "förbindelseleders": "förbindelseled",
    "förbindelseleds": "förbindelseled",
    "förbindelsen": "förbindelse",
    "förbindelsens": "förbindelse",
    "förbindelser": "förbindelse",
    "förbindelserna": "förbindelse",
    "förbindelsernas": "förbindelse",
    "förbindelsers": "förbindelse",
    "förbindelses": "förbindelse",
    "förbinder": "förbinda",
    "förbindes": "förbinda",
    "förbindliga": "förbindlig",
    "förbindligare": "förbindlig",
    "förbindligares": "förbindlig",
    "förbindligas": "förbindlig",
    "förbindligast": "förbindlig",
    "förbindligaste": "förbindlig",
    "förbindligastes": "förbindlig",
    "förbindligasts": "förbindlig",
    "förbindlige": "förbindlig",
    "förbindliges": "förbindlig",
    "förbindligheten": "förbindlighet",
    "förbindlighetens": "förbindlighet",
    "förbindlighets": "förbindlighet",
    "förbindligs": "förbindlig",
    "förbindligt": "förbindlig",
    "förbindligts": "förbindlig",
    "förbindningar": "förbindning",
    "förbindningarna": "förbindning",
    "förbindningarnas": "förbindning",
    "förbindningars": "förbindning",
    "förbindningen": "förbindning",
    "förbindningens": "förbindning",
    "förbindnings": "förbindning",
    "förbinds": "förbinda",
    "förbisedd": "förbise",
    "förbisedda": "förbise",
    "förbiseddas": "förbise",
    "förbisedde": "förbise",
    "förbiseddes": "förbise",
    "förbisedds": "förbise",
    "förbiseende": "förbise",
    "förbiseenden": "förbiseende",
    "förbiseendena": "förbiseende",
    "förbiseendenas": "förbiseende",
    "förbiseendens": "förbiseende",
    "förbiseendes": "förbiseende",
    "förbiseendet": "förbiseende",
    "förbiseendets": "förbiseende",
    "förbiser": "förbise",
    "förbises": "förbise",
    "förbisett": "förbise",
    "förbisetts": "förbise",
    "förbistringar": "förbistring",
    "förbistringarna": "förbistring",
    "förbistringarnas": "förbistring",
    "förbistringars": "förbistring",
    "förbistringen": "förbistring",
    "förbistringens": "förbistring",
    "förbistrings": "förbistring",
    "förbisåg": "förbise",
    "förbisåge": "förbise",
    "förbisåges": "förbise",
    "förbisågs": "förbise",
    "förbittrad": "förbittra",
    "förbittrade": "förbittrad",
    "förbittrades": "förbittrad",
    "förbittrads": "förbittrad",
    "förbittrande": "förbittra",
    "förbittranden": "förbittrande",
    "förbittrandena": "förbittrande",
    "förbittrandenas": "förbittrande",
    "förbittrandens": "förbittrande",
    "förbittrandes": "förbittrande",
    "förbittrandet": "förbittrande",
    "förbittrandets": "förbittrande",
    "förbittrar": "förbittra",
    "förbittras": "förbittra",
    "förbittrat": "förbittrad",
    "förbittrats": "förbittrad",
    "förbittringar": "förbittring",
    "förbittringarna": "förbittring",
    "förbittringarnas": "förbittring",
    "förbittringars": "förbittring",
    "förbittringen": "förbittring",
    "förbittringens": "förbittring",
    "förbittrings": "förbittring",
    "förbjud": "förbjuda",
    "förbjudande": "förbjuda",
    "förbjudanden": "förbjudande",
    "förbjudandena": "förbjudande",
    "förbjudandenas": "förbjudande",
    "förbjudandens": "förbjudande",
    "förbjudandes": "förbjudande",
    "förbjudandet": "förbjudande",
    "förbjudandets": "förbjudande",
    "förbjudas": "förbjuda",
    "förbjude": "förbjuda",
    "förbjuden": "förbjuda",
    "förbjudenheten": "förbjudenhet",
    "förbjudenhetens": "förbjudenhet",
    "förbjudenhets": "förbjudenhet",
    "förbjudens": "förbjuden",
    "förbjuder": "förbjuda",
    "förbjudes": "förbjuda",
    "förbjudet": "förbjuden",
    "förbjudets": "förbjuden",
    "förbjudit": "förbjuda",
    "förbjudits": "förbjuda",
    "förbjudna": "förbjuden",
    "förbjudnare": "förbjuden",
    "förbjudnares": "förbjuden",
    "förbjudnas": "förbjuden",
    "förbjudnast": "förbjuden",
    "förbjudnaste": "förbjuden",
    "förbjudnastes": "förbjuden",
    "förbjudnasts": "förbjuden",
    "förbjudne": "förbjuden",
    "förbjudnes": "förbjuden",
    "förbjuds": "förbjuda",
    "förbjöd": "förbjuda",
    "förbjöde": "förbjuda",
    "förbjödes": "förbjuda",
    "förbjöds": "förbjuda",
    "förbland": "förblanda",
    "förblandad": "förblanda",
    "förblandade": "förblanda",
    "förblandades": "förblanda",
    "förblandads": "förblanda",
    "förblandande": "förblanda",
    "förblandanden": "förblandande",
    "förblandandena": "förblandande",
    "förblandandenas": "förblandande",
    "förblandandens": "förblandande",
    "förblandandes": "förblandande",
    "förblandandet": "förblandande",
    "förblandandets": "förblandande",
    "förblandar": "förblanda",
    "förblandas": "förblanda",
    "förblandat": "förblanda",
    "förblandats": "förblanda",
    "förblekn": "förblekna",
    "förbleknad": "förblekna",
    "förbleknade": "förblekna",
    "förbleknades": "förblekna",
    "förbleknads": "förblekna",
    "förbleknande": "förblekna",
    "förbleknanden": "förbleknande",
    "förbleknandena": "förbleknande",
    "förbleknandenas": "förbleknande",
    "förbleknandens": "förbleknande",
    "förbleknandes": "förbleknande",
    "förbleknandet": "förbleknande",
    "förbleknandets": "förbleknande",
    "förbleknar": "förblekna",
    "förbleknas": "förblekna",
    "förbleknat": "förblekna",
    "förbleknats": "förblekna",
    "förblev": "förbli",
    "förbleve": "förbli",
    "förblind": "förblinda",
    "förblindad": "förblinda",
    "förblindade": "förblinda",
    "förblindades": "förblinda",
    "förblindads": "förblinda",
    "förblindande": "förblinda",
    "förblindanden": "förblindande",
    "förblindandena": "förblindande",
    "förblindandenas": "förblindande",
    "förblindandens": "förblindande",
    "förblindandes": "förblindande",
    "förblindandet": "förblindande",
    "förblindandets": "förblindande",
    "förblindar": "förblinda",
    "förblindas": "förblinda",
    "förblindat": "förblinda",
    "förblindats": "förblinda",
    "förblir": "förbli",
    "förbliv": "förbli",
    "förbliva": "förbli",
    "förblivande": "förbli",
    "förblivanden": "förblivande",
    "förblivandena": "förblivande",
    "förblivandenas": "förblivande",
    "förblivandens": "förblivande",
    "förblivandes": "förblivande",
    "förblivandet": "förblivande",
    "förblivandets": "förblivande",
    "förblive": "förbli",
    "förbliven": "förbli",
    "förblivens": "förbli",
    "förbliver": "förbli",
    "förblivet": "förbli",
    "förblivets": "förbli",
    "förblivit": "förbli",
    "förblivna": "förbli",
    "förblivnas": "förbli",
    "förblivne": "förbli",
    "förblivnes": "förbli",
    "förblommerade": "förblommerad",
    "förblommerades": "förblommerad",
    "förblommerads": "förblommerad",
    "förblommerat": "förblommerad",
    "förblommerats": "förblommerad",
    "förbluff": "förbluffa",
    "förbluffad": "förbluffa",
    "förbluffade": "förbluffad",
    "förbluffades": "förbluffad",
    "förbluffads": "förbluffad",
    "förbluffande": "förbluffa",
    "förbluffanden": "förbluffande",
    "förbluffandena": "förbluffande",
    "förbluffandenas": "förbluffande",
    "förbluffandens": "förbluffande",
    "förbluffandes": "förbluffande",
    "förbluffandet": "förbluffande",
    "förbluffandets": "förbluffande",
    "förbluffar": "förbluffa",
    "förbluffas": "förbluffa",
    "förbluffat": "förbluffad",
    "förbluffats": "förbluffad",
    "förblöd": "förblöda",
    "förblödande": "förblöda",
    "förblödanden": "förblödande",
    "förblödandena": "förblödande",
    "förblödandenas": "förblödande",
    "förblödandens": "förblödande",
    "förblödandes": "förblödande",
    "förblödandet": "förblödande",
    "förblödandets": "förblödande",
    "förblödas": "förblöda",
    "förblödd": "förblöda",
    "förblödda": "förblöda",
    "förblöddas": "förblöda",
    "förblödde": "förblöda",
    "förblöddes": "förblöda",
    "förblödds": "förblöda",
    "förblöder": "förblöda",
    "förblödes": "förblöda",
    "förblöds": "förblöda",
    "förblött": "förblöda",
    "förblötts": "förblöda",
    "förbommade": "förbommad",
    "förbommades": "förbommad",
    "förbommads": "förbommad",
    "förbommat": "förbommad",
    "förbommats": "förbommad",
    "förborg": "förborga",
    "förborgad": "förborga",
    "förborgade": "förborga",
    "förborgades": "förborga",
    "förborgads": "förborga",
    "förborgande": "förborga",
    "förborganden": "förborgande",
    "förborgandena": "förborgande",
    "förborgandenas": "förborgande",
    "förborgandens": "förborgande",
    "förborgandes": "förborgande",
    "förborgandet": "förborgande",
    "förborgandets": "förborgande",
    "förborgar": "förborga",
    "förborgas": "förborga",
    "förborgat": "förborga",
    "förborgats": "förborga",
    "förborgerlig": "förborgerliga",
    "förborgerligad": "förborgerliga",
    "förborgerligade": "förborgerliga",
    "förborgerligades": "förborgerliga",
    "förborgerligads": "förborgerliga",
    "förborgerligande": "förborgerliga",
    "förborgerliganden": "förborgerligande",
    "förborgerligandena": "förborgerligande",
    "förborgerligandenas": "förborgerligande",
    "förborgerligandens": "förborgerligande",
    "förborgerligandes": "förborgerligande",
    "förborgerligandet": "förborgerligande",
    "förborgerligandets": "förborgerligande",
    "förborgerligar": "förborgerliga",
    "förborgerligas": "förborgerliga",
    "förborgerligat": "förborgerliga",
    "förborgerligats": "förborgerliga",
    "förbrann": "förbrinna",
    "förbranns": "förbrinna",
    "förbrinn": "förbrinna",
    "förbrinnande": "förbrinna",
    "förbrinnanden": "förbrinnande",
    "förbrinnandena": "förbrinnande",
    "förbrinnandenas": "förbrinnande",
    "förbrinnandens": "förbrinnande",
    "förbrinnandes": "förbrinnande",
    "förbrinnandet": "förbrinnande",
    "förbrinnandets": "förbrinnande",
    "förbrinnas": "förbrinna",
    "förbrinne": "förbrinna",
    "förbrinner": "förbrinna",
    "förbrinnes": "förbrinna",
    "förbrinns": "förbrinna",
    "förbroskades": "förbroskas",
    "förbroskats": "förbroskas",
    "förbruk": "förbruka",
    "förbrukad": "förbruka",
    "förbrukade": "förbruka",
    "förbrukades": "förbruka",
    "förbrukads": "förbruka",
    "förbrukande": "förbruka",
    "förbrukanden": "förbrukande",
    "förbrukandena": "förbrukande",
    "förbrukandenas": "förbrukande",
    "förbrukandens": "förbrukande",
    "förbrukandes": "förbrukande",
    "förbrukandet": "förbrukande",
    "förbrukandets": "förbrukande",
    "förbrukar": "förbrukare",
    "förbrukaren": "förbrukare",
    "förbrukarens": "förbrukare",
    "förbrukares": "förbrukare",
    "förbrukarna": "förbrukare",
    "förbrukarnas": "förbrukare",
    "förbrukas": "förbruka",
    "förbrukat": "förbruka",
    "förbrukats": "förbruka",
    "förbrukningar": "förbrukning",
    "förbrukningarna": "förbrukning",
    "förbrukningarnas": "förbrukning",
    "förbrukningars": "förbrukning",
    "förbrukningen": "förbrukning",
    "förbrukningens": "förbrukning",
    "förbruknings": "förbrukning",
    "förbrukningsartikeln": "förbrukningsartikel",
    "förbrukningsartikelns": "förbrukningsartikel",
    "förbrukningsartikels": "förbrukningsartikel",
    "förbrukningsartiklar": "förbrukningsartikel",
    "förbrukningsartiklarna": "förbrukningsartikel",
    "förbrukningsartiklarnas": "förbrukningsartikel",
    "förbrukningsartiklars": "förbrukningsartikel",
    "förbrukningsmaterialen": "förbrukningsmaterial",
    "förbrukningsmaterialens": "förbrukningsmaterial",
    "förbrukningsmaterialet": "förbrukningsmaterial",
    "förbrukningsmaterialets": "förbrukningsmaterial",
    "förbrukningsmaterials": "förbrukningsmaterial",
    "förbrunna": "förbrinna",
    "förbrunnas": "förbrinna",
    "förbrunne": "förbrinna",
    "förbrunnen": "förbrinna",
    "förbrunnens": "förbrinna",
    "förbrunnes": "förbrinna",
    "förbrunnet": "förbrinna",
    "förbrunnets": "förbrinna",
    "förbrunnit": "förbrinna",
    "förbrunnits": "förbrinna",
    "förbryll": "förbrylla",
    "förbryllad": "förbrylla",
    "förbryllade": "förbrylla",
    "förbryllades": "förbrylla",
    "förbryllads": "förbrylla",
    "förbryllande": "förbrylla",
    "förbryllanden": "förbryllande",
    "förbryllandena": "förbryllande",
    "förbryllandenas": "förbryllande",
    "förbryllandens": "förbryllande",
    "förbryllandes": "förbryllande",
    "förbryllandet": "förbryllande",
    "förbryllandets": "förbryllande",
    "förbryllar": "förbrylla",
    "förbryllas": "förbrylla",
    "förbryllat": "förbrylla",
    "förbryllats": "förbrylla",
    "förbrytar": "förbrytare",
    "förbrytaren": "förbrytare",
    "förbrytarens": "förbrytare",
    "förbrytares": "förbrytare",
    "förbrytarna": "förbrytare",
    "förbrytarnas": "förbrytare",
    "förbrytelsen": "förbrytelse",
    "förbrytelsens": "förbrytelse",
    "förbrytelser": "förbrytelse",
    "förbrytelserna": "förbrytelse",
    "förbrytelsernas": "förbrytelse",
    "förbrytelsers": "förbrytelse",
    "förbrytelses": "förbrytelse",
    "förbränd": "förbränna",
    "förbrända": "förbränna",
    "förbrändas": "förbränna",
    "förbrände": "förbränna",
    "förbrändes": "förbränna",
    "förbränds": "förbränna",
    "förbränn": "förbränna",
    "förbrännande": "förbränna",
    "förbrännanden": "förbrännande",
    "förbrännandena": "förbrännande",
    "förbrännandenas": "förbrännande",
    "förbrännandens": "förbrännande",
    "förbrännandes": "förbrännande",
    "förbrännandet": "förbrännande",
    "förbrännandets": "förbrännande",
    "förbrännas": "förbränna",
    "förbränner": "förbränna",
    "förbrännes": "förbränna",
    "förbränningar": "förbränning",
    "förbränningarna": "förbränning",
    "förbränningarnas": "förbränning",
    "förbränningars": "förbränning",
    "förbränningen": "förbränning",
    "förbränningens": "förbränning",
    "förbrännings": "förbränning",
    "förbränningsmotorer": "förbränningsmotor",
    "förbränningsmotorerna": "förbränningsmotor",
    "förbränningsmotorernas": "förbränningsmotor",
    "förbränningsmotorers": "förbränningsmotor",
    "förbränningsmotorn": "förbränningsmotor",
    "förbränningsmotorns": "förbränningsmotor",
    "förbränningsmotors": "förbränningsmotor",
    "förbränningsprodukten": "förbränningsprodukt",
    "förbränningsproduktens": "förbränningsprodukt",
    "förbränningsprodukter": "förbränningsprodukt",
    "förbränningsprodukterna": "förbränningsprodukt",
    "förbränningsprodukternas": "förbränningsprodukt",
    "förbränningsprodukters": "förbränningsprodukt",
    "förbränningsprodukts": "förbränningsprodukt",
    "förbränns": "förbränna",
    "förbränt": "förbränna",
    "förbränts": "förbränna",
    "förbrödrad": "förbrödra",
    "förbrödrade": "förbrödra",
    "förbrödrades": "förbrödra",
    "förbrödrads": "förbrödra",
    "förbrödrande": "förbrödra",
    "förbrödranden": "förbrödrande",
    "förbrödrandena": "förbrödrande",
    "förbrödrandenas": "förbrödrande",
    "förbrödrandens": "förbrödrande",
    "förbrödrandes": "förbrödrande",
    "förbrödrandet": "förbrödrande",
    "förbrödrandets": "förbrödrande",
    "förbrödrar": "förbrödra",
    "förbrödras": "förbrödra",
    "förbrödrat": "förbrödra",
    "förbrödrats": "förbrödra",
    "förbrödringar": "förbrödring",
    "förbrödringarna": "förbrödring",
    "förbrödringarnas": "förbrödring",
    "förbrödringars": "förbrödring",
    "förbrödringen": "förbrödring",
    "förbrödringens": "förbrödring",
    "förbrödrings": "förbrödring",
    "förbuden": "förbud",
    "förbudens": "förbud",
    "förbudet": "förbud",
    "förbudets": "förbud",
    "förbuds": "förbud",
    "förbunde": "förbinda",
    "förbunden": "förbund",
    "förbundenheten": "förbundenhet",
    "förbundenhetens": "förbundenhet",
    "förbundenhets": "förbundenhet",
    "förbundens": "förbunden",
    "förbundes": "förbinda",
    "förbundet": "förbunden",
    "förbundets": "förbunden",
    "förbundit": "förbinda",
    "förbundits": "förbinda",
    "förbundna": "förbunden",
    "förbundnare": "förbunden",
    "förbundnares": "förbunden",
    "förbundnas": "förbunden",
    "förbundnast": "förbunden",
    "förbundnaste": "förbunden",
    "förbundnastes": "förbunden",
    "förbundnasts": "förbunden",
    "förbundne": "förbunden",
    "förbundnes": "förbunden",
    "förbunds": "förbund",
    "förbundsbreven": "förbundsbrev",
    "förbundsbrevens": "förbundsbrev",
    "förbundsbrevet": "förbundsbrev",
    "förbundsbrevets": "förbundsbrev",
    "förbundsbrevs": "förbundsbrev",
    "förbundsdagar": "förbundsdag",
    "förbundsdagarna": "förbundsdag",
    "förbundsdagarnas": "förbundsdag",
    "förbundsdagars": "förbundsdag",
    "förbundsdagen": "förbundsdag",
    "förbundsdagens": "förbundsdag",
    "förbundsdags": "förbundsdag",
    "förbundskanslerer": "förbundskansler",
    "förbundskanslererna": "förbundskansler",
    "förbundskanslerernas": "förbundskansler",
    "förbundskanslerers": "förbundskansler",
    "förbundskanslern": "förbundskansler",
    "förbundskanslerns": "förbundskansler",
    "förbundskanslers": "förbundskansler",
    "förbundskaptenen": "förbundskapten",
    "förbundskaptenens": "förbundskapten",
    "förbundskaptener": "förbundskapten",
    "förbundskaptenerna": "förbundskapten",
    "förbundskaptenernas": "förbundskapten",
    "förbundskapteners": "förbundskapten",
    "förbundskaptens": "förbundskapten",
    "förbundspresidenten": "förbundspresident",
    "förbundspresidentens": "förbundspresident",
    "förbundspresidenter": "förbundspresident",
    "förbundspresidenterna": "förbundspresident",
    "förbundspresidenternas": "förbundspresident",
    "förbundspresidenters": "förbundspresident",
    "förbundspresidents": "förbundspresident",
    "förbundsregeringar": "förbundsregering",
    "förbundsregeringarna": "förbundsregering",
    "förbundsregeringarnas": "förbundsregering",
    "förbundsregeringars": "förbundsregering",
    "förbundsregeringen": "förbundsregering",
    "förbundsregeringens": "förbundsregering",
    "förbundsregerings": "förbundsregering",
    "förbundsrepubliken": "förbundsrepublik",
    "förbundsrepublikens": "förbundsrepublik",
    "förbundsrepubliker": "förbundsrepublik",
    "förbundsrepublikerna": "förbundsrepublik",
    "förbundsrepublikernas": "förbundsrepublik",
    "förbundsrepublikers": "förbundsrepublik",
    "förbundsrepubliks": "förbundsrepublik",
    "förbundsstaten": "förbundsstat",
    "förbundsstatens": "förbundsstat",
    "förbundsstater": "förbundsstat",
    "förbundsstaterna": "förbundsstat",
    "förbundsstaternas": "förbundsstat",
    "förbundsstaters": "förbundsstat",
    "förbundsstats": "förbundsstat",
    "förbusk": "förbuska",
    "förbuskad": "förbuska",
    "förbuskade": "förbuska",
    "förbuskades": "förbuska",
    "förbuskads": "förbuska",
    "förbuskande": "förbuska",
    "förbuskanden": "förbuskande",
    "förbuskandena": "förbuskande",
    "förbuskandenas": "förbuskande",
    "förbuskandens": "förbuskande",
    "förbuskandes": "förbuskande",
    "förbuskandet": "förbuskande",
    "förbuskandets": "förbuskande",
    "förbuskar": "förbuska",
    "förbuskas": "förbuska",
    "förbuskat": "förbuska",
    "förbuskats": "förbuska",
    "förbygg": "förbygga",
    "förbyggande": "förbygga",
    "förbygganden": "förbyggande",
    "förbyggandena": "förbyggande",
    "förbyggandenas": "förbyggande",
    "förbyggandens": "förbyggande",
    "förbyggandes": "förbyggande",
    "förbyggandet": "förbyggande",
    "förbyggandets": "förbyggande",
    "förbyggas": "förbygga",
    "förbyggd": "förbygga",
    "förbyggda": "förbygga",
    "förbyggdas": "förbygga",
    "förbyggde": "förbygga",
    "förbyggdes": "förbygga",
    "förbyggds": "förbygga",
    "förbygger": "förbygga",
    "förbygges": "förbygga",
    "förbyggnaden": "förbyggnad",
    "förbyggnadens": "förbyggnad",
    "förbyggnader": "förbyggnad",
    "förbyggnaderna": "förbyggnad",
    "förbyggnadernas": "förbyggnad",
    "förbyggnaders": "förbyggnad",
    "förbyggnads": "förbyggnad",
    "förbyggs": "förbygga",
    "förbyggt": "förbygga",
    "förbyggts": "förbygga",
    "förbyt": "förbyta",
    "förbytande": "förbyta",
    "förbytanden": "förbytande",
    "förbytandena": "förbytande",
    "förbytandenas": "förbytande",
    "förbytandens": "förbytande",
    "förbytandes": "förbytande",
    "förbytandet": "förbytande",
    "förbytandets": "förbytande",
    "förbytas": "förbyta",
    "förbyter": "förbyta",
    "förbytes": "förbyta",
    "förbyts": "förbyta",
    "förbytt": "förbyta",
    "förbytta": "förbyta",
    "förbyttas": "förbyta",
    "förbytte": "förbyta",
    "förbyttes": "förbyta",
    "förbytts": "förbyta",
    "förbätterliga": "förbätterlig",
    "förbätterligare": "förbätterlig",
    "förbätterligares": "förbätterlig",
    "förbätterligas": "förbätterlig",
    "förbätterligast": "förbätterlig",
    "förbätterligaste": "förbätterlig",
    "förbätterligastes": "förbätterlig",
    "förbätterligasts": "förbätterlig",
    "förbätterlige": "förbätterlig",
    "förbätterliges": "förbätterlig",
    "förbätterligheten": "förbätterlighet",
    "förbätterlighetens": "förbätterlighet",
    "förbätterlighets": "förbätterlighet",
    "förbätterligs": "förbätterlig",
    "förbätterligt": "förbätterlig",
    "förbätterligts": "förbätterlig",
    "förbättrad": "förbättra",
    "förbättrade": "förbättra",
    "förbättrades": "förbättra",
    "förbättrads": "förbättra",
    "förbättrande": "förbättra",
    "förbättranden": "förbättrande",
    "förbättrandena": "förbättrande",
    "förbättrandenas": "förbättrande",
    "förbättrandens": "förbättrande",
    "förbättrandes": "förbättrande",
    "förbättrandet": "förbättrande",
    "förbättrandets": "förbättrande",
    "förbättrar": "förbättra",
    "förbättras": "förbättra",
    "förbättrat": "förbättra",
    "förbättrats": "förbättra",
    "förbättringar": "förbättring",
    "förbättringarna": "förbättring",
    "förbättringarnas": "förbättring",
    "förbättringars": "förbättring",
    "förbättringen": "förbättring",
    "förbättringens": "förbättring",
    "förbättrings": "förbättring",
    "förbättringslånen": "förbättringslån",
    "förbättringslånens": "förbättringslån",
    "förbättringslånet": "förbättringslån",
    "förbättringslånets": "förbättringslån",
    "förbättringslåns": "förbättringslån",
    "förbönen": "förbön",
    "förbönens": "förbön",
    "förböner": "förbön",
    "förbönerna": "förbön",
    "förbönernas": "förbön",
    "förböners": "förbön",
    "förböns": "förbön",
    "förd": "föra",
    "förda": "föra",
    "fördas": "föra",
    "förde": "föra",
    "fördel": "fördela",
    "fördelad": "fördela",
    "fördelade": "fördela",
    "fördelades": "fördela",
    "fördelads": "fördela",
    "fördelaktiga": "fördelaktig",
    "fördelaktigare": "fördelaktig",
    "fördelaktigares": "fördelaktig",
    "fördelaktigas": "fördelaktig",
    "fördelaktigast": "fördelaktig",
    "fördelaktigaste": "fördelaktig",
    "fördelaktigastes": "fördelaktig",
    "fördelaktigasts": "fördelaktig",
    "fördelaktige": "fördelaktig",
    "fördelaktiges": "fördelaktig",
    "fördelaktigheten": "fördelaktighet",
    "fördelaktighetens": "fördelaktighet",
    "fördelaktighets": "fördelaktighet",
    "fördelaktigs": "fördelaktig",
    "fördelaktigt": "fördelaktig",
    "fördelaktigts": "fördelaktig",
    "fördelande": "fördela",
    "fördelanden": "fördelande",
    "fördelandena": "fördelande",
    "fördelandenas": "fördelande",
    "fördelandens": "fördelande",
    "fördelandes": "fördelande",
    "fördelandet": "fördelande",
    "fördelandets": "fördelande",
    "fördelar": "fördelare",
    "fördelaren": "fördelare",
    "fördelarens": "fördelare",
    "fördelares": "fördelare",
    "fördelarna": "fördelare",
    "fördelarnas": "fördelare",
    "fördelars": "fördel",
    "fördelas": "fördela",
    "fördelat": "fördela",
    "fördelats": "fördela",
    "fördelen": "fördel",
    "fördelens": "fördel",
    "fördelningar": "fördelning",
    "fördelningarna": "fördelning",
    "fördelningarnas": "fördelning",
    "fördelningars": "fördelning",
    "fördelningen": "fördelning",
    "fördelningens": "fördelning",
    "fördelnings": "fördelning",
    "fördelningsmässiga": "fördelningsmässig",
    "fördelningsmässigare": "fördelningsmässig",
    "fördelningsmässigares": "fördelningsmässig",
    "fördelningsmässigas": "fördelningsmässig",
    "fördelningsmässigast": "fördelningsmässig",
    "fördelningsmässigaste": "fördelningsmässig",
    "fördelningsmässigastes": "fördelningsmässig",
    "fördelningsmässigasts": "fördelningsmässig",
    "fördelningsmässige": "fördelningsmässig",
    "fördelningsmässiges": "fördelningsmässig",
    "fördelningsmässigs": "fördelningsmässig",
    "fördelningsmässigt": "fördelningsmässig",
    "fördelningsmässigts": "fördelningsmässig",
    "fördelningspolitiken": "fördelningspolitik",
    "fördelningspolitikens": "fördelningspolitik",
    "fördelningspolitiks": "fördelningspolitik",
    "fördelningspolitiska": "fördelningspolitisk",
    "fördelningspolitiskare": "fördelningspolitisk",
    "fördelningspolitiskares": "fördelningspolitisk",
    "fördelningspolitiskas": "fördelningspolitisk",
    "fördelningspolitiskast": "fördelningspolitisk",
    "fördelningspolitiskaste": "fördelningspolitisk",
    "fördelningspolitiskastes": "fördelningspolitisk",
    "fördelningspolitiskasts": "fördelningspolitisk",
    "fördelningspolitiske": "fördelningspolitisk",
    "fördelningspolitiskes": "fördelningspolitisk",
    "fördelningspolitisks": "fördelningspolitisk",
    "fördelningspolitiskt": "fördelningspolitisk",
    "fördelningspolitiskts": "fördelningspolitisk",
    "fördels": "fördel",
    "fördes": "föra",
    "fördettingar": "fördetting",
    "fördettingarna": "fördetting",
    "fördettingarnas": "fördetting",
    "fördettingars": "fördetting",
    "fördettingen": "fördetting",
    "fördettingens": "fördetting",
    "fördettings": "fördetting",
    "fördevinds": "fördevind",
    "fördjup": "fördjupa",
    "fördjupad": "fördjupa",
    "fördjupade": "fördjupa",
    "fördjupades": "fördjupa",
    "fördjupads": "fördjupa",
    "fördjupande": "fördjupa",
    "fördjupanden": "fördjupande",
    "fördjupandena": "fördjupande",
    "fördjupandenas": "fördjupande",
    "fördjupandens": "fördjupande",
    "fördjupandes": "fördjupande",
    "fördjupandet": "fördjupande",
    "fördjupandets": "fördjupande",
    "fördjupar": "fördjupa",
    "fördjupas": "fördjupa",
    "fördjupat": "fördjupa",
    "fördjupats": "fördjupa",
    "fördjupningar": "fördjupning",
    "fördjupningarna": "fördjupning",
    "fördjupningarnas": "fördjupning",
    "fördjupningars": "fördjupning",
    "fördjupningen": "fördjupning",
    "fördjupningens": "fördjupning",
    "fördjupnings": "fördjupning",
    "fördjupningskursen": "fördjupningskurs",
    "fördjupningskursens": "fördjupningskurs",
    "fördjupningskurser": "fördjupningskurs",
    "fördjupningskurserna": "fördjupningskurs",
    "fördjupningskursernas": "fördjupningskurs",
    "fördjupningskursers": "fördjupningskurs",
    "fördjupningsreportagen": "fördjupningsreportage",
    "fördjupningsreportagens": "fördjupningsreportage",
    "fördjupningsreportages": "fördjupningsreportage",
    "fördjupningsreportaget": "fördjupningsreportage",
    "fördjupningsreportagets": "fördjupningsreportage",
    "fördold": "fördölja",
    "fördolda": "fördölja",
    "fördoldare": "fördold",
    "fördoldares": "fördold",
    "fördoldas": "fördölja",
    "fördoldast": "fördold",
    "fördoldaste": "fördold",
    "fördoldastes": "fördold",
    "fördoldasts": "fördold",
    "fördolde": "fördölja",
    "fördoldes": "fördölja",
    "fördoldheten": "fördoldhet",
    "fördoldhetens": "fördoldhet",
    "fördoldhets": "fördoldhet",
    "fördolds": "fördölja",
    "fördolt": "fördölja",
    "fördolts": "fördölja",
    "fördomar": "fördom",
    "fördomarna": "fördom",
    "fördomarnas": "fördom",
    "fördomars": "fördom",
    "fördomen": "fördom",
    "fördomens": "fördom",
    "fördoms": "fördom",
    "fördomsfria": "fördomsfri",
    "fördomsfriare": "fördomsfri",
    "fördomsfriares": "fördomsfri",
    "fördomsfrias": "fördomsfri",
    "fördomsfriast": "fördomsfri",
    "fördomsfriaste": "fördomsfri",
    "fördomsfriastes": "fördomsfri",
    "fördomsfriasts": "fördomsfri",
    "fördomsfrie": "fördomsfri",
    "fördomsfries": "fördomsfri",
    "fördomsfris": "fördomsfri",
    "fördomsfritt": "fördomsfri",
    "fördomsfritts": "fördomsfri",
    "fördomsfulla": "fördomsfull",
    "fördomsfullare": "fördomsfull",
    "fördomsfullares": "fördomsfull",
    "fördomsfullas": "fördomsfull",
    "fördomsfullast": "fördomsfull",
    "fördomsfullaste": "fördomsfull",
    "fördomsfullastes": "fördomsfull",
    "fördomsfullasts": "fördomsfull",
    "fördomsfulle": "fördomsfull",
    "fördomsfulles": "fördomsfull",
    "fördomsfullheten": "fördomsfullhet",
    "fördomsfullhetens": "fördomsfullhet",
    "fördomsfullheter": "fördomsfullhet",
    "fördomsfullheterna": "fördomsfullhet",
    "fördomsfullheternas": "fördomsfullhet",
    "fördomsfullheters": "fördomsfullhet",
    "fördomsfullhets": "fördomsfullhet",
    "fördomsfulls": "fördomsfull",
    "fördomsfullt": "fördomsfull",
    "fördomsfullts": "fördomsfull",
    "fördrag": "fördra",
    "fördraga": "fördra",
    "fördragande": "fördra",
    "fördraganden": "fördragande",
    "fördragandena": "fördragande",
    "fördragandenas": "fördragande",
    "fördragandens": "fördragande",
    "fördragandes": "fördragande",
    "fördragandet": "fördragande",
    "fördragandets": "fördragande",
    "fördragas": "fördra",
    "fördrage": "fördra",
    "fördragen": "fördrag",
    "fördragenheten": "fördragenhet",
    "fördragenhetens": "fördragenhet",
    "fördragenhets": "fördragenhet",
    "fördragens": "fördragen",
    "fördrager": "fördra",
    "fördrages": "fördra",
    "fördraget": "fördragen",
    "fördragets": "fördragen",
    "fördragit": "fördra",
    "fördragits": "fördra",
    "fördragna": "fördragen",
    "fördragnare": "fördragen",
    "fördragnares": "fördragen",
    "fördragnas": "fördragen",
    "fördragnast": "fördragen",
    "fördragnaste": "fördragen",
    "fördragnastes": "fördragen",
    "fördragnasts": "fördragen",
    "fördragne": "fördragen",
    "fördragnes": "fördragen",
    "fördrags": "fördrag",
    "fördragsamheten": "fördragsamhet",
    "fördragsamhetens": "fördragsamhet",
    "fördragsamheter": "fördragsamhet",
    "fördragsamheterna": "fördragsamhet",
    "fördragsamheternas": "fördragsamhet",
    "fördragsamheters": "fördragsamhet",
    "fördragsamhets": "fördragsamhet",
    "fördragsamma": "fördragsam",
    "fördragsammare": "fördragsam",
    "fördragsammares": "fördragsam",
    "fördragsammas": "fördragsam",
    "fördragsammast": "fördragsam",
    "fördragsammaste": "fördragsam",
    "fördragsammastes": "fördragsam",
    "fördragsammasts": "fördragsam",
    "fördragsamme": "fördragsam",
    "fördragsammes": "fördragsam",
    "fördragsams": "fördragsam",
    "fördragsamt": "fördragsam",
    "fördragsamts": "fördragsam",
    "fördragsmässiga": "fördragsmässig",
    "fördragsmässigare": "fördragsmässig",
    "fördragsmässigares": "fördragsmässig",
    "fördragsmässigas": "fördragsmässig",
    "fördragsmässigast": "fördragsmässig",
    "fördragsmässigaste": "fördragsmässig",
    "fördragsmässigastes": "fördragsmässig",
    "fördragsmässigasts": "fördragsmässig",
    "fördragsmässige": "fördragsmässig",
    "fördragsmässiges": "fördragsmässig",
    "fördragsmässigs": "fördragsmässig",
    "fördragsmässigt": "fördragsmässig",
    "fördragsmässigts": "fördragsmässig",
    "fördrar": "fördra",
    "fördras": "fördra",
    "fördrev": "fördriva",
    "fördrevs": "fördriva",
    "fördriv": "fördriva",
    "fördrivande": "fördriva",
    "fördrivanden": "fördrivande",
    "fördrivandena": "fördrivande",
    "fördrivandenas": "fördrivande",
    "fördrivandens": "fördrivande",
    "fördrivandes": "fördrivande",
    "fördrivandet": "fördrivande",
    "fördrivandets": "fördrivande",
    "fördrivas": "fördriva",
    "fördrive": "fördriva",
    "fördriven": "fördriva",
    "fördrivens": "fördriva",
    "fördriver": "fördriva",
    "fördrives": "fördriva",
    "fördrivet": "fördriva",
    "fördrivets": "fördriva",
    "fördrivit": "fördriva",
    "fördrivits": "fördriva",
    "fördrivna": "fördriva",
    "fördrivnas": "fördriva",
    "fördrivne": "fördriva",
    "fördrivnes": "fördriva",
    "fördrivningar": "fördrivning",
    "fördrivningarna": "fördrivning",
    "fördrivningarnas": "fördrivning",
    "fördrivningars": "fördrivning",
    "fördrivningen": "fördrivning",
    "fördrivningens": "fördrivning",
    "fördrivnings": "fördrivning",
    "fördrivs": "fördriva",
    "fördrog": "fördra",
    "fördroge": "fördra",
    "fördroges": "fördra",
    "fördrogs": "fördra",
    "fördröj": "fördröja",
    "fördröjande": "fördröja",
    "fördröjanden": "fördröjande",
    "fördröjandena": "fördröjande",
    "fördröjandenas": "fördröjande",
    "fördröjandens": "fördröjande",
    "fördröjandes": "fördröjande",
    "fördröjandet": "fördröjande",
    "fördröjandets": "fördröjande",
    "fördröjas": "fördröja",
    "fördröjd": "fördröja",
    "fördröjda": "fördröja",
    "fördröjdas": "fördröja",
    "fördröjde": "fördröja",
    "fördröjdes": "fördröja",
    "fördröjds": "fördröja",
    "fördröjer": "fördröja",
    "fördröjes": "fördröja",
    "fördröjningar": "fördröjning",
    "fördröjningarna": "fördröjning",
    "fördröjningarnas": "fördröjning",
    "fördröjningars": "fördröjning",
    "fördröjningen": "fördröjning",
    "fördröjningens": "fördröjning",
    "fördröjnings": "fördröjning",
    "fördröjs": "fördröja",
    "fördröjt": "fördröja",
    "fördröjts": "fördröja",
    "fördrömda": "fördrömd",
    "fördrömdare": "fördrömd",
    "fördrömdares": "fördrömd",
    "fördrömdas": "fördrömd",
    "fördrömdast": "fördrömd",
    "fördrömdaste": "fördrömd",
    "fördrömdastes": "fördrömd",
    "fördrömdasts": "fördrömd",
    "fördrömde": "fördrömd",
    "fördrömdes": "fördrömd",
    "fördrömds": "fördrömd",
    "fördrömt": "fördrömd",
    "fördrömts": "fördrömd",
    "förds": "föra",
    "fördubblad": "fördubbla",
    "fördubblade": "fördubbla",
    "fördubblades": "fördubbla",
    "fördubblads": "fördubbla",
    "fördubblande": "fördubbla",
    "fördubblanden": "fördubblande",
    "fördubblandena": "fördubblande",
    "fördubblandenas": "fördubblande",
    "fördubblandens": "fördubblande",
    "fördubblandes": "fördubblande",
    "fördubblandet": "fördubblande",
    "fördubblandets": "fördubblande",
    "fördubblar": "fördubbla",
    "fördubblas": "fördubbla",
    "fördubblat": "fördubbla",
    "fördubblats": "fördubbla",
    "fördubblingar": "fördubbling",
    "fördubblingarna": "fördubbling",
    "fördubblingarnas": "fördubbling",
    "fördubblingars": "fördubbling",
    "fördubblingen": "fördubbling",
    "fördubblingens": "fördubbling",
    "fördubblings": "fördubbling",
    "fördummad": "fördumma",
    "fördummade": "fördumma",
    "fördummades": "fördumma",
    "fördummads": "fördumma",
    "fördummande": "fördumma",
    "fördummanden": "fördummande",
    "fördummandena": "fördummande",
    "fördummandenas": "fördummande",
    "fördummandens": "fördummande",
    "fördummandes": "fördummande",
    "fördummandet": "fördummande",
    "fördummandets": "fördummande",
    "fördummar": "fördumma",
    "fördummas": "fördumma",
    "fördummat": "fördumma",
    "fördummats": "fördumma",
    "fördunklad": "fördunkla",
    "fördunklade": "fördunkla",
    "fördunklades": "fördunkla",
    "fördunklads": "fördunkla",
    "fördunklande": "fördunkla",
    "fördunklanden": "fördunklande",
    "fördunklandena": "fördunklande",
    "fördunklandenas": "fördunklande",
    "fördunklandens": "fördunklande",
    "fördunklandes": "fördunklande",
    "fördunklandet": "fördunklande",
    "fördunklandets": "fördunklande",
    "fördunklar": "fördunkla",
    "fördunklas": "fördunkla",
    "fördunklat": "fördunkla",
    "fördunklats": "fördunkla",
    "fördunst": "fördunsta",
    "fördunstad": "fördunsta",
    "fördunstade": "fördunsta",
    "fördunstades": "fördunsta",
    "fördunstads": "fördunsta",
    "fördunstande": "fördunsta",
    "fördunstanden": "fördunstande",
    "fördunstandena": "fördunstande",
    "fördunstandenas": "fördunstande",
    "fördunstandens": "fördunstande",
    "fördunstandes": "fördunstande",
    "fördunstandet": "fördunstande",
    "fördunstandets": "fördunstande",
    "fördunstar": "fördunsta",
    "fördunstas": "fördunsta",
    "fördunstat": "fördunsta",
    "fördunstats": "fördunsta",
    "fördyr": "fördyra",
    "fördyrad": "fördyra",
    "fördyrade": "fördyra",
    "fördyrades": "fördyra",
    "fördyrads": "fördyra",
    "fördyrande": "fördyra",
    "fördyranden": "fördyrande",
    "fördyrandena": "fördyrande",
    "fördyrandenas": "fördyrande",
    "fördyrandens": "fördyrande",
    "fördyrandes": "fördyrande",
    "fördyrandet": "fördyrande",
    "fördyrandets": "fördyrande",
    "fördyrar": "fördyra",
    "fördyras": "fördyra",
    "fördyrat": "fördyra",
    "fördyrats": "fördyra",
    "fördystrad": "fördystra",
    "fördystrade": "fördystra",
    "fördystrades": "fördystra",
    "fördystrads": "fördystra",
    "fördystrande": "fördystra",
    "fördystranden": "fördystrande",
    "fördystrandena": "fördystrande",
    "fördystrandenas": "fördystrande",
    "fördystrandens": "fördystrande",
    "fördystrandes": "fördystrande",
    "fördystrandet": "fördystrande",
    "fördystrandets": "fördystrande",
    "fördystrar": "fördystra",
    "fördystras": "fördystra",
    "fördystrat": "fördystra",
    "fördystrats": "fördystra",
    "fördäcken": "fördäck",
    "fördäckens": "fördäck",
    "fördäcket": "fördäck",
    "fördäckets": "fördäck",
    "fördäcks": "fördäck",
    "fördäm": "fördämma",
    "fördämd": "fördämma",
    "fördämda": "fördämma",
    "fördämdas": "fördämma",
    "fördämde": "fördämma",
    "fördämdes": "fördämma",
    "fördämds": "fördämma",
    "fördämmande": "fördämma",
    "fördämmanden": "fördämmande",
    "fördämmandena": "fördämmande",
    "fördämmandenas": "fördämmande",
    "fördämmandens": "fördämmande",
    "fördämmandes": "fördämmande",
    "fördämmandet": "fördämmande",
    "fördämmandets": "fördämmande",
    "fördämmas": "fördämma",
    "fördämmer": "fördämma",
    "fördämningar": "fördämning",
    "fördämningarna": "fördämning",
    "fördämningarnas": "fördämning",
    "fördämningars": "fördämning",
    "fördämningen": "fördämning",
    "fördämningens": "fördämning",
    "fördämnings": "fördämning",
    "fördäms": "fördämma",
    "fördämt": "fördämma",
    "fördämts": "fördämma",
    "fördärv": "fördärva",
    "fördärvad": "fördärva",
    "fördärvade": "fördärva",
    "fördärvades": "fördärva",
    "fördärvads": "fördärva",
    "fördärvande": "fördärva",
    "fördärvanden": "fördärvande",
    "fördärvandena": "fördärvande",
    "fördärvandenas": "fördärvande",
    "fördärvandens": "fördärvande",
    "fördärvandes": "fördärvande",
    "fördärvandet": "fördärvande",
    "fördärvandets": "fördärvande",
    "fördärvar": "fördärva",
    "fördärvas": "fördärva",
    "fördärvat": "fördärva",
    "fördärvats": "fördärva",
    "fördärvet": "fördärv",
    "fördärvets": "fördärv",
    "fördärvliga": "fördärvlig",
    "fördärvligare": "fördärvlig",
    "fördärvligares": "fördärvlig",
    "fördärvligas": "fördärvlig",
    "fördärvligast": "fördärvlig",
    "fördärvligaste": "fördärvlig",
    "fördärvligastes": "fördärvlig",
    "fördärvligasts": "fördärvlig",
    "fördärvlige": "fördärvlig",
    "fördärvliges": "fördärvlig",
    "fördärvligheten": "fördärvlighet",
    "fördärvlighetens": "fördärvlighet",
    "fördärvlighets": "fördärvlighet",
    "fördärvligs": "fördärvlig",
    "fördärvligt": "fördärvlig",
    "fördärvligts": "fördärvlig",
    "fördärvs": "fördärv",
    "fördölj": "fördölja",
    "fördöljande": "fördölja",
    "fördöljanden": "fördöljande",
    "fördöljandena": "fördöljande",
    "fördöljandenas": "fördöljande",
    "fördöljandens": "fördöljande",
    "fördöljandes": "fördöljande",
    "fördöljandet": "fördöljande",
    "fördöljandets": "fördöljande",
    "fördöljas": "fördölja",
    "fördöljer": "fördölja",
    "fördöljes": "fördölja",
    "fördöljs": "fördölja",
    "fördöm": "fördöma",
    "fördömande": "fördöma",
    "fördömanden": "fördömande",
    "fördömandena": "fördömande",
    "fördömandenas": "fördömande",
    "fördömandens": "fördömande",
    "fördömandes": "fördömande",
    "fördömandet": "fördömande",
    "fördömandets": "fördömande",
    "fördömas": "fördöma",
    "fördömd": "fördöma",
    "fördömda": "fördömd",
    "fördömdare": "fördömd",
    "fördömdares": "fördömd",
    "fördömdas": "fördömd",
    "fördömdast": "fördömd",
    "fördömdaste": "fördömd",
    "fördömdastes": "fördömd",
    "fördömdasts": "fördömd",
    "fördömde": "fördömd",
    "fördömdes": "fördömd",
    "fördömdheten": "fördömdhet",
    "fördömdhetens": "fördömdhet",
    "fördömdhets": "fördömdhet",
    "fördömds": "fördömd",
    "fördömelsen": "fördömelse",
    "fördömelsens": "fördömelse",
    "fördömelses": "fördömelse",
    "fördömer": "fördöma",
    "fördömliga": "fördömlig",
    "fördömligare": "fördömlig",
    "fördömligares": "fördömlig",
    "fördömligas": "fördömlig",
    "fördömligast": "fördömlig",
    "fördömligaste": "fördömlig",
    "fördömligastes": "fördömlig",
    "fördömligasts": "fördömlig",
    "fördömlige": "fördömlig",
    "fördömliges": "fördömlig",
    "fördömligheten": "fördömlighet",
    "fördömlighetens": "fördömlighet",
    "fördömlighets": "fördömlighet",
    "fördömligs": "fördömlig",
    "fördömligt": "fördömlig",
    "fördömligts": "fördömlig",
    "fördöms": "fördöma",
    "fördömt": "fördömd",
    "fördömts": "fördömd",
    "förebar": "förebära",
    "förebars": "förebära",
    "förebilden": "förebild",
    "förebildens": "förebild",
    "förebilder": "förebild",
    "förebilderna": "förebild",
    "förebildernas": "förebild",
    "förebilders": "förebild",
    "förebildliga": "förebildlig",
    "förebildligare": "förebildlig",
    "förebildligares": "förebildlig",
    "förebildligas": "förebildlig",
    "förebildligast": "förebildlig",
    "förebildligaste": "förebildlig",
    "förebildligastes": "förebildlig",
    "förebildligasts": "förebildlig",
    "förebildlige": "förebildlig",
    "förebildliges": "förebildlig",
    "förebildligheten": "förebildlighet",
    "förebildlighetens": "förebildlighet",
    "förebildlighets": "förebildlighet",
    "förebildligs": "förebildlig",
    "förebildligt": "förebildlig",
    "förebildligts": "förebildlig",
    "förebilds": "förebild",
    "förebrådd": "förebrå",
    "förebrådda": "förebrå",
    "förebråddas": "förebrå",
    "förebrådde": "förebrå",
    "förebråddes": "förebrå",
    "förebrådds": "förebrå",
    "förebråelsen": "förebråelse",
    "förebråelsens": "förebråelse",
    "förebråelser": "förebråelse",
    "förebråelserna": "förebråelse",
    "förebråelsernas": "förebråelse",
    "förebråelsers": "förebråelse",
    "förebråelses": "förebråelse",
    "förebrående": "förebrå",
    "förebråenden": "förebrående",
    "förebråendena": "förebrående",
    "förebråendenas": "förebrående",
    "förebråendens": "förebrående",
    "förebråendes": "förebrående",
    "förebråendet": "förebrående",
    "förebråendets": "förebrående",
    "förebrår": "förebrå",
    "förebrås": "förebrå",
    "förebrått": "förebrå",
    "förebråtts": "förebrå",
    "förebuden": "förebud",
    "förebudens": "förebud",
    "förebudet": "förebud",
    "förebudets": "förebud",
    "förebuds": "förebud",
    "förebure": "förebära",
    "föreburen": "förebära",
    "föreburens": "förebära",
    "förebures": "förebära",
    "föreburet": "förebära",
    "föreburets": "förebära",
    "föreburit": "förebära",
    "föreburits": "förebära",
    "föreburna": "förebära",
    "föreburnas": "förebära",
    "föreburne": "förebära",
    "föreburnes": "förebära",
    "förebygg": "förebygga",
    "förebyggande": "förebygga",
    "förebygganden": "förebyggande",
    "förebyggandena": "förebyggande",
    "förebyggandenas": "förebyggande",
    "förebyggandens": "förebyggande",
    "förebyggandes": "förebyggande",
    "förebyggandet": "förebyggande",
    "förebyggandets": "förebyggande",
    "förebyggas": "förebygga",
    "förebyggd": "förebygga",
    "förebyggda": "förebygga",
    "förebyggdas": "förebygga",
    "förebyggde": "förebygga",
    "förebyggdes": "förebygga",
    "förebyggds": "förebygga",
    "förebygger": "förebygga",
    "förebygges": "förebygga",
    "förebyggs": "förebygga",
    "förebyggt": "förebygga",
    "förebyggts": "förebygga",
    "förebär": "förebära",
    "förebärande": "förebära",
    "förebäranden": "förebärande",
    "förebärandena": "förebärande",
    "förebärandenas": "förebärande",
    "förebärandens": "förebärande",
    "förebärandes": "förebärande",
    "förebärandet": "förebärande",
    "förebärandets": "förebärande",
    "förebäras": "förebära",
    "förebäre": "förebära",
    "förebäres": "förebära",
    "förebärs": "förebära",
    "förebåd": "förebåda",
    "förebådad": "förebåda",
    "förebådade": "förebåda",
    "förebådades": "förebåda",
    "förebådads": "förebåda",
    "förebådande": "förebåda",
    "förebådanden": "förebådande",
    "förebådandena": "förebådande",
    "förebådandenas": "förebådande",
    "förebådandens": "förebådande",
    "förebådandes": "förebådande",
    "förebådandet": "förebådande",
    "förebådandets": "förebådande",
    "förebådar": "förebåda",
    "förebådas": "förebåda",
    "förebådat": "förebåda",
    "förebådats": "förebåda",
    "föredrag": "föredra",
    "föredraga": "föredra",
    "föredragande": "föredra",
    "föredraganden": "föredragande",
    "föredragandena": "föredragande",
    "föredragandenas": "föredragande",
    "föredragandens": "föredragande",
    "föredragandes": "föredragande",
    "föredragandet": "föredragande",
    "föredragandets": "föredragande",
    "föredragas": "föredra",
    "föredrage": "föredra",
    "föredragen": "föredrag",
    "föredragens": "föredrag",
    "föredrager": "föredra",
    "föredrages": "föredra",
    "föredraget": "föredrag",
    "föredragets": "föredrag",
    "föredragit": "föredra",
    "föredragits": "föredra",
    "föredragna": "föredra",
    "föredragnas": "föredra",
    "föredragne": "föredra",
    "föredragnes": "föredra",
    "föredragningar": "föredragning",
    "föredragningarna": "föredragning",
    "föredragningarnas": "föredragning",
    "föredragningars": "föredragning",
    "föredragningen": "föredragning",
    "föredragningens": "föredragning",
    "föredragnings": "föredragning",
    "föredragningslistan": "föredragningslista",
    "föredragningslistans": "föredragningslista",
    "föredragningslistas": "föredragningslista",
    "föredragningsliste": "föredragningslista",
    "föredragningslistor": "föredragningslista",
    "föredragningslistorna": "föredragningslista",
    "föredragningslistornas": "föredragningslista",
    "föredragningslistors": "föredragningslista",
    "föredrags": "föredrag",
    "föredrar": "föredra",
    "föredras": "föredra",
    "föredrog": "föredra",
    "föredroge": "föredra",
    "föredroges": "föredra",
    "föredrogs": "föredra",
    "föredömen": "föredöme",
    "föredömena": "föredöme",
    "föredömenas": "föredöme",
    "föredömens": "föredöme",
    "föredömes": "föredöme",
    "föredömet": "föredöme",
    "föredömets": "föredöme",
    "föredömliga": "föredömlig",
    "föredömligare": "föredömlig",
    "föredömligares": "föredömlig",
    "föredömligas": "föredömlig",
    "föredömligast": "föredömlig",
    "föredömligaste": "föredömlig",
    "föredömligastes": "föredömlig",
    "föredömligasts": "föredömlig",
    "föredömlige": "föredömlig",
    "föredömliges": "föredömlig",
    "föredömligheten": "föredömlighet",
    "föredömlighetens": "föredömlighet",
    "föredömlighets": "föredömlighet",
    "föredömligs": "föredömlig",
    "föredömligt": "föredömlig",
    "föredömligts": "föredömlig",
    "förefall": "förefalla",
    "förefallande": "förefalla",
    "förefallanden": "förefallande",
    "förefallandena": "förefallande",
    "förefallandenas": "förefallande",
    "förefallandens": "förefallande",
    "förefallandes": "förefallande",
    "förefallandet": "förefallande",
    "förefallandets": "förefallande",
    "förefallas": "förefalla",
    "förefalle": "förefalla",
    "förefaller": "förefalla",
    "förefalles": "förefalla",
    "förefallit": "förefalla",
    "förefallits": "förefalla",
    "förefalls": "förefalla",
    "förefanns": "förefinnas",
    "förefinnes": "förefinnas",
    "förefinns": "förefinnas",
    "förefintliga": "förefintlig",
    "förefintligare": "förefintlig",
    "förefintligares": "förefintlig",
    "förefintligas": "förefintlig",
    "förefintligast": "förefintlig",
    "förefintligaste": "förefintlig",
    "förefintligastes": "förefintlig",
    "förefintligasts": "förefintlig",
    "förefintlige": "förefintlig",
    "förefintliges": "förefintlig",
    "förefintligheten": "förefintlighet",
    "förefintlighetens": "förefintlighet",
    "förefintlighets": "förefintlighet",
    "förefintligs": "förefintlig",
    "förefintligt": "förefintlig",
    "förefintligts": "förefintlig",
    "förefunnits": "förefinnas",
    "föreföll": "förefalla",
    "förefölle": "förefalla",
    "förefölles": "förefalla",
    "förefölls": "förefalla",
    "föregav": "förege",
    "föregavs": "förege",
    "föregeende": "förege",
    "föregeendes": "förege",
    "föreger": "förege",
    "föreges": "förege",
    "föregett": "förege",
    "föregetts": "förege",
    "föregick": "föregå",
    "föregicks": "föregå",
    "föreginge": "föregå",
    "föreginges": "föregå",
    "föregiv": "förege",
    "föregiva": "förege",
    "föregivande": "förege",
    "föregivanden": "föregivande",
    "föregivandena": "föregivande",
    "föregivandenas": "föregivande",
    "föregivandens": "föregivande",
    "föregivandes": "föregivande",
    "föregivandet": "föregivande",
    "föregivandets": "föregivande",
    "föregivas": "förege",
    "föregive": "förege",
    "föregiven": "förege",
    "föregivens": "förege",
    "föregiver": "förege",
    "föregives": "förege",
    "föregivet": "förege",
    "föregivets": "förege",
    "föregivit": "förege",
    "föregivits": "förege",
    "föregivna": "förege",
    "föregivnas": "förege",
    "föregivne": "förege",
    "föregivnes": "förege",
    "föregivs": "förege",
    "föregrep": "föregripa",
    "föregreps": "föregripa",
    "föregrip": "föregripa",
    "föregripande": "föregripa",
    "föregripanden": "föregripande",
    "föregripandena": "föregripande",
    "föregripandenas": "föregripande",
    "föregripandens": "föregripande",
    "föregripandes": "föregripande",
    "föregripandet": "föregripande",
    "föregripandets": "föregripande",
    "föregripas": "föregripa",
    "föregripe": "föregripa",
    "föregripen": "föregripa",
    "föregripens": "föregripa",
    "föregriper": "föregripa",
    "föregripes": "föregripa",
    "föregripet": "föregripa",
    "föregripets": "föregripa",
    "föregripit": "föregripa",
    "föregripits": "föregripa",
    "föregripna": "föregripa",
    "föregripnas": "föregripa",
    "föregripne": "föregripa",
    "föregripnes": "föregripa",
    "föregrips": "föregripa",
    "föregående": "föregå",
    "föregåenden": "föregående",
    "föregåendena": "föregående",
    "föregåendenas": "föregående",
    "föregåendens": "föregående",
    "föregåendes": "föregående",
    "föregåendet": "föregående",
    "föregåendets": "föregående",
    "föregångar": "föregångare",
    "föregångaren": "föregångare",
    "föregångarens": "föregångare",
    "föregångares": "föregångare",
    "föregångarna": "föregångare",
    "föregångarnas": "föregångare",
    "föregånge": "föregå",
    "föregången": "föregå",
    "föregångens": "föregå",
    "föregånges": "föregå",
    "föregånget": "föregå",
    "föregångets": "föregå",
    "föregångna": "föregå",
    "föregångnas": "föregå",
    "föregångne": "föregå",
    "föregångnes": "föregå",
    "föregångsmannen": "föregångsman",
    "föregångsmannens": "föregångsman",
    "föregångsmans": "föregångsman",
    "föregångsmän": "föregångsman",
    "föregångsmännen": "föregångsman",
    "föregångsmännens": "föregångsman",
    "föregångsmäns": "föregångsman",
    "föregår": "föregå",
    "föregås": "föregå",
    "föregått": "föregå",
    "föregåtts": "föregå",
    "föregåve": "förege",
    "föregåves": "förege",
    "förehade": "föreha",
    "förehades": "föreha",
    "förehaft": "föreha",
    "förehafts": "föreha",
    "förehande": "föreha",
    "förehandes": "föreha",
    "förehar": "föreha",
    "förehas": "föreha",
    "förehava": "föreha",
    "förehavande": "föreha",
    "förehavanden": "förehavande",
    "förehavandena": "förehavande",
    "förehavandenas": "förehavande",
    "förehavandens": "förehavande",
    "förehavandes": "förehavande",
    "förehavandet": "förehavande",
    "förehavandets": "förehavande",
    "förehavas": "föreha",
    "förehaver": "föreha",
    "förehåll": "förehålla",
    "förehållande": "förehålla",
    "förehållanden": "förehållande",
    "förehållandena": "förehållande",
    "förehållandenas": "förehållande",
    "förehållandens": "förehållande",
    "förehållandes": "förehållande",
    "förehållandet": "förehållande",
    "förehållandets": "förehållande",
    "förehållas": "förehålla",
    "förehålle": "förehålla",
    "förehållen": "förehålla",
    "förehållens": "förehålla",
    "förehåller": "förehålla",
    "förehålles": "förehålla",
    "förehållet": "förehålla",
    "förehållets": "förehålla",
    "förehållit": "förehålla",
    "förehållits": "förehålla",
    "förehållna": "förehålla",
    "förehållnas": "förehålla",
    "förehållne": "förehålla",
    "förehållnes": "förehålla",
    "förehålls": "förehålla",
    "förehöll": "förehålla",
    "förehölle": "förehålla",
    "förehölles": "förehålla",
    "förehölls": "förehålla",
    "förekom": "förekomma",
    "förekomet": "förekomma",
    "förekomets": "förekomma",
    "förekommande": "förekomma",
    "förekommanden": "förekommande",
    "förekommandena": "förekommande",
    "förekommandenas": "förekommande",
    "förekommandens": "förekommande",
    "förekommandes": "förekommande",
    "förekommandet": "förekommande",
    "förekommandets": "förekommande",
    "förekommas": "förekomma",
    "förekomme": "förekomma",
    "förekommen": "förekomma",
    "förekommens": "förekomma",
    "förekommer": "förekomma",
    "förekommes": "förekomma",
    "förekommit": "förekomma",
    "förekommits": "förekomma",
    "förekomna": "förekomma",
    "förekomnas": "förekomma",
    "förekomne": "förekomma",
    "förekomnes": "förekomma",
    "förekoms": "förekomma",
    "förekomsten": "förekomst",
    "förekomstens": "förekomst",
    "förekomster": "förekomst",
    "förekomsterna": "förekomst",
    "förekomsternas": "förekomst",
    "förekomsters": "förekomst",
    "förekomsts": "förekomst",
    "förela": "förelägga",
    "förelade": "förelägga",
    "förelades": "förelägga",
    "förelagd": "förelägga",
    "förelagda": "förelägga",
    "förelagdas": "förelägga",
    "förelagde": "förelägga",
    "förelagdes": "förelägga",
    "förelagds": "förelägga",
    "förelagt": "förelägga",
    "förelagts": "förelägga",
    "förelas": "förelägga",
    "förelegat": "föreligga",
    "förelegats": "föreligga",
    "föreligg": "föreligga",
    "föreliggande": "föreligga",
    "föreligganden": "föreliggande",
    "föreliggandena": "föreliggande",
    "föreliggandenas": "föreliggande",
    "föreliggandens": "föreliggande",
    "föreliggandes": "föreliggande",
    "föreliggandet": "föreliggande",
    "föreliggandets": "föreliggande",
    "föreliggas": "föreligga",
    "föreligge": "föreligga",
    "föreligger": "föreligga",
    "föreligges": "föreligga",
    "föreliggs": "föreligga",
    "förelägg": "förelägga",
    "föreläggande": "förelägga",
    "förelägganden": "föreläggande",
    "föreläggandena": "föreläggande",
    "föreläggandenas": "föreläggande",
    "föreläggandens": "föreläggande",
    "föreläggandes": "föreläggande",
    "föreläggandet": "föreläggande",
    "föreläggandets": "föreläggande",
    "föreläggas": "förelägga",
    "förelägger": "förelägga",
    "förelägges": "förelägga",
    "föreläggs": "förelägga",
    "föreläs": "föreläsa",
    "föreläsande": "föreläsa",
    "föreläsanden": "föreläsande",
    "föreläsandena": "föreläsande",
    "föreläsandenas": "föreläsande",
    "föreläsandens": "föreläsande",
    "föreläsandes": "föreläsande",
    "föreläsandet": "föreläsande",
    "föreläsandets": "föreläsande",
    "föreläsar": "föreläsare",
    "föreläsaren": "föreläsare",
    "föreläsarens": "föreläsare",
    "föreläsares": "föreläsare",
    "föreläsarna": "föreläsare",
    "föreläsarnas": "föreläsare",
    "föreläsas": "föreläsa",
    "föreläser": "föreläsa",
    "föreläses": "föreläsa",
    "föreläsningar": "föreläsning",
    "föreläsningarna": "föreläsning",
    "föreläsningarnas": "föreläsning",
    "föreläsningars": "föreläsning",
    "föreläsningen": "föreläsning",
    "föreläsningens": "föreläsning",
    "föreläsnings": "föreläsning",
    "föreläsningssalar": "föreläsningssal",
    "föreläsningssalarna": "föreläsningssal",
    "föreläsningssalarnas": "föreläsningssal",
    "föreläsningssalars": "föreläsningssal",
    "föreläsningssalen": "föreläsningssal",
    "föreläsningssalens": "föreläsningssal",
    "föreläsningssals": "föreläsningssal",
    "föreläst": "föreläsa",
    "föreläste": "föreläsa",
    "förelästes": "föreläsa",
    "förelästs": "föreläsa",
    "förelåg": "föreligga",
    "förelågge": "föreligga",
    "förelågges": "föreligga",
    "förelågs": "föreligga",
    "förelöpar": "förelöpare",
    "förelöparen": "förelöpare",
    "förelöparens": "förelöpare",
    "förelöpares": "förelöpare",
    "förelöparna": "förelöpare",
    "förelöparnas": "förelöpare",
    "föremålen": "föremål",
    "föremålens": "föremål",
    "föremålet": "föremål",
    "föremålets": "föremål",
    "föremåls": "föremål",
    "fören": "förena",
    "förena": "före",
    "förenad": "förena",
    "förenade": "förena",
    "förenades": "förena",
    "förenads": "förena",
    "förenande": "förena",
    "förenanden": "förenande",
    "förenandena": "förenande",
    "förenandenas": "förenande",
    "förenandens": "förenande",
    "förenandes": "förenande",
    "förenandet": "förenande",
    "förenandets": "förenande",
    "förenar": "förena",
    "förenas": "förena",
    "förenat": "förena",
    "förenats": "förena",
    "föreningar": "förening",
    "föreningarna": "förening",
    "föreningarnas": "förening",
    "föreningars": "förening",
    "föreningen": "förening",
    "föreningens": "förening",
    "förenings": "förening",
    "föreningsbanken": "föreningsbank",
    "föreningsbankens": "föreningsbank",
    "föreningsbanker": "föreningsbank",
    "föreningsbankerna": "föreningsbank",
    "föreningsbankernas": "föreningsbank",
    "föreningsbankers": "föreningsbank",
    "föreningsbanks": "föreningsbank",
    "föreningsfriheten": "föreningsfrihet",
    "föreningsfrihetens": "föreningsfrihet",
    "föreningsfriheter": "föreningsfrihet",
    "föreningsfriheterna": "föreningsfrihet",
    "föreningsfriheternas": "föreningsfrihet",
    "föreningsfriheters": "föreningsfrihet",
    "föreningsfrihets": "föreningsfrihet",
    "föreningsmängden": "föreningsmängd",
    "föreningsmängdens": "föreningsmängd",
    "föreningsmängder": "föreningsmängd",
    "föreningsmängderna": "föreningsmängd",
    "föreningsmängdernas": "föreningsmängd",
    "föreningsmängders": "föreningsmängd",
    "föreningsmängds": "föreningsmängd",
    "föreningsmässiga": "föreningsmässig",
    "föreningsmässigare": "föreningsmässig",
    "föreningsmässigares": "föreningsmässig",
    "föreningsmässigas": "föreningsmässig",
    "föreningsmässigast": "föreningsmässig",
    "föreningsmässigaste": "föreningsmässig",
    "föreningsmässigastes": "föreningsmässig",
    "föreningsmässigasts": "föreningsmässig",
    "föreningsmässige": "föreningsmässig",
    "föreningsmässiges": "föreningsmässig",
    "föreningsmässigs": "föreningsmässig",
    "föreningsmässigt": "föreningsmässig",
    "föreningsmässigts": "föreningsmässig",
    "föreningsrätten": "föreningsrätt",
    "föreningsrättens": "föreningsrätt",
    "föreningsrätts": "föreningsrätt",
    "föreningsrörelsen": "föreningsrörelse",
    "föreningsrörelsens": "föreningsrörelse",
    "föreningsrörelser": "föreningsrörelse",
    "föreningsrörelserna": "föreningsrörelse",
    "föreningsrörelsernas": "föreningsrörelse",
    "föreningsrörelsers": "föreningsrörelse",
    "föreningsrörelses": "föreningsrörelse",
    "förenklad": "förenkla",
    "förenklade": "förenkla",
    "förenklades": "förenkla",
    "förenklads": "förenkla",
    "förenklande": "förenkla",
    "förenklanden": "förenklande",
    "förenklandena": "förenklande",
    "förenklandenas": "förenklande",
    "förenklandens": "förenklande",
    "förenklandes": "förenklande",
    "förenklandet": "förenklande",
    "förenklandets": "förenklande",
    "förenklar": "förenkla",
    "förenklas": "förenkla",
    "förenklat": "förenkla",
    "förenklats": "förenkla",
    "förenklingar": "förenkling",
    "förenklingarna": "förenkling",
    "förenklingarnas": "förenkling",
    "förenklingars": "förenkling",
    "förenklingen": "förenkling",
    "förenklingens": "förenkling",
    "förenklings": "förenkling",
    "förenliga": "förenlig",
    "förenligare": "förenlig",
    "förenligares": "förenlig",
    "förenligas": "förenlig",
    "förenligast": "förenlig",
    "förenligaste": "förenlig",
    "förenligastes": "förenlig",
    "förenligasts": "förenlig",
    "förenlige": "förenlig",
    "förenliges": "förenlig",
    "förenligheten": "förenlighet",
    "förenlighetens": "förenlighet",
    "förenligheter": "förenlighet",
    "förenligheterna": "förenlighet",
    "förenligheternas": "förenlighet",
    "förenligheters": "förenlighet",
    "förenlighets": "förenlighet",
    "förenligs": "förenlig",
    "förenligt": "förenlig",
    "förenligts": "förenlig",
    "förens": "före",
    "förent": "förena",
    "förenta": "förena",
    "förentas": "förena",
    "förente": "förena",
    "förentes": "förena",
    "förents": "förena",
    "föres": "före",
    "föresatsen": "föresats",
    "föresatsens": "föresats",
    "föresatser": "föresats",
    "föresatserna": "föresats",
    "föresatsernas": "föresats",
    "föresatsers": "föresats",
    "föreskrev": "föreskriva",
    "föreskrevs": "föreskriva",
    "föreskriften": "föreskrift",
    "föreskriftens": "föreskrift",
    "föreskrifter": "föreskrift",
    "föreskrifterna": "föreskrift",
    "föreskrifternas": "föreskrift",
    "föreskrifters": "föreskrift",
    "föreskrifts": "föreskrift",
    "föreskriv": "föreskriva",
    "föreskrivande": "föreskriva",
    "föreskrivanden": "föreskrivande",
    "föreskrivandena": "föreskrivande",
    "föreskrivandenas": "föreskrivande",
    "föreskrivandens": "föreskrivande",
    "föreskrivandes": "föreskrivande",
    "föreskrivandet": "föreskrivande",
    "föreskrivandets": "föreskrivande",
    "föreskrivas": "föreskriva",
    "föreskrive": "föreskriva",
    "föreskriven": "föreskriva",
    "föreskrivens": "föreskriva",
    "föreskriver": "föreskriva",
    "föreskrives": "föreskriva",
    "föreskrivet": "föreskriva",
    "föreskrivets": "föreskriva",
    "föreskrivit": "föreskriva",
    "föreskrivits": "föreskriva",
    "föreskrivna": "föreskriva",
    "föreskrivnas": "föreskriva",
    "föreskrivne": "föreskriva",
    "föreskrivnes": "föreskriva",
    "föreskrivs": "föreskriva",
    "föreslagen": "föreslå",
    "föreslagens": "föreslå",
    "föreslaget": "föreslå",
    "föreslagets": "föreslå",
    "föreslagit": "föreslå",
    "föreslagits": "föreslå",
    "föreslagna": "föreslå",
    "föreslagnas": "föreslå",
    "föreslagne": "föreslå",
    "föreslagnes": "föreslå",
    "föreslog": "föreslå",
    "föresloge": "föreslå",
    "föresloges": "föreslå",
    "föreslogs": "föreslå",
    "föreslående": "föreslå",
    "föreslåenden": "föreslående",
    "föreslåendena": "föreslående",
    "föreslåendenas": "föreslående",
    "föreslåendens": "föreslående",
    "föreslåendes": "föreslående",
    "föreslåendet": "föreslående",
    "föreslåendets": "föreslående",
    "föreslår": "föreslå",
    "föreslås": "föreslå",
    "förespeglad": "förespegla",
    "förespeglade": "förespegla",
    "förespeglades": "förespegla",
    "förespeglads": "förespegla",
    "förespeglande": "förespegla",
    "förespeglanden": "förespeglande",
    "förespeglandena": "förespeglande",
    "förespeglandenas": "förespeglande",
    "förespeglandens": "förespeglande",
    "förespeglandes": "förespeglande",
    "förespeglandet": "förespeglande",
    "förespeglandets": "förespeglande",
    "förespeglar": "förespegla",
    "förespeglas": "förespegla",
    "förespeglat": "förespegla",
    "förespeglats": "förespegla",
    "förespeglingar": "förespegling",
    "förespeglingarna": "förespegling",
    "förespeglingarnas": "förespegling",
    "förespeglingars": "förespegling",
    "förespeglingen": "förespegling",
    "förespeglingens": "förespegling",
    "förespeglings": "förespegling",
    "förespråk": "förespråka",
    "förespråkad": "förespråka",
    "förespråkade": "förespråka",
    "förespråkades": "förespråka",
    "förespråkads": "förespråka",
    "förespråkande": "förespråka",
    "förespråkanden": "förespråkande",
    "förespråkandena": "förespråkande",
    "förespråkandenas": "förespråkande",
    "förespråkandens": "förespråkande",
    "förespråkandes": "förespråkande",
    "förespråkandet": "förespråkande",
    "förespråkandets": "förespråkande",
    "förespråkar": "förespråkare",
    "förespråkaren": "förespråkare",
    "förespråkarens": "förespråkare",
    "förespråkares": "förespråkare",
    "förespråkarna": "förespråkare",
    "förespråkarnas": "förespråkare",
    "förespråkas": "förespråka",
    "förespråkat": "förespråka",
    "förespråkats": "förespråka",
    "förespådd": "förespå",
    "förespådda": "förespå",
    "förespåddas": "förespå",
    "förespådde": "förespå",
    "förespåddes": "förespå",
    "förespådds": "förespå",
    "förespående": "förespå",
    "förespåenden": "förespående",
    "förespåendena": "förespående",
    "förespåendenas": "förespående",
    "förespåendens": "förespående",
    "förespåendes": "förespående",
    "förespåendet": "förespående",
    "förespåendets": "förespående",
    "förespår": "förespå",
    "förespås": "förespå",
    "förespått": "förespå",
    "förespåtts": "förespå",
    "förestav": "förestava",
    "förestavad": "förestava",
    "förestavade": "förestava",
    "förestavades": "förestava",
    "förestavads": "förestava",
    "förestavande": "förestava",
    "förestavanden": "förestavande",
    "förestavandena": "förestavande",
    "förestavandenas": "förestavande",
    "förestavandens": "förestavande",
    "förestavandes": "förestavande",
    "förestavandet": "förestavande",
    "förestavandets": "förestavande",
    "förestavar": "förestava",
    "förestavas": "förestava",
    "förestavat": "förestava",
    "förestavats": "förestava",
    "förestod": "förestå",
    "förestode": "förestå",
    "förestodes": "förestå",
    "förestods": "förestå",
    "föreställ": "föreställa",
    "föreställande": "föreställa",
    "föreställanden": "föreställande",
    "föreställandena": "föreställande",
    "föreställandenas": "föreställande",
    "föreställandens": "föreställande",
    "föreställandes": "föreställande",
    "föreställandet": "föreställande",
    "föreställandets": "föreställande",
    "föreställar": "föreställare",
    "föreställaren": "föreställare",
    "föreställarens": "föreställare",
    "föreställares": "föreställare",
    "föreställarna": "föreställare",
    "föreställarnas": "föreställare",
    "föreställas": "föreställa",
    "föreställd": "föreställa",
    "föreställda": "föreställa",
    "föreställdas": "föreställa",
    "föreställde": "föreställa",
    "föreställdes": "föreställa",
    "föreställds": "föreställa",
    "föreställer": "föreställa",
    "föreställes": "föreställa",
    "föreställningar": "föreställning",
    "föreställningarna": "föreställning",
    "föreställningarnas": "föreställning",
    "föreställningars": "föreställning",
    "föreställningen": "föreställning",
    "föreställningens": "föreställning",
    "föreställnings": "föreställning",
    "föreställningsförmågan": "föreställningsförmåga",
    "föreställningsförmågans": "föreställningsförmåga",
    "föreställningsförmågas": "föreställningsförmåga",
    "föreställningsförmåge": "föreställningsförmåga",
    "föreställningsförmågor": "föreställningsförmåga",
    "föreställningsförmågorna": "föreställningsförmåga",
    "föreställningsförmågornas": "föreställningsförmåga",
    "föreställningsförmågors": "föreställningsförmåga",
    "föreställningsvärldar": "föreställningsvärld",
    "föreställningsvärldarna": "föreställningsvärld",
    "föreställningsvärldarnas": "föreställningsvärld",
    "föreställningsvärldars": "föreställningsvärld",
    "föreställningsvärlden": "föreställningsvärld",
    "föreställningsvärldens": "föreställningsvärld",
    "föreställningsvärlds": "föreställningsvärld",
    "föreställs": "föreställa",
    "föreställt": "föreställa",
    "föreställts": "föreställa",
    "förestående": "förestå",
    "föreståenden": "förestående",
    "föreståendena": "förestående",
    "föreståendenas": "förestående",
    "föreståendens": "förestående",
    "föreståendes": "förestående",
    "föreståendet": "förestående",
    "föreståendets": "förestående",
    "föreståndar": "föreståndare",
    "föreståndaren": "föreståndare",
    "föreståndarens": "föreståndare",
    "föreståndares": "föreståndare",
    "föreståndarinnan": "föreståndarinna",
    "föreståndarinnans": "föreståndarinna",
    "föreståndarinnas": "föreståndarinna",
    "föreståndarinne": "föreståndarinna",
    "föreståndarinnor": "föreståndarinna",
    "föreståndarinnorna": "föreståndarinna",
    "föreståndarinnornas": "föreståndarinna",
    "föreståndarinnors": "föreståndarinna",
    "föreståndarna": "föreståndare",
    "föreståndarnas": "föreståndare",
    "förestår": "förestå",
    "förestås": "förestå",
    "förestått": "förestå",
    "föreståtts": "förestå",
    "föresvävade": "föresväva",
    "föresvävades": "föresväva",
    "föresvävande": "föresväva",
    "föresvävanden": "föresvävande",
    "föresvävandena": "föresvävande",
    "föresvävandenas": "föresvävande",
    "föresvävandens": "föresvävande",
    "föresvävandes": "föresvävande",
    "föresvävandet": "föresvävande",
    "föresvävandets": "föresvävande",
    "föresvävar": "föresväva",
    "föresvävas": "föresväva",
    "föresvävat": "föresväva",
    "föresvävats": "föresväva",
    "föret": "före",
    "företag": "företa",
    "företaga": "företa",
    "företagande": "företa",
    "företaganden": "företagande",
    "företagandena": "företagande",
    "företagandenas": "företagande",
    "företagandens": "företagande",
    "företagandes": "företagande",
    "företagandet": "företagande",
    "företagandets": "företagande",
    "företagar": "företagare",
    "företagarandan": "företagaranda",
    "företagarandans": "företagaranda",
    "företagarandas": "företagaranda",
    "företagaren": "företagare",
    "företagarens": "företagare",
    "företagares": "företagare",
    "företagarna": "företagare",
    "företagarnas": "företagare",
    "företagas": "företa",
    "företage": "företa",
    "företagen": "företag",
    "företagens": "företag",
    "företager": "företa",
    "företages": "företa",
    "företaget": "företag",
    "företagets": "företag",
    "företagit": "företa",
    "företagits": "företa",
    "företagna": "företa",
    "företagnas": "företa",
    "företagne": "företa",
    "företagnes": "företa",
    "företags": "företag",
    "företagsamheten": "företagsamhet",
    "företagsamhetens": "företagsamhet",
    "företagsamheter": "företagsamhet",
    "företagsamheterna": "företagsamhet",
    "företagsamheternas": "företagsamhet",
    "företagsamheters": "företagsamhet",
    "företagsamhets": "företagsamhet",
    "företagsamma": "företagsam",
    "företagsammare": "företagsam",
    "företagsammares": "företagsam",
    "företagsammas": "företagsam",
    "företagsammast": "företagsam",
    "företagsammaste": "företagsam",
    "företagsammastes": "företagsam",
    "företagsammasts": "företagsam",
    "företagsamme": "företagsam",
    "företagsammes": "företagsam",
    "företagsams": "företagsam",
    "företagsamt": "företagsam",
    "företagsamts": "företagsam",
    "företagsboten": "företagsbot",
    "företagsbotens": "företagsbot",
    "företagsbots": "företagsbot",
    "företagsdemokratien": "företagsdemokrati",
    "företagsdemokratiens": "företagsdemokrati",
    "företagsdemokratin": "företagsdemokrati",
    "företagsdemokratins": "företagsdemokrati",
    "företagsdemokratis": "företagsdemokrati",
    "företagsekonomen": "företagsekonom",
    "företagsekonomens": "företagsekonom",
    "företagsekonomer": "företagsekonom",
    "företagsekonomerna": "företagsekonom",
    "företagsekonomernas": "företagsekonom",
    "företagsekonomers": "företagsekonom",
    "företagsekonomien": "företagsekonomi",
    "företagsekonomiens": "företagsekonomi",
    "företagsekonomin": "företagsekonomi",
    "företagsekonomins": "företagsekonomi",
    "företagsekonomis": "företagsekonomi",
    "företagsekonomiska": "företagsekonomisk",
    "företagsekonomiskare": "företagsekonomisk",
    "företagsekonomiskares": "företagsekonomisk",
    "företagsekonomiskas": "företagsekonomisk",
    "företagsekonomiskast": "företagsekonomisk",
    "företagsekonomiskaste": "företagsekonomisk",
    "företagsekonomiskastes": "företagsekonomisk",
    "företagsekonomiskasts": "företagsekonomisk",
    "företagsekonomiske": "företagsekonomisk",
    "företagsekonomiskes": "företagsekonomisk",
    "företagsekonomisks": "företagsekonomisk",
    "företagsekonomiskt": "företagsekonomisk",
    "företagsekonomiskts": "företagsekonomisk",
    "företagsekonoms": "företagsekonom",
    "företagsfiaskon": "företagsfiasko",
    "företagsfiaskona": "företagsfiasko",
    "företagsfiaskonas": "företagsfiasko",
    "företagsfiaskons": "företagsfiasko",
    "företagsfiaskos": "företagsfiasko",
    "företagsfiaskot": "företagsfiasko",
    "företagsfiaskots": "företagsfiasko",
    "företagsfilialen": "företagsfilial",
    "företagsfilialens": "företagsfilial",
    "företagsfilialer": "företagsfilial",
    "företagsfilialerna": "företagsfilial",
    "företagsfilialernas": "företagsfilial",
    "företagsfilialers": "företagsfilial",
    "företagsfilials": "företagsfilial",
    "företagshälsovården": "företagshälsovård",
    "företagshälsovårdens": "företagshälsovård",
    "företagshälsovårds": "företagshälsovård",
    "företagsledar": "företagsledare",
    "företagsledaren": "företagsledare",
    "företagsledarens": "företagsledare",
    "företagsledares": "företagsledare",
    "företagsledarna": "företagsledare",
    "företagsledarnas": "företagsledare",
    "företagsledningar": "företagsledning",
    "företagsledningarna": "företagsledning",
    "företagsledningarnas": "företagsledning",
    "företagsledningars": "företagsledning",
    "företagsledningen": "företagsledning",
    "företagsledningens": "företagsledning",
    "företagslednings": "företagsledning",
    "företagsmässiga": "företagsmässig",
    "företagsmässigare": "företagsmässig",
    "företagsmässigares": "företagsmässig",
    "företagsmässigas": "företagsmässig",
    "företagsmässigast": "företagsmässig",
    "företagsmässigaste": "företagsmässig",
    "företagsmässigastes": "företagsmässig",
    "företagsmässigasts": "företagsmässig",
    "företagsmässige": "företagsmässig",
    "företagsmässiges": "företagsmässig",
    "företagsmässigs": "företagsmässig",
    "företagsmässigt": "företagsmässig",
    "företagsmässigts": "företagsmässig",
    "företagsnämnden": "företagsnämnd",
    "företagsnämndens": "företagsnämnd",
    "företagsnämnder": "företagsnämnd",
    "företagsnämnderna": "företagsnämnd",
    "företagsnämndernas": "företagsnämnd",
    "företagsnämnders": "företagsnämnd",
    "företagsnämnds": "företagsnämnd",
    "företagstäta": "företagstät",
    "företagstätare": "företagstät",
    "företagstätares": "företagstät",
    "företagstätas": "företagstät",
    "företagstätast": "företagstät",
    "företagstätaste": "företagstät",
    "företagstätastes": "företagstät",
    "företagstätasts": "företagstät",
    "företagstäte": "företagstät",
    "företagstätes": "företagstät",
    "företagstätheten": "företagstäthet",
    "företagstäthetens": "företagstäthet",
    "företagstäthets": "företagstäthet",
    "företagstäts": "företagstät",
    "företagstätt": "företagstät",
    "företagstätts": "företagstät",
    "företagsvinsten": "företagsvinst",
    "företagsvinstens": "företagsvinst",
    "företagsvinster": "företagsvinst",
    "företagsvinsterna": "företagsvinst",
    "företagsvinsternas": "företagsvinst",
    "företagsvinsters": "företagsvinst",
    "företagsvinsts": "företagsvinst",
    "företalen": "företal",
    "företalens": "företal",
    "företalet": "företal",
    "företalets": "företal",
    "företals": "företal",
    "företar": "företa",
    "företas": "företa",
    "företedd": "förete",
    "företedda": "förete",
    "företeddas": "förete",
    "företedde": "förete",
    "företeddes": "förete",
    "företedds": "förete",
    "företeelsen": "företeelse",
    "företeelsens": "företeelse",
    "företeelser": "företeelse",
    "företeelserna": "företeelse",
    "företeelsernas": "företeelse",
    "företeelsers": "företeelse",
    "företeelses": "företeelse",
    "företeende": "förete",
    "företeenden": "företeende",
    "företeendena": "företeende",
    "företeendenas": "företeende",
    "företeendens": "företeende",
    "företeendes": "företeende",
    "företeendet": "företeende",
    "företeendets": "företeende",
    "företer": "förete",
    "företes": "förete",
    "företett": "förete",
    "företetts": "förete",
    "företog": "företa",
    "företoge": "företa",
    "företoges": "företa",
    "företogs": "företa",
    "företräd": "företräda",
    "företrädande": "företräda",
    "företrädanden": "företrädande",
    "företrädandena": "företrädande",
    "företrädandenas": "företrädande",
    "företrädandens": "företrädande",
    "företrädandes": "företrädande",
    "företrädandet": "företrädande",
    "företrädandets": "företrädande",
    "företrädar": "företrädare",
    "företrädaren": "företrädare",
    "företrädarens": "företrädare",
    "företrädares": "företrädare",
    "företrädarna": "företrädare",
    "företrädarnas": "företrädare",
    "företrädas": "företräda",
    "företrädd": "företräda",
    "företrädda": "företräda",
    "företräddas": "företräda",
    "företrädde": "företräda",
    "företräddes": "företräda",
    "företrädds": "företräda",
    "företräden": "företräde",
    "företrädena": "företräde",
    "företrädenas": "företräde",
    "företrädens": "företräde",
    "företräder": "företräda",
    "företrädes": "företräde",
    "företrädesrätten": "företrädesrätt",
    "företrädesrättens": "företrädesrätt",
    "företrädesrätts": "företrädesrätt",
    "företrädet": "företräde",
    "företrädets": "företräde",
    "företräds": "företräda",
    "företrätt": "företräda",
    "företrätts": "företräda",
    "förets": "före",
    "förevar": "förevara",
    "förevarande": "förevara",
    "förevaranden": "förevarande",
    "förevarandena": "förevarande",
    "förevarandenas": "förevarande",
    "förevarandens": "förevarande",
    "förevarandes": "förevarande",
    "förevarandet": "förevarande",
    "förevarandets": "förevarande",
    "förevaras": "förevara",
    "förevarit": "förevara",
    "förevarits": "förevara",
    "förevars": "förevara",
    "förevig": "föreviga",
    "förevigad": "föreviga",
    "förevigade": "föreviga",
    "förevigades": "föreviga",
    "förevigads": "föreviga",
    "förevigande": "föreviga",
    "föreviganden": "förevigande",
    "förevigandena": "förevigande",
    "förevigandenas": "förevigande",
    "förevigandens": "förevigande",
    "förevigandes": "förevigande",
    "förevigandet": "förevigande",
    "förevigandets": "förevigande",
    "förevigar": "föreviga",
    "förevigas": "föreviga",
    "förevigat": "föreviga",
    "förevigats": "föreviga",
    "förevisad": "förevisa",
    "förevisade": "förevisa",
    "förevisades": "förevisa",
    "förevisads": "förevisa",
    "förevisande": "förevisa",
    "förevisanden": "förevisande",
    "förevisandena": "förevisande",
    "förevisandenas": "förevisande",
    "förevisandens": "förevisande",
    "förevisandes": "förevisande",
    "förevisandet": "förevisande",
    "förevisandets": "förevisande",
    "förevisar": "förevisa",
    "förevisas": "förevisa",
    "förevisat": "förevisa",
    "förevisats": "förevisa",
    "förevit": "förevita",
    "förevitad": "förevita",
    "förevitade": "förevita",
    "förevitades": "förevita",
    "förevitads": "förevita",
    "förevitande": "förevita",
    "förevitanden": "förevitande",
    "förevitandena": "förevitande",
    "förevitandenas": "förevitande",
    "förevitandens": "förevitande",
    "förevitandes": "förevitande",
    "förevitandet": "förevitande",
    "förevitandets": "förevitande",
    "förevitar": "förevita",
    "förevitas": "förevita",
    "förevitat": "förevita",
    "förevitats": "förevita",
    "förevändningar": "förevändning",
    "förevändningarna": "förevändning",
    "förevändningarnas": "förevändning",
    "förevändningars": "förevändning",
    "förevändningen": "förevändning",
    "förevändningens": "förevändning",
    "förevändnings": "förevändning",
    "förfadern": "förfader",
    "förfaderns": "förfader",
    "förfaders": "förfader",
    "förfall": "förfalla",
    "förfallande": "förfalla",
    "förfallanden": "förfallande",
    "förfallandena": "förfallande",
    "förfallandenas": "förfallande",
    "förfallandens": "förfallande",
    "förfallandes": "förfallande",
    "förfallandet": "förfallande",
    "förfallandets": "förfallande",
    "förfallas": "förfalla",
    "förfalle": "förfalla",
    "förfallen": "förfalla",
    "förfallenheten": "förfallenhet",
    "förfallenhetens": "förfallenhet",
    "förfallenhets": "förfallenhet",
    "förfallens": "förfallen",
    "förfaller": "förfalla",
    "förfalles": "förfalla",
    "förfallet": "förfallen",
    "förfallets": "förfallen",
    "förfallit": "förfalla",
    "förfallits": "förfalla",
    "förfallna": "förfallen",
    "förfallnare": "förfallen",
    "förfallnares": "förfallen",
    "förfallnas": "förfallen",
    "förfallnast": "förfallen",
    "förfallnaste": "förfallen",
    "förfallnastes": "förfallen",
    "förfallnasts": "förfallen",
    "förfallne": "förfallen",
    "förfallnes": "förfallen",
    "förfallodagar": "förfallodag",
    "förfallodagarna": "förfallodag",
    "förfallodagarnas": "förfallodag",
    "förfallodagars": "förfallodag",
    "förfallodagen": "förfallodag",
    "förfallodagens": "förfallodag",
    "förfallodags": "förfallodag",
    "förfalls": "förfalla",
    "förfalsk": "förfalska",
    "förfalskad": "förfalska",
    "förfalskade": "förfalska",
    "förfalskades": "förfalska",
    "förfalskads": "förfalska",
    "förfalskande": "förfalska",
    "förfalskanden": "förfalskande",
    "förfalskandena": "förfalskande",
    "förfalskandenas": "förfalskande",
    "förfalskandens": "förfalskande",
    "förfalskandes": "förfalskande",
    "förfalskandet": "förfalskande",
    "förfalskandets": "förfalskande",
    "förfalskar": "förfalskare",
    "förfalskaren": "förfalskare",
    "förfalskarens": "förfalskare",
    "förfalskares": "förfalskare",
    "förfalskarna": "förfalskare",
    "förfalskarnas": "förfalskare",
    "förfalskas": "förfalska",
    "förfalskat": "förfalska",
    "förfalskats": "förfalska",
    "förfalskningar": "förfalskning",
    "förfalskningarna": "förfalskning",
    "förfalskningarnas": "förfalskning",
    "förfalskningars": "förfalskning",
    "förfalskningen": "förfalskning",
    "förfalskningens": "förfalskning",
    "förfalsknings": "förfalskning",
    "förfar": "förfara",
    "förfarande": "förfara",
    "förfaranden": "förfarande",
    "förfarandena": "förfarande",
    "förfarandenas": "förfarande",
    "förfarandens": "förfarande",
    "förfarandes": "förfarande",
    "förfarandet": "förfarande",
    "förfarandets": "förfarande",
    "förfaras": "förfara",
    "förfare": "förfara",
    "förfarenheten": "förfarenhet",
    "förfarenhetens": "förfarenhet",
    "förfarenhets": "förfarenhet",
    "förfarens": "förfaren",
    "förfares": "förfara",
    "förfaret": "förfaren",
    "förfarets": "förfaren",
    "förfaringssätten": "förfaringssätt",
    "förfaringssättens": "förfaringssätt",
    "förfaringssättet": "förfaringssätt",
    "förfaringssättets": "förfaringssätt",
    "förfaringssätts": "förfaringssätt",
    "förfarit": "förfara",
    "förfarits": "förfaras",
    "förfarna": "förfaren",
    "förfarnare": "förfaren",
    "förfarnares": "förfaren",
    "förfarnas": "förfaren",
    "förfarnast": "förfaren",
    "förfarnaste": "förfaren",
    "förfarnastes": "förfaren",
    "förfarnasts": "förfaren",
    "förfarne": "förfaren",
    "förfarnes": "förfaren",
    "förfars": "förfaras",
    "förfasades": "förfasas",
    "förfasats": "förfasas",
    "författ": "författa",
    "författad": "författa",
    "författade": "författa",
    "författades": "författa",
    "författads": "författa",
    "författande": "författa",
    "författanden": "författande",
    "författandena": "författande",
    "författandenas": "författande",
    "författandens": "författande",
    "författandes": "författande",
    "författandet": "författande",
    "författandets": "författande",
    "författar": "författare",
    "författaren": "författare",
    "författarens": "författare",
    "författares": "författare",
    "författarinnan": "författarinna",
    "författarinnans": "författarinna",
    "författarinnas": "författarinna",
    "författarinne": "författarinna",
    "författarinnor": "författarinna",
    "författarinnorna": "författarinna",
    "författarinnornas": "författarinna",
    "författarinnors": "författarinna",
    "författarjagen": "författarjag",
    "författarjagens": "författarjag",
    "författarjaget": "författarjag",
    "författarjagets": "författarjag",
    "författarjags": "författarjag",
    "författarna": "författare",
    "författarnas": "författare",
    "författarporträtten": "författarporträtt",
    "författarporträttens": "författarporträtt",
    "författarporträttet": "författarporträtt",
    "författarporträttets": "författarporträtt",
    "författarporträtts": "författarporträtt",
    "författarskapet": "författarskap",
    "författarskapets": "författarskap",
    "författarskaps": "författarskap",
    "författarskildringar": "författarskildring",
    "författarskildringarna": "författarskildring",
    "författarskildringarnas": "författarskildring",
    "författarskildringars": "författarskildring",
    "författarskildringen": "författarskildring",
    "författarskildringens": "författarskildring",
    "författarskildrings": "författarskildring",
    "författarvännen": "författarvän",
    "författarvännens": "författarvän",
    "författarvänner": "författarvän",
    "författarvännerna": "författarvän",
    "författarvännernas": "författarvän",
    "författarvänners": "författarvän",
    "författarväns": "författarvän",
    "författas": "författa",
    "författat": "författa",
    "författats": "författa",
    "författningar": "författning",
    "författningarna": "författning",
    "författningarnas": "författning",
    "författningars": "författning",
    "författningen": "författning",
    "författningens": "författning",
    "författnings": "författning",
    "författningsdomstolar": "författningsdomstol",
    "författningsdomstolarna": "författningsdomstol",
    "författningsdomstolarnas": "författningsdomstol",
    "författningsdomstolars": "författningsdomstol",
    "författningsdomstolen": "författningsdomstol",
    "författningsdomstolens": "författningsdomstol",
    "författningsdomstols": "författningsdomstol",
    "författningsmässiga": "författningsmässig",
    "författningsmässigare": "författningsmässig",
    "författningsmässigares": "författningsmässig",
    "författningsmässigas": "författningsmässig",
    "författningsmässigast": "författningsmässig",
    "författningsmässigaste": "författningsmässig",
    "författningsmässigastes": "författningsmässig",
    "författningsmässigasts": "författningsmässig",
    "författningsmässige": "författningsmässig",
    "författningsmässiges": "författningsmässig",
    "författningsmässigs": "författningsmässig",
    "författningsmässigt": "författningsmässig",
    "författningsmässigts": "författningsmässig",
    "förfel": "förfela",
    "förfelad": "förfela",
    "förfelade": "förfela",
    "förfelades": "förfela",
    "förfelads": "förfela",
    "förfelande": "förfela",
    "förfelanden": "förfelande",
    "förfelandena": "förfelande",
    "förfelandenas": "förfelande",
    "förfelandens": "förfelande",
    "förfelandes": "förfelande",
    "förfelandet": "förfelande",
    "förfelandets": "förfelande",
    "förfelar": "förfela",
    "förfelas": "förfela",
    "förfelat": "förfela",
    "förfelats": "förfela",
    "förfin": "förfina",
    "förfinad": "förfina",
    "förfinade": "förfinad",
    "förfinades": "förfinad",
    "förfinads": "förfinad",
    "förfinande": "förfina",
    "förfinanden": "förfinande",
    "förfinandena": "förfinande",
    "förfinandenas": "förfinande",
    "förfinandens": "förfinande",
    "förfinandes": "förfinande",
    "förfinandet": "förfinande",
    "förfinandets": "förfinande",
    "förfinar": "förfina",
    "förfinas": "förfina",
    "förfinat": "förfinad",
    "förfinats": "förfinad",
    "förfiningar": "förfining",
    "förfiningarna": "förfining",
    "förfiningarnas": "förfining",
    "förfiningars": "förfining",
    "förfiningen": "förfining",
    "förfiningens": "förfining",
    "förfinings": "förfining",
    "förflack": "förflacka",
    "förflackad": "förflacka",
    "förflackade": "förflacka",
    "förflackades": "förflacka",
    "förflackads": "förflacka",
    "förflackande": "förflacka",
    "förflackanden": "förflackande",
    "förflackandena": "förflackande",
    "förflackandenas": "förflackande",
    "förflackandens": "förflackande",
    "förflackandes": "förflackande",
    "förflackandet": "förflackande",
    "förflackandets": "förflackande",
    "förflackar": "förflacka",
    "förflackas": "förflacka",
    "förflackat": "förflacka",
    "förflackats": "förflacka",
    "förflugenheten": "förflugenhet",
    "förflugenhetens": "förflugenhet",
    "förflugenhets": "förflugenhet",
    "förflugens": "förflugen",
    "förfluget": "förflugen",
    "förflugets": "förflugen",
    "förflugna": "förflugen",
    "förflugnare": "förflugen",
    "förflugnares": "förflugen",
    "förflugnas": "förflugen",
    "förflugnast": "förflugen",
    "förflugnaste": "förflugen",
    "förflugnastes": "förflugen",
    "förflugnasts": "förflugen",
    "förflugne": "förflugen",
    "förflugnes": "förflugen",
    "förfluten": "förflyta",
    "förflutens": "förflyta",
    "förflutet": "förflyta",
    "förflutets": "förflyta",
    "förflutit": "förflyta",
    "förflutits": "förflyta",
    "förflutna": "förflyta",
    "förflutnare": "förfluten",
    "förflutnares": "förfluten",
    "förflutnas": "förflyta",
    "förflutnast": "förfluten",
    "förflutnaste": "förfluten",
    "förflutnastes": "förfluten",
    "förflutnasts": "förfluten",
    "förflutne": "förflyta",
    "förflutnes": "förflyta",
    "förflyktigades": "förflyktigas",
    "förflyktigats": "förflyktigas",
    "förflyt": "förflyta",
    "förflytande": "förflyta",
    "förflytanden": "förflytande",
    "förflytandena": "förflytande",
    "förflytandenas": "förflytande",
    "förflytandens": "förflytande",
    "förflytandes": "förflytande",
    "förflytandet": "förflytande",
    "förflytandets": "förflytande",
    "förflytas": "förflyta",
    "förflyte": "förflyta",
    "förflyter": "förflyta",
    "förflytes": "förflyta",
    "förflyts": "förflyta",
    "förflytt": "förflytta",
    "förflyttad": "förflytta",
    "förflyttade": "förflytta",
    "förflyttades": "förflytta",
    "förflyttads": "förflytta",
    "förflyttande": "förflytta",
    "förflyttanden": "förflyttande",
    "förflyttandena": "förflyttande",
    "förflyttandenas": "förflyttande",
    "förflyttandens": "förflyttande",
    "förflyttandes": "förflyttande",
    "förflyttandet": "förflyttande",
    "förflyttandets": "förflyttande",
    "förflyttar": "förflytta",
    "förflyttas": "förflytta",
    "förflyttat": "förflytta",
    "förflyttats": "förflytta",
    "förflyttningar": "förflyttning",
    "förflyttningarna": "förflyttning",
    "förflyttningarnas": "förflyttning",
    "förflyttningars": "förflyttning",
    "förflyttningen": "förflyttning",
    "förflyttningens": "förflyttning",
    "förflyttnings": "förflyttning",
    "förflöt": "förflyta",
    "förflöte": "förflyta",
    "förflötes": "förflyta",
    "förflöts": "förflyta",
    "förfogade": "förfoga",
    "förfogades": "förfoga",
    "förfogande": "förfoga",
    "förfogandelagar": "förfogandelag",
    "förfogandelagarna": "förfogandelag",
    "förfogandelagarnas": "förfogandelag",
    "förfogandelagars": "förfogandelag",
    "förfogandelagen": "förfogandelag",
    "förfogandelagens": "förfogandelag",
    "förfogandelags": "förfogandelag",
    "förfoganden": "förfogande",
    "förfogandena": "förfogande",
    "förfogandenas": "förfogande",
    "förfogandens": "förfogande",
    "förfogandes": "förfogande",
    "förfogandet": "förfogande",
    "förfogandets": "förfogande",
    "förfogar": "förfoga",
    "förfogas": "förfoga",
    "förfogat": "förfoga",
    "förfogats": "förfoga",
    "förfor": "förfara",
    "förfore": "förfara",
    "förfores": "förfara",
    "förfors": "förfaras",
    "förfransk": "förfranska",
    "förfranskad": "förfranska",
    "förfranskade": "förfranska",
    "förfranskades": "förfranska",
    "förfranskads": "förfranska",
    "förfranskande": "förfranska",
    "förfranskanden": "förfranskande",
    "förfranskandena": "förfranskande",
    "förfranskandenas": "förfranskande",
    "förfranskandens": "förfranskande",
    "förfranskandes": "förfranskande",
    "förfranskandet": "förfranskande",
    "förfranskandets": "förfranskande",
    "förfranskar": "förfranska",
    "förfranskas": "förfranska",
    "förfranskat": "förfranska",
    "förfranskats": "förfranska",
    "förfriskningar": "förfriskning",
    "förfriskningarna": "förfriskning",
    "förfriskningarnas": "förfriskning",
    "förfriskningars": "förfriskning",
    "förfriskningen": "förfriskning",
    "förfriskningens": "förfriskning",
    "förfrisknings": "förfriskning",
    "förfruse": "förfrysa",
    "förfrusen": "förfrysa",
    "förfrusens": "förfrysa",
    "förfruses": "förfrysa",
    "förfruset": "förfrysa",
    "förfrusets": "förfrysa",
    "förfrusit": "förfrysa",
    "förfrusits": "förfrysa",
    "förfrusna": "förfrysa",
    "förfrusnare": "förfrusen",
    "förfrusnares": "förfrusen",
    "förfrusnas": "förfrysa",
    "förfrusnast": "förfrusen",
    "förfrusnaste": "förfrusen",
    "förfrusnastes": "förfrusen",
    "förfrusnasts": "förfrusen",
    "förfrusne": "förfrysa",
    "förfrusnes": "förfrysa",
    "förfrys": "förfrysa",
    "förfrysande": "förfrysa",
    "förfrysanden": "förfrysande",
    "förfrysandena": "förfrysande",
    "förfrysandenas": "förfrysande",
    "förfrysandens": "förfrysande",
    "förfrysandes": "förfrysande",
    "förfrysandet": "förfrysande",
    "förfrysandets": "förfrysande",
    "förfrysas": "förfrysa",
    "förfryse": "förfrysa",
    "förfryser": "förfrysa",
    "förfryses": "förfrysa",
    "förfryst": "förfrysa",
    "förfrysta": "förfrysa",
    "förfrystas": "förfrysa",
    "förfryste": "förfrysa",
    "förfrystes": "förfrysa",
    "förfrysts": "förfrysa",
    "förfrågans": "förfrågan",
    "förfrågningar": "förfrågning",
    "förfrågningarna": "förfrågning",
    "förfrågningarnas": "förfrågning",
    "förfrågningars": "förfrågning",
    "förfrågningen": "förfrågning",
    "förfrågningens": "förfrågning",
    "förfrågnings": "förfrågning",
    "förfrös": "förfrysa",
    "förfusk": "förfuska",
    "förfuskad": "förfuska",
    "förfuskade": "förfuska",
    "förfuskades": "förfuska",
    "förfuskads": "förfuska",
    "förfuskande": "förfuska",
    "förfuskanden": "förfuskande",
    "förfuskandena": "förfuskande",
    "förfuskandenas": "förfuskande",
    "förfuskandens": "förfuskande",
    "förfuskandes": "förfuskande",
    "förfuskandet": "förfuskande",
    "förfuskandets": "förfuskande",
    "förfuskar": "förfuska",
    "förfuskas": "förfuska",
    "förfuskat": "förfuska",
    "förfuskats": "förfuska",
    "förfä": "förfäa",
    "förfäad": "förfäa",
    "förfäade": "förfäa",
    "förfäades": "förfäa",
    "förfäads": "förfäa",
    "förfäande": "förfäa",
    "förfäanden": "förfäande",
    "förfäandena": "förfäande",
    "förfäandenas": "förfäande",
    "förfäandens": "förfäande",
    "förfäandes": "förfäande",
    "förfäandet": "förfäande",
    "förfäandets": "förfäande",
    "förfäar": "förfäa",
    "förfäas": "förfäa",
    "förfäat": "förfäa",
    "förfäats": "förfäa",
    "förfäder": "förfader",
    "förfäderna": "förfader",
    "förfädernas": "förfader",
    "förfäders": "förfader",
    "förfäkt": "förfäkta",
    "förfäktad": "förfäkta",
    "förfäktade": "förfäkta",
    "förfäktades": "förfäkta",
    "förfäktads": "förfäkta",
    "förfäktande": "förfäkta",
    "förfäktanden": "förfäktande",
    "förfäktandena": "förfäktande",
    "förfäktandenas": "förfäktande",
    "förfäktandens": "förfäktande",
    "förfäktandes": "förfäktande",
    "förfäktandet": "förfäktande",
    "förfäktandets": "förfäktande",
    "förfäktar": "förfäkta",
    "förfäktas": "förfäkta",
    "förfäktat": "förfäkta",
    "förfäktats": "förfäkta",
    "förfär": "förfära",
    "förfärad": "förfära",
    "förfärade": "förfära",
    "förfärades": "förfäras",
    "förfärads": "förfära",
    "förfärande": "förfära",
    "förfäranden": "förfärande",
    "förfärandena": "förfärande",
    "förfärandenas": "förfärande",
    "förfärandens": "förfärande",
    "förfärandes": "förfärande",
    "förfärandet": "förfärande",
    "förfärandets": "förfärande",
    "förfärans": "förfäran",
    "förfärar": "förfära",
    "förfäras": "förfära",
    "förfärat": "förfära",
    "förfärats": "förfäras",
    "förfärdig": "förfärdiga",
    "förfärdigad": "förfärdiga",
    "förfärdigade": "förfärdiga",
    "förfärdigades": "förfärdiga",
    "förfärdigads": "förfärdiga",
    "förfärdigande": "förfärdiga",
    "förfärdiganden": "förfärdigande",
    "förfärdigandena": "förfärdigande",
    "förfärdigandenas": "förfärdigande",
    "förfärdigandens": "förfärdigande",
    "förfärdigandes": "förfärdigande",
    "förfärdigandet": "förfärdigande",
    "förfärdigandets": "förfärdigande",
    "förfärdigar": "förfärdiga",
    "förfärdigas": "förfärdiga",
    "förfärdigat": "förfärdiga",
    "förfärdigats": "förfärdiga",
    "förfärliga": "förfärlig",
    "förfärligare": "förfärlig",
    "förfärligares": "förfärlig",
    "förfärligas": "förfärlig",
    "förfärligast": "förfärlig",
    "förfärligaste": "förfärlig",
    "förfärligastes": "förfärlig",
    "förfärligasts": "förfärlig",
    "förfärlige": "förfärlig",
    "förfärliges": "förfärlig",
    "förfärligheten": "förfärlighet",
    "förfärlighetens": "förfärlighet",
    "förfärligheter": "förfärlighet",
    "förfärligheterna": "förfärlighet",
    "förfärligheternas": "förfärlighet",
    "förfärligheters": "förfärlighet",
    "förfärlighets": "förfärlighet",
    "förfärligs": "förfärlig",
    "förfärligt": "förfärlig",
    "förfärligts": "förfärlig",
    "förfång": "förfånga",
    "förfångad": "förfånga",
    "förfångade": "förfånga",
    "förfångades": "förfånga",
    "förfångads": "förfånga",
    "förfångande": "förfånga",
    "förfånganden": "förfångande",
    "förfångandena": "förfångande",
    "förfångandenas": "förfångande",
    "förfångandens": "förfångande",
    "förfångandes": "förfångande",
    "förfångandet": "förfångande",
    "förfångandets": "förfångande",
    "förfångar": "förfånga",
    "förfångas": "förfånga",
    "förfångat": "förfånga",
    "förfångats": "förfånga",
    "förfölj": "förfölja",
    "förföljande": "förfölja",
    "förföljanden": "förföljande",
    "förföljandena": "förföljande",
    "förföljandenas": "förföljande",
    "förföljandens": "förföljande",
    "förföljandes": "förföljande",
    "förföljandet": "förföljande",
    "förföljandets": "förföljande",
    "förföljar": "förföljare",
    "förföljaren": "förföljare",
    "förföljarens": "förföljare",
    "förföljares": "förföljare",
    "förföljarna": "förföljare",
    "förföljarnas": "förföljare",
    "förföljas": "förfölja",
    "förföljd": "förfölja",
    "förföljda": "förfölja",
    "förföljdas": "förfölja",
    "förföljde": "förfölja",
    "förföljdes": "förfölja",
    "förföljds": "förfölja",
    "förföljelsemanien": "förföljelsemani",
    "förföljelsemaniens": "förföljelsemani",
    "förföljelsemanier": "förföljelsemani",
    "förföljelsemanierna": "förföljelsemani",
    "förföljelsemaniernas": "förföljelsemani",
    "förföljelsemaniers": "förföljelsemani",
    "förföljelsemanin": "förföljelsemani",
    "förföljelsemanins": "förföljelsemani",
    "förföljelsemanis": "förföljelsemani",
    "förföljelsen": "förföljelse",
    "förföljelsens": "förföljelse",
    "förföljelser": "förföljelse",
    "förföljelserna": "förföljelse",
    "förföljelsernas": "förföljelse",
    "förföljelsers": "förföljelse",
    "förföljelses": "förföljelse",
    "förföljer": "förfölja",
    "förföljes": "förfölja",
    "förföljs": "förfölja",
    "förföljt": "förfölja",
    "förföljts": "förfölja",
    "förföll": "förfalla",
    "förfölle": "förfalla",
    "förfölles": "förfalla",
    "förfölls": "förfalla",
    "förför": "förföra",
    "förförande": "förföra",
    "förföranden": "förförande",
    "förförandena": "förförande",
    "förförandenas": "förförande",
    "förförandens": "förförande",
    "förförandes": "förförande",
    "förförandet": "förförande",
    "förförandets": "förförande",
    "förförar": "förförare",
    "förföraren": "förförare",
    "förförarens": "förförare",
    "förförares": "förförare",
    "förförarna": "förförare",
    "förförarnas": "förförare",
    "förföras": "förföra",
    "förförd": "förföra",
    "förförda": "förföra",
    "förfördas": "förföra",
    "förförde": "förföra",
    "förfördel": "förfördela",
    "förfördelad": "förfördela",
    "förfördelade": "förfördela",
    "förfördelades": "förfördela",
    "förfördelads": "förfördela",
    "förfördelande": "förfördela",
    "förfördelanden": "förfördelande",
    "förfördelandena": "förfördelande",
    "förfördelandenas": "förfördelande",
    "förfördelandens": "förfördelande",
    "förfördelandes": "förfördelande",
    "förfördelandet": "förfördelande",
    "förfördelandets": "förfördelande",
    "förfördelar": "förfördela",
    "förfördelas": "förfördela",
    "förfördelat": "förfördela",
    "förfördelats": "förfördela",
    "förfördes": "förföra",
    "förförds": "förföra",
    "förförelsen": "förförelse",
    "förförelsens": "förförelse",
    "förförelser": "förförelse",
    "förförelserna": "förförelse",
    "förförelsernas": "förförelse",
    "förförelsers": "förförelse",
    "förförelses": "förförelse",
    "förföres": "förföra",
    "förföriska": "förförisk",
    "förföriskare": "förförisk",
    "förföriskares": "förförisk",
    "förföriskas": "förförisk",
    "förföriskast": "förförisk",
    "förföriskaste": "förförisk",
    "förföriskastes": "förförisk",
    "förföriskasts": "förförisk",
    "förföriske": "förförisk",
    "förföriskes": "förförisk",
    "förförisks": "förförisk",
    "förföriskt": "förförisk",
    "förföriskts": "förförisk",
    "förförs": "förföra",
    "förförståelsen": "förförståelse",
    "förförståelsens": "förförståelse",
    "förförståelses": "förförståelse",
    "förfört": "förföra",
    "förförts": "förföra",
    "förgas": "förgasa",
    "förgasad": "förgasa",
    "förgasade": "förgasa",
    "förgasades": "förgasa",
    "förgasads": "förgasa",
    "förgasande": "förgasa",
    "förgasanden": "förgasande",
    "förgasandena": "förgasande",
    "förgasandenas": "förgasande",
    "förgasandens": "förgasande",
    "förgasandes": "förgasande",
    "förgasandet": "förgasande",
    "förgasandets": "förgasande",
    "förgasar": "förgasare",
    "förgasaren": "förgasare",
    "förgasarens": "förgasare",
    "förgasares": "förgasare",
    "förgasarna": "förgasare",
    "förgasarnas": "förgasare",
    "förgasas": "förgasa",
    "förgasat": "förgasa",
    "förgasats": "förgasa",
    "förgat": "förgäta",
    "förgate": "förgäta",
    "förgates": "förgäta",
    "förgats": "förgäta",
    "förgick": "förgå",
    "förgicks": "förgås",
    "förgift": "förgifta",
    "förgiftad": "förgifta",
    "förgiftade": "förgifta",
    "förgiftades": "förgifta",
    "förgiftads": "förgifta",
    "förgiftande": "förgifta",
    "förgiftanden": "förgiftande",
    "förgiftandena": "förgiftande",
    "förgiftandenas": "förgiftande",
    "förgiftandens": "förgiftande",
    "förgiftandes": "förgiftande",
    "förgiftandet": "förgiftande",
    "förgiftandets": "förgiftande",
    "förgiftar": "förgifta",
    "förgiftas": "förgifta",
    "förgiftat": "förgifta",
    "förgiftats": "förgifta",
    "förgiftningar": "förgiftning",
    "förgiftningarna": "förgiftning",
    "förgiftningarnas": "förgiftning",
    "förgiftningars": "förgiftning",
    "förgiftningen": "förgiftning",
    "förgiftningens": "förgiftning",
    "förgiftnings": "förgiftning",
    "förginge": "förgå",
    "förginges": "förgå",
    "förgjord": "förgöra",
    "förgjorda": "förgöra",
    "förgjordare": "förgjord",
    "förgjordares": "förgjord",
    "förgjordas": "förgöra",
    "förgjordast": "förgjord",
    "förgjordaste": "förgjord",
    "förgjordastes": "förgjord",
    "förgjordasts": "förgjord",
    "förgjorde": "förgöra",
    "förgjordes": "förgöra",
    "förgjords": "förgöra",
    "förgjort": "förgöra",
    "förgjorts": "förgöra",
    "förglöm": "förglömma",
    "förglömd": "förglömma",
    "förglömda": "förglömma",
    "förglömdas": "förglömma",
    "förglömde": "förglömma",
    "förglömdes": "förglömma",
    "förglömds": "förglömma",
    "förglömmande": "förglömma",
    "förglömmanden": "förglömmande",
    "förglömmandena": "förglömmande",
    "förglömmandenas": "förglömmande",
    "förglömmandens": "förglömmande",
    "förglömmandes": "förglömmande",
    "förglömmandet": "förglömmande",
    "förglömmandets": "förglömmande",
    "förglömmas": "förglömma",
    "förglömmer": "förglömma",
    "förglöms": "förglömma",
    "förglömt": "förglömma",
    "förglömts": "förglömma",
    "förgrenade": "förgrenad",
    "förgrenades": "förgrenas",
    "förgrenads": "förgrenad",
    "förgrenat": "förgrenad",
    "förgrenats": "förgrenas",
    "förgreningar": "förgrening",
    "förgreningarna": "förgrening",
    "förgreningarnas": "förgrening",
    "förgreningars": "förgrening",
    "förgreningen": "förgrening",
    "förgreningens": "förgrening",
    "förgrenings": "förgrening",
    "förgripelsen": "förgripelse",
    "förgripelsens": "förgripelse",
    "förgripelser": "förgripelse",
    "förgripelserna": "förgripelse",
    "förgripelsernas": "förgripelse",
    "förgripelsers": "förgripelse",
    "förgripelses": "förgripelse",
    "förgripliga": "förgriplig",
    "förgripligare": "förgriplig",
    "förgripligares": "förgriplig",
    "förgripligas": "förgriplig",
    "förgripligast": "förgriplig",
    "förgripligaste": "förgriplig",
    "förgripligastes": "förgriplig",
    "förgripligasts": "förgriplig",
    "förgriplige": "förgriplig",
    "förgripliges": "förgriplig",
    "förgripligheten": "förgriplighet",
    "förgriplighetens": "förgriplighet",
    "förgripligheter": "förgriplighet",
    "förgripligheterna": "förgriplighet",
    "förgripligheternas": "förgriplighet",
    "förgripligheters": "förgriplighet",
    "förgriplighets": "förgriplighet",
    "förgripligs": "förgriplig",
    "förgripligt": "förgriplig",
    "förgripligts": "förgriplig",
    "förgroningar": "förgroning",
    "förgroningarna": "förgroning",
    "förgroningarnas": "förgroning",
    "förgroningars": "förgroning",
    "förgroningen": "förgroning",
    "förgroningens": "förgroning",
    "förgronings": "förgroning",
    "förgrov": "förgrova",
    "förgrovad": "förgrova",
    "förgrovade": "förgrova",
    "förgrovades": "förgrova",
    "förgrovads": "förgrova",
    "förgrovande": "förgrova",
    "förgrovanden": "förgrovande",
    "förgrovandena": "förgrovande",
    "förgrovandenas": "förgrovande",
    "förgrovandens": "förgrovande",
    "förgrovandes": "förgrovande",
    "förgrovandet": "förgrovande",
    "förgrovandets": "förgrovande",
    "förgrovar": "förgrova",
    "förgrovas": "förgrova",
    "förgrovat": "förgrova",
    "förgrovats": "förgrova",
    "förgrunden": "förgrund",
    "förgrundens": "förgrund",
    "förgrunder": "förgrund",
    "förgrunderna": "förgrund",
    "förgrundernas": "förgrund",
    "förgrunders": "förgrund",
    "förgrunds": "förgrund",
    "förgrundsfiguren": "förgrundsfigur",
    "förgrundsfigurens": "förgrundsfigur",
    "förgrundsfigurer": "förgrundsfigur",
    "förgrundsfigurerna": "förgrundsfigur",
    "förgrundsfigurernas": "förgrundsfigur",
    "förgrundsfigurers": "förgrundsfigur",
    "förgrundsfigurs": "förgrundsfigur",
    "förgrundsgestalten": "förgrundsgestalt",
    "förgrundsgestaltens": "förgrundsgestalt",
    "förgrundsgestalter": "förgrundsgestalt",
    "förgrundsgestalterna": "förgrundsgestalt",
    "förgrundsgestalternas": "förgrundsgestalt",
    "förgrundsgestalters": "förgrundsgestalt",
    "förgrundsgestalts": "förgrundsgestalt",
    "förgrymmad": "förgrymma",
    "förgrymmade": "förgrymmad",
    "förgrymmades": "förgrymmad",
    "förgrymmads": "förgrymmad",
    "förgrymmande": "förgrymma",
    "förgrymmanden": "förgrymmande",
    "förgrymmandena": "förgrymmande",
    "förgrymmandenas": "förgrymmande",
    "förgrymmandens": "förgrymmande",
    "förgrymmandes": "förgrymmande",
    "förgrymmandet": "förgrymmande",
    "förgrymmandets": "förgrymmande",
    "förgrymmar": "förgrymma",
    "förgrymmas": "förgrymma",
    "förgrymmat": "förgrymmad",
    "förgrymmats": "förgrymmad",
    "förgrämda": "förgrämd",
    "förgrämdare": "förgrämd",
    "förgrämdares": "förgrämd",
    "förgrämdas": "förgrämd",
    "förgrämdast": "förgrämd",
    "förgrämdaste": "förgrämd",
    "förgrämdastes": "förgrämd",
    "förgrämdasts": "förgrämd",
    "förgrämde": "förgrämd",
    "förgrämdes": "förgrämd",
    "förgrämdheten": "förgrämdhet",
    "förgrämdhetens": "förgrämdhet",
    "förgrämdhets": "förgrämdhet",
    "förgrämds": "förgrämd",
    "förgrämt": "förgrämd",
    "förgrämts": "förgrämd",
    "förgråtenheten": "förgråtenhet",
    "förgråtenhetens": "förgråtenhet",
    "förgråtenhets": "förgråtenhet",
    "förgråtens": "förgråten",
    "förgråtet": "förgråten",
    "förgråtets": "förgråten",
    "förgråtna": "förgråten",
    "förgråtnare": "förgråten",
    "förgråtnares": "förgråten",
    "förgråtnas": "förgråten",
    "förgråtnast": "förgråten",
    "förgråtnaste": "förgråten",
    "förgråtnastes": "förgråten",
    "förgråtnasts": "förgråten",
    "förgråtne": "förgråten",
    "förgråtnes": "förgråten",
    "förgubbades": "förgubbas",
    "förgubbats": "förgubbas",
    "förgubbningar": "förgubbning",
    "förgubbningarna": "förgubbning",
    "förgubbningarnas": "förgubbning",
    "förgubbningars": "förgubbning",
    "förgubbningen": "förgubbning",
    "förgubbningens": "förgubbning",
    "förgubbnings": "förgubbning",
    "förgudningar": "förgudning",
    "förgudningarna": "förgudning",
    "förgudningarnas": "förgudning",
    "förgudningars": "förgudning",
    "förgudningen": "förgudning",
    "förgudningens": "förgudning",
    "förgudnings": "förgudning",
    "förgyll": "förgylla",
    "förgyllande": "förgylla",
    "förgyllanden": "förgyllande",
    "förgyllandena": "förgyllande",
    "förgyllandenas": "förgyllande",
    "förgyllandens": "förgyllande",
    "förgyllandes": "förgyllande",
    "förgyllandet": "förgyllande",
    "förgyllandets": "förgyllande",
    "förgyllas": "förgylla",
    "förgylld": "förgylla",
    "förgyllda": "förgylla",
    "förgylldas": "förgylla",
    "förgyllde": "förgylla",
    "förgylldes": "förgylla",
    "förgyllds": "förgylla",
    "förgyller": "förgylla",
    "förgylles": "förgylla",
    "förgyllningar": "förgyllning",
    "förgyllningarna": "förgyllning",
    "förgyllningarnas": "förgyllning",
    "förgyllningars": "förgyllning",
    "förgyllningen": "förgyllning",
    "förgyllningens": "förgyllning",
    "förgyllnings": "förgyllning",
    "förgylls": "förgylla",
    "förgyllt": "förgylla",
    "förgyllts": "förgylla",
    "förgängelsen": "förgängelse",
    "förgängelsens": "förgängelse",
    "förgängelses": "förgängelse",
    "förgängliga": "förgänglig",
    "förgängligare": "förgänglig",
    "förgängligares": "förgänglig",
    "förgängligas": "förgänglig",
    "förgängligast": "förgänglig",
    "förgängligaste": "förgänglig",
    "förgängligastes": "förgänglig",
    "förgängligasts": "förgänglig",
    "förgänglige": "förgänglig",
    "förgängliges": "förgänglig",
    "förgängligheten": "förgänglighet",
    "förgänglighetens": "förgänglighet",
    "förgängligheter": "förgänglighet",
    "förgängligheterna": "förgänglighet",
    "förgängligheternas": "förgänglighet",
    "förgängligheters": "förgänglighet",
    "förgänglighets": "förgänglighet",
    "förgängligs": "förgänglig",
    "förgängligt": "förgänglig",
    "förgängligts": "förgänglig",
    "förgät": "förgäta",
    "förgätande": "förgäta",
    "förgätanden": "förgätande",
    "förgätandena": "förgätande",
    "förgätandenas": "förgätande",
    "förgätandens": "förgätande",
    "förgätandes": "förgätande",
    "förgätandet": "förgätande",
    "förgätandets": "förgätande",
    "förgätas": "förgäta",
    "förgäte": "förgäta",
    "förgäten": "förgäta",
    "förgätens": "förgäta",
    "förgäter": "förgäta",
    "förgätes": "förgäta",
    "förgätet": "förgäta",
    "förgätets": "förgäta",
    "förgätit": "förgäta",
    "förgätits": "förgäta",
    "förgätmigejen": "förgätmigej",
    "förgätmigejens": "förgätmigej",
    "förgätmigejer": "förgätmigej",
    "förgätmigejerna": "förgätmigej",
    "förgätmigejernas": "förgätmigej",
    "förgätmigejers": "förgätmigej",
    "förgätmigejs": "förgätmigej",
    "förgätna": "förgäta",
    "förgätnas": "förgäta",
    "förgätne": "förgäta",
    "förgätnes": "förgäta",
    "förgäts": "förgäta",
    "förgående": "förgå",
    "förgåenden": "förgående",
    "förgåendena": "förgående",
    "förgåendenas": "förgående",
    "förgåendens": "förgående",
    "förgåendes": "förgående",
    "förgåendet": "förgående",
    "förgåendets": "förgående",
    "förgånge": "förgå",
    "förgången": "förgå",
    "förgångens": "förgå",
    "förgånges": "förgå",
    "förgånget": "förgå",
    "förgångets": "förgå",
    "förgångna": "förgå",
    "förgångnas": "förgå",
    "förgångne": "förgå",
    "förgångnes": "förgå",
    "förgår": "förgå",
    "förgårdar": "förgård",
    "förgårdarna": "förgård",
    "förgårdarnas": "förgård",
    "förgårdars": "förgård",
    "förgården": "förgård",
    "förgårdens": "förgård",
    "förgårds": "förgård",
    "förgås": "förgå",
    "förgått": "förgå",
    "förgåtts": "förgås",
    "förgör": "förgöra",
    "förgörande": "förgöra",
    "förgöranden": "förgörande",
    "förgörandena": "förgörande",
    "förgörandenas": "förgörande",
    "förgörandens": "förgörande",
    "förgörandes": "förgörande",
    "förgörandet": "förgörande",
    "förgörandets": "förgörande",
    "förgöras": "förgöra",
    "förgöres": "förgöra",
    "förgörs": "förgöra",
    "förhal": "förhala",
    "förhalad": "förhala",
    "förhalade": "förhala",
    "förhalades": "förhala",
    "förhalads": "förhala",
    "förhalande": "förhala",
    "förhalanden": "förhalande",
    "förhalandena": "förhalande",
    "förhalandenas": "förhalande",
    "förhalandens": "förhalande",
    "förhalandes": "förhalande",
    "förhalandet": "förhalande",
    "förhalandets": "förhalande",
    "förhalar": "förhala",
    "förhalas": "förhala",
    "förhalat": "förhala",
    "förhalats": "förhala",
    "förhallar": "förhall",
    "förhallarna": "förhall",
    "förhallarnas": "förhall",
    "förhallars": "förhall",
    "förhallen": "förhall",
    "förhallens": "förhall",
    "förhalls": "förhall",
    "förhalningar": "förhalning",
    "förhalningarna": "förhalning",
    "förhalningarnas": "förhalning",
    "förhalningars": "förhalning",
    "förhalningen": "förhalning",
    "förhalningens": "förhalning",
    "förhalnings": "förhalning",
    "förhalningsförsöken": "förhalningsförsök",
    "förhalningsförsökens": "förhalningsförsök",
    "förhalningsförsöket": "förhalningsförsök",
    "förhalningsförsökets": "förhalningsförsök",
    "förhalningsförsöks": "förhalningsförsök",
    "förhanden": "förhand",
    "förhandens": "förhand",
    "förhandenvaron": "förhandenvaro",
    "förhandenvarons": "förhandenvaro",
    "förhandenvaros": "förhandenvaro",
    "förhandlad": "förhandla",
    "förhandlade": "förhandla",
    "förhandlades": "förhandla",
    "förhandlads": "förhandla",
    "förhandlande": "förhandla",
    "förhandlanden": "förhandlande",
    "förhandlandena": "förhandlande",
    "förhandlandenas": "förhandlande",
    "förhandlandens": "förhandlande",
    "förhandlandes": "förhandlande",
    "förhandlandet": "förhandlande",
    "förhandlandets": "förhandlande",
    "förhandlar": "förhandlare",
    "förhandlaren": "förhandlare",
    "förhandlarens": "förhandlare",
    "förhandlares": "förhandlare",
    "förhandlarna": "förhandlare",
    "förhandlarnas": "förhandlare",
    "förhandlas": "förhandla",
    "förhandlat": "förhandla",
    "förhandlats": "förhandla",
    "förhandlingar": "förhandling",
    "förhandlingarna": "förhandling",
    "förhandlingarnas": "förhandling",
    "förhandlingars": "förhandling",
    "förhandlingen": "förhandling",
    "förhandlingens": "förhandling",
    "förhandlings": "förhandling",
    "förhandlingsbara": "förhandlingsbar",
    "förhandlingsbarare": "förhandlingsbar",
    "förhandlingsbarares": "förhandlingsbar",
    "förhandlingsbaras": "förhandlingsbar",
    "förhandlingsbarast": "förhandlingsbar",
    "förhandlingsbaraste": "förhandlingsbar",
    "förhandlingsbarastes": "förhandlingsbar",
    "förhandlingsbarasts": "förhandlingsbar",
    "förhandlingsbare": "förhandlingsbar",
    "förhandlingsbares": "förhandlingsbar",
    "förhandlingsbarheten": "förhandlingsbarhet",
    "förhandlingsbarhetens": "förhandlingsbarhet",
    "förhandlingsbarhets": "förhandlingsbarhet",
    "förhandlingsbars": "förhandlingsbar",
    "förhandlingsbart": "förhandlingsbar",
    "förhandlingsbarts": "förhandlingsbar",
    "förhandlingsborden": "förhandlingsbord",
    "förhandlingsbordens": "förhandlingsbord",
    "förhandlingsbordet": "förhandlingsbord",
    "förhandlingsbordets": "förhandlingsbord",
    "förhandlingsbords": "förhandlingsbord",
    "förhandlingsbrick": "förhandlingsbricka",
    "förhandlingsbrickan": "förhandlingsbricka",
    "förhandlingsbrickans": "förhandlingsbricka",
    "förhandlingsbrickas": "förhandlingsbricka",
    "förhandlingsbricke": "förhandlingsbricka",
    "förhandlingsbrickor": "förhandlingsbricka",
    "förhandlingsbrickorna": "förhandlingsbricka",
    "förhandlingsbrickornas": "förhandlingsbricka",
    "förhandlingsbrickors": "förhandlingsbricka",
    "förhandlingsbricks": "förhandlingsbricka",
    "förhandlingsfrågan": "förhandlingsfråga",
    "förhandlingsfrågans": "förhandlingsfråga",
    "förhandlingsfrågas": "förhandlingsfråga",
    "förhandlingsfråge": "förhandlingsfråga",
    "förhandlingsfrågor": "förhandlingsfråga",
    "förhandlingsfrågorna": "förhandlingsfråga",
    "förhandlingsfrågornas": "förhandlingsfråga",
    "förhandlingsfrågors": "förhandlingsfråga",
    "förhandlingslägen": "förhandlingsläge",
    "förhandlingslägena": "förhandlingsläge",
    "förhandlingslägenas": "förhandlingsläge",
    "förhandlingslägens": "förhandlingsläge",
    "förhandlingsläges": "förhandlingsläge",
    "förhandlingsläget": "förhandlingsläge",
    "förhandlingslägets": "förhandlingsläge",
    "förhandlingsmodellen": "förhandlingsmodell",
    "förhandlingsmodellens": "förhandlingsmodell",
    "förhandlingsmodeller": "förhandlingsmodell",
    "förhandlingsmodellerna": "förhandlingsmodell",
    "förhandlingsmodellernas": "förhandlingsmodell",
    "förhandlingsmodellers": "förhandlingsmodell",
    "förhandlingsmodells": "förhandlingsmodell",
    "förhandlingsmässiga": "förhandlingsmässig",
    "förhandlingsmässigare": "förhandlingsmässig",
    "förhandlingsmässigares": "förhandlingsmässig",
    "förhandlingsmässigas": "förhandlingsmässig",
    "förhandlingsmässigast": "förhandlingsmässig",
    "förhandlingsmässigaste": "förhandlingsmässig",
    "förhandlingsmässigastes": "förhandlingsmässig",
    "förhandlingsmässigasts": "förhandlingsmässig",
    "förhandlingsmässige": "förhandlingsmässig",
    "förhandlingsmässiges": "förhandlingsmässig",
    "förhandlingsmässigs": "förhandlingsmässig",
    "förhandlingsmässigt": "förhandlingsmässig",
    "förhandlingsmässigts": "förhandlingsmässig",
    "förhandlingsrätten": "förhandlingsrätt",
    "förhandlingsrättens": "förhandlingsrätt",
    "förhandlingsrätts": "förhandlingsrätt",
    "förhandlingstricken": "förhandlingstrick",
    "förhandlingstrickens": "förhandlingstrick",
    "förhandlingstricket": "förhandlingstrick",
    "förhandlingstrickets": "förhandlingstrick",
    "förhandlingstricks": "förhandlingstrick",
    "förhands": "förhand",
    "förhandsbeställningar": "förhandsbeställning",
    "förhandsbeställningarna": "förhandsbeställning",
    "förhandsbeställningarnas": "förhandsbeställning",
    "förhandsbeställningars": "förhandsbeställning",
    "förhandsbeställningen": "förhandsbeställning",
    "förhandsbeställningens": "förhandsbeställning",
    "förhandsbeställnings": "förhandsbeställning",
    "förhandsbukten": "förhandsbukt",
    "förhandsbuktens": "förhandsbukt",
    "förhandsbukter": "förhandsbukt",
    "förhandsbukterna": "förhandsbukt",
    "förhandsbukternas": "förhandsbukt",
    "förhandsbukters": "förhandsbukt",
    "förhandsbukts": "förhandsbukt",
    "förhandscensuren": "förhandscensur",
    "förhandscensurens": "förhandscensur",
    "förhandscensurs": "förhandscensur",
    "förhandsinformationen": "förhandsinformation",
    "förhandsinformationens": "förhandsinformation",
    "förhandsinformationer": "förhandsinformation",
    "förhandsinformationerna": "förhandsinformation",
    "förhandsinformationernas": "förhandsinformation",
    "förhandsinformationers": "förhandsinformation",
    "förhandsinformations": "förhandsinformation",
    "förhandskopian": "förhandskopia",
    "förhandskopians": "förhandskopia",
    "förhandskopias": "förhandskopia",
    "förhandskopie": "förhandskopia",
    "förhandskopior": "förhandskopia",
    "förhandskopiorna": "förhandskopia",
    "förhandskopiornas": "förhandskopia",
    "förhandskopiors": "förhandskopia",
    "förhastade": "förhastad",
    "förhastades": "förhastad",
    "förhastads": "förhastad",
    "förhastat": "förhastad",
    "förhastats": "förhastad",
    "förhatliga": "förhatlig",
    "förhatligare": "förhatlig",
    "förhatligares": "förhatlig",
    "förhatligas": "förhatlig",
    "förhatligast": "förhatlig",
    "förhatligaste": "förhatlig",
    "förhatligastes": "förhatlig",
    "förhatligasts": "förhatlig",
    "förhatlige": "förhatlig",
    "förhatliges": "förhatlig",
    "förhatligheten": "förhatlighet",
    "förhatlighetens": "förhatlighet",
    "förhatligheter": "förhatlighet",
    "förhatligheterna": "förhatlighet",
    "förhatligheternas": "förhatlighet",
    "förhatligheters": "förhatlighet",
    "förhatlighets": "förhatlighet",
    "förhatligs": "förhatlig",
    "förhatligt": "förhatlig",
    "förhatligts": "förhatlig",
    "förhinderen": "förhinder",
    "förhinderens": "förhinder",
    "förhinderet": "förhinder",
    "förhinderets": "förhinder",
    "förhinders": "förhinder",
    "förhindrad": "förhindra",
    "förhindrade": "förhindra",
    "förhindrades": "förhindra",
    "förhindrads": "förhindra",
    "förhindrande": "förhindra",
    "förhindranden": "förhindrande",
    "förhindrandena": "förhindrande",
    "förhindrandenas": "förhindrande",
    "förhindrandens": "förhindrande",
    "förhindrandes": "förhindrande",
    "förhindrandet": "förhindrande",
    "förhindrandets": "förhindrande",
    "förhindrar": "förhindra",
    "förhindras": "förhindra",
    "förhindrat": "förhindra",
    "förhindrats": "förhindra",
    "förhindren": "förhinder",
    "förhindrens": "förhinder",
    "förhindret": "förhinder",
    "förhindrets": "förhinder",
    "förhistorian": "förhistoria",
    "förhistorians": "förhistoria",
    "förhistorias": "förhistoria",
    "förhistorien": "förhistoria",
    "förhistoriens": "förhistoria",
    "förhistoriska": "förhistorisk",
    "förhistoriskare": "förhistorisk",
    "förhistoriskares": "förhistorisk",
    "förhistoriskas": "förhistorisk",
    "förhistoriskast": "förhistorisk",
    "förhistoriskaste": "förhistorisk",
    "förhistoriskastes": "förhistorisk",
    "förhistoriskasts": "förhistorisk",
    "förhistoriske": "förhistorisk",
    "förhistoriskes": "förhistorisk",
    "förhistorisks": "förhistorisk",
    "förhistoriskt": "förhistorisk",
    "förhistoriskts": "förhistorisk",
    "förhoppningar": "förhoppning",
    "förhoppningarna": "förhoppning",
    "förhoppningarnas": "förhoppning",
    "förhoppningars": "förhoppning",
    "förhoppningen": "förhoppning",
    "förhoppningens": "förhoppning",
    "förhoppnings": "förhoppning",
    "förhoppningsfulla": "förhoppningsfull",
    "förhoppningsfullare": "förhoppningsfull",
    "förhoppningsfullares": "förhoppningsfull",
    "förhoppningsfullas": "förhoppningsfull",
    "förhoppningsfullast": "förhoppningsfull",
    "förhoppningsfullaste": "förhoppningsfull",
    "förhoppningsfullastes": "förhoppningsfull",
    "förhoppningsfullasts": "förhoppningsfull",
    "förhoppningsfulle": "förhoppningsfull",
    "förhoppningsfulles": "förhoppningsfull",
    "förhoppningsfullheten": "förhoppningsfullhet",
    "förhoppningsfullhetens": "förhoppningsfullhet",
    "förhoppningsfullhets": "förhoppningsfullhet",
    "förhoppningsfulls": "förhoppningsfull",
    "förhoppningsfullt": "förhoppningsfull",
    "förhoppningsfullts": "förhoppningsfull",
    "förhuden": "förhud",
    "förhudens": "förhud",
    "förhuds": "förhud",
    "förhudsförträngningen": "förhudsförträngning",
    "förhudsförträngningens": "förhudsförträngning",
    "förhudsförträngnings": "förhudsförträngning",
    "förhuggningar": "förhuggning",
    "förhuggningarna": "förhuggning",
    "förhuggningarnas": "förhuggning",
    "förhuggningars": "förhuggning",
    "förhuggningen": "förhuggning",
    "förhuggningens": "förhuggning",
    "förhuggnings": "förhuggning",
    "förhyd": "förhyda",
    "förhydande": "förhyda",
    "förhydanden": "förhydande",
    "förhydandena": "förhydande",
    "förhydandenas": "förhydande",
    "förhydandens": "förhydande",
    "förhydandes": "förhydande",
    "förhydandet": "förhydande",
    "förhydandets": "förhydande",
    "förhydas": "förhyda",
    "förhydd": "förhyda",
    "förhydda": "förhyda",
    "förhyddas": "förhyda",
    "förhydde": "förhyda",
    "förhyddes": "förhyda",
    "förhydds": "förhyda",
    "förhyder": "förhyda",
    "förhydes": "förhyda",
    "förhydningspappen": "förhydningspapp",
    "förhydningspappens": "förhydningspapp",
    "förhydningspapps": "förhydningspapp",
    "förhyds": "förhyda",
    "förhyr": "förhyra",
    "förhyrande": "förhyra",
    "förhyranden": "förhyrande",
    "förhyrandena": "förhyrande",
    "förhyrandenas": "förhyrande",
    "förhyrandens": "förhyrande",
    "förhyrandes": "förhyrande",
    "förhyrandet": "förhyrande",
    "förhyrandets": "förhyrande",
    "förhyras": "förhyra",
    "förhyrd": "förhyra",
    "förhyrda": "förhyra",
    "förhyrdas": "förhyra",
    "förhyrde": "förhyra",
    "förhyrdes": "förhyra",
    "förhyrds": "förhyra",
    "förhyres": "förhyra",
    "förhyrs": "förhyra",
    "förhyrt": "förhyra",
    "förhyrts": "förhyra",
    "förhytt": "förhyda",
    "förhytts": "förhyda",
    "förhänder": "förhand",
    "förhänderna": "förhand",
    "förhändernas": "förhand",
    "förhänders": "förhand",
    "förhängen": "förhänge",
    "förhängena": "förhänge",
    "förhängenas": "förhänge",
    "förhängens": "förhänge",
    "förhänges": "förhänge",
    "förhänget": "förhänge",
    "förhängets": "förhänge",
    "förhängs": "förhänge",
    "förhärd": "förhärda",
    "förhärdad": "förhärda",
    "förhärdade": "förhärda",
    "förhärdades": "förhärda",
    "förhärdads": "förhärda",
    "förhärdande": "förhärda",
    "förhärdanden": "förhärdande",
    "förhärdandena": "förhärdande",
    "förhärdandenas": "förhärdande",
    "förhärdandens": "förhärdande",
    "förhärdandes": "förhärdande",
    "förhärdandet": "förhärdande",
    "förhärdandets": "förhärdande",
    "förhärdar": "förhärda",
    "förhärdas": "förhärda",
    "förhärdat": "förhärda",
    "förhärdats": "förhärda",
    "förhärj": "förhärja",
    "förhärjad": "förhärja",
    "förhärjade": "förhärja",
    "förhärjades": "förhärja",
    "förhärjads": "förhärja",
    "förhärjande": "förhärja",
    "förhärjanden": "förhärjande",
    "förhärjandena": "förhärjande",
    "förhärjandenas": "förhärjande",
    "förhärjandens": "förhärjande",
    "förhärjandes": "förhärjande",
    "förhärjandet": "förhärjande",
    "förhärjandets": "förhärjande",
    "förhärjar": "förhärja",
    "förhärjas": "förhärja",
    "förhärjat": "förhärja",
    "förhärjats": "förhärja",
    "förhärlig": "förhärliga",
    "förhärligad": "förhärliga",
    "förhärligade": "förhärliga",
    "förhärligades": "förhärliga",
    "förhärligads": "förhärliga",
    "förhärligande": "förhärliga",
    "förhärliganden": "förhärligande",
    "förhärligandena": "förhärligande",
    "förhärligandenas": "förhärligande",
    "förhärligandens": "förhärligande",
    "förhärligandes": "förhärligande",
    "förhärligandet": "förhärligande",
    "förhärligandets": "förhärligande",
    "förhärligar": "förhärliga",
    "förhärligas": "förhärliga",
    "förhärligat": "förhärliga",
    "förhärligats": "förhärliga",
    "förhärskade": "förhärska",
    "förhärskades": "förhärska",
    "förhärskande": "förhärska",
    "förhärskanden": "förhärskande",
    "förhärskandena": "förhärskande",
    "förhärskandenas": "förhärskande",
    "förhärskandens": "förhärskande",
    "förhärskandes": "förhärskande",
    "förhärskandet": "förhärskande",
    "förhärskandets": "förhärskande",
    "förhärskar": "förhärska",
    "förhärskas": "förhärska",
    "förhärskat": "förhärska",
    "förhärskats": "förhärska",
    "förhäx": "förhäxa",
    "förhäxad": "förhäxa",
    "förhäxade": "förhäxa",
    "förhäxades": "förhäxa",
    "förhäxads": "förhäxa",
    "förhäxande": "förhäxa",
    "förhäxanden": "förhäxande",
    "förhäxandena": "förhäxande",
    "förhäxandenas": "förhäxande",
    "förhäxandens": "förhäxande",
    "förhäxandes": "förhäxande",
    "förhäxandet": "förhäxande",
    "förhäxandets": "förhäxande",
    "förhäxar": "förhäxa",
    "förhäxas": "förhäxa",
    "förhäxat": "förhäxa",
    "förhäxats": "förhäxa",
    "förhåll": "förhålla",
    "förhållande": "förhålla",
    "förhållanden": "förhållande",
    "förhållandena": "förhållande",
    "förhållandenas": "förhållande",
    "förhållandens": "förhållande",
    "förhållandes": "förhållande",
    "förhållandet": "förhållande",
    "förhållandets": "förhållande",
    "förhållas": "förhålla",
    "förhålle": "förhålla",
    "förhållen": "förhåll",
    "förhållens": "förhåll",
    "förhåller": "förhålla",
    "förhålles": "förhålla",
    "förhållet": "förhåll",
    "förhållets": "förhåll",
    "förhållit": "förhålla",
    "förhållits": "förhållas",
    "förhållningar": "förhållning",
    "förhållningarna": "förhållning",
    "förhållningarnas": "förhållning",
    "förhållningars": "förhållning",
    "förhållningen": "förhållning",
    "förhållningens": "förhållning",
    "förhållnings": "förhållning",
    "förhållningsordern": "förhållningsorder",
    "förhållningsorderna": "förhållningsorder",
    "förhållningsordernas": "förhållningsorder",
    "förhållningsorderns": "förhållningsorder",
    "förhållningsorders": "förhållningsorder",
    "förhållningsordrar": "förhållningsorder",
    "förhållningsordrarna": "förhållningsorder",
    "förhållningsordrarnas": "förhållningsorder",
    "förhållningsordrars": "förhållningsorder",
    "förhållningsregeln": "förhållningsregel",
    "förhållningsregelns": "förhållningsregel",
    "förhållningsregels": "förhållningsregel",
    "förhållningsregler": "förhållningsregel",
    "förhållningsreglerna": "förhållningsregel",
    "förhållningsreglernas": "förhållningsregel",
    "förhållningsreglers": "förhållningsregel",
    "förhållningssätten": "förhållningssätt",
    "förhållningssättens": "förhållningssätt",
    "förhållningssättet": "förhållningssätt",
    "förhållningssättets": "förhållningssätt",
    "förhållningssätts": "förhållningssätt",
    "förhålls": "förhållas",
    "förhån": "förhåna",
    "förhånad": "förhåna",
    "förhånade": "förhåna",
    "förhånades": "förhåna",
    "förhånads": "förhåna",
    "förhånande": "förhåna",
    "förhånanden": "förhånande",
    "förhånandena": "förhånande",
    "förhånandenas": "förhånande",
    "förhånandens": "förhånande",
    "förhånandes": "förhånande",
    "förhånandet": "förhånande",
    "förhånandets": "förhånande",
    "förhånar": "förhåna",
    "förhånas": "förhåna",
    "förhånat": "förhåna",
    "förhånats": "förhåna",
    "förhårdnaden": "förhårdnad",
    "förhårdnadens": "förhårdnad",
    "förhårdnader": "förhårdnad",
    "förhårdnaderna": "förhårdnad",
    "förhårdnadernas": "förhårdnad",
    "förhårdnaders": "förhårdnad",
    "förhårdnads": "förhårdnad",
    "förhöj": "förhöja",
    "förhöjande": "förhöja",
    "förhöjanden": "förhöjande",
    "förhöjandena": "förhöjande",
    "förhöjandenas": "förhöjande",
    "förhöjandens": "förhöjande",
    "förhöjandes": "förhöjande",
    "förhöjandet": "förhöjande",
    "förhöjandets": "förhöjande",
    "förhöjas": "förhöja",
    "förhöjd": "förhöja",
    "förhöjda": "förhöja",
    "förhöjdas": "förhöja",
    "förhöjde": "förhöja",
    "förhöjdes": "förhöja",
    "förhöjds": "förhöja",
    "förhöjer": "förhöja",
    "förhöjes": "förhöja",
    "förhöjningar": "förhöjning",
    "förhöjningarna": "förhöjning",
    "förhöjningarnas": "förhöjning",
    "förhöjningars": "förhöjning",
    "förhöjningen": "förhöjning",
    "förhöjningens": "förhöjning",
    "förhöjnings": "förhöjning",
    "förhöjs": "förhöja",
    "förhöjt": "förhöja",
    "förhöjts": "förhöja",
    "förhöll": "förhålla",
    "förhölle": "förhålla",
    "förhölles": "förhålla",
    "förhölls": "förhållas",
    "förhör": "förhöra",
    "förhörande": "förhöra",
    "förhöranden": "förhörande",
    "förhörandena": "förhörande",
    "förhörandenas": "förhörande",
    "förhörandens": "förhörande",
    "förhörandes": "förhörande",
    "förhörandet": "förhörande",
    "förhörandets": "förhörande",
    "förhöras": "förhöra",
    "förhörd": "förhöra",
    "förhörda": "förhöra",
    "förhördas": "förhöra",
    "förhörde": "förhöra",
    "förhördes": "förhöra",
    "förhörds": "förhöra",
    "förhören": "förhör",
    "förhörens": "förhör",
    "förhöres": "förhöra",
    "förhöret": "förhör",
    "förhörets": "förhör",
    "förhörs": "förhöra",
    "förhörsledar": "förhörsledare",
    "förhörsledaren": "förhörsledare",
    "förhörsledarens": "förhörsledare",
    "förhörsledares": "förhörsledare",
    "förhörsledarna": "förhörsledare",
    "förhörsledarnas": "förhörsledare",
    "förhörsprotokollen": "förhörsprotokoll",
    "förhörsprotokollens": "förhörsprotokoll",
    "förhörsprotokollet": "förhörsprotokoll",
    "förhörsprotokollets": "förhörsprotokoll",
    "förhörsprotokolls": "förhörsprotokoll",
    "förhörsrummen": "förhörsrum",
    "förhörsrummens": "förhörsrum",
    "förhörsrummet": "förhörsrum",
    "förhörsrummets": "förhörsrum",
    "förhörsrums": "förhörsrum",
    "förhörsrumsscenerier": "förhörsrumssceneri",
    "förhörsrumsscenerierna": "förhörsrumssceneri",
    "förhörsrumssceneriernas": "förhörsrumssceneri",
    "förhörsrumssceneriers": "förhörsrumssceneri",
    "förhörsrumssceneriet": "förhörsrumssceneri",
    "förhörsrumssceneriets": "förhörsrumssceneri",
    "förhörsrumssceneris": "förhörsrumssceneri",
    "förhörsrumsscenerit": "förhörsrumssceneri",
    "förhörsrumsscenerits": "förhörsrumssceneri",
    "förhörsvittnen": "förhörsvittne",
    "förhörsvittnena": "förhörsvittne",
    "förhörsvittnenas": "förhörsvittne",
    "förhörsvittnens": "förhörsvittne",
    "förhörsvittnes": "förhörsvittne",
    "förhörsvittnet": "förhörsvittne",
    "förhörsvittnets": "förhörsvittne",
    "förhört": "förhöra",
    "förhörts": "förhöra",
    "förint": "förinta",
    "förintad": "förinta",
    "förintade": "förinta",
    "förintades": "förinta",
    "förintads": "förinta",
    "förintande": "förinta",
    "förintanden": "förintande",
    "förintandena": "förintande",
    "förintandenas": "förintande",
    "förintandens": "förintande",
    "förintandes": "förintande",
    "förintandet": "förintande",
    "förintandets": "förintande",
    "förintar": "förinta",
    "förintas": "förinta",
    "förintat": "förinta",
    "förintats": "förinta",
    "förintelsemuseer": "förintelsemuseum",
    "förintelsemuseerna": "förintelsemuseum",
    "förintelsemuseernas": "förintelsemuseum",
    "förintelsemuseers": "förintelsemuseum",
    "förintelsemuseet": "förintelsemuseum",
    "förintelsemuseets": "förintelsemuseum",
    "förintelsemusei": "förintelsemuseum",
    "förintelsemuseums": "förintelsemuseum",
    "förintelsen": "förintelse",
    "förintelsens": "förintelse",
    "förintelses": "förintelse",
    "förjag": "förjaga",
    "förjagad": "förjaga",
    "förjagade": "förjaga",
    "förjagades": "förjaga",
    "förjagads": "förjaga",
    "förjagande": "förjaga",
    "förjaganden": "förjagande",
    "förjagandena": "förjagande",
    "förjagandenas": "förjagande",
    "förjagandens": "förjagande",
    "förjagandes": "förjagande",
    "förjagandet": "förjagande",
    "förjagandets": "förjagande",
    "förjagar": "förjaga",
    "förjagas": "förjaga",
    "förjagat": "förjaga",
    "förjagats": "förjaga",
    "förkalkades": "förkalkas",
    "förkalkats": "förkalkas",
    "förkalkningar": "förkalkning",
    "förkalkningarna": "förkalkning",
    "förkalkningarnas": "förkalkning",
    "förkalkningars": "förkalkning",
    "förkalkningen": "förkalkning",
    "förkalkningens": "förkalkning",
    "förkalknings": "förkalkning",
    "förkast": "förkasta",
    "förkastad": "förkasta",
    "förkastade": "förkasta",
    "förkastades": "förkasta",
    "förkastads": "förkasta",
    "förkastande": "förkasta",
    "förkastanden": "förkastande",
    "förkastandena": "förkastande",
    "förkastandenas": "förkastande",
    "förkastandens": "förkastande",
    "förkastandes": "förkastande",
    "förkastandet": "förkastande",
    "förkastandets": "förkastande",
    "förkastar": "förkasta",
    "förkastas": "förkasta",
    "förkastat": "förkasta",
    "förkastats": "förkasta",
    "förkastelsedomar": "förkastelsedom",
    "förkastelsedomarna": "förkastelsedom",
    "förkastelsedomarnas": "förkastelsedom",
    "förkastelsedomars": "förkastelsedom",
    "förkastelsedomen": "förkastelsedom",
    "förkastelsedomens": "förkastelsedom",
    "förkastelsedoms": "förkastelsedom",
    "förkastelsen": "förkastelse",
    "förkastelsens": "förkastelse",
    "förkastelses": "förkastelse",
    "förkastliga": "förkastlig",
    "förkastligare": "förkastlig",
    "förkastligares": "förkastlig",
    "förkastligas": "förkastlig",
    "förkastligast": "förkastlig",
    "förkastligaste": "förkastlig",
    "förkastligastes": "förkastlig",
    "förkastligasts": "förkastlig",
    "förkastlige": "förkastlig",
    "förkastliges": "förkastlig",
    "förkastligheten": "förkastlighet",
    "förkastlighetens": "förkastlighet",
    "förkastlighets": "förkastlighet",
    "förkastligs": "förkastlig",
    "förkastligt": "förkastlig",
    "förkastligts": "förkastlig",
    "förkastningar": "förkastning",
    "förkastningarna": "förkastning",
    "förkastningarnas": "förkastning",
    "förkastningars": "förkastning",
    "förkastningen": "förkastning",
    "förkastningens": "förkastning",
    "förkastnings": "förkastning",
    "förklar": "förklara",
    "förklarad": "förklara",
    "förklarade": "förklarad",
    "förklarades": "förklarad",
    "förklarads": "förklarad",
    "förklarande": "förklara",
    "förklaranden": "förklarande",
    "förklarandena": "förklarande",
    "förklarandenas": "förklarande",
    "förklarandens": "förklarande",
    "förklarandes": "förklarande",
    "förklarandet": "förklarande",
    "förklarandets": "förklarande",
    "förklarar": "förklara",
    "förklaras": "förklara",
    "förklarat": "förklarad",
    "förklarats": "förklarad",
    "förklaringar": "förklaring",
    "förklaringarna": "förklaring",
    "förklaringarnas": "förklaring",
    "förklaringars": "förklaring",
    "förklaringen": "förklaring",
    "förklaringens": "förklaring",
    "förklarings": "förklaring",
    "förklaringskraften": "förklaringskraft",
    "förklaringskraftens": "förklaringskraft",
    "förklaringskrafts": "förklaringskraft",
    "förklaringsmodellen": "förklaringsmodell",
    "förklaringsmodellens": "förklaringsmodell",
    "förklaringsmodeller": "förklaringsmodell",
    "förklaringsmodellerna": "förklaringsmodell",
    "förklaringsmodellernas": "förklaringsmodell",
    "förklaringsmodellers": "förklaringsmodell",
    "förklaringsmodells": "förklaringsmodell",
    "förklarliga": "förklarlig",
    "förklarligare": "förklarlig",
    "förklarligares": "förklarlig",
    "förklarligas": "förklarlig",
    "förklarligast": "förklarlig",
    "förklarligaste": "förklarlig",
    "förklarligastes": "förklarlig",
    "förklarligasts": "förklarlig",
    "förklarlige": "förklarlig",
    "förklarliges": "förklarlig",
    "förklarligs": "förklarlig",
    "förklarligt": "förklarlig",
    "förklarligts": "förklarlig",
    "förkling": "förklinga",
    "förklingad": "förklinga",
    "förklingade": "förklinga",
    "förklingades": "förklinga",
    "förklingads": "förklinga",
    "förklingande": "förklinga",
    "förklinganden": "förklingande",
    "förklingandena": "förklingande",
    "förklingandenas": "förklingande",
    "förklingandens": "förklingande",
    "förklingandes": "förklingande",
    "förklingandet": "förklingande",
    "förklingandets": "förklingande",
    "förklingar": "förklinga",
    "förklingas": "förklinga",
    "förklingat": "förklinga",
    "förklingats": "förklinga",
    "förklistrad": "förklistra",
    "förklistrade": "förklistra",
    "förklistrades": "förklistra",
    "förklistrads": "förklistra",
    "förklistrande": "förklistra",
    "förklistranden": "förklistrande",
    "förklistrandena": "förklistrande",
    "förklistrandenas": "förklistrande",
    "förklistrandens": "förklistrande",
    "förklistrandes": "förklistrande",
    "förklistrandet": "förklistrande",
    "förklistrandets": "förklistrande",
    "förklistrar": "förklistra",
    "förklistras": "förklistra",
    "förklistrat": "förklistra",
    "förklistrats": "förklistra",
    "förklistringar": "förklistring",
    "förklistringarna": "förklistring",
    "förklistringarnas": "förklistring",
    "förklistringars": "förklistring",
    "förklistringen": "förklistring",
    "förklistringens": "förklistring",
    "förklistrings": "förklistring",
    "förklyftningar": "förklyftning",
    "förklyftningarna": "förklyftning",
    "förklyftningarnas": "förklyftning",
    "förklyftningars": "förklyftning",
    "förklyftningen": "förklyftning",
    "förklyftningens": "förklyftning",
    "förklyftnings": "förklyftning",
    "förklädda": "förklädd",
    "förkläddare": "förklädd",
    "förkläddares": "förklädd",
    "förkläddas": "förklädd",
    "förkläddast": "förklädd",
    "förkläddaste": "förklädd",
    "förkläddastes": "förklädd",
    "förkläddasts": "förklädd",
    "förklädde": "förklädd",
    "förkläddes": "förklädd",
    "förkläddheten": "förkläddhet",
    "förkläddhetens": "förkläddhet",
    "förkläddhets": "förkläddhet",
    "förklädds": "förklädd",
    "förkläden": "förkläde",
    "förklädena": "förkläde",
    "förklädenas": "förkläde",
    "förklädens": "förkläde",
    "förklädes": "förkläde",
    "förklädeskjolar": "förklädeskjol",
    "förklädeskjolarna": "förklädeskjol",
    "förklädeskjolarnas": "förklädeskjol",
    "förklädeskjolars": "förklädeskjol",
    "förklädeskjolen": "förklädeskjol",
    "förklädeskjolens": "förklädeskjol",
    "förklädeskjols": "förklädeskjol",
    "förklädet": "förkläde",
    "förklädets": "förkläde",
    "förklädnaden": "förklädnad",
    "förklädnadens": "förklädnad",
    "förklädnader": "förklädnad",
    "förklädnaderna": "förklädnad",
    "förklädnadernas": "förklädnad",
    "förklädnaders": "förklädnad",
    "förklädnads": "förklädnad",
    "förkläenden": "förkläende",
    "förkläendena": "förkläende",
    "förkläendenas": "förkläende",
    "förkläendens": "förkläende",
    "förkläendes": "förkläende",
    "förkläendet": "förkläende",
    "förkläendets": "förkläende",
    "förklän": "förklä",
    "förkläna": "förklä",
    "förklänas": "förklä",
    "förkläns": "förklä",
    "förkläs": "förklä",
    "förklät": "förklä",
    "förkläts": "förklä",
    "förklätt": "förklädd",
    "förklätts": "förklädd",
    "förknipp": "förknippa",
    "förknippad": "förknippa",
    "förknippade": "förknippa",
    "förknippades": "förknippa",
    "förknippads": "förknippa",
    "förknippande": "förknippa",
    "förknippanden": "förknippande",
    "förknippandena": "förknippande",
    "förknippandenas": "förknippande",
    "förknippandens": "förknippande",
    "förknippandes": "förknippande",
    "förknippandet": "förknippande",
    "förknippandets": "förknippande",
    "förknippar": "förknippa",
    "förknippas": "förknippa",
    "förknippat": "förknippa",
    "förknippats": "förknippa",
    "förknippningar": "förknippning",
    "förknippningarna": "förknippning",
    "förknippningarnas": "förknippning",
    "förknippningars": "förknippning",
    "förknippningen": "förknippning",
    "förknippningens": "förknippning",
    "förknippnings": "förknippning",
    "förkoksades": "förkoksas",
    "förkoksats": "förkoksas",
    "förkoln": "förkolna",
    "förkolnad": "förkolna",
    "förkolnade": "förkolna",
    "förkolnades": "förkolna",
    "förkolnads": "förkolna",
    "förkolnande": "förkolna",
    "förkolnanden": "förkolnande",
    "förkolnandena": "förkolnande",
    "förkolnandenas": "förkolnande",
    "förkolnandens": "förkolnande",
    "förkolnandes": "förkolnande",
    "förkolnandet": "förkolnande",
    "förkolnandets": "förkolnande",
    "förkolnar": "förkolna",
    "förkolnas": "förkolna",
    "förkolnat": "förkolna",
    "förkolnats": "förkolna",
    "förkom": "förkomma",
    "förkomet": "förkomma",
    "förkomets": "förkomma",
    "förkommande": "förkomma",
    "förkommanden": "förkommande",
    "förkommandena": "förkommande",
    "förkommandenas": "förkommande",
    "förkommandens": "förkommande",
    "förkommandes": "förkommande",
    "förkommandet": "förkommande",
    "förkommandets": "förkommande",
    "förkommas": "förkomma",
    "förkomme": "förkomma",
    "förkommen": "förkomma",
    "förkommens": "förkommen",
    "förkommer": "förkomma",
    "förkommes": "förkomma",
    "förkommet": "förkommen",
    "förkommets": "förkommen",
    "förkommit": "förkomma",
    "förkommits": "förkomma",
    "förkomna": "förkommen",
    "förkomnare": "förkommen",
    "förkomnares": "förkommen",
    "förkomnas": "förkommen",
    "förkomnast": "förkommen",
    "förkomnaste": "förkommen",
    "förkomnastes": "förkommen",
    "förkomnasts": "förkommen",
    "förkomne": "förkommen",
    "förkomnes": "förkommen",
    "förkoms": "förkomma",
    "förkonstlade": "förkonstlad",
    "förkonstlades": "förkonstlad",
    "förkonstlads": "förkonstlad",
    "förkonstlat": "förkonstlad",
    "förkonstlats": "förkonstlad",
    "förkonstlingar": "förkonstling",
    "förkonstlingarna": "förkonstling",
    "förkonstlingarnas": "förkonstling",
    "förkonstlingars": "förkonstling",
    "förkonstlingen": "förkonstling",
    "förkonstlingens": "förkonstling",
    "förkonstlings": "förkonstling",
    "förkort": "förkorta",
    "förkortad": "förkorta",
    "förkortade": "förkorta",
    "förkortades": "förkorta",
    "förkortads": "förkorta",
    "förkortande": "förkorta",
    "förkortanden": "förkortande",
    "förkortandena": "förkortande",
    "förkortandenas": "förkortande",
    "förkortandens": "förkortande",
    "förkortandes": "förkortande",
    "förkortandet": "förkortande",
    "förkortandets": "förkortande",
    "förkortar": "förkorta",
    "förkortas": "förkorta",
    "förkortat": "förkorta",
    "förkortats": "förkorta",
    "förkortningar": "förkortning",
    "förkortningarna": "förkortning",
    "förkortningarnas": "förkortning",
    "förkortningars": "förkortning",
    "förkortningen": "förkortning",
    "förkortningens": "förkortning",
    "förkortnings": "förkortning",
    "förkovrad": "förkovra",
    "förkovrade": "förkovra",
    "förkovrades": "förkovra",
    "förkovrads": "förkovra",
    "förkovrande": "förkovra",
    "förkovranden": "förkovrande",
    "förkovrandena": "förkovrande",
    "förkovrandenas": "förkovrande",
    "förkovrandens": "förkovrande",
    "förkovrandes": "förkovrande",
    "förkovrandet": "förkovrande",
    "förkovrandets": "förkovrande",
    "förkovrans": "förkovran",
    "förkovrar": "förkovra",
    "förkovras": "förkovra",
    "förkovrat": "förkovra",
    "förkovrats": "förkovra",
    "förkoxades": "förkoxas",
    "förkoxats": "förkoxas",
    "förkrigstiden": "förkrigstid",
    "förkrigstidens": "förkrigstid",
    "förkrigstider": "förkrigstid",
    "förkrigstiderna": "förkrigstid",
    "förkrigstidernas": "förkrigstid",
    "förkrigstiders": "förkrigstid",
    "förkrigstids": "förkrigstid",
    "förkristens": "förkristen",
    "förkristet": "förkristen",
    "förkristets": "förkristen",
    "förkristna": "förkristen",
    "förkristnare": "förkristen",
    "förkristnares": "förkristen",
    "förkristnas": "förkristen",
    "förkristnast": "förkristen",
    "förkristnaste": "förkristen",
    "förkristnastes": "förkristen",
    "förkristnasts": "förkristen",
    "förkristne": "förkristen",
    "förkristnes": "förkristen",
    "förkromad": "förkroma",
    "förkromade": "förkroma",
    "förkromades": "förkroma",
    "förkromads": "förkroma",
    "förkromande": "förkroma",
    "förkromanden": "förkromande",
    "förkromandena": "förkromande",
    "förkromandenas": "förkromande",
    "förkromandens": "förkromande",
    "förkromandes": "förkromande",
    "förkromandet": "förkromande",
    "förkromandets": "förkromande",
    "förkromar": "förkroma",
    "förkromas": "förkroma",
    "förkromat": "förkroma",
    "förkromats": "förkroma",
    "förkromningen": "förkromning",
    "förkromningens": "förkromning",
    "förkromnings": "förkromning",
    "förkroppningar": "förkroppning",
    "förkroppningarna": "förkroppning",
    "förkroppningarnas": "förkroppning",
    "förkroppningars": "förkroppning",
    "förkroppningen": "förkroppning",
    "förkroppningens": "förkroppning",
    "förkroppnings": "förkroppning",
    "förkroppslig": "förkroppsliga",
    "förkroppsligad": "förkroppsliga",
    "förkroppsligade": "förkroppsliga",
    "förkroppsligades": "förkroppsliga",
    "förkroppsligads": "förkroppsliga",
    "förkroppsligande": "förkroppsliga",
    "förkroppsliganden": "förkroppsligande",
    "förkroppsligandena": "förkroppsligande",
    "förkroppsligandenas": "förkroppsligande",
    "förkroppsligandens": "förkroppsligande",
    "förkroppsligandes": "förkroppsligande",
    "förkroppsligandet": "förkroppsligande",
    "förkroppsligandets": "förkroppsligande",
    "förkroppsligar": "förkroppsliga",
    "förkroppsligas": "förkroppsliga",
    "förkroppsligat": "förkroppsliga",
    "förkroppsligats": "förkroppsliga",
    "förkross": "förkrossa",
    "förkrossad": "förkrossa",
    "förkrossade": "förkrossad",
    "förkrossades": "förkrossad",
    "förkrossads": "förkrossad",
    "förkrossande": "förkrossa",
    "förkrossanden": "förkrossande",
    "förkrossandena": "förkrossande",
    "förkrossandenas": "förkrossande",
    "förkrossandens": "förkrossande",
    "förkrossandes": "förkrossande",
    "förkrossandet": "förkrossande",
    "förkrossandets": "förkrossande",
    "förkrossar": "förkrossa",
    "förkrossas": "förkrossa",
    "förkrossat": "förkrossad",
    "förkrossats": "förkrossad",
    "förkrosselsen": "förkrosselse",
    "förkrosselsens": "förkrosselse",
    "förkrosselses": "förkrosselse",
    "förkrymp": "förkrympa",
    "förkrympande": "förkrympa",
    "förkrympanden": "förkrympande",
    "förkrympandena": "förkrympande",
    "förkrympandenas": "förkrympande",
    "förkrympandens": "förkrympande",
    "förkrympandes": "förkrympande",
    "förkrympandet": "förkrympande",
    "förkrympandets": "förkrympande",
    "förkrympas": "förkrympa",
    "förkrymper": "förkrympa",
    "förkrympes": "förkrympa",
    "förkrymps": "förkrympa",
    "förkrympt": "förkrympa",
    "förkrympta": "förkrympt",
    "förkrymptare": "förkrympt",
    "förkrymptares": "förkrympt",
    "förkrymptas": "förkrympt",
    "förkrymptast": "förkrympt",
    "förkrymptaste": "förkrympt",
    "förkrymptastes": "förkrympt",
    "förkrymptasts": "förkrympt",
    "förkrympte": "förkrympt",
    "förkrymptes": "förkrympt",
    "förkrymptheten": "förkrympthet",
    "förkrympthetens": "förkrympthet",
    "förkrympthets": "förkrympthet",
    "förkrympts": "förkrympt",
    "förkråmad": "förkråma",
    "förkråmade": "förkråma",
    "förkråmades": "förkråma",
    "förkråmads": "förkråma",
    "förkråmande": "förkråma",
    "förkråmanden": "förkråmande",
    "förkråmandena": "förkråmande",
    "förkråmandenas": "förkråmande",
    "förkråmandens": "förkråmande",
    "förkråmandes": "förkråmande",
    "förkråmandet": "förkråmande",
    "förkråmandets": "förkråmande",
    "förkråmar": "förkråma",
    "förkråmas": "förkråma",
    "förkråmat": "förkråma",
    "förkråmats": "förkråma",
    "förkunn": "förkunna",
    "förkunnad": "förkunna",
    "förkunnade": "förkunna",
    "förkunnades": "förkunna",
    "förkunnads": "förkunna",
    "förkunnande": "förkunna",
    "förkunnanden": "förkunnande",
    "förkunnandena": "förkunnande",
    "förkunnandenas": "förkunnande",
    "förkunnandens": "förkunnande",
    "förkunnandes": "förkunnande",
    "förkunnandet": "förkunnande",
    "förkunnandets": "förkunnande",
    "förkunnar": "förkunnare",
    "förkunnaren": "förkunnare",
    "förkunnarens": "förkunnare",
    "förkunnares": "förkunnare",
    "förkunnarna": "förkunnare",
    "förkunnarnas": "förkunnare",
    "förkunnas": "förkunna",
    "förkunnat": "förkunna",
    "förkunnats": "förkunna",
    "förkunnelsen": "förkunnelse",
    "förkunnelsens": "förkunnelse",
    "förkunnelser": "förkunnelse",
    "förkunnelserna": "förkunnelse",
    "förkunnelsernas": "förkunnelse",
    "förkunnelsers": "förkunnelse",
    "förkunnelses": "förkunnelse",
    "förkunskaperna": "förkunskaper",
    "förkunskapernas": "förkunskaper",
    "förkunskapers": "förkunskaper",
    "förkunskaps": "förkunskaper",
    "förkväv": "förkväva",
    "förkvävande": "förkväva",
    "förkvävanden": "förkvävande",
    "förkvävandena": "förkvävande",
    "förkvävandenas": "förkvävande",
    "förkvävandens": "förkvävande",
    "förkvävandes": "förkvävande",
    "förkvävandet": "förkvävande",
    "förkvävandets": "förkvävande",
    "förkvävas": "förkväva",
    "förkvävd": "förkväva",
    "förkvävda": "förkväva",
    "förkvävdas": "förkväva",
    "förkvävde": "förkväva",
    "förkvävdes": "förkväva",
    "förkvävds": "förkväva",
    "förkväver": "förkväva",
    "förkväves": "förkväva",
    "förkvävs": "förkväva",
    "förkvävt": "förkväva",
    "förkvävts": "förkväva",
    "förkylda": "förkyld",
    "förkyldare": "förkyld",
    "förkyldares": "förkyld",
    "förkyldas": "förkyld",
    "förkyldast": "förkyld",
    "förkyldaste": "förkyld",
    "förkyldastes": "förkyld",
    "förkyldasts": "förkyld",
    "förkylde": "förkyld",
    "förkyldes": "förkyld",
    "förkyldheten": "förkyldhet",
    "förkyldhetens": "förkyldhet",
    "förkyldhets": "förkyldhet",
    "förkylds": "förkyld",
    "förkylningar": "förkylning",
    "förkylningarna": "förkylning",
    "förkylningarnas": "förkylning",
    "förkylningars": "förkylning",
    "förkylningen": "förkylning",
    "förkylningens": "förkylning",
    "förkylnings": "förkylning",
    "förkylt": "förkyld",
    "förkylts": "förkyld",
    "förkämpar": "förkämpe",
    "förkämparna": "förkämpe",
    "förkämparnas": "förkämpe",
    "förkämpars": "förkämpe",
    "förkämpen": "förkämpe",
    "förkämpens": "förkämpe",
    "förkämpes": "förkämpe",
    "förkänningar": "förkänning",
    "förkänningarna": "förkänning",
    "förkänningarnas": "förkänning",
    "förkänningars": "förkänning",
    "förkänningen": "förkänning",
    "förkänningens": "förkänning",
    "förkännings": "förkänning",
    "förkänsl": "förkänsla",
    "förkänslan": "förkänsla",
    "förkänslans": "förkänsla",
    "förkänslas": "förkänsla",
    "förkänsle": "förkänsla",
    "förkänslo": "förkänsla",
    "förkänslor": "förkänsla",
    "förkänslorna": "förkänsla",
    "förkänslornas": "förkänsla",
    "förkänslors": "förkänsla",
    "förkärlekar": "förkärlek",
    "förkärlekarna": "förkärlek",
    "förkärlekarnas": "förkärlek",
    "förkärlekars": "förkärlek",
    "förkärleken": "förkärlek",
    "förkärlekens": "förkärlek",
    "förkärleks": "förkärlek",
    "förkättrade": "förkättrad",
    "förkättrades": "förkättrad",
    "förkättrads": "förkättrad",
    "förkättrat": "förkättrad",
    "förkättrats": "förkättrad",
    "förköpen": "förköp",
    "förköpens": "förköp",
    "förköpet": "förköp",
    "förköpets": "förköp",
    "förköps": "förköp",
    "förköpsrätten": "förköpsrätt",
    "förköpsrättens": "förköpsrätt",
    "förköpsrätts": "förköpsrätt",
    "förkörsrätten": "förkörsrätt",
    "förkörsrättens": "förkörsrätt",
    "förkörsrätts": "förkörsrätt",
    "förla": "förlägga",
    "förladdningar": "förladdning",
    "förladdningarna": "förladdning",
    "förladdningarnas": "förladdning",
    "förladdningars": "förladdning",
    "förladdningen": "förladdning",
    "förladdningens": "förladdning",
    "förladdnings": "förladdning",
    "förlade": "förlägga",
    "förlades": "förlägga",
    "förlag": "förlaga",
    "förlagan": "förlaga",
    "förlagans": "förlaga",
    "förlagas": "förlaga",
    "förlagd": "förlägga",
    "förlagda": "förlägga",
    "förlagdas": "förlägga",
    "förlagde": "förlägga",
    "förlagdes": "förlägga",
    "förlagds": "förlägga",
    "förlage": "förlaga",
    "förlagen": "förlag",
    "förlagens": "förlag",
    "förlaget": "förlag",
    "förlagets": "förlag",
    "förlagor": "förlaga",
    "förlagorna": "förlaga",
    "förlagornas": "förlaga",
    "förlagors": "förlaga",
    "förlags": "förlaga",
    "förlagsbevisen": "förlagsbevis",
    "förlagsbevisens": "förlagsbevis",
    "förlagsbeviset": "förlagsbevis",
    "förlagsbevisets": "förlagsbevis",
    "förlagslånen": "förlagslån",
    "förlagslånens": "förlagslån",
    "förlagslånet": "förlagslån",
    "förlagslånets": "förlagslån",
    "förlagslåns": "förlagslån",
    "förlagsmässiga": "förlagsmässig",
    "förlagsmässigare": "förlagsmässig",
    "förlagsmässigares": "förlagsmässig",
    "förlagsmässigas": "förlagsmässig",
    "förlagsmässigast": "förlagsmässig",
    "förlagsmässigaste": "förlagsmässig",
    "förlagsmässigastes": "förlagsmässig",
    "förlagsmässigasts": "förlagsmässig",
    "förlagsmässige": "förlagsmässig",
    "förlagsmässiges": "förlagsmässig",
    "förlagsmässigs": "förlagsmässig",
    "förlagsmässigt": "förlagsmässig",
    "förlagsmässigts": "förlagsmässig",
    "förlagt": "förlägga",
    "förlagts": "förlägga",
    "förlam": "förlama",
    "förlamad": "förlama",
    "förlamade": "förlama",
    "förlamades": "förlama",
    "förlamads": "förlama",
    "förlamande": "förlama",
    "förlamanden": "förlamande",
    "förlamandena": "förlamande",
    "förlamandenas": "förlamande",
    "förlamandens": "förlamande",
    "förlamandes": "förlamande",
    "förlamandet": "förlamande",
    "förlamandets": "förlamande",
    "förlamar": "förlama",
    "förlamas": "förlama",
    "förlamat": "förlama",
    "förlamats": "förlama",
    "förlamningar": "förlamning",
    "förlamningarna": "förlamning",
    "förlamningarnas": "förlamning",
    "förlamningars": "förlamning",
    "förlamningen": "förlamning",
    "förlamningens": "förlamning",
    "förlamnings": "förlamning",
    "förlas": "förlägga",
    "förled": "förlida",
    "förledande": "förleda",
    "förledanden": "förledande",
    "förledandena": "förledande",
    "förledandenas": "förledande",
    "förledandens": "förledande",
    "förledandes": "förledande",
    "förledandet": "förledande",
    "förledandets": "förledande",
    "förledas": "förleda",
    "förledd": "förleda",
    "förledda": "förleda",
    "förleddas": "förleda",
    "förledde": "förleda",
    "förleddes": "förleda",
    "förledds": "förleda",
    "förleden": "förled",
    "förledens": "förled",
    "förleder": "förleda",
    "förlederna": "förled",
    "förledernas": "förled",
    "förleders": "förled",
    "förledes": "förleda",
    "förledet": "förled",
    "förledets": "förled",
    "förleds": "förlida",
    "förlegade": "förlegad",
    "förlegades": "förlegad",
    "förlegads": "förlegad",
    "förlegat": "förlegad",
    "förlegats": "förlegad",
    "förlett": "förleda",
    "förletts": "förleda",
    "förlid": "förlida",
    "förlidande": "förlida",
    "förlidanden": "förlidande",
    "förlidandena": "förlidande",
    "förlidandenas": "förlidande",
    "förlidandens": "förlidande",
    "förlidandes": "förlidande",
    "förlidandet": "förlidande",
    "förlidandets": "förlidande",
    "förlidas": "förlida",
    "förlide": "förlida",
    "förliden": "förlida",
    "förlidens": "förliden",
    "förlider": "förlida",
    "förlides": "förlida",
    "förlidet": "förliden",
    "förlidets": "förliden",
    "förlidit": "förlida",
    "förlidits": "förlida",
    "förlidna": "förliden",
    "förlidnare": "förliden",
    "förlidnares": "förliden",
    "förlidnas": "förliden",
    "förlidnast": "förliden",
    "förlidnaste": "förliden",
    "förlidnastes": "förliden",
    "förlidnasts": "förliden",
    "förlidne": "förliden",
    "förlidnes": "förliden",
    "förlids": "förlida",
    "förliga": "förlig",
    "förligare": "förlig",
    "förligares": "förlig",
    "förligas": "förlig",
    "förligast": "förlig",
    "förligaste": "förlig",
    "förligastes": "förlig",
    "förligasts": "förlig",
    "förlige": "förlig",
    "förliges": "förlig",
    "förligs": "förlig",
    "förligt": "förlig",
    "förligts": "förlig",
    "förlik": "förlika",
    "förlikande": "förlika",
    "förlikanden": "förlikande",
    "förlikandena": "förlikande",
    "förlikandenas": "förlikande",
    "förlikandens": "förlikande",
    "förlikandes": "förlikande",
    "förlikandet": "förlikande",
    "förlikandets": "förlikande",
    "förlikas": "förlika",
    "förliker": "förlika",
    "förlikes": "förlika",
    "förlikningar": "förlikning",
    "förlikningarna": "förlikning",
    "förlikningarnas": "förlikning",
    "förlikningars": "förlikning",
    "förlikningen": "förlikning",
    "förlikningens": "förlikning",
    "förliknings": "förlikning",
    "förlikningskommissionen": "förlikningskommission",
    "förlikningskommissionens": "förlikningskommission",
    "förlikningskommissioner": "förlikningskommission",
    "förlikningskommissionerna": "förlikningskommission",
    "förlikningskommissionernas": "förlikningskommission",
    "förlikningskommissioners": "förlikningskommission",
    "förlikningskommissions": "förlikningskommission",
    "förlikningsmannen": "förlikningsman",
    "förlikningsmannens": "förlikningsman",
    "förlikningsmans": "förlikningsman",
    "förlikningsmän": "förlikningsman",
    "förlikningsmännen": "förlikningsman",
    "förlikningsmännens": "förlikningsman",
    "förlikningsmäns": "förlikningsman",
    "förliks": "förlika",
    "förlikt": "förlika",
    "förlikta": "förlika",
    "förliktas": "förlika",
    "förlikte": "förlika",
    "förliktes": "förlikas",
    "förlikts": "förlikas",
    "förlis": "förlisa",
    "förlisande": "förlisa",
    "förlisanden": "förlisande",
    "förlisandena": "förlisande",
    "förlisandenas": "förlisande",
    "förlisandens": "förlisande",
    "förlisandes": "förlisande",
    "förlisandet": "förlisande",
    "förlisandets": "förlisande",
    "förlisas": "förlisa",
    "förliser": "förlisa",
    "förlises": "förlisa",
    "förlisningar": "förlisning",
    "förlisningarna": "förlisning",
    "förlisningarnas": "förlisning",
    "förlisningars": "förlisning",
    "förlisningen": "förlisning",
    "förlisningens": "förlisning",
    "förlisnings": "förlisning",
    "förlist": "förlisa",
    "förlista": "förlisa",
    "förlistas": "förlisa",
    "förliste": "förlisa",
    "förlistes": "förlisa",
    "förlists": "förlisa",
    "förlitandes": "förlitande",
    "förlitandet": "förlitande",
    "förlitandets": "förlitande",
    "förlitans": "förlitan",
    "förljudanden": "förljudande",
    "förljudandena": "förljudande",
    "förljudandenas": "förljudande",
    "förljudandens": "förljudande",
    "förljudandes": "förljudande",
    "förljudandet": "förljudande",
    "förljudandets": "förljudande",
    "förljudes": "förljudas",
    "förljudits": "förljudas",
    "förljuds": "förljudas",
    "förljugenheten": "förljugenhet",
    "förljugenhetens": "förljugenhet",
    "förljugenhets": "förljugenhet",
    "förljugens": "förljugen",
    "förljuget": "förljugen",
    "förljugets": "förljugen",
    "förljugna": "förljugen",
    "förljugnare": "förljugen",
    "förljugnares": "förljugen",
    "förljugnas": "förljugen",
    "förljugnast": "förljugen",
    "förljugnaste": "förljugen",
    "förljugnastes": "förljugen",
    "förljugnasts": "förljugen",
    "förljugne": "förljugen",
    "förljugnes": "förljugen",
    "förljuv": "förljuva",
    "förljuvad": "förljuva",
    "förljuvade": "förljuva",
    "förljuvades": "förljuva",
    "förljuvads": "förljuva",
    "förljuvande": "förljuva",
    "förljuvanden": "förljuvande",
    "förljuvandena": "förljuvande",
    "förljuvandenas": "förljuvande",
    "förljuvandens": "förljuvande",
    "förljuvandes": "förljuvande",
    "förljuvandet": "förljuvande",
    "förljuvandets": "förljuvande",
    "förljuvar": "förljuva",
    "förljuvas": "förljuva",
    "förljuvat": "förljuva",
    "förljuvats": "förljuva",
    "förljöds": "förljudas",
    "förloppen": "förlopp",
    "förloppens": "förlopp",
    "förloppet": "förlopp",
    "förloppets": "förlopp",
    "förlopps": "förlopp",
    "förlor": "förlora",
    "förlorad": "förlora",
    "förlorade": "förlorad",
    "förlorades": "förlorad",
    "förlorads": "förlorad",
    "förlorande": "förlora",
    "förloranden": "förlorande",
    "förlorandena": "förlorande",
    "förlorandenas": "förlorande",
    "förlorandens": "förlorande",
    "förlorandes": "förlorande",
    "förlorandet": "förlorande",
    "förlorandets": "förlorande",
    "förlorar": "förlorare",
    "förloraren": "förlorare",
    "förlorarens": "förlorare",
    "förlorares": "förlorare",
    "förlorarna": "förlorare",
    "förlorarnas": "förlorare",
    "förloras": "förlora",
    "förlorat": "förlorad",
    "förlorats": "förlorad",
    "förloss": "förlossa",
    "förlossad": "förlossa",
    "förlossade": "förlossa",
    "förlossades": "förlossa",
    "förlossads": "förlossa",
    "förlossande": "förlossa",
    "förlossanden": "förlossande",
    "förlossandena": "förlossande",
    "förlossandenas": "förlossande",
    "förlossandens": "förlossande",
    "förlossandes": "förlossande",
    "förlossandet": "förlossande",
    "förlossandets": "förlossande",
    "förlossar": "förlossa",
    "förlossas": "förlossa",
    "förlossat": "förlossa",
    "förlossats": "förlossa",
    "förlossningar": "förlossning",
    "förlossningarna": "förlossning",
    "förlossningarnas": "förlossning",
    "förlossningars": "förlossning",
    "förlossningen": "förlossning",
    "förlossningens": "förlossning",
    "förlossnings": "förlossning",
    "förlossningsanstalten": "förlossningsanstalt",
    "förlossningsanstaltens": "förlossningsanstalt",
    "förlossningsanstalter": "förlossningsanstalt",
    "förlossningsanstalterna": "förlossningsanstalt",
    "förlossningsanstalternas": "förlossningsanstalt",
    "förlossningsanstalters": "förlossningsanstalt",
    "förlossningsanstalts": "förlossningsanstalt",
    "förlossningsarbeten": "förlossningsarbete",
    "förlossningsarbetena": "förlossningsarbete",
    "förlossningsarbetenas": "förlossningsarbete",
    "förlossningsarbetens": "förlossningsarbete",
    "förlossningsarbetes": "förlossningsarbete",
    "förlossningsarbetet": "förlossningsarbete",
    "förlossningsarbetets": "förlossningsarbete",
    "förlossningsarbets": "förlossningsarbete",
    "förlossningskliniken": "förlossningsklinik",
    "förlossningsklinikens": "förlossningsklinik",
    "förlossningskliniker": "förlossningsklinik",
    "förlossningsklinikerna": "förlossningsklinik",
    "förlossningsklinikernas": "förlossningsklinik",
    "förlossningsklinikers": "förlossningsklinik",
    "förlossningskliniks": "förlossningsklinik",
    "förlossningstänger": "förlossningstång",
    "förlossningstängerna": "förlossningstång",
    "förlossningstängernas": "förlossningstång",
    "förlossningstängers": "förlossningstång",
    "förlossningstången": "förlossningstång",
    "förlossningstångens": "förlossningstång",
    "förlossningstångs": "förlossningstång",
    "förlovade": "förlovad",
    "förlovades": "förlovad",
    "förlovads": "förlovad",
    "förlovat": "förlovad",
    "förlovats": "förlovad",
    "förlovningar": "förlovning",
    "förlovningarna": "förlovning",
    "förlovningarnas": "förlovning",
    "förlovningars": "förlovning",
    "förlovningen": "förlovning",
    "förlovningens": "förlovning",
    "förlovnings": "förlovning",
    "förlovningsringar": "förlovningsring",
    "förlovningsringarna": "förlovningsring",
    "förlovningsringarnas": "förlovningsring",
    "förlovningsringars": "förlovningsring",
    "förlovningsringen": "förlovningsring",
    "förlovningsringens": "förlovningsring",
    "förlovningsrings": "förlovningsring",
    "förlupe": "förlöpa",
    "förlupen": "förlöpa",
    "förlupens": "förlupen",
    "förlupet": "förlupen",
    "förlupets": "förlupen",
    "förlupit": "förlöpa",
    "förlupna": "förlupen",
    "förlupnare": "förlupen",
    "förlupnares": "förlupen",
    "förlupnas": "förlupen",
    "förlupnast": "förlupen",
    "förlupnaste": "förlupen",
    "förlupnastes": "förlupen",
    "förlupnasts": "förlupen",
    "förlupne": "förlupen",
    "förlupnes": "förlupen",
    "förlust": "förlusta",
    "förlustad": "förlusta",
    "förlustade": "förlusta",
    "förlustades": "förlusta",
    "förlustads": "förlusta",
    "förlustande": "förlusta",
    "förlustanden": "förlustande",
    "förlustandena": "förlustande",
    "förlustandenas": "förlustande",
    "förlustandens": "förlustande",
    "förlustandes": "förlustande",
    "förlustandet": "förlustande",
    "förlustandets": "förlustande",
    "förlustar": "förlusta",
    "förlustas": "förlusta",
    "förlustat": "förlusta",
    "förlustats": "förlusta",
    "förlustelsen": "förlustelse",
    "förlustelsens": "förlustelse",
    "förlustelser": "förlustelse",
    "förlustelserna": "förlustelse",
    "förlustelsernas": "förlustelse",
    "förlustelsers": "förlustelse",
    "förlustelses": "förlustelse",
    "förlusten": "förlust",
    "förlustens": "förlust",
    "förluster": "förlust",
    "förlusterna": "förlust",
    "förlusternas": "förlust",
    "förlusters": "förlust",
    "förlustiga": "förlustig",
    "förlustigare": "förlustig",
    "förlustigares": "förlustig",
    "förlustigas": "förlustig",
    "förlustigast": "förlustig",
    "förlustigaste": "förlustig",
    "förlustigastes": "förlustig",
    "förlustigasts": "förlustig",
    "förlustige": "förlustig",
    "förlustiges": "förlustig",
    "förlustigheten": "förlustighet",
    "förlustighetens": "förlustighet",
    "förlustighets": "förlustighet",
    "förlustigs": "förlustig",
    "förlustigt": "förlustig",
    "förlustigts": "förlustig",
    "förlusts": "förlust",
    "förlägenheten": "förlägenhet",
    "förlägenhetens": "förlägenhet",
    "förlägenheter": "förlägenhet",
    "förlägenheterna": "förlägenhet",
    "förlägenheternas": "förlägenhet",
    "förlägenheters": "förlägenhet",
    "förlägenhets": "förlägenhet",
    "förlägens": "förlägen",
    "förläget": "förlägen",
    "förlägets": "förlägen",
    "förlägg": "förlägga",
    "förläggande": "förlägga",
    "förlägganden": "förläggande",
    "förläggandena": "förläggande",
    "förläggandenas": "förläggande",
    "förläggandens": "förläggande",
    "förläggandes": "förläggande",
    "förläggandet": "förläggande",
    "förläggandets": "förläggande",
    "förläggar": "förläggare",
    "förläggaren": "förläggare",
    "förläggarens": "förläggare",
    "förläggares": "förläggare",
    "förläggarna": "förläggare",
    "förläggarnas": "förläggare",
    "förläggas": "förlägga",
    "förlägger": "förlägga",
    "förlägges": "förlägga",
    "förläggningar": "förläggning",
    "förläggningarna": "förläggning",
    "förläggningarnas": "förläggning",
    "förläggningars": "förläggning",
    "förläggningen": "förläggning",
    "förläggningens": "förläggning",
    "förläggnings": "förläggning",
    "förläggs": "förlägga",
    "förlägna": "förlägen",
    "förlägnare": "förlägen",
    "förlägnares": "förlägen",
    "förlägnas": "förlägen",
    "förlägnast": "förlägen",
    "förlägnaste": "förlägen",
    "förlägnastes": "förlägen",
    "förlägnasts": "förlägen",
    "förlägne": "förlägen",
    "förlägnes": "förlägen",
    "förlän": "förläna",
    "förlänad": "förläna",
    "förlänade": "förläna",
    "förlänades": "förläna",
    "förlänads": "förläna",
    "förlänande": "förläna",
    "förlänanden": "förlänande",
    "förlänandena": "förlänande",
    "förlänandenas": "förlänande",
    "förlänandens": "förlänande",
    "förlänandes": "förlänande",
    "förlänandet": "förlänande",
    "förlänandets": "förlänande",
    "förlänar": "förläna",
    "förlänas": "förläna",
    "förlänat": "förläna",
    "förlänats": "förläna",
    "förläng": "förlänga",
    "förlängande": "förlänga",
    "förlänganden": "förlängande",
    "förlängandena": "förlängande",
    "förlängandenas": "förlängande",
    "förlängandens": "förlängande",
    "förlängandes": "förlängande",
    "förlängandet": "förlängande",
    "förlängandets": "förlängande",
    "förlängas": "förlänga",
    "förlängd": "förlänga",
    "förlängda": "förlänga",
    "förlängdas": "förlänga",
    "förlängde": "förlänga",
    "förlängdes": "förlänga",
    "förlängds": "förlänga",
    "förlänger": "förlänga",
    "förlänges": "förlänga",
    "förlängningar": "förlängning",
    "förlängningarna": "förlängning",
    "förlängningarnas": "förlängning",
    "förlängningars": "förlängning",
    "förlängningen": "förlängning",
    "förlängningens": "förlängning",
    "förlängnings": "förlängning",
    "förlängningsrören": "förlängningsrör",
    "förlängningsrörens": "förlängningsrör",
    "förlängningsröret": "förlängningsrör",
    "förlängningsrörets": "förlängningsrör",
    "förlängningsrörs": "förlängningsrör",
    "förlängningsskaften": "förlängningsskaft",
    "förlängningsskaftens": "förlängningsskaft",
    "förlängningsskaftet": "förlängningsskaft",
    "förlängningsskaftets": "förlängningsskaft",
    "förlängningsskafts": "förlängningsskaft",
    "förlängningssladdar": "förlängningssladd",
    "förlängningssladdarna": "förlängningssladd",
    "förlängningssladdarnas": "förlängningssladd",
    "förlängningssladdars": "förlängningssladd",
    "förlängningssladden": "förlängningssladd",
    "förlängningssladdens": "förlängningssladd",
    "förlängningssladds": "förlängningssladd",
    "förlängs": "förlänga",
    "förlängt": "förlänga",
    "förlängts": "förlänga",
    "förläningar": "förläning",
    "förläningarna": "förläning",
    "förläningarnas": "förläning",
    "förläningars": "förläning",
    "förläningen": "förläning",
    "förläningens": "förläning",
    "förlänings": "förläning",
    "förlästa": "förläst",
    "förlästare": "förläst",
    "förlästares": "förläst",
    "förlästas": "förläst",
    "förlästast": "förläst",
    "förlästaste": "förläst",
    "förlästastes": "förläst",
    "förlästasts": "förläst",
    "förläste": "förläst",
    "förlästes": "förläst",
    "förlästheten": "förlästhet",
    "förlästhetens": "förlästhet",
    "förlästhets": "förlästhet",
    "förlästs": "förläst",
    "förlät": "förlåta",
    "förläts": "förlåta",
    "förlåt": "förlåta",
    "förlåtande": "förlåta",
    "förlåtanden": "förlåtande",
    "förlåtandena": "förlåtande",
    "förlåtandenas": "förlåtande",
    "förlåtandens": "förlåtande",
    "förlåtandes": "förlåtande",
    "förlåtandet": "förlåtande",
    "förlåtandets": "förlåtande",
    "förlåtas": "förlåta",
    "förlåte": "förlåta",
    "förlåtelsen": "förlåtelse",
    "förlåtelsens": "förlåtelse",
    "förlåtelses": "förlåtelse",
    "förlåten": "förlåta",
    "förlåtens": "förlåta",
    "förlåter": "förlåta",
    "förlåterna": "förlåt",
    "förlåternas": "förlåt",
    "förlåters": "förlåt",
    "förlåtes": "förlåta",
    "förlåtet": "förlåta",
    "förlåtets": "förlåta",
    "förlåtit": "förlåta",
    "förlåtits": "förlåta",
    "förlåtliga": "förlåtlig",
    "förlåtligare": "förlåtlig",
    "förlåtligares": "förlåtlig",
    "förlåtligas": "förlåtlig",
    "förlåtligast": "förlåtlig",
    "förlåtligaste": "förlåtlig",
    "förlåtligastes": "förlåtlig",
    "förlåtligasts": "förlåtlig",
    "förlåtlige": "förlåtlig",
    "förlåtliges": "förlåtlig",
    "förlåtligheten": "förlåtlighet",
    "förlåtlighetens": "förlåtlighet",
    "förlåtlighets": "förlåtlighet",
    "förlåtligs": "förlåtlig",
    "förlåtligt": "förlåtlig",
    "förlåtligts": "förlåtlig",
    "förlåtna": "förlåta",
    "förlåtnas": "förlåta",
    "förlåtne": "förlåta",
    "förlåtnes": "förlåta",
    "förlåts": "förlåta",
    "förlöjlig": "förlöjliga",
    "förlöjligad": "förlöjliga",
    "förlöjligade": "förlöjliga",
    "förlöjligades": "förlöjliga",
    "förlöjligads": "förlöjliga",
    "förlöjligande": "förlöjliga",
    "förlöjliganden": "förlöjligande",
    "förlöjligandena": "förlöjligande",
    "förlöjligandenas": "förlöjligande",
    "förlöjligandens": "förlöjligande",
    "förlöjligandes": "förlöjligande",
    "förlöjligandet": "förlöjligande",
    "förlöjligandets": "förlöjligande",
    "förlöjligar": "förlöjliga",
    "förlöjligas": "förlöjliga",
    "förlöjligat": "förlöjliga",
    "förlöjligats": "förlöjliga",
    "förlöp": "förlöpa",
    "förlöpande": "förlöpa",
    "förlöpanden": "förlöpande",
    "förlöpandena": "förlöpande",
    "förlöpandenas": "förlöpande",
    "förlöpandens": "förlöpande",
    "förlöpandes": "förlöpande",
    "förlöpandet": "förlöpande",
    "förlöpandets": "förlöpande",
    "förlöpar": "förlöpare",
    "förlöparen": "förlöpare",
    "förlöparens": "förlöpare",
    "förlöpares": "förlöpare",
    "förlöparna": "förlöpare",
    "förlöparnas": "förlöpare",
    "förlöpe": "förlöpa",
    "förlöper": "förlöpa",
    "förlöpningar": "förlöpning",
    "förlöpningarna": "förlöpning",
    "förlöpningarnas": "förlöpning",
    "förlöpningars": "förlöpning",
    "förlöpningen": "förlöpning",
    "förlöpningens": "förlöpning",
    "förlöpnings": "förlöpning",
    "förlöpt": "förlöpa",
    "förlöpta": "förlöpa",
    "förlöptas": "förlöpa",
    "förlöpte": "förlöpa",
    "förlöptes": "förlöpa",
    "förlöpts": "förlöpa",
    "förlös": "förlösa",
    "förlösande": "förlösa",
    "förlösanden": "förlösande",
    "förlösandena": "förlösande",
    "förlösandenas": "förlösande",
    "förlösandens": "förlösande",
    "förlösandes": "förlösande",
    "förlösandet": "förlösande",
    "förlösandets": "förlösande",
    "förlösas": "förlösa",
    "förlöser": "förlösa",
    "förlöses": "förlösa",
    "förlöst": "förlösa",
    "förlösta": "förlösa",
    "förlöstas": "förlösa",
    "förlöste": "förlösa",
    "förlöstes": "förlösa",
    "förlösts": "förlösa",
    "förmaken": "förmak",
    "förmakens": "förmak",
    "förmaket": "förmak",
    "förmakets": "förmak",
    "förmaks": "förmak",
    "förmaksflimmers": "förmaksflimmer",
    "förmaksflimret": "förmaksflimmer",
    "förmaksflimrets": "förmaksflimmer",
    "förman": "förmana",
    "förmanad": "förmana",
    "förmanade": "förmana",
    "förmanades": "förmana",
    "förmanads": "förmana",
    "förmanande": "förmana",
    "förmananden": "förmanande",
    "förmanandena": "förmanande",
    "förmanandenas": "förmanande",
    "förmanandens": "förmanande",
    "förmanandes": "förmanande",
    "förmanandet": "förmanande",
    "förmanandets": "förmanande",
    "förmanar": "förmana",
    "förmanas": "förmana",
    "förmanat": "förmana",
    "förmanats": "förmana",
    "förmaningar": "förmaning",
    "förmaningarna": "förmaning",
    "förmaningarnas": "förmaning",
    "förmaningars": "förmaning",
    "förmaningen": "förmaning",
    "förmaningens": "förmaning",
    "förmanings": "förmaning",
    "förmannen": "förman",
    "förmannens": "förman",
    "förmans": "förman",
    "förmatchen": "förmatch",
    "förmatchens": "förmatch",
    "förmatcher": "förmatch",
    "förmatcherna": "förmatch",
    "förmatchernas": "förmatch",
    "förmatchers": "förmatch",
    "förmatchs": "förmatch",
    "förmedlad": "förmedla",
    "förmedlade": "förmedla",
    "förmedlades": "förmedla",
    "förmedlads": "förmedla",
    "förmedlande": "förmedla",
    "förmedlanden": "förmedlande",
    "förmedlandena": "förmedlande",
    "förmedlandenas": "förmedlande",
    "förmedlandens": "förmedlande",
    "förmedlandes": "förmedlande",
    "förmedlandet": "förmedlande",
    "förmedlandets": "förmedlande",
    "förmedlans": "förmedlan",
    "förmedlar": "förmedlare",
    "förmedlaren": "förmedlare",
    "förmedlarens": "förmedlare",
    "förmedlares": "förmedlare",
    "förmedlarna": "förmedlare",
    "förmedlarnas": "förmedlare",
    "förmedlas": "förmedla",
    "förmedlat": "förmedla",
    "förmedlats": "förmedla",
    "förmedlingar": "förmedling",
    "förmedlingarna": "förmedling",
    "förmedlingarnas": "förmedling",
    "förmedlingars": "förmedling",
    "förmedlingen": "förmedling",
    "förmedlingens": "förmedling",
    "förmedlings": "förmedling",
    "förmedvetenheten": "förmedvetenhet",
    "förmedvetenhetens": "förmedvetenhet",
    "förmedvetenhets": "förmedvetenhet",
    "förmedvetens": "förmedveten",
    "förmedvetet": "förmedveten",
    "förmedvetets": "förmedveten",
    "förmedvetna": "förmedveten",
    "förmedvetnare": "förmedveten",
    "förmedvetnares": "förmedveten",
    "förmedvetnas": "förmedveten",
    "förmedvetnast": "förmedveten",
    "förmedvetnaste": "förmedveten",
    "förmedvetnastes": "förmedveten",
    "förmedvetnasts": "förmedveten",
    "förmedvetne": "förmedveten",
    "förmedvetnes": "förmedveten",
    "förmen": "förmena",
    "förmenad": "förmena",
    "förmenade": "förmena",
    "förmenades": "förmena",
    "förmenads": "förmena",
    "förmenande": "förmena",
    "förmenanden": "förmenande",
    "förmenandena": "förmenande",
    "förmenandenas": "förmenande",
    "förmenandens": "förmenande",
    "förmenandes": "förmenande",
    "förmenandet": "förmenande",
    "förmenandets": "förmenande",
    "förmenar": "förmena",
    "förmenas": "förmena",
    "förmenat": "förmena",
    "förmenats": "förmena",
    "förmend": "förmena",
    "förmenda": "förmena",
    "förmendas": "förmena",
    "förmende": "förmena",
    "förmendes": "förmena",
    "förmends": "förmena",
    "förment": "förmena",
    "förmenta": "förment",
    "förmentare": "förment",
    "förmentares": "förment",
    "förmentas": "förment",
    "förmentast": "förment",
    "förmentaste": "förment",
    "förmentastes": "förment",
    "förmentasts": "förment",
    "förmente": "förment",
    "förmentes": "förment",
    "förments": "förment",
    "förmiddagar": "förmiddag",
    "förmiddagarna": "förmiddag",
    "förmiddagarnas": "förmiddag",
    "förmiddagars": "förmiddag",
    "förmiddagen": "förmiddag",
    "förmiddagens": "förmiddag",
    "förmiddags": "förmiddag",
    "förmiddan": "förmiddag",
    "förmiddans": "förmiddag",
    "förmildrad": "förmildra",
    "förmildrade": "förmildra",
    "förmildrades": "förmildra",
    "förmildrads": "förmildra",
    "förmildrande": "förmildra",
    "förmildranden": "förmildrande",
    "förmildrandena": "förmildrande",
    "förmildrandenas": "förmildrande",
    "förmildrandens": "förmildrande",
    "förmildrandes": "förmildrande",
    "förmildrandet": "förmildrande",
    "förmildrandets": "förmildrande",
    "förmildrar": "förmildra",
    "förmildras": "förmildra",
    "förmildrat": "förmildra",
    "förmildrats": "förmildra",
    "förminskad": "förminska",
    "förminskade": "förminska",
    "förminskades": "förminska",
    "förminskads": "förminska",
    "förminskande": "förminska",
    "förminskanden": "förminskande",
    "förminskandena": "förminskande",
    "förminskandenas": "förminskande",
    "förminskandens": "förminskande",
    "förminskandes": "förminskande",
    "förminskandet": "förminskande",
    "förminskandets": "förminskande",
    "förminskar": "förminska",
    "förminskas": "förminska",
    "förminskat": "förminska",
    "förminskats": "förminska",
    "förminskningar": "förminskning",
    "förminskningarna": "förminskning",
    "förminskningarnas": "förminskning",
    "förminskningars": "förminskning",
    "förminskningen": "förminskning",
    "förminskningens": "förminskning",
    "förminsknings": "förminskning",
    "förmod": "förmoda",
    "förmodad": "förmoda",
    "förmodade": "förmoda",
    "förmodades": "förmoda",
    "förmodads": "förmoda",
    "förmodande": "förmoda",
    "förmodanden": "förmodande",
    "förmodandena": "förmodande",
    "förmodandenas": "förmodande",
    "förmodandens": "förmodande",
    "förmodandes": "förmodande",
    "förmodandet": "förmodande",
    "förmodandets": "förmodande",
    "förmodans": "förmodan",
    "förmodar": "förmoda",
    "förmodas": "förmoda",
    "förmodat": "förmoda",
    "förmodats": "förmoda",
    "förmoderna": "förmodern",
    "förmodernare": "förmodern",
    "förmodernares": "förmodern",
    "förmodernas": "förmodern",
    "förmodernast": "förmodern",
    "förmodernaste": "förmodern",
    "förmodernastes": "förmodern",
    "förmodernasts": "förmodern",
    "förmoderne": "förmodern",
    "förmodernes": "förmodern",
    "förmoderns": "förmodern",
    "förmodernt": "förmodern",
    "förmodernts": "förmodern",
    "förmultn": "förmultna",
    "förmultnad": "förmultna",
    "förmultnade": "förmultna",
    "förmultnades": "förmultna",
    "förmultnads": "förmultna",
    "förmultnande": "förmultna",
    "förmultnanden": "förmultnande",
    "förmultnandena": "förmultnande",
    "förmultnandenas": "förmultnande",
    "förmultnandens": "förmultnande",
    "förmultnandes": "förmultnande",
    "förmultnandet": "förmultnande",
    "förmultnandets": "förmultnande",
    "förmultnar": "förmultna",
    "förmultnas": "förmultna",
    "förmultnat": "förmultna",
    "förmultnats": "förmultna",
    "förmultningar": "förmultning",
    "förmultningarna": "förmultning",
    "förmultningarnas": "förmultning",
    "förmultningars": "förmultning",
    "förmultningen": "förmultning",
    "förmultningens": "förmultning",
    "förmultnings": "förmultning",
    "förmyndar": "förmyndare",
    "förmyndaraktiga": "förmyndaraktig",
    "förmyndaraktigare": "förmyndaraktig",
    "förmyndaraktigares": "förmyndaraktig",
    "förmyndaraktigas": "förmyndaraktig",
    "förmyndaraktigast": "förmyndaraktig",
    "förmyndaraktigaste": "förmyndaraktig",
    "förmyndaraktigastes": "förmyndaraktig",
    "förmyndaraktigasts": "förmyndaraktig",
    "förmyndaraktige": "förmyndaraktig",
    "förmyndaraktiges": "förmyndaraktig",
    "förmyndaraktigheten": "förmyndaraktighet",
    "förmyndaraktighetens": "förmyndaraktighet",
    "förmyndaraktighets": "förmyndaraktighet",
    "förmyndaraktigs": "förmyndaraktig",
    "förmyndaraktigt": "förmyndaraktig",
    "förmyndaraktigts": "förmyndaraktig",
    "förmyndaren": "förmyndare",
    "förmyndarens": "förmyndare",
    "förmyndares": "förmyndare",
    "förmyndarna": "förmyndare",
    "förmyndarnas": "förmyndare",
    "förmyndarskapen": "förmyndarskap",
    "förmyndarskapens": "förmyndarskap",
    "förmyndarskapet": "förmyndarskap",
    "förmyndarskapets": "förmyndarskap",
    "förmyndarskaps": "förmyndarskap",
    "förmynderiet": "förmynderi",
    "förmynderiets": "förmynderi",
    "förmynderis": "förmynderi",
    "förmynderit": "förmynderi",
    "förmynderits": "förmynderi",
    "förmynderskapet": "förmynderskap",
    "förmynderskapets": "förmynderskap",
    "förmynderskaps": "förmynderskap",
    "förmäl": "förmäla",
    "förmälande": "förmäla",
    "förmälanden": "förmälande",
    "förmälandena": "förmälande",
    "förmälandenas": "förmälande",
    "förmälandens": "förmälande",
    "förmälandes": "förmälande",
    "förmälandet": "förmälande",
    "förmälandets": "förmälande",
    "förmälas": "förmäla",
    "förmäld": "förmäla",
    "förmälda": "förmäld",
    "förmäldare": "förmäld",
    "förmäldares": "förmäld",
    "förmäldas": "förmäld",
    "förmäldast": "förmäld",
    "förmäldaste": "förmäld",
    "förmäldastes": "förmäld",
    "förmäldasts": "förmäld",
    "förmälde": "förmäld",
    "förmäldes": "förmäld",
    "förmälds": "förmäld",
    "förmäler": "förmäla",
    "förmäles": "förmäla",
    "förmäls": "förmäla",
    "förmält": "förmäld",
    "förmälte": "förmäla",
    "förmältes": "förmäla",
    "förmälts": "förmäld",
    "förmän": "förman",
    "förmännen": "förman",
    "förmännens": "förman",
    "förmäns": "förman",
    "förmänsklig": "förmänskliga",
    "förmänskligad": "förmänskliga",
    "förmänskligade": "förmänskliga",
    "förmänskligades": "förmänskliga",
    "förmänskligads": "förmänskliga",
    "förmänskligande": "förmänskliga",
    "förmänskliganden": "förmänskligande",
    "förmänskligandena": "förmänskligande",
    "förmänskligandenas": "förmänskligande",
    "förmänskligandens": "förmänskligande",
    "förmänskligandes": "förmänskligande",
    "förmänskligandet": "förmänskligande",
    "förmänskligandets": "förmänskligande",
    "förmänskligar": "förmänskliga",
    "förmänskligas": "förmänskliga",
    "förmänskligat": "förmänskliga",
    "förmänskligats": "förmänskliga",
    "förmärk": "förmärka",
    "förmärkande": "förmärka",
    "förmärkanden": "förmärkande",
    "förmärkandena": "förmärkande",
    "förmärkandenas": "förmärkande",
    "förmärkandens": "förmärkande",
    "förmärkandes": "förmärkande",
    "förmärkandet": "förmärkande",
    "förmärkandets": "förmärkande",
    "förmärkas": "förmärka",
    "förmärker": "förmärka",
    "förmärkes": "förmärka",
    "förmärks": "förmärka",
    "förmärkt": "förmärka",
    "förmärkta": "förmärka",
    "förmärktas": "förmärka",
    "förmärkte": "förmärka",
    "förmärktes": "förmärka",
    "förmärkts": "förmärka",
    "förmätenheten": "förmätenhet",
    "förmätenhetens": "förmätenhet",
    "förmätenhets": "förmätenhet",
    "förmätens": "förmäten",
    "förmätet": "förmäten",
    "förmätets": "förmäten",
    "förmätna": "förmäten",
    "förmätnare": "förmäten",
    "förmätnares": "förmäten",
    "förmätnas": "förmäten",
    "förmätnast": "förmäten",
    "förmätnaste": "förmäten",
    "förmätnastes": "förmäten",
    "förmätnasts": "förmäten",
    "förmätne": "förmäten",
    "förmätnes": "förmäten",
    "förmådd": "förmå",
    "förmådda": "förmå",
    "förmåddas": "förmå",
    "förmådde": "förmå",
    "förmåddes": "förmå",
    "förmådds": "förmå",
    "förmående": "förmå",
    "förmåenden": "förmående",
    "förmåendena": "förmående",
    "förmåendenas": "förmående",
    "förmåendens": "förmående",
    "förmåendes": "förmående",
    "förmåendet": "förmående",
    "förmåendets": "förmående",
    "förmågan": "förmåga",
    "förmågans": "förmåga",
    "förmågas": "förmåga",
    "förmåge": "förmåga",
    "förmågor": "förmåga",
    "förmågorna": "förmåga",
    "förmågornas": "förmåga",
    "förmågors": "förmåga",
    "förmånen": "förmån",
    "förmånens": "förmån",
    "förmåner": "förmån",
    "förmånerna": "förmån",
    "förmånernas": "förmån",
    "förmåners": "förmån",
    "förmånliga": "förmånlig",
    "förmånligare": "förmånlig",
    "förmånligares": "förmånlig",
    "förmånligas": "förmånlig",
    "förmånligast": "förmånlig",
    "förmånligaste": "förmånlig",
    "förmånligastes": "förmånlig",
    "förmånligasts": "förmånlig",
    "förmånlige": "förmånlig",
    "förmånliges": "förmånlig",
    "förmånligheten": "förmånlighet",
    "förmånlighetens": "förmånlighet",
    "förmånlighets": "förmånlighet",
    "förmånligs": "förmånlig",
    "förmånligt": "förmånlig",
    "förmånligts": "förmånlig",
    "förmåns": "förmån",
    "förmånserbjudanden": "förmånserbjudande",
    "förmånserbjudandena": "förmånserbjudande",
    "förmånserbjudandenas": "förmånserbjudande",
    "förmånserbjudandens": "förmånserbjudande",
    "förmånserbjudandes": "förmånserbjudande",
    "förmånserbjudandet": "förmånserbjudande",
    "förmånserbjudandets": "förmånserbjudande",
    "förmånsrätten": "förmånsrätt",
    "förmånsrättens": "förmånsrätt",
    "förmånsrätts": "förmånsrätt",
    "förmånstagar": "förmånstagare",
    "förmånstagaren": "förmånstagare",
    "förmånstagarens": "förmånstagare",
    "förmånstagares": "förmånstagare",
    "förmånstagarna": "förmånstagare",
    "förmånstagarnas": "förmånstagare",
    "förmår": "förmå",
    "förmås": "förmå",
    "förmått": "förmå",
    "förmåtts": "förmå",
    "förmögenheten": "förmögenhet",
    "förmögenhetens": "förmögenhet",
    "förmögenheter": "förmögenhet",
    "förmögenheterna": "förmögenhet",
    "förmögenheternas": "förmögenhet",
    "förmögenheters": "förmögenhet",
    "förmögenhets": "förmögenhet",
    "förmögenhetsbrotten": "förmögenhetsbrott",
    "förmögenhetsbrottens": "förmögenhetsbrott",
    "förmögenhetsbrottet": "förmögenhetsbrott",
    "förmögenhetsbrottets": "förmögenhetsbrott",
    "förmögenhetsbrotts": "förmögenhetsbrott",
    "förmögenhetsrätten": "förmögenhetsrätt",
    "förmögenhetsrättens": "förmögenhetsrätt",
    "förmögenhetsrätter": "förmögenhetsrätt",
    "förmögenhetsrätterna": "förmögenhetsrätt",
    "förmögenhetsrätternas": "förmögenhetsrätt",
    "förmögenhetsrätters": "förmögenhetsrätt",
    "förmögenhetsrätts": "förmögenhetsrätt",
    "förmögenhetsskatten": "förmögenhetsskatt",
    "förmögenhetsskattens": "förmögenhetsskatt",
    "förmögenhetsskatter": "förmögenhetsskatt",
    "förmögenhetsskatterna": "förmögenhetsskatt",
    "förmögenhetsskatternas": "förmögenhetsskatt",
    "förmögenhetsskatters": "förmögenhetsskatt",
    "förmögenhetsskatts": "förmögenhetsskatt",
    "förmögens": "förmögen",
    "förmöget": "förmögen",
    "förmögets": "förmögen",
    "förmögna": "förmögen",
    "förmögnare": "förmögen",
    "förmögnares": "förmögen",
    "förmögnas": "förmögen",
    "förmögnast": "förmögen",
    "förmögnaste": "förmögen",
    "förmögnastes": "förmögen",
    "förmögnasts": "förmögen",
    "förmögne": "förmögen",
    "förmögnes": "förmögen",
    "förmörk": "förmörka",
    "förmörkad": "förmörka",
    "förmörkade": "förmörka",
    "förmörkades": "förmörka",
    "förmörkads": "förmörka",
    "förmörkande": "förmörka",
    "förmörkanden": "förmörkande",
    "förmörkandena": "förmörkande",
    "förmörkandenas": "förmörkande",
    "förmörkandens": "förmörkande",
    "förmörkandes": "förmörkande",
    "förmörkandet": "förmörkande",
    "förmörkandets": "förmörkande",
    "förmörkar": "förmörka",
    "förmörkas": "förmörka",
    "förmörkat": "förmörka",
    "förmörkats": "förmörka",
    "förmörkelsen": "förmörkelse",
    "förmörkelsens": "förmörkelse",
    "förmörkelser": "förmörkelse",
    "förmörkelserna": "förmörkelse",
    "förmörkelsernas": "förmörkelse",
    "förmörkelsers": "förmörkelse",
    "förmörkelses": "förmörkelse",
    "förmörkelsevariabeln": "förmörkelsevariabel",
    "förmörkelsevariabelns": "förmörkelsevariabel",
    "förmörkelsevariabels": "förmörkelsevariabel",
    "förmörkelsevariabler": "förmörkelsevariabel",
    "förmörkelsevariablerna": "förmörkelsevariabel",
    "förmörkelsevariablernas": "förmörkelsevariabel",
    "förmörkelsevariablers": "förmörkelsevariabel",
    "förmörkningar": "förmörkning",
    "förmörkningarna": "förmörkning",
    "förmörkningarnas": "förmörkning",
    "förmörkningars": "förmörkning",
    "förmörkningen": "förmörkning",
    "förmörkningens": "förmörkning",
    "förmörknings": "förmörkning",
    "förnam": "förnimma",
    "förnamnen": "förnamn",
    "förnamnens": "förnamn",
    "förnamnet": "förnamn",
    "förnamnets": "förnamn",
    "förnamns": "förnamn",
    "förnams": "förnimma",
    "förnan": "förna",
    "förnans": "förna",
    "förnas": "förna",
    "förnedrad": "förnedra",
    "förnedrade": "förnedra",
    "förnedrades": "förnedra",
    "förnedrads": "förnedra",
    "förnedrande": "förnedra",
    "förnedranden": "förnedrande",
    "förnedrandena": "förnedrande",
    "förnedrandenas": "förnedrande",
    "förnedrandens": "förnedrande",
    "förnedrandes": "förnedrande",
    "förnedrandet": "förnedrande",
    "förnedrandets": "förnedrande",
    "förnedrar": "förnedra",
    "förnedras": "förnedra",
    "förnedrat": "förnedra",
    "förnedrats": "förnedra",
    "förnedringar": "förnedring",
    "förnedringarna": "förnedring",
    "förnedringarnas": "förnedring",
    "förnedringars": "förnedring",
    "förnedringen": "förnedring",
    "förnedringens": "förnedring",
    "förnedrings": "förnedring",
    "förnek": "förneka",
    "förnekad": "förneka",
    "förnekade": "förneka",
    "förnekades": "förneka",
    "förnekads": "förneka",
    "förnekande": "förneka",
    "förnekanden": "förnekande",
    "förnekandena": "förnekande",
    "förnekandenas": "förnekande",
    "förnekandens": "förnekande",
    "förnekandes": "förnekande",
    "förnekandet": "förnekande",
    "förnekandets": "förnekande",
    "förnekar": "förnekare",
    "förnekaren": "förnekare",
    "förnekarens": "förnekare",
    "förnekares": "förnekare",
    "förnekarna": "förnekare",
    "förnekarnas": "förnekare",
    "förnekas": "förneka",
    "förnekat": "förneka",
    "förnekats": "förneka",
    "förnekelsefasen": "förnekelsefas",
    "förnekelsefasens": "förnekelsefas",
    "förnekelsefaser": "förnekelsefas",
    "förnekelsefaserna": "förnekelsefas",
    "förnekelsefasernas": "förnekelsefas",
    "förnekelsefasers": "förnekelsefas",
    "förnekelsen": "förnekelse",
    "förnekelsens": "förnekelse",
    "förnekelser": "förnekelse",
    "förnekelserna": "förnekelse",
    "förnekelsernas": "förnekelse",
    "förnekelsers": "förnekelse",
    "förnekelses": "förnekelse",
    "förnicklad": "förnickla",
    "förnicklade": "förnickla",
    "förnicklades": "förnickla",
    "förnicklads": "förnickla",
    "förnicklande": "förnickla",
    "förnicklanden": "förnicklande",
    "förnicklandena": "förnicklande",
    "förnicklandenas": "förnicklande",
    "förnicklandens": "förnicklande",
    "förnicklandes": "förnicklande",
    "förnicklandet": "förnicklande",
    "förnicklandets": "förnicklande",
    "förnicklar": "förnickla",
    "förnicklas": "förnickla",
    "förnicklat": "förnickla",
    "förnicklats": "förnickla",
    "förnim": "förnimma",
    "förnimbara": "förnimbar",
    "förnimbarare": "förnimbar",
    "förnimbarares": "förnimbar",
    "förnimbaras": "förnimbar",
    "förnimbarast": "förnimbar",
    "förnimbaraste": "förnimbar",
    "förnimbarastes": "förnimbar",
    "förnimbarasts": "förnimbar",
    "förnimbare": "förnimbar",
    "förnimbares": "förnimbar",
    "förnimbarheten": "förnimbarhet",
    "förnimbarhetens": "förnimbarhet",
    "förnimbarheter": "förnimbarhet",
    "förnimbarheterna": "förnimbarhet",
    "förnimbarheternas": "förnimbarhet",
    "förnimbarheters": "förnimbarhet",
    "förnimbarhets": "förnimbarhet",
    "förnimbars": "förnimbar",
    "förnimbart": "förnimbar",
    "förnimbarts": "förnimbar",
    "förnimmande": "förnimma",
    "förnimmanden": "förnimmande",
    "förnimmandena": "förnimmande",
    "förnimmandenas": "förnimmande",
    "förnimmandens": "förnimmande",
    "förnimmandes": "förnimmande",
    "förnimmandet": "förnimmande",
    "förnimmandets": "förnimmande",
    "förnimmas": "förnimma",
    "förnimme": "förnimma",
    "förnimmelsen": "förnimmelse",
    "förnimmelsens": "förnimmelse",
    "förnimmelser": "förnimmelse",
    "förnimmelserna": "förnimmelse",
    "förnimmelsernas": "förnimmelse",
    "förnimmelsers": "förnimmelse",
    "förnimmelses": "förnimmelse",
    "förnimmer": "förnimma",
    "förnimmes": "förnimma",
    "förnims": "förnimma",
    "förningar": "förning",
    "förningarna": "förning",
    "förningarnas": "förning",
    "förningars": "förning",
    "förningen": "förning",
    "förningens": "förning",
    "förnings": "förning",
    "förnuftet": "förnuft",
    "förnuftets": "förnuft",
    "förnuftiga": "förnuftig",
    "förnuftigare": "förnuftig",
    "förnuftigares": "förnuftig",
    "förnuftigas": "förnuftig",
    "förnuftigast": "förnuftig",
    "förnuftigaste": "förnuftig",
    "förnuftigastes": "förnuftig",
    "förnuftigasts": "förnuftig",
    "förnuftige": "förnuftig",
    "förnuftiges": "förnuftig",
    "förnuftigheten": "förnuftighet",
    "förnuftighetens": "förnuftighet",
    "förnuftighets": "förnuftighet",
    "förnuftigs": "förnuftig",
    "förnuftigt": "förnuftig",
    "förnuftigts": "förnuftig",
    "förnufts": "förnuft",
    "förnuftsmässiga": "förnuftsmässig",
    "förnuftsmässigare": "förnuftsmässig",
    "förnuftsmässigares": "förnuftsmässig",
    "förnuftsmässigas": "förnuftsmässig",
    "förnuftsmässigast": "förnuftsmässig",
    "förnuftsmässigaste": "förnuftsmässig",
    "förnuftsmässigastes": "förnuftsmässig",
    "förnuftsmässigasts": "förnuftsmässig",
    "förnuftsmässige": "förnuftsmässig",
    "förnuftsmässiges": "förnuftsmässig",
    "förnuftsmässigs": "förnuftsmässig",
    "förnuftsmässigt": "förnuftsmässig",
    "förnuftsmässigts": "förnuftsmässig",
    "förnuftsskälen": "förnuftsskäl",
    "förnuftsskälens": "förnuftsskäl",
    "förnuftsskälet": "förnuftsskäl",
    "förnuftsskälets": "förnuftsskäl",
    "förnuftsskäls": "förnuftsskäl",
    "förnuftsstridiga": "förnuftsstridig",
    "förnuftsstridigare": "förnuftsstridig",
    "förnuftsstridigares": "förnuftsstridig",
    "förnuftsstridigas": "förnuftsstridig",
    "förnuftsstridigast": "förnuftsstridig",
    "förnuftsstridigaste": "förnuftsstridig",
    "förnuftsstridigastes": "förnuftsstridig",
    "förnuftsstridigasts": "förnuftsstridig",
    "förnuftsstridige": "förnuftsstridig",
    "förnuftsstridiges": "förnuftsstridig",
    "förnuftsstridigheten": "förnuftsstridighet",
    "förnuftsstridighetens": "förnuftsstridighet",
    "förnuftsstridighets": "förnuftsstridighet",
    "förnuftsstridigs": "förnuftsstridig",
    "förnuftsstridigt": "förnuftsstridig",
    "förnuftsstridigts": "förnuftsstridig",
    "förnuftstron": "förnuftstro",
    "förnuftstrons": "förnuftstro",
    "förnuftstros": "förnuftstro",
    "förnuftsvidriga": "förnuftsvidrig",
    "förnuftsvidrigare": "förnuftsvidrig",
    "förnuftsvidrigares": "förnuftsvidrig",
    "förnuftsvidrigas": "förnuftsvidrig",
    "förnuftsvidrigast": "förnuftsvidrig",
    "förnuftsvidrigaste": "förnuftsvidrig",
    "förnuftsvidrigastes": "förnuftsvidrig",
    "förnuftsvidrigasts": "förnuftsvidrig",
    "förnuftsvidrige": "förnuftsvidrig",
    "förnuftsvidriges": "förnuftsvidrig",
    "förnuftsvidrigheten": "förnuftsvidrighet",
    "förnuftsvidrighetens": "förnuftsvidrighet",
    "förnuftsvidrighets": "förnuftsvidrighet",
    "förnuftsvidrigs": "förnuftsvidrig",
    "förnuftsvidrigt": "förnuftsvidrig",
    "förnuftsvidrigts": "förnuftsvidrig",
    "förnumet": "förnimma",
    "förnumets": "förnimma",
    "förnumme": "förnimma",
    "förnummen": "förnimma",
    "förnummens": "förnimma",
    "förnummes": "förnimma",
    "förnummit": "förnimma",
    "förnummits": "förnimma",
    "förnumna": "förnimma",
    "förnumnas": "förnimma",
    "förnumne": "förnimma",
    "förnumnes": "förnimma",
    "förnumstiga": "förnumstig",
    "förnumstigare": "förnumstig",
    "förnumstigares": "förnumstig",
    "förnumstigas": "förnumstig",
    "förnumstigast": "förnumstig",
    "förnumstigaste": "förnumstig",
    "förnumstigastes": "förnumstig",
    "förnumstigasts": "förnumstig",
    "förnumstige": "förnumstig",
    "förnumstiges": "förnumstig",
    "förnumstigheten": "förnumstighet",
    "förnumstighetens": "förnumstighet",
    "förnumstigheter": "förnumstighet",
    "förnumstigheterna": "förnumstighet",
    "förnumstigheternas": "förnumstighet",
    "förnumstigheters": "förnumstighet",
    "förnumstighets": "förnumstighet",
    "förnumstigs": "förnumstig",
    "förnumstigt": "förnumstig",
    "förnumstigts": "förnumstig",
    "förny": "förnya",
    "förnyad": "förnya",
    "förnyade": "förnya",
    "förnyades": "förnya",
    "förnyads": "förnya",
    "förnyande": "förnya",
    "förnyanden": "förnyande",
    "förnyandena": "förnyande",
    "förnyandenas": "förnyande",
    "förnyandens": "förnyande",
    "förnyandes": "förnyande",
    "förnyandet": "förnyande",
    "förnyandets": "förnyande",
    "förnyar": "förnyare",
    "förnyaren": "förnyare",
    "förnyarens": "förnyare",
    "förnyares": "förnyare",
    "förnyarna": "förnyare",
    "förnyarnas": "förnyare",
    "förnyas": "förnya",
    "förnyat": "förnya",
    "förnyats": "förnya",
    "förnybara": "förnybar",
    "förnybarare": "förnybar",
    "förnybarares": "förnybar",
    "förnybaras": "förnybar",
    "förnybarast": "förnybar",
    "förnybaraste": "förnybar",
    "förnybarastes": "förnybar",
    "förnybarasts": "förnybar",
    "förnybare": "förnybar",
    "förnybares": "förnybar",
    "förnybarheten": "förnybarhet",
    "förnybarhetens": "förnybarhet",
    "förnybarhets": "förnybarhet",
    "förnybars": "förnybar",
    "förnybart": "förnybar",
    "förnybarts": "förnybar",
    "förnyelsebara": "förnyelsebar",
    "förnyelsebarare": "förnyelsebar",
    "förnyelsebarares": "förnyelsebar",
    "förnyelsebaras": "förnyelsebar",
    "förnyelsebarast": "förnyelsebar",
    "förnyelsebaraste": "förnyelsebar",
    "förnyelsebarastes": "förnyelsebar",
    "förnyelsebarasts": "förnyelsebar",
    "förnyelsebare": "förnyelsebar",
    "förnyelsebares": "förnyelsebar",
    "förnyelsebars": "förnyelsebar",
    "förnyelsebart": "förnyelsebar",
    "förnyelsebarts": "förnyelsebar",
    "förnyelsen": "förnyelse",
    "förnyelsens": "förnyelse",
    "förnyelser": "förnyelse",
    "förnyelserna": "förnyelse",
    "förnyelsernas": "förnyelse",
    "förnyelsers": "förnyelse",
    "förnyelses": "förnyelse",
    "förnäma": "förnäm",
    "förnämare": "förnäm",
    "förnämares": "förnäm",
    "förnämas": "förnäm",
    "förnämast": "förnäm",
    "förnämasta": "förnäm",
    "förnämastas": "förnäm",
    "förnämaste": "förnäm",
    "förnämastes": "förnäm",
    "förnämasts": "förnäm",
    "förnäme": "förnäm",
    "förnämes": "förnäm",
    "förnämiteten": "förnämitet",
    "förnämitetens": "förnämitet",
    "förnämiteter": "förnämitet",
    "förnämiteterna": "förnämitet",
    "förnämiteternas": "förnämitet",
    "förnämiteters": "förnämitet",
    "förnämitets": "förnämitet",
    "förnämliga": "förnämlig",
    "förnämligare": "förnämlig",
    "förnämligares": "förnämlig",
    "förnämligas": "förnämlig",
    "förnämligast": "förnämlig",
    "förnämligaste": "förnämlig",
    "förnämligastes": "förnämlig",
    "förnämligasts": "förnämlig",
    "förnämlige": "förnämlig",
    "förnämliges": "förnämlig",
    "förnämligheten": "förnämlighet",
    "förnämlighetens": "förnämlighet",
    "förnämlighets": "förnämlighet",
    "förnämligs": "förnämlig",
    "förnämligt": "förnämlig",
    "förnämligts": "förnämlig",
    "förnäms": "förnäm",
    "förnämst": "förnäm",
    "förnämsta": "förnäm",
    "förnämstas": "förnäm",
    "förnämste": "förnäm",
    "förnämstes": "förnäm",
    "förnämsts": "förnäm",
    "förnämt": "förnäm",
    "förnämts": "förnäm",
    "förnärm": "förnärma",
    "förnärmad": "förnärma",
    "förnärmade": "förnärmad",
    "förnärmades": "förnärmad",
    "förnärmads": "förnärmad",
    "förnärmande": "förnärma",
    "förnärmanden": "förnärmande",
    "förnärmandena": "förnärmande",
    "förnärmandenas": "förnärmande",
    "förnärmandens": "förnärmande",
    "förnärmandes": "förnärmande",
    "förnärmandet": "förnärmande",
    "förnärmandets": "förnärmande",
    "förnärmar": "förnärma",
    "förnärmas": "förnärma",
    "förnärmat": "förnärmad",
    "förnärmats": "förnärmad",
    "förnärmelsen": "förnärmelse",
    "förnärmelsens": "förnärmelse",
    "förnärmelser": "förnärmelse",
    "förnärmelserna": "förnärmelse",
    "förnärmelsernas": "förnärmelse",
    "förnärmelsers": "förnärmelse",
    "förnärmelses": "förnärmelse",
    "förnödenheten": "förnödenhet",
    "förnödenhetens": "förnödenhet",
    "förnödenheter": "förnödenhet",
    "förnödenheterna": "förnödenhet",
    "förnödenheternas": "förnödenhet",
    "förnödenheters": "förnödenhet",
    "förnödenhets": "förnödenhet",
    "förnöj": "förnöja",
    "förnöjande": "förnöja",
    "förnöjanden": "förnöjande",
    "förnöjandena": "förnöjande",
    "förnöjandenas": "förnöjande",
    "förnöjandens": "förnöjande",
    "förnöjandes": "förnöjande",
    "förnöjandet": "förnöjande",
    "förnöjandets": "förnöjande",
    "förnöjas": "förnöja",
    "förnöjd": "förnöja",
    "förnöjda": "förnöjd",
    "förnöjdare": "förnöjd",
    "förnöjdares": "förnöjd",
    "förnöjdas": "förnöjd",
    "förnöjdast": "förnöjd",
    "förnöjdaste": "förnöjd",
    "förnöjdastes": "förnöjd",
    "förnöjdasts": "förnöjd",
    "förnöjde": "förnöjd",
    "förnöjdes": "förnöjd",
    "förnöjdheten": "förnöjdhet",
    "förnöjdhetens": "förnöjdhet",
    "förnöjdhets": "förnöjdhet",
    "förnöjds": "förnöjd",
    "förnöjelsen": "förnöjelse",
    "förnöjelsens": "förnöjelse",
    "förnöjelser": "förnöjelse",
    "förnöjelserna": "förnöjelse",
    "förnöjelsernas": "förnöjelse",
    "förnöjelsers": "förnöjelse",
    "förnöjelses": "förnöjelse",
    "förnöjer": "förnöja",
    "förnöjes": "förnöja",
    "förnöjs": "förnöja",
    "förnöjsamheten": "förnöjsamhet",
    "förnöjsamhetens": "förnöjsamhet",
    "förnöjsamhets": "förnöjsamhet",
    "förnöjsamma": "förnöjsam",
    "förnöjsammare": "förnöjsam",
    "förnöjsammares": "förnöjsam",
    "förnöjsammas": "förnöjsam",
    "förnöjsammast": "förnöjsam",
    "förnöjsammaste": "förnöjsam",
    "förnöjsammastes": "förnöjsam",
    "förnöjsammasts": "förnöjsam",
    "förnöjsamme": "förnöjsam",
    "förnöjsammes": "förnöjsam",
    "förnöjsams": "förnöjsam",
    "förnöjsamt": "förnöjsam",
    "förnöjsamts": "förnöjsam",
    "förnöjt": "förnöjd",
    "förnöjts": "förnöjd",
    "förnöt": "förnöta",
    "förnötande": "förnöta",
    "förnötanden": "förnötande",
    "förnötandena": "förnötande",
    "förnötandenas": "förnötande",
    "förnötandens": "förnötande",
    "förnötandes": "förnötande",
    "förnötandet": "förnötande",
    "förnötandets": "förnötande",
    "förnötas": "förnöta",
    "förnöter": "förnöta",
    "förnötes": "förnöta",
    "förnöts": "förnöta",
    "förnött": "förnöta",
    "förnötta": "förnöta",
    "förnöttas": "förnöta",
    "förnötte": "förnöta",
    "förnöttes": "förnöta",
    "förnötts": "förnöta",
    "förolyckade": "förolyckad",
    "förolyckades": "förolyckas",
    "förolyckads": "förolyckad",
    "förolyckat": "förolyckad",
    "förolyckats": "förolyckas",
    "förolämp": "förolämpa",
    "förolämpad": "förolämpa",
    "förolämpade": "förolämpa",
    "förolämpades": "förolämpa",
    "förolämpads": "förolämpa",
    "förolämpande": "förolämpa",
    "förolämpanden": "förolämpande",
    "förolämpandena": "förolämpande",
    "förolämpandenas": "förolämpande",
    "förolämpandens": "förolämpande",
    "förolämpandes": "förolämpande",
    "förolämpandet": "förolämpande",
    "förolämpandets": "förolämpande",
    "förolämpar": "förolämpa",
    "förolämpas": "förolämpa",
    "förolämpat": "förolämpa",
    "förolämpats": "förolämpa",
    "förolämpningar": "förolämpning",
    "förolämpningarna": "förolämpning",
    "förolämpningarnas": "förolämpning",
    "förolämpningars": "förolämpning",
    "förolämpningen": "förolämpning",
    "förolämpningens": "förolämpning",
    "förolämpnings": "förolämpning",
    "förord": "förorda",
    "förordad": "förorda",
    "förordade": "förorda",
    "förordades": "förorda",
    "förordads": "förorda",
    "förordande": "förorda",
    "förordanden": "förordande",
    "förordandena": "förordande",
    "förordandenas": "förordande",
    "förordandens": "förordande",
    "förordandes": "förordande",
    "förordandet": "förordande",
    "förordandets": "förordande",
    "förordar": "förorda",
    "förordas": "förorda",
    "förordat": "förorda",
    "förordats": "förorda",
    "förorden": "förord",
    "förordens": "förord",
    "förordet": "förord",
    "förordets": "förord",
    "förordn": "förordna",
    "förordnad": "förordna",
    "förordnade": "förordna",
    "förordnades": "förordna",
    "förordnads": "förordna",
    "förordnande": "förordna",
    "förordnanden": "förordnande",
    "förordnandena": "förordnande",
    "förordnandenas": "förordnande",
    "förordnandens": "förordnande",
    "förordnandes": "förordnande",
    "förordnandet": "förordnande",
    "förordnandets": "förordnande",
    "förordnar": "förordna",
    "förordnas": "förordna",
    "förordnat": "förordna",
    "förordnats": "förordna",
    "förordningar": "förordning",
    "förordningarna": "förordning",
    "förordningarnas": "förordning",
    "förordningars": "förordning",
    "förordningen": "förordning",
    "förordningens": "förordning",
    "förordnings": "förordning",
    "förords": "förord",
    "föroren": "förorena",
    "förorenad": "förorena",
    "förorenade": "förorena",
    "förorenades": "förorena",
    "förorenads": "förorena",
    "förorenande": "förorena",
    "förorenanden": "förorenande",
    "förorenandena": "förorenande",
    "förorenandenas": "förorenande",
    "förorenandens": "förorenande",
    "förorenandes": "förorenande",
    "förorenandet": "förorenande",
    "förorenandets": "förorenande",
    "förorenar": "förorena",
    "förorenas": "förorena",
    "förorenat": "förorena",
    "förorenats": "förorena",
    "föroreningar": "förorening",
    "föroreningarna": "förorening",
    "föroreningarnas": "förorening",
    "föroreningars": "förorening",
    "föroreningen": "förorening",
    "föroreningens": "förorening",
    "förorenings": "förorening",
    "föroreningsgraden": "föroreningsgrad",
    "föroreningsgradens": "föroreningsgrad",
    "föroreningsgrader": "föroreningsgrad",
    "föroreningsgraderna": "föroreningsgrad",
    "föroreningsgradernas": "föroreningsgrad",
    "föroreningsgraders": "föroreningsgrad",
    "föroreningsgrads": "föroreningsgrad",
    "förorsak": "förorsaka",
    "förorsakad": "förorsaka",
    "förorsakade": "förorsaka",
    "förorsakades": "förorsaka",
    "förorsakads": "förorsaka",
    "förorsakande": "förorsaka",
    "förorsakanden": "förorsakande",
    "förorsakandena": "förorsakande",
    "förorsakandenas": "förorsakande",
    "förorsakandens": "förorsakande",
    "förorsakandes": "förorsakande",
    "förorsakandet": "förorsakande",
    "förorsakandets": "förorsakande",
    "förorsakar": "förorsaka",
    "förorsakas": "förorsaka",
    "förorsakat": "förorsaka",
    "förorsakats": "förorsaka",
    "förorten": "förort",
    "förortens": "förort",
    "förorter": "förort",
    "förorterna": "förort",
    "förorternas": "förort",
    "förorters": "förort",
    "förorts": "förort",
    "förortsträdgårdar": "förortsträdgård",
    "förortsträdgårdarna": "förortsträdgård",
    "förortsträdgårdarnas": "förortsträdgård",
    "förortsträdgårdars": "förortsträdgård",
    "förortsträdgården": "förortsträdgård",
    "förortsträdgårdens": "förortsträdgård",
    "förortsträdgårds": "förortsträdgård",
    "förorätt": "förorätta",
    "förorättad": "förorätta",
    "förorättade": "förorättad",
    "förorättades": "förorättad",
    "förorättads": "förorättad",
    "förorättande": "förorätta",
    "förorättanden": "förorättande",
    "förorättandena": "förorättande",
    "förorättandenas": "förorättande",
    "förorättandens": "förorättande",
    "förorättandes": "förorättande",
    "förorättandet": "förorättande",
    "förorättandets": "förorättande",
    "förorättar": "förorätta",
    "förorättas": "förorätta",
    "förorättat": "förorättad",
    "förorättats": "förorättad",
    "förpack": "förpacka",
    "förpackad": "förpacka",
    "förpackade": "förpacka",
    "förpackades": "förpacka",
    "förpackads": "förpacka",
    "förpackande": "förpacka",
    "förpackanden": "förpackande",
    "förpackandena": "förpackande",
    "förpackandenas": "förpackande",
    "förpackandens": "förpackande",
    "förpackandes": "förpackande",
    "förpackandet": "förpackande",
    "förpackandets": "förpackande",
    "förpackar": "förpacka",
    "förpackas": "förpacka",
    "förpackat": "förpacka",
    "förpackats": "förpacka",
    "förpackningar": "förpackning",
    "förpackningarna": "förpackning",
    "förpackningarnas": "förpackning",
    "förpackningars": "förpackning",
    "förpackningen": "förpackning",
    "förpackningens": "förpackning",
    "förpacknings": "förpackning",
    "förpackningsindustrien": "förpackningsindustri",
    "förpackningsindustriens": "förpackningsindustri",
    "förpackningsindustrier": "förpackningsindustri",
    "förpackningsindustrierna": "förpackningsindustri",
    "förpackningsindustriernas": "förpackningsindustri",
    "förpackningsindustriers": "förpackningsindustri",
    "förpackningsindustrin": "förpackningsindustri",
    "förpackningsindustrins": "förpackningsindustri",
    "förpackningsindustris": "förpackningsindustri",
    "förpakt": "förpakta",
    "förpaktad": "förpakta",
    "förpaktade": "förpakta",
    "förpaktades": "förpakta",
    "förpaktads": "förpakta",
    "förpaktande": "förpakta",
    "förpaktanden": "förpaktande",
    "förpaktandena": "förpaktande",
    "förpaktandenas": "förpaktande",
    "förpaktandens": "förpaktande",
    "förpaktandes": "förpaktande",
    "förpaktandet": "förpaktande",
    "förpaktandets": "förpaktande",
    "förpaktar": "förpaktare",
    "förpaktaren": "förpaktare",
    "förpaktarens": "förpaktare",
    "förpaktares": "förpaktare",
    "förpaktarna": "förpaktare",
    "förpaktarnas": "förpaktare",
    "förpaktas": "förpakta",
    "förpaktat": "förpakta",
    "förpaktats": "förpakta",
    "förpant": "förpanta",
    "förpantad": "förpanta",
    "förpantade": "förpanta",
    "förpantades": "förpanta",
    "förpantads": "förpanta",
    "förpantande": "förpanta",
    "förpantanden": "förpantande",
    "förpantandena": "förpantande",
    "förpantandenas": "förpantande",
    "förpantandens": "förpantande",
    "förpantandes": "förpantande",
    "förpantandet": "förpantande",
    "förpantandets": "förpantande",
    "förpantar": "förpanta",
    "förpantas": "förpanta",
    "förpantat": "förpanta",
    "förpantats": "förpanta",
    "förpass": "förpassa",
    "förpassad": "förpassa",
    "förpassade": "förpassa",
    "förpassades": "förpassa",
    "förpassads": "förpassa",
    "förpassande": "förpassa",
    "förpassanden": "förpassande",
    "förpassandena": "förpassande",
    "förpassandenas": "förpassande",
    "förpassandens": "förpassande",
    "förpassandes": "förpassande",
    "förpassandet": "förpassande",
    "förpassandets": "förpassande",
    "förpassar": "förpassa",
    "förpassas": "förpassa",
    "förpassat": "förpassa",
    "förpassats": "förpassa",
    "förpassningar": "förpassning",
    "förpassningarna": "förpassning",
    "förpassningarnas": "förpassning",
    "förpassningars": "förpassning",
    "förpassningen": "förpassning",
    "förpassningens": "förpassning",
    "förpassnings": "förpassning",
    "förpatrullen": "förpatrull",
    "förpatrullens": "förpatrull",
    "förpatruller": "förpatrull",
    "förpatrullerna": "förpatrull",
    "förpatrullernas": "förpatrull",
    "förpatrullers": "förpatrull",
    "förpatrulls": "förpatrull",
    "förpest": "förpesta",
    "förpestad": "förpesta",
    "förpestade": "förpesta",
    "förpestades": "förpesta",
    "förpestads": "förpesta",
    "förpestande": "förpesta",
    "förpestanden": "förpestande",
    "förpestandena": "förpestande",
    "förpestandenas": "förpestande",
    "förpestandens": "förpestande",
    "förpestandes": "förpestande",
    "förpestandet": "förpestande",
    "förpestandets": "förpestande",
    "förpestar": "förpesta",
    "förpestas": "förpesta",
    "förpestat": "förpesta",
    "förpestats": "förpesta",
    "förpikar": "förpik",
    "förpikarna": "förpik",
    "förpikarnas": "förpik",
    "förpikars": "förpik",
    "förpiken": "förpik",
    "förpikens": "förpik",
    "förpiks": "förpik",
    "förpliktad": "förplikta",
    "förpliktade": "förpliktad",
    "förpliktades": "förpliktad",
    "förpliktads": "förpliktad",
    "förpliktande": "förplikta",
    "förpliktanden": "förpliktande",
    "förpliktandena": "förpliktande",
    "förpliktandenas": "förpliktande",
    "förpliktandens": "förpliktande",
    "förpliktandes": "förpliktande",
    "förpliktandet": "förpliktande",
    "förpliktandets": "förpliktande",
    "förpliktar": "förplikta",
    "förpliktas": "förplikta",
    "förpliktat": "förpliktad",
    "förpliktats": "förpliktad",
    "förpliktelsen": "förpliktelse",
    "förpliktelsens": "förpliktelse",
    "förpliktelser": "förpliktelse",
    "förpliktelserna": "förpliktelse",
    "förpliktelsernas": "förpliktelse",
    "förpliktelsers": "förpliktelse",
    "förpliktelses": "förpliktelse",
    "förpliktigad": "förpliktiga",
    "förpliktigade": "förpliktigad",
    "förpliktigades": "förpliktigad",
    "förpliktigads": "förpliktigad",
    "förpliktigande": "förpliktiga",
    "förpliktiganden": "förpliktigande",
    "förpliktigandena": "förpliktigande",
    "förpliktigandenas": "förpliktigande",
    "förpliktigandens": "förpliktigande",
    "förpliktigandes": "förpliktigande",
    "förpliktigandet": "förpliktigande",
    "förpliktigandets": "förpliktigande",
    "förpliktigar": "förpliktiga",
    "förpliktigas": "förpliktiga",
    "förpliktigat": "förpliktigad",
    "förpliktigats": "förpliktigad",
    "förpläg": "förpläga",
    "förplägad": "förpläga",
    "förplägade": "förpläga",
    "förplägades": "förpläga",
    "förplägads": "förpläga",
    "förplägande": "förpläga",
    "förpläganden": "förplägande",
    "förplägandena": "förplägande",
    "förplägandenas": "förplägande",
    "förplägandens": "förplägande",
    "förplägandes": "förplägande",
    "förplägandet": "förplägande",
    "förplägandets": "förplägande",
    "förplägar": "förpläga",
    "förplägas": "förpläga",
    "förplägat": "förpläga",
    "förplägats": "förpläga",
    "förplägnaden": "förplägnad",
    "förplägnadens": "förplägnad",
    "förplägnader": "förplägnad",
    "förplägnaderna": "förplägnad",
    "förplägnadernas": "förplägnad",
    "förplägnaders": "förplägnad",
    "förplägnads": "förplägnad",
    "förplägningar": "förplägning",
    "förplägningarna": "förplägning",
    "förplägningarnas": "förplägning",
    "förplägningars": "förplägning",
    "förplägningen": "förplägning",
    "förplägningens": "förplägning",
    "förplägnings": "förplägning",
    "förposten": "förpost",
    "förpostens": "förpost",
    "förposter": "förpost",
    "förposterna": "förpost",
    "förposternas": "förpost",
    "förposters": "förpost",
    "förpostfäktningar": "förpostfäktning",
    "förpostfäktningarna": "förpostfäktning",
    "förpostfäktningarnas": "förpostfäktning",
    "förpostfäktningars": "förpostfäktning",
    "förpostfäktningen": "förpostfäktning",
    "förpostfäktningens": "förpostfäktning",
    "förpostfäktnings": "förpostfäktning",
    "förposts": "förpost",
    "förprick": "förpricka",
    "förprickad": "förpricka",
    "förprickade": "förpricka",
    "förprickades": "förpricka",
    "förprickads": "förpricka",
    "förprickande": "förpricka",
    "förprickanden": "förprickande",
    "förprickandena": "förprickande",
    "förprickandenas": "förprickande",
    "förprickandens": "förprickande",
    "förprickandes": "förprickande",
    "förprickandet": "förprickande",
    "förprickandets": "förprickande",
    "förprickar": "förpricka",
    "förprickas": "förpricka",
    "förprickat": "förpricka",
    "förprickats": "förpricka",
    "förpuberteten": "förpubertet",
    "förpubertetens": "förpubertet",
    "förpuberteter": "förpubertet",
    "förpuberteterna": "förpubertet",
    "förpuberteternas": "förpubertet",
    "förpuberteters": "förpubertet",
    "förpubertets": "förpubertet",
    "förpuppades": "förpuppas",
    "förpuppats": "förpuppas",
    "förpuppningar": "förpuppning",
    "förpuppningarna": "förpuppning",
    "förpuppningarnas": "förpuppning",
    "förpuppningars": "förpuppning",
    "förpuppningen": "förpuppning",
    "förpuppningens": "förpuppning",
    "förpuppnings": "förpuppning",
    "förrann": "förrinna",
    "förranns": "förrinna",
    "förras": "förra",
    "förre": "förra",
    "förreglingar": "förregling",
    "förreglingarna": "förregling",
    "förreglingarnas": "förregling",
    "förreglingars": "förregling",
    "förreglingen": "förregling",
    "förreglingens": "förregling",
    "förreglings": "förregling",
    "förres": "förra",
    "förring": "förringa",
    "förringad": "förringa",
    "förringade": "förringa",
    "förringades": "förringa",
    "förringads": "förringa",
    "förringande": "förringa",
    "förringanden": "förringande",
    "förringandena": "förringande",
    "förringandenas": "förringande",
    "förringandens": "förringande",
    "förringandes": "förringande",
    "förringandet": "förringande",
    "förringandets": "förringande",
    "förringar": "förringa",
    "förringas": "förringa",
    "förringat": "förringa",
    "förringats": "förringa",
    "förrinn": "förrinna",
    "förrinnande": "förrinna",
    "förrinnanden": "förrinnande",
    "förrinnandena": "förrinnande",
    "förrinnandenas": "förrinnande",
    "förrinnandens": "förrinnande",
    "förrinnandes": "förrinnande",
    "förrinnandet": "förrinnande",
    "förrinnandets": "förrinnande",
    "förrinnas": "förrinna",
    "förrinne": "förrinna",
    "förrinner": "förrinna",
    "förrinnes": "förrinna",
    "förrinns": "förrinna",
    "förromantiken": "förromantik",
    "förromantikens": "förromantik",
    "förromantiks": "förromantik",
    "förromantiska": "förromantisk",
    "förromantiskare": "förromantisk",
    "förromantiskares": "förromantisk",
    "förromantiskas": "förromantisk",
    "förromantiskast": "förromantisk",
    "förromantiskaste": "förromantisk",
    "förromantiskastes": "förromantisk",
    "förromantiskasts": "förromantisk",
    "förromantiske": "förromantisk",
    "förromantiskes": "förromantisk",
    "förromantisks": "förromantisk",
    "förromantiskt": "förromantisk",
    "förromantiskts": "förromantisk",
    "förromerska": "förromersk",
    "förromerskare": "förromersk",
    "förromerskares": "förromersk",
    "förromerskas": "förromersk",
    "förromerskast": "förromersk",
    "förromerskaste": "förromersk",
    "förromerskastes": "förromersk",
    "förromerskasts": "förromersk",
    "förromerske": "förromersk",
    "förromerskes": "förromersk",
    "förromersks": "förromersk",
    "förromerskt": "förromersk",
    "förromerskts": "förromersk",
    "förrummen": "förrum",
    "förrummens": "förrum",
    "förrummet": "förrum",
    "förrummets": "förrum",
    "förrums": "förrum",
    "förrunna": "förrinna",
    "förrunnas": "förrinna",
    "förrunne": "förrinna",
    "förrunnen": "förrinna",
    "förrunnens": "förrinna",
    "förrunnes": "förrinna",
    "förrunnet": "förrinna",
    "förrunnets": "förrinna",
    "förrunnit": "förrinna",
    "förrunnits": "förrinna",
    "förruttn": "förruttna",
    "förruttnad": "förruttna",
    "förruttnade": "förruttna",
    "förruttnades": "förruttna",
    "förruttnads": "förruttna",
    "förruttnande": "förruttna",
    "förruttnanden": "förruttnande",
    "förruttnandena": "förruttnande",
    "förruttnandenas": "förruttnande",
    "förruttnandens": "förruttnande",
    "förruttnandes": "förruttnande",
    "förruttnandet": "förruttnande",
    "förruttnandets": "förruttnande",
    "förruttnar": "förruttna",
    "förruttnas": "förruttna",
    "förruttnat": "förruttna",
    "förruttnats": "förruttna",
    "förruttnelsegasen": "förruttnelsegas",
    "förruttnelsegasens": "förruttnelsegas",
    "förruttnelsegaser": "förruttnelsegas",
    "förruttnelsegaserna": "förruttnelsegas",
    "förruttnelsegasernas": "förruttnelsegas",
    "förruttnelsegasers": "förruttnelsegas",
    "förruttnelsen": "förruttnelse",
    "förruttnelsens": "förruttnelse",
    "förruttnelses": "förruttnelse",
    "förryck": "förrycka",
    "förryckande": "förrycka",
    "förryckanden": "förryckande",
    "förryckandena": "förryckande",
    "förryckandenas": "förryckande",
    "förryckandens": "förryckande",
    "förryckandes": "förryckande",
    "förryckandet": "förryckande",
    "förryckandets": "förryckande",
    "förryckas": "förrycka",
    "förrycker": "förrycka",
    "förryckes": "förrycka",
    "förrycks": "förrycka",
    "förryckt": "förrycka",
    "förryckta": "förryckt",
    "förrycktare": "förryckt",
    "förrycktares": "förryckt",
    "förrycktas": "förryckt",
    "förrycktast": "förryckt",
    "förrycktaste": "förryckt",
    "förrycktastes": "förryckt",
    "förrycktasts": "förryckt",
    "förryckte": "förryckt",
    "förrycktes": "förryckt",
    "förrycktheten": "förryckthet",
    "förryckthetens": "förryckthet",
    "förryckthets": "förryckthet",
    "förryckts": "förryckt",
    "förrymda": "förrymd",
    "förrymdare": "förrymd",
    "förrymdares": "förrymd",
    "förrymdas": "förrymd",
    "förrymdast": "förrymd",
    "förrymdaste": "förrymd",
    "förrymdastes": "förrymd",
    "förrymdasts": "förrymd",
    "förrymde": "förrymd",
    "förrymdes": "förrymd",
    "förrymds": "förrymd",
    "förrymt": "förrymd",
    "förrymts": "förrymd",
    "förrysk": "förryska",
    "förryskad": "förryska",
    "förryskade": "förryska",
    "förryskades": "förryska",
    "förryskads": "förryska",
    "förryskande": "förryska",
    "förryskanden": "förryskande",
    "förryskandena": "förryskande",
    "förryskandenas": "förryskande",
    "förryskandens": "förryskande",
    "förryskandes": "förryskande",
    "förryskandet": "förryskande",
    "förryskandets": "förryskande",
    "förryskar": "förryska",
    "förryskas": "förryska",
    "förryskat": "förryska",
    "förryskats": "förryska",
    "förrädar": "förrädare",
    "förrädaren": "förrädare",
    "förrädarens": "förrädare",
    "förrädares": "förrädare",
    "förrädarna": "förrädare",
    "förrädarnas": "förrädare",
    "förräderier": "förräderi",
    "förräderierna": "förräderi",
    "förräderiernas": "förräderi",
    "förräderiers": "förräderi",
    "förräderiet": "förräderi",
    "förräderiets": "förräderi",
    "förräderis": "förräderi",
    "förräderit": "förräderi",
    "förräderits": "förräderi",
    "förrädiska": "förrädisk",
    "förrädiskare": "förrädisk",
    "förrädiskares": "förrädisk",
    "förrädiskas": "förrädisk",
    "förrädiskast": "förrädisk",
    "förrädiskaste": "förrädisk",
    "förrädiskastes": "förrädisk",
    "förrädiskasts": "förrädisk",
    "förrädiske": "förrädisk",
    "förrädiskes": "förrädisk",
    "förrädisks": "förrädisk",
    "förrädiskt": "förrädisk",
    "förrädiskts": "förrädisk",
    "förränt": "förränta",
    "förräntad": "förränta",
    "förräntade": "förränta",
    "förräntades": "förränta",
    "förräntads": "förränta",
    "förräntande": "förränta",
    "förräntanden": "förräntande",
    "förräntandena": "förräntande",
    "förräntandenas": "förräntande",
    "förräntandens": "förräntande",
    "förräntandes": "förräntande",
    "förräntandet": "förräntande",
    "förräntandets": "förräntande",
    "förräntar": "förränta",
    "förräntas": "förränta",
    "förräntat": "förränta",
    "förräntats": "förränta",
    "förrätt": "förrätta",
    "förrättad": "förrätta",
    "förrättade": "förrätta",
    "förrättades": "förrätta",
    "förrättads": "förrätta",
    "förrättande": "förrätta",
    "förrättanden": "förrättande",
    "förrättandena": "förrättande",
    "förrättandenas": "förrättande",
    "förrättandens": "förrättande",
    "förrättandes": "förrättande",
    "förrättandet": "förrättande",
    "förrättandets": "förrättande",
    "förrättar": "förrättare",
    "förrättaren": "förrättare",
    "förrättarens": "förrättare",
    "förrättares": "förrättare",
    "förrättarna": "förrättare",
    "förrättarnas": "förrättare",
    "förrättas": "förrätta",
    "förrättat": "förrätta",
    "förrättats": "förrätta",
    "förrätten": "förrätt",
    "förrättens": "förrätt",
    "förrätter": "förrätt",
    "förrätterna": "förrätt",
    "förrätternas": "förrätt",
    "förrätters": "förrätt",
    "förrättningar": "förrättning",
    "förrättningarna": "förrättning",
    "förrättningarnas": "förrättning",
    "förrättningars": "förrättning",
    "förrättningen": "förrättning",
    "förrättningens": "förrättning",
    "förrättnings": "förrättning",
    "förrätts": "förrätt",
    "förrå": "förråa",
    "förråad": "förråa",
    "förråade": "förråa",
    "förråades": "förråa",
    "förråads": "förråa",
    "förråande": "förråa",
    "förråanden": "förråande",
    "förråandena": "förråande",
    "förråandenas": "förråande",
    "förråandens": "förråande",
    "förråandes": "förråande",
    "förråandet": "förråande",
    "förråandets": "förråande",
    "förråar": "förråa",
    "förråas": "förråa",
    "förråat": "förråa",
    "förråats": "förråa",
    "förråd": "förråda",
    "förrådande": "förråda",
    "förrådanden": "förrådande",
    "förrådandena": "förrådande",
    "förrådandenas": "förrådande",
    "förrådandens": "förrådande",
    "förrådandes": "förrådande",
    "förrådandet": "förrådande",
    "förrådandets": "förrådande",
    "förrådas": "förråda",
    "förrådd": "förråda",
    "förrådda": "förråda",
    "förråddas": "förråda",
    "förrådde": "förråda",
    "förråddes": "förråda",
    "förrådds": "förråda",
    "förråden": "förråd",
    "förrådens": "förråd",
    "förråder": "förråda",
    "förrådes": "förråda",
    "förrådet": "förråd",
    "förrådets": "förråd",
    "förråds": "förråda",
    "förrådshusen": "förrådshus",
    "förrådshusens": "förrådshus",
    "förrådshuset": "förrådshus",
    "förrådshusets": "förrådshus",
    "förrått": "förråda",
    "förråtts": "förråda",
    "förs": "före",
    "försagda": "försagd",
    "försagdare": "försagd",
    "försagdares": "försagd",
    "försagdas": "försagd",
    "försagdast": "försagd",
    "försagdaste": "försagd",
    "försagdastes": "försagd",
    "försagdasts": "försagd",
    "försagde": "försagd",
    "försagdes": "försagd",
    "försagdheten": "försagdhet",
    "försagdhetens": "försagdhet",
    "försagdhets": "försagdhet",
    "försagds": "försagd",
    "försagt": "försagd",
    "försagts": "försagd",
    "försak": "försaka",
    "försakad": "försaka",
    "försakade": "försaka",
    "försakades": "försaka",
    "försakads": "försaka",
    "försakande": "försaka",
    "försakanden": "försakande",
    "försakandena": "försakande",
    "försakandenas": "försakande",
    "försakandens": "försakande",
    "försakandes": "försakande",
    "försakandet": "försakande",
    "försakandets": "försakande",
    "försakar": "försaka",
    "försakas": "försaka",
    "försakat": "försaka",
    "försakats": "försaka",
    "försakelsen": "försakelse",
    "försakelsens": "försakelse",
    "försakelser": "försakelse",
    "försakelserna": "försakelse",
    "försakelsernas": "försakelse",
    "försakelsers": "försakelse",
    "försakelses": "försakelse",
    "församlad": "församla",
    "församlade": "församla",
    "församlades": "församlas",
    "församlads": "församla",
    "församlande": "församla",
    "församlanden": "församlande",
    "församlandena": "församlande",
    "församlandenas": "församlande",
    "församlandens": "församlande",
    "församlandes": "församlande",
    "församlandet": "församlande",
    "församlandets": "församlande",
    "församlar": "församla",
    "församlas": "församla",
    "församlat": "församla",
    "församlats": "församlas",
    "församlingar": "församling",
    "församlingarna": "församling",
    "församlingarnas": "församling",
    "församlingars": "församling",
    "församlingen": "församling",
    "församlingens": "församling",
    "församlings": "församling",
    "församlingsassistenten": "församlingsassistent",
    "församlingsassistentens": "församlingsassistent",
    "församlingsassistenter": "församlingsassistent",
    "församlingsassistenterna": "församlingsassistent",
    "församlingsassistenternas": "församlingsassistent",
    "församlingsassistenters": "församlingsassistent",
    "församlingsassistents": "församlingsassistent",
    "församlingsboken": "församlingsbok",
    "församlingsbokens": "församlingsbok",
    "församlingsboks": "församlingsbok",
    "församlingsböcker": "församlingsbok",
    "församlingsböckerna": "församlingsbok",
    "församlingsböckernas": "församlingsbok",
    "församlingsböckers": "församlingsbok",
    "församlingsfriheten": "församlingsfrihet",
    "församlingsfrihetens": "församlingsfrihet",
    "församlingsfriheter": "församlingsfrihet",
    "församlingsfriheterna": "församlingsfrihet",
    "församlingsfriheternas": "församlingsfrihet",
    "församlingsfriheters": "församlingsfrihet",
    "församlingsfrihets": "församlingsfrihet",
    "församlingshemmen": "församlingshem",
    "församlingshemmens": "församlingshem",
    "församlingshemmet": "församlingshem",
    "församlingshemmets": "församlingshem",
    "församlingshems": "församlingshem",
    "församlingsmedlemmar": "församlingsmedlem",
    "församlingsmedlemmarna": "församlingsmedlem",
    "församlingsmedlemmarnas": "församlingsmedlem",
    "församlingsmedlemmars": "församlingsmedlem",
    "församlingsmedlemmen": "församlingsmedlem",
    "församlingsmedlemmens": "församlingsmedlem",
    "församlingsmedlems": "församlingsmedlem",
    "församlingsprästen": "församlingspräst",
    "församlingsprästens": "församlingspräst",
    "församlingspräster": "församlingspräst",
    "församlingsprästerna": "församlingspräst",
    "församlingsprästernas": "församlingspräst",
    "församlingsprästers": "församlingspräst",
    "församlingsprästs": "församlingspräst",
    "försatsen": "försats",
    "försatsens": "försats",
    "försatser": "försats",
    "försatserna": "försats",
    "försatsernas": "försats",
    "försatsers": "försats",
    "försatt": "försitta",
    "försatta": "försätta",
    "försattas": "försätta",
    "försatte": "försätta",
    "försattes": "försätta",
    "försatts": "försitta",
    "försedd": "förse",
    "försedda": "förse",
    "förseddas": "förse",
    "försedde": "förse",
    "förseddes": "förse",
    "försedds": "förse",
    "förseelsen": "förseelse",
    "förseelsens": "förseelse",
    "förseelser": "förseelse",
    "förseelserna": "förseelse",
    "förseelsernas": "förseelse",
    "förseelsers": "förseelse",
    "förseelses": "förseelse",
    "förseende": "förse",
    "förseenden": "förseende",
    "förseendena": "förseende",
    "förseendenas": "förseende",
    "förseendens": "förseende",
    "förseendes": "förseende",
    "förseendet": "förseende",
    "förseendets": "förseende",
    "försegels": "försegel",
    "förseglad": "försegla",
    "förseglade": "försegla",
    "förseglades": "försegla",
    "förseglads": "försegla",
    "förseglande": "försegla",
    "förseglanden": "förseglande",
    "förseglandena": "förseglande",
    "förseglandenas": "förseglande",
    "förseglandens": "förseglande",
    "förseglandes": "förseglande",
    "förseglandet": "förseglande",
    "förseglandets": "förseglande",
    "förseglar": "försegla",
    "förseglas": "försegla",
    "förseglat": "försegla",
    "förseglats": "försegla",
    "förseglen": "försegel",
    "förseglens": "försegel",
    "förseglet": "försegel",
    "förseglets": "försegel",
    "försen": "försena",
    "försenad": "försena",
    "försenade": "försenad",
    "försenades": "försenad",
    "försenads": "försenad",
    "försenande": "försena",
    "försenanden": "försenande",
    "försenandena": "försenande",
    "försenandenas": "försenande",
    "försenandens": "försenande",
    "försenandes": "försenande",
    "försenandet": "försenande",
    "försenandets": "försenande",
    "försenar": "försena",
    "försenas": "försena",
    "försenat": "försenad",
    "försenats": "försenad",
    "förseningar": "försening",
    "förseningarna": "försening",
    "förseningarnas": "försening",
    "förseningars": "försening",
    "förseningen": "försening",
    "förseningens": "försening",
    "försenings": "försening",
    "förseningskampanjen": "förseningskampanj",
    "förseningskampanjens": "förseningskampanj",
    "förseningskampanjer": "förseningskampanj",
    "förseningskampanjerna": "förseningskampanj",
    "förseningskampanjernas": "förseningskampanj",
    "förseningskampanjers": "förseningskampanj",
    "förseningskampanjs": "förseningskampanj",
    "förseningstim": "förseningstimme",
    "förseningstimmar": "förseningstimme",
    "förseningstimmarna": "förseningstimme",
    "förseningstimmarnas": "förseningstimme",
    "förseningstimmars": "förseningstimme",
    "förseningstimmen": "förseningstimme",
    "förseningstimmens": "förseningstimme",
    "förseningstimmes": "förseningstimme",
    "förseningstims": "förseningstimme",
    "förser": "förse",
    "förses": "förse",
    "försett": "förse",
    "försetts": "förse",
    "försiggick": "försiggå",
    "försiggicks": "försiggå",
    "försigginge": "försiggå",
    "försigginges": "försiggå",
    "försiggående": "försiggå",
    "försiggåenden": "försiggående",
    "försiggåendena": "försiggående",
    "försiggåendenas": "försiggående",
    "försiggåendens": "försiggående",
    "försiggåendes": "försiggående",
    "försiggåendet": "försiggående",
    "försiggåendets": "försiggående",
    "försiggånge": "försiggå",
    "försiggången": "försiggå",
    "försiggångens": "försiggå",
    "försiggånges": "försiggå",
    "försiggånget": "försiggå",
    "försiggångets": "försiggå",
    "försiggångna": "försiggå",
    "försiggångnas": "försiggå",
    "försiggångne": "försiggå",
    "försiggångnes": "försiggå",
    "försiggår": "försiggå",
    "försiggås": "försiggå",
    "försiggått": "försiggå",
    "försiggåtts": "försiggå",
    "försigkommenheten": "försigkommenhet",
    "försigkommenhetens": "försigkommenhet",
    "försigkommenhets": "försigkommenhet",
    "försigkommens": "försigkommen",
    "försigkommet": "försigkommen",
    "försigkommets": "försigkommen",
    "försigkomna": "försigkommen",
    "försigkomnare": "försigkommen",
    "försigkomnares": "försigkommen",
    "försigkomnas": "försigkommen",
    "försigkomnast": "försigkommen",
    "försigkomnaste": "försigkommen",
    "försigkomnastes": "försigkommen",
    "försigkomnasts": "försigkommen",
    "försigkomne": "försigkommen",
    "försigkomnes": "försigkommen",
    "försiktiga": "försiktig",
    "försiktigare": "försiktig",
    "försiktigares": "försiktig",
    "försiktigas": "försiktig",
    "försiktigast": "försiktig",
    "försiktigaste": "försiktig",
    "försiktigastes": "försiktig",
    "försiktigasts": "försiktig",
    "försiktige": "försiktig",
    "försiktiges": "försiktig",
    "försiktigheten": "försiktighet",
    "försiktighetens": "försiktighet",
    "försiktigheter": "försiktighet",
    "försiktigheterna": "försiktighet",
    "försiktigheternas": "försiktighet",
    "försiktigheters": "försiktighet",
    "försiktighets": "försiktighet",
    "försiktighetsmåtten": "försiktighetsmått",
    "försiktighetsmåttens": "försiktighetsmått",
    "försiktighetsmåttet": "försiktighetsmått",
    "försiktighetsmåttets": "försiktighetsmått",
    "försiktighetsmåtts": "försiktighetsmått",
    "försiktighetsprincipen": "försiktighetsprincip",
    "försiktighetsprincipens": "försiktighetsprincip",
    "försiktighetsprinciper": "försiktighetsprincip",
    "försiktighetsprinciperna": "försiktighetsprincip",
    "försiktighetsprincipernas": "försiktighetsprincip",
    "försiktighetsprincipers": "försiktighetsprincip",
    "försiktighetsprincips": "försiktighetsprincip",
    "försiktighetsåtgärden": "försiktighetsåtgärd",
    "försiktighetsåtgärdens": "försiktighetsåtgärd",
    "försiktighetsåtgärder": "försiktighetsåtgärd",
    "försiktighetsåtgärderna": "försiktighetsåtgärd",
    "försiktighetsåtgärdernas": "försiktighetsåtgärd",
    "försiktighetsåtgärders": "försiktighetsåtgärd",
    "försiktighetsåtgärds": "försiktighetsåtgärd",
    "försiktigs": "försiktig",
    "försiktigt": "försiktig",
    "försiktigts": "försiktig",
    "försilvrad": "försilvra",
    "försilvrade": "försilvra",
    "försilvrades": "försilvra",
    "försilvrads": "försilvra",
    "försilvrande": "försilvra",
    "försilvranden": "försilvrande",
    "försilvrandena": "försilvrande",
    "försilvrandenas": "försilvrande",
    "försilvrandens": "försilvrande",
    "försilvrandes": "försilvrande",
    "försilvrandet": "försilvrande",
    "försilvrandets": "försilvrande",
    "försilvrar": "försilvra",
    "försilvras": "försilvra",
    "försilvrat": "försilvra",
    "försilvrats": "försilvra",
    "försinkad": "försinka",
    "försinkade": "försinka",
    "försinkades": "försinka",
    "försinkads": "försinka",
    "försinkande": "försinka",
    "försinkanden": "försinkande",
    "försinkandena": "försinkande",
    "försinkandenas": "försinkande",
    "försinkandens": "försinkande",
    "försinkandes": "försinkande",
    "försinkandet": "försinkande",
    "försinkandets": "försinkande",
    "försinkar": "försinka",
    "försinkas": "försinka",
    "försinkat": "försinka",
    "försinkats": "försinka",
    "försitt": "försitta",
    "försittande": "försitta",
    "försittanden": "försittande",
    "försittandena": "försittande",
    "försittandenas": "försittande",
    "försittandens": "försittande",
    "försittandes": "försittande",
    "försittandet": "försittande",
    "försittandets": "försittande",
    "försittas": "försitta",
    "försitte": "försitta",
    "försitter": "försitta",
    "försittes": "försitta",
    "försitts": "försitta",
    "försjunk": "försjunka",
    "försjunkande": "försjunka",
    "försjunkanden": "försjunkande",
    "försjunkandena": "försjunkande",
    "försjunkandenas": "försjunkande",
    "försjunkandens": "försjunkande",
    "försjunkandes": "försjunkande",
    "försjunkandet": "försjunkande",
    "försjunkandets": "försjunkande",
    "försjunkas": "försjunka",
    "försjunke": "försjunka",
    "försjunken": "försjunka",
    "försjunkenheten": "försjunkenhet",
    "försjunkenhetens": "försjunkenhet",
    "försjunkenhets": "försjunkenhet",
    "försjunkens": "försjunken",
    "försjunker": "försjunka",
    "försjunkes": "försjunka",
    "försjunket": "försjunken",
    "försjunkets": "försjunken",
    "försjunkit": "försjunka",
    "försjunkits": "försjunka",
    "försjunkna": "försjunken",
    "försjunknare": "försjunken",
    "försjunknares": "försjunken",
    "försjunknas": "försjunken",
    "försjunknast": "försjunken",
    "försjunknaste": "försjunken",
    "försjunknastes": "försjunken",
    "försjunknasts": "försjunken",
    "försjunkne": "försjunken",
    "försjunknes": "försjunken",
    "försjunks": "försjunka",
    "försjönk": "försjunka",
    "försjönke": "försjunka",
    "försjönkes": "försjunka",
    "försjönks": "försjunka",
    "förskaff": "förskaffa",
    "förskaffad": "förskaffa",
    "förskaffade": "förskaffa",
    "förskaffades": "förskaffa",
    "förskaffads": "förskaffa",
    "förskaffande": "förskaffa",
    "förskaffanden": "förskaffande",
    "förskaffandena": "förskaffande",
    "förskaffandenas": "förskaffande",
    "förskaffandens": "förskaffande",
    "förskaffandes": "förskaffande",
    "förskaffandet": "förskaffande",
    "förskaffandets": "förskaffande",
    "förskaffar": "förskaffa",
    "förskaffas": "förskaffa",
    "förskaffat": "förskaffa",
    "förskaffats": "förskaffa",
    "förskans": "förskansa",
    "förskansad": "förskansa",
    "förskansade": "förskansa",
    "förskansades": "förskansa",
    "förskansads": "förskansa",
    "förskansande": "förskansa",
    "förskansanden": "förskansande",
    "förskansandena": "förskansande",
    "förskansandenas": "förskansande",
    "förskansandens": "förskansande",
    "förskansandes": "förskansande",
    "förskansandet": "förskansande",
    "förskansandets": "förskansande",
    "förskansar": "förskansa",
    "förskansas": "förskansa",
    "förskansat": "förskansa",
    "förskansats": "förskansa",
    "förskansningar": "förskansning",
    "förskansningarna": "förskansning",
    "förskansningarnas": "förskansning",
    "förskansningars": "förskansning",
    "förskansningen": "förskansning",
    "förskansningens": "förskansning",
    "förskansnings": "förskansning",
    "förskar": "förskära",
    "förskars": "förskära",
    "förskeppen": "förskepp",
    "förskeppens": "förskepp",
    "förskeppet": "förskepp",
    "förskeppets": "förskepp",
    "förskepps": "förskepp",
    "förskiffringar": "förskiffring",
    "förskiffringarna": "förskiffring",
    "förskiffringarnas": "förskiffring",
    "förskiffringars": "förskiffring",
    "förskiffringen": "förskiffring",
    "förskiffringens": "förskiffring",
    "förskiffrings": "förskiffring",
    "förskingrad": "förskingra",
    "förskingrade": "förskingra",
    "förskingrades": "förskingra",
    "förskingrads": "förskingra",
    "förskingrande": "förskingra",
    "förskingranden": "förskingrande",
    "förskingrandena": "förskingrande",
    "förskingrandenas": "förskingrande",
    "förskingrandens": "förskingrande",
    "förskingrandes": "förskingrande",
    "förskingrandet": "förskingrande",
    "förskingrandets": "förskingrande",
    "förskingrar": "förskingrare",
    "förskingraren": "förskingrare",
    "förskingrarens": "förskingrare",
    "förskingrares": "förskingrare",
    "förskingrarna": "förskingrare",
    "förskingrarnas": "förskingrare",
    "förskingras": "förskingra",
    "förskingrat": "förskingra",
    "förskingrats": "förskingra",
    "förskingringar": "förskingring",
    "förskingringarna": "förskingring",
    "förskingringarnas": "förskingring",
    "förskingringars": "förskingring",
    "förskingringen": "förskingring",
    "förskingringens": "förskingring",
    "förskingrings": "förskingring",
    "förskinnen": "förskinn",
    "förskinnens": "förskinn",
    "förskinnet": "förskinn",
    "förskinnets": "förskinn",
    "förskinns": "förskinn",
    "förskjut": "förskjuta",
    "förskjutande": "förskjuta",
    "förskjutanden": "förskjutande",
    "förskjutandena": "förskjutande",
    "förskjutandenas": "förskjutande",
    "förskjutandens": "förskjutande",
    "förskjutandes": "förskjutande",
    "förskjutandet": "förskjutande",
    "förskjutandets": "förskjutande",
    "förskjutas": "förskjuta",
    "förskjute": "förskjuta",
    "förskjuten": "förskjuta",
    "förskjutens": "förskjuta",
    "förskjuter": "förskjuta",
    "förskjutes": "förskjuta",
    "förskjutet": "förskjuta",
    "förskjutets": "förskjuta",
    "förskjutit": "förskjuta",
    "förskjutits": "förskjuta",
    "förskjutna": "förskjuta",
    "förskjutnas": "förskjuta",
    "förskjutne": "förskjuta",
    "förskjutnes": "förskjuta",
    "förskjutningar": "förskjutning",
    "förskjutningarna": "förskjutning",
    "förskjutningarnas": "förskjutning",
    "förskjutningars": "förskjutning",
    "förskjutningen": "förskjutning",
    "förskjutningens": "förskjutning",
    "förskjutnings": "förskjutning",
    "förskjuts": "förskjuta",
    "förskolan": "förskola",
    "förskolans": "förskola",
    "förskolas": "förskola",
    "förskole": "förskola",
    "förskolelärar": "förskolelärare",
    "förskoleläraren": "förskolelärare",
    "förskolelärarens": "förskolelärare",
    "förskolelärares": "förskolelärare",
    "förskolelärarna": "förskolelärare",
    "förskolelärarnas": "förskolelärare",
    "förskoleåldern": "förskoleålder",
    "förskoleålderns": "förskoleålder",
    "förskoleålders": "förskoleålder",
    "förskoleåldrar": "förskoleålder",
    "förskoleåldrarna": "förskoleålder",
    "förskoleåldrarnas": "förskoleålder",
    "förskoleåldrars": "förskoleålder",
    "förskollärar": "förskollärare",
    "förskolläraren": "förskollärare",
    "förskollärarens": "förskollärare",
    "förskollärares": "förskollärare",
    "förskollärarna": "förskollärare",
    "förskollärarnas": "förskollärare",
    "förskolor": "förskola",
    "förskolorna": "förskola",
    "förskolornas": "förskola",
    "förskolors": "förskola",
    "förskon": "förskona",
    "förskonad": "förskona",
    "förskonade": "förskona",
    "förskonades": "förskona",
    "förskonads": "förskona",
    "förskonande": "förskona",
    "förskonanden": "förskonande",
    "förskonandena": "förskonande",
    "förskonandenas": "förskonande",
    "förskonandens": "förskonande",
    "förskonandes": "förskonande",
    "förskonandet": "förskonande",
    "förskonandets": "förskonande",
    "förskonar": "förskona",
    "förskonas": "förskona",
    "förskonat": "förskona",
    "förskonats": "förskona",
    "förskoningar": "förskoning",
    "förskoningarna": "förskoning",
    "förskoningarnas": "förskoning",
    "förskoningars": "förskoning",
    "förskoningen": "förskoning",
    "förskoningens": "förskoning",
    "förskonings": "förskoning",
    "förskotten": "förskott",
    "förskottens": "förskott",
    "förskotterad": "förskottera",
    "förskotterade": "förskottera",
    "förskotterades": "förskottera",
    "förskotterads": "förskottera",
    "förskotterande": "förskottera",
    "förskotteranden": "förskotterande",
    "förskotterandena": "förskotterande",
    "förskotterandenas": "förskotterande",
    "förskotterandens": "förskotterande",
    "förskotterandes": "förskotterande",
    "förskotterandet": "förskotterande",
    "förskotterandets": "förskotterande",
    "förskotterar": "förskottera",
    "förskotteras": "förskottera",
    "förskotterat": "förskottera",
    "förskotterats": "förskottera",
    "förskotterbara": "förskotterbar",
    "förskotterbarare": "förskotterbar",
    "förskotterbarares": "förskotterbar",
    "förskotterbaras": "förskotterbar",
    "förskotterbarast": "förskotterbar",
    "förskotterbaraste": "förskotterbar",
    "förskotterbarastes": "förskotterbar",
    "förskotterbarasts": "förskotterbar",
    "förskotterbare": "förskotterbar",
    "förskotterbares": "förskotterbar",
    "förskotterbarheten": "förskotterbarhet",
    "förskotterbarhetens": "förskotterbarhet",
    "förskotterbarhets": "förskotterbarhet",
    "förskotterbars": "förskotterbar",
    "förskotterbart": "förskotterbar",
    "förskotterbarts": "förskotterbar",
    "förskotteringar": "förskottering",
    "förskotteringarna": "förskottering",
    "förskotteringarnas": "förskottering",
    "förskotteringars": "förskottering",
    "förskotteringen": "förskottering",
    "förskotteringens": "förskottering",
    "förskotterings": "förskottering",
    "förskottet": "förskott",
    "förskottets": "förskott",
    "förskotts": "förskott",
    "förskrev": "förskriva",
    "förskrevs": "förskriva",
    "förskriv": "förskriva",
    "förskrivande": "förskriva",
    "förskrivanden": "förskrivande",
    "förskrivandena": "förskrivande",
    "förskrivandenas": "förskrivande",
    "förskrivandens": "förskrivande",
    "förskrivandes": "förskrivande",
    "förskrivandet": "förskrivande",
    "förskrivandets": "förskrivande",
    "förskrivas": "förskriva",
    "förskrive": "förskriva",
    "förskriven": "förskriva",
    "förskrivens": "förskriva",
    "förskriver": "förskriva",
    "förskrives": "förskriva",
    "förskrivet": "förskriva",
    "förskrivets": "förskriva",
    "förskrivit": "förskriva",
    "förskrivits": "förskriva",
    "förskrivna": "förskriva",
    "förskrivnas": "förskriva",
    "förskrivne": "förskriva",
    "förskrivnes": "förskriva",
    "förskrivningar": "förskrivning",
    "förskrivningarna": "förskrivning",
    "förskrivningarnas": "förskrivning",
    "förskrivningars": "förskrivning",
    "förskrivningen": "förskrivning",
    "förskrivningens": "förskrivning",
    "förskrivnings": "förskrivning",
    "förskrivs": "förskriva",
    "förskräck": "förskräcka",
    "förskräckande": "förskräcka",
    "förskräckanden": "förskräckande",
    "förskräckandena": "förskräckande",
    "förskräckandenas": "förskräckande",
    "förskräckandens": "förskräckande",
    "förskräckandes": "förskräckande",
    "förskräckandet": "förskräckande",
    "förskräckandets": "förskräckande",
    "förskräckas": "förskräcka",
    "förskräckelsen": "förskräckelse",
    "förskräckelsens": "förskräckelse",
    "förskräckelser": "förskräckelse",
    "förskräckelserna": "förskräckelse",
    "förskräckelsernas": "förskräckelse",
    "förskräckelsers": "förskräckelse",
    "förskräckelses": "förskräckelse",
    "förskräcker": "förskräcka",
    "förskräckes": "förskräcka",
    "förskräckliga": "förskräcklig",
    "förskräckligare": "förskräcklig",
    "förskräckligares": "förskräcklig",
    "förskräckligas": "förskräcklig",
    "förskräckligast": "förskräcklig",
    "förskräckligaste": "förskräcklig",
    "förskräckligastes": "förskräcklig",
    "förskräckligasts": "förskräcklig",
    "förskräcklige": "förskräcklig",
    "förskräckliges": "förskräcklig",
    "förskräckligheten": "förskräcklighet",
    "förskräcklighetens": "förskräcklighet",
    "förskräckligheter": "förskräcklighet",
    "förskräckligheterna": "förskräcklighet",
    "förskräckligheternas": "förskräcklighet",
    "förskräckligheters": "förskräcklighet",
    "förskräcklighets": "förskräcklighet",
    "förskräckligs": "förskräcklig",
    "förskräckligt": "förskräcklig",
    "förskräckligts": "förskräcklig",
    "förskräcks": "förskräcka",
    "förskräckt": "förskräcka",
    "förskräckta": "förskräckt",
    "förskräcktare": "förskräckt",
    "förskräcktares": "förskräckt",
    "förskräcktas": "förskräckt",
    "förskräcktast": "förskräckt",
    "förskräcktaste": "förskräckt",
    "förskräcktastes": "förskräckt",
    "förskräcktasts": "förskräckt",
    "förskräckte": "förskräckt",
    "förskräcktes": "förskräckt",
    "förskräcktheten": "förskräckthet",
    "förskräckthetens": "förskräckthet",
    "förskräckthets": "förskräckthet",
    "förskräckts": "förskräckt",
    "förskrämda": "förskrämd",
    "förskrämdare": "förskrämd",
    "förskrämdares": "förskrämd",
    "förskrämdas": "förskrämd",
    "förskrämdast": "förskrämd",
    "förskrämdaste": "förskrämd",
    "förskrämdastes": "förskrämd",
    "förskrämdasts": "förskrämd",
    "förskrämde": "förskrämd",
    "förskrämdes": "förskrämd",
    "förskrämdheten": "förskrämdhet",
    "förskrämdhetens": "förskrämdhet",
    "förskrämdhets": "förskrämdhet",
    "förskrämds": "förskrämd",
    "förskrämt": "förskrämd",
    "förskrämts": "förskrämd",
    "förskure": "förskära",
    "förskuren": "förskära",
    "förskurens": "förskära",
    "förskures": "förskära",
    "förskuret": "förskära",
    "förskurets": "förskära",
    "förskurit": "förskära",
    "förskurits": "förskära",
    "förskurna": "förskära",
    "förskurnas": "förskära",
    "förskurne": "förskära",
    "förskurnes": "förskära",
    "förskyll": "förskylla",
    "förskyllande": "förskylla",
    "förskyllanden": "förskyllande",
    "förskyllandena": "förskyllande",
    "förskyllandenas": "förskyllande",
    "förskyllandens": "förskyllande",
    "förskyllandes": "förskyllande",
    "förskyllandet": "förskyllande",
    "förskyllandets": "förskyllande",
    "förskyllans": "förskyllan",
    "förskyllas": "förskylla",
    "förskylld": "förskylla",
    "förskyllda": "förskylla",
    "förskylldas": "förskylla",
    "förskyllde": "förskylla",
    "förskylldes": "förskylla",
    "förskyllds": "förskylla",
    "förskyller": "förskylla",
    "förskylles": "förskylla",
    "förskylls": "förskylla",
    "förskyllt": "förskylla",
    "förskyllts": "förskylla",
    "förskämda": "förskämd",
    "förskämdare": "förskämd",
    "förskämdares": "förskämd",
    "förskämdas": "förskämd",
    "förskämdast": "förskämd",
    "förskämdaste": "förskämd",
    "förskämdastes": "förskämd",
    "förskämdasts": "förskämd",
    "förskämde": "förskämd",
    "förskämdes": "förskämd",
    "förskämdheten": "förskämdhet",
    "förskämdhetens": "förskämdhet",
    "förskämdhets": "förskämdhet",
    "förskämds": "förskämd",
    "förskämningar": "förskämning",
    "förskämningarna": "förskämning",
    "förskämningarnas": "förskämning",
    "förskämningars": "förskämning",
    "förskämningen": "förskämning",
    "förskämningens": "förskämning",
    "förskämnings": "förskämning",
    "förskämt": "förskämd",
    "förskämts": "förskämd",
    "förskär": "förskära",
    "förskärande": "förskära",
    "förskäranden": "förskärande",
    "förskärandena": "förskärande",
    "förskärandenas": "förskärande",
    "förskärandens": "förskärande",
    "förskärandes": "förskärande",
    "förskärandet": "förskärande",
    "förskärandets": "förskärande",
    "förskärar": "förskärare",
    "förskäraren": "förskärare",
    "förskärarens": "förskärare",
    "förskärares": "förskärare",
    "förskärargaffeln": "förskärargaffel",
    "förskärargaffelns": "förskärargaffel",
    "förskärargaffels": "förskärargaffel",
    "förskärargafflar": "förskärargaffel",
    "förskärargafflarna": "förskärargaffel",
    "förskärargafflarnas": "förskärargaffel",
    "förskärargafflars": "förskärargaffel",
    "förskärarknivar": "förskärarkniv",
    "förskärarknivarna": "förskärarkniv",
    "förskärarknivarnas": "förskärarkniv",
    "förskärarknivars": "förskärarkniv",
    "förskärarkniven": "förskärarkniv",
    "förskärarknivens": "förskärarkniv",
    "förskärarknivs": "förskärarkniv",
    "förskärarna": "förskärare",
    "förskärarnas": "förskärare",
    "förskäras": "förskära",
    "förskäre": "förskära",
    "förskäres": "förskära",
    "förskärs": "förskära",
    "förskön": "försköna",
    "förskönad": "försköna",
    "förskönade": "försköna",
    "förskönades": "försköna",
    "förskönads": "försköna",
    "förskönande": "försköna",
    "förskönanden": "förskönande",
    "förskönandena": "förskönande",
    "förskönandenas": "förskönande",
    "förskönandens": "förskönande",
    "förskönandes": "förskönande",
    "förskönandet": "förskönande",
    "förskönandets": "förskönande",
    "förskönar": "försköna",
    "förskönas": "försköna",
    "förskönat": "försköna",
    "förskönats": "försköna",
    "försköt": "förskjuta",
    "försköte": "förskjuta",
    "förskötes": "förskjuta",
    "försköts": "förskjuta",
    "förslagen": "förslag",
    "förslagenheten": "förslagenhet",
    "förslagenhetens": "förslagenhet",
    "förslagenhets": "förslagenhet",
    "förslagens": "förslagen",
    "förslaget": "förslagen",
    "förslagets": "förslagen",
    "förslagit": "förslå",
    "förslagits": "förslå",
    "förslagna": "förslagen",
    "förslagnare": "förslagen",
    "förslagnares": "förslagen",
    "förslagnas": "förslagen",
    "förslagnast": "förslagen",
    "förslagnaste": "förslagen",
    "förslagnastes": "förslagen",
    "förslagnasts": "förslagen",
    "förslagne": "förslagen",
    "förslagnes": "förslagen",
    "förslags": "förslag",
    "förslagsrummen": "förslagsrum",
    "förslagsrummens": "förslagsrum",
    "förslagsrummet": "förslagsrum",
    "förslagsrummets": "förslagsrum",
    "förslagsrums": "förslagsrum",
    "förslapp": "förslappa",
    "förslappad": "förslappa",
    "förslappade": "förslappa",
    "förslappades": "förslappa",
    "förslappads": "förslappa",
    "förslappande": "förslappa",
    "förslappanden": "förslappande",
    "förslappandena": "förslappande",
    "förslappandenas": "förslappande",
    "förslappandens": "förslappande",
    "förslappandes": "förslappande",
    "förslappandet": "förslappande",
    "förslappandets": "förslappande",
    "förslappar": "förslappa",
    "förslappas": "förslappa",
    "förslappat": "förslappa",
    "förslappats": "förslappa",
    "förslappningar": "förslappning",
    "förslappningarna": "förslappning",
    "förslappningarnas": "förslappning",
    "förslappningars": "förslappning",
    "förslappningen": "förslappning",
    "förslappningens": "förslappning",
    "förslappnings": "förslappning",
    "förslav": "förslava",
    "förslavad": "förslava",
    "förslavade": "förslava",
    "förslavades": "förslava",
    "förslavads": "förslava",
    "förslavande": "förslava",
    "förslavanden": "förslavande",
    "förslavandena": "förslavande",
    "förslavandenas": "förslavande",
    "förslavandens": "förslavande",
    "förslavandes": "förslavande",
    "förslavandet": "förslavande",
    "förslavandets": "förslavande",
    "förslavar": "förslava",
    "förslavas": "förslava",
    "förslavat": "förslava",
    "förslavats": "förslava",
    "förslet": "förslita",
    "förslets": "förslita",
    "förslit": "förslita",
    "förslitande": "förslita",
    "förslitanden": "förslitande",
    "förslitandena": "förslitande",
    "förslitandenas": "förslitande",
    "förslitandens": "förslitande",
    "förslitandes": "förslitande",
    "förslitandet": "förslitande",
    "förslitandets": "förslitande",
    "förslitas": "förslita",
    "förslite": "förslita",
    "försliten": "förslita",
    "förslitens": "förslita",
    "försliter": "förslita",
    "förslites": "förslita",
    "förslitet": "förslita",
    "förslitets": "förslita",
    "förslitit": "förslita",
    "förslitits": "förslita",
    "förslitna": "förslita",
    "förslitnas": "förslita",
    "förslitne": "förslita",
    "förslitnes": "förslita",
    "förslitningar": "förslitning",
    "förslitningarna": "förslitning",
    "förslitningarnas": "förslitning",
    "förslitningars": "förslitning",
    "förslitningen": "förslitning",
    "förslitningens": "förslitning",
    "förslitnings": "förslitning",
    "förslits": "förslita",
    "försloe": "förslå",
    "försloes": "förslå",
    "förslog": "förslå",
    "förslogs": "förslå",
    "förslummades": "förslummas",
    "förslummats": "förslummas",
    "förslut": "försluta",
    "förslutande": "försluta",
    "förslutanden": "förslutande",
    "förslutandena": "förslutande",
    "förslutandenas": "förslutande",
    "förslutandens": "förslutande",
    "förslutandes": "förslutande",
    "förslutandet": "förslutande",
    "förslutandets": "förslutande",
    "förslutas": "försluta",
    "förslute": "försluta",
    "försluten": "försluta",
    "förslutens": "försluta",
    "försluter": "försluta",
    "förslutes": "försluta",
    "förslutet": "försluta",
    "förslutets": "försluta",
    "förslutit": "försluta",
    "förslutits": "försluta",
    "förslutna": "försluta",
    "förslutnas": "försluta",
    "förslutne": "försluta",
    "förslutnes": "försluta",
    "förslutningar": "förslutning",
    "förslutningarna": "förslutning",
    "förslutningarnas": "förslutning",
    "förslutningars": "förslutning",
    "förslutningen": "förslutning",
    "förslutningens": "förslutning",
    "förslutnings": "förslutning",
    "försluts": "försluta",
    "förslående": "förslå",
    "förslåenden": "förslående",
    "förslåendena": "förslående",
    "förslåendenas": "förslående",
    "förslåendens": "förslående",
    "förslåendes": "förslående",
    "förslåendet": "förslående",
    "förslåendets": "förslående",
    "förslåge": "förslå",
    "förslåges": "förslå",
    "förslår": "förslå",
    "förslås": "förslå",
    "förslö": "förslöa",
    "förslöad": "förslöa",
    "förslöade": "förslöa",
    "förslöades": "förslöa",
    "förslöads": "förslöa",
    "förslöande": "förslöa",
    "förslöanden": "förslöande",
    "förslöandena": "förslöande",
    "förslöandenas": "förslöande",
    "förslöandens": "förslöande",
    "förslöandes": "förslöande",
    "förslöandet": "förslöande",
    "förslöandets": "förslöande",
    "förslöar": "förslöa",
    "förslöas": "förslöa",
    "förslöat": "förslöa",
    "förslöats": "förslöa",
    "förslös": "förslösa",
    "förslösad": "förslösa",
    "förslösade": "förslösa",
    "förslösades": "förslösa",
    "förslösads": "förslösa",
    "förslösande": "förslösa",
    "förslösanden": "förslösande",
    "förslösandena": "förslösande",
    "förslösandenas": "förslösande",
    "förslösandens": "förslösande",
    "förslösandes": "förslösande",
    "förslösandet": "förslösande",
    "förslösandets": "förslösande",
    "förslösar": "förslösa",
    "förslösas": "förslösa",
    "förslösat": "förslösa",
    "förslösats": "förslösa",
    "förslöt": "försluta",
    "förslöte": "försluta",
    "förslötes": "försluta",
    "förslöts": "försluta",
    "försmaken": "försmak",
    "försmakens": "försmak",
    "försmaks": "försmak",
    "försmädliga": "försmädlig",
    "försmädligare": "försmädlig",
    "försmädligares": "försmädlig",
    "försmädligas": "försmädlig",
    "försmädligast": "försmädlig",
    "försmädligaste": "försmädlig",
    "försmädligastes": "försmädlig",
    "försmädligasts": "försmädlig",
    "försmädlige": "försmädlig",
    "försmädliges": "försmädlig",
    "försmädligheten": "försmädlighet",
    "försmädlighetens": "försmädlighet",
    "försmädlighets": "försmädlighet",
    "försmädligs": "försmädlig",
    "försmädligt": "försmädlig",
    "försmädligts": "försmädlig",
    "försmäktade": "försmäkta",
    "försmäktades": "försmäkta",
    "försmäktande": "försmäkta",
    "försmäktanden": "försmäktande",
    "försmäktandena": "försmäktande",
    "försmäktandenas": "försmäktande",
    "försmäktandens": "försmäktande",
    "försmäktandes": "försmäktande",
    "försmäktandet": "försmäktande",
    "försmäktandets": "försmäktande",
    "försmäktar": "försmäkta",
    "försmäktas": "försmäkta",
    "försmäktat": "försmäkta",
    "försmäktats": "försmäkta",
    "försmådd": "försmå",
    "försmådda": "försmå",
    "försmåddas": "försmå",
    "försmådde": "försmå",
    "försmåddes": "försmå",
    "försmådds": "försmå",
    "försmående": "försmå",
    "försmåenden": "försmående",
    "försmåendena": "försmående",
    "försmåendenas": "försmående",
    "försmåendens": "försmående",
    "försmåendes": "försmående",
    "försmåendet": "försmående",
    "försmåendets": "försmående",
    "försmår": "försmå",
    "försmås": "försmå",
    "försmått": "försmå",
    "försmåtts": "försmå",
    "försnill": "försnilla",
    "försnillad": "försnilla",
    "försnillade": "försnilla",
    "försnillades": "försnilla",
    "försnillads": "försnilla",
    "försnillande": "försnilla",
    "försnillanden": "försnillande",
    "försnillandena": "försnillande",
    "försnillandenas": "försnillande",
    "försnillandens": "försnillande",
    "försnillandes": "försnillande",
    "försnillandet": "försnillande",
    "försnillandets": "försnillande",
    "försnillar": "försnilla",
    "försnillas": "försnilla",
    "försnillat": "försnilla",
    "försnillats": "försnilla",
    "försockringar": "försockring",
    "försockringarna": "försockring",
    "försockringarnas": "försockring",
    "försockringars": "försockring",
    "försockringen": "försockring",
    "försockringens": "försockring",
    "försockrings": "försockring",
    "försoff": "försoffa",
    "försoffad": "försoffa",
    "försoffade": "försoffa",
    "försoffades": "försoffa",
    "försoffads": "försoffa",
    "försoffande": "försoffa",
    "försoffanden": "försoffande",
    "försoffandena": "försoffande",
    "försoffandenas": "försoffande",
    "försoffandens": "försoffande",
    "försoffandes": "försoffande",
    "försoffandet": "försoffande",
    "försoffandets": "försoffande",
    "försoffar": "försoffa",
    "försoffas": "försoffa",
    "försoffat": "försoffa",
    "försoffats": "försoffa",
    "försommaren": "försommar",
    "försommarens": "försommar",
    "försommarkvällar": "försommarkväll",
    "försommarkvällarna": "försommarkväll",
    "försommarkvällarnas": "försommarkväll",
    "försommarkvällars": "försommarkväll",
    "försommarkvällen": "försommarkväll",
    "försommarkvällens": "försommarkväll",
    "försommarkvälls": "försommarkväll",
    "försommarn": "försommar",
    "försommarns": "försommar",
    "försommars": "försommar",
    "försomrar": "försommar",
    "försomrarna": "försommar",
    "försomrarnas": "försommar",
    "försomrars": "försommar",
    "förson": "försona",
    "försonad": "försona",
    "försonade": "försona",
    "försonades": "försonas",
    "försonads": "försona",
    "försonande": "försona",
    "försonanden": "försonande",
    "försonandena": "försonande",
    "försonandenas": "försonande",
    "försonandens": "försonande",
    "försonandes": "försonande",
    "försonandet": "försonande",
    "försonandets": "försonande",
    "försonar": "försona",
    "försonas": "försona",
    "försonat": "försona",
    "försonats": "försonas",
    "försoningar": "försoning",
    "försoningarna": "försoning",
    "försoningarnas": "försoning",
    "försoningars": "försoning",
    "försoningen": "försoning",
    "försoningens": "försoning",
    "försonings": "försoning",
    "försoningsgåvan": "försoningsgåva",
    "försoningsgåvans": "försoningsgåva",
    "försoningsgåvas": "försoningsgåva",
    "försoningsgåve": "försoningsgåva",
    "försoningsgåvo": "försoningsgåva",
    "försoningsgåvor": "försoningsgåva",
    "försoningsgåvorna": "försoningsgåva",
    "försoningsgåvornas": "försoningsgåva",
    "försoningsgåvors": "försoningsgåva",
    "försoningsknullen": "försoningsknull",
    "försoningsknullens": "försoningsknull",
    "försoningsknullet": "försoningsknull",
    "försoningsknullets": "försoningsknull",
    "försoningsknulls": "försoningsknull",
    "försonliga": "försonlig",
    "försonligare": "försonlig",
    "försonligares": "försonlig",
    "försonligas": "försonlig",
    "försonligast": "försonlig",
    "försonligaste": "försonlig",
    "försonligastes": "försonlig",
    "försonligasts": "försonlig",
    "försonlige": "försonlig",
    "försonliges": "försonlig",
    "försonligheten": "försonlighet",
    "försonlighetens": "försonlighet",
    "försonlighets": "försonlighet",
    "försonligs": "försonlig",
    "försonligt": "försonlig",
    "försonligts": "försonlig",
    "försorgs": "försorg",
    "förspelen": "förspel",
    "förspelens": "förspel",
    "förspelet": "förspel",
    "förspelets": "förspel",
    "förspels": "förspel",
    "förspill": "förspilla",
    "förspillande": "förspilla",
    "förspillanden": "förspillande",
    "förspillandena": "förspillande",
    "förspillandenas": "förspillande",
    "förspillandens": "förspillande",
    "förspillandes": "förspillande",
    "förspillandet": "förspillande",
    "förspillandets": "förspillande",
    "förspillas": "förspilla",
    "förspilld": "förspilla",
    "förspillda": "förspilla",
    "förspilldas": "förspilla",
    "förspillde": "förspilla",
    "förspilldes": "förspilla",
    "förspillds": "förspilla",
    "förspiller": "förspilla",
    "förspilles": "förspilla",
    "förspills": "förspilla",
    "förspillt": "förspilla",
    "förspillts": "förspilla",
    "förspord": "förspörja",
    "försporda": "förspörja",
    "förspordas": "förspörja",
    "försporde": "förspörja",
    "förspordes": "förspörja",
    "förspords": "förspörja",
    "försport": "förspörja",
    "försports": "förspörja",
    "försprånget": "försprång",
    "försprångets": "försprång",
    "försprångs": "försprång",
    "förspända": "förspänd",
    "förspändare": "förspänd",
    "förspändares": "förspänd",
    "förspändas": "förspänd",
    "förspändast": "förspänd",
    "förspändaste": "förspänd",
    "förspändastes": "förspänd",
    "förspändasts": "förspänd",
    "förspände": "förspänd",
    "förspändes": "förspänd",
    "förspänds": "förspänd",
    "förspänningar": "förspänning",
    "förspänningarna": "förspänning",
    "förspänningarnas": "förspänning",
    "förspänningars": "förspänning",
    "förspänningen": "förspänning",
    "förspänningens": "förspänning",
    "förspännings": "förspänning",
    "förspänt": "förspänd",
    "förspänts": "förspänd",
    "förspörj": "förspörja",
    "förspörjande": "förspörja",
    "förspörjanden": "förspörjande",
    "förspörjandena": "förspörjande",
    "förspörjandenas": "förspörjande",
    "förspörjandens": "förspörjande",
    "förspörjandes": "förspörjande",
    "förspörjandet": "förspörjande",
    "förspörjandets": "förspörjande",
    "förspörjas": "förspörja",
    "förspörjer": "förspörja",
    "förspörjes": "förspörja",
    "förspörjs": "förspörja",
    "första": "en",
    "förstadagsbreven": "förstadagsbrev",
    "förstadagsbrevens": "förstadagsbrev",
    "förstadagsbrevet": "förstadagsbrev",
    "förstadagsbrevets": "förstadagsbrev",
    "förstadagsbrevs": "förstadagsbrev",
    "förstaden": "förstad",
    "förstadens": "förstad",
    "förstadie": "förstadium",
    "förstadier": "förstadium",
    "förstadierna": "förstadium",
    "förstadiernas": "förstadium",
    "förstadiers": "förstadium",
    "förstadiet": "förstadium",
    "förstadiets": "förstadium",
    "förstadiums": "förstadium",
    "förstads": "förstad",
    "förstadsvillan": "förstadsvilla",
    "förstadsvillans": "förstadsvilla",
    "förstadsvillas": "förstadsvilla",
    "förstadsville": "förstadsvilla",
    "förstadsvillor": "förstadsvilla",
    "förstadsvillorna": "förstadsvilla",
    "förstadsvillornas": "förstadsvilla",
    "förstadsvillors": "förstadsvilla",
    "förstagen": "förstag",
    "förstagens": "förstag",
    "förstaget": "förstag",
    "förstagets": "förstag",
    "förstagradsekvationen": "förstagradsekvation",
    "förstagradsekvationens": "förstagradsekvation",
    "förstagradsekvationer": "förstagradsekvation",
    "förstagradsekvationerna": "förstagradsekvation",
    "förstagradsekvationernas": "förstagradsekvation",
    "förstagradsekvationers": "förstagradsekvation",
    "förstagradsekvations": "förstagradsekvation",
    "förstags": "förstag",
    "förstagångsväljar": "förstagångsväljare",
    "förstagångsväljaren": "förstagångsväljare",
    "förstagångsväljarens": "förstagångsväljare",
    "förstagångsväljares": "förstagångsväljare",
    "förstagångsväljarna": "förstagångsväljare",
    "förstagångsväljarnas": "förstagångsväljare",
    "förstahandsalternativen": "förstahandsalternativ",
    "förstahandsalternativens": "förstahandsalternativ",
    "förstahandsalternativet": "förstahandsalternativ",
    "förstahandsalternativets": "förstahandsalternativ",
    "förstahandsalternativs": "förstahandsalternativ",
    "förstahandsuppgiften": "förstahandsuppgift",
    "förstahandsuppgiftens": "förstahandsuppgift",
    "förstahandsuppgifter": "förstahandsuppgift",
    "förstahandsuppgifterna": "förstahandsuppgift",
    "förstahandsuppgifternas": "förstahandsuppgift",
    "förstahandsuppgifters": "förstahandsuppgift",
    "förstahandsuppgifts": "förstahandsuppgift",
    "förstainstansen": "förstainstans",
    "förstainstansens": "förstainstans",
    "förstainstanser": "förstainstans",
    "förstainstanserna": "förstainstans",
    "förstainstansernas": "förstainstans",
    "förstainstansers": "förstainstans",
    "förstaklasshotellen": "förstaklasshotell",
    "förstaklasshotellens": "förstaklasshotell",
    "förstaklasshotellet": "förstaklasshotell",
    "förstaklasshotellets": "förstaklasshotell",
    "förstaklasshotells": "förstaklasshotell",
    "förstaklasshytten": "förstaklasshytt",
    "förstaklasshyttens": "förstaklasshytt",
    "förstaklasshytter": "förstaklasshytt",
    "förstaklasshytterna": "förstaklasshytt",
    "förstaklasshytternas": "förstaklasshytt",
    "förstaklasshytters": "förstaklasshytt",
    "förstaklasshytts": "förstaklasshytt",
    "förstamajblom": "förstamajblomma",
    "förstamajblomman": "förstamajblomma",
    "förstamajblommans": "förstamajblomma",
    "förstamajblommas": "förstamajblomma",
    "förstamajblomme": "förstamajblomma",
    "förstamajblommor": "förstamajblomma",
    "förstamajblommorna": "förstamajblomma",
    "förstamajblommornas": "förstamajblomma",
    "förstamajblommors": "förstamajblomma",
    "förstamajbloms": "förstamajblomma",
    "förstamajtalen": "förstamajtal",
    "förstamajtalens": "förstamajtal",
    "förstamajtalet": "förstamajtal",
    "förstamajtalets": "förstamajtal",
    "förstamajtals": "förstamajtal",
    "förstamajtågen": "förstamajtåg",
    "förstamajtågens": "förstamajtåg",
    "förstamajtåget": "förstamajtåg",
    "förstamajtågets": "förstamajtåg",
    "förstamajtågs": "förstamajtåg",
    "förstan": "förstad",
    "förstanamnen": "förstanamn",
    "förstanamnens": "förstanamn",
    "förstanamnet": "förstanamn",
    "förstanamnets": "förstanamn",
    "förstanamns": "förstanamn",
    "förstans": "förstad",
    "förstaplatsen": "förstaplats",
    "förstaplatsens": "förstaplats",
    "förstaplatser": "förstaplats",
    "förstaplatserna": "förstaplats",
    "förstaplatsernas": "förstaplats",
    "förstaplatsers": "förstaplats",
    "förstaresan": "förstaresa",
    "förstaresans": "förstaresa",
    "förstaresas": "förstaresa",
    "förstarese": "förstaresa",
    "förstaresor": "förstaresa",
    "förstaresorna": "förstaresa",
    "förstaresornas": "förstaresa",
    "förstaresors": "förstaresa",
    "förstas": "en",
    "förstaservar": "förstaserve",
    "förstaservarna": "förstaserve",
    "förstaservarnas": "förstaserve",
    "förstaservars": "förstaserve",
    "förstaserven": "förstaserve",
    "förstaservens": "förstaserve",
    "förstaserves": "förstaserve",
    "förstasidan": "förstasida",
    "förstasidans": "förstasida",
    "förstasidas": "förstasida",
    "förstaside": "förstasida",
    "förstasides": "förstasida",
    "förstasidor": "förstasida",
    "förstasidorna": "förstasida",
    "förstasidornas": "förstasida",
    "förstasidors": "förstasida",
    "förstaslagen": "förstaslag",
    "förstaslagens": "förstaslag",
    "förstaslaget": "förstaslag",
    "förstaslagets": "förstaslag",
    "förstaslags": "förstaslag",
    "förstaslagsförmågan": "förstaslagsförmåga",
    "förstaslagsförmågans": "förstaslagsförmåga",
    "förstaslagsförmågas": "förstaslagsförmåga",
    "förstaslagsförmåge": "förstaslagsförmåga",
    "förstatlig": "förstatliga",
    "förstatligad": "förstatliga",
    "förstatligade": "förstatliga",
    "förstatligades": "förstatliga",
    "förstatligads": "förstatliga",
    "förstatligande": "förstatliga",
    "förstatliganden": "förstatligande",
    "förstatligandena": "förstatligande",
    "förstatligandenas": "förstatligande",
    "förstatligandens": "förstatligande",
    "förstatligandes": "förstatligande",
    "förstatligandet": "förstatligande",
    "förstatligandets": "förstatligande",
    "förstatligar": "förstatliga",
    "förstatligas": "förstatliga",
    "förstatligat": "förstatliga",
    "förstatligats": "förstatliga",
    "förstaupplagan": "förstaupplaga",
    "förstaupplagans": "förstaupplaga",
    "förstaupplagas": "förstaupplaga",
    "förstaupplage": "förstaupplaga",
    "förstaupplagor": "förstaupplaga",
    "förstaupplagorna": "förstaupplaga",
    "förstaupplagornas": "förstaupplaga",
    "förstaupplagors": "förstaupplaga",
    "förstavelsen": "förstavelse",
    "förstavelsens": "förstavelse",
    "förstavelser": "förstavelse",
    "förstavelserna": "förstavelse",
    "förstavelsernas": "förstavelse",
    "förstavelsers": "förstavelse",
    "förstavelses": "förstavelse",
    "förstaårsstudenten": "förstaårsstudent",
    "förstaårsstudentens": "förstaårsstudent",
    "förstaårsstudenter": "förstaårsstudent",
    "förstaårsstudenterna": "förstaårsstudent",
    "förstaårsstudenternas": "förstaårsstudent",
    "förstaårsstudenters": "förstaårsstudent",
    "förstaårsstudents": "förstaårsstudent",
    "förste": "en",
    "förstegen": "försteg",
    "förstegens": "försteg",
    "försteget": "försteg",
    "förstegets": "försteg",
    "förstegs": "försteg",
    "försteln": "förstelna",
    "förstelnad": "förstelna",
    "förstelnade": "förstelna",
    "förstelnades": "förstelna",
    "förstelnads": "förstelna",
    "förstelnande": "förstelna",
    "förstelnanden": "förstelnande",
    "förstelnandena": "förstelnande",
    "förstelnandenas": "förstelnande",
    "förstelnandens": "förstelnande",
    "förstelnandes": "förstelnande",
    "förstelnandet": "förstelnande",
    "förstelnandets": "förstelnande",
    "förstelnar": "förstelna",
    "förstelnas": "förstelna",
    "förstelnat": "förstelna",
    "förstelnats": "förstelna",
    "försten": "förstena",
    "förstenad": "förstena",
    "förstenade": "förstena",
    "förstenades": "förstena",
    "förstenads": "förstena",
    "förstenande": "förstena",
    "förstenanden": "förstenande",
    "förstenandena": "förstenande",
    "förstenandenas": "förstenande",
    "förstenandens": "förstenande",
    "förstenandes": "förstenande",
    "förstenandet": "förstenande",
    "förstenandets": "förstenande",
    "förstenar": "förstena",
    "förstenas": "förstena",
    "förstenat": "förstena",
    "förstenats": "förstena",
    "förstes": "en",
    "förstfödda": "förstfödd",
    "förstföddare": "förstfödd",
    "förstföddares": "förstfödd",
    "förstföddas": "förstfödd",
    "förstföddast": "förstfödd",
    "förstföddaste": "förstfödd",
    "förstföddastes": "förstfödd",
    "förstföddasts": "förstfödd",
    "förstfödde": "förstfödd",
    "förstföddes": "förstfödd",
    "förstfödds": "förstfödd",
    "förstföderskan": "förstföderska",
    "förstföderskans": "förstföderska",
    "förstföderskas": "förstföderska",
    "förstföderske": "förstföderska",
    "förstföderskor": "förstföderska",
    "förstföderskorna": "förstföderska",
    "förstföderskornas": "förstföderska",
    "förstföderskors": "förstföderska",
    "förstfödslorätten": "förstfödslorätt",
    "förstfödslorättens": "förstfödslorätt",
    "förstfödslorätts": "förstfödslorätt",
    "förstfött": "förstfödd",
    "förstfötts": "förstfödd",
    "förstklassiga": "förstklassig",
    "förstklassigare": "förstklassig",
    "förstklassigares": "förstklassig",
    "förstklassigas": "förstklassig",
    "förstklassigast": "förstklassig",
    "förstklassigaste": "förstklassig",
    "förstklassigastes": "förstklassig",
    "förstklassigasts": "förstklassig",
    "förstklassige": "förstklassig",
    "förstklassiges": "förstklassig",
    "förstklassigheten": "förstklassighet",
    "förstklassighetens": "förstklassighet",
    "förstklassighets": "förstklassighet",
    "förstklassigs": "förstklassig",
    "förstklassigt": "förstklassig",
    "förstklassigts": "förstklassig",
    "förstlingar": "förstling",
    "förstlingarna": "förstling",
    "förstlingarnas": "förstling",
    "förstlingars": "förstling",
    "förstlingen": "förstling",
    "förstlingens": "förstling",
    "förstlings": "förstling",
    "förstnämnda": "förstnämnd",
    "förstnämndare": "förstnämnd",
    "förstnämndares": "förstnämnd",
    "förstnämndas": "förstnämnd",
    "förstnämndast": "förstnämnd",
    "förstnämndaste": "förstnämnd",
    "förstnämndastes": "förstnämnd",
    "förstnämndasts": "förstnämnd",
    "förstnämnde": "förstnämnd",
    "förstnämndes": "förstnämnd",
    "förstnämnds": "förstnämnd",
    "förstnämnt": "förstnämnd",
    "förstnämnts": "förstnämnd",
    "förstock": "förstocka",
    "förstockad": "förstocka",
    "förstockade": "förstockad",
    "förstockades": "förstockad",
    "förstockads": "förstockad",
    "förstockande": "förstocka",
    "förstockanden": "förstockande",
    "förstockandena": "förstockande",
    "förstockandenas": "förstockande",
    "förstockandens": "förstockande",
    "förstockandes": "förstockande",
    "förstockandet": "förstockande",
    "förstockandets": "förstockande",
    "förstockar": "förstocka",
    "förstockas": "förstocka",
    "förstockat": "förstockad",
    "förstockats": "förstockad",
    "förstockelsen": "förstockelse",
    "förstockelsens": "förstockelse",
    "förstockelses": "förstockelse",
    "förstod": "förstå",
    "förstode": "förstå",
    "förstodes": "förstå",
    "förstods": "förstå",
    "förstopp": "förstoppa",
    "förstoppad": "förstoppa",
    "förstoppade": "förstoppa",
    "förstoppades": "förstoppa",
    "förstoppads": "förstoppa",
    "förstoppande": "förstoppa",
    "förstoppanden": "förstoppande",
    "förstoppandena": "förstoppande",
    "förstoppandenas": "förstoppande",
    "förstoppandens": "förstoppande",
    "förstoppandes": "förstoppande",
    "förstoppandet": "förstoppande",
    "förstoppandets": "förstoppande",
    "förstoppar": "förstoppa",
    "förstoppas": "förstoppa",
    "förstoppat": "förstoppa",
    "förstoppats": "förstoppa",
    "förstoppningar": "förstoppning",
    "förstoppningarna": "förstoppning",
    "förstoppningarnas": "förstoppning",
    "förstoppningars": "förstoppning",
    "förstoppningen": "förstoppning",
    "förstoppningens": "förstoppning",
    "förstoppnings": "förstoppning",
    "förstoppningsbesvären": "förstoppningsbesvär",
    "förstoppningsbesvärens": "förstoppningsbesvär",
    "förstoppningsbesväret": "förstoppningsbesvär",
    "förstoppningsbesvärets": "förstoppningsbesvär",
    "förstoppningsbesvärs": "förstoppningsbesvär",
    "förstor": "förstora",
    "förstorad": "förstora",
    "förstorade": "förstora",
    "förstorades": "förstora",
    "förstorads": "förstora",
    "förstorande": "förstora",
    "förstoranden": "förstorande",
    "förstorandena": "förstorande",
    "förstorandenas": "förstorande",
    "förstorandens": "förstorande",
    "förstorandes": "förstorande",
    "förstorandet": "förstorande",
    "förstorandets": "förstorande",
    "förstorar": "förstora",
    "förstoras": "förstora",
    "förstorat": "förstora",
    "förstorats": "förstora",
    "förstoringar": "förstoring",
    "förstoringarna": "förstoring",
    "förstoringarnas": "förstoring",
    "förstoringars": "förstoring",
    "förstoringen": "förstoring",
    "förstoringens": "förstoring",
    "förstorings": "förstoring",
    "förstoringsapparaten": "förstoringsapparat",
    "förstoringsapparatens": "förstoringsapparat",
    "förstoringsapparater": "förstoringsapparat",
    "förstoringsapparaterna": "förstoringsapparat",
    "förstoringsapparaternas": "förstoringsapparat",
    "förstoringsapparaters": "förstoringsapparat",
    "förstoringsapparats": "förstoringsapparat",
    "förstoringsglasen": "förstoringsglas",
    "förstoringsglasens": "förstoringsglas",
    "förstoringsglaset": "förstoringsglas",
    "förstoringsglasets": "förstoringsglas",
    "försträck": "försträcka",
    "försträckande": "försträcka",
    "försträckanden": "försträckande",
    "försträckandena": "försträckande",
    "försträckandenas": "försträckande",
    "försträckandens": "försträckande",
    "försträckandes": "försträckande",
    "försträckandet": "försträckande",
    "försträckandets": "försträckande",
    "försträckas": "försträcka",
    "försträcker": "försträcka",
    "försträckes": "försträcka",
    "försträckningar": "försträckning",
    "försträckningarna": "försträckning",
    "försträckningarnas": "försträckning",
    "försträckningars": "försträckning",
    "försträckningen": "försträckning",
    "försträckningens": "försträckning",
    "försträcknings": "försträckning",
    "försträcks": "försträcka",
    "försträckt": "försträcka",
    "försträckta": "försträcka",
    "försträcktas": "försträcka",
    "försträckte": "försträcka",
    "försträcktes": "försträcka",
    "försträckts": "försträcka",
    "försträv": "försträva",
    "försträvad": "försträva",
    "försträvade": "försträva",
    "försträvades": "försträva",
    "försträvads": "försträva",
    "försträvande": "försträva",
    "försträvanden": "försträvande",
    "försträvandena": "försträvande",
    "försträvandenas": "försträvande",
    "försträvandens": "försträvande",
    "försträvandes": "försträvande",
    "försträvandet": "försträvande",
    "försträvandets": "försträvande",
    "försträvar": "försträva",
    "försträvas": "försträva",
    "försträvat": "försträva",
    "försträvats": "försträva",
    "förströdd": "förströ",
    "förströdda": "förströdd",
    "förströddare": "förströdd",
    "förströddares": "förströdd",
    "förströddas": "förströdd",
    "förströddast": "förströdd",
    "förströddaste": "förströdd",
    "förströddastes": "förströdd",
    "förströddasts": "förströdd",
    "förströdde": "förströdd",
    "förströddes": "förströdd",
    "förströddheten": "förströddhet",
    "förströddhetens": "förströddhet",
    "förströddhets": "förströddhet",
    "förströdds": "förströdd",
    "förströelsen": "förströelse",
    "förströelsens": "förströelse",
    "förströelser": "förströelse",
    "förströelserna": "förströelse",
    "förströelsernas": "förströelse",
    "förströelsers": "förströelse",
    "förströelses": "förströelse",
    "förströende": "förströ",
    "förströenden": "förströende",
    "förströendena": "förströende",
    "förströendenas": "förströende",
    "förströendens": "förströende",
    "förströendes": "förströende",
    "förströendet": "förströende",
    "förströendets": "förströende",
    "förströr": "förströ",
    "förströs": "förströ",
    "förstrött": "förströdd",
    "förströtts": "förströdd",
    "förstubroar": "förstubro",
    "förstubroarna": "förstubro",
    "förstubroarnas": "förstubro",
    "förstubroars": "förstubro",
    "förstubron": "förstubro",
    "förstubrons": "förstubro",
    "förstubros": "förstubro",
    "förstuckenheten": "förstuckenhet",
    "förstuckenhetens": "förstuckenhet",
    "förstuckenhets": "förstuckenhet",
    "förstuckens": "förstucken",
    "förstucket": "förstucken",
    "förstuckets": "förstucken",
    "förstuckna": "förstucken",
    "förstucknare": "förstucken",
    "förstucknares": "förstucken",
    "förstucknas": "förstucken",
    "förstucknast": "förstucken",
    "förstucknaste": "förstucken",
    "förstucknastes": "förstucken",
    "förstucknasts": "förstucken",
    "förstuckne": "förstucken",
    "förstucknes": "förstucken",
    "förstudien": "förstudie",
    "förstudiens": "förstudie",
    "förstudier": "förstudie",
    "förstudierna": "förstudie",
    "förstudiernas": "förstudie",
    "förstudiers": "förstudie",
    "förstudies": "förstudie",
    "förstugan": "förstuga",
    "förstugans": "förstuga",
    "förstugas": "förstuga",
    "förstuge": "förstuga",
    "förstugor": "förstuga",
    "förstugorna": "förstuga",
    "förstugornas": "förstuga",
    "förstugors": "förstuga",
    "förstugu": "förstuga",
    "förstugubroar": "förstugubro",
    "förstugubroarna": "förstugubro",
    "förstugubroarnas": "förstugubro",
    "förstugubroars": "förstugubro",
    "förstugubron": "förstugubro",
    "förstugubrons": "förstugubro",
    "förstugubros": "förstugubro",
    "förstugukvistar": "förstugukvist",
    "förstugukvistarna": "förstugukvist",
    "förstugukvistarnas": "förstugukvist",
    "förstugukvistars": "förstugukvist",
    "förstugukvisten": "förstugukvist",
    "förstugukvistens": "förstugukvist",
    "förstugukvists": "förstugukvist",
    "förstukvistar": "förstukvist",
    "förstukvistarna": "förstukvist",
    "förstukvistarnas": "förstukvist",
    "förstukvistars": "förstukvist",
    "förstukvisten": "förstukvist",
    "förstukvistens": "förstukvist",
    "förstukvists": "förstukvist",
    "förstulenheten": "förstulenhet",
    "förstulenhetens": "förstulenhet",
    "förstulenhets": "förstulenhet",
    "förstulens": "förstulen",
    "förstulet": "förstulen",
    "förstulets": "förstulen",
    "förstulna": "förstulen",
    "förstulnare": "förstulen",
    "förstulnares": "förstulen",
    "förstulnas": "förstulen",
    "förstulnast": "förstulen",
    "förstulnaste": "förstulen",
    "förstulnastes": "förstulen",
    "förstulnasts": "förstulen",
    "förstulne": "förstulen",
    "förstulnes": "förstulen",
    "förstummad": "förstumma",
    "förstummade": "förstumma",
    "förstummades": "förstumma",
    "förstummads": "förstumma",
    "förstummande": "förstumma",
    "förstummanden": "förstummande",
    "förstummandena": "förstummande",
    "förstummandenas": "förstummande",
    "förstummandens": "förstummande",
    "förstummandes": "förstummande",
    "förstummandet": "förstummande",
    "förstummandets": "förstummande",
    "förstummar": "förstumma",
    "förstummas": "förstumma",
    "förstummat": "förstumma",
    "förstummats": "förstumma",
    "förstäder": "förstad",
    "förstäderna": "förstad",
    "förstädernas": "förstad",
    "förstäders": "förstad",
    "förställ": "förställa",
    "förställande": "förställa",
    "förställanden": "förställande",
    "förställandena": "förställande",
    "förställandenas": "förställande",
    "förställandens": "förställande",
    "förställandes": "förställande",
    "förställandet": "förställande",
    "förställandets": "förställande",
    "förställas": "förställa",
    "förställd": "förställa",
    "förställda": "förställa",
    "förställdas": "förställa",
    "förställde": "förställa",
    "förställdes": "förställa",
    "förställds": "förställa",
    "förställer": "förställa",
    "förställes": "förställa",
    "förställningar": "förställning",
    "förställningarna": "förställning",
    "förställningarnas": "förställning",
    "förställningars": "förställning",
    "förställningen": "förställning",
    "förställningens": "förställning",
    "förställnings": "förställning",
    "förställs": "förställa",
    "förställt": "förställa",
    "förställts": "förställa",
    "förstäm": "förstämma",
    "förstämd": "förstämma",
    "förstämda": "förstämma",
    "förstämdare": "förstämd",
    "förstämdares": "förstämd",
    "förstämdas": "förstämma",
    "förstämdast": "förstämd",
    "förstämdaste": "förstämd",
    "förstämdastes": "förstämd",
    "förstämdasts": "förstämd",
    "förstämde": "förstämma",
    "förstämdes": "förstämma",
    "förstämdheten": "förstämdhet",
    "förstämdhetens": "förstämdhet",
    "förstämdhets": "förstämdhet",
    "förstämds": "förstämma",
    "förstämmande": "förstämma",
    "förstämmanden": "förstämmande",
    "förstämmandena": "förstämmande",
    "förstämmandenas": "förstämmande",
    "förstämmandens": "förstämmande",
    "förstämmandes": "förstämmande",
    "förstämmandet": "förstämmande",
    "förstämmandets": "förstämmande",
    "förstämmas": "förstämma",
    "förstämmer": "förstämma",
    "förstämningar": "förstämning",
    "förstämningarna": "förstämning",
    "förstämningarnas": "förstämning",
    "förstämningars": "förstämning",
    "förstämningen": "förstämning",
    "förstämningens": "förstämning",
    "förstämnings": "förstämning",
    "förstäms": "förstämma",
    "förstämt": "förstämma",
    "förstämts": "förstämma",
    "förständig": "förständiga",
    "förständigad": "förständiga",
    "förständigade": "förständiga",
    "förständigades": "förständiga",
    "förständigads": "förständiga",
    "förständigande": "förständiga",
    "förständiganden": "förständigande",
    "förständigandena": "förständigande",
    "förständigandenas": "förständigande",
    "förständigandens": "förständigande",
    "förständigandes": "förständigande",
    "förständigandet": "förständigande",
    "förständigandets": "förständigande",
    "förständigar": "förständiga",
    "förständigas": "förständiga",
    "förständigat": "förständiga",
    "förständigats": "förständiga",
    "förstänger": "förstång",
    "förstängerna": "förstång",
    "förstängernas": "förstång",
    "förstängers": "förstång",
    "förstärk": "förstärka",
    "förstärkande": "förstärka",
    "förstärkanden": "förstärkande",
    "förstärkandena": "förstärkande",
    "förstärkandenas": "förstärkande",
    "förstärkandens": "förstärkande",
    "förstärkandes": "förstärkande",
    "förstärkandet": "förstärkande",
    "förstärkandets": "förstärkande",
    "förstärkar": "förstärkare",
    "förstärkaren": "förstärkare",
    "förstärkarens": "förstärkare",
    "förstärkares": "förstärkare",
    "förstärkarna": "förstärkare",
    "förstärkarnas": "förstärkare",
    "förstärkas": "förstärka",
    "förstärker": "förstärka",
    "förstärkes": "förstärka",
    "förstärkningar": "förstärkning",
    "förstärkningarna": "förstärkning",
    "förstärkningarnas": "förstärkning",
    "förstärkningars": "förstärkning",
    "förstärkningen": "förstärkning",
    "förstärkningens": "förstärkning",
    "förstärknings": "förstärkning",
    "förstärkningsorden": "förstärkningsord",
    "förstärkningsordens": "förstärkningsord",
    "förstärkningsordet": "förstärkningsord",
    "förstärkningsordets": "förstärkningsord",
    "förstärkningsords": "förstärkningsord",
    "förstärks": "förstärka",
    "förstärkt": "förstärka",
    "förstärkta": "förstärka",
    "förstärktas": "förstärka",
    "förstärkte": "förstärka",
    "förstärktes": "förstärka",
    "förstärkts": "förstärka",
    "förstävar": "förstäv",
    "förstävarna": "förstäv",
    "förstävarnas": "förstäv",
    "förstävars": "förstäv",
    "förstäven": "förstäv",
    "förstävens": "förstäv",
    "förstävs": "förstäv",
    "förståeliga": "förståelig",
    "förståeligare": "förståelig",
    "förståeligares": "förståelig",
    "förståeligas": "förståelig",
    "förståeligast": "förståelig",
    "förståeligaste": "förståelig",
    "förståeligastes": "förståelig",
    "förståeligasts": "förståelig",
    "förståelige": "förståelig",
    "förståeliges": "förståelig",
    "förståeligheten": "förståelighet",
    "förståelighetens": "förståelighet",
    "förståelighets": "förståelighet",
    "förståeligs": "förståelig",
    "förståeligt": "förståelig",
    "förståeligts": "förståelig",
    "förståelsen": "förståelse",
    "förståelsens": "förståelse",
    "förståelses": "förståelse",
    "förstående": "förstå",
    "förståenden": "förstående",
    "förståendena": "förstående",
    "förståendenas": "förstående",
    "förståendens": "förstående",
    "förståendes": "förstående",
    "förståendet": "förstående",
    "förståendets": "förstående",
    "förståndet": "förstånd",
    "förståndets": "förstånd",
    "förståndiga": "förståndig",
    "förståndigare": "förståndig",
    "förståndigares": "förståndig",
    "förståndigas": "förståndig",
    "förståndigast": "förståndig",
    "förståndigaste": "förståndig",
    "förståndigastes": "förståndig",
    "förståndigasts": "förståndig",
    "förståndige": "förståndig",
    "förståndiges": "förståndig",
    "förståndigheten": "förståndighet",
    "förståndighetens": "förståndighet",
    "förståndighets": "förståndighet",
    "förståndigs": "förståndig",
    "förståndigt": "förståndig",
    "förståndigts": "förståndig",
    "förstånds": "förstånd",
    "förståndshandikappade": "förståndshandikappad",
    "förståndshandikappades": "förståndshandikappad",
    "förståndshandikappads": "förståndshandikappad",
    "förståndshandikappat": "förståndshandikappad",
    "förståndshandikappats": "förståndshandikappad",
    "förståndshandikappen": "förståndshandikapp",
    "förståndshandikappens": "förståndshandikapp",
    "förståndshandikappet": "förståndshandikapp",
    "förståndshandikappets": "förståndshandikapp",
    "förståndshandikapps": "förståndshandikapp",
    "förståndsmässiga": "förståndsmässig",
    "förståndsmässigare": "förståndsmässig",
    "förståndsmässigares": "förståndsmässig",
    "förståndsmässigas": "förståndsmässig",
    "förståndsmässigast": "förståndsmässig",
    "förståndsmässigaste": "förståndsmässig",
    "förståndsmässigastes": "förståndsmässig",
    "förståndsmässigasts": "förståndsmässig",
    "förståndsmässige": "förståndsmässig",
    "förståndsmässiges": "förståndsmässig",
    "förståndsmässigs": "förståndsmässig",
    "förståndsmässigt": "förståndsmässig",
    "förståndsmässigts": "förståndsmässig",
    "förstången": "förstång",
    "förstångens": "förstång",
    "förstångs": "förstång",
    "förstår": "förstå",
    "förstås": "förstå",
    "förståsigpåar": "förståsigpåare",
    "förståsigpåaren": "förståsigpåare",
    "förståsigpåarens": "förståsigpåare",
    "förståsigpåares": "förståsigpåare",
    "förståsigpåarna": "förståsigpåare",
    "förståsigpåarnas": "förståsigpåare",
    "förstått": "förstå",
    "förståtts": "förstå",
    "förstör": "förstöra",
    "förstörande": "förstöra",
    "förstöranden": "förstörande",
    "förstörandena": "förstörande",
    "förstörandenas": "förstörande",
    "förstörandens": "förstörande",
    "förstörandes": "förstörande",
    "förstörandet": "förstörande",
    "förstörandets": "förstörande",
    "förstöras": "förstöra",
    "förstörd": "förstöra",
    "förstörda": "förstöra",
    "förstördas": "förstöra",
    "förstörde": "förstörd",
    "förstördes": "förstörd",
    "förstördheten": "förstördhet",
    "förstördhetens": "förstördhet",
    "förstördhets": "förstördhet",
    "förstörds": "förstörd",
    "förstörelsen": "förstörelse",
    "förstörelsens": "förstörelse",
    "förstörelser": "förstörelse",
    "förstörelserna": "förstörelse",
    "förstörelsernas": "förstörelse",
    "förstörelsers": "förstörelse",
    "förstörelses": "förstörelse",
    "förstöres": "förstöras",
    "förstöringar": "förstöring",
    "förstöringarna": "förstöring",
    "förstöringarnas": "förstöring",
    "förstöringars": "förstöring",
    "förstöringen": "förstöring",
    "förstöringens": "förstöring",
    "förstörings": "förstöring",
    "förstörs": "förstöras",
    "förstört": "förstörd",
    "förstörts": "förstörd",
    "försumbara": "försumbar",
    "försumbarare": "försumbar",
    "försumbarares": "försumbar",
    "försumbaras": "försumbar",
    "försumbarast": "försumbar",
    "försumbaraste": "försumbar",
    "försumbarastes": "försumbar",
    "försumbarasts": "försumbar",
    "försumbare": "försumbar",
    "försumbares": "försumbar",
    "försumbarheten": "försumbarhet",
    "försumbarhetens": "försumbarhet",
    "försumbarhets": "försumbarhet",
    "försumbars": "försumbar",
    "försumbart": "försumbar",
    "försumbarts": "försumbar",
    "försumliga": "försumlig",
    "försumligare": "försumlig",
    "försumligares": "försumlig",
    "försumligas": "försumlig",
    "försumligast": "försumlig",
    "försumligaste": "försumlig",
    "försumligastes": "försumlig",
    "försumligasts": "försumlig",
    "försumlige": "försumlig",
    "försumliges": "försumlig",
    "försumligheten": "försumlighet",
    "försumlighetens": "försumlighet",
    "försumligheter": "försumlighet",
    "försumligheterna": "försumlighet",
    "försumligheternas": "försumlighet",
    "försumligheters": "försumlighet",
    "försumlighets": "försumlighet",
    "försumligs": "försumlig",
    "försumligt": "försumlig",
    "försumligts": "försumlig",
    "försummad": "försumma",
    "försummade": "försumma",
    "försummades": "försumma",
    "försummads": "försumma",
    "försummande": "försumma",
    "försummanden": "försummande",
    "försummandena": "försummande",
    "försummandenas": "försummande",
    "försummandens": "försummande",
    "försummandes": "försummande",
    "försummandet": "försummande",
    "försummandets": "försummande",
    "försummar": "försumma",
    "försummas": "försumma",
    "försummat": "försumma",
    "försummats": "försumma",
    "försummelsen": "försummelse",
    "försummelsens": "försummelse",
    "försummelser": "försummelse",
    "försummelserna": "försummelse",
    "försummelsernas": "försummelse",
    "försummelsers": "försummelse",
    "försummelses": "försummelse",
    "försumpades": "försumpas",
    "försumpats": "försumpas",
    "försumpningar": "försumpning",
    "försumpningarna": "försumpning",
    "försumpningarnas": "försumpning",
    "försumpningars": "försumpning",
    "försumpningen": "försumpning",
    "försumpningens": "försumpning",
    "försumpnings": "försumpning",
    "försupenheten": "försupenhet",
    "försupenhetens": "försupenhet",
    "försupenhets": "försupenhet",
    "försupens": "försupen",
    "försupet": "försupen",
    "försupets": "försupen",
    "försupna": "försupen",
    "försupnare": "försupen",
    "försupnares": "försupen",
    "försupnas": "försupen",
    "försupnast": "försupen",
    "försupnaste": "försupen",
    "försupnastes": "försupen",
    "försupnasts": "försupen",
    "försupne": "försupen",
    "försupnes": "försupen",
    "försur": "försura",
    "försurad": "försura",
    "försurade": "försura",
    "försurades": "försuras",
    "försurads": "försura",
    "försurande": "försura",
    "försuranden": "försurande",
    "försurandena": "försurande",
    "försurandenas": "försurande",
    "försurandens": "försurande",
    "försurandes": "försurande",
    "försurandet": "försurande",
    "försurandets": "försurande",
    "försurar": "försura",
    "försuras": "försura",
    "försurat": "försura",
    "försurats": "försuras",
    "försurningar": "försurning",
    "försurningarna": "försurning",
    "försurningarnas": "försurning",
    "försurningars": "försurning",
    "försurningen": "försurning",
    "försurningens": "försurning",
    "försurnings": "försurning",
    "försutte": "försitta",
    "försutten": "försitta",
    "försuttens": "försitta",
    "försuttes": "försitta",
    "försuttet": "försitta",
    "försuttets": "försitta",
    "försuttit": "försitta",
    "försuttits": "försitta",
    "försuttna": "försitta",
    "försuttnas": "försitta",
    "försuttne": "försitta",
    "försuttnes": "försitta",
    "försvag": "försvaga",
    "försvagad": "försvaga",
    "försvagade": "försvaga",
    "försvagades": "försvaga",
    "försvagads": "försvaga",
    "försvagande": "försvaga",
    "försvaganden": "försvagande",
    "försvagandena": "försvagande",
    "försvagandenas": "försvagande",
    "försvagandens": "försvagande",
    "försvagandes": "försvagande",
    "försvagandet": "försvagande",
    "försvagandets": "försvagande",
    "försvagar": "försvaga",
    "försvagas": "försvaga",
    "försvagat": "försvaga",
    "försvagats": "försvaga",
    "försvagningar": "försvagning",
    "försvagningarna": "försvagning",
    "försvagningarnas": "försvagning",
    "försvagningars": "försvagning",
    "försvagningen": "försvagning",
    "försvagningens": "försvagning",
    "försvagnings": "försvagning",
    "försvann": "försvinna",
    "försvanns": "försvinna",
    "försvarad": "försvara",
    "försvarade": "försvara",
    "försvarades": "försvara",
    "försvarads": "försvara",
    "försvarande": "försvara",
    "försvaranden": "försvarande",
    "försvarandena": "försvarande",
    "försvarandenas": "försvarande",
    "försvarandens": "försvarande",
    "försvarandes": "försvarande",
    "försvarandet": "försvarande",
    "försvarandets": "försvarande",
    "försvarar": "försvarare",
    "försvararen": "försvarare",
    "försvararens": "försvarare",
    "försvarares": "försvarare",
    "försvararna": "försvarare",
    "försvararnas": "försvarare",
    "försvaras": "försvara",
    "försvarat": "försvara",
    "försvarats": "försvara",
    "försvarbara": "försvarbar",
    "försvarbarare": "försvarbar",
    "försvarbarares": "försvarbar",
    "försvarbaras": "försvarbar",
    "försvarbarast": "försvarbar",
    "försvarbaraste": "försvarbar",
    "försvarbarastes": "försvarbar",
    "försvarbarasts": "försvarbar",
    "försvarbare": "försvarbar",
    "försvarbares": "försvarbar",
    "försvarbarheten": "försvarbarhet",
    "försvarbarhetens": "försvarbarhet",
    "försvarbarhets": "försvarbarhet",
    "försvarbars": "försvarbar",
    "försvarbart": "försvarbar",
    "försvarbarts": "försvarbar",
    "försvaret": "försvar",
    "försvarets": "försvar",
    "försvarliga": "försvarlig",
    "försvarligare": "försvarlig",
    "försvarligares": "försvarlig",
    "försvarligas": "försvarlig",
    "försvarligast": "försvarlig",
    "försvarligaste": "försvarlig",
    "försvarligastes": "försvarlig",
    "försvarligasts": "försvarlig",
    "försvarlige": "försvarlig",
    "försvarliges": "försvarlig",
    "försvarligheten": "försvarlighet",
    "försvarlighetens": "försvarlighet",
    "försvarlighets": "försvarlighet",
    "försvarligs": "försvarlig",
    "försvarligt": "försvarlig",
    "försvarligts": "försvarlig",
    "försvars": "försvar",
    "försvarsadvokaten": "försvarsadvokat",
    "försvarsadvokatens": "försvarsadvokat",
    "försvarsadvokater": "försvarsadvokat",
    "försvarsadvokaterna": "försvarsadvokat",
    "försvarsadvokaternas": "försvarsadvokat",
    "försvarsadvokaters": "försvarsadvokat",
    "försvarsadvokats": "försvarsadvokat",
    "försvarsanläggningar": "försvarsanläggning",
    "försvarsanläggningarna": "försvarsanläggning",
    "försvarsanläggningarnas": "försvarsanläggning",
    "försvarsanläggningars": "försvarsanläggning",
    "försvarsanläggningen": "försvarsanläggning",
    "försvarsanläggningens": "försvarsanläggning",
    "försvarsanläggnings": "försvarsanläggning",
    "försvarsattachéer": "försvarsattaché",
    "försvarsattachéerna": "försvarsattaché",
    "försvarsattachéernas": "försvarsattaché",
    "försvarsattachéers": "försvarsattaché",
    "försvarsattachén": "försvarsattaché",
    "försvarsattachéns": "försvarsattaché",
    "försvarsattachés": "försvarsattaché",
    "försvarsberedskapen": "försvarsberedskap",
    "försvarsberedskapens": "försvarsberedskap",
    "försvarsberedskaps": "försvarsberedskap",
    "försvarsdatorer": "försvarsdator",
    "försvarsdatorerna": "försvarsdator",
    "försvarsdatorernas": "försvarsdator",
    "försvarsdatorers": "försvarsdator",
    "försvarsdatorn": "försvarsdator",
    "försvarsdatorns": "försvarsdator",
    "försvarsdators": "försvarsdator",
    "försvarsfunktionen": "försvarsfunktion",
    "försvarsfunktionens": "försvarsfunktion",
    "försvarsfunktioner": "försvarsfunktion",
    "försvarsfunktionerna": "försvarsfunktion",
    "försvarsfunktionernas": "försvarsfunktion",
    "försvarsfunktioners": "försvarsfunktion",
    "försvarsfunktions": "försvarsfunktion",
    "försvarsgrenar": "försvarsgren",
    "försvarsgrenarna": "försvarsgren",
    "försvarsgrenarnas": "försvarsgren",
    "försvarsgrenars": "försvarsgren",
    "försvarsgrenen": "försvarsgren",
    "försvarsgrenens": "försvarsgren",
    "försvarsgrens": "försvarsgren",
    "försvarsgrenschefen": "försvarsgrenschef",
    "försvarsgrenschefens": "försvarsgrenschef",
    "försvarsgrenschefer": "försvarsgrenschef",
    "försvarsgrenscheferna": "försvarsgrenschef",
    "försvarsgrenschefernas": "försvarsgrenschef",
    "försvarsgrenschefers": "försvarsgrenschef",
    "försvarsgrenschefs": "försvarsgrenschef",
    "försvarshemligheten": "försvarshemlighet",
    "försvarshemlighetens": "försvarshemlighet",
    "försvarshemligheter": "försvarshemlighet",
    "försvarshemligheterna": "försvarshemlighet",
    "försvarshemligheternas": "försvarshemlighet",
    "försvarshemligheters": "försvarshemlighet",
    "försvarshemlighets": "försvarshemlighet",
    "försvarshögskolan": "försvarshögskola",
    "försvarshögskolans": "försvarshögskola",
    "försvarshögskolas": "försvarshögskola",
    "försvarshögskole": "försvarshögskola",
    "försvarshögskolor": "försvarshögskola",
    "försvarshögskolorna": "försvarshögskola",
    "försvarshögskolornas": "försvarshögskola",
    "försvarshögskolors": "försvarshögskola",
    "försvarsinlag": "försvarsinlaga",
    "försvarsinlagan": "försvarsinlaga",
    "försvarsinlagans": "försvarsinlaga",
    "försvarsinlagas": "försvarsinlaga",
    "försvarsinlage": "försvarsinlaga",
    "försvarsinlagor": "försvarsinlaga",
    "försvarsinlagorna": "försvarsinlaga",
    "försvarsinlagornas": "försvarsinlaga",
    "försvarsinlagors": "försvarsinlaga",
    "försvarsinlags": "försvarsinlaga",
    "försvarskostnaden": "försvarskostnad",
    "försvarskostnadens": "försvarskostnad",
    "försvarskostnader": "försvarskostnad",
    "försvarskostnaderna": "försvarskostnad",
    "försvarskostnadernas": "försvarskostnad",
    "försvarskostnaders": "försvarskostnad",
    "försvarskostnads": "försvarskostnad",
    "försvarskraften": "försvarskraft",
    "försvarskraftens": "försvarskraft",
    "försvarskrafter": "försvarskraft",
    "försvarskrafterna": "försvarskraft",
    "försvarskrafternas": "försvarskraft",
    "försvarskrafters": "försvarskraft",
    "försvarskrafts": "försvarskraft",
    "försvarskrigen": "försvarskrig",
    "försvarskrigens": "försvarskrig",
    "försvarskriget": "försvarskrig",
    "försvarskrigets": "försvarskrig",
    "försvarskrigs": "försvarskrig",
    "försvarslinjen": "försvarslinje",
    "försvarslinjens": "försvarslinje",
    "försvarslinjer": "försvarslinje",
    "försvarslinjerna": "försvarslinje",
    "försvarslinjernas": "försvarslinje",
    "försvarslinjers": "försvarslinje",
    "försvarslinjes": "försvarslinje",
    "försvarslösa": "försvarslös",
    "försvarslösare": "försvarslös",
    "försvarslösares": "försvarslös",
    "försvarslösas": "försvarslös",
    "försvarslösast": "försvarslös",
    "försvarslösaste": "försvarslös",
    "försvarslösastes": "försvarslös",
    "försvarslösasts": "försvarslös",
    "försvarslöse": "försvarslös",
    "försvarslöses": "försvarslös",
    "försvarslösheten": "försvarslöshet",
    "försvarslöshetens": "försvarslöshet",
    "försvarslöshets": "försvarslöshet",
    "försvarslöst": "försvarslös",
    "försvarslösts": "försvarslös",
    "försvarsmakten": "försvarsmakt",
    "försvarsmaktens": "försvarsmakt",
    "försvarsmakts": "försvarsmakt",
    "försvarsmekanismen": "försvarsmekanism",
    "försvarsmekanismens": "försvarsmekanism",
    "försvarsmekanismer": "försvarsmekanism",
    "försvarsmekanismerna": "försvarsmekanism",
    "försvarsmekanismernas": "försvarsmekanism",
    "försvarsmekanismers": "försvarsmekanism",
    "försvarsmekanisms": "försvarsmekanism",
    "försvarsministern": "försvarsminister",
    "försvarsministerns": "försvarsminister",
    "försvarsministers": "försvarsminister",
    "försvarsministrar": "försvarsminister",
    "försvarsministrarna": "försvarsminister",
    "försvarsministrarnas": "försvarsminister",
    "försvarsministrars": "försvarsminister",
    "försvarsmässiga": "försvarsmässig",
    "försvarsmässigare": "försvarsmässig",
    "försvarsmässigares": "försvarsmässig",
    "försvarsmässigas": "försvarsmässig",
    "försvarsmässigast": "försvarsmässig",
    "försvarsmässigaste": "försvarsmässig",
    "försvarsmässigastes": "försvarsmässig",
    "försvarsmässigasts": "försvarsmässig",
    "försvarsmässige": "försvarsmässig",
    "försvarsmässiges": "försvarsmässig",
    "försvarsmässigs": "försvarsmässig",
    "försvarsmässigt": "försvarsmässig",
    "försvarsmässigts": "försvarsmässig",
    "försvarsområden": "försvarsområde",
    "försvarsområdena": "försvarsområde",
    "försvarsområdenas": "försvarsområde",
    "försvarsområdens": "försvarsområde",
    "försvarsområdes": "försvarsområde",
    "försvarsområdet": "försvarsområde",
    "försvarsområdets": "försvarsområde",
    "försvarsplaneringar": "försvarsplanering",
    "försvarsplaneringarna": "försvarsplanering",
    "försvarsplaneringarnas": "försvarsplanering",
    "försvarsplaneringars": "försvarsplanering",
    "försvarsplaneringen": "försvarsplanering",
    "försvarsplaneringens": "försvarsplanering",
    "försvarsplanerings": "försvarsplanering",
    "försvarspolitiken": "försvarspolitik",
    "försvarspolitikens": "försvarspolitik",
    "försvarspolitiks": "försvarspolitik",
    "försvarspolitiska": "försvarspolitisk",
    "försvarspolitiskas": "försvarspolitisk",
    "försvarspolitiske": "försvarspolitisk",
    "försvarspolitiskes": "försvarspolitisk",
    "försvarspolitisks": "försvarspolitisk",
    "försvarspolitiskt": "försvarspolitisk",
    "försvarspolitiskts": "försvarspolitisk",
    "försvarsskriften": "försvarsskrift",
    "försvarsskriftens": "försvarsskrift",
    "försvarsskrifter": "försvarsskrift",
    "försvarsskrifterna": "försvarsskrift",
    "försvarsskrifternas": "försvarsskrift",
    "försvarsskrifters": "försvarsskrift",
    "försvarsskrifts": "försvarsskrift",
    "försvarsspelar": "försvarsspelare",
    "försvarsspelaren": "försvarsspelare",
    "försvarsspelarens": "försvarsspelare",
    "försvarsspelares": "försvarsspelare",
    "försvarsspelarna": "försvarsspelare",
    "försvarsspelarnas": "försvarsspelare",
    "försvarsspelen": "försvarsspel",
    "försvarsspelens": "försvarsspel",
    "försvarsspelet": "försvarsspel",
    "försvarsspelets": "försvarsspel",
    "försvarsspels": "försvarsspel",
    "försvarsstaben": "försvarsstab",
    "försvarsstabens": "försvarsstab",
    "försvarsstaber": "försvarsstab",
    "försvarsstaberna": "försvarsstab",
    "försvarsstabernas": "försvarsstab",
    "försvarsstabers": "försvarsstab",
    "försvarsstabs": "försvarsstab",
    "försvarsstrategien": "försvarsstrategi",
    "försvarsstrategiens": "försvarsstrategi",
    "försvarsstrategier": "försvarsstrategi",
    "försvarsstrategierna": "försvarsstrategi",
    "försvarsstrategiernas": "försvarsstrategi",
    "försvarsstrategiers": "försvarsstrategi",
    "försvarsstrategin": "försvarsstrategi",
    "försvarsstrategins": "försvarsstrategi",
    "försvarsstrategis": "försvarsstrategi",
    "försvarsställningar": "försvarsställning",
    "försvarsställningarna": "försvarsställning",
    "försvarsställningarnas": "försvarsställning",
    "försvarsställningars": "försvarsställning",
    "försvarsställningen": "försvarsställning",
    "försvarsställningens": "försvarsställning",
    "försvarsställnings": "försvarsställning",
    "försvarstalen": "försvarstal",
    "försvarstalens": "försvarstal",
    "försvarstalet": "försvarstal",
    "försvarstalets": "försvarstal",
    "försvarstals": "försvarstal",
    "försvarsutskotten": "försvarsutskott",
    "försvarsutskottens": "försvarsutskott",
    "försvarsutskottet": "försvarsutskott",
    "försvarsutskottets": "försvarsutskott",
    "försvarsutskotts": "försvarsutskott",
    "försvarsverken": "försvarsverk",
    "försvarsverkens": "försvarsverk",
    "försvarsverket": "försvarsverk",
    "försvarsverkets": "försvarsverk",
    "försvarsverks": "försvarsverk",
    "försvarsväsendet": "försvarsväsen",
    "försvarsväsendets": "försvarsväsen",
    "försvarsväsenet": "försvarsväsen",
    "försvarsväsenets": "försvarsväsen",
    "försvarsväsens": "försvarsväsen",
    "försvarsåtaganden": "försvarsåtagande",
    "försvarsåtagandena": "försvarsåtagande",
    "försvarsåtagandenas": "försvarsåtagande",
    "försvarsåtagandens": "försvarsåtagande",
    "försvarsåtagandes": "försvarsåtagande",
    "försvarsåtagandet": "försvarsåtagande",
    "försvarsåtagandets": "försvarsåtagande",
    "försvensk": "försvenska",
    "försvenskad": "försvenska",
    "försvenskade": "försvenska",
    "försvenskades": "försvenska",
    "försvenskads": "försvenska",
    "försvenskande": "försvenska",
    "försvenskanden": "försvenskande",
    "försvenskandena": "försvenskande",
    "försvenskandenas": "försvenskande",
    "försvenskandens": "försvenskande",
    "försvenskandes": "försvenskande",
    "försvenskandet": "försvenskande",
    "försvenskandets": "försvenskande",
    "försvenskar": "försvenska",
    "försvenskas": "försvenska",
    "försvenskat": "försvenska",
    "försvenskats": "försvenska",
    "försvinn": "försvinna",
    "försvinnande": "försvinna",
    "försvinnanden": "försvinnande",
    "försvinnandena": "försvinnande",
    "försvinnandenas": "försvinnande",
    "försvinnandens": "försvinnande",
    "försvinnandes": "försvinnande",
    "försvinnandet": "försvinnande",
    "försvinnandets": "försvinnande",
    "försvinnas": "försvinna",
    "försvinne": "försvinna",
    "försvinner": "försvinna",
    "försvinnes": "försvinna",
    "försvinns": "försvinna",
    "försvor": "försvärja",
    "försvors": "försvärja",
    "försvunna": "försvinna",
    "försvunnas": "försvinna",
    "försvunne": "försvinna",
    "försvunnen": "försvinna",
    "försvunnens": "försvinna",
    "försvunnes": "försvinna",
    "försvunnet": "försvinna",
    "försvunnets": "försvinna",
    "försvunnit": "försvinna",
    "försvunnits": "försvinna",
    "försvure": "försvärja",
    "försvuren": "försvärja",
    "försvurens": "försvärja",
    "försvures": "försvärja",
    "försvuret": "försvärja",
    "försvurets": "försvärja",
    "försvurit": "försvärja",
    "försvurits": "försvärja",
    "försvurna": "försvärja",
    "försvurnas": "försvärja",
    "försvurne": "försvärja",
    "försvurnes": "försvärja",
    "försvär": "försvärja",
    "försvära": "försvärja",
    "försvärande": "försvärja",
    "försvärandes": "försvärja",
    "försväras": "försvärja",
    "försvärj": "försvärja",
    "försvärjande": "försvärja",
    "försvärjanden": "försvärjande",
    "försvärjandena": "försvärjande",
    "försvärjandenas": "försvärjande",
    "försvärjandens": "försvärjande",
    "försvärjandes": "försvärjande",
    "försvärjandet": "försvärjande",
    "försvärjandets": "försvärjande",
    "försvärjas": "försvärja",
    "försvärjd": "försvärja",
    "försvärjda": "försvärja",
    "försvärjdas": "försvärja",
    "försvärjde": "försvärja",
    "försvärjdes": "försvärja",
    "försvärjds": "försvärja",
    "försvärje": "försvärja",
    "försvärjer": "försvärja",
    "försvärjes": "försvärja",
    "försvärjs": "försvärja",
    "försvärjt": "försvärja",
    "försvärjts": "försvärja",
    "försvår": "försvåra",
    "försvårad": "försvåra",
    "försvårade": "försvåra",
    "försvårades": "försvåra",
    "försvårads": "försvåra",
    "försvårande": "försvåra",
    "försvåranden": "försvårande",
    "försvårandena": "försvårande",
    "försvårandenas": "försvårande",
    "försvårandens": "försvårande",
    "försvårandes": "försvårande",
    "försvårandet": "försvårande",
    "försvårandets": "försvårande",
    "försvårar": "försvåra",
    "försvåras": "försvåra",
    "försvårat": "försvåra",
    "försvårats": "försvåra",
    "försynen": "försyn",
    "försynens": "försyn",
    "försyns": "försyn",
    "försynta": "försynt",
    "försyntare": "försynt",
    "försyntares": "försynt",
    "försyntas": "försynt",
    "försyntast": "försynt",
    "försyntaste": "försynt",
    "försyntastes": "försynt",
    "försyntasts": "försynt",
    "försynte": "försynt",
    "försyntes": "försynt",
    "försyntheten": "försynthet",
    "försynthetens": "försynthet",
    "försynthets": "försynthet",
    "försynts": "försynt",
    "försägningar": "försägning",
    "försägningarna": "försägning",
    "försägningarnas": "försägning",
    "försägningars": "försägning",
    "försägningen": "försägning",
    "försägningens": "försägning",
    "försägnings": "försägning",
    "försäkrad": "försäkra",
    "försäkrade": "försäkra",
    "försäkrades": "försäkra",
    "försäkrads": "försäkra",
    "försäkrande": "försäkra",
    "försäkranden": "försäkrande",
    "försäkrandena": "försäkrande",
    "försäkrandenas": "försäkrande",
    "försäkrandens": "försäkrande",
    "försäkrandes": "försäkrande",
    "försäkrandet": "försäkrande",
    "försäkrandets": "försäkrande",
    "försäkrans": "försäkran",
    "försäkrar": "försäkra",
    "försäkras": "försäkra",
    "försäkrat": "försäkra",
    "försäkrats": "försäkra",
    "försäkringar": "försäkring",
    "försäkringarna": "försäkring",
    "försäkringarnas": "försäkring",
    "försäkringars": "försäkring",
    "försäkringen": "försäkring",
    "försäkringens": "försäkring",
    "försäkrings": "försäkring",
    "försäkringsagenten": "försäkringsagent",
    "försäkringsagentens": "försäkringsagent",
    "försäkringsagenter": "försäkringsagent",
    "försäkringsagenterna": "försäkringsagent",
    "försäkringsagenternas": "försäkringsagent",
    "försäkringsagenters": "försäkringsagent",
    "försäkringsagents": "försäkringsagent",
    "försäkringsbedrägerier": "försäkringsbedrägeri",
    "försäkringsbedrägerierna": "försäkringsbedrägeri",
    "försäkringsbedrägeriernas": "försäkringsbedrägeri",
    "försäkringsbedrägeriers": "försäkringsbedrägeri",
    "försäkringsbedrägeriet": "försäkringsbedrägeri",
    "försäkringsbedrägeriets": "försäkringsbedrägeri",
    "försäkringsbedrägeris": "försäkringsbedrägeri",
    "försäkringsbedrägerit": "försäkringsbedrägeri",
    "försäkringsbedrägerits": "försäkringsbedrägeri",
    "försäkringsbeskeden": "försäkringsbesked",
    "försäkringsbeskedens": "försäkringsbesked",
    "försäkringsbeskedet": "försäkringsbesked",
    "försäkringsbeskedets": "försäkringsbesked",
    "försäkringsbeskeds": "försäkringsbesked",
    "försäkringsbolagen": "försäkringsbolag",
    "försäkringsbolagens": "försäkringsbolag",
    "försäkringsbolaget": "försäkringsbolag",
    "försäkringsbolagets": "försäkringsbolag",
    "försäkringsbolags": "försäkringsbolag",
    "försäkringsbolagskontoren": "försäkringsbolagskontor",
    "försäkringsbolagskontorens": "försäkringsbolagskontor",
    "försäkringsbolagskontoret": "försäkringsbolagskontor",
    "försäkringsbolagskontorets": "försäkringsbolagskontor",
    "försäkringsbolagskontors": "försäkringsbolagskontor",
    "försäkringsbreven": "försäkringsbrev",
    "försäkringsbrevens": "försäkringsbrev",
    "försäkringsbrevet": "försäkringsbrev",
    "försäkringsbrevets": "försäkringsbrev",
    "försäkringsbrevs": "försäkringsbrev",
    "försäkringsgivar": "försäkringsgivare",
    "försäkringsgivaren": "försäkringsgivare",
    "försäkringsgivarens": "försäkringsgivare",
    "försäkringsgivares": "försäkringsgivare",
    "försäkringsgivarna": "försäkringsgivare",
    "försäkringsgivarnas": "försäkringsgivare",
    "försäkringsinslagen": "försäkringsinslag",
    "försäkringsinslagens": "försäkringsinslag",
    "försäkringsinslaget": "försäkringsinslag",
    "försäkringsinslagets": "försäkringsinslag",
    "försäkringsinslags": "försäkringsinslag",
    "försäkringskassan": "försäkringskassa",
    "försäkringskassans": "försäkringskassa",
    "försäkringskassas": "försäkringskassa",
    "försäkringskasse": "försäkringskassa",
    "försäkringskassor": "försäkringskassa",
    "försäkringskassorna": "försäkringskassa",
    "försäkringskassornas": "försäkringskassa",
    "försäkringskassors": "försäkringskassa",
    "försäkringsmarknaden": "försäkringsmarknad",
    "försäkringsmarknadens": "försäkringsmarknad",
    "försäkringsmarknader": "försäkringsmarknad",
    "försäkringsmarknaderna": "försäkringsmarknad",
    "försäkringsmarknadernas": "försäkringsmarknad",
    "försäkringsmarknaders": "försäkringsmarknad",
    "försäkringsmarknads": "försäkringsmarknad",
    "försäkringsmässiga": "försäkringsmässig",
    "försäkringsmässigare": "försäkringsmässig",
    "försäkringsmässigares": "försäkringsmässig",
    "försäkringsmässigas": "försäkringsmässig",
    "försäkringsmässigast": "försäkringsmässig",
    "försäkringsmässigaste": "försäkringsmässig",
    "försäkringsmässigastes": "försäkringsmässig",
    "försäkringsmässigasts": "försäkringsmässig",
    "försäkringsmässige": "försäkringsmässig",
    "försäkringsmässiges": "försäkringsmässig",
    "försäkringsmässigs": "försäkringsmässig",
    "försäkringsmässigt": "försäkringsmässig",
    "försäkringsmässigts": "försäkringsmässig",
    "försäkringspengar": "försäkringspeng",
    "försäkringspengarna": "försäkringspeng",
    "försäkringspengarnas": "försäkringspeng",
    "försäkringspengars": "försäkringspeng",
    "försäkringspengen": "försäkringspeng",
    "försäkringspengens": "försäkringspeng",
    "försäkringspengs": "försäkringspeng",
    "försäkringspolisen": "försäkringspolis",
    "försäkringspolisens": "försäkringspolis",
    "försäkringspoliser": "försäkringspolis",
    "försäkringspoliserna": "försäkringspolis",
    "försäkringspolisernas": "försäkringspolis",
    "försäkringspolisers": "försäkringspolis",
    "försäkringspremien": "försäkringspremie",
    "försäkringspremiens": "försäkringspremie",
    "försäkringspremier": "försäkringspremie",
    "försäkringspremierna": "försäkringspremie",
    "försäkringspremiernas": "försäkringspremie",
    "försäkringspremiers": "försäkringspremie",
    "försäkringspremies": "försäkringspremie",
    "försäkringsskydden": "försäkringsskydd",
    "försäkringsskyddens": "försäkringsskydd",
    "försäkringsskyddet": "försäkringsskydd",
    "försäkringsskyddets": "försäkringsskydd",
    "försäkringsskydds": "försäkringsskydd",
    "försäkringssystemen": "försäkringssystem",
    "försäkringssystemens": "försäkringssystem",
    "försäkringssystemet": "försäkringssystem",
    "försäkringssystemets": "försäkringssystem",
    "försäkringssystems": "försäkringssystem",
    "försäkringsvillkoren": "försäkringsvillkor",
    "försäkringsvillkorens": "försäkringsvillkor",
    "försäkringsvillkoret": "försäkringsvillkor",
    "försäkringsvillkorets": "försäkringsvillkor",
    "försäkringsvillkors": "försäkringsvillkor",
    "försälj": "försälja",
    "försäljande": "försälja",
    "försäljanden": "försäljande",
    "försäljandena": "försäljande",
    "försäljandenas": "försäljande",
    "försäljandens": "försäljande",
    "försäljandes": "försäljande",
    "försäljandet": "försäljande",
    "försäljandets": "försäljande",
    "försäljar": "försäljare",
    "försäljaren": "försäljare",
    "försäljarens": "försäljare",
    "försäljares": "försäljare",
    "försäljarna": "försäljare",
    "försäljarnas": "försäljare",
    "försäljas": "försälja",
    "försäljer": "försälja",
    "försäljes": "försälja",
    "försäljningar": "försäljning",
    "försäljningarna": "försäljning",
    "försäljningarnas": "försäljning",
    "försäljningars": "försäljning",
    "försäljningen": "försäljning",
    "försäljningens": "försäljning",
    "försäljnings": "försäljning",
    "försäljningsbranschen": "försäljningsbransch",
    "försäljningsbranschens": "försäljningsbransch",
    "försäljningsbranscher": "försäljningsbransch",
    "försäljningsbranscherna": "försäljningsbransch",
    "försäljningsbranschernas": "försäljningsbransch",
    "försäljningsbranschers": "försäljningsbransch",
    "försäljningsbranschs": "försäljningsbransch",
    "försäljningschefen": "försäljningschef",
    "försäljningschefens": "försäljningschef",
    "försäljningschefer": "försäljningschef",
    "försäljningscheferna": "försäljningschef",
    "försäljningschefernas": "försäljningschef",
    "försäljningschefers": "försäljningschef",
    "försäljningschefs": "försäljningschef",
    "försäljningsdiskar": "försäljningsdisk",
    "försäljningsdiskarna": "försäljningsdisk",
    "försäljningsdiskarnas": "försäljningsdisk",
    "försäljningsdiskars": "försäljningsdisk",
    "försäljningsdisken": "försäljningsdisk",
    "försäljningsdiskens": "försäljningsdisk",
    "försäljningsdisks": "försäljningsdisk",
    "försäljningsleden": "försäljningsled",
    "försäljningsledens": "försäljningsled",
    "försäljningsleder": "försäljningsled",
    "försäljningslederna": "försäljningsled",
    "försäljningsledernas": "försäljningsled",
    "försäljningsleders": "försäljningsled",
    "försäljningsledet": "försäljningsled",
    "försäljningsledets": "försäljningsled",
    "försäljningsleds": "försäljningsled",
    "försäljningsmässiga": "försäljningsmässig",
    "försäljningsmässigare": "försäljningsmässig",
    "försäljningsmässigares": "försäljningsmässig",
    "försäljningsmässigas": "försäljningsmässig",
    "försäljningsmässigast": "försäljningsmässig",
    "försäljningsmässigaste": "försäljningsmässig",
    "försäljningsmässigastes": "försäljningsmässig",
    "försäljningsmässigasts": "försäljningsmässig",
    "försäljningsmässige": "försäljningsmässig",
    "försäljningsmässiges": "försäljningsmässig",
    "försäljningsmässigs": "försäljningsmässig",
    "försäljningsmässigt": "försäljningsmässig",
    "försäljningsmässigts": "försäljningsmässig",
    "försäljningsorten": "försäljningsort",
    "försäljningsortens": "försäljningsort",
    "försäljningsorter": "försäljningsort",
    "försäljningsorterna": "försäljningsort",
    "försäljningsorternas": "försäljningsort",
    "försäljningsorters": "försäljningsort",
    "försäljningsorts": "försäljningsort",
    "försäljningsprisen": "försäljningspris",
    "försäljningsprisens": "försäljningspris",
    "försäljningspriser": "försäljningspris",
    "försäljningspriserna": "försäljningspris",
    "försäljningsprisernas": "försäljningspris",
    "försäljningsprisers": "försäljningspris",
    "försäljningspriset": "försäljningspris",
    "försäljningsprisets": "försäljningspris",
    "försäljningsstoppen": "försäljningsstopp",
    "försäljningsstoppens": "försäljningsstopp",
    "försäljningsstoppet": "försäljningsstopp",
    "försäljningsstoppets": "försäljningsstopp",
    "försäljningsstopps": "försäljningsstopp",
    "försäljningsstånden": "försäljningsstånd",
    "försäljningsståndens": "försäljningsstånd",
    "försäljningsståndet": "försäljningsstånd",
    "försäljningsståndets": "försäljningsstånd",
    "försäljningsstånds": "försäljningsstånd",
    "försäljningssuccéer": "försäljningssuccé",
    "försäljningssuccéerna": "försäljningssuccé",
    "försäljningssuccéernas": "försäljningssuccé",
    "försäljningssuccéers": "försäljningssuccé",
    "försäljningssuccén": "försäljningssuccé",
    "försäljningssuccéns": "försäljningssuccé",
    "försäljningssuccés": "försäljningssuccé",
    "försäljningsvanan": "försäljningsvana",
    "försäljningsvanans": "försäljningsvana",
    "försäljningsvanas": "försäljningsvana",
    "försäljningsvane": "försäljningsvana",
    "försäljningsvanor": "försäljningsvana",
    "försäljningsvanorna": "försäljningsvana",
    "försäljningsvanornas": "försäljningsvana",
    "försäljningsvanors": "försäljningsvana",
    "försäljningsvinsten": "försäljningsvinst",
    "försäljningsvinstens": "försäljningsvinst",
    "försäljningsvinster": "försäljningsvinst",
    "försäljningsvinsterna": "försäljningsvinst",
    "försäljningsvinsternas": "försäljningsvinst",
    "försäljningsvinsters": "försäljningsvinst",
    "försäljningsvinsts": "försäljningsvinst",
    "försäljs": "försälja",
    "försämrad": "försämra",
    "försämrade": "försämra",
    "försämrades": "försämra",
    "försämrads": "försämra",
    "försämrande": "försämra",
    "försämranden": "försämrande",
    "försämrandena": "försämrande",
    "försämrandenas": "försämrande",
    "försämrandens": "försämrande",
    "försämrandes": "försämrande",
    "försämrandet": "försämrande",
    "försämrandets": "försämrande",
    "försämrar": "försämra",
    "försämras": "försämra",
    "försämrat": "försämra",
    "försämrats": "försämra",
    "försämringar": "försämring",
    "försämringarna": "försämring",
    "försämringarnas": "försämring",
    "försämringars": "försämring",
    "försämringen": "försämring",
    "försämringens": "försämring",
    "försämrings": "försämring",
    "försänd": "försända",
    "försändande": "försända",
    "försändanden": "försändande",
    "försändandena": "försändande",
    "försändandenas": "försändande",
    "försändandens": "försändande",
    "försändandes": "försändande",
    "försändandet": "försändande",
    "försändandets": "försändande",
    "försändas": "försända",
    "försände": "försända",
    "försändelsen": "försändelse",
    "försändelsens": "försändelse",
    "försändelser": "försändelse",
    "försändelserna": "försändelse",
    "försändelsernas": "försändelse",
    "försändelsers": "försändelse",
    "försändelses": "försändelse",
    "försänder": "försända",
    "försändes": "försända",
    "försänds": "försända",
    "försänk": "försänka",
    "försänkande": "försänka",
    "försänkanden": "försänkande",
    "försänkandena": "försänkande",
    "försänkandenas": "försänkande",
    "försänkandens": "försänkande",
    "försänkandes": "försänkande",
    "försänkandet": "försänkande",
    "försänkandets": "försänkande",
    "försänkar": "försänkare",
    "försänkaren": "försänkare",
    "försänkarens": "försänkare",
    "försänkares": "försänkare",
    "försänkarna": "försänkare",
    "försänkarnas": "försänkare",
    "försänkas": "försänka",
    "försänker": "försänka",
    "försänkes": "försänka",
    "försänkningar": "försänkning",
    "försänkningarna": "försänkning",
    "försänkningarnas": "försänkning",
    "försänkningars": "försänkning",
    "försänkningen": "försänkning",
    "försänkningens": "försänkning",
    "försänknings": "försänkning",
    "försänks": "försänka",
    "försänkt": "försänka",
    "försänkta": "försänka",
    "försänktas": "försänka",
    "försänkte": "försänka",
    "försänktes": "försänka",
    "försänkts": "försänka",
    "försänt": "försända",
    "försänts": "försända",
    "försätt": "försätta",
    "försättande": "försätta",
    "försättanden": "försättande",
    "försättandena": "försättande",
    "försättandenas": "försättande",
    "försättandens": "försättande",
    "försättandes": "försättande",
    "försättandet": "försättande",
    "försättandets": "försättande",
    "försättas": "försätta",
    "försätter": "försätta",
    "försättes": "försätta",
    "försätts": "försätta",
    "försättsbladen": "försättsblad",
    "försättsbladens": "försättsblad",
    "försättsbladet": "försättsblad",
    "försättsbladets": "försättsblad",
    "försättsblads": "försättsblad",
    "försättslinsen": "försättslins",
    "försättslinsens": "försättslins",
    "försättslinser": "försättslins",
    "försättslinserna": "försättslins",
    "försättslinsernas": "försättslins",
    "försättslinsers": "försättslins",
    "försåg": "förse",
    "försågs": "förse",
    "försåld": "försälja",
    "försålda": "försälja",
    "försåldas": "försälja",
    "försålde": "försälja",
    "försåldes": "försälja",
    "försålds": "försälja",
    "försålt": "försälja",
    "försålts": "försälja",
    "försåpningar": "försåpning",
    "försåpningarna": "försåpning",
    "försåpningarnas": "försåpning",
    "försåpningars": "försåpning",
    "försåpningen": "försåpning",
    "försåpningens": "försåpning",
    "försåpnings": "försåpning",
    "försåten": "försåt",
    "försåtens": "försåt",
    "försåtet": "försåt",
    "försåtets": "försåt",
    "försåtliga": "försåtlig",
    "försåtligare": "försåtlig",
    "försåtligares": "försåtlig",
    "försåtligas": "försåtlig",
    "försåtligast": "försåtlig",
    "försåtligaste": "försåtlig",
    "försåtligastes": "försåtlig",
    "försåtligasts": "försåtlig",
    "försåtlige": "försåtlig",
    "försåtliges": "försåtlig",
    "försåtligheten": "försåtlighet",
    "försåtlighetens": "försåtlighet",
    "försåtligheter": "försåtlighet",
    "försåtligheterna": "försåtlighet",
    "försåtligheternas": "försåtlighet",
    "försåtligheters": "försåtlighet",
    "försåtlighets": "försåtlighet",
    "försåtligs": "försåtlig",
    "försåtligt": "försåtlig",
    "försåtligts": "försåtlig",
    "försåts": "försåt",
    "försök": "försöka",
    "försökande": "försöka",
    "försökanden": "försökande",
    "försökandena": "försökande",
    "försökandenas": "försökande",
    "försökandens": "försökande",
    "försökandes": "försökande",
    "försökandet": "försökande",
    "försökandets": "försökande",
    "försökas": "försöka",
    "försöken": "försök",
    "försökens": "försök",
    "försöker": "försöka",
    "försökes": "försöka",
    "försöket": "försök",
    "försökets": "försök",
    "försöks": "försöka",
    "försöksballongen": "försöksballong",
    "försöksballongens": "försöksballong",
    "försöksballonger": "försöksballong",
    "försöksballongerna": "försöksballong",
    "försöksballongernas": "försöksballong",
    "försöksballongers": "försöksballong",
    "försöksballongs": "försöksballong",
    "försöksdammar": "försöksdamm",
    "försöksdammarna": "försöksdamm",
    "försöksdammarnas": "försöksdamm",
    "försöksdammars": "försöksdamm",
    "försöksdammen": "försöksdamm",
    "försöksdammens": "försöksdamm",
    "försöksdamms": "försöksdamm",
    "försöksdjuren": "försöksdjur",
    "försöksdjurens": "försöksdjur",
    "försöksdjuret": "försöksdjur",
    "försöksdjurets": "försöksdjur",
    "försöksdjurs": "försöksdjur",
    "försöksgymnasie": "försöksgymnasium",
    "försöksgymnasier": "försöksgymnasium",
    "försöksgymnasierna": "försöksgymnasium",
    "försöksgymnasiernas": "försöksgymnasium",
    "försöksgymnasiers": "försöksgymnasium",
    "försöksgymnasiet": "försöksgymnasium",
    "försöksgymnasiets": "försöksgymnasium",
    "försöksgymnasiums": "försöksgymnasium",
    "försöksheaten": "försöksheat",
    "försöksheatens": "försöksheat",
    "försöksheatet": "försöksheat",
    "försöksheatets": "försöksheat",
    "försöksheats": "försöksheat",
    "försökskaninen": "försökskanin",
    "försökskaninens": "försökskanin",
    "försökskaniner": "försökskanin",
    "försökskaninerna": "försökskanin",
    "försökskaninernas": "försökskanin",
    "försökskaniners": "försökskanin",
    "försökskanins": "försökskanin",
    "försöksledar": "försöksledare",
    "försöksledaren": "försöksledare",
    "försöksledarens": "försöksledare",
    "försöksledares": "försöksledare",
    "försöksledarna": "försöksledare",
    "försöksledarnas": "försöksledare",
    "försöksobjekten": "försöksobjekt",
    "försöksobjektens": "försöksobjekt",
    "försöksobjektet": "försöksobjekt",
    "försöksobjektets": "försöksobjekt",
    "försöksobjekts": "försöksobjekt",
    "försökspersonen": "försöksperson",
    "försökspersonens": "försöksperson",
    "försökspersoner": "försöksperson",
    "försökspersonerna": "försöksperson",
    "försökspersonernas": "försöksperson",
    "försökspersoners": "försöksperson",
    "försökspersons": "försöksperson",
    "försöksverksamheten": "försöksverksamhet",
    "försöksverksamhetens": "försöksverksamhet",
    "försöksverksamheter": "försöksverksamhet",
    "försöksverksamheterna": "försöksverksamhet",
    "försöksverksamheternas": "försöksverksamhet",
    "försöksverksamheters": "försöksverksamhet",
    "försöksverksamhets": "försöksverksamhet",
    "försökt": "försöka",
    "försökte": "försöka",
    "försöktes": "försöka",
    "försökts": "försöka",
    "försörj": "försörja",
    "försörjande": "försörja",
    "försörjanden": "försörjande",
    "försörjandena": "försörjande",
    "försörjandenas": "försörjande",
    "försörjandens": "försörjande",
    "försörjandes": "försörjande",
    "försörjandet": "försörjande",
    "försörjandets": "försörjande",
    "försörjar": "försörjare",
    "försörjaren": "försörjare",
    "försörjarens": "försörjare",
    "försörjares": "försörjare",
    "försörjarna": "försörjare",
    "försörjarnas": "försörjare",
    "försörjas": "försörja",
    "försörjd": "försörja",
    "försörjda": "försörja",
    "försörjdas": "försörja",
    "försörjde": "försörja",
    "försörjdes": "försörja",
    "försörjds": "försörja",
    "försörjer": "försörja",
    "försörjes": "försörja",
    "försörjningar": "försörjning",
    "försörjningarna": "försörjning",
    "försörjningarnas": "försörjning",
    "försörjningars": "försörjning",
    "försörjningen": "försörjning",
    "försörjningens": "försörjning",
    "försörjnings": "försörjning",
    "försörjningsbalansen": "försörjningsbalans",
    "försörjningsbalansens": "försörjningsbalans",
    "försörjningsbördan": "försörjningsbörda",
    "försörjningsbördans": "försörjningsbörda",
    "försörjningsbördas": "försörjningsbörda",
    "försörjningsbörde": "försörjningsbörda",
    "försörjningsbördor": "försörjningsbörda",
    "försörjningsbördorna": "försörjningsbörda",
    "försörjningsbördornas": "försörjningsbörda",
    "försörjningsbördors": "försörjningsbörda",
    "försörjningsinrättningar": "försörjningsinrättning",
    "försörjningsinrättningarna": "försörjningsinrättning",
    "försörjningsinrättningarnas": "försörjningsinrättning",
    "försörjningsinrättningars": "försörjningsinrättning",
    "försörjningsinrättningen": "försörjningsinrättning",
    "försörjningsinrättningens": "försörjningsinrättning",
    "försörjningsinrättnings": "försörjningsinrättning",
    "försörjningsmässiga": "försörjningsmässig",
    "försörjningsmässigare": "försörjningsmässig",
    "försörjningsmässigares": "försörjningsmässig",
    "försörjningsmässigas": "försörjningsmässig",
    "försörjningsmässigast": "försörjningsmässig",
    "försörjningsmässigaste": "försörjningsmässig",
    "försörjningsmässigastes": "försörjningsmässig",
    "försörjningsmässigasts": "försörjningsmässig",
    "försörjningsmässige": "försörjningsmässig",
    "försörjningsmässiges": "försörjningsmässig",
    "försörjningsmässigs": "försörjningsmässig",
    "försörjningsmässigt": "försörjningsmässig",
    "försörjningsmässigts": "försörjningsmässig",
    "försörjningspolitiken": "försörjningspolitik",
    "försörjningspolitikens": "försörjningspolitik",
    "försörjningspolitiks": "försörjningspolitik",
    "försörjningspolitiska": "försörjningspolitisk",
    "försörjningspolitiskas": "försörjningspolitisk",
    "försörjningspolitiske": "försörjningspolitisk",
    "försörjningspolitiskes": "försörjningspolitisk",
    "försörjningspolitisks": "försörjningspolitisk",
    "försörjningspolitiskt": "försörjningspolitisk",
    "försörjningspolitiskts": "försörjningspolitisk",
    "försörjs": "försörja",
    "försörjt": "försörja",
    "försörjts": "försörja",
    "fört": "föra",
    "förtag": "förta",
    "förtaga": "förta",
    "förtagande": "förta",
    "förtaganden": "förtagande",
    "förtagandena": "förtagande",
    "förtagandenas": "förtagande",
    "förtagandens": "förtagande",
    "förtagandes": "förtagande",
    "förtagandet": "förtagande",
    "förtagandets": "förtagande",
    "förtagas": "förta",
    "förtage": "förta",
    "förtagen": "förta",
    "förtagens": "förta",
    "förtager": "förta",
    "förtages": "förta",
    "förtaget": "förta",
    "förtagets": "förta",
    "förtagit": "förta",
    "förtagits": "förta",
    "förtagna": "förta",
    "förtagnas": "förta",
    "förtagne": "förta",
    "förtagnes": "förta",
    "förtags": "förta",
    "förtal": "förtala",
    "förtalad": "förtala",
    "förtalade": "förtala",
    "förtalades": "förtala",
    "förtalads": "förtala",
    "förtalande": "förtala",
    "förtalanden": "förtalande",
    "förtalandena": "förtalande",
    "förtalandenas": "förtalande",
    "förtalandens": "förtalande",
    "förtalandes": "förtalande",
    "förtalandet": "förtalande",
    "förtalandets": "förtalande",
    "förtalar": "förtala",
    "förtalas": "förtala",
    "förtalat": "förtala",
    "förtalats": "förtala",
    "förtalde": "förtälja",
    "förtaldes": "förtälja",
    "förtalet": "förtal",
    "förtalets": "förtal",
    "förtals": "förtal",
    "förtalskampanjen": "förtalskampanj",
    "förtalskampanjens": "förtalskampanj",
    "förtalskampanjer": "förtalskampanj",
    "förtalskampanjerna": "förtalskampanj",
    "förtalskampanjernas": "förtalskampanj",
    "förtalskampanjers": "förtalskampanj",
    "förtalskampanjs": "förtalskampanj",
    "förtalsmålen": "förtalsmål",
    "förtalsmålens": "förtalsmål",
    "förtalsmålet": "förtalsmål",
    "förtalsmålets": "förtalsmål",
    "förtalsmåls": "förtalsmål",
    "förtalt": "förtälja",
    "förtalts": "förtälja",
    "förtappade": "förtappad",
    "förtappades": "förtappad",
    "förtappads": "förtappad",
    "förtappat": "förtappad",
    "förtappats": "förtappad",
    "förtappelsen": "förtappelse",
    "förtappelsens": "förtappelse",
    "förtappelses": "förtappelse",
    "förtar": "förta",
    "förtas": "förta",
    "förteckens": "förtecken",
    "förtecknad": "förteckna",
    "förtecknade": "förteckna",
    "förtecknades": "förteckna",
    "förtecknads": "förteckna",
    "förtecknande": "förteckna",
    "förtecknanden": "förtecknande",
    "förtecknandena": "förtecknande",
    "förtecknandenas": "förtecknande",
    "förtecknandens": "förtecknande",
    "förtecknandes": "förtecknande",
    "förtecknandet": "förtecknande",
    "förtecknandets": "förtecknande",
    "förtecknar": "förteckna",
    "förtecknas": "förteckna",
    "förtecknat": "förteckna",
    "förtecknats": "förteckna",
    "förtecknen": "förtecken",
    "förtecknens": "förtecken",
    "förtecknet": "förtecken",
    "förtecknets": "förtecken",
    "förteckningar": "förteckning",
    "förteckningarna": "förteckning",
    "förteckningarnas": "förteckning",
    "förteckningars": "förteckning",
    "förteckningen": "förteckning",
    "förteckningens": "förteckning",
    "förtecknings": "förteckning",
    "förteg": "förtiga",
    "förtegenheten": "förtegenhet",
    "förtegenhetens": "förtegenhet",
    "förtegenhets": "förtegenhet",
    "förtegens": "förtegen",
    "förteget": "förtegen",
    "förtegets": "förtegen",
    "förtegna": "förtegen",
    "förtegnare": "förtegen",
    "förtegnares": "förtegen",
    "förtegnas": "förtegen",
    "förtegnast": "förtegen",
    "förtegnaste": "förtegen",
    "förtegnastes": "förtegen",
    "förtegnasts": "förtegen",
    "förtegne": "förtegen",
    "förtegnes": "förtegen",
    "förtegs": "förtiga",
    "förtennad": "förtenna",
    "förtennade": "förtenna",
    "förtennades": "förtenna",
    "förtennads": "förtenna",
    "förtennande": "förtenna",
    "förtennanden": "förtennande",
    "förtennandena": "förtennande",
    "förtennandenas": "förtennande",
    "förtennandens": "förtennande",
    "förtennandes": "förtennande",
    "förtennandet": "förtennande",
    "förtennandets": "förtennande",
    "förtennar": "förtenna",
    "förtennas": "förtenna",
    "förtennat": "förtenna",
    "förtennats": "förtenna",
    "förtenta": "förtent",
    "förtentas": "förtent",
    "förtente": "förtent",
    "förtentes": "förtent",
    "förtents": "förtent",
    "förtidsbörden": "förtidsbörd",
    "förtidsbördens": "förtidsbörd",
    "förtidsbörder": "förtidsbörd",
    "förtidsbörderna": "förtidsbörd",
    "förtidsbördernas": "förtidsbörd",
    "förtidsbörders": "förtidsbörd",
    "förtidsbörds": "förtidsbörd",
    "förtidspensionen": "förtidspension",
    "förtidspensionens": "förtidspension",
    "förtidspensioner": "förtidspension",
    "förtidspensionerad": "förtidspensionera",
    "förtidspensionerade": "förtidspensionera",
    "förtidspensionerades": "förtidspensionera",
    "förtidspensionerads": "förtidspensionera",
    "förtidspensionerande": "förtidspensionera",
    "förtidspensioneranden": "förtidspensionerande",
    "förtidspensionerandena": "förtidspensionerande",
    "förtidspensionerandenas": "förtidspensionerande",
    "förtidspensionerandens": "förtidspensionerande",
    "förtidspensionerandes": "förtidspensionerande",
    "förtidspensionerandet": "förtidspensionerande",
    "förtidspensionerandets": "förtidspensionerande",
    "förtidspensionerar": "förtidspensionera",
    "förtidspensioneras": "förtidspensionera",
    "förtidspensionerat": "förtidspensionera",
    "förtidspensionerats": "förtidspensionera",
    "förtidspensionerbara": "förtidspensionerbar",
    "förtidspensionerbarare": "förtidspensionerbar",
    "förtidspensionerbarares": "förtidspensionerbar",
    "förtidspensionerbaras": "förtidspensionerbar",
    "förtidspensionerbarast": "förtidspensionerbar",
    "förtidspensionerbaraste": "förtidspensionerbar",
    "förtidspensionerbarastes": "förtidspensionerbar",
    "förtidspensionerbarasts": "förtidspensionerbar",
    "förtidspensionerbare": "förtidspensionerbar",
    "förtidspensionerbares": "förtidspensionerbar",
    "förtidspensionerbarheten": "förtidspensionerbarhet",
    "förtidspensionerbarhetens": "förtidspensionerbarhet",
    "förtidspensionerbarhets": "förtidspensionerbarhet",
    "förtidspensionerbars": "förtidspensionerbar",
    "förtidspensionerbart": "förtidspensionerbar",
    "förtidspensionerbarts": "förtidspensionerbar",
    "förtidspensioneringar": "förtidspensionering",
    "förtidspensioneringarna": "förtidspensionering",
    "förtidspensioneringarnas": "förtidspensionering",
    "förtidspensioneringars": "förtidspensionering",
    "förtidspensioneringen": "förtidspensionering",
    "förtidspensioneringens": "förtidspensionering",
    "förtidspensionerings": "förtidspensionering",
    "förtidspensionerna": "förtidspension",
    "förtidspensionernas": "förtidspension",
    "förtidspensioners": "förtidspension",
    "förtidspensions": "förtidspension",
    "förtidsröstningar": "förtidsröstning",
    "förtidsröstningarna": "förtidsröstning",
    "förtidsröstningarnas": "förtidsröstning",
    "förtidsröstningars": "förtidsröstning",
    "förtidsröstningen": "förtidsröstning",
    "förtidsröstningens": "förtidsröstning",
    "förtidsröstnings": "förtidsröstning",
    "förtig": "förtiga",
    "förtigande": "förtiga",
    "förtiganden": "förtigande",
    "förtigandena": "förtigande",
    "förtigandenas": "förtigande",
    "förtigandens": "förtigande",
    "förtigandes": "förtigande",
    "förtigandet": "förtigande",
    "förtigandets": "förtigande",
    "förtigas": "förtiga",
    "förtige": "förtiga",
    "förtiger": "förtiga",
    "förtiges": "förtiga",
    "förtigit": "förtiga",
    "förtigits": "förtiga",
    "förtigs": "förtiga",
    "förtimringar": "förtimring",
    "förtimringarna": "förtimring",
    "förtimringarnas": "förtimring",
    "förtimringars": "förtimring",
    "förtimringen": "förtimring",
    "förtimringens": "förtimring",
    "förtimrings": "förtimring",
    "förtingligandes": "förtingligande",
    "förtingligandet": "förtingligande",
    "förtingligandets": "förtingligande",
    "förtis": "förti",
    "förtjock": "förtjocka",
    "förtjockad": "förtjocka",
    "förtjockade": "förtjocka",
    "förtjockades": "förtjocka",
    "förtjockads": "förtjocka",
    "förtjockande": "förtjocka",
    "förtjockanden": "förtjockande",
    "förtjockandena": "förtjockande",
    "förtjockandenas": "förtjockande",
    "förtjockandens": "förtjockande",
    "förtjockandes": "förtjockande",
    "förtjockandet": "förtjockande",
    "förtjockandets": "förtjockande",
    "förtjockar": "förtjocka",
    "förtjockas": "förtjocka",
    "förtjockat": "förtjocka",
    "förtjockats": "förtjocka",
    "förtjocknade": "förtjocknad",
    "förtjocknades": "förtjocknad",
    "förtjocknads": "förtjocknad",
    "förtjocknat": "förtjocknad",
    "förtjocknats": "förtjocknad",
    "förtjus": "förtjusa",
    "förtjusande": "förtjusa",
    "förtjusanden": "förtjusande",
    "förtjusandena": "förtjusande",
    "förtjusandenas": "förtjusande",
    "förtjusandens": "förtjusande",
    "förtjusandes": "förtjusande",
    "förtjusandet": "förtjusande",
    "förtjusandets": "förtjusande",
    "förtjusas": "förtjusa",
    "förtjuser": "förtjusa",
    "förtjuses": "förtjusa",
    "förtjusningar": "förtjusning",
    "förtjusningarna": "förtjusning",
    "förtjusningarnas": "förtjusning",
    "förtjusningars": "förtjusning",
    "förtjusningen": "förtjusning",
    "förtjusningens": "förtjusning",
    "förtjusnings": "förtjusning",
    "förtjust": "förtjusa",
    "förtjusta": "förtjust",
    "förtjustare": "förtjust",
    "förtjustares": "förtjust",
    "förtjustas": "förtjust",
    "förtjustast": "förtjust",
    "förtjustaste": "förtjust",
    "förtjustastes": "förtjust",
    "förtjustasts": "förtjust",
    "förtjuste": "förtjust",
    "förtjustes": "förtjust",
    "förtjusts": "förtjust",
    "förtjän": "förtjäna",
    "förtjänad": "förtjäna",
    "förtjänade": "förtjäna",
    "förtjänades": "förtjäna",
    "förtjänads": "förtjäna",
    "förtjänande": "förtjäna",
    "förtjänanden": "förtjänande",
    "förtjänandena": "förtjänande",
    "förtjänandenas": "förtjänande",
    "förtjänandens": "förtjänande",
    "förtjänandes": "förtjänande",
    "förtjänandet": "förtjänande",
    "förtjänandets": "förtjänande",
    "förtjänar": "förtjäna",
    "förtjänas": "förtjäna",
    "förtjänat": "förtjäna",
    "förtjänats": "förtjäna",
    "förtjänsten": "förtjänst",
    "förtjänstens": "förtjänst",
    "förtjänster": "förtjänst",
    "förtjänsterna": "förtjänst",
    "förtjänsternas": "förtjänst",
    "förtjänsters": "förtjänst",
    "förtjänstfulla": "förtjänstfull",
    "förtjänstfullare": "förtjänstfull",
    "förtjänstfullares": "förtjänstfull",
    "förtjänstfullas": "förtjänstfull",
    "förtjänstfullast": "förtjänstfull",
    "förtjänstfullaste": "förtjänstfull",
    "förtjänstfullastes": "förtjänstfull",
    "förtjänstfullasts": "förtjänstfull",
    "förtjänstfulle": "förtjänstfull",
    "förtjänstfulles": "förtjänstfull",
    "förtjänstfullheten": "förtjänstfullhet",
    "förtjänstfullhetens": "förtjänstfullhet",
    "förtjänstfullhets": "förtjänstfullhet",
    "förtjänstfulls": "förtjänstfull",
    "förtjänstfullt": "förtjänstfull",
    "förtjänstfullts": "förtjänstfull",
    "förtjänsts": "förtjänst",
    "förtjänstteckens": "förtjänsttecken",
    "förtjänsttecknen": "förtjänsttecken",
    "förtjänsttecknens": "förtjänsttecken",
    "förtjänsttecknet": "förtjänsttecken",
    "förtjänsttecknets": "förtjänsttecken",
    "förtjänta": "förtjänt",
    "förtjäntare": "förtjänt",
    "förtjäntares": "förtjänt",
    "förtjäntas": "förtjänt",
    "förtjäntast": "förtjänt",
    "förtjäntaste": "förtjänt",
    "förtjäntastes": "förtjänt",
    "förtjäntasts": "förtjänt",
    "förtjänte": "förtjänt",
    "förtjäntes": "förtjänt",
    "förtjänts": "förtjänt",
    "förtog": "förta",
    "förtoge": "förta",
    "förtoges": "förta",
    "förtogs": "förta",
    "förtonade": "förtona",
    "förtonades": "förtona",
    "förtonande": "förtona",
    "förtonanden": "förtonande",
    "förtonandena": "förtonande",
    "förtonandenas": "förtonande",
    "förtonandens": "förtonande",
    "förtonandes": "förtonande",
    "förtonandet": "förtonande",
    "förtonandets": "förtonande",
    "förtonar": "förtona",
    "förtonas": "förtona",
    "förtonat": "förtona",
    "förtonats": "förtona",
    "förtoningar": "förtoning",
    "förtoningarna": "förtoning",
    "förtoningarnas": "förtoning",
    "förtoningars": "förtoning",
    "förtoningen": "förtoning",
    "förtoningens": "förtoning",
    "förtonings": "förtoning",
    "förtork": "förtorka",
    "förtorkad": "förtorka",
    "förtorkade": "förtorka",
    "förtorkades": "förtorka",
    "förtorkads": "förtorka",
    "förtorkande": "förtorka",
    "förtorkanden": "förtorkande",
    "förtorkandena": "förtorkande",
    "förtorkandenas": "förtorkande",
    "förtorkandens": "förtorkande",
    "förtorkandes": "förtorkande",
    "förtorkandet": "förtorkande",
    "förtorkandets": "förtorkande",
    "förtorkar": "förtorka",
    "förtorkas": "förtorka",
    "förtorkat": "förtorka",
    "förtorkats": "förtorka",
    "förtramp": "förtrampa",
    "förtrampad": "förtrampa",
    "förtrampade": "förtrampa",
    "förtrampades": "förtrampa",
    "förtrampads": "förtrampa",
    "förtrampande": "förtrampa",
    "förtrampanden": "förtrampande",
    "förtrampandena": "förtrampande",
    "förtrampandenas": "förtrampande",
    "förtrampandens": "förtrampande",
    "förtrampandes": "förtrampande",
    "förtrampandet": "förtrampande",
    "förtrampandets": "förtrampande",
    "förtrampar": "förtrampa",
    "förtrampas": "förtrampa",
    "förtrampat": "förtrampa",
    "förtrampats": "förtrampa",
    "förtret": "förtreta",
    "förtretad": "förtreta",
    "förtretade": "förtreta",
    "förtretades": "förtreta",
    "förtretads": "förtreta",
    "förtretande": "förtreta",
    "förtretanden": "förtretande",
    "förtretandena": "förtretande",
    "förtretandenas": "förtretande",
    "förtretandens": "förtretande",
    "förtretandes": "förtretande",
    "förtretandet": "förtretande",
    "förtretandets": "förtretande",
    "förtretar": "förtreta",
    "förtretas": "förtreta",
    "förtretat": "förtreta",
    "förtretats": "förtreta",
    "förtreten": "förtret",
    "förtretens": "förtret",
    "förtretliga": "förtretlig",
    "förtretligare": "förtretlig",
    "förtretligares": "förtretlig",
    "förtretligas": "förtretlig",
    "förtretligast": "förtretlig",
    "förtretligaste": "förtretlig",
    "förtretligastes": "förtretlig",
    "förtretligasts": "förtretlig",
    "förtretlige": "förtretlig",
    "förtretliges": "förtretlig",
    "förtretligheten": "förtretlighet",
    "förtretlighetens": "förtretlighet",
    "förtretligheter": "förtretlighet",
    "förtretligheterna": "förtretlighet",
    "förtretligheternas": "förtretlighet",
    "förtretligheters": "förtretlighet",
    "förtretlighets": "förtretlighet",
    "förtretligs": "förtretlig",
    "förtretligt": "förtretlig",
    "förtretligts": "förtretlig",
    "förtrets": "förtret",
    "förtrodd": "förtro",
    "förtrodda": "förtro",
    "förtroddas": "förtro",
    "förtrodde": "förtro",
    "förtroddes": "förtro",
    "förtrodds": "förtro",
    "förtroende": "förtro",
    "förtroendearbetstiden": "förtroendearbetstid",
    "förtroendearbetstidens": "förtroendearbetstid",
    "förtroendearbetstids": "förtroendearbetstid",
    "förtroendefrågan": "förtroendefråga",
    "förtroendefrågans": "förtroendefråga",
    "förtroendefrågas": "förtroendefråga",
    "förtroendefråge": "förtroendefråga",
    "förtroendefrågor": "förtroendefråga",
    "förtroendefrågorna": "förtroendefråga",
    "förtroendefrågornas": "förtroendefråga",
    "förtroendefrågors": "förtroendefråga",
    "förtroendefulla": "förtroendefull",
    "förtroendefullare": "förtroendefull",
    "förtroendefullares": "förtroendefull",
    "förtroendefullas": "förtroendefull",
    "förtroendefullast": "förtroendefull",
    "förtroendefullaste": "förtroendefull",
    "förtroendefullastes": "förtroendefull",
    "förtroendefullasts": "förtroendefull",
    "förtroendefulle": "förtroendefull",
    "förtroendefulles": "förtroendefull",
    "förtroendefullheten": "förtroendefullhet",
    "förtroendefullhetens": "förtroendefullhet",
    "förtroendefullhets": "förtroendefullhet",
    "förtroendefulls": "förtroendefull",
    "förtroendefullt": "förtroendefull",
    "förtroendefullts": "förtroendefull",
    "förtroendeklyftan": "förtroendeklyfta",
    "förtroendeklyftans": "förtroendeklyfta",
    "förtroendeklyftas": "förtroendeklyfta",
    "förtroendeklyfte": "förtroendeklyfta",
    "förtroendeklyftor": "förtroendeklyfta",
    "förtroendeklyftorna": "förtroendeklyfta",
    "förtroendeklyftornas": "förtroendeklyfta",
    "förtroendeklyftors": "förtroendeklyfta",
    "förtroendekrisen": "förtroendekris",
    "förtroendekrisens": "förtroendekris",
    "förtroendekriser": "förtroendekris",
    "förtroendekriserna": "förtroendekris",
    "förtroendekrisernas": "förtroendekris",
    "förtroendekrisers": "förtroendekris",
    "förtroendemannen": "förtroendeman",
    "förtroendemannens": "förtroendeman",
    "förtroendemans": "förtroendeman",
    "förtroendemän": "förtroendeman",
    "förtroendemännen": "förtroendeman",
    "förtroendemännens": "förtroendeman",
    "förtroendemäns": "förtroendeman",
    "förtroendemässiga": "förtroendemässig",
    "förtroendemässigare": "förtroendemässig",
    "förtroendemässigares": "förtroendemässig",
    "förtroendemässigas": "förtroendemässig",
    "förtroendemässigast": "förtroendemässig",
    "förtroendemässigaste": "förtroendemässig",
    "förtroendemässigastes": "förtroendemässig",
    "förtroendemässigasts": "förtroendemässig",
    "förtroendemässige": "förtroendemässig",
    "förtroendemässiges": "förtroendemässig",
    "förtroendemässigs": "förtroendemässig",
    "förtroendemässigt": "förtroendemässig",
    "förtroendemässigts": "förtroendemässig",
    "förtroendemätningar": "förtroendemätning",
    "förtroendemätningarna": "förtroendemätning",
    "förtroendemätningarnas": "förtroendemätning",
    "förtroendemätningars": "förtroendemätning",
    "förtroendemätningen": "förtroendemätning",
    "förtroendemätningens": "förtroendemätning",
    "förtroendemätnings": "förtroendemätning",
    "förtroenden": "förtroende",
    "förtroendena": "förtroende",
    "förtroendenas": "förtroende",
    "förtroendens": "förtroende",
    "förtroenderåden": "förtroenderåd",
    "förtroenderådens": "förtroenderåd",
    "förtroenderådet": "förtroenderåd",
    "förtroenderådets": "förtroenderåd",
    "förtroenderåds": "förtroenderåd",
    "förtroendes": "förtroende",
    "förtroendet": "förtroende",
    "förtroendets": "förtroende",
    "förtroendeuppdragen": "förtroendeuppdrag",
    "förtroendeuppdragens": "förtroendeuppdrag",
    "förtroendeuppdraget": "förtroendeuppdrag",
    "förtroendeuppdragets": "förtroendeuppdrag",
    "förtroendeuppdrags": "förtroendeuppdrag",
    "förtroendevalda": "förtroendevald",
    "förtroendevaldare": "förtroendevald",
    "förtroendevaldares": "förtroendevald",
    "förtroendevaldas": "förtroendevald",
    "förtroendevaldast": "förtroendevald",
    "förtroendevaldaste": "förtroendevald",
    "förtroendevaldastes": "förtroendevald",
    "förtroendevaldasts": "förtroendevald",
    "förtroendevalde": "förtroendevald",
    "förtroendevaldes": "förtroendevald",
    "förtroendevalds": "förtroendevald",
    "förtroendevalt": "förtroendevald",
    "förtroendevalts": "förtroendevald",
    "förtroendevota": "förtroendevotum",
    "förtroendevotana": "förtroendevotum",
    "förtroendevotanas": "förtroendevotum",
    "förtroendevotas": "förtroendevotum",
    "förtroendevotumen": "förtroendevotum",
    "förtroendevotumens": "förtroendevotum",
    "förtroendevotumet": "förtroendevotum",
    "förtroendevotumets": "förtroendevotum",
    "förtroendevotums": "förtroendevotum",
    "förtrogenheten": "förtrogenhet",
    "förtrogenhetens": "förtrogenhet",
    "förtrogenheter": "förtrogenhet",
    "förtrogenheterna": "förtrogenhet",
    "förtrogenheternas": "förtrogenhet",
    "förtrogenheters": "förtrogenhet",
    "förtrogenhets": "förtrogenhet",
    "förtrogens": "förtrogen",
    "förtroget": "förtrogen",
    "förtrogets": "förtrogen",
    "förtrogna": "förtrogen",
    "förtrognare": "förtrogen",
    "förtrognares": "förtrogen",
    "förtrognas": "förtrogen",
    "förtrognast": "förtrogen",
    "förtrognaste": "förtrogen",
    "förtrognastes": "förtrogen",
    "förtrognasts": "förtrogen",
    "förtrogne": "förtrogen",
    "förtrognes": "förtrogen",
    "förtroliga": "förtrolig",
    "förtroligare": "förtrolig",
    "förtroligares": "förtrolig",
    "förtroligas": "förtrolig",
    "förtroligast": "förtrolig",
    "förtroligaste": "förtrolig",
    "förtroligastes": "förtrolig",
    "förtroligasts": "förtrolig",
    "förtrolige": "förtrolig",
    "förtroliges": "förtrolig",
    "förtroligheten": "förtrolighet",
    "förtrolighetens": "förtrolighet",
    "förtroligheter": "förtrolighet",
    "förtroligheterna": "förtrolighet",
    "förtroligheternas": "förtrolighet",
    "förtroligheters": "förtrolighet",
    "förtrolighets": "förtrolighet",
    "förtroligs": "förtrolig",
    "förtroligt": "förtrolig",
    "förtroligts": "förtrolig",
    "förtroll": "förtrolla",
    "förtrollad": "förtrolla",
    "förtrollade": "förtrolla",
    "förtrollades": "förtrolla",
    "förtrollads": "förtrolla",
    "förtrollande": "förtrolla",
    "förtrollanden": "förtrollande",
    "förtrollandena": "förtrollande",
    "förtrollandenas": "förtrollande",
    "förtrollandens": "förtrollande",
    "förtrollandes": "förtrollande",
    "förtrollandet": "förtrollande",
    "förtrollandets": "förtrollande",
    "förtrollar": "förtrolla",
    "förtrollas": "förtrolla",
    "förtrollat": "förtrolla",
    "förtrollats": "förtrolla",
    "förtrollningar": "förtrollning",
    "förtrollningarna": "förtrollning",
    "förtrollningarnas": "förtrollning",
    "förtrollningars": "förtrollning",
    "förtrollningen": "förtrollning",
    "förtrollningens": "förtrollning",
    "förtrollnings": "förtrollning",
    "förtror": "förtro",
    "förtros": "förtro",
    "förtrott": "förtro",
    "förtrotts": "förtro",
    "förtruppen": "förtrupp",
    "förtruppens": "förtrupp",
    "förtrupper": "förtrupp",
    "förtrupperna": "förtrupp",
    "förtruppernas": "förtrupp",
    "förtruppers": "förtrupp",
    "förtrupps": "förtrupp",
    "förtrust": "förtrusta",
    "förtrustad": "förtrusta",
    "förtrustade": "förtrusta",
    "förtrustades": "förtrusta",
    "förtrustads": "förtrusta",
    "förtrustande": "förtrusta",
    "förtrustanden": "förtrustande",
    "förtrustandena": "förtrustande",
    "förtrustandenas": "förtrustande",
    "förtrustandens": "förtrustande",
    "förtrustandes": "förtrustande",
    "förtrustandet": "förtrustande",
    "förtrustandets": "förtrustande",
    "förtrustar": "förtrusta",
    "förtrustas": "förtrusta",
    "förtrustat": "förtrusta",
    "förtrustats": "förtrusta",
    "förtrute": "förtryta",
    "förtrutes": "förtryta",
    "förtrutit": "förtryta",
    "förtrutits": "förtryta",
    "förtryck": "förtrycka",
    "förtryckande": "förtrycka",
    "förtryckanden": "förtryckande",
    "förtryckandena": "förtryckande",
    "förtryckandenas": "förtryckande",
    "förtryckandens": "förtryckande",
    "förtryckandes": "förtryckande",
    "förtryckandet": "förtryckande",
    "förtryckandets": "förtryckande",
    "förtryckar": "förtryckare",
    "förtryckaren": "förtryckare",
    "förtryckarens": "förtryckare",
    "förtryckares": "förtryckare",
    "förtryckarna": "förtryckare",
    "förtryckarnas": "förtryckare",
    "förtryckas": "förtrycka",
    "förtrycker": "förtrycka",
    "förtryckes": "förtrycka",
    "förtrycket": "förtryck",
    "förtryckets": "förtryck",
    "förtrycks": "förtrycka",
    "förtryckt": "förtrycka",
    "förtryckta": "förtrycka",
    "förtrycktas": "förtrycka",
    "förtryckte": "förtrycka",
    "förtrycktes": "förtrycka",
    "förtryckts": "förtrycka",
    "förtryt": "förtryta",
    "förtrytande": "förtryta",
    "förtrytanden": "förtrytande",
    "förtrytandena": "förtrytande",
    "förtrytandenas": "förtrytande",
    "förtrytandens": "förtrytande",
    "förtrytandes": "förtrytande",
    "förtrytandet": "förtrytande",
    "förtrytandets": "förtrytande",
    "förtrytas": "förtryta",
    "förtryte": "förtryta",
    "förtrytelsen": "förtrytelse",
    "förtrytelsens": "förtrytelse",
    "förtrytelses": "förtrytelse",
    "förtryter": "förtryta",
    "förtrytes": "förtryta",
    "förtryts": "förtryta",
    "förtrytsamheten": "förtrytsamhet",
    "förtrytsamhetens": "förtrytsamhet",
    "förtrytsamhets": "förtrytsamhet",
    "förtrytsamma": "förtrytsam",
    "förtrytsammare": "förtrytsam",
    "förtrytsammares": "förtrytsam",
    "förtrytsammas": "förtrytsam",
    "förtrytsammast": "förtrytsam",
    "förtrytsammaste": "förtrytsam",
    "förtrytsammastes": "förtrytsam",
    "förtrytsammasts": "förtrytsam",
    "förtrytsamme": "förtrytsam",
    "förtrytsammes": "förtrytsam",
    "förtrytsams": "förtrytsam",
    "förtrytsamt": "förtrytsam",
    "förtrytsamts": "förtrytsam",
    "förträffliga": "förträfflig",
    "förträffligare": "förträfflig",
    "förträffligares": "förträfflig",
    "förträffligas": "förträfflig",
    "förträffligast": "förträfflig",
    "förträffligaste": "förträfflig",
    "förträffligastes": "förträfflig",
    "förträffligasts": "förträfflig",
    "förträfflige": "förträfflig",
    "förträffliges": "förträfflig",
    "förträffligheten": "förträfflighet",
    "förträfflighetens": "förträfflighet",
    "förträffligheter": "förträfflighet",
    "förträffligheterna": "förträfflighet",
    "förträffligheternas": "förträfflighet",
    "förträffligheters": "förträfflighet",
    "förträfflighets": "förträfflighet",
    "förträffligs": "förträfflig",
    "förträffligt": "förträfflig",
    "förträffligts": "förträfflig",
    "förträng": "förtränga",
    "förträngande": "förtränga",
    "förtränganden": "förträngande",
    "förträngandena": "förträngande",
    "förträngandenas": "förträngande",
    "förträngandens": "förträngande",
    "förträngandes": "förträngande",
    "förträngandet": "förträngande",
    "förträngandets": "förträngande",
    "förträngas": "förtränga",
    "förträngd": "förtränga",
    "förträngda": "förtränga",
    "förträngdas": "förtränga",
    "förträngde": "förtränga",
    "förträngdes": "förtränga",
    "förträngds": "förtränga",
    "förtränger": "förtränga",
    "förtränges": "förtränga",
    "förträngningar": "förträngning",
    "förträngningarna": "förträngning",
    "förträngningarnas": "förträngning",
    "förträngningars": "förträngning",
    "förträngningen": "förträngning",
    "förträngningens": "förträngning",
    "förträngnings": "förträngning",
    "förträngs": "förtränga",
    "förträngt": "förtränga",
    "förträngts": "förtränga",
    "förtröst": "förtrösta",
    "förtröstad": "förtrösta",
    "förtröstade": "förtrösta",
    "förtröstades": "förtrösta",
    "förtröstads": "förtrösta",
    "förtröstande": "förtrösta",
    "förtröstanden": "förtröstande",
    "förtröstandena": "förtröstande",
    "förtröstandenas": "förtröstande",
    "förtröstandens": "förtröstande",
    "förtröstandes": "förtröstande",
    "förtröstandet": "förtröstande",
    "förtröstandets": "förtröstande",
    "förtröstans": "förtröstan",
    "förtröstar": "förtrösta",
    "förtröstas": "förtrösta",
    "förtröstat": "förtrösta",
    "förtröstats": "förtrösta",
    "förtröt": "förtryta",
    "förtröts": "förtryta",
    "förtröttades": "förtröttas",
    "förtröttats": "förtröttas",
    "förts": "föra",
    "förtull": "förtulla",
    "förtullad": "förtulla",
    "förtullade": "förtulla",
    "förtullades": "förtulla",
    "förtullads": "förtulla",
    "förtullande": "förtulla",
    "förtullanden": "förtullande",
    "förtullandena": "förtullande",
    "förtullandenas": "förtullande",
    "förtullandens": "förtullande",
    "förtullandes": "förtullande",
    "förtullandet": "förtullande",
    "förtullandets": "förtullande",
    "förtullar": "förtulla",
    "förtullas": "förtulla",
    "förtullat": "förtulla",
    "förtullats": "förtulla",
    "förtunn": "förtunna",
    "förtunnad": "förtunna",
    "förtunnade": "förtunna",
    "förtunnades": "förtunna",
    "förtunnads": "förtunna",
    "förtunnande": "förtunna",
    "förtunnanden": "förtunnande",
    "förtunnandena": "förtunnande",
    "förtunnandenas": "förtunnande",
    "förtunnandens": "förtunnande",
    "förtunnandes": "förtunnande",
    "förtunnandet": "förtunnande",
    "förtunnandets": "förtunnande",
    "förtunnar": "förtunna",
    "förtunnas": "förtunna",
    "förtunnat": "förtunna",
    "förtunnats": "förtunna",
    "förtunningar": "förtunning",
    "förtunningarna": "förtunning",
    "förtunningarnas": "förtunning",
    "förtunningars": "förtunning",
    "förtunningen": "förtunning",
    "förtunningens": "förtunning",
    "förtunnings": "förtunning",
    "förturen": "förtur",
    "förturens": "förtur",
    "förturs": "förtur",
    "förtvin": "förtvina",
    "förtvinad": "förtvina",
    "förtvinade": "förtvina",
    "förtvinades": "förtvina",
    "förtvinads": "förtvina",
    "förtvinande": "förtvina",
    "förtvinanden": "förtvinande",
    "förtvinandena": "förtvinande",
    "förtvinandenas": "förtvinande",
    "förtvinandens": "förtvinande",
    "förtvinandes": "förtvinande",
    "förtvinandet": "förtvinande",
    "förtvinandets": "förtvinande",
    "förtvinar": "förtvina",
    "förtvinas": "förtvina",
    "förtvinat": "förtvina",
    "förtvinats": "förtvina",
    "förtviningar": "förtvining",
    "förtviningarna": "förtvining",
    "förtviningarnas": "förtvining",
    "förtviningars": "förtvining",
    "förtviningen": "förtvining",
    "förtviningens": "förtvining",
    "förtvinings": "förtvining",
    "förtvivlad": "förtvivla",
    "förtvivlade": "förtvivlad",
    "förtvivlades": "förtvivlad",
    "förtvivlads": "förtvivlad",
    "förtvivlande": "förtvivla",
    "förtvivlanden": "förtvivlande",
    "förtvivlandena": "förtvivlande",
    "förtvivlandenas": "förtvivlande",
    "förtvivlandens": "förtvivlande",
    "förtvivlandes": "förtvivlande",
    "förtvivlandet": "förtvivlande",
    "förtvivlandets": "förtvivlande",
    "förtvivlans": "förtvivlan",
    "förtvivlar": "förtvivla",
    "förtvivlas": "förtvivla",
    "förtvivlat": "förtvivlad",
    "förtvivlats": "förtvivlad",
    "förtvättar": "förtvätt",
    "förtvättarna": "förtvätt",
    "förtvättarnas": "förtvätt",
    "förtvättars": "förtvätt",
    "förtvätten": "förtvätt",
    "förtvättens": "förtvätt",
    "förtvätts": "förtvätt",
    "förtvålad": "förtvåla",
    "förtvålade": "förtvåla",
    "förtvålades": "förtvåla",
    "förtvålads": "förtvåla",
    "förtvålande": "förtvåla",
    "förtvålanden": "förtvålande",
    "förtvålandena": "förtvålande",
    "förtvålandenas": "förtvålande",
    "förtvålandens": "förtvålande",
    "förtvålandes": "förtvålande",
    "förtvålandet": "förtvålande",
    "förtvålandets": "förtvålande",
    "förtvålar": "förtvåla",
    "förtvålas": "förtvåla",
    "förtvålat": "förtvåla",
    "förtvålats": "förtvåla",
    "förtvålningar": "förtvålning",
    "förtvålningarna": "förtvålning",
    "förtvålningarnas": "förtvålning",
    "förtvålningars": "förtvålning",
    "förtvålningen": "förtvålning",
    "förtvålningens": "förtvålning",
    "förtvålnings": "förtvålning",
    "förtyck": "förtycka",
    "förtyckande": "förtycka",
    "förtyckanden": "förtyckande",
    "förtyckandena": "förtyckande",
    "förtyckandenas": "förtyckande",
    "förtyckandens": "förtyckande",
    "förtyckandes": "förtyckande",
    "förtyckandet": "förtyckande",
    "förtyckandets": "förtyckande",
    "förtyckas": "förtycka",
    "förtycker": "förtycka",
    "förtyckes": "förtycka",
    "förtycks": "förtycka",
    "förtyckt": "förtycka",
    "förtyckta": "förtycka",
    "förtycktas": "förtycka",
    "förtyckte": "förtycka",
    "förtycktes": "förtycka",
    "förtyckts": "förtycka",
    "förtydlig": "förtydliga",
    "förtydligad": "förtydliga",
    "förtydligade": "förtydliga",
    "förtydligades": "förtydliga",
    "förtydligads": "förtydliga",
    "förtydligande": "förtydliga",
    "förtydliganden": "förtydligande",
    "förtydligandena": "förtydligande",
    "förtydligandenas": "förtydligande",
    "förtydligandens": "förtydligande",
    "förtydligandes": "förtydligande",
    "förtydligandet": "förtydligande",
    "förtydligandets": "förtydligande",
    "förtydligar": "förtydliga",
    "förtydligas": "förtydliga",
    "förtydligat": "förtydliga",
    "förtydligats": "förtydliga",
    "förtysk": "förtyska",
    "förtyskad": "förtyska",
    "förtyskade": "förtyska",
    "förtyskades": "förtyska",
    "förtyskads": "förtyska",
    "förtyskande": "förtyska",
    "förtyskanden": "förtyskande",
    "förtyskandena": "förtyskande",
    "förtyskandenas": "förtyskande",
    "förtyskandens": "förtyskande",
    "förtyskandes": "förtyskande",
    "förtyskandet": "förtyskande",
    "förtyskandets": "förtyskande",
    "förtyskar": "förtyska",
    "förtyskas": "förtyska",
    "förtyskat": "förtyska",
    "förtyskats": "förtyska",
    "förtäckta": "förtäckt",
    "förtäcktare": "förtäckt",
    "förtäcktares": "förtäckt",
    "förtäcktas": "förtäckt",
    "förtäcktast": "förtäckt",
    "förtäcktaste": "förtäckt",
    "förtäcktastes": "förtäckt",
    "förtäcktasts": "förtäckt",
    "förtäckte": "förtäckt",
    "förtäcktes": "förtäckt",
    "förtäckts": "förtäckt",
    "förtälj": "förtälja",
    "förtäljande": "förtälja",
    "förtäljanden": "förtäljande",
    "förtäljandena": "förtäljande",
    "förtäljandenas": "förtäljande",
    "förtäljandens": "förtäljande",
    "förtäljandes": "förtäljande",
    "förtäljandet": "förtäljande",
    "förtäljandets": "förtäljande",
    "förtäljas": "förtälja",
    "förtäljd": "förtälja",
    "förtäljda": "förtälja",
    "förtäljdas": "förtälja",
    "förtäljde": "förtälja",
    "förtäljdes": "förtälja",
    "förtäljds": "förtälja",
    "förtäljer": "förtälja",
    "förtäljes": "förtälja",
    "förtäljs": "förtälja",
    "förtäljt": "förtälja",
    "förtäljts": "förtälja",
    "förtändningar": "förtändning",
    "förtändningarna": "förtändning",
    "förtändningarnas": "förtändning",
    "förtändningars": "förtändning",
    "förtändningen": "förtändning",
    "förtändningens": "förtändning",
    "förtändnings": "förtändning",
    "förtänk": "förtänka",
    "förtänkande": "förtänka",
    "förtänkanden": "förtänkande",
    "förtänkandena": "förtänkande",
    "förtänkandenas": "förtänkande",
    "förtänkandens": "förtänkande",
    "förtänkandes": "förtänkande",
    "förtänkandet": "förtänkande",
    "förtänkandets": "förtänkande",
    "förtänkas": "förtänka",
    "förtänker": "förtänka",
    "förtänkes": "förtänka",
    "förtänks": "förtänka",
    "förtänksamheten": "förtänksamhet",
    "förtänksamhetens": "förtänksamhet",
    "förtänksamhets": "förtänksamhet",
    "förtänksamma": "förtänksam",
    "förtänksammare": "förtänksam",
    "förtänksammares": "förtänksam",
    "förtänksammas": "förtänksam",
    "förtänksammast": "förtänksam",
    "förtänksammaste": "förtänksam",
    "förtänksammastes": "förtänksam",
    "förtänksammasts": "förtänksam",
    "förtänksamme": "förtänksam",
    "förtänksammes": "förtänksam",
    "förtänksams": "förtänksam",
    "förtänksamt": "förtänksam",
    "förtänksamts": "förtänksam",
    "förtänkt": "förtänka",
    "förtänkta": "förtänka",
    "förtänktas": "förtänka",
    "förtänkte": "förtänka",
    "förtänktes": "förtänka",
    "förtänkts": "förtänka",
    "förtär": "förtära",
    "förtärande": "förtära",
    "förtäranden": "förtärande",
    "förtärandena": "förtärande",
    "förtärandenas": "förtärande",
    "förtärandens": "förtärande",
    "förtärandes": "förtärande",
    "förtärandet": "förtärande",
    "förtärandets": "förtärande",
    "förtäras": "förtära",
    "förtärd": "förtära",
    "förtärda": "förtära",
    "förtärdas": "förtära",
    "förtärde": "förtära",
    "förtärdes": "förtära",
    "förtärds": "förtära",
    "förtäres": "förtära",
    "förtäringar": "förtäring",
    "förtäringarna": "förtäring",
    "förtäringarnas": "förtäring",
    "förtäringars": "förtäring",
    "förtäringen": "förtäring",
    "förtäringens": "förtäring",
    "förtärings": "förtäring",
    "förtärs": "förtära",
    "förtärt": "förtära",
    "förtärts": "förtära",
    "förtät": "förtäta",
    "förtätad": "förtäta",
    "förtätade": "förtäta",
    "förtätades": "förtäta",
    "förtätads": "förtäta",
    "förtätande": "förtäta",
    "förtätanden": "förtätande",
    "förtätandena": "förtätande",
    "förtätandenas": "förtätande",
    "förtätandens": "förtätande",
    "förtätandes": "förtätande",
    "förtätandet": "förtätande",
    "förtätandets": "förtätande",
    "förtätar": "förtäta",
    "förtätas": "förtäta",
    "förtätat": "förtäta",
    "förtätats": "förtäta",
    "förtätningar": "förtätning",
    "förtätningarna": "förtätning",
    "förtätningarnas": "förtätning",
    "förtätningars": "förtätning",
    "förtätningen": "förtätning",
    "förtätningens": "förtätning",
    "förtätnings": "förtätning",
    "förtöj": "förtöja",
    "förtöjande": "förtöja",
    "förtöjanden": "förtöjande",
    "förtöjandena": "förtöjande",
    "förtöjandenas": "förtöjande",
    "förtöjandens": "förtöjande",
    "förtöjandes": "förtöjande",
    "förtöjandet": "förtöjande",
    "förtöjandets": "förtöjande",
    "förtöjas": "förtöja",
    "förtöjd": "förtöja",
    "förtöjda": "förtöja",
    "förtöjdas": "förtöja",
    "förtöjde": "förtöja",
    "förtöjdes": "förtöja",
    "förtöjds": "förtöja",
    "förtöjer": "förtöja",
    "förtöjes": "förtöja",
    "förtöjningar": "förtöjning",
    "förtöjningarna": "förtöjning",
    "förtöjningarnas": "förtöjning",
    "förtöjningars": "förtöjning",
    "förtöjningen": "förtöjning",
    "förtöjningens": "förtöjning",
    "förtöjnings": "förtöjning",
    "förtöjningslin": "förtöjningslina",
    "förtöjningslinan": "förtöjningslina",
    "förtöjningslinans": "förtöjningslina",
    "förtöjningslinas": "förtöjningslina",
    "förtöjningsline": "förtöjningslina",
    "förtöjningslinor": "förtöjningslina",
    "förtöjningslinorna": "förtöjningslina",
    "förtöjningslinornas": "förtöjningslina",
    "förtöjningslinors": "förtöjningslina",
    "förtöjningslins": "förtöjningslina",
    "förtöjningsringar": "förtöjningsring",
    "förtöjningsringarna": "förtöjningsring",
    "förtöjningsringarnas": "förtöjningsring",
    "förtöjningsringars": "förtöjningsring",
    "förtöjningsringen": "förtöjningsring",
    "förtöjningsringens": "förtöjningsring",
    "förtöjningsrings": "förtöjningsring",
    "förtöjs": "förtöja",
    "förtöjt": "förtöja",
    "förtöjts": "förtöja",
    "förtörnade": "förtörnad",
    "förtörnades": "förtörnad",
    "förtörnads": "förtörnad",
    "förtörnat": "förtörnad",
    "förtörnats": "förtörnad",
    "förunderliga": "förunderlig",
    "förunderligare": "förunderlig",
    "förunderligares": "förunderlig",
    "förunderligas": "förunderlig",
    "förunderligast": "förunderlig",
    "förunderligaste": "förunderlig",
    "förunderligastes": "förunderlig",
    "förunderligasts": "förunderlig",
    "förunderlige": "förunderlig",
    "förunderliges": "förunderlig",
    "förunderligheten": "förunderlighet",
    "förunderlighetens": "förunderlighet",
    "förunderligheter": "förunderlighet",
    "förunderligheterna": "förunderlighet",
    "förunderligheternas": "förunderlighet",
    "förunderligheters": "förunderlighet",
    "förunderlighets": "förunderlighet",
    "förunderligs": "förunderlig",
    "förunderligt": "förunderlig",
    "förunderligts": "förunderlig",
    "förundersök": "förundersöka",
    "förundersökande": "förundersöka",
    "förundersökanden": "förundersökande",
    "förundersökandena": "förundersökande",
    "förundersökandenas": "förundersökande",
    "förundersökandens": "förundersökande",
    "förundersökandes": "förundersökande",
    "förundersökandet": "förundersökande",
    "förundersökandets": "förundersökande",
    "förundersökas": "förundersöka",
    "förundersöker": "förundersöka",
    "förundersökes": "förundersöka",
    "förundersökningar": "förundersökning",
    "förundersökningarna": "förundersökning",
    "förundersökningarnas": "förundersökning",
    "förundersökningars": "förundersökning",
    "förundersökningen": "förundersökning",
    "förundersökningens": "förundersökning",
    "förundersöknings": "förundersökning",
    "förundersökningsledar": "förundersökningsledare",
    "förundersökningsledaren": "förundersökningsledare",
    "förundersökningsledarens": "förundersökningsledare",
    "förundersökningsledares": "förundersökningsledare",
    "förundersökningsledarna": "förundersökningsledare",
    "förundersökningsledarnas": "förundersökningsledare",
    "förundersökningsprotokollen": "förundersökningsprotokoll",
    "förundersökningsprotokollens": "förundersökningsprotokoll",
    "förundersökningsprotokollet": "förundersökningsprotokoll",
    "förundersökningsprotokollets": "förundersökningsprotokoll",
    "förundersökningsprotokolls": "förundersökningsprotokoll",
    "förundersöks": "förundersöka",
    "förundersökt": "förundersöka",
    "förundersökta": "förundersöka",
    "förundersöktas": "förundersöka",
    "förundersökte": "förundersöka",
    "förundersöktes": "förundersöka",
    "förundersökts": "förundersöka",
    "förundrad": "förundra",
    "förundrade": "förundra",
    "förundrades": "förundra",
    "förundrads": "förundra",
    "förundrande": "förundra",
    "förundranden": "förundrande",
    "förundrandena": "förundrande",
    "förundrandenas": "förundrande",
    "förundrandens": "förundrande",
    "förundrandes": "förundrande",
    "förundrandet": "förundrande",
    "förundrandets": "förundrande",
    "förundrans": "förundran",
    "förundransvärda": "förundransvärd",
    "förundransvärdare": "förundransvärd",
    "förundransvärdares": "förundransvärd",
    "förundransvärdas": "förundransvärd",
    "förundransvärdast": "förundransvärd",
    "förundransvärdaste": "förundransvärd",
    "förundransvärdastes": "förundransvärd",
    "förundransvärdasts": "förundransvärd",
    "förundransvärde": "förundransvärd",
    "förundransvärdes": "förundransvärd",
    "förundransvärdheten": "förundransvärdhet",
    "förundransvärdhetens": "förundransvärdhet",
    "förundransvärdhets": "förundransvärdhet",
    "förundransvärds": "förundransvärd",
    "förundransvärt": "förundransvärd",
    "förundransvärts": "förundransvärd",
    "förundrar": "förundra",
    "förundras": "förundra",
    "förundrat": "förundra",
    "förundrats": "förundra",
    "förunn": "förunna",
    "förunnad": "förunna",
    "förunnade": "förunna",
    "förunnades": "förunna",
    "förunnads": "förunna",
    "förunnande": "förunna",
    "förunnanden": "förunnande",
    "förunnandena": "förunnande",
    "förunnandenas": "förunnande",
    "förunnandens": "förunnande",
    "förunnandes": "förunnande",
    "förunnandet": "förunnande",
    "förunnandets": "förunnande",
    "förunnar": "förunna",
    "förunnas": "förunna",
    "förunnat": "förunna",
    "förunnats": "förunna",
    "förunta": "förunt",
    "föruntas": "förunt",
    "förunte": "förunt",
    "föruntes": "förunt",
    "förunts": "förunt",
    "förutbestäm": "förutbestämma",
    "förutbestämd": "förutbestämma",
    "förutbestämda": "förutbestämma",
    "förutbestämdare": "förutbestämd",
    "förutbestämdares": "förutbestämd",
    "förutbestämdas": "förutbestämma",
    "förutbestämdast": "förutbestämd",
    "förutbestämdaste": "förutbestämd",
    "förutbestämdastes": "förutbestämd",
    "förutbestämdasts": "förutbestämd",
    "förutbestämde": "förutbestämma",
    "förutbestämdes": "förutbestämma",
    "förutbestämdheten": "förutbestämdhet",
    "förutbestämdhetens": "förutbestämdhet",
    "förutbestämdhets": "förutbestämdhet",
    "förutbestämds": "förutbestämma",
    "förutbestämmande": "förutbestämma",
    "förutbestämmanden": "förutbestämmande",
    "förutbestämmandena": "förutbestämmande",
    "förutbestämmandenas": "förutbestämmande",
    "förutbestämmandens": "förutbestämmande",
    "förutbestämmandes": "förutbestämmande",
    "förutbestämmandet": "förutbestämmande",
    "förutbestämmandets": "förutbestämmande",
    "förutbestämmas": "förutbestämma",
    "förutbestämmer": "förutbestämma",
    "förutbestäms": "förutbestämma",
    "förutbestämt": "förutbestämma",
    "förutbestämts": "förutbestämma",
    "förutfattade": "förutfattad",
    "förutfattades": "förutfattad",
    "förutfattads": "förutfattad",
    "förutfattat": "förutfattad",
    "förutfattats": "förutfattad",
    "förutsade": "förutsäga",
    "förutsades": "förutsäga",
    "förutsagd": "förutsäga",
    "förutsagda": "förutsäga",
    "förutsagdas": "förutsäga",
    "förutsagde": "förutsäga",
    "förutsagdes": "förutsäga",
    "förutsagds": "förutsäga",
    "förutsagt": "förutsäga",
    "förutsagts": "förutsäga",
    "förutsatt": "förutsätta",
    "förutsatta": "förutsätta",
    "förutsattas": "förutsätta",
    "förutsatte": "förutsätta",
    "förutsattes": "förutsätta",
    "förutsatts": "förutsätta",
    "förutsedd": "förutse",
    "förutsedda": "förutse",
    "förutseddas": "förutse",
    "förutsedde": "förutse",
    "förutseddes": "förutse",
    "förutsedds": "förutse",
    "förutseende": "förutse",
    "förutseendes": "förutseende",
    "förutseendet": "förutseende",
    "förutseendets": "förutseende",
    "förutser": "förutse",
    "förutses": "förutse",
    "förutsett": "förutse",
    "förutsetts": "förutse",
    "förutskick": "förutskicka",
    "förutskickad": "förutskicka",
    "förutskickade": "förutskicka",
    "förutskickades": "förutskicka",
    "förutskickads": "förutskicka",
    "förutskickande": "förutskicka",
    "förutskickanden": "förutskickande",
    "förutskickandena": "förutskickande",
    "förutskickandenas": "förutskickande",
    "förutskickandens": "förutskickande",
    "förutskickandes": "förutskickande",
    "förutskickandet": "förutskickande",
    "förutskickandets": "förutskickande",
    "förutskickar": "förutskicka",
    "förutskickas": "förutskicka",
    "förutskickat": "förutskicka",
    "förutskickats": "förutskicka",
    "förutspådd": "förutspå",
    "förutspådda": "förutspå",
    "förutspåddas": "förutspå",
    "förutspådde": "förutspå",
    "förutspåddes": "förutspå",
    "förutspådds": "förutspå",
    "förutspående": "förutspå",
    "förutspåenden": "förutspående",
    "förutspåendena": "förutspående",
    "förutspåendenas": "förutspående",
    "förutspåendens": "förutspående",
    "förutspåendes": "förutspående",
    "förutspåendet": "förutspående",
    "förutspåendets": "förutspående",
    "förutspår": "förutspå",
    "förutspås": "förutspå",
    "förutspått": "förutspå",
    "förutspåtts": "förutspå",
    "förutsäg": "förutsäga",
    "förutsägande": "förutsäga",
    "förutsäganden": "förutsägande",
    "förutsägandena": "förutsägande",
    "förutsägandenas": "förutsägande",
    "förutsägandens": "förutsägande",
    "förutsägandes": "förutsägande",
    "förutsägandet": "förutsägande",
    "förutsägandets": "förutsägande",
    "förutsägas": "förutsäga",
    "förutsägbara": "förutsägbar",
    "förutsägbarare": "förutsägbar",
    "förutsägbarares": "förutsägbar",
    "förutsägbaras": "förutsägbar",
    "förutsägbarast": "förutsägbar",
    "förutsägbaraste": "förutsägbar",
    "förutsägbarastes": "förutsägbar",
    "förutsägbarasts": "förutsägbar",
    "förutsägbare": "förutsägbar",
    "förutsägbares": "förutsägbar",
    "förutsägbarheten": "förutsägbarhet",
    "förutsägbarhetens": "förutsägbarhet",
    "förutsägbarhets": "förutsägbarhet",
    "förutsägbars": "förutsägbar",
    "förutsägbart": "förutsägbar",
    "förutsägbarts": "förutsägbar",
    "förutsägelsekraften": "förutsägelsekraft",
    "förutsägelsekraftens": "förutsägelsekraft",
    "förutsägelsekrafts": "förutsägelsekraft",
    "förutsägelsen": "förutsägelse",
    "förutsägelsens": "förutsägelse",
    "förutsägelser": "förutsägelse",
    "förutsägelserna": "förutsägelse",
    "förutsägelsernas": "förutsägelse",
    "förutsägelsers": "förutsägelse",
    "förutsägelses": "förutsägelse",
    "förutsäger": "förutsäga",
    "förutsäges": "förutsäga",
    "förutsägs": "förutsäga",
    "förutsätt": "förutsätta",
    "förutsättande": "förutsätta",
    "förutsättanden": "förutsättande",
    "förutsättandena": "förutsättande",
    "förutsättandenas": "förutsättande",
    "förutsättandens": "förutsättande",
    "förutsättandes": "förutsättande",
    "förutsättandet": "förutsättande",
    "förutsättandets": "förutsättande",
    "förutsättas": "förutsätta",
    "förutsätter": "förutsätta",
    "förutsättes": "förutsätta",
    "förutsättningar": "förutsättning",
    "förutsättningarna": "förutsättning",
    "förutsättningarnas": "förutsättning",
    "förutsättningars": "förutsättning",
    "förutsättningen": "förutsättning",
    "förutsättningens": "förutsättning",
    "förutsättnings": "förutsättning",
    "förutsättningslösa": "förutsättningslös",
    "förutsättningslösare": "förutsättningslös",
    "förutsättningslösares": "förutsättningslös",
    "förutsättningslösas": "förutsättningslös",
    "förutsättningslösast": "förutsättningslös",
    "förutsättningslösaste": "förutsättningslös",
    "förutsättningslösastes": "förutsättningslös",
    "förutsättningslösasts": "förutsättningslös",
    "förutsättningslöse": "förutsättningslös",
    "förutsättningslöses": "förutsättningslös",
    "förutsättningslösheten": "förutsättningslöshet",
    "förutsättningslöshetens": "förutsättningslöshet",
    "förutsättningslöshets": "förutsättningslöshet",
    "förutsättningslöst": "förutsättningslös",
    "förutsättningslösts": "förutsättningslös",
    "förutsätts": "förutsätta",
    "förutsåg": "förutse",
    "förutsåge": "förutse",
    "förutsåges": "förutse",
    "förutsågs": "förutse",
    "förvalt": "förvalta",
    "förvaltad": "förvalta",
    "förvaltade": "förvalta",
    "förvaltades": "förvalta",
    "förvaltads": "förvalta",
    "förvaltande": "förvalta",
    "förvaltanden": "förvaltande",
    "förvaltandena": "förvaltande",
    "förvaltandenas": "förvaltande",
    "förvaltandens": "förvaltande",
    "förvaltandes": "förvaltande",
    "förvaltandet": "förvaltande",
    "förvaltandets": "förvaltande",
    "förvaltar": "förvaltare",
    "förvaltaren": "förvaltare",
    "förvaltarens": "förvaltare",
    "förvaltares": "förvaltare",
    "förvaltarna": "förvaltare",
    "förvaltarnas": "förvaltare",
    "förvaltarskapet": "förvaltarskap",
    "förvaltarskapets": "förvaltarskap",
    "förvaltarskaps": "förvaltarskap",
    "förvaltarskapsområden": "förvaltarskapsområde",
    "förvaltarskapsområdena": "förvaltarskapsområde",
    "förvaltarskapsområdenas": "förvaltarskapsområde",
    "förvaltarskapsområdens": "förvaltarskapsområde",
    "förvaltarskapsområdes": "förvaltarskapsområde",
    "förvaltarskapsområdet": "förvaltarskapsområde",
    "förvaltarskapsområdets": "förvaltarskapsområde",
    "förvaltas": "förvalta",
    "förvaltat": "förvalta",
    "förvaltats": "förvalta",
    "förvaltningar": "förvaltning",
    "förvaltningarna": "förvaltning",
    "förvaltningarnas": "förvaltning",
    "förvaltningars": "förvaltning",
    "förvaltningen": "förvaltning",
    "förvaltningens": "förvaltning",
    "förvaltnings": "förvaltning",
    "förvaltningsberättelsen": "förvaltningsberättelse",
    "förvaltningsberättelsens": "förvaltningsberättelse",
    "förvaltningsberättelser": "förvaltningsberättelse",
    "förvaltningsberättelserna": "förvaltningsberättelse",
    "förvaltningsberättelsernas": "förvaltningsberättelse",
    "förvaltningsberättelsers": "förvaltningsberättelse",
    "förvaltningsberättelses": "förvaltningsberättelse",
    "förvaltningsbesluten": "förvaltningsbeslut",
    "förvaltningsbeslutens": "förvaltningsbeslut",
    "förvaltningsbeslutet": "förvaltningsbeslut",
    "förvaltningsbeslutets": "förvaltningsbeslut",
    "förvaltningsbesluts": "förvaltningsbeslut",
    "förvaltningsbolagen": "förvaltningsbolag",
    "förvaltningsbolagens": "förvaltningsbolag",
    "förvaltningsbolaget": "förvaltningsbolag",
    "förvaltningsbolagets": "förvaltningsbolag",
    "förvaltningsbolags": "förvaltningsbolag",
    "förvaltningsbyggnaden": "förvaltningsbyggnad",
    "förvaltningsbyggnadens": "förvaltningsbyggnad",
    "förvaltningsbyggnader": "förvaltningsbyggnad",
    "förvaltningsbyggnaderna": "förvaltningsbyggnad",
    "förvaltningsbyggnadernas": "förvaltningsbyggnad",
    "förvaltningsbyggnaders": "förvaltningsbyggnad",
    "förvaltningsbyggnads": "förvaltningsbyggnad",
    "förvaltningsmässiga": "förvaltningsmässig",
    "förvaltningsmässigare": "förvaltningsmässig",
    "förvaltningsmässigares": "förvaltningsmässig",
    "förvaltningsmässigas": "förvaltningsmässig",
    "förvaltningsmässigast": "förvaltningsmässig",
    "förvaltningsmässigaste": "förvaltningsmässig",
    "förvaltningsmässigastes": "förvaltningsmässig",
    "förvaltningsmässigasts": "förvaltningsmässig",
    "förvaltningsmässige": "förvaltningsmässig",
    "förvaltningsmässiges": "förvaltningsmässig",
    "förvaltningsmässigs": "förvaltningsmässig",
    "förvaltningsmässigt": "förvaltningsmässig",
    "förvaltningsmässigts": "förvaltningsmässig",
    "förvaltningsutskotten": "förvaltningsutskott",
    "förvaltningsutskottens": "förvaltningsutskott",
    "förvaltningsutskottet": "förvaltningsutskott",
    "förvaltningsutskottets": "förvaltningsutskott",
    "förvaltningsutskotts": "förvaltningsutskott",
    "förvandlad": "förvandla",
    "förvandlade": "förvandla",
    "förvandlades": "förvandla",
    "förvandlads": "förvandla",
    "förvandlande": "förvandla",
    "förvandlanden": "förvandlande",
    "förvandlandena": "förvandlande",
    "förvandlandenas": "förvandlande",
    "förvandlandens": "förvandlande",
    "förvandlandes": "förvandlande",
    "förvandlandet": "förvandlande",
    "förvandlandets": "förvandlande",
    "förvandlar": "förvandla",
    "förvandlas": "förvandla",
    "förvandlat": "förvandla",
    "förvandlats": "förvandla",
    "förvandlingar": "förvandling",
    "förvandlingarna": "förvandling",
    "förvandlingarnas": "förvandling",
    "förvandlingars": "förvandling",
    "förvandlingen": "förvandling",
    "förvandlingens": "förvandling",
    "förvandlings": "förvandling",
    "förvandlingskonstnären": "förvandlingskonstnär",
    "förvandlingskonstnärens": "förvandlingskonstnär",
    "förvandlingskonstnärer": "förvandlingskonstnär",
    "förvandlingskonstnärerna": "förvandlingskonstnär",
    "förvandlingskonstnärernas": "förvandlingskonstnär",
    "förvandlingskonstnärers": "förvandlingskonstnär",
    "förvandlingskonstnärs": "förvandlingskonstnär",
    "förvandlingsnummerna": "förvandlingsnummer",
    "förvandlingsnummernas": "förvandlingsnummer",
    "förvandlingsnummers": "förvandlingsnummer",
    "förvandlingsnumren": "förvandlingsnummer",
    "förvandlingsnumrens": "förvandlingsnummer",
    "förvandlingsnumret": "förvandlingsnummer",
    "förvandlingsnumrets": "förvandlingsnummer",
    "förvandlingsstraffen": "förvandlingsstraff",
    "förvandlingsstraffens": "förvandlingsstraff",
    "förvandlingsstraffet": "förvandlingsstraff",
    "förvandlingsstraffets": "förvandlingsstraff",
    "förvandlingsstraffs": "förvandlingsstraff",
    "förvansk": "förvanska",
    "förvanskad": "förvanska",
    "förvanskade": "förvanska",
    "förvanskades": "förvanska",
    "förvanskads": "förvanska",
    "förvanskande": "förvanska",
    "förvanskanden": "förvanskande",
    "förvanskandena": "förvanskande",
    "förvanskandenas": "förvanskande",
    "förvanskandens": "förvanskande",
    "förvanskandes": "förvanskande",
    "förvanskandet": "förvanskande",
    "förvanskandets": "förvanskande",
    "förvanskar": "förvanska",
    "förvanskas": "förvanska",
    "förvanskat": "förvanska",
    "förvanskats": "förvanska",
    "förvanskningar": "förvanskning",
    "förvanskningarna": "förvanskning",
    "förvanskningarnas": "förvanskning",
    "förvanskningars": "förvanskning",
    "förvanskningen": "förvanskning",
    "förvanskningens": "förvanskning",
    "förvansknings": "förvanskning",
    "förvar": "förvara",
    "förvarad": "förvara",
    "förvarade": "förvara",
    "förvarades": "förvara",
    "förvarads": "förvara",
    "förvarande": "förvara",
    "förvaranden": "förvarande",
    "förvarandena": "förvarande",
    "förvarandenas": "förvarande",
    "förvarandens": "förvarande",
    "förvarandes": "förvarande",
    "förvarandet": "förvarande",
    "förvarandets": "förvarande",
    "förvarar": "förvara",
    "förvaras": "förvara",
    "förvarat": "förvara",
    "förvarats": "förvara",
    "förvaret": "förvar",
    "förvarets": "förvar",
    "förvaringar": "förvaring",
    "förvaringarna": "förvaring",
    "förvaringarnas": "förvaring",
    "förvaringars": "förvaring",
    "förvaringen": "förvaring",
    "förvaringens": "förvaring",
    "förvarings": "förvaring",
    "förvaringsaskar": "förvaringsask",
    "förvaringsaskarna": "förvaringsask",
    "förvaringsaskarnas": "förvaringsask",
    "förvaringsaskars": "förvaringsask",
    "förvaringsasken": "förvaringsask",
    "förvaringsaskens": "förvaringsask",
    "förvaringsasks": "förvaringsask",
    "förvaringsbackar": "förvaringsback",
    "förvaringsbackarna": "förvaringsback",
    "förvaringsbackarnas": "förvaringsback",
    "förvaringsbackars": "förvaringsback",
    "förvaringsbacken": "förvaringsback",
    "förvaringsbackens": "förvaringsback",
    "förvaringsbacks": "förvaringsback",
    "förvaringsboxar": "förvaringsbox",
    "förvaringsboxarna": "förvaringsbox",
    "förvaringsboxarnas": "förvaringsbox",
    "förvaringsboxars": "förvaringsbox",
    "förvaringsboxen": "förvaringsbox",
    "förvaringsboxens": "förvaringsbox",
    "förvaringshallar": "förvaringshall",
    "förvaringshallarna": "förvaringshall",
    "förvaringshallarnas": "förvaringshall",
    "förvaringshallars": "förvaringshall",
    "förvaringshallen": "förvaringshall",
    "förvaringshallens": "förvaringshall",
    "förvaringshalls": "förvaringshall",
    "förvaringskorgar": "förvaringskorg",
    "förvaringskorgarna": "förvaringskorg",
    "förvaringskorgarnas": "förvaringskorg",
    "förvaringskorgars": "förvaringskorg",
    "förvaringskorgen": "förvaringskorg",
    "förvaringskorgens": "förvaringskorg",
    "förvaringskorgs": "förvaringskorg",
    "förvaringsmöjligheten": "förvaringsmöjlighet",
    "förvaringsmöjlighetens": "förvaringsmöjlighet",
    "förvaringsmöjligheter": "förvaringsmöjlighet",
    "förvaringsmöjligheterna": "förvaringsmöjlighet",
    "förvaringsmöjligheternas": "förvaringsmöjlighet",
    "förvaringsmöjligheters": "förvaringsmöjlighet",
    "förvaringsmöjlighets": "förvaringsmöjlighet",
    "förvaringsskåpen": "förvaringsskåp",
    "förvaringsskåpens": "förvaringsskåp",
    "förvaringsskåpet": "förvaringsskåp",
    "förvaringsskåpets": "förvaringsskåp",
    "förvaringsskåps": "förvaringsskåp",
    "förvaringsutrymmen": "förvaringsutrymme",
    "förvaringsutrymmena": "förvaringsutrymme",
    "förvaringsutrymmenas": "förvaringsutrymme",
    "förvaringsutrymmens": "förvaringsutrymme",
    "förvaringsutrymmes": "förvaringsutrymme",
    "förvaringsutrymmet": "förvaringsutrymme",
    "förvaringsutrymmets": "förvaringsutrymme",
    "förvarn": "förvarna",
    "förvarnad": "förvarna",
    "förvarnade": "förvarna",
    "förvarnades": "förvarna",
    "förvarnads": "förvarna",
    "förvarnande": "förvarna",
    "förvarnanden": "förvarnande",
    "förvarnandena": "förvarnande",
    "förvarnandenas": "förvarnande",
    "förvarnandens": "förvarnande",
    "förvarnandes": "förvarnande",
    "förvarnandet": "förvarnande",
    "förvarnandets": "förvarnande",
    "förvarnar": "förvarna",
    "förvarnas": "förvarna",
    "förvarnat": "förvarna",
    "förvarnats": "förvarna",
    "förvarningar": "förvarning",
    "förvarningarna": "förvarning",
    "förvarningarnas": "förvarning",
    "förvarningars": "förvarning",
    "förvarningen": "förvarning",
    "förvarningens": "förvarning",
    "förvarnings": "förvarning",
    "förvars": "förvar",
    "förvecklingar": "förveckling",
    "förvecklingarna": "förveckling",
    "förvecklingarnas": "förveckling",
    "förvecklingars": "förveckling",
    "förvecklingen": "förveckling",
    "förvecklingens": "förveckling",
    "förvecklings": "förveckling",
    "förved": "förveda",
    "förvedad": "förveda",
    "förvedade": "förveda",
    "förvedades": "förveda",
    "förvedads": "förveda",
    "förvedande": "förveda",
    "förvedanden": "förvedande",
    "förvedandena": "förvedande",
    "förvedandenas": "förvedande",
    "förvedandens": "förvedande",
    "förvedandes": "förvedande",
    "förvedandet": "förvedande",
    "förvedandets": "förvedande",
    "förvedar": "förveda",
    "förvedas": "förveda",
    "förvedat": "förveda",
    "förvedats": "förveda",
    "förvedningar": "förvedning",
    "förvedningarna": "förvedning",
    "förvedningarnas": "förvedning",
    "förvedningars": "förvedning",
    "förvedningen": "förvedning",
    "förvedningens": "förvedning",
    "förvednings": "förvedning",
    "förveklig": "förvekliga",
    "förvekligad": "förvekliga",
    "förvekligade": "förvekliga",
    "förvekligades": "förvekliga",
    "förvekligads": "förvekliga",
    "förvekligande": "förvekliga",
    "förvekliganden": "förvekligande",
    "förvekligandena": "förvekligande",
    "förvekligandenas": "förvekligande",
    "förvekligandens": "förvekligande",
    "förvekligandes": "förvekligande",
    "förvekligandet": "förvekligande",
    "förvekligandets": "förvekligande",
    "förvekligar": "förvekliga",
    "förvekligas": "förvekliga",
    "förvekligat": "förvekliga",
    "förvekligats": "förvekliga",
    "förverk": "förverka",
    "förverkad": "förverka",
    "förverkade": "förverka",
    "förverkades": "förverka",
    "förverkads": "förverka",
    "förverkande": "förverka",
    "förverkanden": "förverkande",
    "förverkandena": "förverkande",
    "förverkandenas": "förverkande",
    "förverkandens": "förverkande",
    "förverkandes": "förverkande",
    "förverkandet": "förverkande",
    "förverkandets": "förverkande",
    "förverkar": "förverka",
    "förverkas": "förverka",
    "förverkat": "förverka",
    "förverkats": "förverka",
    "förverklig": "förverkliga",
    "förverkligad": "förverkliga",
    "förverkligade": "förverkliga",
    "förverkligades": "förverkliga",
    "förverkligads": "förverkliga",
    "förverkligande": "förverkliga",
    "förverkliganden": "förverkligande",
    "förverkligandena": "förverkligande",
    "förverkligandenas": "förverkligande",
    "förverkligandens": "förverkligande",
    "förverkligandes": "förverkligande",
    "förverkligandet": "förverkligande",
    "förverkligandets": "förverkligande",
    "förverkligar": "förverkliga",
    "förverkligas": "förverkliga",
    "förverkligat": "förverkliga",
    "förverkligats": "förverkliga",
    "förvetenheten": "förvetenhet",
    "förvetenhetens": "förvetenhet",
    "förvetenhets": "förvetenhet",
    "förvetens": "förveten",
    "förvetet": "förveten",
    "förvetets": "förveten",
    "förvetna": "förveten",
    "förvetnare": "förveten",
    "förvetnares": "förveten",
    "förvetnas": "förveten",
    "förvetnast": "förveten",
    "förvetnaste": "förveten",
    "förvetnastes": "förveten",
    "förvetnasts": "förveten",
    "förvetne": "förveten",
    "förvetnes": "förveten",
    "förvildades": "förvildas",
    "förvildats": "förvildas",
    "förvill": "förvilla",
    "förvillad": "förvilla",
    "förvillade": "förvilla",
    "förvillades": "förvilla",
    "förvillads": "förvilla",
    "förvillande": "förvilla",
    "förvillanden": "förvillande",
    "förvillandena": "förvillande",
    "förvillandenas": "förvillande",
    "förvillandens": "förvillande",
    "förvillandes": "förvillande",
    "förvillandet": "förvillande",
    "förvillandets": "förvillande",
    "förvillar": "förvillare",
    "förvillaren": "förvillare",
    "förvillarens": "förvillare",
    "förvillares": "förvillare",
    "förvillarna": "förvillare",
    "förvillarnas": "förvillare",
    "förvillas": "förvilla",
    "förvillat": "förvilla",
    "förvillats": "förvilla",
    "förvillelsen": "förvillelse",
    "förvillelsens": "förvillelse",
    "förvillelser": "förvillelse",
    "förvillelserna": "förvillelse",
    "förvillelsernas": "förvillelse",
    "förvillelsers": "förvillelse",
    "förvillelses": "förvillelse",
    "förvirr": "förvirra",
    "förvirrad": "förvirra",
    "förvirrade": "förvirrad",
    "förvirrades": "förvirrad",
    "förvirrads": "förvirrad",
    "förvirrande": "förvirra",
    "förvirranden": "förvirrande",
    "förvirrandena": "förvirrande",
    "förvirrandenas": "förvirrande",
    "förvirrandens": "förvirrande",
    "förvirrandes": "förvirrande",
    "förvirrandet": "förvirrande",
    "förvirrandets": "förvirrande",
    "förvirrar": "förvirra",
    "förvirras": "förvirra",
    "förvirrat": "förvirrad",
    "förvirrats": "förvirrad",
    "förvirringar": "förvirring",
    "förvirringarna": "förvirring",
    "förvirringarnas": "förvirring",
    "förvirringars": "förvirring",
    "förvirringen": "förvirring",
    "förvirringens": "förvirring",
    "förvirrings": "förvirring",
    "förvis": "förvisa",
    "förvisad": "förvisa",
    "förvisade": "förvisa",
    "förvisades": "förvisa",
    "förvisads": "förvisa",
    "förvisande": "förvisa",
    "förvisanden": "förvisande",
    "förvisandena": "förvisande",
    "förvisandenas": "förvisande",
    "förvisandens": "förvisande",
    "förvisandes": "förvisande",
    "förvisandet": "förvisande",
    "förvisandets": "förvisande",
    "förvisar": "förvisa",
    "förvisas": "förvisa",
    "förvisat": "förvisa",
    "förvisats": "förvisa",
    "förvisningar": "förvisning",
    "förvisningarna": "förvisning",
    "förvisningarnas": "förvisning",
    "förvisningars": "förvisning",
    "förvisningen": "förvisning",
    "förvisningens": "förvisning",
    "förvisnings": "förvisning",
    "förviss": "förvissa",
    "förvissad": "förvissa",
    "förvissade": "förvissa",
    "förvissades": "förvissa",
    "förvissads": "förvissa",
    "förvissande": "förvissa",
    "förvissanden": "förvissande",
    "förvissandena": "förvissande",
    "förvissandenas": "förvissande",
    "förvissandens": "förvissande",
    "förvissandes": "förvissande",
    "förvissandet": "förvissande",
    "förvissandets": "förvissande",
    "förvissar": "förvissa",
    "förvissas": "förvissa",
    "förvissat": "förvissa",
    "förvissats": "förvissa",
    "förvissn": "förvissna",
    "förvissnad": "förvissna",
    "förvissnade": "förvissna",
    "förvissnades": "förvissna",
    "förvissnads": "förvissna",
    "förvissnande": "förvissna",
    "förvissnanden": "förvissnande",
    "förvissnandena": "förvissnande",
    "förvissnandenas": "förvissnande",
    "förvissnandens": "förvissnande",
    "förvissnandes": "förvissnande",
    "förvissnandet": "förvissnande",
    "förvissnandets": "förvissnande",
    "förvissnar": "förvissna",
    "förvissnas": "förvissna",
    "förvissnat": "förvissna",
    "förvissnats": "förvissna",
    "förvissningar": "förvissning",
    "förvissningarna": "förvissning",
    "förvissningarnas": "förvissning",
    "förvissningars": "förvissning",
    "förvissningen": "förvissning",
    "förvissningens": "förvissning",
    "förvissnings": "förvissning",
    "förvittrad": "förvittra",
    "förvittrade": "förvittra",
    "förvittrades": "förvittra",
    "förvittrads": "förvittra",
    "förvittrande": "förvittra",
    "förvittranden": "förvittrande",
    "förvittrandena": "förvittrande",
    "förvittrandenas": "förvittrande",
    "förvittrandens": "förvittrande",
    "förvittrandes": "förvittrande",
    "förvittrandet": "förvittrande",
    "förvittrandets": "förvittrande",
    "förvittrar": "förvittra",
    "förvittras": "förvittra",
    "förvittrat": "förvittra",
    "förvittrats": "förvittra",
    "förvittringar": "förvittring",
    "förvittringarna": "förvittring",
    "förvittringarnas": "förvittring",
    "förvittringars": "förvittring",
    "förvittringen": "förvittring",
    "förvittringens": "förvittring",
    "förvittrings": "förvittring",
    "förvred": "förvrida",
    "förvreds": "förvrida",
    "förvrid": "förvrida",
    "förvridande": "förvrida",
    "förvridanden": "förvridande",
    "förvridandena": "förvridande",
    "förvridandenas": "förvridande",
    "förvridandens": "förvridande",
    "förvridandes": "förvridande",
    "förvridandet": "förvridande",
    "förvridandets": "förvridande",
    "förvridas": "förvrida",
    "förvride": "förvrida",
    "förvriden": "förvrida",
    "förvridens": "förvrida",
    "förvrider": "förvrida",
    "förvrides": "förvrida",
    "förvridet": "förvrida",
    "förvridets": "förvrida",
    "förvridit": "förvrida",
    "förvridits": "förvrida",
    "förvridna": "förvrida",
    "förvridnas": "förvrida",
    "förvridne": "förvrida",
    "förvridnes": "förvrida",
    "förvrids": "förvrida",
    "förvräng": "förvränga",
    "förvrängande": "förvränga",
    "förvränganden": "förvrängande",
    "förvrängandena": "förvrängande",
    "förvrängandenas": "förvrängande",
    "förvrängandens": "förvrängande",
    "förvrängandes": "förvrängande",
    "förvrängandet": "förvrängande",
    "förvrängandets": "förvrängande",
    "förvrängas": "förvränga",
    "förvrängd": "förvränga",
    "förvrängda": "förvränga",
    "förvrängdas": "förvränga",
    "förvrängde": "förvränga",
    "förvrängdes": "förvränga",
    "förvrängds": "förvränga",
    "förvränger": "förvränga",
    "förvränges": "förvränga",
    "förvrängningar": "förvrängning",
    "förvrängningarna": "förvrängning",
    "förvrängningarnas": "förvrängning",
    "förvrängningars": "förvrängning",
    "förvrängningen": "förvrängning",
    "förvrängningens": "förvrängning",
    "förvrängnings": "förvrängning",
    "förvrängs": "förvränga",
    "förvrängt": "förvränga",
    "förvrängts": "förvränga",
    "förvunna": "förvunnen",
    "förvunnare": "förvunnen",
    "förvunnares": "förvunnen",
    "förvunnas": "förvunnen",
    "förvunnast": "förvunnen",
    "förvunnaste": "förvunnen",
    "förvunnastes": "förvunnen",
    "förvunnasts": "förvunnen",
    "förvunne": "förvunnen",
    "förvunnens": "förvunnen",
    "förvunnes": "förvunnen",
    "förvunnet": "förvunnen",
    "förvunnets": "förvunnen",
    "förvuxenheten": "förvuxenhet",
    "förvuxenhetens": "förvuxenhet",
    "förvuxenhets": "förvuxenhet",
    "förvuxens": "förvuxen",
    "förvuxet": "förvuxen",
    "förvuxets": "förvuxen",
    "förvuxna": "förvuxen",
    "förvuxnare": "förvuxen",
    "förvuxnares": "förvuxen",
    "förvuxnas": "förvuxen",
    "förvuxnast": "förvuxen",
    "förvuxnaste": "förvuxen",
    "förvuxnastes": "förvuxen",
    "förvuxnasts": "förvuxen",
    "förvuxne": "förvuxen",
    "förvuxnes": "förvuxen",
    "förvägenheten": "förvägenhet",
    "förvägenhetens": "förvägenhet",
    "förvägenhets": "förvägenhet",
    "förvägens": "förvägen",
    "förväget": "förvägen",
    "förvägets": "förvägen",
    "förvägna": "förvägen",
    "förvägnare": "förvägen",
    "förvägnares": "förvägen",
    "förvägnas": "förvägen",
    "förvägnast": "förvägen",
    "förvägnaste": "förvägen",
    "förvägnastes": "förvägen",
    "förvägnasts": "förvägen",
    "förvägne": "förvägen",
    "förvägnes": "förvägen",
    "förvägrad": "förvägra",
    "förvägrade": "förvägra",
    "förvägrades": "förvägra",
    "förvägrads": "förvägra",
    "förvägrande": "förvägra",
    "förvägranden": "förvägrande",
    "förvägrandena": "förvägrande",
    "förvägrandenas": "förvägrande",
    "förvägrandens": "förvägrande",
    "förvägrandes": "förvägrande",
    "förvägrandet": "förvägrande",
    "förvägrandets": "förvägrande",
    "förvägrar": "förvägra",
    "förvägras": "förvägra",
    "förvägrat": "förvägra",
    "förvägrats": "förvägra",
    "förväljar": "förväljare",
    "förväljaren": "förväljare",
    "förväljarens": "förväljare",
    "förväljares": "förväljare",
    "förväljarna": "förväljare",
    "förväljarnas": "förväljare",
    "förväll": "förvälla",
    "förvällande": "förvälla",
    "förvällanden": "förvällande",
    "förvällandena": "förvällande",
    "förvällandenas": "förvällande",
    "förvällandens": "förvällande",
    "förvällandes": "förvällande",
    "förvällandet": "förvällande",
    "förvällandets": "förvällande",
    "förvällas": "förvälla",
    "förvälld": "förvälla",
    "förvällda": "förvälla",
    "förvälldas": "förvälla",
    "förvällde": "förvälla",
    "förvälldes": "förvälla",
    "förvällds": "förvälla",
    "förväller": "förvälla",
    "förvälles": "förvälla",
    "förvälls": "förvälla",
    "förvällt": "förvälla",
    "förvällts": "förvälla",
    "förvänd": "förvända",
    "förvända": "förvänd",
    "förvändande": "förvända",
    "förvändanden": "förvändande",
    "förvändandena": "förvändande",
    "förvändandenas": "förvändande",
    "förvändandens": "förvändande",
    "förvändandes": "förvändande",
    "förvändandet": "förvändande",
    "förvändandets": "förvändande",
    "förvändare": "förvänd",
    "förvändares": "förvänd",
    "förvändas": "förvända",
    "förvändast": "förvänd",
    "förvändaste": "förvänd",
    "förvändastes": "förvänd",
    "förvändasts": "förvänd",
    "förvände": "förvända",
    "förvänder": "förvända",
    "förvändes": "förvända",
    "förvänds": "förvända",
    "förvänt": "förvänta",
    "förväntad": "förvänta",
    "förväntade": "förvänta",
    "förväntades": "förvänta",
    "förväntads": "förvänta",
    "förväntande": "förvänta",
    "förväntanden": "förväntande",
    "förväntandena": "förväntande",
    "förväntandenas": "förväntande",
    "förväntandens": "förväntande",
    "förväntandes": "förväntande",
    "förväntandet": "förväntande",
    "förväntandets": "förväntande",
    "förväntans": "förväntan",
    "förväntansfulla": "förväntansfull",
    "förväntansfullare": "förväntansfull",
    "förväntansfullares": "förväntansfull",
    "förväntansfullas": "förväntansfull",
    "förväntansfullast": "förväntansfull",
    "förväntansfullaste": "förväntansfull",
    "förväntansfullastes": "förväntansfull",
    "förväntansfullasts": "förväntansfull",
    "förväntansfulle": "förväntansfull",
    "förväntansfulles": "förväntansfull",
    "förväntansfullheten": "förväntansfullhet",
    "förväntansfullhetens": "förväntansfullhet",
    "förväntansfullhets": "förväntansfullhet",
    "förväntansfulls": "förväntansfull",
    "förväntansfullt": "förväntansfull",
    "förväntansfullts": "förväntansfull",
    "förväntar": "förvänta",
    "förväntas": "förvänta",
    "förväntat": "förvänta",
    "förväntats": "förvänta",
    "förväntningar": "förväntning",
    "förväntningarna": "förväntning",
    "förväntningarnas": "förväntning",
    "förväntningars": "förväntning",
    "förväntningen": "förväntning",
    "förväntningens": "förväntning",
    "förväntnings": "förväntning",
    "förvänts": "förvända",
    "förvärldslig": "förvärldsliga",
    "förvärldsligad": "förvärldsliga",
    "förvärldsligade": "förvärldsliga",
    "förvärldsligades": "förvärldsliga",
    "förvärldsligads": "förvärldsliga",
    "förvärldsligande": "förvärldsliga",
    "förvärldsliganden": "förvärldsligande",
    "förvärldsligandena": "förvärldsligande",
    "förvärldsligandenas": "förvärldsligande",
    "förvärldsligandens": "förvärldsligande",
    "förvärldsligandes": "förvärldsligande",
    "förvärldsligandet": "förvärldsligande",
    "förvärldsligandets": "förvärldsligande",
    "förvärldsligar": "förvärldsliga",
    "förvärldsligas": "förvärldsliga",
    "förvärldsligat": "förvärldsliga",
    "förvärldsligats": "förvärldsliga",
    "förvärmar": "förvärmare",
    "förvärmaren": "förvärmare",
    "förvärmarens": "förvärmare",
    "förvärmares": "förvärmare",
    "förvärmarna": "förvärmare",
    "förvärmarnas": "förvärmare",
    "förvärrad": "förvärra",
    "förvärrade": "förvärra",
    "förvärrades": "förvärra",
    "förvärrads": "förvärra",
    "förvärrande": "förvärra",
    "förvärranden": "förvärrande",
    "förvärrandena": "förvärrande",
    "förvärrandenas": "förvärrande",
    "förvärrandens": "förvärrande",
    "förvärrandes": "förvärrande",
    "förvärrandet": "förvärrande",
    "förvärrandets": "förvärrande",
    "förvärrar": "förvärra",
    "förvärras": "förvärra",
    "förvärrat": "förvärra",
    "förvärrats": "förvärra",
    "förvärvad": "förvärva",
    "förvärvade": "förvärva",
    "förvärvades": "förvärva",
    "förvärvads": "förvärva",
    "förvärvande": "förvärva",
    "förvärvanden": "förvärvande",
    "förvärvandena": "förvärvande",
    "förvärvandenas": "förvärvande",
    "förvärvandens": "förvärvande",
    "förvärvandes": "förvärvande",
    "förvärvandet": "förvärvande",
    "förvärvandets": "förvärvande",
    "förvärvar": "förvärva",
    "förvärvas": "förvärva",
    "förvärvat": "förvärva",
    "förvärvats": "förvärva",
    "förvärven": "förvärv",
    "förvärvens": "förvärv",
    "förvärvet": "förvärv",
    "förvärvets": "förvärv",
    "förvärvs": "förvärv",
    "förvärvsarbetade": "förvärvsarbeta",
    "förvärvsarbetades": "förvärvsarbeta",
    "förvärvsarbetande": "förvärvsarbeta",
    "förvärvsarbetanden": "förvärvsarbetande",
    "förvärvsarbetandena": "förvärvsarbetande",
    "förvärvsarbetandenas": "förvärvsarbetande",
    "förvärvsarbetandens": "förvärvsarbetande",
    "förvärvsarbetandes": "förvärvsarbetande",
    "förvärvsarbetandet": "förvärvsarbetande",
    "förvärvsarbetandets": "förvärvsarbetande",
    "förvärvsarbetar": "förvärvsarbeta",
    "förvärvsarbetas": "förvärvsarbeta",
    "förvärvsarbetat": "förvärvsarbeta",
    "förvärvsarbetats": "förvärvsarbeta",
    "förvärvsavdragen": "förvärvsavdrag",
    "förvärvsavdragens": "förvärvsavdrag",
    "förvärvsavdraget": "förvärvsavdrag",
    "förvärvsavdragets": "förvärvsavdrag",
    "förvärvsavdrags": "förvärvsavdrag",
    "förvärvskäll": "förvärvskälla",
    "förvärvskällan": "förvärvskälla",
    "förvärvskällans": "förvärvskälla",
    "förvärvskällas": "förvärvskälla",
    "förvärvskälle": "förvärvskälla",
    "förvärvskällor": "förvärvskälla",
    "förvärvskällorna": "förvärvskälla",
    "förvärvskällornas": "förvärvskälla",
    "förvärvskällors": "förvärvskälla",
    "förvärvskälls": "förvärvskälla",
    "förvärvslivet": "förvärvsliv",
    "förvärvslivets": "förvärvsliv",
    "förvärvslivs": "förvärvsliv",
    "förvärvslystenheten": "förvärvslystenhet",
    "förvärvslystenhetens": "förvärvslystenhet",
    "förvärvslystenhets": "förvärvslystenhet",
    "förvärvslystens": "förvärvslysten",
    "förvärvslystet": "förvärvslysten",
    "förvärvslystets": "förvärvslysten",
    "förvärvslystna": "förvärvslysten",
    "förvärvslystnare": "förvärvslysten",
    "förvärvslystnares": "förvärvslysten",
    "förvärvslystnas": "förvärvslysten",
    "förvärvslystnast": "förvärvslysten",
    "förvärvslystnaste": "förvärvslysten",
    "förvärvslystnastes": "förvärvslysten",
    "förvärvslystnasts": "förvärvslysten",
    "förvärvslystne": "förvärvslysten",
    "förvärvslystnes": "förvärvslysten",
    "förvärvsmässiga": "förvärvsmässig",
    "förvärvsmässigare": "förvärvsmässig",
    "förvärvsmässigares": "förvärvsmässig",
    "förvärvsmässigas": "förvärvsmässig",
    "förvärvsmässigast": "förvärvsmässig",
    "förvärvsmässigaste": "förvärvsmässig",
    "förvärvsmässigastes": "förvärvsmässig",
    "förvärvsmässigasts": "förvärvsmässig",
    "förvärvsmässige": "förvärvsmässig",
    "förvärvsmässiges": "förvärvsmässig",
    "förvärvsmässigs": "förvärvsmässig",
    "förvärvsmässigt": "förvärvsmässig",
    "förvärvsmässigts": "förvärvsmässig",
    "förvärvsverksamheten": "förvärvsverksamhet",
    "förvärvsverksamhetens": "förvärvsverksamhet",
    "förvärvsverksamheter": "förvärvsverksamhet",
    "förvärvsverksamheterna": "förvärvsverksamhet",
    "förvärvsverksamheternas": "förvärvsverksamhet",
    "förvärvsverksamheters": "förvärvsverksamhet",
    "förvärvsverksamhets": "förvärvsverksamhet",
    "förväxlad": "förväxla",
    "förväxlade": "förväxla",
    "förväxlades": "förväxla",
    "förväxlads": "förväxla",
    "förväxlande": "förväxla",
    "förväxlanden": "förväxlande",
    "förväxlandena": "förväxlande",
    "förväxlandenas": "förväxlande",
    "förväxlandens": "förväxlande",
    "förväxlandes": "förväxlande",
    "förväxlandet": "förväxlande",
    "förväxlandets": "förväxlande",
    "förväxlar": "förväxla",
    "förväxlas": "förväxla",
    "förväxlat": "förväxla",
    "förväxlats": "förväxla",
    "förväxlingar": "förväxling",
    "förväxlingarna": "förväxling",
    "förväxlingarnas": "förväxling",
    "förväxlingars": "förväxling",
    "förväxlingen": "förväxling",
    "förväxlingens": "förväxling",
    "förväxlings": "förväxling",
    "förväxlingslekar": "förväxlingslek",
    "förväxlingslekarna": "förväxlingslek",
    "förväxlingslekarnas": "förväxlingslek",
    "förväxlingslekars": "förväxlingslek",
    "förväxlingsleken": "förväxlingslek",
    "förväxlingslekens": "förväxlingslek",
    "förväxlingsleks": "förväxlingslek",
    "förväxta": "förväxt",
    "förväxtare": "förväxt",
    "förväxtares": "förväxt",
    "förväxtas": "förväxt",
    "förväxtast": "förväxt",
    "förväxtaste": "förväxt",
    "förväxtastes": "förväxt",
    "förväxtasts": "förväxt",
    "förväxte": "förväxt",
    "förväxtes": "förväxt",
    "förväxts": "förväxt",
    "förvåll": "förvålla",
    "förvållad": "förvålla",
    "förvållade": "förvålla",
    "förvållades": "förvålla",
    "förvållads": "förvålla",
    "förvållande": "förvålla",
    "förvållandes": "förvållande",
    "förvållandet": "förvållande",
    "förvållandets": "förvållande",
    "förvållans": "förvållan",
    "förvållar": "förvålla",
    "förvållas": "förvålla",
    "förvållat": "förvålla",
    "förvållats": "förvålla",
    "förvån": "förvåna",
    "förvånad": "förvåna",
    "förvånade": "förvånad",
    "förvånades": "förvånad",
    "förvånads": "förvånad",
    "förvånande": "förvåna",
    "förvånanden": "förvånande",
    "förvånandena": "förvånande",
    "förvånandenas": "förvånande",
    "förvånandens": "förvånande",
    "förvånandes": "förvånande",
    "förvånandet": "förvånande",
    "förvånandets": "förvånande",
    "förvånansvärda": "förvånansvärd",
    "förvånansvärdare": "förvånansvärd",
    "förvånansvärdares": "förvånansvärd",
    "förvånansvärdas": "förvånansvärd",
    "förvånansvärdast": "förvånansvärd",
    "förvånansvärdaste": "förvånansvärd",
    "förvånansvärdastes": "förvånansvärd",
    "förvånansvärdasts": "förvånansvärd",
    "förvånansvärde": "förvånansvärd",
    "förvånansvärdes": "förvånansvärd",
    "förvånansvärds": "förvånansvärd",
    "förvånansvärt": "förvånansvärd",
    "förvånansvärts": "förvånansvärd",
    "förvånar": "förvåna",
    "förvånas": "förvåna",
    "förvånat": "förvånad",
    "förvånats": "förvånad",
    "förvåningar": "förvåning",
    "förvåningarna": "förvåning",
    "förvåningarnas": "förvåning",
    "förvåningars": "förvåning",
    "förvåningen": "förvåning",
    "förvåningens": "förvåning",
    "förvånings": "förvåning",
    "föryngrad": "föryngra",
    "föryngrade": "föryngra",
    "föryngrades": "föryngra",
    "föryngrads": "föryngra",
    "föryngrande": "föryngra",
    "föryngranden": "föryngrande",
    "föryngrandena": "föryngrande",
    "föryngrandenas": "föryngrande",
    "föryngrandens": "föryngrande",
    "föryngrandes": "föryngrande",
    "föryngrandet": "föryngrande",
    "föryngrandets": "föryngrande",
    "föryngrar": "föryngra",
    "föryngras": "föryngra",
    "föryngrat": "föryngra",
    "föryngrats": "föryngra",
    "föryngringar": "föryngring",
    "föryngringarna": "föryngring",
    "föryngringarnas": "föryngring",
    "föryngringars": "föryngring",
    "föryngringen": "föryngring",
    "föryngringens": "föryngring",
    "föryngrings": "föryngring",
    "föryngringsytan": "föryngringsyta",
    "föryngringsytans": "föryngringsyta",
    "föryngringsytas": "föryngringsyta",
    "föryngringsyte": "föryngringsyta",
    "föryngringsytor": "föryngringsyta",
    "föryngringsytorna": "föryngringsyta",
    "föryngringsytornas": "föryngringsyta",
    "föryngringsytors": "föryngringsyta",
    "förzink": "förzinka",
    "förzinkad": "förzinka",
    "förzinkade": "förzinka",
    "förzinkades": "förzinka",
    "förzinkads": "förzinka",
    "förzinkande": "förzinka",
    "förzinkanden": "förzinkande",
    "förzinkandena": "förzinkande",
    "förzinkandenas": "förzinkande",
    "förzinkandens": "förzinkande",
    "förzinkandes": "förzinkande",
    "förzinkandet": "förzinkande",
    "förzinkandets": "förzinkande",
    "förzinkar": "förzinka",
    "förzinkas": "förzinka",
    "förzinkat": "förzinka",
    "förzinkats": "förzinka",
    "förädlad": "förädla",
    "förädlade": "förädla",
    "förädlades": "förädla",
    "förädlads": "förädla",
    "förädlande": "förädla",
    "förädlanden": "förädlande",
    "förädlandena": "förädlande",
    "förädlandenas": "förädlande",
    "förädlandens": "förädlande",
    "förädlandes": "förädlande",
    "förädlandet": "förädlande",
    "förädlandets": "förädlande",
    "förädlar": "förädla",
    "förädlas": "förädla",
    "förädlat": "förädla",
    "förädlats": "förädla",
    "förädlingar": "förädling",
    "förädlingarna": "förädling",
    "förädlingarnas": "förädling",
    "förädlingars": "förädling",
    "förädlingen": "förädling",
    "förädlingens": "förädling",
    "förädlings": "förädling",
    "förädlingsarbeten": "förädlingsarbete",
    "förädlingsarbetena": "förädlingsarbete",
    "förädlingsarbetenas": "förädlingsarbete",
    "förädlingsarbetens": "förädlingsarbete",
    "förädlingsarbetes": "förädlingsarbete",
    "förädlingsarbetet": "förädlingsarbete",
    "förädlingsarbetets": "förädlingsarbete",
    "förädlingsarbets": "förädlingsarbete",
    "föräktenskapliga": "föräktenskaplig",
    "föräktenskapligare": "föräktenskaplig",
    "föräktenskapligares": "föräktenskaplig",
    "föräktenskapligas": "föräktenskaplig",
    "föräktenskapligast": "föräktenskaplig",
    "föräktenskapligaste": "föräktenskaplig",
    "föräktenskapligastes": "föräktenskaplig",
    "föräktenskapligasts": "föräktenskaplig",
    "föräktenskaplige": "föräktenskaplig",
    "föräktenskapliges": "föräktenskaplig",
    "föräktenskapligheten": "föräktenskaplighet",
    "föräktenskaplighetens": "föräktenskaplighet",
    "föräktenskaplighets": "föräktenskaplighet",
    "föräktenskapligs": "föräktenskaplig",
    "föräktenskapligt": "föräktenskaplig",
    "föräktenskapligts": "föräktenskaplig",
    "föräldern": "förälder",
    "förälderns": "förälder",
    "förälders": "förälder",
    "föräldraansvaret": "föräldraansvar",
    "föräldraansvarets": "föräldraansvar",
    "föräldraansvars": "föräldraansvar",
    "föräldrabalkar": "föräldrabalk",
    "föräldrabalkarna": "föräldrabalk",
    "föräldrabalkarnas": "föräldrabalk",
    "föräldrabalkars": "föräldrabalk",
    "föräldrabalken": "föräldrabalk",
    "föräldrabalkens": "föräldrabalk",
    "föräldrabalks": "föräldrabalk",
    "föräldrabesöken": "föräldrabesök",
    "föräldrabesökens": "föräldrabesök",
    "föräldrabesöket": "föräldrabesök",
    "föräldrabesökets": "föräldrabesök",
    "föräldrabesöks": "föräldrabesök",
    "föräldradagar": "föräldradag",
    "föräldradagarna": "föräldradag",
    "föräldradagarnas": "föräldradag",
    "föräldradagars": "föräldradag",
    "föräldradagen": "föräldradag",
    "föräldradagens": "föräldradag",
    "föräldradags": "föräldradag",
    "föräldrafria": "föräldrafri",
    "föräldrafriare": "föräldrafri",
    "föräldrafriares": "föräldrafri",
    "föräldrafrias": "föräldrafri",
    "föräldrafriast": "föräldrafri",
    "föräldrafriaste": "föräldrafri",
    "föräldrafriastes": "föräldrafri",
    "föräldrafriasts": "föräldrafri",
    "föräldrafrie": "föräldrafri",
    "föräldrafries": "föräldrafri",
    "föräldrafris": "föräldrafri",
    "föräldrafritt": "föräldrafri",
    "föräldrafritts": "föräldrafri",
    "föräldraförmånen": "föräldraförmån",
    "föräldraförmånens": "föräldraförmån",
    "föräldraförmåner": "föräldraförmån",
    "föräldraförmånerna": "föräldraförmån",
    "föräldraförmånernas": "föräldraförmån",
    "föräldraförmåners": "föräldraförmån",
    "föräldraförmåns": "föräldraförmån",
    "föräldraförsäkringar": "föräldraförsäkring",
    "föräldraförsäkringarna": "föräldraförsäkring",
    "föräldraförsäkringarnas": "föräldraförsäkring",
    "föräldraförsäkringars": "föräldraförsäkring",
    "föräldraförsäkringen": "föräldraförsäkring",
    "föräldraförsäkringens": "föräldraförsäkring",
    "föräldraförsäkrings": "föräldraförsäkring",
    "föräldrahemmen": "föräldrahem",
    "föräldrahemmens": "föräldrahem",
    "föräldrahemmet": "föräldrahem",
    "föräldrahemmets": "föräldrahem",
    "föräldrahems": "föräldrahem",
    "föräldrakärleken": "föräldrakärlek",
    "föräldrakärlekens": "föräldrakärlek",
    "föräldrakärleks": "föräldrakärlek",
    "föräldralediga": "föräldraledig",
    "föräldraledigare": "föräldraledig",
    "föräldraledigares": "föräldraledig",
    "föräldraledigas": "föräldraledig",
    "föräldraledigast": "föräldraledig",
    "föräldraledigaste": "föräldraledig",
    "föräldraledigastes": "föräldraledig",
    "föräldraledigasts": "föräldraledig",
    "föräldraledige": "föräldraledig",
    "föräldralediges": "föräldraledig",
    "föräldraledigheten": "föräldraledighet",
    "föräldraledighetens": "föräldraledighet",
    "föräldraledigheter": "föräldraledighet",
    "föräldraledigheterna": "föräldraledighet",
    "föräldraledigheternas": "föräldraledighet",
    "föräldraledigheters": "föräldraledighet",
    "föräldraledighets": "föräldraledighet",
    "föräldraledigs": "föräldraledig",
    "föräldraledigt": "föräldraledig",
    "föräldraledigts": "föräldraledig",
    "föräldralösa": "föräldralös",
    "föräldralösare": "föräldralös",
    "föräldralösares": "föräldralös",
    "föräldralösas": "föräldralös",
    "föräldralösast": "föräldralös",
    "föräldralösaste": "föräldralös",
    "föräldralösastes": "föräldralös",
    "föräldralösasts": "föräldralös",
    "föräldralöse": "föräldralös",
    "föräldralöses": "föräldralös",
    "föräldralösheten": "föräldralöshet",
    "föräldralöshetens": "föräldralöshet",
    "föräldralöshets": "föräldralöshet",
    "föräldralöst": "föräldralös",
    "föräldralösts": "föräldralös",
    "föräldramöten": "föräldramöte",
    "föräldramötena": "föräldramöte",
    "föräldramötenas": "föräldramöte",
    "föräldramötens": "föräldramöte",
    "föräldramötes": "föräldramöte",
    "föräldramötet": "föräldramöte",
    "föräldramötets": "föräldramöte",
    "föräldrapenningar": "föräldrapenning",
    "föräldrapenningarna": "föräldrapenning",
    "föräldrapenningarnas": "föräldrapenning",
    "föräldrapenningars": "föräldrapenning",
    "föräldrapenningen": "föräldrapenning",
    "föräldrapenningens": "föräldrapenning",
    "föräldrapennings": "föräldrapenning",
    "föräldrar": "förälder",
    "föräldrarna": "förälder",
    "föräldrarnas": "förälder",
    "föräldrars": "förälder",
    "föräldraskapet": "föräldraskap",
    "föräldraskapets": "föräldraskap",
    "föräldraskaps": "föräldraskap",
    "föräldraträden": "föräldraträd",
    "föräldraträdens": "föräldraträd",
    "föräldraträdet": "föräldraträd",
    "föräldraträdets": "föräldraträd",
    "föräldraträds": "föräldraträd",
    "föräldraträn": "föräldraträd",
    "föräldraträna": "föräldraträd",
    "föräldratränas": "föräldraträd",
    "föräldraträns": "föräldraträd",
    "förälskade": "förälskad",
    "förälskades": "förälskad",
    "förälskads": "förälskad",
    "förälskat": "förälskad",
    "förälskats": "förälskad",
    "förälskelsen": "förälskelse",
    "förälskelsens": "förälskelse",
    "förälskelser": "förälskelse",
    "förälskelserna": "förälskelse",
    "förälskelsernas": "förälskelse",
    "förälskelsers": "förälskelse",
    "förälskelses": "förälskelse",
    "föränderliga": "föränderlig",
    "föränderligare": "föränderlig",
    "föränderligares": "föränderlig",
    "föränderligas": "föränderlig",
    "föränderligast": "föränderlig",
    "föränderligaste": "föränderlig",
    "föränderligastes": "föränderlig",
    "föränderligasts": "föränderlig",
    "föränderlige": "föränderlig",
    "föränderliges": "föränderlig",
    "föränderligheten": "föränderlighet",
    "föränderlighetens": "föränderlighet",
    "föränderlighets": "föränderlighet",
    "föränderligs": "föränderlig",
    "föränderligt": "föränderlig",
    "föränderligts": "föränderlig",
    "förändrad": "förändra",
    "förändrade": "förändra",
    "förändrades": "förändra",
    "förändrads": "förändra",
    "förändrande": "förändra",
    "förändranden": "förändrande",
    "förändrandena": "förändrande",
    "förändrandenas": "förändrande",
    "förändrandens": "förändrande",
    "förändrandes": "förändrande",
    "förändrandet": "förändrande",
    "förändrandets": "förändrande",
    "förändrar": "förändra",
    "förändras": "förändra",
    "förändrat": "förändra",
    "förändrats": "förändra",
    "förändringar": "förändring",
    "förändringarna": "förändring",
    "förändringarnas": "förändring",
    "förändringars": "förändring",
    "förändringen": "förändring",
    "förändringens": "förändring",
    "förändrings": "förändring",
    "förändringstakten": "förändringstakt",
    "förändringstaktens": "förändringstakt",
    "förändringstakter": "förändringstakt",
    "förändringstakterna": "förändringstakt",
    "förändringstakternas": "förändringstakt",
    "förändringstakters": "förändringstakt",
    "förändringstakts": "förändringstakt",
    "förär": "förära",
    "förärad": "förära",
    "förärade": "förära",
    "förärades": "förära",
    "förärads": "förära",
    "förärande": "förära",
    "föräranden": "förärande",
    "förärandena": "förärande",
    "förärandenas": "förärande",
    "förärandens": "förärande",
    "förärandes": "förärande",
    "förärandet": "förärande",
    "förärandets": "förärande",
    "förärar": "förära",
    "föräras": "förära",
    "förärat": "förära",
    "förärats": "förära",
    "föråldrade": "föråldrad",
    "föråldrades": "föråldrad",
    "föråldrads": "föråldrad",
    "föråldrat": "föråldrad",
    "föråldrats": "föråldrad",
    "förång": "förånga",
    "förångad": "förånga",
    "förångade": "förånga",
    "förångades": "förånga",
    "förångads": "förånga",
    "förångande": "förånga",
    "förånganden": "förångande",
    "förångandena": "förångande",
    "förångandenas": "förångande",
    "förångandens": "förångande",
    "förångandes": "förångande",
    "förångandet": "förångande",
    "förångandets": "förångande",
    "förångar": "förånga",
    "förångas": "förånga",
    "förångat": "förånga",
    "förångats": "förånga",
    "föröd": "föröda",
    "förödande": "föröda",
    "förödanden": "förödande",
    "förödandena": "förödande",
    "förödandenas": "förödande",
    "förödandens": "förödande",
    "förödandes": "förödande",
    "förödandet": "förödande",
    "förödandets": "förödande",
    "förödas": "föröda",
    "förödd": "föröda",
    "förödda": "föröda",
    "föröddas": "föröda",
    "förödde": "föröda",
    "föröddes": "föröda",
    "förödds": "föröda",
    "förödelsen": "förödelse",
    "förödelsens": "förödelse",
    "förödelser": "förödelse",
    "förödelserna": "förödelse",
    "förödelsernas": "förödelse",
    "förödelsers": "förödelse",
    "förödelses": "förödelse",
    "föröder": "föröda",
    "förödes": "föröda",
    "förödmjuk": "förödmjuka",
    "förödmjukad": "förödmjuka",
    "förödmjukade": "förödmjuka",
    "förödmjukades": "förödmjuka",
    "förödmjukads": "förödmjuka",
    "förödmjukande": "förödmjuka",
    "förödmjukanden": "förödmjukande",
    "förödmjukandena": "förödmjukande",
    "förödmjukandenas": "förödmjukande",
    "förödmjukandens": "förödmjukande",
    "förödmjukandes": "förödmjukande",
    "förödmjukandet": "förödmjukande",
    "förödmjukandets": "förödmjukande",
    "förödmjukar": "förödmjuka",
    "förödmjukas": "förödmjuka",
    "förödmjukat": "förödmjuka",
    "förödmjukats": "förödmjuka",
    "förödmjukelsen": "förödmjukelse",
    "förödmjukelsens": "förödmjukelse",
    "förödmjukelser": "förödmjukelse",
    "förödmjukelserna": "förödmjukelse",
    "förödmjukelsernas": "förödmjukelse",
    "förödmjukelsers": "förödmjukelse",
    "förödmjukelses": "förödmjukelse",
    "föröds": "föröda",
    "förök": "föröka",
    "förökad": "föröka",
    "förökade": "föröka",
    "förökades": "föröka",
    "förökads": "föröka",
    "förökande": "föröka",
    "förökanden": "förökande",
    "förökandena": "förökande",
    "förökandenas": "förökande",
    "förökandens": "förökande",
    "förökandes": "förökande",
    "förökandet": "förökande",
    "förökandets": "förökande",
    "förökar": "föröka",
    "förökas": "föröka",
    "förökat": "föröka",
    "förökats": "föröka",
    "förökningar": "förökning",
    "förökningarna": "förökning",
    "förökningarnas": "förökning",
    "förökningars": "förökning",
    "förökningen": "förökning",
    "förökningens": "förökning",
    "föröknings": "förökning",
    "förött": "föröda",
    "förötts": "föröda",
    "föröv": "föröva",
    "förövad": "föröva",
    "förövade": "föröva",
    "förövades": "föröva",
    "förövads": "föröva",
    "förövande": "föröva",
    "förövanden": "förövande",
    "förövandena": "förövande",
    "förövandenas": "förövande",
    "förövandens": "förövande",
    "förövandes": "förövande",
    "förövandet": "förövande",
    "förövandets": "förövande",
    "förövar": "förövare",
    "förövaren": "förövare",
    "förövarens": "förövare",
    "förövares": "förövare",
    "förövarna": "förövare",
    "förövarnas": "förövare",
    "förövas": "föröva",
    "förövat": "föröva",
    "förövats": "föröva",
    "förövningar": "förövning",
    "förövningarna": "förövning",
    "förövningarnas": "förövning",
    "förövningars": "förövning",
    "förövningen": "förövning",
    "förövningens": "förövning",
    "förövnings": "förövning",
    "fös": "fösa",
    "fösande": "fösa",
    "fösanden": "fösande",
    "fösandena": "fösande",
    "fösandenas": "fösande",
    "fösandens": "fösande",
    "fösandes": "fösande",
    "fösandet": "fösande",
    "fösandets": "fösande",
    "fösas": "fösa",
    "föser": "fösa",
    "föses": "fösa",
    "föst": "fösa",
    "fösta": "fösa",
    "föstas": "fösa",
    "föste": "fösa",
    "föstes": "fösa",
    "fösts": "fösa",
    "fött": "född",
    "fötter": "fot",
    "fötterna": "fot",
    "fötternas": "fot",
    "fötters": "fot",
    "fötts": "född",
    "g-dräkten": "g-dräkt",
    "g-dräktens": "g-dräkt",
    "g-dräkter": "g-dräkt",
    "g-dräkterna": "g-dräkt",
    "g-dräkternas": "g-dräkt",
    "g-dräkters": "g-dräkt",
    "g-dräkts": "g-dräkt",
    "g-et": "g",
    "g-ets": "g",
    "g-klaven": "g-klav",
    "g-klavens": "g-klav",
    "g-klaver": "g-klav",
    "g-klaverna": "g-klav",
    "g-klavernas": "g-klav",
    "g-klavers": "g-klav",
    "g-klavs": "g-klav",
    "g-kraften": "g-kraft",
    "g-krafter": "g-kraft",
    "g-krafternas": "g-kraft",
    "g-krafters": "g-kraft",
    "g-n": "g",
    "g-na": "g",
    "g-nas": "g",
    "g-ns": "g",
    "g-punktens": "g-punkt",
    "g-punkterna": "g-punkt",
    "g-punkters": "g-punkt",
    "g-s": "g",
    "g-t": "g",
    "g-ts": "g",
    "g:et": "g",
    "g:ets": "g",
    "g:n": "g",
    "g:na": "g",
    "g:nas": "g",
    "g:ns": "g",
    "g:s": "g",
    "g:t": "g",
    "g:ts": "g",
    "gabardinen": "gabardin",
    "gabardinens": "gabardin",
    "gabardinet": "gabardin",
    "gabardinets": "gabardin",
    "gabardins": "gabardin",
    "gabbron": "gabbro",
    "gabbrons": "gabbro",
    "gabbros": "gabbro",
    "gabondörrar": "gabondörr",
    "gabondörrarna": "gabondörr",
    "gabondörrarnas": "gabondörr",
    "gabondörrars": "gabondörr",
    "gabondörren": "gabondörr",
    "gabondörrens": "gabondörr",
    "gabondörrs": "gabondörr",
    "gabonen": "gabon",
    "gabonens": "gabon",
    "gaboner": "gabon",
    "gabonerna": "gabon",
    "gabonernas": "gabon",
    "gaboners": "gabon",
    "gabonesen": "gabones",
    "gabonesens": "gabones",
    "gaboneser": "gabones",
    "gaboneserna": "gabones",
    "gabonesernas": "gabones",
    "gabonesers": "gabones",
    "gabonesiska": "gabonesisk",
    "gabonesiskan": "gabonesiska",
    "gabonesiskans": "gabonesiska",
    "gabonesiskare": "gabonesisk",
    "gabonesiskares": "gabonesisk",
    "gabonesiskas": "gabonesiska",
    "gabonesiskast": "gabonesisk",
    "gabonesiskaste": "gabonesisk",
    "gabonesiskastes": "gabonesisk",
    "gabonesiskasts": "gabonesisk",
    "gabonesiske": "gabonesiska",
    "gabonesiskes": "gabonesisk",
    "gabonesiskor": "gabonesiska",
    "gabonesiskorna": "gabonesiska",
    "gabonesiskornas": "gabonesiska",
    "gabonesiskors": "gabonesiska",
    "gabonesisks": "gabonesisk",
    "gabonesiskt": "gabonesisk",
    "gabonesiskts": "gabonesisk",
    "gabonet": "gabon",
    "gabonets": "gabon",
    "gabonhuggormar": "gabonhuggorm",
    "gabonhuggormarna": "gabonhuggorm",
    "gabonhuggormarnas": "gabonhuggorm",
    "gabonhuggormars": "gabonhuggorm",
    "gabonhuggormen": "gabonhuggorm",
    "gabonhuggormens": "gabonhuggorm",
    "gabonhuggorms": "gabonhuggorm",
    "gabons": "gabon",
    "gaddar": "gadd",
    "gaddarna": "gadd",
    "gaddarnas": "gadd",
    "gaddars": "gadd",
    "gadden": "gadd",
    "gaddens": "gadd",
    "gaddlösa": "gaddlös",
    "gaddlösare": "gaddlös",
    "gaddlösares": "gaddlös",
    "gaddlösas": "gaddlös",
    "gaddlösast": "gaddlös",
    "gaddlösaste": "gaddlös",
    "gaddlösastes": "gaddlös",
    "gaddlösasts": "gaddlös",
    "gaddlöse": "gaddlös",
    "gaddlöses": "gaddlös",
    "gaddlösheten": "gaddlöshet",
    "gaddlöshetens": "gaddlöshet",
    "gaddlöshets": "gaddlöshet",
    "gaddlöst": "gaddlös",
    "gaddlösts": "gaddlös",
    "gadds": "gadd",
    "gaddstekeln": "gaddstekel",
    "gaddstekelns": "gaddstekel",
    "gaddstekels": "gaddstekel",
    "gaddsteklar": "gaddstekel",
    "gaddsteklarna": "gaddstekel",
    "gaddsteklarnas": "gaddstekel",
    "gaddsteklars": "gaddstekel",
    "gadoliniet": "gadolinium",
    "gadoliniets": "gadolinium",
    "gadoliniumet": "gadolinium",
    "gadoliniumets": "gadolinium",
    "gadoliniums": "gadolinium",
    "gaelen": "gael",
    "gaelens": "gael",
    "gaeler": "gael",
    "gaelerna": "gael",
    "gaelernas": "gael",
    "gaelers": "gael",
    "gaelisk": "gaeliska",
    "gaeliska": "gaelisk",
    "gaeliskan": "gaeliska",
    "gaeliskans": "gaeliska",
    "gaeliskare": "gaelisk",
    "gaeliskares": "gaelisk",
    "gaeliskas": "gaeliska",
    "gaeliskast": "gaelisk",
    "gaeliskaste": "gaelisk",
    "gaeliskastes": "gaelisk",
    "gaeliskasts": "gaelisk",
    "gaeliske": "gaeliska",
    "gaeliskes": "gaelisk",
    "gaeliskor": "gaeliska",
    "gaeliskorna": "gaeliska",
    "gaeliskornas": "gaeliska",
    "gaeliskors": "gaeliska",
    "gaelisks": "gaelisk",
    "gaeliskt": "gaelisk",
    "gaeliskts": "gaelisk",
    "gaels": "gael",
    "gaffar": "gaff",
    "gaffarna": "gaff",
    "gaffarnas": "gaff",
    "gaffars": "gaff",
    "gaffelankar": "gaffelankare",
    "gaffelankaren": "gaffelankare",
    "gaffelankarens": "gaffelankare",
    "gaffelankares": "gaffelankare",
    "gaffelankaret": "gaffelankare",
    "gaffelankarets": "gaffelankare",
    "gaffelankarna": "gaffelankare",
    "gaffelankarnas": "gaffelankare",
    "gaffelantilopen": "gaffelantilop",
    "gaffelantilopens": "gaffelantilop",
    "gaffelantiloper": "gaffelantilop",
    "gaffelantiloperna": "gaffelantilop",
    "gaffelantilopernas": "gaffelantilop",
    "gaffelantilopers": "gaffelantilop",
    "gaffelantilops": "gaffelantilop",
    "gaffelap": "gaffelapa",
    "gaffelapan": "gaffelapa",
    "gaffelapans": "gaffelapa",
    "gaffelapas": "gaffelapa",
    "gaffelape": "gaffelapa",
    "gaffelapor": "gaffelapa",
    "gaffelaporna": "gaffelapa",
    "gaffelapornas": "gaffelapa",
    "gaffelapors": "gaffelapa",
    "gaffelaps": "gaffelapa",
    "gaffelbitar": "gaffelbit",
    "gaffelbitarna": "gaffelbit",
    "gaffelbitarnas": "gaffelbit",
    "gaffelbitars": "gaffelbit",
    "gaffelbiten": "gaffelbit",
    "gaffelbitens": "gaffelbit",
    "gaffelbits": "gaffelbit",
    "gaffelbockar": "gaffelbock",
    "gaffelbockarna": "gaffelbock",
    "gaffelbockarnas": "gaffelbock",
    "gaffelbockars": "gaffelbock",
    "gaffelbocken": "gaffelbock",
    "gaffelbockens": "gaffelbock",
    "gaffelbocks": "gaffelbock",
    "gaffelhjortar": "gaffelhjort",
    "gaffelhjortarna": "gaffelhjort",
    "gaffelhjortarnas": "gaffelhjort",
    "gaffelhjortars": "gaffelhjort",
    "gaffelhjorten": "gaffelhjort",
    "gaffelhjortens": "gaffelhjort",
    "gaffelhjorts": "gaffelhjort",
    "gaffelklon": "gaffelklo",
    "gaffelklons": "gaffelklo",
    "gaffelklor": "gaffelklo",
    "gaffelklorna": "gaffelklo",
    "gaffelklornas": "gaffelklo",
    "gaffelklors": "gaffelklo",
    "gaffelklos": "gaffelklo",
    "gaffellyftar": "gaffellyft",
    "gaffellyftarna": "gaffellyft",
    "gaffellyftarnas": "gaffellyft",
    "gaffellyftars": "gaffellyft",
    "gaffellyften": "gaffellyft",
    "gaffellyftens": "gaffellyft",
    "gaffellyfts": "gaffellyft",
    "gaffellängden": "gaffellängd",
    "gaffellängdens": "gaffellängd",
    "gaffellängder": "gaffellängd",
    "gaffellängderna": "gaffellängd",
    "gaffellängdernas": "gaffellängd",
    "gaffellängders": "gaffellängd",
    "gaffellängds": "gaffellängd",
    "gaffeln": "gaffel",
    "gaffelns": "gaffel",
    "gaffelriggar": "gaffelrigg",
    "gaffelriggarna": "gaffelrigg",
    "gaffelriggarnas": "gaffelrigg",
    "gaffelriggars": "gaffelrigg",
    "gaffelriggen": "gaffelrigg",
    "gaffelriggens": "gaffelrigg",
    "gaffelriggs": "gaffelrigg",
    "gaffels": "gaffel",
    "gaffelsegels": "gaffelsegel",
    "gaffelseglen": "gaffelsegel",
    "gaffelseglens": "gaffelsegel",
    "gaffelseglet": "gaffelsegel",
    "gaffelseglets": "gaffelsegel",
    "gaffeltruckar": "gaffeltruck",
    "gaffeltruckarna": "gaffeltruck",
    "gaffeltruckarnas": "gaffeltruck",
    "gaffeltruckars": "gaffeltruck",
    "gaffeltrucken": "gaffeltruck",
    "gaffeltruckens": "gaffeltruck",
    "gaffeltrucks": "gaffeltruck",
    "gaffen": "gaff",
    "gaffens": "gaff",
    "gafflade": "gaffla",
    "gafflades": "gaffla",
    "gafflande": "gaffla",
    "gafflanden": "gafflande",
    "gafflandena": "gafflande",
    "gafflandenas": "gafflande",
    "gafflandens": "gafflande",
    "gafflandes": "gafflande",
    "gafflandet": "gafflande",
    "gafflandets": "gafflande",
    "gafflar": "gaffla",
    "gafflarna": "gaffel",
    "gafflarnas": "gaffel",
    "gafflars": "gaffel",
    "gafflas": "gaffla",
    "gafflat": "gaffla",
    "gafflats": "gaffla",
    "gaffs": "gaff",
    "gagaten": "gagat",
    "gagatens": "gagat",
    "gagater": "gagat",
    "gagaterna": "gagat",
    "gagaternas": "gagat",
    "gagaters": "gagat",
    "gagats": "gagat",
    "gagatsvarta": "gagatsvart",
    "gagatsvartare": "gagatsvart",
    "gagatsvartares": "gagatsvart",
    "gagatsvartas": "gagatsvart",
    "gagatsvartast": "gagatsvart",
    "gagatsvartaste": "gagatsvart",
    "gagatsvartastes": "gagatsvart",
    "gagatsvartasts": "gagatsvart",
    "gagatsvarte": "gagatsvart",
    "gagatsvartes": "gagatsvart",
    "gagatsvarts": "gagatsvart",
    "gagen": "gage",
    "gagens": "gage",
    "gager": "gage",
    "gagerna": "gage",
    "gagernas": "gage",
    "gagers": "gage",
    "gages": "gage",
    "gaget": "gage",
    "gagets": "gage",
    "gagg": "gagga",
    "gaggade": "gagga",
    "gaggades": "gagga",
    "gaggande": "gagga",
    "gagganden": "gaggande",
    "gaggandena": "gaggande",
    "gaggandenas": "gaggande",
    "gaggandens": "gaggande",
    "gaggandes": "gaggande",
    "gaggandet": "gaggande",
    "gaggandets": "gaggande",
    "gaggar": "gagga",
    "gaggas": "gagga",
    "gaggat": "gagga",
    "gaggats": "gagga",
    "gagget": "gagg",
    "gaggets": "gagg",
    "gaggiga": "gaggig",
    "gaggigare": "gaggig",
    "gaggigares": "gaggig",
    "gaggigas": "gaggig",
    "gaggigast": "gaggig",
    "gaggigaste": "gaggig",
    "gaggigastes": "gaggig",
    "gaggigasts": "gaggig",
    "gaggige": "gaggig",
    "gaggiges": "gaggig",
    "gaggigheten": "gaggighet",
    "gaggighetens": "gaggighet",
    "gaggighets": "gaggighet",
    "gaggigs": "gaggig",
    "gaggigt": "gaggig",
    "gaggigts": "gaggig",
    "gaggs": "gagg",
    "gagn": "gagna",
    "gagnad": "gagna",
    "gagnade": "gagna",
    "gagnades": "gagna",
    "gagnads": "gagna",
    "gagnande": "gagna",
    "gagnanden": "gagnande",
    "gagnandena": "gagnande",
    "gagnandenas": "gagnande",
    "gagnandens": "gagnande",
    "gagnandes": "gagnande",
    "gagnandet": "gagnande",
    "gagnandets": "gagnande",
    "gagnar": "gagna",
    "gagnas": "gagna",
    "gagnat": "gagna",
    "gagnats": "gagna",
    "gagneliga": "gagnelig",
    "gagneligare": "gagnelig",
    "gagneligares": "gagnelig",
    "gagneligas": "gagnelig",
    "gagneligast": "gagnelig",
    "gagneligaste": "gagnelig",
    "gagneligastes": "gagnelig",
    "gagneligasts": "gagnelig",
    "gagnelige": "gagnelig",
    "gagneliges": "gagnelig",
    "gagneligheten": "gagnelighet",
    "gagnelighetens": "gagnelighet",
    "gagneligheter": "gagnelighet",
    "gagneligheterna": "gagnelighet",
    "gagneligheternas": "gagnelighet",
    "gagneligheters": "gagnelighet",
    "gagnelighets": "gagnelighet",
    "gagneligs": "gagnelig",
    "gagneligt": "gagnelig",
    "gagneligts": "gagnelig",
    "gagnerika": "gagnerik",
    "gagnerikare": "gagnerik",
    "gagnerikares": "gagnerik",
    "gagnerikas": "gagnerik",
    "gagnerikast": "gagnerik",
    "gagnerikaste": "gagnerik",
    "gagnerikastes": "gagnerik",
    "gagnerikasts": "gagnerik",
    "gagnerike": "gagnerik",
    "gagnerikes": "gagnerik",
    "gagnerikheten": "gagnerikhet",
    "gagnerikhetens": "gagnerikhet",
    "gagnerikhets": "gagnerikhet",
    "gagneriks": "gagnerik",
    "gagnerikt": "gagnerik",
    "gagnerikts": "gagnerik",
    "gagnet": "gagn",
    "gagnets": "gagn",
    "gagnlösa": "gagnlös",
    "gagnlösare": "gagnlös",
    "gagnlösares": "gagnlös",
    "gagnlösas": "gagnlös",
    "gagnlösast": "gagnlös",
    "gagnlösaste": "gagnlös",
    "gagnlösastes": "gagnlös",
    "gagnlösasts": "gagnlös",
    "gagnlöse": "gagnlös",
    "gagnlöses": "gagnlös",
    "gagnlösheten": "gagnlöshet",
    "gagnlöshetens": "gagnlöshet",
    "gagnlöshets": "gagnlöshet",
    "gagnlöst": "gagnlös",
    "gagnlösts": "gagnlös",
    "gagnrika": "gagnrik",
    "gagnrikare": "gagnrik",
    "gagnrikares": "gagnrik",
    "gagnrikas": "gagnrik",
    "gagnrikast": "gagnrik",
    "gagnrikaste": "gagnrik",
    "gagnrikastes": "gagnrik",
    "gagnrikasts": "gagnrik",
    "gagnrike": "gagnrik",
    "gagnrikes": "gagnrik",
    "gagnrikheten": "gagnrikhet",
    "gagnrikhetens": "gagnrikhet",
    "gagnrikhets": "gagnrikhet",
    "gagnriks": "gagnrik",
    "gagnrikt": "gagnrik",
    "gagnrikts": "gagnrik",
    "gagns": "gagn",
    "gagnvirkes": "gagnvirke",
    "gagnvirket": "gagnvirke",
    "gagnvirkets": "gagnvirke",
    "gagnväxten": "gagnväxt",
    "gagnväxtens": "gagnväxt",
    "gagnväxter": "gagnväxt",
    "gagnväxterna": "gagnväxt",
    "gagnväxternas": "gagnväxt",
    "gagnväxters": "gagnväxt",
    "gagnväxts": "gagnväxt",
    "gags": "gag",
    "gagsen": "gag",
    "gagsens": "gag",
    "gaillarden": "gaillarde",
    "gaillardens": "gaillarde",
    "gaillarder": "gaillarde",
    "gaillarderna": "gaillarde",
    "gaillardernas": "gaillarde",
    "gaillarders": "gaillarde",
    "gaillardes": "gaillarde",
    "gajar": "gaj",
    "gajarna": "gaj",
    "gajarnas": "gaj",
    "gajars": "gaj",
    "gajen": "gaj",
    "gajens": "gaj",
    "gajs": "gaj",
    "gal": "gala",
    "galaktiska": "galaktisk",
    "galaktiskare": "galaktisk",
    "galaktiskares": "galaktisk",
    "galaktiskas": "galaktisk",
    "galaktiskast": "galaktisk",
    "galaktiskaste": "galaktisk",
    "galaktiskastes": "galaktisk",
    "galaktiskasts": "galaktisk",
    "galaktiske": "galaktisk",
    "galaktiskes": "galaktisk",
    "galaktisks": "galaktisk",
    "galaktiskt": "galaktisk",
    "galaktiskts": "galaktisk",
    "galaktosen": "galaktos",
    "galaktosens": "galaktos",
    "galaliten": "galalit",
    "galalitens": "galalit",
    "galalits": "galalit",
    "galan": "gala",
    "galande": "gala",
    "galanden": "galande",
    "galandena": "galande",
    "galandenas": "galande",
    "galandens": "galande",
    "galandes": "galande",
    "galandet": "galande",
    "galandets": "galande",
    "galans": "gala",
    "galanta": "galant",
    "galantare": "galant",
    "galantares": "galant",
    "galantas": "galant",
    "galantast": "galant",
    "galantaste": "galant",
    "galantastes": "galant",
    "galantasts": "galant",
    "galante": "galant",
    "galanterier": "galanteri",
    "galanterierna": "galanteri",
    "galanteriernas": "galanteri",
    "galanteriers": "galanteri",
    "galanteriet": "galanteri",
    "galanteriets": "galanteri",
    "galanteris": "galanteri",
    "galanterit": "galanteri",
    "galanterits": "galanteri",
    "galantes": "galant",
    "galants": "galant",
    "galapremiären": "galapremiär",
    "galapremiärens": "galapremiär",
    "galapremiärer": "galapremiär",
    "galapremiärerna": "galapremiär",
    "galapremiärernas": "galapremiär",
    "galapremiärers": "galapremiär",
    "galapremiärs": "galapremiär",
    "galas": "gala",
    "galaten": "galat",
    "galatens": "galat",
    "galater": "galat",
    "galaterna": "galat",
    "galaternas": "galat",
    "galaters": "galat",
    "galats": "galat",
    "galavagnar": "galavagn",
    "galavagnarna": "galavagn",
    "galavagnarnas": "galavagn",
    "galavagnars": "galavagn",
    "galavagnen": "galavagn",
    "galavagnens": "galavagn",
    "galavagns": "galavagn",
    "galaxbildningar": "galaxbildning",
    "galaxbildningarna": "galaxbildning",
    "galaxbildningarnas": "galaxbildning",
    "galaxbildningars": "galaxbildning",
    "galaxbildningen": "galaxbildning",
    "galaxbildningens": "galaxbildning",
    "galaxbildnings": "galaxbildning",
    "galaxcentra": "galaxcentrum",
    "galaxcentrana": "galaxcentrum",
    "galaxcentranas": "galaxcentrum",
    "galaxcentras": "galaxcentrum",
    "galaxcentrer": "galaxcentrum",
    "galaxcentrerna": "galaxcentrum",
    "galaxcentrernas": "galaxcentrum",
    "galaxcentrers": "galaxcentrum",
    "galaxcentret": "galaxcentrum",
    "galaxcentrets": "galaxcentrum",
    "galaxcentrumen": "galaxcentrum",
    "galaxcentrumens": "galaxcentrum",
    "galaxcentrumet": "galaxcentrum",
    "galaxcentrumets": "galaxcentrum",
    "galaxcentrums": "galaxcentrum",
    "galaxen": "galax",
    "galaxens": "galax",
    "galaxer": "galax",
    "galaxerna": "galax",
    "galaxernas": "galax",
    "galaxers": "galax",
    "galaxhopar": "galaxhop",
    "galaxhoparna": "galaxhop",
    "galaxhoparnas": "galaxhop",
    "galaxhopars": "galaxhop",
    "galaxhopen": "galaxhop",
    "galaxhopens": "galaxhop",
    "galaxhops": "galaxhop",
    "galaxspektra": "galaxspektrum",
    "galaxspektrana": "galaxspektrum",
    "galaxspektranas": "galaxspektrum",
    "galaxspektras": "galaxspektrum",
    "galaxspektrena": "galaxspektrum",
    "galaxspektrenas": "galaxspektrum",
    "galaxspektrer": "galaxspektrum",
    "galaxspektrers": "galaxspektrum",
    "galaxspektret": "galaxspektrum",
    "galaxspektrets": "galaxspektrum",
    "galaxspektrumen": "galaxspektrum",
    "galaxspektrumens": "galaxspektrum",
    "galaxspektrumet": "galaxspektrum",
    "galaxspektrumets": "galaxspektrum",
    "galaxspektrums": "galaxspektrum",
    "galaxvärldar": "galaxvärld",
    "galaxvärldarna": "galaxvärld",
    "galaxvärldarnas": "galaxvärld",
    "galaxvärldars": "galaxvärld",
    "galaxvärlden": "galaxvärld",
    "galaxvärldens": "galaxvärld",
    "galaxvärlds": "galaxvärld",
    "galdern": "galder",
    "galderns": "galder",
    "galders": "galder",
    "galdrar": "galder",
    "galdrarna": "galder",
    "galdrarnas": "galder",
    "galdrars": "galder",
    "gale": "gala",
    "galeasen": "galeas",
    "galeasens": "galeas",
    "galeaser": "galeas",
    "galeaserna": "galeas",
    "galeasernas": "galeas",
    "galeasers": "galeas",
    "galej": "galeja",
    "galejan": "galeja",
    "galejans": "galeja",
    "galejas": "galeja",
    "galeje": "galeja",
    "galejet": "galej",
    "galejets": "galej",
    "galejor": "galeja",
    "galejorna": "galeja",
    "galejornas": "galeja",
    "galejors": "galeja",
    "galejs": "galeja",
    "galenheten": "galenhet",
    "galenhetens": "galenhet",
    "galenhets": "galenhet",
    "galenpann": "galenpanna",
    "galenpannan": "galenpanna",
    "galenpannans": "galenpanna",
    "galenpannas": "galenpanna",
    "galenpanne": "galenpanna",
    "galenpannor": "galenpanna",
    "galenpannorna": "galenpanna",
    "galenpannornas": "galenpanna",
    "galenpannors": "galenpanna",
    "galenpanns": "galenpanna",
    "galens": "galen",
    "galenskapen": "galenskap",
    "galenskapens": "galenskap",
    "galenskaper": "galenskap",
    "galenskaperna": "galenskap",
    "galenskapernas": "galenskap",
    "galenskapers": "galenskap",
    "galenskaps": "galenskap",
    "gales": "gala",
    "galet": "galen",
    "galets": "galen",
    "galg": "galge",
    "galgar": "galge",
    "galgarna": "galge",
    "galgarnas": "galge",
    "galgars": "galge",
    "galgback": "galgbacke",
    "galgbackar": "galgbacke",
    "galgbackarna": "galgbacke",
    "galgbackarnas": "galgbacke",
    "galgbackars": "galgbacke",
    "galgbacken": "galgbacke",
    "galgbackens": "galgbacke",
    "galgbackes": "galgbacke",
    "galgbacks": "galgbacke",
    "galgen": "galge",
    "galgenfrists": "galgenfrist",
    "galgens": "galge",
    "galges": "galge",
    "galgfågeln": "galgfågel",
    "galgfågelns": "galgfågel",
    "galgfågels": "galgfågel",
    "galgfåglar": "galgfågel",
    "galgfåglarna": "galgfågel",
    "galgfåglarnas": "galgfågel",
    "galgfåglars": "galgfågel",
    "galghumorn": "galghumor",
    "galghumorns": "galghumor",
    "galghumors": "galghumor",
    "galgs": "galge",
    "galiciska": "galicisk",
    "galiciskare": "galicisk",
    "galiciskares": "galicisk",
    "galiciskas": "galicisk",
    "galiciskast": "galicisk",
    "galiciskaste": "galicisk",
    "galiciskastes": "galicisk",
    "galiciskasts": "galicisk",
    "galiciske": "galicisk",
    "galiciskes": "galicisk",
    "galicisks": "galicisk",
    "galiciskt": "galicisk",
    "galiciskts": "galicisk",
    "galiléen": "galilé",
    "galiléens": "galilé",
    "galiléer": "galilé",
    "galiléerna": "galilé",
    "galiléernas": "galilé",
    "galiléers": "galilé",
    "galilén": "galilé",
    "galiléns": "galilé",
    "galilés": "galilé",
    "galit": "gala",
    "galits": "gala",
    "galjonen": "galjon",
    "galjonens": "galjon",
    "galjoner": "galjon",
    "galjonerna": "galjon",
    "galjonernas": "galjon",
    "galjoners": "galjon",
    "galjons": "galjon",
    "galjonsbilden": "galjonsbild",
    "galjonsbildens": "galjonsbild",
    "galjonsbilder": "galjonsbild",
    "galjonsbilderna": "galjonsbild",
    "galjonsbildernas": "galjonsbild",
    "galjonsbilders": "galjonsbild",
    "galjonsbilds": "galjonsbild",
    "galjonsfiguren": "galjonsfigur",
    "galjonsfigurens": "galjonsfigur",
    "galjonsfigurer": "galjonsfigur",
    "galjonsfigurerna": "galjonsfigur",
    "galjonsfigurernas": "galjonsfigur",
    "galjonsfigurers": "galjonsfigur",
    "galjonsfigurs": "galjonsfigur",
    "gall": "galla",
    "gallan": "galla",
    "gallans": "galla",
    "gallas": "galla",
    "gallbildningar": "gallbildning",
    "gallbildningarna": "gallbildning",
    "gallbildningarnas": "gallbildning",
    "gallbildningars": "gallbildning",
    "gallbildningen": "gallbildning",
    "gallbildningens": "gallbildning",
    "gallbildnings": "gallbildning",
    "gallblom": "gallblomma",
    "gallblomman": "gallblomma",
    "gallblommans": "gallblomma",
    "gallblommas": "gallblomma",
    "gallblomme": "gallblomma",
    "gallblommor": "gallblomma",
    "gallblommorna": "gallblomma",
    "gallblommornas": "gallblomma",
    "gallblommors": "gallblomma",
    "gallbloms": "gallblomma",
    "gallblås": "gallblåsa",
    "gallblåsan": "gallblåsa",
    "gallblåsans": "gallblåsa",
    "gallblåsas": "gallblåsa",
    "gallblåse": "gallblåsa",
    "gallblåsor": "gallblåsa",
    "gallblåsorna": "gallblåsa",
    "gallblåsornas": "gallblåsa",
    "gallblåsors": "gallblåsa",
    "galle": "galla",
    "gallen": "gall",
    "gallens": "gall",
    "galler": "gall",
    "gallerdurkar": "gallerdurk",
    "gallerdurkarna": "gallerdurk",
    "gallerdurkarnas": "gallerdurk",
    "gallerdurkars": "gallerdurk",
    "gallerdurken": "gallerdurk",
    "gallerdurkens": "gallerdurk",
    "gallerdurks": "gallerdurk",
    "gallerian": "galleria",
    "gallerians": "galleria",
    "gallerias": "galleria",
    "gallerier": "galleri",
    "gallerierna": "galleri",
    "galleriernas": "galleri",
    "galleriers": "galleri",
    "galleriet": "galleri",
    "galleriets": "galleri",
    "gallerior": "galleria",
    "galleriorna": "galleria",
    "galleriornas": "galleria",
    "galleriors": "galleria",
    "galleris": "galleri",
    "galleriskogar": "galleriskog",
    "galleriskogarna": "galleriskog",
    "galleriskogarnas": "galleriskog",
    "galleriskogars": "galleriskog",
    "galleriskogen": "galleriskog",
    "galleriskogens": "galleriskog",
    "galleriskogs": "galleriskog",
    "galleristen": "gallerist",
    "galleristens": "gallerist",
    "gallerister": "gallerist",
    "galleristerna": "gallerist",
    "galleristernas": "gallerist",
    "galleristers": "gallerist",
    "gallerists": "gallerist",
    "gallerit": "galleri",
    "gallerits": "galleri",
    "gallern": "galler",
    "gallerna": "galler",
    "gallernas": "galler",
    "gallerns": "galler",
    "gallers": "galler",
    "gallerstaketen": "gallerstaket",
    "gallerstaketens": "gallerstaket",
    "gallerstaketet": "gallerstaket",
    "gallerstaketets": "gallerstaket",
    "gallerstakets": "gallerstaket",
    "gallerverken": "gallerverk",
    "gallerverkens": "gallerverk",
    "gallerverket": "gallerverk",
    "gallerverkets": "gallerverk",
    "gallerverks": "gallerverk",
    "gallfebern": "gallfeber",
    "gallfeberns": "gallfeber",
    "gallfebers": "gallfeber",
    "gallgångar": "gallgång",
    "gallgångarna": "gallgång",
    "gallgångarnas": "gallgång",
    "gallgångars": "gallgång",
    "gallgången": "gallgång",
    "gallgångens": "gallgång",
    "gallgångs": "gallgång",
    "gallicismen": "gallicism",
    "gallicismens": "gallicism",
    "gallicismer": "gallicism",
    "gallicismerna": "gallicism",
    "gallicismernas": "gallicism",
    "gallicismers": "gallicism",
    "gallicisms": "gallicism",
    "galliern": "gallier",
    "gallierna": "gallier",
    "galliernas": "gallier",
    "gallierns": "gallier",
    "galliers": "gallier",
    "galliet": "gallium",
    "galliets": "gallium",
    "gallimatiasen": "gallimatias",
    "gallimatiasens": "gallimatias",
    "gallimattiasen": "gallimattias",
    "gallimattiasens": "gallimattias",
    "gallionen": "gallion",
    "gallionens": "gallion",
    "gallioner": "gallion",
    "gallionerna": "gallion",
    "gallionernas": "gallion",
    "gallioners": "gallion",
    "gallions": "gallion",
    "galliserad": "gallisera",
    "galliserade": "gallisera",
    "galliserades": "gallisera",
    "galliserads": "gallisera",
    "galliserande": "gallisera",
    "galliseranden": "galliserande",
    "galliserandena": "galliserande",
    "galliserandenas": "galliserande",
    "galliserandens": "galliserande",
    "galliserandes": "galliserande",
    "galliserandet": "galliserande",
    "galliserandets": "galliserande",
    "galliserar": "gallisera",
    "galliseras": "gallisera",
    "galliserat": "gallisera",
    "galliserats": "gallisera",
    "galliserbara": "galliserbar",
    "galliserbarare": "galliserbar",
    "galliserbarares": "galliserbar",
    "galliserbaras": "galliserbar",
    "galliserbarast": "galliserbar",
    "galliserbaraste": "galliserbar",
    "galliserbarastes": "galliserbar",
    "galliserbarasts": "galliserbar",
    "galliserbare": "galliserbar",
    "galliserbares": "galliserbar",
    "galliserbarheten": "galliserbarhet",
    "galliserbarhetens": "galliserbarhet",
    "galliserbarhets": "galliserbarhet",
    "galliserbars": "galliserbar",
    "galliserbart": "galliserbar",
    "galliserbarts": "galliserbar",
    "galliseringar": "gallisering",
    "galliseringarna": "gallisering",
    "galliseringarnas": "gallisering",
    "galliseringars": "gallisering",
    "galliseringen": "gallisering",
    "galliseringens": "gallisering",
    "galliserings": "gallisering",
    "galliska": "gallisk",
    "galliskare": "gallisk",
    "galliskares": "gallisk",
    "galliskas": "gallisk",
    "galliskast": "gallisk",
    "galliskaste": "gallisk",
    "galliskastes": "gallisk",
    "galliskasts": "gallisk",
    "galliske": "gallisk",
    "galliskes": "gallisk",
    "gallisks": "gallisk",
    "galliskt": "gallisk",
    "galliskts": "gallisk",
    "galliumet": "gallium",
    "galliumets": "gallium",
    "galliums": "gallium",
    "gallkon": "gallko",
    "gallkons": "gallko",
    "gallkor": "gallko",
    "gallkorna": "gallko",
    "gallkornas": "gallko",
    "gallkors": "gallko",
    "gallkos": "gallko",
    "gallkvalsterna": "gallkvalster",
    "gallkvalsternas": "gallkvalster",
    "gallkvalsters": "gallkvalster",
    "gallkvalstren": "gallkvalster",
    "gallkvalstrens": "gallkvalster",
    "gallkvalstret": "gallkvalster",
    "gallkvalstrets": "gallkvalster",
    "gallmygg": "gallmygga",
    "gallmyggan": "gallmygga",
    "gallmyggans": "gallmygga",
    "gallmyggas": "gallmygga",
    "gallmygge": "gallmygga",
    "gallmyggor": "gallmygga",
    "gallmyggorna": "gallmygga",
    "gallmyggornas": "gallmygga",
    "gallmyggors": "gallmygga",
    "gallmyggs": "gallmygga",
    "gallonen": "gallon",
    "gallonens": "gallon",
    "gallons": "gallon",
    "gallonsen": "gallon",
    "gallonsens": "gallon",
    "gallor": "galla",
    "gallorna": "galla",
    "gallornas": "galla",
    "gallors": "galla",
    "gallrad": "gallra",
    "gallrade": "gallra",
    "gallrades": "gallra",
    "gallrads": "gallra",
    "gallrande": "gallra",
    "gallranden": "gallrande",
    "gallrandena": "gallrande",
    "gallrandenas": "gallrande",
    "gallrandens": "gallrande",
    "gallrandes": "gallrande",
    "gallrandet": "gallrande",
    "gallrandets": "gallrande",
    "gallrar": "gallra",
    "gallras": "gallra",
    "gallrat": "gallra",
    "gallrats": "gallra",
    "gallren": "galler",
    "gallrens": "galler",
    "gallret": "galler",
    "gallrets": "galler",
    "gallringar": "gallring",
    "gallringarna": "gallring",
    "gallringarnas": "gallring",
    "gallringars": "gallring",
    "gallringen": "gallring",
    "gallringens": "gallring",
    "gallrings": "gallring",
    "galls": "galla",
    "gallsjuka": "gallsjuk",
    "gallsjukare": "gallsjuk",
    "gallsjukares": "gallsjuk",
    "gallsjukas": "gallsjuk",
    "gallsjukast": "gallsjuk",
    "gallsjukaste": "gallsjuk",
    "gallsjukastes": "gallsjuk",
    "gallsjukasts": "gallsjuk",
    "gallsjuke": "gallsjuk",
    "gallsjukes": "gallsjuk",
    "gallsjukheten": "gallsjukhet",
    "gallsjukhetens": "gallsjukhet",
    "gallsjukhets": "gallsjukhet",
    "gallsjuks": "gallsjuk",
    "gallsjukt": "gallsjuk",
    "gallsjukts": "gallsjuk",
    "gallskrek": "gallskrika",
    "gallskreks": "gallskrika",
    "gallskrik": "gallskrika",
    "gallskrikande": "gallskrika",
    "gallskrikanden": "gallskrikande",
    "gallskrikandena": "gallskrikande",
    "gallskrikandenas": "gallskrikande",
    "gallskrikandens": "gallskrikande",
    "gallskrikandes": "gallskrikande",
    "gallskrikandet": "gallskrikande",
    "gallskrikandets": "gallskrikande",
    "gallskrikas": "gallskrika",
    "gallskrike": "gallskrika",
    "gallskriken": "gallskrik",
    "gallskrikens": "gallskrik",
    "gallskriker": "gallskrika",
    "gallskrikes": "gallskrika",
    "gallskriket": "gallskrik",
    "gallskrikets": "gallskrik",
    "gallskrikit": "gallskrika",
    "gallskrikits": "gallskrika",
    "gallskriks": "gallskrika",
    "gallsprängda": "gallsprängd",
    "gallsprängdare": "gallsprängd",
    "gallsprängdares": "gallsprängd",
    "gallsprängdas": "gallsprängd",
    "gallsprängdast": "gallsprängd",
    "gallsprängdaste": "gallsprängd",
    "gallsprängdastes": "gallsprängd",
    "gallsprängdasts": "gallsprängd",
    "gallsprängde": "gallsprängd",
    "gallsprängdes": "gallsprängd",
    "gallsprängdheten": "gallsprängdhet",
    "gallsprängdhetens": "gallsprängdhet",
    "gallsprängdhets": "gallsprängdhet",
    "gallsprängds": "gallsprängd",
    "gallsprängt": "gallsprängd",
    "gallsprängts": "gallsprängd",
    "gallstekeln": "gallstekel",
    "gallstekelns": "gallstekel",
    "gallstekels": "gallstekel",
    "gallsteklar": "gallstekel",
    "gallsteklarna": "gallstekel",
    "gallsteklarnas": "gallstekel",
    "gallsteklars": "gallstekel",
    "gallstenar": "gallsten",
    "gallstenarna": "gallsten",
    "gallstenarnas": "gallsten",
    "gallstenars": "gallsten",
    "gallstenen": "gallsten",
    "gallstenens": "gallsten",
    "gallstens": "gallsten",
    "gallsyran": "gallsyra",
    "gallsyrans": "gallsyra",
    "gallsyras": "gallsyra",
    "gallsyre": "gallsyra",
    "galltjut": "galltjuta",
    "galltjutande": "galltjuta",
    "galltjutanden": "galltjutande",
    "galltjutandena": "galltjutande",
    "galltjutandenas": "galltjutande",
    "galltjutandens": "galltjutande",
    "galltjutandes": "galltjutande",
    "galltjutandet": "galltjutande",
    "galltjutandets": "galltjutande",
    "galltjutas": "galltjuta",
    "galltjute": "galltjuta",
    "galltjuten": "galltjut",
    "galltjutens": "galltjut",
    "galltjuter": "galltjuta",
    "galltjutes": "galltjuta",
    "galltjutet": "galltjut",
    "galltjutets": "galltjut",
    "galltjutit": "galltjuta",
    "galltjutits": "galltjuta",
    "galltjuts": "galltjuta",
    "galltjöt": "galltjuta",
    "galltjöte": "galltjuta",
    "galltjötes": "galltjuta",
    "galltjöts": "galltjuta",
    "gallupar": "gallup",
    "galluparna": "gallup",
    "galluparnas": "gallup",
    "gallupars": "gallup",
    "gallupen": "gallup",
    "gallupens": "gallup",
    "gallupmätningar": "gallupmätning",
    "gallupmätningarna": "gallupmätning",
    "gallupmätningarnas": "gallupmätning",
    "gallupmätningars": "gallupmätning",
    "gallupmätningen": "gallupmätning",
    "gallupmätningens": "gallupmätning",
    "gallupmätnings": "gallupmätning",
    "gallups": "gallup",
    "gallussyran": "gallussyra",
    "gallussyrans": "gallussyra",
    "gallussyras": "gallussyra",
    "gallussyre": "gallussyra",
    "galläpplen": "galläpple",
    "galläpplena": "galläpple",
    "galläpplenas": "galläpple",
    "galläpplens": "galläpple",
    "galläpples": "galläpple",
    "galläpplet": "galläpple",
    "galläpplets": "galläpple",
    "galmejan": "galmeja",
    "galmejans": "galmeja",
    "galmejas": "galmeja",
    "galna": "galen",
    "galnades": "galnas",
    "galnakosjukans": "galnakosjukan",
    "galnare": "galen",
    "galnares": "galen",
    "galnas": "galen",
    "galnast": "galen",
    "galnaste": "galen",
    "galnastes": "galen",
    "galnasts": "galen",
    "galnats": "galnas",
    "galne": "galen",
    "galnes": "galen",
    "galningar": "galning",
    "galningarna": "galning",
    "galningarnas": "galning",
    "galningars": "galning",
    "galningen": "galning",
    "galningens": "galning",
    "galnings": "galning",
    "galonen": "galon",
    "galonens": "galon",
    "galoner": "galon",
    "galonerade": "galonerad",
    "galonerades": "galonerad",
    "galonerads": "galonerad",
    "galonerat": "galonerad",
    "galonerats": "galonerad",
    "galonerna": "galon",
    "galonernas": "galon",
    "galoners": "galon",
    "galonet": "galon",
    "galonets": "galon",
    "galons": "galon",
    "galoppaden": "galoppad",
    "galoppadens": "galoppad",
    "galoppader": "galoppad",
    "galoppaderna": "galoppad",
    "galoppadernas": "galoppad",
    "galoppaders": "galoppad",
    "galoppads": "galoppad",
    "galoppen": "galopp",
    "galoppens": "galopp",
    "galopper": "galopp",
    "galopperade": "galoppera",
    "galopperades": "galoppera",
    "galopperande": "galoppera",
    "galopperanden": "galopperande",
    "galopperandena": "galopperande",
    "galopperandenas": "galopperande",
    "galopperandens": "galopperande",
    "galopperandes": "galopperande",
    "galopperandet": "galopperande",
    "galopperandets": "galopperande",
    "galopperar": "galoppera",
    "galopperas": "galoppera",
    "galopperat": "galoppera",
    "galopperats": "galoppera",
    "galopperingar": "galoppering",
    "galopperingarna": "galoppering",
    "galopperingarnas": "galoppering",
    "galopperingars": "galoppering",
    "galopperingen": "galoppering",
    "galopperingens": "galoppering",
    "galopperings": "galoppering",
    "galopperna": "galopp",
    "galoppernas": "galopp",
    "galoppers": "galopp",
    "galopps": "galopp",
    "galoppsporten": "galoppsport",
    "galoppsportens": "galoppsport",
    "galoppsports": "galoppsport",
    "galopptävlingar": "galopptävling",
    "galopptävlingarna": "galopptävling",
    "galopptävlingarnas": "galopptävling",
    "galopptävlingars": "galopptävling",
    "galopptävlingen": "galopptävling",
    "galopptävlingens": "galopptävling",
    "galopptävlings": "galopptävling",
    "galor": "gala",
    "galorna": "gala",
    "galornas": "gala",
    "galors": "gala",
    "galoschbettet": "galoschbett",
    "galoschbettets": "galoschbett",
    "galoschbetts": "galoschbett",
    "galoschen": "galosch",
    "galoschens": "galosch",
    "galoscher": "galosch",
    "galoscherad": "galoschera",
    "galoscherade": "galoschera",
    "galoscherades": "galoschera",
    "galoscherads": "galoschera",
    "galoscherande": "galoschera",
    "galoscheranden": "galoscherande",
    "galoscherandena": "galoscherande",
    "galoscherandenas": "galoscherande",
    "galoscherandens": "galoscherande",
    "galoscherandes": "galoscherande",
    "galoscherandet": "galoscherande",
    "galoscherandets": "galoscherande",
    "galoscherar": "galoschera",
    "galoscheras": "galoschera",
    "galoscherat": "galoschera",
    "galoscherats": "galoschera",
    "galoscherbara": "galoscherbar",
    "galoscherbarare": "galoscherbar",
    "galoscherbarares": "galoscherbar",
    "galoscherbaras": "galoscherbar",
    "galoscherbarast": "galoscherbar",
    "galoscherbaraste": "galoscherbar",
    "galoscherbarastes": "galoscherbar",
    "galoscherbarasts": "galoscherbar",
    "galoscherbare": "galoscherbar",
    "galoscherbares": "galoscherbar",
    "galoscherbarheten": "galoscherbarhet",
    "galoscherbarhetens": "galoscherbarhet",
    "galoscherbarhets": "galoscherbarhet",
    "galoscherbars": "galoscherbar",
    "galoscherbart": "galoscherbar",
    "galoscherbarts": "galoscherbar",
    "galoscheringar": "galoschering",
    "galoscheringarna": "galoschering",
    "galoscheringarnas": "galoschering",
    "galoscheringars": "galoschering",
    "galoscheringen": "galoschering",
    "galoscheringens": "galoschering",
    "galoscherings": "galoschering",
    "galoscherna": "galosch",
    "galoschernas": "galosch",
    "galoschers": "galosch",
    "galoschhak": "galoschhaka",
    "galoschhakan": "galoschhaka",
    "galoschhakans": "galoschhaka",
    "galoschhakas": "galoschhaka",
    "galoschhake": "galoschhaka",
    "galoschhakor": "galoschhaka",
    "galoschhakorna": "galoschhaka",
    "galoschhakornas": "galoschhaka",
    "galoschhakors": "galoschhaka",
    "galoschhaks": "galoschhaka",
    "galoschhyll": "galoschhylla",
    "galoschhyllan": "galoschhylla",
    "galoschhyllans": "galoschhylla",
    "galoschhyllas": "galoschhylla",
    "galoschhylle": "galoschhylla",
    "galoschhyllor": "galoschhylla",
    "galoschhyllorna": "galoschhylla",
    "galoschhyllornas": "galoschhylla",
    "galoschhyllors": "galoschhylla",
    "galoschhylls": "galoschhylla",
    "galoschs": "galosch",
    "gals": "gala",
    "galt": "gala",
    "galtar": "galt",
    "galtarna": "galt",
    "galtarnas": "galt",
    "galtars": "galt",
    "galten": "galt",
    "galtens": "galt",
    "galts": "galt",
    "galv": "galva",
    "galvad": "galva",
    "galvade": "galva",
    "galvades": "galva",
    "galvads": "galva",
    "galvande": "galva",
    "galvanden": "galvande",
    "galvandena": "galvande",
    "galvandenas": "galvande",
    "galvandens": "galvande",
    "galvandes": "galvande",
    "galvandet": "galvande",
    "galvandets": "galvande",
    "galvaniserad": "galvanisera",
    "galvaniserade": "galvanisera",
    "galvaniserades": "galvanisera",
    "galvaniserads": "galvanisera",
    "galvaniserande": "galvanisera",
    "galvaniseranden": "galvaniserande",
    "galvaniserandena": "galvaniserande",
    "galvaniserandenas": "galvaniserande",
    "galvaniserandens": "galvaniserande",
    "galvaniserandes": "galvaniserande",
    "galvaniserandet": "galvaniserande",
    "galvaniserandets": "galvaniserande",
    "galvaniserar": "galvanisera",
    "galvaniseras": "galvanisera",
    "galvaniserat": "galvanisera",
    "galvaniserats": "galvanisera",
    "galvaniserbara": "galvaniserbar",
    "galvaniserbarare": "galvaniserbar",
    "galvaniserbarares": "galvaniserbar",
    "galvaniserbaras": "galvaniserbar",
    "galvaniserbarast": "galvaniserbar",
    "galvaniserbaraste": "galvaniserbar",
    "galvaniserbarastes": "galvaniserbar",
    "galvaniserbarasts": "galvaniserbar",
    "galvaniserbare": "galvaniserbar",
    "galvaniserbares": "galvaniserbar",
    "galvaniserbarheten": "galvaniserbarhet",
    "galvaniserbarhetens": "galvaniserbarhet",
    "galvaniserbarhets": "galvaniserbarhet",
    "galvaniserbars": "galvaniserbar",
    "galvaniserbart": "galvaniserbar",
    "galvaniserbarts": "galvaniserbar",
    "galvaniseringar": "galvanisering",
    "galvaniseringarna": "galvanisering",
    "galvaniseringarnas": "galvanisering",
    "galvaniseringars": "galvanisering",
    "galvaniseringen": "galvanisering",
    "galvaniseringens": "galvanisering",
    "galvaniserings": "galvanisering",
    "galvaniska": "galvanisk",
    "galvaniskare": "galvanisk",
    "galvaniskares": "galvanisk",
    "galvaniskas": "galvanisk",
    "galvaniskast": "galvanisk",
    "galvaniskaste": "galvanisk",
    "galvaniskastes": "galvanisk",
    "galvaniskasts": "galvanisk",
    "galvaniske": "galvanisk",
    "galvaniskes": "galvanisk",
    "galvanisks": "galvanisk",
    "galvaniskt": "galvanisk",
    "galvaniskts": "galvanisk",
    "galvanismen": "galvanism",
    "galvanismens": "galvanism",
    "galvanismer": "galvanism",
    "galvanismerna": "galvanism",
    "galvanismernas": "galvanism",
    "galvanismers": "galvanism",
    "galvanisms": "galvanism",
    "galvanometern": "galvanometer",
    "galvanometerns": "galvanometer",
    "galvanometers": "galvanometer",
    "galvanometrar": "galvanometer",
    "galvanometrarna": "galvanometer",
    "galvanometrarnas": "galvanometer",
    "galvanometrars": "galvanometer",
    "galvanoplastiken": "galvanoplastik",
    "galvanoplastikens": "galvanoplastik",
    "galvanoplastiks": "galvanoplastik",
    "galvanoskopen": "galvanoskop",
    "galvanoskopens": "galvanoskop",
    "galvanoskopet": "galvanoskop",
    "galvanoskopets": "galvanoskop",
    "galvanoskops": "galvanoskop",
    "galvanostegien": "galvanostegi",
    "galvanostegiens": "galvanostegi",
    "galvanostegin": "galvanostegi",
    "galvanostegins": "galvanostegi",
    "galvanostegis": "galvanostegi",
    "galvanotekniken": "galvanoteknik",
    "galvanoteknikens": "galvanoteknik",
    "galvanotekniks": "galvanoteknik",
    "galvanotypen": "galvanotyp",
    "galvanotypens": "galvanotyp",
    "galvanotyper": "galvanotyp",
    "galvanotyperna": "galvanotyp",
    "galvanotypernas": "galvanotyp",
    "galvanotypers": "galvanotyp",
    "galvanotypien": "galvanotypi",
    "galvanotypiens": "galvanotypi",
    "galvanotypin": "galvanotypi",
    "galvanotypins": "galvanotypi",
    "galvanotypis": "galvanotypi",
    "galvanotyps": "galvanotyp",
    "galvar": "galva",
    "galvas": "galva",
    "galvat": "galva",
    "galvats": "galva",
    "galären": "galär",
    "galärens": "galär",
    "galärer": "galär",
    "galärerna": "galär",
    "galärernas": "galär",
    "galärers": "galär",
    "galärs": "galär",
    "galärslavar": "galärslav",
    "galärslavarna": "galärslav",
    "galärslavarnas": "galärslav",
    "galärslavars": "galärslav",
    "galärslaven": "galärslav",
    "galärslavens": "galärslav",
    "galärslavs": "galärslav",
    "gamade": "gama",
    "gamades": "gama",
    "gamande": "gama",
    "gamanden": "gamande",
    "gamandena": "gamande",
    "gamandenas": "gamande",
    "gamandens": "gamande",
    "gamandes": "gamande",
    "gamandet": "gamande",
    "gamandets": "gamande",
    "gamar": "gama",
    "gamarna": "gam",
    "gamarnas": "gam",
    "gamars": "gam",
    "gamas": "gama",
    "gamaschen": "gamasch",
    "gamaschens": "gamasch",
    "gamascher": "gamasch",
    "gamascherna": "gamasch",
    "gamaschernas": "gamasch",
    "gamaschers": "gamasch",
    "gamaschs": "gamasch",
    "gamat": "gama",
    "gamats": "gama",
    "gambiern": "gambier",
    "gambierna": "gambier",
    "gambiernas": "gambier",
    "gambierns": "gambier",
    "gambiers": "gambier",
    "gambiska": "gambisk",
    "gambiskan": "gambiska",
    "gambiskans": "gambiska",
    "gambiskare": "gambisk",
    "gambiskares": "gambisk",
    "gambiskas": "gambiska",
    "gambiskast": "gambisk",
    "gambiskaste": "gambisk",
    "gambiskastes": "gambisk",
    "gambiskasts": "gambisk",
    "gambiske": "gambiska",
    "gambiskes": "gambisk",
    "gambiskor": "gambiska",
    "gambiskorna": "gambiska",
    "gambiskornas": "gambiska",
    "gambiskors": "gambiska",
    "gambisks": "gambisk",
    "gambiskt": "gambisk",
    "gambiskts": "gambisk",
    "gambitar": "gambit",
    "gambitarna": "gambit",
    "gambitarnas": "gambit",
    "gambitars": "gambit",
    "gambiten": "gambit",
    "gambitens": "gambit",
    "gambiter": "gambit",
    "gambiterna": "gambit",
    "gambiternas": "gambit",
    "gambiters": "gambit",
    "gambits": "gambit",
    "gamen": "game",
    "gamens": "game",
    "games": "game",
    "gamet": "game",
    "gameten": "gamet",
    "gametens": "gamet",
    "gameter": "gamet",
    "gameterna": "gamet",
    "gameternas": "gamet",
    "gameters": "gamet",
    "gamets": "gamet",
    "gamla": "gammal",
    "gamlas": "gammal",
    "gamle": "gammal",
    "gamles": "gammal",
    "gamlingar": "gamling",
    "gamlingarna": "gamling",
    "gamlingarnas": "gamling",
    "gamlingars": "gamling",
    "gamlingen": "gamling",
    "gamlingens": "gamling",
    "gamlings": "gamling",
    "gammaflyen": "gammafly",
    "gammaflyens": "gammafly",
    "gammaflyet": "gammafly",
    "gammaflyets": "gammafly",
    "gammaflyn": "gammafly",
    "gammaflyna": "gammafly",
    "gammaflynas": "gammafly",
    "gammaflyns": "gammafly",
    "gammaflys": "gammafly",
    "gammaflyt": "gammafly",
    "gammaflyts": "gammafly",
    "gammaglobulinen": "gammaglobulin",
    "gammaglobulinens": "gammaglobulin",
    "gammaglobuliner": "gammaglobulin",
    "gammaglobulinerna": "gammaglobulin",
    "gammaglobulinernas": "gammaglobulin",
    "gammaglobuliners": "gammaglobulin",
    "gammaglobulinet": "gammaglobulin",
    "gammaglobulinets": "gammaglobulin",
    "gammaglobulins": "gammaglobulin",
    "gammakameran": "gammakamera",
    "gammakamerans": "gammakamera",
    "gammakameras": "gammakamera",
    "gammakameror": "gammakamera",
    "gammakamerorna": "gammakamera",
    "gammakamerornas": "gammakamera",
    "gammakamerors": "gammakamera",
    "gammaldansen": "gammaldans",
    "gammaldansens": "gammaldans",
    "gammaldanser": "gammaldans",
    "gammaldanserna": "gammaldans",
    "gammaldansernas": "gammaldans",
    "gammaldansers": "gammaldans",
    "gammalhögern": "gammalhöger",
    "gammalhögerns": "gammalhöger",
    "gammalhögers": "gammalhöger",
    "gammalkommunisten": "gammalkommunist",
    "gammalkommunistens": "gammalkommunist",
    "gammalkommunister": "gammalkommunist",
    "gammalkommunisterna": "gammalkommunist",
    "gammalkommunisternas": "gammalkommunist",
    "gammalkommunisters": "gammalkommunist",
    "gammalkommunists": "gammalkommunist",
    "gammalkristenheten": "gammalkristenhet",
    "gammalkristenhetens": "gammalkristenhet",
    "gammalkristenhets": "gammalkristenhet",
    "gammalkristens": "gammalkristen",
    "gammalkristet": "gammalkristen",
    "gammalkristets": "gammalkristen",
    "gammalkristna": "gammalkristen",
    "gammalkristnare": "gammalkristen",
    "gammalkristnares": "gammalkristen",
    "gammalkristnas": "gammalkristen",
    "gammalkristnast": "gammalkristen",
    "gammalkristnaste": "gammalkristen",
    "gammalkristnastes": "gammalkristen",
    "gammalkristnasts": "gammalkristen",
    "gammalkristne": "gammalkristen",
    "gammalkristnes": "gammalkristen",
    "gammalkyrkliga": "gammalkyrklig",
    "gammalkyrkligare": "gammalkyrklig",
    "gammalkyrkligares": "gammalkyrklig",
    "gammalkyrkligas": "gammalkyrklig",
    "gammalkyrkligast": "gammalkyrklig",
    "gammalkyrkligaste": "gammalkyrklig",
    "gammalkyrkligastes": "gammalkyrklig",
    "gammalkyrkligasts": "gammalkyrklig",
    "gammalkyrklige": "gammalkyrklig",
    "gammalkyrkliges": "gammalkyrklig",
    "gammalkyrkligheten": "gammalkyrklighet",
    "gammalkyrklighetens": "gammalkyrklighet",
    "gammalkyrklighets": "gammalkyrklighet",
    "gammalkyrkligs": "gammalkyrklig",
    "gammalkyrkligt": "gammalkyrklig",
    "gammalkyrkligts": "gammalkyrklig",
    "gammalmodiga": "gammalmodig",
    "gammalmodigare": "gammalmodig",
    "gammalmodigares": "gammalmodig",
    "gammalmodigas": "gammalmodig",
    "gammalmodigast": "gammalmodig",
    "gammalmodigaste": "gammalmodig",
    "gammalmodigastes": "gammalmodig",
    "gammalmodigasts": "gammalmodig",
    "gammalmodige": "gammalmodig",
    "gammalmodiges": "gammalmodig",
    "gammalmodigheten": "gammalmodighet",
    "gammalmodighetens": "gammalmodighet",
    "gammalmodighets": "gammalmodighet",
    "gammalmodigs": "gammalmodig",
    "gammalmodigt": "gammalmodig",
    "gammalmodigts": "gammalmodig",
    "gammals": "gammal",
    "gammalstavningar": "gammalstavning",
    "gammalstavningarna": "gammalstavning",
    "gammalstavningarnas": "gammalstavning",
    "gammalstavningars": "gammalstavning",
    "gammalstavningen": "gammalstavning",
    "gammalstavningens": "gammalstavning",
    "gammalstavnings": "gammalstavning",
    "gammalt": "gammal",
    "gammaltestamentliga": "gammaltestamentlig",
    "gammaltestamentligare": "gammaltestamentlig",
    "gammaltestamentligares": "gammaltestamentlig",
    "gammaltestamentligas": "gammaltestamentlig",
    "gammaltestamentligast": "gammaltestamentlig",
    "gammaltestamentligaste": "gammaltestamentlig",
    "gammaltestamentligastes": "gammaltestamentlig",
    "gammaltestamentligasts": "gammaltestamentlig",
    "gammaltestamentlige": "gammaltestamentlig",
    "gammaltestamentliges": "gammaltestamentlig",
    "gammaltestamentligheten": "gammaltestamentlighet",
    "gammaltestamentlighetens": "gammaltestamentlighet",
    "gammaltestamentlighets": "gammaltestamentlighet",
    "gammaltestamentligs": "gammaltestamentlig",
    "gammaltestamentligt": "gammaltestamentlig",
    "gammaltestamentligts": "gammaltestamentlig",
    "gammalts": "gammal",
    "gammalvalsen": "gammalvals",
    "gammalvalsens": "gammalvals",
    "gammalvalser": "gammalvals",
    "gammalvalserna": "gammalvals",
    "gammalvalsernas": "gammalvals",
    "gammalvalsers": "gammalvals",
    "gamman": "gamma",
    "gammana": "gamma",
    "gammanas": "gamma",
    "gammans": "gamman",
    "gammas": "gamma",
    "gammastrål": "gammastråle",
    "gammastrålar": "gammastråle",
    "gammastrålarna": "gammastråle",
    "gammastrålarnas": "gammastråle",
    "gammastrålars": "gammastråle",
    "gammastrålen": "gammastråle",
    "gammastrålens": "gammastråle",
    "gammastråles": "gammastråle",
    "gammastrålningar": "gammastrålning",
    "gammastrålningarna": "gammastrålning",
    "gammastrålningarnas": "gammastrålning",
    "gammastrålningars": "gammastrålning",
    "gammastrålningen": "gammastrålning",
    "gammastrålningens": "gammastrålning",
    "gammastrålnings": "gammastrålning",
    "gammastråls": "gammastråle",
    "gammat": "gamma",
    "gammats": "gamma",
    "gammeldansen": "gammeldans",
    "gammeldansens": "gammeldans",
    "gammeldanser": "gammeldans",
    "gammeldanserna": "gammeldans",
    "gammeldansernas": "gammeldans",
    "gammeldansers": "gammeldans",
    "gammelkommunisten": "gammelkommunist",
    "gammelkommunistens": "gammelkommunist",
    "gammelkommunister": "gammelkommunist",
    "gammelkommunisterna": "gammelkommunist",
    "gammelkommunisternas": "gammelkommunist",
    "gammelkommunisters": "gammelkommunist",
    "gammelkommunists": "gammelkommunist",
    "gammeltantsgarderoben": "gammeltantsgarderob",
    "gammeltantsgarderobens": "gammeltantsgarderob",
    "gammeltantsgarderober": "gammeltantsgarderob",
    "gammeltantsgarderoberna": "gammeltantsgarderob",
    "gammeltantsgarderobernas": "gammeltantsgarderob",
    "gammeltantsgarderobers": "gammeltantsgarderob",
    "gammeltantsgarderobs": "gammeltantsgarderob",
    "gammelvalsen": "gammelvals",
    "gammelvalsens": "gammelvals",
    "gammelvalser": "gammelvals",
    "gammelvalserna": "gammelvals",
    "gammelvalsernas": "gammelvals",
    "gammelvalsers": "gammelvals",
    "gams": "gam",
    "gamängen": "gamäng",
    "gamängens": "gamäng",
    "gamänger": "gamäng",
    "gamängerna": "gamäng",
    "gamängernas": "gamäng",
    "gamängers": "gamäng",
    "gamängs": "gamäng",
    "gan": "gana",
    "ganad": "gana",
    "ganade": "gana",
    "ganades": "gana",
    "ganads": "gana",
    "ganande": "gana",
    "gananden": "ganande",
    "ganandena": "ganande",
    "ganandenas": "ganande",
    "ganandens": "ganande",
    "ganandes": "ganande",
    "ganandet": "ganande",
    "ganandets": "ganande",
    "ganar": "gana",
    "ganarna": "gan",
    "ganarnas": "gan",
    "ganars": "gan",
    "ganas": "gana",
    "ganaschen": "ganasch",
    "ganaschens": "ganasch",
    "ganascher": "ganasch",
    "ganascherna": "ganasch",
    "ganaschernas": "ganasch",
    "ganaschers": "ganasch",
    "ganaschs": "ganasch",
    "ganat": "gana",
    "ganats": "gana",
    "gandhiskynken": "gandhiskynke",
    "gandhiskynkena": "gandhiskynke",
    "gandhiskynkenas": "gandhiskynke",
    "gandhiskynkens": "gandhiskynke",
    "gandhiskynkes": "gandhiskynke",
    "gandhiskynket": "gandhiskynke",
    "gandhiskynkets": "gandhiskynke",
    "gandhiskynks": "gandhiskynke",
    "ganen": "gan",
    "ganens": "gan",
    "ganer": "gan",
    "ganerna": "gan",
    "ganernas": "gan",
    "ganers": "gan",
    "ganglien": "ganglie",
    "gangliens": "ganglie",
    "ganglier": "ganglie",
    "ganglierna": "ganglie",
    "gangliernas": "ganglie",
    "gangliers": "ganglie",
    "ganglies": "ganglie",
    "gangliet": "ganglie",
    "gangliets": "ganglie",
    "ganglionen": "ganglion",
    "ganglionens": "ganglion",
    "ganglioner": "ganglion",
    "ganglionerna": "ganglion",
    "ganglionernas": "ganglion",
    "ganglioners": "ganglion",
    "ganglionet": "ganglion",
    "ganglionets": "ganglion",
    "ganglions": "ganglion",
    "gangrenösa": "gangrenös",
    "gangrenösare": "gangrenös",
    "gangrenösares": "gangrenös",
    "gangrenösas": "gangrenös",
    "gangrenösast": "gangrenös",
    "gangrenösaste": "gangrenös",
    "gangrenösastes": "gangrenös",
    "gangrenösasts": "gangrenös",
    "gangrenöse": "gangrenös",
    "gangrenöses": "gangrenös",
    "gangrenöst": "gangrenös",
    "gangrenösts": "gangrenös",
    "gangränen": "gangrän",
    "gangränens": "gangrän",
    "gangräns": "gangrän",
    "gangsterismen": "gangsterism",
    "gangsterismens": "gangsterism",
    "gangsterismer": "gangsterism",
    "gangsterismerna": "gangsterism",
    "gangsterismernas": "gangsterism",
    "gangsterismers": "gangsterism",
    "gangsterisms": "gangsterism",
    "gangstern": "gangster",
    "gangsterns": "gangster",
    "gangsterromantiken": "gangsterromantik",
    "gangsterromantikens": "gangsterromantik",
    "gangsterromantiks": "gangsterromantik",
    "gangsters": "gangster",
    "gangstersarna": "gangster",
    "gangstersarnas": "gangster",
    "gangstersen": "gangster",
    "gangstersens": "gangster",
    "gangstrar": "gangster",
    "gangstrarna": "gangster",
    "gangstrarnas": "gangster",
    "gangstrars": "gangster",
    "gans": "gan",
    "gansen": "gans",
    "gansens": "gans",
    "ganser": "gans",
    "ganserna": "gans",
    "gansernas": "gans",
    "gansers": "gans",
    "ganymeden": "ganymed",
    "ganymedens": "ganymed",
    "ganymeder": "ganymed",
    "ganymederna": "ganymed",
    "ganymedernas": "ganymed",
    "ganymeders": "ganymed",
    "ganymeds": "ganymed",
    "gap": "gapa",
    "gapade": "gapa",
    "gapades": "gapa",
    "gapande": "gapa",
    "gapanden": "gapande",
    "gapandena": "gapande",
    "gapandenas": "gapande",
    "gapandens": "gapande",
    "gapandes": "gapande",
    "gapandet": "gapande",
    "gapandets": "gapande",
    "gapar": "gapa",
    "gapas": "gapa",
    "gapat": "gapa",
    "gapats": "gapa",
    "gapen": "gap",
    "gapens": "gap",
    "gapet": "gap",
    "gapets": "gap",
    "gaphalsar": "gaphals",
    "gaphalsarna": "gaphals",
    "gaphalsarnas": "gaphals",
    "gaphalsars": "gaphals",
    "gaphalsen": "gaphals",
    "gaphalsens": "gaphals",
    "gapiga": "gapig",
    "gapigare": "gapig",
    "gapigares": "gapig",
    "gapigas": "gapig",
    "gapigast": "gapig",
    "gapigaste": "gapig",
    "gapigastes": "gapig",
    "gapigasts": "gapig",
    "gapige": "gapig",
    "gapiges": "gapig",
    "gapigs": "gapig",
    "gapigt": "gapig",
    "gapigts": "gapig",
    "gaps": "gap",
    "gapsaxar": "gapsax",
    "gapsaxarna": "gapsax",
    "gapsaxarnas": "gapsax",
    "gapsaxars": "gapsax",
    "gapsaxen": "gapsax",
    "gapsaxens": "gapsax",
    "gapskrattade": "gapskratta",
    "gapskrattades": "gapskratta",
    "gapskrattande": "gapskratta",
    "gapskrattanden": "gapskrattande",
    "gapskrattandena": "gapskrattande",
    "gapskrattandenas": "gapskrattande",
    "gapskrattandens": "gapskrattande",
    "gapskrattandes": "gapskrattande",
    "gapskrattandet": "gapskrattande",
    "gapskrattandets": "gapskrattande",
    "gapskrattar": "gapskratta",
    "gapskrattas": "gapskratta",
    "gapskrattat": "gapskratta",
    "gapskrattats": "gapskratta",
    "gapskratten": "gapskratt",
    "gapskrattens": "gapskratt",
    "gapskrattet": "gapskratt",
    "gapskrattets": "gapskratt",
    "gapskratts": "gapskratt",
    "gapstockar": "gapstock",
    "gapstockarna": "gapstock",
    "gapstockarnas": "gapstock",
    "gapstockars": "gapstock",
    "gapstocken": "gapstock",
    "gapstockens": "gapstock",
    "gapstocks": "gapstock",
    "gar": "gara",
    "garad": "gara",
    "garade": "gara",
    "garades": "gara",
    "garads": "gara",
    "garagedomkraften": "garagedomkraft",
    "garagedomkraftens": "garagedomkraft",
    "garagedomkrafter": "garagedomkraft",
    "garagedomkrafterna": "garagedomkraft",
    "garagedomkrafternas": "garagedomkraft",
    "garagedomkrafters": "garagedomkraft",
    "garagedomkrafts": "garagedomkraft",
    "garagen": "garage",
    "garagens": "garage",
    "garagerad": "garagera",
    "garagerade": "garagera",
    "garagerades": "garagera",
    "garagerads": "garagera",
    "garagerande": "garagera",
    "garageranden": "garagerande",
    "garagerandena": "garagerande",
    "garagerandenas": "garagerande",
    "garagerandens": "garagerande",
    "garagerandes": "garagerande",
    "garagerandet": "garagerande",
    "garagerandets": "garagerande",
    "garagerar": "garagera",
    "garageras": "garagera",
    "garagerat": "garagera",
    "garagerats": "garagera",
    "garagerbara": "garagerbar",
    "garagerbarare": "garagerbar",
    "garagerbarares": "garagerbar",
    "garagerbaras": "garagerbar",
    "garagerbarast": "garagerbar",
    "garagerbaraste": "garagerbar",
    "garagerbarastes": "garagerbar",
    "garagerbarasts": "garagerbar",
    "garagerbare": "garagerbar",
    "garagerbares": "garagerbar",
    "garagerbarheten": "garagerbarhet",
    "garagerbarhetens": "garagerbarhet",
    "garagerbarhets": "garagerbarhet",
    "garagerbars": "garagerbar",
    "garagerbart": "garagerbar",
    "garagerbarts": "garagerbar",
    "garageringar": "garagering",
    "garageringarna": "garagering",
    "garageringarnas": "garagering",
    "garageringars": "garagering",
    "garageringen": "garagering",
    "garageringens": "garagering",
    "garagerings": "garagering",
    "garages": "garage",
    "garaget": "garage",
    "garagets": "garage",
    "garagevakten": "garagevakt",
    "garagevaktens": "garagevakt",
    "garagevakter": "garagevakt",
    "garagevakterna": "garagevakt",
    "garagevakternas": "garagevakt",
    "garagevakters": "garagevakt",
    "garagevakts": "garagevakt",
    "garande": "gara",
    "garanden": "garande",
    "garandena": "garande",
    "garandenas": "garande",
    "garandens": "garande",
    "garandes": "garande",
    "garandet": "garande",
    "garandets": "garande",
    "garanten": "garant",
    "garantens": "garant",
    "garanter": "garant",
    "garanterad": "garantera",
    "garanterade": "garantera",
    "garanterades": "garantera",
    "garanterads": "garantera",
    "garanterande": "garantera",
    "garanteranden": "garanterande",
    "garanterandena": "garanterande",
    "garanterandenas": "garanterande",
    "garanterandens": "garanterande",
    "garanterandes": "garanterande",
    "garanterandet": "garanterande",
    "garanterandets": "garanterande",
    "garanterar": "garantera",
    "garanteras": "garantera",
    "garanterat": "garantera",
    "garanterats": "garantera",
    "garanterbara": "garanterbar",
    "garanterbarare": "garanterbar",
    "garanterbarares": "garanterbar",
    "garanterbaras": "garanterbar",
    "garanterbarast": "garanterbar",
    "garanterbaraste": "garanterbar",
    "garanterbarastes": "garanterbar",
    "garanterbarasts": "garanterbar",
    "garanterbare": "garanterbar",
    "garanterbares": "garanterbar",
    "garanterbarheten": "garanterbarhet",
    "garanterbarhetens": "garanterbarhet",
    "garanterbarhets": "garanterbarhet",
    "garanterbars": "garanterbar",
    "garanterbart": "garanterbar",
    "garanterbarts": "garanterbar",
    "garanteringar": "garantering",
    "garanteringarna": "garantering",
    "garanteringarnas": "garantering",
    "garanteringars": "garantering",
    "garanteringen": "garantering",
    "garanteringens": "garantering",
    "garanterings": "garantering",
    "garanterna": "garant",
    "garanternas": "garant",
    "garanters": "garant",
    "garantibeloppen": "garantibelopp",
    "garantibeloppens": "garantibelopp",
    "garantibeloppet": "garantibelopp",
    "garantibeloppets": "garantibelopp",
    "garantibelopps": "garantibelopp",
    "garantibevisen": "garantibevis",
    "garantibevisens": "garantibevis",
    "garantibeviset": "garantibevis",
    "garantibevisets": "garantibevis",
    "garantien": "garanti",
    "garantiens": "garanti",
    "garantier": "garanti",
    "garantierna": "garanti",
    "garantiernas": "garanti",
    "garantiers": "garanti",
    "garantifonden": "garantifond",
    "garantifondens": "garantifond",
    "garantifonder": "garantifond",
    "garantifonderna": "garantifond",
    "garantifondernas": "garantifond",
    "garantifonders": "garantifond",
    "garantifonds": "garantifond",
    "garantifördragen": "garantifördrag",
    "garantifördragens": "garantifördrag",
    "garantifördraget": "garantifördrag",
    "garantifördragets": "garantifördrag",
    "garantifördrags": "garantifördrag",
    "garantiförsäkringar": "garantiförsäkring",
    "garantiförsäkringarna": "garantiförsäkring",
    "garantiförsäkringarnas": "garantiförsäkring",
    "garantiförsäkringars": "garantiförsäkring",
    "garantiförsäkringen": "garantiförsäkring",
    "garantiförsäkringens": "garantiförsäkring",
    "garantiförsäkrings": "garantiförsäkring",
    "garantilånen": "garantilån",
    "garantilånens": "garantilån",
    "garantilånet": "garantilån",
    "garantilånets": "garantilån",
    "garantilåns": "garantilån",
    "garantin": "garanti",
    "garantins": "garanti",
    "garantis": "garanti",
    "garants": "garant",
    "garar": "gara",
    "garas": "gara",
    "garat": "gara",
    "garats": "gara",
    "garden": "garde",
    "gardena": "garde",
    "gardenas": "garde",
    "gardeni": "gardenia",
    "gardenian": "gardenia",
    "gardenians": "gardenia",
    "gardenias": "gardenia",
    "gardenie": "gardenia",
    "gardenior": "gardenia",
    "gardeniorna": "gardenia",
    "gardeniornas": "gardenia",
    "gardeniors": "gardenia",
    "gardenis": "gardenia",
    "gardens": "garde",
    "garder": "gard",
    "garderad": "gardera",
    "garderade": "gardera",
    "garderades": "gardera",
    "garderads": "gardera",
    "garderande": "gardera",
    "garderanden": "garderande",
    "garderandena": "garderande",
    "garderandenas": "garderande",
    "garderandens": "garderande",
    "garderandes": "garderande",
    "garderandet": "garderande",
    "garderandets": "garderande",
    "garderar": "gardera",
    "garderas": "gardera",
    "garderat": "gardera",
    "garderats": "gardera",
    "garderbara": "garderbar",
    "garderbarare": "garderbar",
    "garderbarares": "garderbar",
    "garderbaras": "garderbar",
    "garderbarast": "garderbar",
    "garderbaraste": "garderbar",
    "garderbarastes": "garderbar",
    "garderbarasts": "garderbar",
    "garderbare": "garderbar",
    "garderbares": "garderbar",
    "garderbarheten": "garderbarhet",
    "garderbarhetens": "garderbarhet",
    "garderbarhets": "garderbarhet",
    "garderbars": "garderbar",
    "garderbart": "garderbar",
    "garderbarts": "garderbar",
    "garderingar": "gardering",
    "garderingarna": "gardering",
    "garderingarnas": "gardering",
    "garderingars": "gardering",
    "garderingen": "gardering",
    "garderingens": "gardering",
    "garderings": "gardering",
    "garderna": "gard",
    "gardernas": "gard",
    "garderoben": "garderob",
    "garderobens": "garderob",
    "garderober": "garderob",
    "garderoberna": "garderob",
    "garderobernas": "garderob",
    "garderobers": "garderob",
    "garderobiären": "garderobiär",
    "garderobiärens": "garderobiär",
    "garderobiärer": "garderobiär",
    "garderobiärerna": "garderobiär",
    "garderobiärernas": "garderobiär",
    "garderobiärers": "garderobiär",
    "garderobiärs": "garderobiär",
    "garderobiéer": "garderobié",
    "garderobiéerna": "garderobié",
    "garderobiéernas": "garderobié",
    "garderobiéers": "garderobié",
    "garderobién": "garderobié",
    "garderobiéns": "garderobié",
    "garderobiés": "garderobié",
    "garderobs": "garderob",
    "garderobsdörrar": "garderobsdörr",
    "garderobsdörrarna": "garderobsdörr",
    "garderobsdörrarnas": "garderobsdörr",
    "garderobsdörrars": "garderobsdörr",
    "garderobsdörren": "garderobsdörr",
    "garderobsdörrens": "garderobsdörr",
    "garderobsdörrs": "garderobsdörr",
    "garderobsmässiga": "garderobsmässig",
    "garderobsmässigare": "garderobsmässig",
    "garderobsmässigares": "garderobsmässig",
    "garderobsmässigas": "garderobsmässig",
    "garderobsmässigast": "garderobsmässig",
    "garderobsmässigaste": "garderobsmässig",
    "garderobsmässigastes": "garderobsmässig",
    "garderobsmässigasts": "garderobsmässig",
    "garderobsmässige": "garderobsmässig",
    "garderobsmässiges": "garderobsmässig",
    "garderobsmässigs": "garderobsmässig",
    "garderobsmässigt": "garderobsmässig",
    "garderobsmässigts": "garderobsmässig",
    "garderobssorgs": "garderobssorg",
    "garderobsstänger": "garderobsstång",
    "garderobsstängerna": "garderobsstång",
    "garderobsstängernas": "garderobsstång",
    "garderobsstängers": "garderobsstång",
    "garderobsstången": "garderobsstång",
    "garderobsstångens": "garderobsstång",
    "garderobsstångs": "garderobsstång",
    "garders": "gard",
    "gardes": "garde",
    "gardet": "garde",
    "gardets": "garde",
    "gardianen": "gardian",
    "gardianens": "gardian",
    "gardianer": "gardian",
    "gardianerna": "gardian",
    "gardianernas": "gardian",
    "gardianers": "gardian",
    "gardians": "gardian",
    "gardinbanden": "gardinband",
    "gardinbandens": "gardinband",
    "gardinbandet": "gardinband",
    "gardinbandets": "gardinband",
    "gardinbands": "gardinband",
    "gardinen": "gardin",
    "gardinens": "gardin",
    "gardiner": "gardin",
    "gardinerna": "gardin",
    "gardinernas": "gardin",
    "gardiners": "gardin",
    "gardinkapp": "gardinkappa",
    "gardinkappan": "gardinkappa",
    "gardinkappans": "gardinkappa",
    "gardinkappas": "gardinkappa",
    "gardinkappe": "gardinkappa",
    "gardinkappor": "gardinkappa",
    "gardinkapporna": "gardinkappa",
    "gardinkappornas": "gardinkappa",
    "gardinkappors": "gardinkappa",
    "gardinkapps": "gardinkappa",
    "gardinluften": "gardinluft",
    "gardinluftens": "gardinluft",
    "gardinlufter": "gardinluft",
    "gardinlufterna": "gardinluft",
    "gardinlufternas": "gardinluft",
    "gardinlufters": "gardinluft",
    "gardinlufts": "gardinluft",
    "gardinringar": "gardinring",
    "gardinringarna": "gardinring",
    "gardinringarnas": "gardinring",
    "gardinringars": "gardinring",
    "gardinringen": "gardinring",
    "gardinringens": "gardinring",
    "gardinrings": "gardinring",
    "gardins": "gardin",
    "gardinspring": "gardinspringa",
    "gardinspringan": "gardinspringa",
    "gardinspringans": "gardinspringa",
    "gardinspringas": "gardinspringa",
    "gardinspringe": "gardinspringa",
    "gardinspringor": "gardinspringa",
    "gardinspringorna": "gardinspringa",
    "gardinspringornas": "gardinspringa",
    "gardinspringors": "gardinspringa",
    "gardinsprings": "gardinspringa",
    "gardinstänger": "gardinstång",
    "gardinstängerna": "gardinstång",
    "gardinstängernas": "gardinstång",
    "gardinstängers": "gardinstång",
    "gardinstången": "gardinstång",
    "gardinstångens": "gardinstång",
    "gardinstångs": "gardinstång",
    "gardisten": "gardist",
    "gardistens": "gardist",
    "gardister": "gardist",
    "gardisterna": "gardist",
    "gardisternas": "gardist",
    "gardisters": "gardist",
    "gardists": "gardist",
    "gardjärnen": "gardjärn",
    "gardjärnens": "gardjärn",
    "gardjärnet": "gardjärn",
    "gardjärnets": "gardjärn",
    "gardjärns": "gardjärn",
    "gards": "gard",
    "garfågeln": "garfågel",
    "garfågelns": "garfågel",
    "garfågels": "garfågel",
    "garfåglar": "garfågel",
    "garfåglarna": "garfågel",
    "garfåglarnas": "garfågel",
    "garfåglars": "garfågel",
    "garnbommar": "garnbom",
    "garnbommarna": "garnbom",
    "garnbommarnas": "garnbom",
    "garnbommars": "garnbom",
    "garnbommen": "garnbom",
    "garnbommens": "garnbom",
    "garnboms": "garnbom",
    "garndock": "garndocka",
    "garndockan": "garndocka",
    "garndockans": "garndocka",
    "garndockas": "garndocka",
    "garndocke": "garndocka",
    "garndockor": "garndocka",
    "garndockorna": "garndocka",
    "garndockornas": "garndocka",
    "garndockors": "garndocka",
    "garndocks": "garndocka",
    "garnen": "garn",
    "garnens": "garn",
    "garner": "garn",
    "garnerad": "garnera",
    "garnerade": "garnera",
    "garnerades": "garnera",
    "garnerads": "garnera",
    "garnerande": "garnera",
    "garneranden": "garnerande",
    "garnerandena": "garnerande",
    "garnerandenas": "garnerande",
    "garnerandens": "garnerande",
    "garnerandes": "garnerande",
    "garnerandet": "garnerande",
    "garnerandets": "garnerande",
    "garnerar": "garnera",
    "garneras": "garnera",
    "garnerat": "garnera",
    "garnerats": "garnera",
    "garnerbara": "garnerbar",
    "garnerbarare": "garnerbar",
    "garnerbarares": "garnerbar",
    "garnerbaras": "garnerbar",
    "garnerbarast": "garnerbar",
    "garnerbaraste": "garnerbar",
    "garnerbarastes": "garnerbar",
    "garnerbarasts": "garnerbar",
    "garnerbare": "garnerbar",
    "garnerbares": "garnerbar",
    "garnerbarheten": "garnerbarhet",
    "garnerbarhetens": "garnerbarhet",
    "garnerbarhets": "garnerbarhet",
    "garnerbars": "garnerbar",
    "garnerbart": "garnerbar",
    "garnerbarts": "garnerbar",
    "garneringar": "garnering",
    "garneringarna": "garnering",
    "garneringarnas": "garnering",
    "garneringars": "garnering",
    "garneringen": "garnering",
    "garneringens": "garnering",
    "garnerings": "garnering",
    "garnerna": "garn",
    "garnernas": "garn",
    "garners": "garn",
    "garnet": "garn",
    "garnets": "garn",
    "garnhankar": "garnhank",
    "garnhankarna": "garnhank",
    "garnhankarnas": "garnhank",
    "garnhankars": "garnhank",
    "garnhanken": "garnhank",
    "garnhankens": "garnhank",
    "garnhanks": "garnhank",
    "garnhärvan": "garnhärva",
    "garnhärvans": "garnhärva",
    "garnhärvas": "garnhärva",
    "garnhärve": "garnhärva",
    "garnhärvor": "garnhärva",
    "garnhärvorna": "garnhärva",
    "garnhärvornas": "garnhärva",
    "garnhärvors": "garnhärva",
    "garnisonen": "garnison",
    "garnisonens": "garnison",
    "garnisoner": "garnison",
    "garnisonerad": "garnisonera",
    "garnisonerade": "garnisonera",
    "garnisonerades": "garnisonera",
    "garnisonerads": "garnisonera",
    "garnisonerande": "garnisonera",
    "garnisoneranden": "garnisonerande",
    "garnisonerandena": "garnisonerande",
    "garnisonerandenas": "garnisonerande",
    "garnisonerandens": "garnisonerande",
    "garnisonerandes": "garnisonerande",
    "garnisonerandet": "garnisonerande",
    "garnisonerandets": "garnisonerande",
    "garnisonerar": "garnisonera",
    "garnisoneras": "garnisonera",
    "garnisonerat": "garnisonera",
    "garnisonerats": "garnisonera",
    "garnisonerbara": "garnisonerbar",
    "garnisonerbarare": "garnisonerbar",
    "garnisonerbarares": "garnisonerbar",
    "garnisonerbaras": "garnisonerbar",
    "garnisonerbarast": "garnisonerbar",
    "garnisonerbaraste": "garnisonerbar",
    "garnisonerbarastes": "garnisonerbar",
    "garnisonerbarasts": "garnisonerbar",
    "garnisonerbare": "garnisonerbar",
    "garnisonerbares": "garnisonerbar",
    "garnisonerbarheten": "garnisonerbarhet",
    "garnisonerbarhetens": "garnisonerbarhet",
    "garnisonerbarhets": "garnisonerbarhet",
    "garnisonerbars": "garnisonerbar",
    "garnisonerbart": "garnisonerbar",
    "garnisonerbarts": "garnisonerbar",
    "garnisoneringar": "garnisonering",
    "garnisoneringarna": "garnisonering",
    "garnisoneringarnas": "garnisonering",
    "garnisoneringars": "garnisonering",
    "garnisoneringen": "garnisonering",
    "garnisoneringens": "garnisonering",
    "garnisonerings": "garnisonering",
    "garnisonerna": "garnison",
    "garnisonernas": "garnison",
    "garnisoners": "garnison",
    "garnisons": "garnison",
    "garnityren": "garnityr",
    "garnityrens": "garnityr",
    "garnityret": "garnityr",
    "garnityrets": "garnityr",
    "garnityrs": "garnityr",
    "garns": "garn",
    "garnspol": "garnspole",
    "garnspolar": "garnspole",
    "garnspolarna": "garnspole",
    "garnspolarnas": "garnspole",
    "garnspolars": "garnspole",
    "garnspolen": "garnspole",
    "garnspolens": "garnspole",
    "garnspoles": "garnspole",
    "garnspols": "garnspole",
    "garrotterad": "garrottera",
    "garrotterade": "garrottera",
    "garrotterades": "garrottera",
    "garrotterads": "garrottera",
    "garrotterande": "garrottera",
    "garrotteranden": "garrotterande",
    "garrotterandena": "garrotterande",
    "garrotterandenas": "garrotterande",
    "garrotterandens": "garrotterande",
    "garrotterandes": "garrotterande",
    "garrotterandet": "garrotterande",
    "garrotterandets": "garrotterande",
    "garrotterar": "garrottera",
    "garrotteras": "garrottera",
    "garrotterat": "garrottera",
    "garrotterats": "garrottera",
    "garrotterbara": "garrotterbar",
    "garrotterbarare": "garrotterbar",
    "garrotterbarares": "garrotterbar",
    "garrotterbaras": "garrotterbar",
    "garrotterbarast": "garrotterbar",
    "garrotterbaraste": "garrotterbar",
    "garrotterbarastes": "garrotterbar",
    "garrotterbarasts": "garrotterbar",
    "garrotterbare": "garrotterbar",
    "garrotterbares": "garrotterbar",
    "garrotterbarheten": "garrotterbarhet",
    "garrotterbarhetens": "garrotterbarhet",
    "garrotterbarhets": "garrotterbarhet",
    "garrotterbars": "garrotterbar",
    "garrotterbart": "garrotterbar",
    "garrotterbarts": "garrotterbar",
    "garrotteringar": "garrottering",
    "garrotteringarna": "garrottering",
    "garrotteringarnas": "garrottering",
    "garrotteringars": "garrottering",
    "garrotteringen": "garrottering",
    "garrotteringens": "garrottering",
    "garrotterings": "garrottering",
    "garsongen": "garsong",
    "garsongens": "garsong",
    "garsonger": "garsong",
    "garsongerna": "garsong",
    "garsongernas": "garsong",
    "garsongers": "garsong",
    "garsongs": "garsong",
    "gartnern": "gartner",
    "gartnerna": "gartner",
    "gartnernas": "gartner",
    "gartnerns": "gartner",
    "gartners": "gartner",
    "garv": "garva",
    "garvad": "garva",
    "garvade": "garvad",
    "garvades": "garvad",
    "garvads": "garvad",
    "garvande": "garva",
    "garvanden": "garvande",
    "garvandena": "garvande",
    "garvandenas": "garvande",
    "garvandens": "garvande",
    "garvandes": "garvande",
    "garvandet": "garvande",
    "garvandets": "garvande",
    "garvar": "garvare",
    "garvaren": "garvare",
    "garvarens": "garvare",
    "garvares": "garvare",
    "garvarna": "garvare",
    "garvarnas": "garvare",
    "garvas": "garva",
    "garvat": "garvad",
    "garvats": "garvad",
    "garven": "garv",
    "garvens": "garv",
    "garverier": "garveri",
    "garverierna": "garveri",
    "garveriernas": "garveri",
    "garveriers": "garveri",
    "garveriet": "garveri",
    "garveriets": "garveri",
    "garveris": "garveri",
    "garverit": "garveri",
    "garverits": "garveri",
    "garvet": "garv",
    "garvets": "garv",
    "garvmedels": "garvmedel",
    "garvmedlen": "garvmedel",
    "garvmedlens": "garvmedel",
    "garvmedlet": "garvmedel",
    "garvmedlets": "garvmedel",
    "garvningar": "garvning",
    "garvningarna": "garvning",
    "garvningarnas": "garvning",
    "garvningars": "garvning",
    "garvningen": "garvning",
    "garvningens": "garvning",
    "garvnings": "garvning",
    "garvs": "garv",
    "garvsyran": "garvsyra",
    "garvsyrans": "garvsyra",
    "garvsyras": "garvsyra",
    "garvsyre": "garvsyra",
    "garvämnen": "garvämne",
    "garvämnena": "garvämne",
    "garvämnenas": "garvämne",
    "garvämnens": "garvämne",
    "garvämnes": "garvämne",
    "garvämnet": "garvämne",
    "garvämnets": "garvämne",
    "garçonen": "garçon",
    "garçonens": "garçon",
    "garçoner": "garçon",
    "garçonerna": "garçon",
    "garçonernas": "garçon",
    "garçoners": "garçon",
    "garçons": "garçon",
    "gasackumulatorer": "gasackumulator",
    "gasackumulatorerna": "gasackumulator",
    "gasackumulatorernas": "gasackumulator",
    "gasackumulatorers": "gasackumulator",
    "gasackumulatorn": "gasackumulator",
    "gasackumulatorns": "gasackumulator",
    "gasackumulators": "gasackumulator",
    "gasad": "gasa",
    "gasade": "gasa",
    "gasades": "gasa",
    "gasads": "gasa",
    "gasande": "gasa",
    "gasanden": "gasande",
    "gasandena": "gasande",
    "gasandenas": "gasande",
    "gasandens": "gasande",
    "gasandes": "gasande",
    "gasandet": "gasande",
    "gasandets": "gasande",
    "gasar": "gasa",
    "gasas": "gasa",
    "gasat": "gasa",
    "gasats": "gasa",
    "gasbetongen": "gasbetong",
    "gasbetongens": "gasbetong",
    "gasbetongs": "gasbetong",
    "gasbind": "gasbinda",
    "gasbindan": "gasbinda",
    "gasbindans": "gasbinda",
    "gasbindas": "gasbinda",
    "gasbinde": "gasbinda",
    "gasbindor": "gasbinda",
    "gasbindorna": "gasbinda",
    "gasbindornas": "gasbinda",
    "gasbindors": "gasbinda",
    "gasbinds": "gasbinda",
    "gasblandningar": "gasblandning",
    "gasblandningarna": "gasblandning",
    "gasblandningarnas": "gasblandning",
    "gasblandningars": "gasblandning",
    "gasblandningen": "gasblandning",
    "gasblandningens": "gasblandning",
    "gasblandnings": "gasblandning",
    "gasbranden": "gasbrand",
    "gasbrandens": "gasbrand",
    "gasbrands": "gasbrand",
    "gasbrännar": "gasbrännare",
    "gasbrännaren": "gasbrännare",
    "gasbrännarens": "gasbrännare",
    "gasbrännares": "gasbrännare",
    "gasbrännarna": "gasbrännare",
    "gasbrännarnas": "gasbrännare",
    "gasbubbel": "gasbubbla",
    "gasbubblan": "gasbubbla",
    "gasbubblans": "gasbubbla",
    "gasbubblas": "gasbubbla",
    "gasbubble": "gasbubbla",
    "gasbubblor": "gasbubbla",
    "gasbubblorna": "gasbubbla",
    "gasbubblornas": "gasbubbla",
    "gasbubblors": "gasbubbla",
    "gascognar": "gascognare",
    "gascognaren": "gascognare",
    "gascognarens": "gascognare",
    "gascognares": "gascognare",
    "gascognarna": "gascognare",
    "gascognarnas": "gascognare",
    "gasdynamiken": "gasdynamik",
    "gasdynamikens": "gasdynamik",
    "gasdynamiks": "gasdynamik",
    "gasellen": "gasell",
    "gasellens": "gasell",
    "gaseller": "gasell",
    "gasellerna": "gasell",
    "gasellernas": "gasell",
    "gasellers": "gasell",
    "gasells": "gasell",
    "gasen": "gas",
    "gasens": "gas",
    "gaser": "gas",
    "gaserna": "gas",
    "gasernas": "gas",
    "gasers": "gas",
    "gaseruptionen": "gaseruption",
    "gaseruptionens": "gaseruption",
    "gaseruptioner": "gaseruption",
    "gaseruptionerna": "gaseruption",
    "gaseruptionernas": "gaseruption",
    "gaseruptioners": "gaseruption",
    "gaseruptions": "gaseruption",
    "gaset": "gas",
    "gasets": "gas",
    "gasetten": "gasett",
    "gasettens": "gasett",
    "gasetter": "gasett",
    "gasetterna": "gasett",
    "gasetternas": "gasett",
    "gasetters": "gasett",
    "gasetts": "gasett",
    "gasexplosionen": "gasexplosion",
    "gasexplosionens": "gasexplosion",
    "gasexplosioner": "gasexplosion",
    "gasexplosionerna": "gasexplosion",
    "gasexplosionernas": "gasexplosion",
    "gasexplosioners": "gasexplosion",
    "gasexplosions": "gasexplosion",
    "gasformiga": "gasformig",
    "gasformigare": "gasformig",
    "gasformigares": "gasformig",
    "gasformigas": "gasformig",
    "gasformigast": "gasformig",
    "gasformigaste": "gasformig",
    "gasformigastes": "gasformig",
    "gasformigasts": "gasformig",
    "gasformige": "gasformig",
    "gasformiges": "gasformig",
    "gasformigs": "gasformig",
    "gasformigt": "gasformig",
    "gasformigts": "gasformig",
    "gasförgiftningar": "gasförgiftning",
    "gasförgiftningarna": "gasförgiftning",
    "gasförgiftningarnas": "gasförgiftning",
    "gasförgiftningars": "gasförgiftning",
    "gasförgiftningen": "gasförgiftning",
    "gasförgiftningens": "gasförgiftning",
    "gasförgiftnings": "gasförgiftning",
    "gasgeneratorer": "gasgenerator",
    "gasgeneratorerna": "gasgenerator",
    "gasgeneratorernas": "gasgenerator",
    "gasgeneratorers": "gasgenerator",
    "gasgeneratorn": "gasgenerator",
    "gasgeneratorns": "gasgenerator",
    "gasgenerators": "gasgenerator",
    "gaskammar": "gaskammare",
    "gaskammaren": "gaskammare",
    "gaskammarens": "gaskammare",
    "gaskammares": "gaskammare",
    "gaskamrar": "gaskammare",
    "gaskamrarna": "gaskammare",
    "gaskamrarnas": "gaskammare",
    "gaskamrars": "gaskammare",
    "gaskar": "gask",
    "gaskarna": "gask",
    "gaskarnas": "gask",
    "gaskars": "gask",
    "gaskatastrofen": "gaskatastrof",
    "gaskatastrofens": "gaskatastrof",
    "gaskatastrofer": "gaskatastrof",
    "gaskatastroferna": "gaskatastrof",
    "gaskatastrofernas": "gaskatastrof",
    "gaskatastrofers": "gaskatastrof",
    "gaskatastrofs": "gaskatastrof",
    "gasken": "gask",
    "gaskens": "gask",
    "gasker": "gask",
    "gaskerna": "gask",
    "gaskernas": "gask",
    "gaskers": "gask",
    "gasklock": "gasklocka",
    "gasklockan": "gasklocka",
    "gasklockans": "gasklocka",
    "gasklockas": "gasklocka",
    "gasklocke": "gasklocka",
    "gasklockor": "gasklocka",
    "gasklockorna": "gasklocka",
    "gasklockornas": "gasklocka",
    "gasklockors": "gasklocka",
    "gasklocks": "gasklocka",
    "gaskloten": "gasklot",
    "gasklotens": "gasklot",
    "gasklotet": "gasklot",
    "gasklotets": "gasklot",
    "gasklots": "gasklot",
    "gaskromatografen": "gaskromatograf",
    "gaskromatografens": "gaskromatograf",
    "gaskromatografer": "gaskromatograf",
    "gaskromatograferna": "gaskromatograf",
    "gaskromatografernas": "gaskromatograf",
    "gaskromatografers": "gaskromatograf",
    "gaskromatografien": "gaskromatografi",
    "gaskromatografiens": "gaskromatografi",
    "gaskromatografin": "gaskromatografi",
    "gaskromatografins": "gaskromatografi",
    "gaskromatografis": "gaskromatografi",
    "gaskromatografs": "gaskromatograf",
    "gaskroppar": "gaskropp",
    "gaskropparna": "gaskropp",
    "gaskropparnas": "gaskropp",
    "gaskroppars": "gaskropp",
    "gaskroppen": "gaskropp",
    "gaskroppens": "gaskropp",
    "gaskropps": "gaskropp",
    "gasks": "gask",
    "gaslamp": "gaslampa",
    "gaslampan": "gaslampa",
    "gaslampans": "gaslampa",
    "gaslampas": "gaslampa",
    "gaslampe": "gaslampa",
    "gaslampor": "gaslampa",
    "gaslamporna": "gaslampa",
    "gaslampornas": "gaslampa",
    "gaslampors": "gaslampa",
    "gaslamps": "gaslampa",
    "gasledningar": "gasledning",
    "gasledningarna": "gasledning",
    "gasledningarnas": "gasledning",
    "gasledningars": "gasledning",
    "gasledningen": "gasledning",
    "gasledningens": "gasledning",
    "gaslednings": "gasledning",
    "gasläck": "gasläcka",
    "gasläckagen": "gasläckage",
    "gasläckagens": "gasläckage",
    "gasläckages": "gasläckage",
    "gasläckaget": "gasläckage",
    "gasläckagets": "gasläckage",
    "gasläckan": "gasläcka",
    "gasläckans": "gasläcka",
    "gasläckas": "gasläcka",
    "gasläcke": "gasläcka",
    "gasläckor": "gasläcka",
    "gasläckorna": "gasläcka",
    "gasläckornas": "gasläcka",
    "gasläckors": "gasläcka",
    "gasläcks": "gasläcka",
    "gasläran": "gaslära",
    "gaslärans": "gaslära",
    "gasläras": "gaslära",
    "gasläre": "gaslära",
    "gasläro": "gaslära",
    "gasläror": "gaslära",
    "gaslärorna": "gaslära",
    "gaslärornas": "gaslära",
    "gaslärors": "gaslära",
    "gaslåg": "gaslåga",
    "gaslågan": "gaslåga",
    "gaslågans": "gaslåga",
    "gaslågas": "gaslåga",
    "gaslåge": "gaslåga",
    "gaslågor": "gaslåga",
    "gaslågorna": "gaslåga",
    "gaslågornas": "gaslåga",
    "gaslågors": "gaslåga",
    "gaslågs": "gaslåga",
    "gasmasken": "gasmask",
    "gasmaskens": "gasmask",
    "gasmasker": "gasmask",
    "gasmaskerna": "gasmask",
    "gasmaskernas": "gasmask",
    "gasmaskers": "gasmask",
    "gasmaskfodralen": "gasmaskfodral",
    "gasmaskfodralens": "gasmaskfodral",
    "gasmaskfodralet": "gasmaskfodral",
    "gasmaskfodralets": "gasmaskfodral",
    "gasmaskfodrals": "gasmaskfodral",
    "gasmasks": "gasmask",
    "gasmassan": "gasmassa",
    "gasmassans": "gasmassa",
    "gasmassas": "gasmassa",
    "gasmasse": "gasmassa",
    "gasmassor": "gasmassa",
    "gasmassorna": "gasmassa",
    "gasmassornas": "gasmassa",
    "gasmassors": "gasmassa",
    "gasmolnen": "gasmoln",
    "gasmolnens": "gasmoln",
    "gasmolnet": "gasmoln",
    "gasmolnets": "gasmoln",
    "gasmolns": "gasmoln",
    "gasolen": "gasol",
    "gasolens": "gasol",
    "gasolgrillar": "gasolgrill",
    "gasolgrillarna": "gasolgrill",
    "gasolgrillarnas": "gasolgrill",
    "gasolgrillars": "gasolgrill",
    "gasolgrillen": "gasolgrill",
    "gasolgrillens": "gasolgrill",
    "gasolgrills": "gasolgrill",
    "gasolinen": "gasolin",
    "gasolinens": "gasolin",
    "gasolinet": "gasolin",
    "gasolinets": "gasolin",
    "gasolins": "gasolin",
    "gasolköken": "gasolkök",
    "gasolkökens": "gasolkök",
    "gasolköket": "gasolkök",
    "gasolkökets": "gasolkök",
    "gasolköks": "gasolkök",
    "gasols": "gasol",
    "gasoltuben": "gasoltub",
    "gasoltubens": "gasoltub",
    "gasoltuber": "gasoltub",
    "gasoltuberna": "gasoltub",
    "gasoltubernas": "gasoltub",
    "gasoltubers": "gasoltub",
    "gasoltubs": "gasoltub",
    "gasometern": "gasometer",
    "gasometerns": "gasometer",
    "gasometers": "gasometer",
    "gasometrar": "gasometer",
    "gasometrarna": "gasometer",
    "gasometrarnas": "gasometer",
    "gasometrars": "gasometer",
    "gaspedalen": "gaspedal",
    "gaspedalens": "gaspedal",
    "gaspedaler": "gaspedal",
    "gaspedalerna": "gaspedal",
    "gaspedalernas": "gaspedal",
    "gaspedalers": "gaspedal",
    "gaspedals": "gaspedal",
    "gasreglagen": "gasreglage",
    "gasreglagens": "gasreglage",
    "gasreglages": "gasreglage",
    "gasreglaget": "gasreglage",
    "gasreglagets": "gasreglage",
    "gasräkningar": "gasräkning",
    "gasräkningarna": "gasräkning",
    "gasräkningarnas": "gasräkning",
    "gasräkningars": "gasräkning",
    "gasräkningen": "gasräkning",
    "gasräkningens": "gasräkning",
    "gasräknings": "gasräkning",
    "gassade": "gassa",
    "gassades": "gassa",
    "gassande": "gassa",
    "gassanden": "gassande",
    "gassandena": "gassande",
    "gassandenas": "gassande",
    "gassandens": "gassande",
    "gassandes": "gassande",
    "gassandet": "gassande",
    "gassandets": "gassande",
    "gassar": "gassa",
    "gassas": "gassa",
    "gassat": "gassa",
    "gassats": "gassa",
    "gasset": "gass",
    "gassets": "gass",
    "gassiga": "gassig",
    "gassigare": "gassig",
    "gassigares": "gassig",
    "gassigas": "gassig",
    "gassigast": "gassig",
    "gassigaste": "gassig",
    "gassigastes": "gassig",
    "gassigasts": "gassig",
    "gassige": "gassig",
    "gassiges": "gassig",
    "gassigheten": "gassighet",
    "gassighetens": "gassighet",
    "gassighets": "gassighet",
    "gassigs": "gassig",
    "gassigt": "gassig",
    "gassigts": "gassig",
    "gasskivan": "gasskiva",
    "gasskivans": "gasskiva",
    "gasskivas": "gasskiva",
    "gasskive": "gasskiva",
    "gasskivor": "gasskiva",
    "gasskivorna": "gasskiva",
    "gasskivornas": "gasskiva",
    "gasskivors": "gasskiva",
    "gasskydden": "gasskydd",
    "gasskyddens": "gasskydd",
    "gasskyddet": "gasskydd",
    "gasskyddets": "gasskydd",
    "gasskydds": "gasskydd",
    "gasspisar": "gasspis",
    "gasspisarna": "gasspis",
    "gasspisarnas": "gasspis",
    "gasspisars": "gasspis",
    "gasspisen": "gasspis",
    "gasspisens": "gasspis",
    "gasströmmar": "gasström",
    "gasströmmarna": "gasström",
    "gasströmmarnas": "gasström",
    "gasströmmars": "gasström",
    "gasströmmen": "gasström",
    "gasströmmens": "gasström",
    "gasströms": "gasström",
    "gassvetsningar": "gassvetsning",
    "gassvetsningarna": "gassvetsning",
    "gassvetsningarnas": "gassvetsning",
    "gassvetsningars": "gassvetsning",
    "gassvetsningen": "gassvetsning",
    "gassvetsningens": "gassvetsning",
    "gassvetsnings": "gassvetsning",
    "gast": "gasta",
    "gastade": "gasta",
    "gastades": "gasta",
    "gastande": "gasta",
    "gastanden": "gastande",
    "gastandena": "gastande",
    "gastandenas": "gastande",
    "gastandens": "gastande",
    "gastandes": "gastande",
    "gastandet": "gastande",
    "gastandets": "gastande",
    "gastar": "gasta",
    "gastarna": "gast",
    "gastarnas": "gast",
    "gastars": "gast",
    "gastas": "gasta",
    "gastat": "gasta",
    "gastats": "gasta",
    "gasten": "gast",
    "gastens": "gast",
    "gasterade": "gastera",
    "gasterades": "gastera",
    "gasterande": "gastera",
    "gasteranden": "gasterande",
    "gasterandena": "gasterande",
    "gasterandenas": "gasterande",
    "gasterandens": "gasterande",
    "gasterandes": "gasterande",
    "gasterandet": "gasterande",
    "gasterandets": "gasterande",
    "gasterar": "gastera",
    "gasteras": "gastera",
    "gasterat": "gastera",
    "gasterats": "gastera",
    "gasteringar": "gastering",
    "gasteringarna": "gastering",
    "gasteringarnas": "gastering",
    "gasteringars": "gastering",
    "gasteringen": "gastering",
    "gasteringens": "gastering",
    "gasterings": "gastering",
    "gastkramad": "gastkrama",
    "gastkramade": "gastkrama",
    "gastkramades": "gastkrama",
    "gastkramads": "gastkrama",
    "gastkramande": "gastkrama",
    "gastkramanden": "gastkramande",
    "gastkramandena": "gastkramande",
    "gastkramandenas": "gastkramande",
    "gastkramandens": "gastkramande",
    "gastkramandes": "gastkramande",
    "gastkramandet": "gastkramande",
    "gastkramandets": "gastkramande",
    "gastkramar": "gastkrama",
    "gastkramas": "gastkrama",
    "gastkramat": "gastkrama",
    "gastkramats": "gastkrama",
    "gastriska": "gastrisk",
    "gastriskare": "gastrisk",
    "gastriskares": "gastrisk",
    "gastriskas": "gastrisk",
    "gastriskast": "gastrisk",
    "gastriskaste": "gastrisk",
    "gastriskastes": "gastrisk",
    "gastriskasts": "gastrisk",
    "gastriske": "gastrisk",
    "gastriskes": "gastrisk",
    "gastrisks": "gastrisk",
    "gastriskt": "gastrisk",
    "gastriskts": "gastrisk",
    "gastriten": "gastrit",
    "gastritens": "gastrit",
    "gastriter": "gastrit",
    "gastriterna": "gastrit",
    "gastriternas": "gastrit",
    "gastriters": "gastrit",
    "gastrits": "gastrit",
    "gastronomen": "gastronom",
    "gastronomens": "gastronom",
    "gastronomer": "gastronom",
    "gastronomerna": "gastronom",
    "gastronomernas": "gastronom",
    "gastronomers": "gastronom",
    "gastronomien": "gastronomi",
    "gastronomiens": "gastronomi",
    "gastronomin": "gastronomi",
    "gastronomins": "gastronomi",
    "gastronomis": "gastronomi",
    "gastronomiska": "gastronomisk",
    "gastronomiskare": "gastronomisk",
    "gastronomiskares": "gastronomisk",
    "gastronomiskas": "gastronomisk",
    "gastronomiskast": "gastronomisk",
    "gastronomiskaste": "gastronomisk",
    "gastronomiskastes": "gastronomisk",
    "gastronomiskasts": "gastronomisk",
    "gastronomiske": "gastronomisk",
    "gastronomiskes": "gastronomisk",
    "gastronomisks": "gastronomisk",
    "gastronomiskt": "gastronomisk",
    "gastronomiskts": "gastronomisk",
    "gastronoms": "gastronom",
    "gastroskopen": "gastroskop",
    "gastroskopens": "gastroskop",
    "gastroskoperad": "gastroskopera",
    "gastroskoperade": "gastroskopera",
    "gastroskoperades": "gastroskopera",
    "gastroskoperads": "gastroskopera",
    "gastroskoperande": "gastroskopera",
    "gastroskoperanden": "gastroskoperande",
    "gastroskoperandena": "gastroskoperande",
    "gastroskoperandenas": "gastroskoperande",
    "gastroskoperandens": "gastroskoperande",
    "gastroskoperandes": "gastroskoperande",
    "gastroskoperandet": "gastroskoperande",
    "gastroskoperandets": "gastroskoperande",
    "gastroskoperar": "gastroskopera",
    "gastroskoperas": "gastroskopera",
    "gastroskoperat": "gastroskopera",
    "gastroskoperats": "gastroskopera",
    "gastroskoperbara": "gastroskoperbar",
    "gastroskoperbarare": "gastroskoperbar",
    "gastroskoperbarares": "gastroskoperbar",
    "gastroskoperbaras": "gastroskoperbar",
    "gastroskoperbarast": "gastroskoperbar",
    "gastroskoperbaraste": "gastroskoperbar",
    "gastroskoperbarastes": "gastroskoperbar",
    "gastroskoperbarasts": "gastroskoperbar",
    "gastroskoperbare": "gastroskoperbar",
    "gastroskoperbares": "gastroskoperbar",
    "gastroskoperbarheten": "gastroskoperbarhet",
    "gastroskoperbarhetens": "gastroskoperbarhet",
    "gastroskoperbarhets": "gastroskoperbarhet",
    "gastroskoperbars": "gastroskoperbar",
    "gastroskoperbart": "gastroskoperbar",
    "gastroskoperbarts": "gastroskoperbar",
    "gastroskoperingar": "gastroskopering",
    "gastroskoperingarna": "gastroskopering",
    "gastroskoperingarnas": "gastroskopering",
    "gastroskoperingars": "gastroskopering",
    "gastroskoperingen": "gastroskopering",
    "gastroskoperingens": "gastroskopering",
    "gastroskoperings": "gastroskopering",
    "gastroskopet": "gastroskop",
    "gastroskopets": "gastroskop",
    "gastroskopien": "gastroskopi",
    "gastroskopiens": "gastroskopi",
    "gastroskopier": "gastroskopi",
    "gastroskopierna": "gastroskopi",
    "gastroskopiernas": "gastroskopi",
    "gastroskopiers": "gastroskopi",
    "gastroskopin": "gastroskopi",
    "gastroskopins": "gastroskopi",
    "gastroskopis": "gastroskopi",
    "gastroskops": "gastroskop",
    "gastrycken": "gastryck",
    "gastryckens": "gastryck",
    "gastrycket": "gastryck",
    "gastryckets": "gastryck",
    "gastrycks": "gastryck",
    "gasts": "gast",
    "gasturbinen": "gasturbin",
    "gasturbinens": "gasturbin",
    "gasturbiner": "gasturbin",
    "gasturbinerna": "gasturbin",
    "gasturbinernas": "gasturbin",
    "gasturbiners": "gasturbin",
    "gasturbins": "gasturbin",
    "gasurladdningar": "gasurladdning",
    "gasurladdningarna": "gasurladdning",
    "gasurladdningarnas": "gasurladdning",
    "gasurladdningars": "gasurladdning",
    "gasurladdningen": "gasurladdning",
    "gasurladdningens": "gasurladdning",
    "gasurladdnings": "gasurladdning",
    "gasutsläppen": "gasutsläpp",
    "gasutsläppens": "gasutsläpp",
    "gasutsläppet": "gasutsläpp",
    "gasutsläppets": "gasutsläpp",
    "gasutsläpps": "gasutsläpp",
    "gasventilen": "gasventil",
    "gasventilens": "gasventil",
    "gasventiler": "gasventil",
    "gasventilerna": "gasventil",
    "gasventilernas": "gasventil",
    "gasventilers": "gasventil",
    "gasventils": "gasventil",
    "gasverken": "gasverk",
    "gasverkens": "gasverk",
    "gasverket": "gasverk",
    "gasverkets": "gasverk",
    "gasverks": "gasverk",
    "gat": "gata",
    "gatan": "gata",
    "gatans": "gata",
    "gatas": "gata",
    "gatflick": "gatflicka",
    "gatflickan": "gatflicka",
    "gatflickans": "gatflicka",
    "gatflickas": "gatflicka",
    "gatflicke": "gatflicka",
    "gatflickor": "gatflicka",
    "gatflickorna": "gatflicka",
    "gatflickornas": "gatflicka",
    "gatflickors": "gatflicka",
    "gatflicks": "gatflicka",
    "gathusen": "gathus",
    "gathusens": "gathus",
    "gathuset": "gathus",
    "gathusets": "gathus",
    "gathörnen": "gathörn",
    "gathörnens": "gathörn",
    "gathörnet": "gathörn",
    "gathörnets": "gathörn",
    "gathörns": "gathörn",
    "gatloppen": "gatlopp",
    "gatloppens": "gatlopp",
    "gatloppet": "gatlopp",
    "gatloppets": "gatlopp",
    "gatlopps": "gatlopp",
    "gatlykt": "gatlykta",
    "gatlyktan": "gatlykta",
    "gatlyktans": "gatlykta",
    "gatlyktas": "gatlykta",
    "gatlykte": "gatlykta",
    "gatlyktor": "gatlykta",
    "gatlyktorna": "gatlykta",
    "gatlyktornas": "gatlykta",
    "gatlyktors": "gatlykta",
    "gatlykts": "gatlykta",
    "gatläggningar": "gatläggning",
    "gatläggningarna": "gatläggning",
    "gatläggningarnas": "gatläggning",
    "gatläggningars": "gatläggning",
    "gatläggningen": "gatläggning",
    "gatläggningens": "gatläggning",
    "gatläggnings": "gatläggning",
    "gator": "gata",
    "gatorna": "gata",
    "gatornas": "gata",
    "gators": "gata",
    "gatpojk": "gatpojke",
    "gatpojkar": "gatpojke",
    "gatpojkarna": "gatpojke",
    "gatpojkarnas": "gatpojke",
    "gatpojkars": "gatpojke",
    "gatpojken": "gatpojke",
    "gatpojkens": "gatpojke",
    "gatpojkes": "gatpojke",
    "gatpojks": "gatpojke",
    "gatslink": "gatslinka",
    "gatslinkan": "gatslinka",
    "gatslinkans": "gatslinka",
    "gatslinkas": "gatslinka",
    "gatslinke": "gatslinka",
    "gatslinkor": "gatslinka",
    "gatslinkorna": "gatslinka",
    "gatslinkornas": "gatslinka",
    "gatslinkors": "gatslinka",
    "gatslinks": "gatslinka",
    "gatsopar": "gatsopare",
    "gatsoparen": "gatsopare",
    "gatsoparens": "gatsopare",
    "gatsopares": "gatsopare",
    "gatsoparna": "gatsopare",
    "gatsoparnas": "gatsopare",
    "gatstenar": "gatsten",
    "gatstenarna": "gatsten",
    "gatstenarnas": "gatsten",
    "gatstenars": "gatsten",
    "gatstenen": "gatsten",
    "gatstenens": "gatsten",
    "gatstens": "gatsten",
    "gatten": "gatt",
    "gattens": "gatt",
    "gattet": "gatt",
    "gattets": "gatt",
    "gatts": "gatt",
    "gatu": "gata",
    "gatubarnen": "gatubarn",
    "gatubarnens": "gatubarn",
    "gatubarnet": "gatubarn",
    "gatubarnets": "gatubarn",
    "gatubarns": "gatubarn",
    "gatubelysningar": "gatubelysning",
    "gatubelysningarna": "gatubelysning",
    "gatubelysningarnas": "gatubelysning",
    "gatubelysningars": "gatubelysning",
    "gatubelysningen": "gatubelysning",
    "gatubelysningens": "gatubelysning",
    "gatubelysnings": "gatubelysning",
    "gatubeläggningar": "gatubeläggning",
    "gatubeläggningarna": "gatubeläggning",
    "gatubeläggningarnas": "gatubeläggning",
    "gatubeläggningars": "gatubeläggning",
    "gatubeläggningen": "gatubeläggning",
    "gatubeläggningens": "gatubeläggning",
    "gatubeläggnings": "gatubeläggning",
    "gatufreden": "gatufred",
    "gatufredens": "gatufred",
    "gatufreds": "gatufred",
    "gatufriden": "gatufrid",
    "gatufridens": "gatufrid",
    "gatufrids": "gatufrid",
    "gatuförsäljar": "gatuförsäljare",
    "gatuförsäljaren": "gatuförsäljare",
    "gatuförsäljarens": "gatuförsäljare",
    "gatuförsäljares": "gatuförsäljare",
    "gatuförsäljarna": "gatuförsäljare",
    "gatuförsäljarnas": "gatuförsäljare",
    "gatuhusen": "gatuhus",
    "gatuhusens": "gatuhus",
    "gatuhuset": "gatuhus",
    "gatuhusets": "gatuhus",
    "gatukontoren": "gatukontor",
    "gatukontorens": "gatukontor",
    "gatukontoret": "gatukontor",
    "gatukontorets": "gatukontor",
    "gatukontors": "gatukontor",
    "gatukorsen": "gatukors",
    "gatukorsens": "gatukors",
    "gatukorset": "gatukors",
    "gatukorsets": "gatukors",
    "gatukorsningar": "gatukorsning",
    "gatukorsningarna": "gatukorsning",
    "gatukorsningarnas": "gatukorsning",
    "gatukorsningars": "gatukorsning",
    "gatukorsningen": "gatukorsning",
    "gatukorsningens": "gatukorsning",
    "gatukorsnings": "gatukorsning",
    "gatuköken": "gatukök",
    "gatukökens": "gatukök",
    "gatuköket": "gatukök",
    "gatukökets": "gatukök",
    "gatuköks": "gatukök",
    "gatuliven": "gatuliv",
    "gatulivens": "gatuliv",
    "gatulivet": "gatuliv",
    "gatulivets": "gatuliv",
    "gatulivs": "gatuliv",
    "gatumusikanten": "gatumusikant",
    "gatumusikantens": "gatumusikant",
    "gatumusikanter": "gatumusikant",
    "gatumusikanterna": "gatumusikant",
    "gatumusikanternas": "gatumusikant",
    "gatumusikanters": "gatumusikant",
    "gatumusikants": "gatumusikant",
    "gatumusiken": "gatumusik",
    "gatumusikens": "gatumusik",
    "gatumusiks": "gatumusik",
    "gatunamnen": "gatunamn",
    "gatunamnens": "gatunamn",
    "gatunamnet": "gatunamn",
    "gatunamnets": "gatunamn",
    "gatunamns": "gatunamn",
    "gatungar": "gatunge",
    "gatungarna": "gatunge",
    "gatungarnas": "gatunge",
    "gatungars": "gatunge",
    "gatungen": "gatunge",
    "gatungens": "gatunge",
    "gatunges": "gatunge",
    "gatuplanen": "gatuplan",
    "gatuplanens": "gatuplan",
    "gatuplanet": "gatuplan",
    "gatuplanets": "gatuplan",
    "gatuplans": "gatuplan",
    "gatuscenen": "gatuscen",
    "gatuscenens": "gatuscen",
    "gatuscener": "gatuscen",
    "gatuscenerna": "gatuscen",
    "gatuscenernas": "gatuscen",
    "gatusceners": "gatuscen",
    "gatuscens": "gatuscen",
    "gatustånden": "gatustånd",
    "gatuståndens": "gatustånd",
    "gatuståndet": "gatustånd",
    "gatuståndets": "gatustånd",
    "gatustånds": "gatustånd",
    "gatuteatern": "gatuteater",
    "gatuteaterns": "gatuteater",
    "gatuteaters": "gatuteater",
    "gatuteatrar": "gatuteater",
    "gatuteatrarna": "gatuteater",
    "gatuteatrarnas": "gatuteater",
    "gatuteatrars": "gatuteater",
    "gatuvåldet": "gatuvåld",
    "gatuvåldets": "gatuvåld",
    "gatuvålds": "gatuvåld",
    "gauchon": "gaucho",
    "gauchons": "gaucho",
    "gauchor": "gaucho",
    "gauchorna": "gaucho",
    "gauchornas": "gaucho",
    "gauchors": "gaucho",
    "gauchos": "gaucho",
    "gauchosen": "gaucho",
    "gauchosens": "gaucho",
    "gauffrerad": "gauffrera",
    "gauffrerade": "gauffrera",
    "gauffrerades": "gauffrera",
    "gauffrerads": "gauffrera",
    "gauffrerande": "gauffrera",
    "gauffreranden": "gauffrerande",
    "gauffrerandena": "gauffrerande",
    "gauffrerandenas": "gauffrerande",
    "gauffrerandens": "gauffrerande",
    "gauffrerandes": "gauffrerande",
    "gauffrerandet": "gauffrerande",
    "gauffrerandets": "gauffrerande",
    "gauffrerar": "gauffrera",
    "gauffreras": "gauffrera",
    "gauffrerat": "gauffrera",
    "gauffrerats": "gauffrera",
    "gauffrerbara": "gauffrerbar",
    "gauffrerbarare": "gauffrerbar",
    "gauffrerbarares": "gauffrerbar",
    "gauffrerbaras": "gauffrerbar",
    "gauffrerbarast": "gauffrerbar",
    "gauffrerbaraste": "gauffrerbar",
    "gauffrerbarastes": "gauffrerbar",
    "gauffrerbarasts": "gauffrerbar",
    "gauffrerbare": "gauffrerbar",
    "gauffrerbares": "gauffrerbar",
    "gauffrerbarheten": "gauffrerbarhet",
    "gauffrerbarhetens": "gauffrerbarhet",
    "gauffrerbarhets": "gauffrerbarhet",
    "gauffrerbars": "gauffrerbar",
    "gauffrerbart": "gauffrerbar",
    "gauffrerbarts": "gauffrerbar",
    "gauffreringar": "gauffrering",
    "gauffreringarna": "gauffrering",
    "gauffreringarnas": "gauffrering",
    "gauffreringars": "gauffrering",
    "gauffreringen": "gauffrering",
    "gauffreringens": "gauffrering",
    "gauffrerings": "gauffrering",
    "gaugen": "gauge",
    "gaugena": "gauge",
    "gaugenas": "gauge",
    "gaugens": "gauge",
    "gauges": "gauge",
    "gaullismen": "gaullism",
    "gaullismens": "gaullism",
    "gaullismer": "gaullism",
    "gaullismerna": "gaullism",
    "gaullismernas": "gaullism",
    "gaullismers": "gaullism",
    "gaullisms": "gaullism",
    "gaullisten": "gaullist",
    "gaullistens": "gaullist",
    "gaullister": "gaullist",
    "gaullisterna": "gaullist",
    "gaullisternas": "gaullist",
    "gaullisters": "gaullist",
    "gaullistiska": "gaullistisk",
    "gaullistiskare": "gaullistisk",
    "gaullistiskares": "gaullistisk",
    "gaullistiskas": "gaullistisk",
    "gaullistiskast": "gaullistisk",
    "gaullistiskaste": "gaullistisk",
    "gaullistiskastes": "gaullistisk",
    "gaullistiskasts": "gaullistisk",
    "gaullistiske": "gaullistisk",
    "gaullistiskes": "gaullistisk",
    "gaullistisks": "gaullistisk",
    "gaullistiskt": "gaullistisk",
    "gaullistiskts": "gaullistisk",
    "gaullists": "gaullist",
    "gauren": "gaur",
    "gaurens": "gaur",
    "gaurer": "gaur",
    "gaurerna": "gaur",
    "gaurernas": "gaur",
    "gaurers": "gaur",
    "gaurs": "gaur",
    "gaussen": "gauss",
    "gaussens": "gauss",
    "gausskurv": "gausskurva",
    "gausskurvan": "gausskurva",
    "gausskurvans": "gausskurva",
    "gausskurvas": "gausskurva",
    "gausskurve": "gausskurva",
    "gausskurvor": "gausskurva",
    "gausskurvorna": "gausskurva",
    "gausskurvornas": "gausskurva",
    "gausskurvors": "gausskurva",
    "gausskurvs": "gausskurva",
    "gav": "ge",
    "gavelfälten": "gavelfält",
    "gavelfältens": "gavelfält",
    "gavelfältet": "gavelfält",
    "gavelfältets": "gavelfält",
    "gavelfälts": "gavelfält",
    "gavelhusen": "gavelhus",
    "gavelhusens": "gavelhus",
    "gavelhuset": "gavelhus",
    "gavelhusets": "gavelhus",
    "gaveln": "gavel",
    "gavelns": "gavel",
    "gavelrösten": "gavelröste",
    "gavelröstena": "gavelröste",
    "gavelröstenas": "gavelröste",
    "gavelröstens": "gavelröste",
    "gavelröstes": "gavelröste",
    "gavelröstet": "gavelröste",
    "gavelröstets": "gavelröste",
    "gavelrösts": "gavelröst",
    "gavels": "gavel",
    "gavialen": "gavial",
    "gavialens": "gavial",
    "gavialer": "gavial",
    "gavialerna": "gavial",
    "gavialernas": "gavial",
    "gavialers": "gavial",
    "gavials": "gavial",
    "gavlar": "gavel",
    "gavlarna": "gavel",
    "gavlarnas": "gavel",
    "gavlars": "gavel",
    "gavotten": "gavott",
    "gavottens": "gavott",
    "gavotter": "gavott",
    "gavotterna": "gavott",
    "gavotternas": "gavott",
    "gavotters": "gavott",
    "gavotts": "gavott",
    "gavs": "ge",
    "gaya": "gay",
    "gayalen": "gayal",
    "gayalens": "gayal",
    "gayaler": "gayal",
    "gayalerna": "gayal",
    "gayalernas": "gayal",
    "gayalers": "gayal",
    "gayals": "gayal",
    "gayare": "gay",
    "gayares": "gay",
    "gayas": "gay",
    "gayast": "gay",
    "gayaste": "gay",
    "gayastes": "gay",
    "gayasts": "gay",
    "gaye": "gay",
    "gayes": "gay",
    "gays": "gay",
    "gayt": "gay",
    "gayts": "gay",
    "gebiten": "gebit",
    "gebitens": "gebit",
    "gebitet": "gebit",
    "gebitets": "gebit",
    "gebits": "gebit",
    "geckon": "gecko",
    "geckons": "gecko",
    "geckor": "gecko",
    "geckorna": "gecko",
    "geckornas": "gecko",
    "geckors": "gecko",
    "geckos": "gecko",
    "geckoödlan": "geckoödla",
    "geckoödlans": "geckoödla",
    "geckoödlas": "geckoödla",
    "geckoödle": "geckoödla",
    "geckoödlor": "geckoödla",
    "geckoödlorna": "geckoödla",
    "geckoödlornas": "geckoödla",
    "geckoödlors": "geckoödla",
    "gedigenheten": "gedigenhet",
    "gedigenhetens": "gedigenhet",
    "gedigenhets": "gedigenhet",
    "gedigens": "gedigen",
    "gediget": "gedigen",
    "gedigets": "gedigen",
    "gedigna": "gedigen",
    "gedignare": "gedigen",
    "gedignares": "gedigen",
    "gedignas": "gedigen",
    "gedignast": "gedigen",
    "gedignaste": "gedigen",
    "gedignastes": "gedigen",
    "gedignasts": "gedigen",
    "gedigne": "gedigen",
    "gedignes": "gedigen",
    "geende": "ge",
    "geenden": "geende",
    "geendena": "geende",
    "geendenas": "geende",
    "geendens": "geende",
    "geendes": "geende",
    "geendet": "geende",
    "geendets": "geende",
    "gegen": "geg",
    "gegens": "geg",
    "geger": "geg",
    "gegerna": "geg",
    "gegernas": "geg",
    "gegers": "geg",
    "gegg": "gegga",
    "geggade": "gegga",
    "geggades": "gegga",
    "geggamojan": "geggamoja",
    "geggamojans": "geggamoja",
    "geggamojas": "geggamoja",
    "geggan": "gegga",
    "geggande": "gegga",
    "gegganden": "geggande",
    "geggandena": "geggande",
    "geggandenas": "geggande",
    "geggandens": "geggande",
    "geggandes": "geggande",
    "geggandet": "geggande",
    "geggandets": "geggande",
    "geggans": "gegga",
    "geggar": "gegga",
    "geggas": "gegga",
    "geggat": "gegga",
    "geggats": "gegga",
    "geggen": "gegg",
    "geggens": "gegg",
    "gegget": "gegg",
    "geggets": "gegg",
    "geggiga": "geggig",
    "geggigare": "geggig",
    "geggigares": "geggig",
    "geggigas": "geggig",
    "geggigast": "geggig",
    "geggigaste": "geggig",
    "geggigastes": "geggig",
    "geggigasts": "geggig",
    "geggige": "geggig",
    "geggiges": "geggig",
    "geggigheten": "geggighet",
    "geggighetens": "geggighet",
    "geggighets": "geggighet",
    "geggigs": "geggig",
    "geggigt": "geggig",
    "geggigts": "geggig",
    "geggs": "gegg",
    "gegs": "geg",
    "geheimeråden": "geheimeråd",
    "geheimerådens": "geheimeråd",
    "geheimerådet": "geheimeråd",
    "geheimerådets": "geheimeråd",
    "geheimeråds": "geheimeråd",
    "gehennas": "gehenna",
    "gehennat": "gehenna",
    "gehennats": "gehenna",
    "gehängen": "gehäng",
    "gehängens": "gehäng",
    "gehänget": "gehäng",
    "gehängets": "gehäng",
    "gehängs": "gehäng",
    "gehöret": "gehör",
    "gehörets": "gehör",
    "gehörs": "gehör",
    "geiger-müllerrören": "geiger-müllerrör",
    "geiger-müllerrörens": "geiger-müllerrör",
    "geiger-müllerröret": "geiger-müllerrör",
    "geiger-müllerrörets": "geiger-müllerrör",
    "geiger-müllerrörs": "geiger-müllerrör",
    "geigermätar": "geigermätare",
    "geigermätaren": "geigermätare",
    "geigermätarens": "geigermätare",
    "geigermätares": "geigermätare",
    "geigermätarna": "geigermätare",
    "geigermätarnas": "geigermätare",
    "geish": "geisha",
    "geishan": "geisha",
    "geishans": "geisha",
    "geishas": "geisha",
    "geishe": "geisha",
    "geishor": "geisha",
    "geishorna": "geisha",
    "geishornas": "geisha",
    "geishors": "geisha",
    "geisten": "geist",
    "geistens": "geist",
    "geists": "geist",
    "gejden": "gejd",
    "gejdens": "gejd",
    "gejder": "gejd",
    "gejderna": "gejd",
    "gejdernas": "gejd",
    "gejders": "gejd",
    "gejds": "gejd",
    "gejsern": "gejser",
    "gejserns": "gejser",
    "gejsers": "gejser",
    "gejsrar": "gejser",
    "gejsrarna": "gejser",
    "gejsrarnas": "gejser",
    "gejsrars": "gejser",
    "geladan": "gelada",
    "geladans": "gelada",
    "geladas": "gelada",
    "gelador": "gelada",
    "geladorna": "gelada",
    "geladornas": "gelada",
    "geladors": "gelada",
    "gelatinen": "gelatin",
    "gelatinens": "gelatin",
    "gelatinerad": "gelatinera",
    "gelatinerade": "gelatinera",
    "gelatinerades": "gelatinera",
    "gelatinerads": "gelatinera",
    "gelatinerande": "gelatinera",
    "gelatineranden": "gelatinerande",
    "gelatinerandena": "gelatinerande",
    "gelatinerandenas": "gelatinerande",
    "gelatinerandens": "gelatinerande",
    "gelatinerandes": "gelatinerande",
    "gelatinerandet": "gelatinerande",
    "gelatinerandets": "gelatinerande",
    "gelatinerar": "gelatinera",
    "gelatineras": "gelatinera",
    "gelatinerat": "gelatinera",
    "gelatinerats": "gelatinera",
    "gelatinerbara": "gelatinerbar",
    "gelatinerbarare": "gelatinerbar",
    "gelatinerbarares": "gelatinerbar",
    "gelatinerbaras": "gelatinerbar",
    "gelatinerbarast": "gelatinerbar",
    "gelatinerbaraste": "gelatinerbar",
    "gelatinerbarastes": "gelatinerbar",
    "gelatinerbarasts": "gelatinerbar",
    "gelatinerbare": "gelatinerbar",
    "gelatinerbares": "gelatinerbar",
    "gelatinerbarheten": "gelatinerbarhet",
    "gelatinerbarhetens": "gelatinerbarhet",
    "gelatinerbarhets": "gelatinerbarhet",
    "gelatinerbars": "gelatinerbar",
    "gelatinerbart": "gelatinerbar",
    "gelatinerbarts": "gelatinerbar",
    "gelatineringen": "gelatinering",
    "gelatineringens": "gelatinering",
    "gelatinerings": "gelatinering",
    "gelatinet": "gelatin",
    "gelatinets": "gelatin",
    "gelatinkapseln": "gelatinkapsel",
    "gelatinkapselns": "gelatinkapsel",
    "gelatinkapsels": "gelatinkapsel",
    "gelatinkapslar": "gelatinkapsel",
    "gelatinkapslarna": "gelatinkapsel",
    "gelatinkapslarnas": "gelatinkapsel",
    "gelatinkapslars": "gelatinkapsel",
    "gelatins": "gelatin",
    "gelatinösa": "gelatinös",
    "gelatinösare": "gelatinös",
    "gelatinösares": "gelatinös",
    "gelatinösas": "gelatinös",
    "gelatinösast": "gelatinös",
    "gelatinösaste": "gelatinös",
    "gelatinösastes": "gelatinös",
    "gelatinösasts": "gelatinös",
    "gelatinöse": "gelatinös",
    "gelatinöses": "gelatinös",
    "gelatinöst": "gelatinös",
    "gelatinösts": "gelatinös",
    "gelbgjutar": "gelbgjutare",
    "gelbgjutaren": "gelbgjutare",
    "gelbgjutarens": "gelbgjutare",
    "gelbgjutares": "gelbgjutare",
    "gelbgjutarna": "gelbgjutare",
    "gelbgjutarnas": "gelbgjutare",
    "gelbgjuterier": "gelbgjuteri",
    "gelbgjuterierna": "gelbgjuteri",
    "gelbgjuteriernas": "gelbgjuteri",
    "gelbgjuteriers": "gelbgjuteri",
    "gelbgjuteriet": "gelbgjuteri",
    "gelbgjuteriets": "gelbgjuteri",
    "gelbgjuteris": "gelbgjuteri",
    "gelbgjuterit": "gelbgjuteri",
    "gelbgjuterits": "gelbgjuteri",
    "gelcoaten": "gelcoat",
    "gelcoatens": "gelcoat",
    "gelcoats": "gelcoat",
    "gele": "gelea",
    "gelead": "gelea",
    "geleade": "gelea",
    "geleades": "gelea",
    "geleads": "gelea",
    "geleande": "gelea",
    "geleanden": "geleande",
    "geleandena": "geleande",
    "geleandenas": "geleande",
    "geleandens": "geleande",
    "geleandes": "geleande",
    "geleandet": "geleande",
    "geleandets": "geleande",
    "gelear": "gelea",
    "geleas": "gelea",
    "geleat": "gelea",
    "geleats": "gelea",
    "geleiga": "geleig",
    "geleigare": "geleig",
    "geleigares": "geleig",
    "geleigas": "geleig",
    "geleigast": "geleig",
    "geleigaste": "geleig",
    "geleigastes": "geleig",
    "geleigasts": "geleig",
    "geleige": "geleig",
    "geleiges": "geleig",
    "geleigs": "geleig",
    "geleigt": "geleig",
    "geleigts": "geleig",
    "geler": "gel",
    "gelerna": "gel",
    "gelernas": "gel",
    "gelers": "gel",
    "gelet": "gel",
    "gelets": "gel",
    "gelik": "gelike",
    "gelikar": "gelike",
    "gelikarna": "gelike",
    "gelikarnas": "gelike",
    "gelikars": "gelike",
    "geliken": "gelike",
    "gelikens": "gelike",
    "gelikes": "gelike",
    "geliks": "gelike",
    "gels": "gel",
    "gelänken": "gelänk",
    "gelänkens": "gelänk",
    "gelänker": "gelänk",
    "gelänkerna": "gelänk",
    "gelänkernas": "gelänk",
    "gelänkers": "gelänk",
    "gelänket": "gelänk",
    "gelänkets": "gelänk",
    "gelänks": "gelänk",
    "geléartade": "geléartad",
    "geléartades": "geléartad",
    "geléartads": "geléartad",
    "geléartat": "geléartad",
    "geléartats": "geléartad",
    "geléer": "gelé",
    "geléerna": "gelé",
    "geléernas": "gelé",
    "geléers": "gelé",
    "geléet": "gelé",
    "geléets": "gelé",
    "geléhallonen": "geléhallon",
    "geléhallonens": "geléhallon",
    "geléhallonet": "geléhallon",
    "geléhallonets": "geléhallon",
    "geléhallons": "geléhallon",
    "geléklumpar": "geléklump",
    "geléklumparna": "geléklump",
    "geléklumparnas": "geléklump",
    "geléklumpars": "geléklump",
    "geléklumpen": "geléklump",
    "geléklumpens": "geléklump",
    "geléklumps": "geléklump",
    "gelén": "gelé",
    "geléns": "gelé",
    "gelés": "gelé",
    "gelésvampar": "gelésvamp",
    "gelésvamparna": "gelésvamp",
    "gelésvamparnas": "gelésvamp",
    "gelésvampars": "gelésvamp",
    "gelésvampen": "gelésvamp",
    "gelésvampens": "gelésvamp",
    "gelésvamps": "gelésvamp",
    "gelét": "gelé",
    "geléts": "gelé",
    "gemaken": "gemak",
    "gemakens": "gemak",
    "gemaket": "gemak",
    "gemakets": "gemak",
    "gemaks": "gemak",
    "gematrien": "gematri",
    "gematriens": "gematri",
    "gematrin": "gematri",
    "gematrins": "gematri",
    "gematris": "gematri",
    "gemen": "gem",
    "gemena": "gemen",
    "gemenare": "gemen",
    "gemenares": "gemen",
    "gemenas": "gemen",
    "gemenast": "gemen",
    "gemenaste": "gemen",
    "gemenastes": "gemen",
    "gemenasts": "gemen",
    "gemene": "gemen",
    "gemenes": "gemen",
    "gemenheten": "gemenhet",
    "gemenhetens": "gemenhet",
    "gemenheter": "gemenhet",
    "gemenheterna": "gemenhet",
    "gemenheternas": "gemenhet",
    "gemenheters": "gemenhet",
    "gemenhets": "gemenhet",
    "gemens": "gemen",
    "gemensamheten": "gemensamhet",
    "gemensamhetens": "gemensamhet",
    "gemensamheter": "gemensamhet",
    "gemensamheterna": "gemensamhet",
    "gemensamheternas": "gemensamhet",
    "gemensamheters": "gemensamhet",
    "gemensamhets": "gemensamhet",
    "gemensamhetsgravar": "gemensamhetsgrav",
    "gemensamhetsgravarna": "gemensamhetsgrav",
    "gemensamhetsgravarnas": "gemensamhetsgrav",
    "gemensamhetsgravars": "gemensamhetsgrav",
    "gemensamhetsgraven": "gemensamhetsgrav",
    "gemensamhetsgravens": "gemensamhetsgrav",
    "gemensamhetsgravs": "gemensamhetsgrav",
    "gemensamma": "gemensam",
    "gemensammare": "gemensam",
    "gemensammares": "gemensam",
    "gemensammas": "gemensam",
    "gemensammast": "gemensam",
    "gemensammaste": "gemensam",
    "gemensammastes": "gemensam",
    "gemensammasts": "gemensam",
    "gemensamme": "gemensam",
    "gemensammes": "gemensam",
    "gemensams": "gemensam",
    "gemensamt": "gemensam",
    "gemensamts": "gemensam",
    "gemenskapen": "gemenskap",
    "gemenskapens": "gemenskap",
    "gemenskaper": "gemenskap",
    "gemenskaperna": "gemenskap",
    "gemenskapernas": "gemenskap",
    "gemenskapers": "gemenskap",
    "gemenskaps": "gemenskap",
    "gement": "gemen",
    "gements": "gemen",
    "gemet": "gem",
    "gemets": "gem",
    "geminationen": "gemination",
    "geminationens": "gemination",
    "geminationer": "gemination",
    "geminationerna": "gemination",
    "geminationernas": "gemination",
    "geminationers": "gemination",
    "geminations": "gemination",
    "geminerad": "geminera",
    "geminerade": "geminera",
    "geminerades": "geminera",
    "geminerads": "geminera",
    "geminerande": "geminera",
    "gemineranden": "geminerande",
    "geminerandena": "geminerande",
    "geminerandenas": "geminerande",
    "geminerandens": "geminerande",
    "geminerandes": "geminerande",
    "geminerandet": "geminerande",
    "geminerandets": "geminerande",
    "geminerar": "geminera",
    "gemineras": "geminera",
    "geminerat": "geminera",
    "geminerats": "geminera",
    "geminerbara": "geminerbar",
    "geminerbarare": "geminerbar",
    "geminerbarares": "geminerbar",
    "geminerbaras": "geminerbar",
    "geminerbarast": "geminerbar",
    "geminerbaraste": "geminerbar",
    "geminerbarastes": "geminerbar",
    "geminerbarasts": "geminerbar",
    "geminerbare": "geminerbar",
    "geminerbares": "geminerbar",
    "geminerbarheten": "geminerbarhet",
    "geminerbarhetens": "geminerbarhet",
    "geminerbarhets": "geminerbarhet",
    "geminerbars": "geminerbar",
    "geminerbart": "geminerbar",
    "geminerbarts": "geminerbar",
    "gemineringar": "geminering",
    "gemineringarna": "geminering",
    "gemineringarnas": "geminering",
    "gemineringars": "geminering",
    "gemineringen": "geminering",
    "gemineringens": "geminering",
    "geminerings": "geminering",
    "gemmen": "gem",
    "gemmens": "gem",
    "gemmer": "gem",
    "gemmerna": "gem",
    "gemmernas": "gem",
    "gemmers": "gem",
    "gemmologien": "gemmologi",
    "gemmologiens": "gemmologi",
    "gemmologin": "gemmologi",
    "gemmologins": "gemmologi",
    "gemmologis": "gemmologi",
    "gems": "gem",
    "gemsen": "gems",
    "gemsens": "gems",
    "gemser": "gems",
    "gemserna": "gems",
    "gemsernas": "gems",
    "gemsers": "gems",
    "gemyten": "gemyt",
    "gemytens": "gemyt",
    "gemytet": "gemyt",
    "gemytets": "gemyt",
    "gemytliga": "gemytlig",
    "gemytligare": "gemytlig",
    "gemytligares": "gemytlig",
    "gemytligas": "gemytlig",
    "gemytligast": "gemytlig",
    "gemytligaste": "gemytlig",
    "gemytligastes": "gemytlig",
    "gemytligasts": "gemytlig",
    "gemytlige": "gemytlig",
    "gemytliges": "gemytlig",
    "gemytligheten": "gemytlighet",
    "gemytlighetens": "gemytlighet",
    "gemytligheter": "gemytlighet",
    "gemytligheterna": "gemytlighet",
    "gemytligheternas": "gemytlighet",
    "gemytligheters": "gemytlighet",
    "gemytlighets": "gemytlighet",
    "gemytligs": "gemytlig",
    "gemytligt": "gemytlig",
    "gemytligts": "gemytlig",
    "gemyts": "gemyt",
    "gemålen": "gemål",
    "gemålens": "gemål",
    "gemåler": "gemål",
    "gemålerna": "gemål",
    "gemålernas": "gemål",
    "gemålers": "gemål",
    "gemåls": "gemål",
    "gen": "gena",
    "gena": "gen",
    "genade": "gena",
    "genades": "gena",
    "genande": "gena",
    "genanden": "genande",
    "genandena": "genande",
    "genandenas": "genande",
    "genandens": "genande",
    "genandes": "genande",
    "genandet": "genande",
    "genandets": "genande",
    "genansen": "genans",
    "genansens": "genans",
    "genanta": "genant",
    "genantare": "genant",
    "genantares": "genant",
    "genantas": "genant",
    "genantast": "genant",
    "genantaste": "genant",
    "genantastes": "genant",
    "genantasts": "genant",
    "genante": "genant",
    "genantes": "genant",
    "genants": "genant",
    "genar": "gena",
    "genare": "gen",
    "genares": "gen",
    "genas": "gena",
    "genast": "gen",
    "genaste": "gen",
    "genastes": "gen",
    "genasts": "gen",
    "genat": "gena",
    "genats": "gena",
    "genbanken": "genbank",
    "genbankens": "genbank",
    "genbanker": "genbank",
    "genbankerna": "genbank",
    "genbankernas": "genbank",
    "genbankers": "genbank",
    "genbankningen": "genbankning",
    "genbankningens": "genbankning",
    "genbanknings": "genbankning",
    "genbanks": "genbank",
    "gendarmen": "gendarm",
    "gendarmens": "gendarm",
    "gendarmer": "gendarm",
    "gendarmeriet": "gendarmeri",
    "gendarmeriets": "gendarmeri",
    "gendarmeris": "gendarmeri",
    "gendarmerit": "gendarmeri",
    "gendarmerits": "gendarmeri",
    "gendarmerna": "gendarm",
    "gendarmernas": "gendarm",
    "gendarmers": "gendarm",
    "gendarms": "gendarm",
    "gendrev": "gendriva",
    "gendrevs": "gendriva",
    "gendriv": "gendriva",
    "gendrivande": "gendriva",
    "gendrivanden": "gendrivande",
    "gendrivandena": "gendrivande",
    "gendrivandenas": "gendrivande",
    "gendrivandens": "gendrivande",
    "gendrivandes": "gendrivande",
    "gendrivandet": "gendrivande",
    "gendrivandets": "gendrivande",
    "gendrivas": "gendriva",
    "gendrive": "gendriva",
    "gendriven": "gendriva",
    "gendrivens": "gendriva",
    "gendriver": "gendriva",
    "gendrives": "gendriva",
    "gendrivet": "gendriva",
    "gendrivets": "gendriva",
    "gendrivit": "gendriva",
    "gendrivits": "gendriva",
    "gendrivna": "gendriva",
    "gendrivnas": "gendriva",
    "gendrivne": "gendriva",
    "gendrivnes": "gendriva",
    "gendrivs": "gendriva",
    "gene": "gen",
    "genealogen": "genealog",
    "genealogens": "genealog",
    "genealoger": "genealog",
    "genealogerna": "genealog",
    "genealogernas": "genealog",
    "genealogers": "genealog",
    "genealogien": "genealogi",
    "genealogiens": "genealogi",
    "genealogier": "genealogi",
    "genealogierna": "genealogi",
    "genealogiernas": "genealogi",
    "genealogiers": "genealogi",
    "genealogin": "genealogi",
    "genealogins": "genealogi",
    "genealogis": "genealogi",
    "genealogs": "genealog",
    "genen": "gen",
    "genens": "gen",
    "gener": "gen",
    "generad": "genera",
    "generade": "generad",
    "generades": "generad",
    "generads": "generad",
    "generalagenten": "generalagent",
    "generalagentens": "generalagent",
    "generalagenter": "generalagent",
    "generalagenterna": "generalagent",
    "generalagenternas": "generalagent",
    "generalagenters": "generalagent",
    "generalagents": "generalagent",
    "generalangreppen": "generalangrepp",
    "generalangreppens": "generalangrepp",
    "generalangreppet": "generalangrepp",
    "generalangreppets": "generalangrepp",
    "generalangrepps": "generalangrepp",
    "generalbasen": "generalbas",
    "generalbasens": "generalbas",
    "generaldirektören": "generaldirektör",
    "generaldirektörens": "generaldirektör",
    "generaldirektörer": "generaldirektör",
    "generaldirektörerna": "generaldirektör",
    "generaldirektörernas": "generaldirektör",
    "generaldirektörers": "generaldirektör",
    "generaldirektörn": "generaldirektör",
    "generaldirektörns": "generaldirektör",
    "generaldirektörs": "generaldirektör",
    "generalen": "general",
    "generalens": "general",
    "generaler": "general",
    "generalerna": "general",
    "generalernas": "general",
    "generalers": "general",
    "generalförsamlingar": "generalförsamling",
    "generalförsamlingarna": "generalförsamling",
    "generalförsamlingarnas": "generalförsamling",
    "generalförsamlingars": "generalförsamling",
    "generalförsamlingen": "generalförsamling",
    "generalförsamlingens": "generalförsamling",
    "generalförsamlings": "generalförsamling",
    "generalguvernören": "generalguvernör",
    "generalguvernörens": "generalguvernör",
    "generalguvernörer": "generalguvernör",
    "generalguvernörerna": "generalguvernör",
    "generalguvernörernas": "generalguvernör",
    "generalguvernörers": "generalguvernör",
    "generalguvernörn": "generalguvernör",
    "generalguvernörns": "generalguvernör",
    "generalguvernörs": "generalguvernör",
    "generalisationen": "generalisation",
    "generalisationens": "generalisation",
    "generalisationer": "generalisation",
    "generalisationerna": "generalisation",
    "generalisationernas": "generalisation",
    "generalisationers": "generalisation",
    "generalisations": "generalisation",
    "generaliserad": "generalisera",
    "generaliserade": "generalisera",
    "generaliserades": "generalisera",
    "generaliserads": "generalisera",
    "generaliserande": "generalisera",
    "generaliseranden": "generaliserande",
    "generaliserandena": "generaliserande",
    "generaliserandenas": "generaliserande",
    "generaliserandens": "generaliserande",
    "generaliserandes": "generaliserande",
    "generaliserandet": "generaliserande",
    "generaliserandets": "generaliserande",
    "generaliserar": "generalisera",
    "generaliseras": "generalisera",
    "generaliserat": "generalisera",
    "generaliserats": "generalisera",
    "generaliserbara": "generaliserbar",
    "generaliserbarare": "generaliserbar",
    "generaliserbarares": "generaliserbar",
    "generaliserbaras": "generaliserbar",
    "generaliserbarast": "generaliserbar",
    "generaliserbaraste": "generaliserbar",
    "generaliserbarastes": "generaliserbar",
    "generaliserbarasts": "generaliserbar",
    "generaliserbare": "generaliserbar",
    "generaliserbares": "generaliserbar",
    "generaliserbarheten": "generaliserbarhet",
    "generaliserbarhetens": "generaliserbarhet",
    "generaliserbarhets": "generaliserbarhet",
    "generaliserbars": "generaliserbar",
    "generaliserbart": "generaliserbar",
    "generaliserbarts": "generaliserbar",
    "generaliseringar": "generalisering",
    "generaliseringarna": "generalisering",
    "generaliseringarnas": "generalisering",
    "generaliseringars": "generalisering",
    "generaliseringen": "generalisering",
    "generaliseringens": "generalisering",
    "generaliserings": "generalisering",
    "generalisten": "generalist",
    "generalistens": "generalist",
    "generalister": "generalist",
    "generalisterna": "generalist",
    "generalisternas": "generalist",
    "generalisters": "generalist",
    "generalists": "generalist",
    "generaliteten": "generalitet",
    "generalitetens": "generalitet",
    "generaliteter": "generalitet",
    "generaliteterna": "generalitet",
    "generaliteternas": "generalitet",
    "generaliteters": "generalitet",
    "generalitetet": "generalitet",
    "generalitetets": "generalitet",
    "generalitets": "generalitet",
    "generalkonsulaten": "generalkonsulat",
    "generalkonsulatens": "generalkonsulat",
    "generalkonsulatet": "generalkonsulat",
    "generalkonsulatets": "generalkonsulat",
    "generalkonsulats": "generalkonsulat",
    "generalkonsuler": "generalkonsul",
    "generalkonsulerna": "generalkonsul",
    "generalkonsulernas": "generalkonsul",
    "generalkonsulers": "generalkonsul",
    "generalkonsuln": "generalkonsul",
    "generalkonsulns": "generalkonsul",
    "generalkonsuls": "generalkonsul",
    "generallöjtnanten": "generallöjtnant",
    "generallöjtnantens": "generallöjtnant",
    "generallöjtnanter": "generallöjtnant",
    "generallöjtnanterna": "generallöjtnant",
    "generallöjtnanternas": "generallöjtnant",
    "generallöjtnanters": "generallöjtnant",
    "generallöjtnants": "generallöjtnant",
    "generalmajoren": "generalmajor",
    "generalmajorens": "generalmajor",
    "generalmajorer": "generalmajor",
    "generalmajorerna": "generalmajor",
    "generalmajorernas": "generalmajor",
    "generalmajorers": "generalmajor",
    "generalmajorn": "generalmajor",
    "generalmajorns": "generalmajor",
    "generalmajors": "generalmajor",
    "generalpausen": "generalpaus",
    "generalpausens": "generalpaus",
    "generalpauser": "generalpaus",
    "generalpauserna": "generalpaus",
    "generalpausernas": "generalpaus",
    "generalpausers": "generalpaus",
    "generalplane": "generalplan",
    "generalplanemässiga": "generalplanemässig",
    "generalplanemässigare": "generalplanemässig",
    "generalplanemässigares": "generalplanemässig",
    "generalplanemässigas": "generalplanemässig",
    "generalplanemässigast": "generalplanemässig",
    "generalplanemässigaste": "generalplanemässig",
    "generalplanemässigastes": "generalplanemässig",
    "generalplanemässigasts": "generalplanemässig",
    "generalplanemässige": "generalplanemässig",
    "generalplanemässiges": "generalplanemässig",
    "generalplanemässigs": "generalplanemässig",
    "generalplanemässigt": "generalplanemässig",
    "generalplanemässigts": "generalplanemässig",
    "generalplanen": "generalplan",
    "generalplanens": "generalplan",
    "generalplaner": "generalplan",
    "generalplanerna": "generalplan",
    "generalplanernas": "generalplan",
    "generalplaners": "generalplan",
    "generalplans": "generalplan",
    "generalpreventionen": "generalprevention",
    "generalpreventionens": "generalprevention",
    "generalpreventioner": "generalprevention",
    "generalpreventionerna": "generalprevention",
    "generalpreventionernas": "generalprevention",
    "generalpreventioners": "generalprevention",
    "generalpreventions": "generalprevention",
    "generalrepen": "generalrep",
    "generalrepens": "generalrep",
    "generalrepet": "generalrep",
    "generalrepetitionen": "generalrepetition",
    "generalrepetitionens": "generalrepetition",
    "generalrepetitioner": "generalrepetition",
    "generalrepetitionerna": "generalrepetition",
    "generalrepetitionernas": "generalrepetition",
    "generalrepetitioners": "generalrepetition",
    "generalrepetitions": "generalrepetition",
    "generalrepets": "generalrep",
    "generalreps": "generalrep",
    "generals": "general",
    "generalsekreterar": "generalsekreterare",
    "generalsekreteraren": "generalsekreterare",
    "generalsekreterarens": "generalsekreterare",
    "generalsekreterares": "generalsekreterare",
    "generalsekreterarna": "generalsekreterare",
    "generalsekreterarnas": "generalsekreterare",
    "generalskan": "generalska",
    "generalskans": "generalska",
    "generalskas": "generalska",
    "generalske": "generalska",
    "generalskor": "generalska",
    "generalskorna": "generalska",
    "generalskornas": "generalska",
    "generalskors": "generalska",
    "generalspersonen": "generalsperson",
    "generalspersonens": "generalsperson",
    "generalspersoner": "generalsperson",
    "generalspersonerna": "generalsperson",
    "generalspersonernas": "generalsperson",
    "generalspersoners": "generalsperson",
    "generalspersons": "generalsperson",
    "generalstaben": "generalstab",
    "generalstabens": "generalstab",
    "generalstaber": "generalstab",
    "generalstaberna": "generalstab",
    "generalstabernas": "generalstab",
    "generalstabers": "generalstab",
    "generalstabs": "generalstab",
    "generalstabskart": "generalstabskarta",
    "generalstabskartan": "generalstabskarta",
    "generalstabskartans": "generalstabskarta",
    "generalstabskartas": "generalstabskarta",
    "generalstabskarte": "generalstabskarta",
    "generalstabskartor": "generalstabskarta",
    "generalstabskartorna": "generalstabskarta",
    "generalstabskartornas": "generalstabskarta",
    "generalstabskartors": "generalstabskarta",
    "generalstabskarts": "generalstabskarta",
    "generalstabsnivåer": "generalstabsnivå",
    "generalstabsnivåerna": "generalstabsnivå",
    "generalstabsnivåernas": "generalstabsnivå",
    "generalstabsnivåers": "generalstabsnivå",
    "generalstabsnivån": "generalstabsnivå",
    "generalstabsnivåns": "generalstabsnivå",
    "generalstabsnivås": "generalstabsnivå",
    "generalstrejken": "generalstrejk",
    "generalstrejkens": "generalstrejk",
    "generalstrejker": "generalstrejk",
    "generalstrejkerna": "generalstrejk",
    "generalstrejkernas": "generalstrejk",
    "generalstrejkers": "generalstrejk",
    "generalstrejks": "generalstrejk",
    "generalöverst": "generalöverste",
    "generalöverstar": "generalöverste",
    "generalöverstarna": "generalöverste",
    "generalöverstarnas": "generalöverste",
    "generalöverstars": "generalöverste",
    "generalöversten": "generalöverste",
    "generalöverstens": "generalöverste",
    "generalöverstes": "generalöverste",
    "generande": "genera",
    "generanden": "generande",
    "generandena": "generande",
    "generandenas": "generande",
    "generandens": "generande",
    "generandes": "generande",
    "generandet": "generande",
    "generandets": "generande",
    "generar": "genera",
    "generas": "genera",
    "generat": "generad",
    "generationen": "generation",
    "generationens": "generation",
    "generationer": "generation",
    "generationerna": "generation",
    "generationernas": "generation",
    "generationers": "generation",
    "generations": "generation",
    "generationsklyftan": "generationsklyfta",
    "generationsklyftans": "generationsklyfta",
    "generationsklyftas": "generationsklyfta",
    "generationsklyfte": "generationsklyfta",
    "generationsklyftor": "generationsklyfta",
    "generationsklyftorna": "generationsklyfta",
    "generationsklyftornas": "generationsklyfta",
    "generationsklyftors": "generationsklyfta",
    "generationsmässiga": "generationsmässig",
    "generationsmässigare": "generationsmässig",
    "generationsmässigares": "generationsmässig",
    "generationsmässigas": "generationsmässig",
    "generationsmässigast": "generationsmässig",
    "generationsmässigaste": "generationsmässig",
    "generationsmässigastes": "generationsmässig",
    "generationsmässigasts": "generationsmässig",
    "generationsmässige": "generationsmässig",
    "generationsmässiges": "generationsmässig",
    "generationsmässigs": "generationsmässig",
    "generationsmässigt": "generationsmässig",
    "generationsmässigts": "generationsmässig",
    "generationstiden": "generationstid",
    "generationstidens": "generationstid",
    "generationstider": "generationstid",
    "generationstiderna": "generationstid",
    "generationstidernas": "generationstid",
    "generationstiders": "generationstid",
    "generationstids": "generationstid",
    "generationsväxlingar": "generationsväxling",
    "generationsväxlingarna": "generationsväxling",
    "generationsväxlingarnas": "generationsväxling",
    "generationsväxlingars": "generationsväxling",
    "generationsväxlingen": "generationsväxling",
    "generationsväxlingens": "generationsväxling",
    "generationsväxlings": "generationsväxling",
    "generativa": "generativ",
    "generativare": "generativ",
    "generativares": "generativ",
    "generativas": "generativ",
    "generativast": "generativ",
    "generativaste": "generativ",
    "generativastes": "generativ",
    "generativasts": "generativ",
    "generative": "generativ",
    "generatives": "generativ",
    "generativs": "generativ",
    "generativt": "generativ",
    "generativts": "generativ",
    "generatorer": "generator",
    "generatorerna": "generator",
    "generatorernas": "generator",
    "generatorers": "generator",
    "generatorgasen": "generatorgas",
    "generatorgasens": "generatorgas",
    "generatorn": "generator",
    "generatorns": "generator",
    "generators": "generator",
    "generatrisen": "generatris",
    "generatrisens": "generatris",
    "generatriser": "generatris",
    "generatriserna": "generatris",
    "generatrisernas": "generatris",
    "generatrisers": "generatris",
    "generats": "generad",
    "generbara": "generbar",
    "generbarare": "generbar",
    "generbarares": "generbar",
    "generbaras": "generbar",
    "generbarast": "generbar",
    "generbaraste": "generbar",
    "generbarastes": "generbar",
    "generbarasts": "generbar",
    "generbare": "generbar",
    "generbares": "generbar",
    "generbarheten": "generbarhet",
    "generbarhetens": "generbarhet",
    "generbarhets": "generbarhet",
    "generbars": "generbar",
    "generbart": "generbar",
    "generbarts": "generbar",
    "generella": "generell",
    "generellare": "generell",
    "generellares": "generell",
    "generellas": "generell",
    "generellast": "generell",
    "generellaste": "generell",
    "generellastes": "generell",
    "generellasts": "generell",
    "generelle": "generell",
    "generelles": "generell",
    "generells": "generell",
    "generellt": "generell",
    "generellts": "generell",
    "genererad": "generera",
    "genererade": "generera",
    "genererades": "generera",
    "genererads": "generera",
    "genererande": "generera",
    "genereranden": "genererande",
    "genererandena": "genererande",
    "genererandenas": "genererande",
    "genererandens": "genererande",
    "genererandes": "genererande",
    "genererandet": "genererande",
    "genererandets": "genererande",
    "genererar": "generera",
    "genereras": "generera",
    "genererat": "generera",
    "genererats": "generera",
    "genererbara": "genererbar",
    "genererbarare": "genererbar",
    "genererbarares": "genererbar",
    "genererbaras": "genererbar",
    "genererbarast": "genererbar",
    "genererbaraste": "genererbar",
    "genererbarastes": "genererbar",
    "genererbarasts": "genererbar",
    "genererbare": "genererbar",
    "genererbares": "genererbar",
    "genererbarheten": "genererbarhet",
    "genererbarhetens": "genererbarhet",
    "genererbarhets": "genererbarhet",
    "genererbars": "genererbar",
    "genererbart": "genererbar",
    "genererbarts": "genererbar",
    "genereringar": "generering",
    "genereringarna": "generering",
    "genereringarnas": "generering",
    "genereringars": "generering",
    "genereringen": "generering",
    "genereringens": "generering",
    "genererings": "generering",
    "generingar": "genering",
    "generingarna": "genering",
    "generingarnas": "genering",
    "generingars": "genering",
    "generingen": "genering",
    "generingens": "genering",
    "generings": "genering",
    "generiska": "generisk",
    "generiskare": "generisk",
    "generiskares": "generisk",
    "generiskas": "generisk",
    "generiskast": "generisk",
    "generiskaste": "generisk",
    "generiskastes": "generisk",
    "generiskasts": "generisk",
    "generiske": "generisk",
    "generiskes": "generisk",
    "generisks": "generisk",
    "generiskt": "generisk",
    "generiskts": "generisk",
    "generna": "gen",
    "genernas": "gen",
    "generositeten": "generositet",
    "generositetens": "generositet",
    "generositeter": "generositet",
    "generositeterna": "generositet",
    "generositeternas": "generositet",
    "generositeters": "generositet",
    "generositets": "generositet",
    "geners": "gen",
    "generösa": "generös",
    "generösare": "generös",
    "generösares": "generös",
    "generösas": "generös",
    "generösast": "generös",
    "generösaste": "generös",
    "generösastes": "generös",
    "generösasts": "generös",
    "generöse": "generös",
    "generöses": "generös",
    "generöst": "generös",
    "generösts": "generös",
    "genes": "gen",
    "genesen": "genes",
    "genesens": "genes",
    "genetiken": "genetik",
    "genetikens": "genetik",
    "genetikern": "genetiker",
    "genetikerna": "genetiker",
    "genetikernas": "genetiker",
    "genetikerns": "genetiker",
    "genetikers": "genetiker",
    "genetiks": "genetik",
    "genetiska": "genetisk",
    "genetiskare": "genetisk",
    "genetiskares": "genetisk",
    "genetiskas": "genetisk",
    "genetiskast": "genetisk",
    "genetiskaste": "genetisk",
    "genetiskastes": "genetisk",
    "genetiskasts": "genetisk",
    "genetiske": "genetisk",
    "genetiskes": "genetisk",
    "genetisks": "genetisk",
    "genetiskt": "genetisk",
    "genetiskts": "genetisk",
    "genetten": "genett",
    "genettens": "genett",
    "genetter": "genett",
    "genetterna": "genett",
    "genetternas": "genett",
    "genetters": "genett",
    "genetts": "genett",
    "genevern": "genever",
    "geneverns": "genever",
    "genevers": "genever",
    "genfordrans": "genfordran",
    "genfordringar": "genfordring",
    "genfordringarna": "genfordring",
    "genfordringarnas": "genfordring",
    "genfordringars": "genfordring",
    "genfordringen": "genfordring",
    "genfordringens": "genfordring",
    "genfordrings": "genfordring",
    "genförändrade": "genförändrad",
    "genförändrades": "genförändrad",
    "genförändrads": "genförändrad",
    "genförändrat": "genförändrad",
    "genförändrats": "genförändrad",
    "genförändringar": "genförändring",
    "genförändringarna": "genförändring",
    "genförändringarnas": "genförändring",
    "genförändringars": "genförändring",
    "genförändringen": "genförändring",
    "genförändringens": "genförändring",
    "genförändrings": "genförändring",
    "gengasen": "gengas",
    "gengasens": "gengas",
    "gengäld": "gengälda",
    "gengäldad": "gengälda",
    "gengäldade": "gengälda",
    "gengäldades": "gengälda",
    "gengäldads": "gengälda",
    "gengäldande": "gengälda",
    "gengäldanden": "gengäldande",
    "gengäldandena": "gengäldande",
    "gengäldandenas": "gengäldande",
    "gengäldandens": "gengäldande",
    "gengäldandes": "gengäldande",
    "gengäldandet": "gengäldande",
    "gengäldandets": "gengäldande",
    "gengäldar": "gengälda",
    "gengäldas": "gengälda",
    "gengäldat": "gengälda",
    "gengäldats": "gengälda",
    "gengångar": "gengångare",
    "gengångaren": "gengångare",
    "gengångarens": "gengångare",
    "gengångares": "gengångare",
    "gengångarna": "gengångare",
    "gengångarnas": "gengångare",
    "gengåvan": "gengåva",
    "gengåvans": "gengåva",
    "gengåvas": "gengåva",
    "gengåve": "gengåva",
    "gengåvo": "gengåva",
    "gengåvor": "gengåva",
    "gengåvorna": "gengåva",
    "gengåvornas": "gengåva",
    "gengåvors": "gengåva",
    "geniala": "genial",
    "genialare": "genial",
    "genialares": "genial",
    "genialas": "genial",
    "genialast": "genial",
    "genialaste": "genial",
    "genialastes": "genial",
    "genialasts": "genial",
    "geniale": "genial",
    "geniales": "genial",
    "genialiska": "genialisk",
    "genialiskare": "genialisk",
    "genialiskares": "genialisk",
    "genialiskas": "genialisk",
    "genialiskast": "genialisk",
    "genialiskaste": "genialisk",
    "genialiskastes": "genialisk",
    "genialiskasts": "genialisk",
    "genialiske": "genialisk",
    "genialiskes": "genialisk",
    "genialisks": "genialisk",
    "genialiskt": "genialisk",
    "genialiskts": "genialisk",
    "genialiteten": "genialitet",
    "genialitetens": "genialitet",
    "genialiteter": "genialitet",
    "genialiteterna": "genialitet",
    "genialiteternas": "genialitet",
    "genialiteters": "genialitet",
    "genialitets": "genialitet",
    "genials": "genial",
    "genialt": "genial",
    "genialts": "genial",
    "genien": "genie",
    "geniens": "genie",
    "genier": "genie",
    "genierna": "genie",
    "geniernas": "genie",
    "geniers": "genie",
    "genies": "genie",
    "geniet": "geni",
    "geniets": "geni",
    "genis": "geni",
    "genit": "geni",
    "genitalie": "genitalier",
    "genitalierna": "genitalier",
    "genitaliernas": "genitalier",
    "genitaliers": "genitalier",
    "genitalorganen": "genitalorgan",
    "genitalorganens": "genitalorgan",
    "genitalorgans": "genitalorgan",
    "genitivattributen": "genitivattribut",
    "genitivattributens": "genitivattribut",
    "genitivattributet": "genitivattribut",
    "genitivattributets": "genitivattribut",
    "genitivattributs": "genitivattribut",
    "genitiven": "genitiv",
    "genitivens": "genitiv",
    "genitiver": "genitiv",
    "genitiverna": "genitiv",
    "genitivernas": "genitiv",
    "genitivers": "genitiv",
    "genitivs": "genitiv",
    "genits": "geni",
    "genklangen": "genklang",
    "genklangens": "genklang",
    "genklangs": "genklang",
    "genkäranden": "genkärande",
    "genkärandena": "genkärande",
    "genkärandenas": "genkärande",
    "genkärandens": "genkärande",
    "genkärandes": "genkärande",
    "genljud": "genljuda",
    "genljudande": "genljuda",
    "genljudanden": "genljudande",
    "genljudandena": "genljudande",
    "genljudandenas": "genljudande",
    "genljudandens": "genljudande",
    "genljudandes": "genljudande",
    "genljudandet": "genljudande",
    "genljudandets": "genljudande",
    "genljudas": "genljuda",
    "genljude": "genljuda",
    "genljuder": "genljuda",
    "genljudes": "genljuda",
    "genljudet": "genljud",
    "genljudets": "genljud",
    "genljudit": "genljuda",
    "genljudits": "genljuda",
    "genljuds": "genljuda",
    "genljöd": "genljuda",
    "genljöde": "genljuda",
    "genljödes": "genljuda",
    "genljöds": "genljuda",
    "genmanipulationen": "genmanipulation",
    "genmanipulationens": "genmanipulation",
    "genmanipulationer": "genmanipulation",
    "genmanipulationerna": "genmanipulation",
    "genmanipulationernas": "genmanipulation",
    "genmanipulationers": "genmanipulation",
    "genmanipulations": "genmanipulation",
    "genmanipulerad": "genmanipulera",
    "genmanipulerade": "genmanipulera",
    "genmanipulerades": "genmanipulera",
    "genmanipulerads": "genmanipulera",
    "genmanipulerande": "genmanipulera",
    "genmanipuleranden": "genmanipulerande",
    "genmanipulerandena": "genmanipulerande",
    "genmanipulerandenas": "genmanipulerande",
    "genmanipulerandens": "genmanipulerande",
    "genmanipulerandes": "genmanipulerande",
    "genmanipulerandet": "genmanipulerande",
    "genmanipulerandets": "genmanipulerande",
    "genmanipulerar": "genmanipulera",
    "genmanipuleras": "genmanipulera",
    "genmanipulerat": "genmanipulera",
    "genmanipulerats": "genmanipulera",
    "genmanipulerbara": "genmanipulerbar",
    "genmanipulerbarare": "genmanipulerbar",
    "genmanipulerbarares": "genmanipulerbar",
    "genmanipulerbaras": "genmanipulerbar",
    "genmanipulerbarast": "genmanipulerbar",
    "genmanipulerbaraste": "genmanipulerbar",
    "genmanipulerbarastes": "genmanipulerbar",
    "genmanipulerbarasts": "genmanipulerbar",
    "genmanipulerbare": "genmanipulerbar",
    "genmanipulerbares": "genmanipulerbar",
    "genmanipulerbarheten": "genmanipulerbarhet",
    "genmanipulerbarhetens": "genmanipulerbarhet",
    "genmanipulerbarhets": "genmanipulerbarhet",
    "genmanipulerbars": "genmanipulerbar",
    "genmanipulerbart": "genmanipulerbar",
    "genmanipulerbarts": "genmanipulerbar",
    "genmanipuleringar": "genmanipulering",
    "genmanipuleringarna": "genmanipulering",
    "genmanipuleringarnas": "genmanipulering",
    "genmanipuleringars": "genmanipulering",
    "genmanipuleringen": "genmanipulering",
    "genmanipuleringens": "genmanipulering",
    "genmanipulerings": "genmanipulering",
    "genmodifierade": "genmodifierad",
    "genmodifierades": "genmodifierad",
    "genmodifierads": "genmodifierad",
    "genmodifierat": "genmodifierad",
    "genmodifierats": "genmodifierad",
    "genmäl": "genmäla",
    "genmälande": "genmäla",
    "genmälanden": "genmälande",
    "genmälandena": "genmälande",
    "genmälandenas": "genmälande",
    "genmälandens": "genmälande",
    "genmälandes": "genmälande",
    "genmälandet": "genmälande",
    "genmälandets": "genmälande",
    "genmälas": "genmäla",
    "genmäld": "genmäla",
    "genmälda": "genmäla",
    "genmäldas": "genmäla",
    "genmälde": "genmäla",
    "genmäldes": "genmäla",
    "genmälds": "genmäla",
    "genmälen": "genmäle",
    "genmälena": "genmäle",
    "genmälenas": "genmäle",
    "genmälens": "genmäle",
    "genmäler": "genmäla",
    "genmäles": "genmäle",
    "genmälet": "genmäle",
    "genmälets": "genmäle",
    "genmäls": "genmäla",
    "genmält": "genmäla",
    "genmälte": "genmäla",
    "genmältes": "genmäla",
    "genmälts": "genmäla",
    "genociden": "genocid",
    "genocidens": "genocid",
    "genocider": "genocid",
    "genociderna": "genocid",
    "genocidernas": "genocid",
    "genociders": "genocid",
    "genocids": "genocid",
    "genomarbet": "genomarbeta",
    "genomarbetad": "genomarbeta",
    "genomarbetade": "genomarbeta",
    "genomarbetades": "genomarbeta",
    "genomarbetads": "genomarbeta",
    "genomarbetande": "genomarbeta",
    "genomarbetanden": "genomarbetande",
    "genomarbetandena": "genomarbetande",
    "genomarbetandenas": "genomarbetande",
    "genomarbetandens": "genomarbetande",
    "genomarbetandes": "genomarbetande",
    "genomarbetandet": "genomarbetande",
    "genomarbetandets": "genomarbetande",
    "genomarbetar": "genomarbeta",
    "genomarbetas": "genomarbeta",
    "genomarbetat": "genomarbeta",
    "genomarbetats": "genomarbeta",
    "genomblödningar": "genomblödning",
    "genomblödningarna": "genomblödning",
    "genomblödningarnas": "genomblödning",
    "genomblödningars": "genomblödning",
    "genomblödningen": "genomblödning",
    "genomblödningens": "genomblödning",
    "genomblödnings": "genomblödning",
    "genomblöta": "genomblöt",
    "genomblötare": "genomblöt",
    "genomblötares": "genomblöt",
    "genomblötas": "genomblöt",
    "genomblötast": "genomblöt",
    "genomblötaste": "genomblöt",
    "genomblötastes": "genomblöt",
    "genomblötasts": "genomblöt",
    "genomblöte": "genomblöt",
    "genomblötes": "genomblöt",
    "genomblöts": "genomblöt",
    "genomblött": "genomblöt",
    "genomblötts": "genomblöt",
    "genomborr": "genomborra",
    "genomborrad": "genomborra",
    "genomborrade": "genomborra",
    "genomborrades": "genomborra",
    "genomborrads": "genomborra",
    "genomborrande": "genomborra",
    "genomborranden": "genomborrande",
    "genomborrandena": "genomborrande",
    "genomborrandenas": "genomborrande",
    "genomborrandens": "genomborrande",
    "genomborrandes": "genomborrande",
    "genomborrandet": "genomborrande",
    "genomborrandets": "genomborrande",
    "genomborrar": "genomborra",
    "genomborras": "genomborra",
    "genomborrat": "genomborra",
    "genomborrats": "genomborra",
    "genombrotten": "genombrott",
    "genombrottens": "genombrott",
    "genombrottet": "genombrott",
    "genombrottets": "genombrott",
    "genombrotts": "genombrott",
    "genombrottsboken": "genombrottsbok",
    "genombrottsbokens": "genombrottsbok",
    "genombrottsboks": "genombrottsbok",
    "genombrottsböcker": "genombrottsbok",
    "genombrottsböckerna": "genombrottsbok",
    "genombrottsböckernas": "genombrottsbok",
    "genombrottsböckers": "genombrottsbok",
    "genombruten": "genombryta",
    "genombrutens": "genombryta",
    "genombrutet": "genombryta",
    "genombrutets": "genombryta",
    "genombrutit": "genombryta",
    "genombrutits": "genombryta",
    "genombrutna": "genombryta",
    "genombrutnare": "genombruten",
    "genombrutnares": "genombruten",
    "genombrutnas": "genombryta",
    "genombrutnast": "genombruten",
    "genombrutnaste": "genombruten",
    "genombrutnastes": "genombruten",
    "genombrutnasts": "genombruten",
    "genombrutne": "genombryta",
    "genombrutnes": "genombryta",
    "genombryt": "genombryta",
    "genombrytande": "genombryta",
    "genombrytanden": "genombrytande",
    "genombrytandena": "genombrytande",
    "genombrytandenas": "genombrytande",
    "genombrytandens": "genombrytande",
    "genombrytandes": "genombrytande",
    "genombrytandet": "genombrytande",
    "genombrytandets": "genombrytande",
    "genombrytas": "genombryta",
    "genombryte": "genombryta",
    "genombryter": "genombryta",
    "genombrytes": "genombryta",
    "genombryts": "genombryta",
    "genombröt": "genombryta",
    "genombröte": "genombryta",
    "genombrötes": "genombryta",
    "genombröts": "genombryta",
    "genomdrev": "genomdriva",
    "genomdrevs": "genomdriva",
    "genomdriv": "genomdriva",
    "genomdrivande": "genomdriva",
    "genomdrivanden": "genomdrivande",
    "genomdrivandena": "genomdrivande",
    "genomdrivandenas": "genomdrivande",
    "genomdrivandens": "genomdrivande",
    "genomdrivandes": "genomdrivande",
    "genomdrivandet": "genomdrivande",
    "genomdrivandets": "genomdrivande",
    "genomdrivas": "genomdriva",
    "genomdrive": "genomdriva",
    "genomdriven": "genomdriva",
    "genomdrivens": "genomdriva",
    "genomdriver": "genomdriva",
    "genomdrives": "genomdriva",
    "genomdrivet": "genomdriva",
    "genomdrivets": "genomdriva",
    "genomdrivit": "genomdriva",
    "genomdrivits": "genomdriva",
    "genomdrivna": "genomdriva",
    "genomdrivnas": "genomdriva",
    "genomdrivne": "genomdriva",
    "genomdrivnes": "genomdriva",
    "genomdrivs": "genomdriva",
    "genomdumheten": "genomdumhet",
    "genomdumhetens": "genomdumhet",
    "genomdumhets": "genomdumhet",
    "genomdumma": "genomdum",
    "genomdummare": "genomdum",
    "genomdummares": "genomdum",
    "genomdummas": "genomdum",
    "genomdummast": "genomdum",
    "genomdummaste": "genomdum",
    "genomdummastes": "genomdum",
    "genomdummasts": "genomdum",
    "genomdumme": "genomdum",
    "genomdummes": "genomdum",
    "genomdums": "genomdum",
    "genomdumt": "genomdum",
    "genomdumts": "genomdum",
    "genomen": "genom",
    "genomens": "genom",
    "genomet": "genom",
    "genomets": "genom",
    "genomfar": "genomfara",
    "genomfarande": "genomfara",
    "genomfaranden": "genomfarande",
    "genomfarandena": "genomfarande",
    "genomfarandenas": "genomfarande",
    "genomfarandens": "genomfarande",
    "genomfarandes": "genomfarande",
    "genomfarandet": "genomfarande",
    "genomfarandets": "genomfarande",
    "genomfaras": "genomfara",
    "genomfare": "genomfara",
    "genomfaren": "genomfara",
    "genomfarens": "genomfara",
    "genomfares": "genomfara",
    "genomfaret": "genomfara",
    "genomfarets": "genomfara",
    "genomfarit": "genomfara",
    "genomfarits": "genomfara",
    "genomfarna": "genomfara",
    "genomfarnas": "genomfara",
    "genomfarne": "genomfara",
    "genomfarnes": "genomfara",
    "genomfars": "genomfara",
    "genomfarten": "genomfart",
    "genomfartens": "genomfart",
    "genomfarter": "genomfart",
    "genomfarterna": "genomfart",
    "genomfarternas": "genomfart",
    "genomfarters": "genomfart",
    "genomfarts": "genomfart",
    "genomfartsgat": "genomfartsgata",
    "genomfartsgatan": "genomfartsgata",
    "genomfartsgatans": "genomfartsgata",
    "genomfartsgatas": "genomfartsgata",
    "genomfartsgate": "genomfartsgata",
    "genomfartsgator": "genomfartsgata",
    "genomfartsgatorna": "genomfartsgata",
    "genomfartsgatornas": "genomfartsgata",
    "genomfartsgators": "genomfartsgata",
    "genomfartsgats": "genomfartsgata",
    "genomfartsleden": "genomfartsled",
    "genomfartsledens": "genomfartsled",
    "genomfartsleder": "genomfartsled",
    "genomfartslederna": "genomfartsled",
    "genomfartsledernas": "genomfartsled",
    "genomfartsleders": "genomfartsled",
    "genomfartsleds": "genomfartsled",
    "genomfor": "genomfara",
    "genomfore": "genomfara",
    "genomfores": "genomfara",
    "genomfors": "genomfara",
    "genomfärden": "genomfärd",
    "genomfärdens": "genomfärd",
    "genomfärds": "genomfärd",
    "genomför": "genomföra",
    "genomförande": "genomföra",
    "genomföranden": "genomförande",
    "genomförandena": "genomförande",
    "genomförandenas": "genomförande",
    "genomförandens": "genomförande",
    "genomförandes": "genomförande",
    "genomförandet": "genomförande",
    "genomförandets": "genomförande",
    "genomföras": "genomföra",
    "genomförbara": "genomförbar",
    "genomförbarare": "genomförbar",
    "genomförbarares": "genomförbar",
    "genomförbaras": "genomförbar",
    "genomförbarast": "genomförbar",
    "genomförbaraste": "genomförbar",
    "genomförbarastes": "genomförbar",
    "genomförbarasts": "genomförbar",
    "genomförbare": "genomförbar",
    "genomförbares": "genomförbar",
    "genomförbarheten": "genomförbarhet",
    "genomförbarhetens": "genomförbarhet",
    "genomförbarhets": "genomförbarhet",
    "genomförbars": "genomförbar",
    "genomförbart": "genomförbar",
    "genomförbarts": "genomförbar",
    "genomförd": "genomföra",
    "genomförda": "genomföra",
    "genomfördas": "genomföra",
    "genomförde": "genomföra",
    "genomfördes": "genomföra",
    "genomförds": "genomföra",
    "genomföres": "genomföra",
    "genomföringar": "genomföring",
    "genomföringarna": "genomföring",
    "genomföringarnas": "genomföring",
    "genomföringars": "genomföring",
    "genomföringen": "genomföring",
    "genomföringens": "genomföring",
    "genomförings": "genomföring",
    "genomförkylda": "genomförkyld",
    "genomförkyldare": "genomförkyld",
    "genomförkyldares": "genomförkyld",
    "genomförkyldas": "genomförkyld",
    "genomförkyldast": "genomförkyld",
    "genomförkyldaste": "genomförkyld",
    "genomförkyldastes": "genomförkyld",
    "genomförkyldasts": "genomförkyld",
    "genomförkylde": "genomförkyld",
    "genomförkyldes": "genomförkyld",
    "genomförkylds": "genomförkyld",
    "genomförkylt": "genomförkyld",
    "genomförkylts": "genomförkyld",
    "genomförs": "genomföra",
    "genomfört": "genomföra",
    "genomförts": "genomföra",
    "genomgick": "genomgå",
    "genomgicks": "genomgå",
    "genomginge": "genomgå",
    "genomginges": "genomgå",
    "genomgående": "genomgå",
    "genomgåenden": "genomgående",
    "genomgåendena": "genomgående",
    "genomgåendenas": "genomgående",
    "genomgåendens": "genomgående",
    "genomgåendes": "genomgående",
    "genomgåendet": "genomgående",
    "genomgåendets": "genomgående",
    "genomgångar": "genomgång",
    "genomgångarna": "genomgång",
    "genomgångarnas": "genomgång",
    "genomgångars": "genomgång",
    "genomgånge": "genomgå",
    "genomgången": "genomgång",
    "genomgångens": "genomgång",
    "genomgånges": "genomgå",
    "genomgånget": "genomgå",
    "genomgångets": "genomgå",
    "genomgångna": "genomgå",
    "genomgångnas": "genomgå",
    "genomgångne": "genomgå",
    "genomgångnes": "genomgå",
    "genomgångs": "genomgång",
    "genomgår": "genomgå",
    "genomgås": "genomgå",
    "genomgått": "genomgå",
    "genomgåtts": "genomgå",
    "genomklappningar": "genomklappning",
    "genomklappningarna": "genomklappning",
    "genomklappningarnas": "genomklappning",
    "genomklappningars": "genomklappning",
    "genomklappningen": "genomklappning",
    "genomklappningens": "genomklappning",
    "genomklappnings": "genomklappning",
    "genomkomponerade": "genomkomponerad",
    "genomkomponerades": "genomkomponerad",
    "genomkomponerads": "genomkomponerad",
    "genomkomponerat": "genomkomponerad",
    "genomkomponerats": "genomkomponerad",
    "genomkors": "genomkorsa",
    "genomkorsad": "genomkorsa",
    "genomkorsade": "genomkorsa",
    "genomkorsades": "genomkorsa",
    "genomkorsads": "genomkorsa",
    "genomkorsande": "genomkorsa",
    "genomkorsanden": "genomkorsande",
    "genomkorsandena": "genomkorsande",
    "genomkorsandenas": "genomkorsande",
    "genomkorsandens": "genomkorsande",
    "genomkorsandes": "genomkorsande",
    "genomkorsandet": "genomkorsande",
    "genomkorsandets": "genomkorsande",
    "genomkorsar": "genomkorsa",
    "genomkorsas": "genomkorsa",
    "genomkorsat": "genomkorsa",
    "genomkorsats": "genomkorsa",
    "genomkörar": "genomkörare",
    "genomköraren": "genomkörare",
    "genomkörarens": "genomkörare",
    "genomkörares": "genomkörare",
    "genomkörarna": "genomkörare",
    "genomkörarnas": "genomkörare",
    "genomled": "genomlida",
    "genomleds": "genomlida",
    "genomlev": "genomleva",
    "genomlevande": "genomleva",
    "genomlevanden": "genomlevande",
    "genomlevandena": "genomlevande",
    "genomlevandenas": "genomlevande",
    "genomlevandens": "genomlevande",
    "genomlevandes": "genomlevande",
    "genomlevandet": "genomlevande",
    "genomlevandets": "genomlevande",
    "genomlevas": "genomleva",
    "genomlevat": "genomleva",
    "genomlevats": "genomleva",
    "genomlevd": "genomleva",
    "genomlevda": "genomleva",
    "genomlevdas": "genomleva",
    "genomlevde": "genomleva",
    "genomlevdes": "genomleva",
    "genomlevds": "genomleva",
    "genomlever": "genomleva",
    "genomleves": "genomleva",
    "genomlevs": "genomleva",
    "genomlevt": "genomleva",
    "genomlevts": "genomleva",
    "genomlid": "genomlida",
    "genomlidande": "genomlida",
    "genomlidanden": "genomlidande",
    "genomlidandena": "genomlidande",
    "genomlidandenas": "genomlidande",
    "genomlidandens": "genomlidande",
    "genomlidandes": "genomlidande",
    "genomlidandet": "genomlidande",
    "genomlidandets": "genomlidande",
    "genomlidas": "genomlida",
    "genomlide": "genomlida",
    "genomliden": "genomlida",
    "genomlidens": "genomlida",
    "genomlider": "genomlida",
    "genomlides": "genomlida",
    "genomlidet": "genomlida",
    "genomlidets": "genomlida",
    "genomlidit": "genomlida",
    "genomlidits": "genomlida",
    "genomlidna": "genomlida",
    "genomlidnas": "genomlida",
    "genomlidne": "genomlida",
    "genomlidnes": "genomlida",
    "genomlids": "genomlida",
    "genomlys": "genomlysa",
    "genomlysande": "genomlysa",
    "genomlysanden": "genomlysande",
    "genomlysandena": "genomlysande",
    "genomlysandenas": "genomlysande",
    "genomlysandens": "genomlysande",
    "genomlysandes": "genomlysande",
    "genomlysandet": "genomlysande",
    "genomlysandets": "genomlysande",
    "genomlysas": "genomlysa",
    "genomlyser": "genomlysa",
    "genomlyses": "genomlysa",
    "genomlysningar": "genomlysning",
    "genomlysningarna": "genomlysning",
    "genomlysningarnas": "genomlysning",
    "genomlysningars": "genomlysning",
    "genomlysningen": "genomlysning",
    "genomlysningens": "genomlysning",
    "genomlysnings": "genomlysning",
    "genomlyst": "genomlysa",
    "genomlysta": "genomlysa",
    "genomlystas": "genomlysa",
    "genomlyste": "genomlysa",
    "genomlystes": "genomlysa",
    "genomlysts": "genomlysa",
    "genommönstringar": "genommönstring",
    "genommönstringarna": "genommönstring",
    "genommönstringarnas": "genommönstring",
    "genommönstringars": "genommönstring",
    "genommönstringen": "genommönstring",
    "genommönstringens": "genommönstring",
    "genommönstrings": "genommönstring",
    "genomorganiserade": "genomorganiserad",
    "genomorganiserades": "genomorganiserad",
    "genomorganiserads": "genomorganiserad",
    "genomorganiserat": "genomorganiserad",
    "genomorganiserats": "genomorganiserad",
    "genomresan": "genomresa",
    "genomresans": "genomresa",
    "genomresas": "genomresa",
    "genomrese": "genomresa",
    "genomresor": "genomresa",
    "genomresorna": "genomresa",
    "genomresornas": "genomresa",
    "genomresors": "genomresa",
    "genomrostade": "genomrostad",
    "genomrostades": "genomrostad",
    "genomrostads": "genomrostad",
    "genomrostat": "genomrostad",
    "genomrostats": "genomrostad",
    "genoms": "genom",
    "genomsipprad": "genomsippra",
    "genomsipprade": "genomsippra",
    "genomsipprades": "genomsippra",
    "genomsipprads": "genomsippra",
    "genomsipprande": "genomsippra",
    "genomsippranden": "genomsipprande",
    "genomsipprandena": "genomsipprande",
    "genomsipprandenas": "genomsipprande",
    "genomsipprandens": "genomsipprande",
    "genomsipprandes": "genomsipprande",
    "genomsipprandet": "genomsipprande",
    "genomsipprandets": "genomsipprande",
    "genomsipprar": "genomsippra",
    "genomsippras": "genomsippra",
    "genomsipprat": "genomsippra",
    "genomsipprats": "genomsippra",
    "genomsippringar": "genomsippring",
    "genomsippringarna": "genomsippring",
    "genomsippringarnas": "genomsippring",
    "genomsippringars": "genomsippring",
    "genomsippringen": "genomsippring",
    "genomsippringens": "genomsippring",
    "genomsipprings": "genomsippring",
    "genomskinliga": "genomskinlig",
    "genomskinligare": "genomskinlig",
    "genomskinligares": "genomskinlig",
    "genomskinligas": "genomskinlig",
    "genomskinligast": "genomskinlig",
    "genomskinligaste": "genomskinlig",
    "genomskinligastes": "genomskinlig",
    "genomskinligasts": "genomskinlig",
    "genomskinlige": "genomskinlig",
    "genomskinliges": "genomskinlig",
    "genomskinligheten": "genomskinlighet",
    "genomskinlighetens": "genomskinlighet",
    "genomskinlighets": "genomskinlighet",
    "genomskinligs": "genomskinlig",
    "genomskinligt": "genomskinlig",
    "genomskinligts": "genomskinlig",
    "genomskärningar": "genomskärning",
    "genomskärningarna": "genomskärning",
    "genomskärningarnas": "genomskärning",
    "genomskärningars": "genomskärning",
    "genomskärningen": "genomskärning",
    "genomskärningens": "genomskärning",
    "genomskärnings": "genomskärning",
    "genomskåd": "genomskåda",
    "genomskådad": "genomskåda",
    "genomskådade": "genomskåda",
    "genomskådades": "genomskåda",
    "genomskådads": "genomskåda",
    "genomskådande": "genomskåda",
    "genomskådanden": "genomskådande",
    "genomskådandena": "genomskådande",
    "genomskådandenas": "genomskådande",
    "genomskådandens": "genomskådande",
    "genomskådandes": "genomskådande",
    "genomskådandet": "genomskådande",
    "genomskådandets": "genomskådande",
    "genomskådar": "genomskåda",
    "genomskådas": "genomskåda",
    "genomskådat": "genomskåda",
    "genomskådats": "genomskåda",
    "genomskölj": "genomskölja",
    "genomsköljande": "genomskölja",
    "genomsköljanden": "genomsköljande",
    "genomsköljandena": "genomsköljande",
    "genomsköljandenas": "genomsköljande",
    "genomsköljandens": "genomsköljande",
    "genomsköljandes": "genomsköljande",
    "genomsköljandet": "genomsköljande",
    "genomsköljandets": "genomsköljande",
    "genomsköljas": "genomskölja",
    "genomsköljd": "genomskölja",
    "genomsköljda": "genomskölja",
    "genomsköljdas": "genomskölja",
    "genomsköljde": "genomskölja",
    "genomsköljdes": "genomskölja",
    "genomsköljds": "genomskölja",
    "genomsköljer": "genomskölja",
    "genomsköljes": "genomskölja",
    "genomsköljs": "genomskölja",
    "genomsköljt": "genomskölja",
    "genomsköljts": "genomskölja",
    "genomslagen": "genomslag",
    "genomslagens": "genomslag",
    "genomslaget": "genomslag",
    "genomslagets": "genomslag",
    "genomslags": "genomslag",
    "genomslagsförmågan": "genomslagsförmåga",
    "genomslagsförmågans": "genomslagsförmåga",
    "genomslagsförmågas": "genomslagsförmåga",
    "genomslagsförmåge": "genomslagsförmåga",
    "genomslagskopian": "genomslagskopia",
    "genomslagskopians": "genomslagskopia",
    "genomslagskopias": "genomslagskopia",
    "genomslagskopie": "genomslagskopia",
    "genomslagskopior": "genomslagskopia",
    "genomslagskopiorna": "genomslagskopia",
    "genomslagskopiornas": "genomslagskopia",
    "genomslagskopiors": "genomslagskopia",
    "genomslagskraften": "genomslagskraft",
    "genomslagskraftens": "genomslagskraft",
    "genomslagskrafts": "genomslagskraft",
    "genomslagspapperen": "genomslagspapper",
    "genomslagspapperens": "genomslagspapper",
    "genomslagspapperet": "genomslagspapper",
    "genomslagspapperets": "genomslagspapper",
    "genomslagspapperna": "genomslagspapper",
    "genomslagspappernas": "genomslagspapper",
    "genomslagspappers": "genomslagspapper",
    "genomslagspappren": "genomslagspapper",
    "genomslagspapprens": "genomslagspapper",
    "genomslagspappret": "genomslagspapper",
    "genomslagspapprets": "genomslagspapper",
    "genomsläppliga": "genomsläpplig",
    "genomsläppligare": "genomsläpplig",
    "genomsläppligares": "genomsläpplig",
    "genomsläppligas": "genomsläpplig",
    "genomsläppligast": "genomsläpplig",
    "genomsläppligaste": "genomsläpplig",
    "genomsläppligastes": "genomsläpplig",
    "genomsläppligasts": "genomsläpplig",
    "genomsläpplige": "genomsläpplig",
    "genomsläppliges": "genomsläpplig",
    "genomsläppligheten": "genomsläpplighet",
    "genomsläpplighetens": "genomsläpplighet",
    "genomsläppligheter": "genomsläpplighet",
    "genomsläppligheterna": "genomsläpplighet",
    "genomsläppligheternas": "genomsläpplighet",
    "genomsläppligheters": "genomsläpplighet",
    "genomsläpplighets": "genomsläpplighet",
    "genomsläppligs": "genomsläpplig",
    "genomsläppligt": "genomsläpplig",
    "genomsläppligts": "genomsläpplig",
    "genomsnitten": "genomsnitt",
    "genomsnittens": "genomsnitt",
    "genomsnittet": "genomsnitt",
    "genomsnittets": "genomsnitt",
    "genomsnittliga": "genomsnittlig",
    "genomsnittligare": "genomsnittlig",
    "genomsnittligares": "genomsnittlig",
    "genomsnittligas": "genomsnittlig",
    "genomsnittligast": "genomsnittlig",
    "genomsnittligaste": "genomsnittlig",
    "genomsnittligastes": "genomsnittlig",
    "genomsnittligasts": "genomsnittlig",
    "genomsnittlige": "genomsnittlig",
    "genomsnittliges": "genomsnittlig",
    "genomsnittligheten": "genomsnittlighet",
    "genomsnittlighetens": "genomsnittlighet",
    "genomsnittlighets": "genomsnittlighet",
    "genomsnittligs": "genomsnittlig",
    "genomsnittligt": "genomsnittlig",
    "genomsnittligts": "genomsnittlig",
    "genomsnitts": "genomsnitt",
    "genomsnittsinkomsten": "genomsnittsinkomst",
    "genomsnittsinkomstens": "genomsnittsinkomst",
    "genomsnittsinkomster": "genomsnittsinkomst",
    "genomsnittsinkomsterna": "genomsnittsinkomst",
    "genomsnittsinkomsternas": "genomsnittsinkomst",
    "genomsnittsinkomsters": "genomsnittsinkomst",
    "genomsnittsinkomsts": "genomsnittsinkomst",
    "genomsnittsskatten": "genomsnittsskatt",
    "genomsnittsskattens": "genomsnittsskatt",
    "genomsnittsskatter": "genomsnittsskatt",
    "genomsnittsskatterna": "genomsnittsskatt",
    "genomsnittsskatternas": "genomsnittsskatt",
    "genomsnittsskatters": "genomsnittsskatt",
    "genomsnittsskatts": "genomsnittsskatt",
    "genomsnittssvenskar": "genomsnittssvensk",
    "genomsnittssvenskarna": "genomsnittssvensk",
    "genomsnittssvenskarnas": "genomsnittssvensk",
    "genomsnittssvenskars": "genomsnittssvensk",
    "genomsnittssvensken": "genomsnittssvensk",
    "genomsnittssvenskens": "genomsnittssvensk",
    "genomsnittssvensks": "genomsnittssvensk",
    "genomsnittsvärden": "genomsnittsvärde",
    "genomsnittsvärdena": "genomsnittsvärde",
    "genomsnittsvärdenas": "genomsnittsvärde",
    "genomsnittsvärdens": "genomsnittsvärde",
    "genomsnittsvärdes": "genomsnittsvärde",
    "genomsnittsvärdet": "genomsnittsvärde",
    "genomsnittsvärdets": "genomsnittsvärde",
    "genomströmmad": "genomströmma",
    "genomströmmade": "genomströmma",
    "genomströmmades": "genomströmma",
    "genomströmmads": "genomströmma",
    "genomströmmande": "genomströmma",
    "genomströmmanden": "genomströmmande",
    "genomströmmandena": "genomströmmande",
    "genomströmmandenas": "genomströmmande",
    "genomströmmandens": "genomströmmande",
    "genomströmmandes": "genomströmmande",
    "genomströmmandet": "genomströmmande",
    "genomströmmandets": "genomströmmande",
    "genomströmmar": "genomströmma",
    "genomströmmas": "genomströmma",
    "genomströmmat": "genomströmma",
    "genomströmmats": "genomströmma",
    "genomströmningar": "genomströmning",
    "genomströmningarna": "genomströmning",
    "genomströmningarnas": "genomströmning",
    "genomströmningars": "genomströmning",
    "genomströmningen": "genomströmning",
    "genomströmningens": "genomströmning",
    "genomströmnings": "genomströmning",
    "genomsyr": "genomsyra",
    "genomsyrad": "genomsyra",
    "genomsyrade": "genomsyra",
    "genomsyrades": "genomsyra",
    "genomsyrads": "genomsyra",
    "genomsyrande": "genomsyra",
    "genomsyranden": "genomsyrande",
    "genomsyrandena": "genomsyrande",
    "genomsyrandenas": "genomsyrande",
    "genomsyrandens": "genomsyrande",
    "genomsyrandes": "genomsyrande",
    "genomsyrandet": "genomsyrande",
    "genomsyrandets": "genomsyrande",
    "genomsyrar": "genomsyra",
    "genomsyras": "genomsyra",
    "genomsyrat": "genomsyra",
    "genomsyrats": "genomsyra",
    "genomsök": "genomsöka",
    "genomsökande": "genomsöka",
    "genomsökanden": "genomsökande",
    "genomsökandena": "genomsökande",
    "genomsökandenas": "genomsökande",
    "genomsökandens": "genomsökande",
    "genomsökandes": "genomsökande",
    "genomsökandet": "genomsökande",
    "genomsökandets": "genomsökande",
    "genomsökas": "genomsöka",
    "genomsöker": "genomsöka",
    "genomsökes": "genomsöka",
    "genomsöks": "genomsöka",
    "genomsökt": "genomsöka",
    "genomsökta": "genomsöka",
    "genomsöktas": "genomsöka",
    "genomsökte": "genomsöka",
    "genomsöktes": "genomsöka",
    "genomsökts": "genomsöka",
    "genomtrampningar": "genomtrampning",
    "genomtrampningarna": "genomtrampning",
    "genomtrampningarnas": "genomtrampning",
    "genomtrampningars": "genomtrampning",
    "genomtrampningen": "genomtrampning",
    "genomtrampningens": "genomtrampning",
    "genomtrampnings": "genomtrampning",
    "genomtryckta": "genomtryckt",
    "genomtrycktare": "genomtryckt",
    "genomtrycktares": "genomtryckt",
    "genomtrycktas": "genomtryckt",
    "genomtrycktast": "genomtryckt",
    "genomtrycktaste": "genomtryckt",
    "genomtrycktastes": "genomtryckt",
    "genomtrycktasts": "genomtryckt",
    "genomtryckte": "genomtryckt",
    "genomtrycktes": "genomtryckt",
    "genomtryckts": "genomtryckt",
    "genomträng": "genomtränga",
    "genomträngande": "genomtränga",
    "genomtränganden": "genomträngande",
    "genomträngandena": "genomträngande",
    "genomträngandenas": "genomträngande",
    "genomträngandens": "genomträngande",
    "genomträngandes": "genomträngande",
    "genomträngandet": "genomträngande",
    "genomträngandets": "genomträngande",
    "genomträngas": "genomtränga",
    "genomträngd": "genomtränga",
    "genomträngda": "genomtränga",
    "genomträngdas": "genomtränga",
    "genomträngde": "genomtränga",
    "genomträngdes": "genomtränga",
    "genomträngds": "genomtränga",
    "genomtränger": "genomtränga",
    "genomtränges": "genomtränga",
    "genomträngliga": "genomtränglig",
    "genomträngligare": "genomtränglig",
    "genomträngligares": "genomtränglig",
    "genomträngligas": "genomtränglig",
    "genomträngligast": "genomtränglig",
    "genomträngligaste": "genomtränglig",
    "genomträngligastes": "genomtränglig",
    "genomträngligasts": "genomtränglig",
    "genomtränglige": "genomtränglig",
    "genomträngliges": "genomtränglig",
    "genomträngligheten": "genomtränglighet",
    "genomtränglighetens": "genomtränglighet",
    "genomtränglighets": "genomtränglighet",
    "genomträngligs": "genomtränglig",
    "genomträngligt": "genomtränglig",
    "genomträngligts": "genomtränglig",
    "genomträngningar": "genomträngning",
    "genomträngningarna": "genomträngning",
    "genomträngningarnas": "genomträngning",
    "genomträngningars": "genomträngning",
    "genomträngningen": "genomträngning",
    "genomträngningens": "genomträngning",
    "genomträngnings": "genomträngning",
    "genomträngningsförmågan": "genomträngningsförmåga",
    "genomträngningsförmågans": "genomträngningsförmåga",
    "genomträngningsförmågas": "genomträngningsförmåga",
    "genomträngningsförmåge": "genomträngningsförmåga",
    "genomträngs": "genomtränga",
    "genomträngt": "genomtränga",
    "genomträngts": "genomtränga",
    "genomtänk": "genomtänka",
    "genomtänkande": "genomtänka",
    "genomtänkanden": "genomtänkande",
    "genomtänkandena": "genomtänkande",
    "genomtänkandenas": "genomtänkande",
    "genomtänkandens": "genomtänkande",
    "genomtänkandes": "genomtänkande",
    "genomtänkandet": "genomtänkande",
    "genomtänkandets": "genomtänkande",
    "genomtänkas": "genomtänka",
    "genomtänker": "genomtänka",
    "genomtänkes": "genomtänka",
    "genomtänks": "genomtänka",
    "genomtänkt": "genomtänka",
    "genomtänkta": "genomtänkt",
    "genomtänktare": "genomtänkt",
    "genomtänktares": "genomtänkt",
    "genomtänktas": "genomtänkt",
    "genomtänktast": "genomtänkt",
    "genomtänktaste": "genomtänkt",
    "genomtänktastes": "genomtänkt",
    "genomtänktasts": "genomtänkt",
    "genomtänkte": "genomtänkt",
    "genomtänktes": "genomtänkt",
    "genomtänktheten": "genomtänkthet",
    "genomtänkthetens": "genomtänkthet",
    "genomtänkthets": "genomtänkthet",
    "genomtänkts": "genomtänkt",
    "genomvävda": "genomvävd",
    "genomvävdare": "genomvävd",
    "genomvävdares": "genomvävd",
    "genomvävdas": "genomvävd",
    "genomvävdast": "genomvävd",
    "genomvävdaste": "genomvävd",
    "genomvävdastes": "genomvävd",
    "genomvävdasts": "genomvävd",
    "genomvävde": "genomvävd",
    "genomvävdes": "genomvävd",
    "genomvävds": "genomvävd",
    "genomvävt": "genomvävd",
    "genomvävts": "genomvävd",
    "genomvåta": "genomvåt",
    "genomvåtare": "genomvåt",
    "genomvåtares": "genomvåt",
    "genomvåtas": "genomvåt",
    "genomvåtast": "genomvåt",
    "genomvåtaste": "genomvåt",
    "genomvåtastes": "genomvåt",
    "genomvåtasts": "genomvåt",
    "genomvåte": "genomvåt",
    "genomvåtes": "genomvåt",
    "genomvåts": "genomvåt",
    "genomvått": "genomvåt",
    "genomvåtts": "genomvåt",
    "genotypen": "genotyp",
    "genotypens": "genotyp",
    "genotyper": "genotyp",
    "genotyperna": "genotyp",
    "genotypernas": "genotyp",
    "genotypers": "genotyp",
    "genotyps": "genotyp",
    "genpoolen": "genpool",
    "genpoolens": "genpool",
    "genpooler": "genpool",
    "genpoolerna": "genpool",
    "genpoolernas": "genpool",
    "genpoolers": "genpool",
    "genpools": "genpool",
    "genremässiga": "genremässig",
    "genremässigare": "genremässig",
    "genremässigares": "genremässig",
    "genremässigas": "genremässig",
    "genremässigast": "genremässig",
    "genremässigaste": "genremässig",
    "genremässigastes": "genremässig",
    "genremässigasts": "genremässig",
    "genremässige": "genremässig",
    "genremässiges": "genremässig",
    "genremässigs": "genremässig",
    "genremässigt": "genremässig",
    "genremässigts": "genremässig",
    "genren": "genre",
    "genrens": "genre",
    "genrepen": "genrep",
    "genrepens": "genrep",
    "genrepet": "genrep",
    "genrepets": "genrep",
    "genreps": "genrep",
    "genrer": "genre",
    "genrerna": "genre",
    "genrernas": "genre",
    "genrers": "genre",
    "genres": "genre",
    "gens": "gen",
    "gensagan": "gensaga",
    "gensagans": "gensaga",
    "gensagas": "gensaga",
    "gensage": "gensaga",
    "gensago": "gensaga",
    "gensagor": "gensaga",
    "gensagorna": "gensaga",
    "gensagornas": "gensaga",
    "gensagors": "gensaga",
    "gensar": "gensare",
    "gensaren": "gensare",
    "gensarens": "gensare",
    "gensares": "gensare",
    "gensarna": "gensare",
    "gensarnas": "gensare",
    "genskjut": "genskjuta",
    "genskjutande": "genskjuta",
    "genskjutanden": "genskjutande",
    "genskjutandena": "genskjutande",
    "genskjutandenas": "genskjutande",
    "genskjutandens": "genskjutande",
    "genskjutandes": "genskjutande",
    "genskjutandet": "genskjutande",
    "genskjutandets": "genskjutande",
    "genskjutas": "genskjuta",
    "genskjute": "genskjuta",
    "genskjuten": "genskjuta",
    "genskjutens": "genskjuta",
    "genskjuter": "genskjuta",
    "genskjutes": "genskjuta",
    "genskjutet": "genskjuta",
    "genskjutets": "genskjuta",
    "genskjutit": "genskjuta",
    "genskjutits": "genskjuta",
    "genskjutna": "genskjuta",
    "genskjutnas": "genskjuta",
    "genskjutne": "genskjuta",
    "genskjutnes": "genskjuta",
    "genskjuts": "genskjuta",
    "gensköt": "genskjuta",
    "gensköte": "genskjuta",
    "genskötes": "genskjuta",
    "gensköts": "genskjuta",
    "genstridiga": "genstridig",
    "genstridigare": "genstridig",
    "genstridigares": "genstridig",
    "genstridigas": "genstridig",
    "genstridigast": "genstridig",
    "genstridigaste": "genstridig",
    "genstridigastes": "genstridig",
    "genstridigasts": "genstridig",
    "genstridige": "genstridig",
    "genstridiges": "genstridig",
    "genstridigheten": "genstridighet",
    "genstridighetens": "genstridighet",
    "genstridighets": "genstridighet",
    "genstridigs": "genstridig",
    "genstridigt": "genstridig",
    "genstridigts": "genstridig",
    "gensträviga": "gensträvig",
    "gensträvigare": "gensträvig",
    "gensträvigares": "gensträvig",
    "gensträvigas": "gensträvig",
    "gensträvigast": "gensträvig",
    "gensträvigaste": "gensträvig",
    "gensträvigastes": "gensträvig",
    "gensträvigasts": "gensträvig",
    "gensträvige": "gensträvig",
    "gensträviges": "gensträvig",
    "gensträvigheten": "gensträvighet",
    "gensträvighetens": "gensträvighet",
    "gensträvighets": "gensträvighet",
    "gensträvigs": "gensträvig",
    "gensträvigt": "gensträvig",
    "gensträvigts": "gensträvig",
    "genstämningar": "genstämning",
    "genstämningarna": "genstämning",
    "genstämningarnas": "genstämning",
    "genstämningars": "genstämning",
    "genstämningen": "genstämning",
    "genstämningens": "genstämning",
    "genstämnings": "genstämning",
    "genstörtiga": "genstörtig",
    "genstörtigare": "genstörtig",
    "genstörtigares": "genstörtig",
    "genstörtigas": "genstörtig",
    "genstörtigast": "genstörtig",
    "genstörtigaste": "genstörtig",
    "genstörtigastes": "genstörtig",
    "genstörtigasts": "genstörtig",
    "genstörtige": "genstörtig",
    "genstörtiges": "genstörtig",
    "genstörtigheten": "genstörtighet",
    "genstörtighetens": "genstörtighet",
    "genstörtighets": "genstörtighet",
    "genstörtigs": "genstörtig",
    "genstörtigt": "genstörtig",
    "genstörtigts": "genstörtig",
    "gensvaret": "gensvar",
    "gensvarets": "gensvar",
    "gensvars": "gensvar",
    "gensägelsen": "gensägelse",
    "gensägelsens": "gensägelse",
    "gensägelser": "gensägelse",
    "gensägelserna": "gensägelse",
    "gensägelsernas": "gensägelse",
    "gensägelsers": "gensägelse",
    "gensägelses": "gensägelse",
    "gent": "gen",
    "gentag": "genta",
    "gentaga": "genta",
    "gentagande": "genta",
    "gentaganden": "gentagande",
    "gentagandena": "gentagande",
    "gentagandenas": "gentagande",
    "gentagandens": "gentagande",
    "gentagandes": "gentagande",
    "gentagandet": "gentagande",
    "gentagandets": "gentagande",
    "gentagas": "genta",
    "gentage": "genta",
    "gentagen": "genta",
    "gentagens": "genta",
    "gentager": "genta",
    "gentages": "genta",
    "gentaget": "genta",
    "gentagets": "genta",
    "gentagit": "genta",
    "gentagits": "genta",
    "gentagna": "genta",
    "gentagnas": "genta",
    "gentagne": "genta",
    "gentagnes": "genta",
    "gentags": "genta",
    "gentar": "genta",
    "gentas": "genta",
    "gentekniken": "genteknik",
    "genteknikens": "genteknik",
    "gentekniks": "genteknik",
    "gentian": "gentiana",
    "gentianan": "gentiana",
    "gentianans": "gentiana",
    "gentianas": "gentiana",
    "gentiane": "gentiana",
    "gentianor": "gentiana",
    "gentianorna": "gentiana",
    "gentianornas": "gentiana",
    "gentianors": "gentiana",
    "gentians": "gentiana",
    "gentila": "gentil",
    "gentilare": "gentil",
    "gentilares": "gentil",
    "gentilas": "gentil",
    "gentilast": "gentil",
    "gentilaste": "gentil",
    "gentilastes": "gentil",
    "gentilasts": "gentil",
    "gentile": "gentil",
    "gentiles": "gentil",
    "gentiljessen": "gentiljess",
    "gentiljessens": "gentiljess",
    "gentils": "gentil",
    "gentilt": "gentil",
    "gentilts": "gentil",
    "gentjänsten": "gentjänst",
    "gentjänstens": "gentjänst",
    "gentjänster": "gentjänst",
    "gentjänsterna": "gentjänst",
    "gentjänsternas": "gentjänst",
    "gentjänsters": "gentjänst",
    "gentjänsts": "gentjänst",
    "gentlemannabesluten": "gentlemannabeslut",
    "gentlemannabeslutens": "gentlemannabeslut",
    "gentlemannabeslutet": "gentlemannabeslut",
    "gentlemannabeslutets": "gentlemannabeslut",
    "gentlemannabesluts": "gentlemannabeslut",
    "gentlemannamässiga": "gentlemannamässig",
    "gentlemannamässigare": "gentlemannamässig",
    "gentlemannamässigares": "gentlemannamässig",
    "gentlemannamässigas": "gentlemannamässig",
    "gentlemannamässigast": "gentlemannamässig",
    "gentlemannamässigaste": "gentlemannamässig",
    "gentlemannamässigastes": "gentlemannamässig",
    "gentlemannamässigasts": "gentlemannamässig",
    "gentlemannamässige": "gentlemannamässig",
    "gentlemannamässiges": "gentlemannamässig",
    "gentlemannamässigs": "gentlemannamässig",
    "gentlemannamässigt": "gentlemannamässig",
    "gentlemannamässigts": "gentlemannamässig",
    "gentlemannen": "gentleman",
    "gentlemannens": "gentleman",
    "gentlemans": "gentleman",
    "gentlemän": "gentleman",
    "gentlemännen": "gentleman",
    "gentlemännens": "gentleman",
    "gentlemäns": "gentleman",
    "gentog": "genta",
    "gentoge": "genta",
    "gentoges": "genta",
    "gentogs": "genta",
    "gents": "gen",
    "genu": "genua",
    "genuafockar": "genuafock",
    "genuafockarna": "genuafock",
    "genuafockarnas": "genuafock",
    "genuafockars": "genuafock",
    "genuafocken": "genuafock",
    "genuafockens": "genuafock",
    "genuafocks": "genuafock",
    "genuan": "genua",
    "genuans": "genua",
    "genuas": "genua",
    "genue": "genua",
    "genuina": "genuin",
    "genuinare": "genuin",
    "genuinares": "genuin",
    "genuinas": "genuin",
    "genuinast": "genuin",
    "genuinaste": "genuin",
    "genuinastes": "genuin",
    "genuinasts": "genuin",
    "genuine": "genuin",
    "genuines": "genuin",
    "genuins": "genuin",
    "genuint": "genuin",
    "genuints": "genuin",
    "genuor": "genua",
    "genuorna": "genua",
    "genuornas": "genua",
    "genuors": "genua",
    "genus": "genua",
    "genusen": "genus",
    "genusens": "genus",
    "genuset": "genus",
    "genusets": "genus",
    "genusmässiga": "genusmässig",
    "genusmässigare": "genusmässig",
    "genusmässigares": "genusmässig",
    "genusmässigas": "genusmässig",
    "genusmässigast": "genusmässig",
    "genusmässigaste": "genusmässig",
    "genusmässigastes": "genusmässig",
    "genusmässigasts": "genusmässig",
    "genusmässige": "genusmässig",
    "genusmässiges": "genusmässig",
    "genusmässigs": "genusmässig",
    "genusmässigt": "genusmässig",
    "genusmässigts": "genusmässig",
    "genusperspektiven": "genusperspektiv",
    "genusperspektivens": "genusperspektiv",
    "genusperspektivet": "genusperspektiv",
    "genusperspektivets": "genusperspektiv",
    "genusperspektivs": "genusperspektiv",
    "genusvetenskapen": "genusvetenskap",
    "genusvetenskapens": "genusvetenskap",
    "genusvetenskaper": "genusvetenskap",
    "genusvetenskaperna": "genusvetenskap",
    "genusvetenskapernas": "genusvetenskap",
    "genusvetenskapers": "genusvetenskap",
    "genusvetenskaps": "genusvetenskap",
    "genvägar": "genväg",
    "genvägarna": "genväg",
    "genvägarnas": "genväg",
    "genvägars": "genväg",
    "genvägen": "genväg",
    "genvägens": "genväg",
    "genvägs": "genväg",
    "geocentriska": "geocentrisk",
    "geocentriskare": "geocentrisk",
    "geocentriskares": "geocentrisk",
    "geocentriskas": "geocentrisk",
    "geocentriskast": "geocentrisk",
    "geocentriskaste": "geocentrisk",
    "geocentriskastes": "geocentrisk",
    "geocentriskasts": "geocentrisk",
    "geocentriske": "geocentrisk",
    "geocentriskes": "geocentrisk",
    "geocentrisks": "geocentrisk",
    "geocentriskt": "geocentrisk",
    "geocentriskts": "geocentrisk",
    "geodatan": "geodata",
    "geodatana": "geodata",
    "geodatanas": "geodata",
    "geodatans": "geodata",
    "geodatas": "geodata",
    "geodatat": "geodata",
    "geodatats": "geodata",
    "geodesien": "geodesi",
    "geodesiens": "geodesi",
    "geodesin": "geodesi",
    "geodesins": "geodesi",
    "geodesis": "geodesi",
    "geodeten": "geodet",
    "geodetens": "geodet",
    "geodeter": "geodet",
    "geodeterna": "geodet",
    "geodeternas": "geodet",
    "geodeters": "geodet",
    "geodetiska": "geodetisk",
    "geodetiskare": "geodetisk",
    "geodetiskares": "geodetisk",
    "geodetiskas": "geodetisk",
    "geodetiskast": "geodetisk",
    "geodetiskaste": "geodetisk",
    "geodetiskastes": "geodetisk",
    "geodetiskasts": "geodetisk",
    "geodetiske": "geodetisk",
    "geodetiskes": "geodetisk",
    "geodetisks": "geodetisk",
    "geodetiskt": "geodetisk",
    "geodetiskts": "geodetisk",
    "geodets": "geodet",
    "geodimetern": "geodimeter",
    "geodimeterns": "geodimeter",
    "geodimeters": "geodimeter",
    "geodimetrar": "geodimeter",
    "geodimetrarna": "geodimeter",
    "geodimetrarnas": "geodimeter",
    "geodimetrars": "geodimeter",
    "geodynamiken": "geodynamik",
    "geodynamikens": "geodynamik",
    "geodynamiks": "geodynamik",
    "geofonen": "geofon",
    "geofonens": "geofon",
    "geofoner": "geofon",
    "geofonerna": "geofon",
    "geofonernas": "geofon",
    "geofoners": "geofon",
    "geofons": "geofon",
    "geofysiken": "geofysik",
    "geofysikens": "geofysik",
    "geofysiks": "geofysik",
    "geografen": "geograf",
    "geografens": "geograf",
    "geografer": "geograf",
    "geograferna": "geograf",
    "geografernas": "geograf",
    "geografers": "geograf",
    "geografien": "geografi",
    "geografiens": "geografi",
    "geografin": "geografi",
    "geografins": "geografi",
    "geografis": "geografi",
    "geografiska": "geografisk",
    "geografiskare": "geografisk",
    "geografiskares": "geografisk",
    "geografiskas": "geografisk",
    "geografiskast": "geografisk",
    "geografiskaste": "geografisk",
    "geografiskastes": "geografisk",
    "geografiskasts": "geografisk",
    "geografiske": "geografisk",
    "geografiskes": "geografisk",
    "geografisks": "geografisk",
    "geografiskt": "geografisk",
    "geografiskts": "geografisk",
    "geografs": "geograf",
    "geoiden": "geoid",
    "geoidens": "geoid",
    "geoids": "geoid",
    "geokemien": "geokemi",
    "geokemiens": "geokemi",
    "geokemin": "geokemi",
    "geokemins": "geokemi",
    "geokemis": "geokemi",
    "geokemiska": "geokemisk",
    "geokemiskare": "geokemisk",
    "geokemiskares": "geokemisk",
    "geokemiskas": "geokemisk",
    "geokemiskast": "geokemisk",
    "geokemiskaste": "geokemisk",
    "geokemiskastes": "geokemisk",
    "geokemiskasts": "geokemisk",
    "geokemiske": "geokemisk",
    "geokemiskes": "geokemisk",
    "geokemisks": "geokemisk",
    "geokemiskt": "geokemisk",
    "geokemiskts": "geokemisk",
    "geokronologien": "geokronologi",
    "geokronologiens": "geokronologi",
    "geokronologin": "geokronologi",
    "geokronologins": "geokronologi",
    "geokronologis": "geokronologi",
    "geokronologiska": "geokronologisk",
    "geokronologiskare": "geokronologisk",
    "geokronologiskares": "geokronologisk",
    "geokronologiskas": "geokronologisk",
    "geokronologiskast": "geokronologisk",
    "geokronologiskaste": "geokronologisk",
    "geokronologiskastes": "geokronologisk",
    "geokronologiskasts": "geokronologisk",
    "geokronologiske": "geokronologisk",
    "geokronologiskes": "geokronologisk",
    "geokronologisks": "geokronologisk",
    "geokronologiskt": "geokronologisk",
    "geokronologiskts": "geokronologisk",
    "geologen": "geolog",
    "geologens": "geolog",
    "geologer": "geolog",
    "geologerna": "geolog",
    "geologernas": "geolog",
    "geologers": "geolog",
    "geologien": "geologi",
    "geologiens": "geologi",
    "geologin": "geologi",
    "geologins": "geologi",
    "geologis": "geologi",
    "geologiska": "geologisk",
    "geologiskare": "geologisk",
    "geologiskares": "geologisk",
    "geologiskas": "geologisk",
    "geologiskast": "geologisk",
    "geologiskaste": "geologisk",
    "geologiskastes": "geologisk",
    "geologiskasts": "geologisk",
    "geologiske": "geologisk",
    "geologiskes": "geologisk",
    "geologisks": "geologisk",
    "geologiskt": "geologisk",
    "geologiskts": "geologisk",
    "geologs": "geolog",
    "geometrien": "geometri",
    "geometriens": "geometri",
    "geometrier": "geometri",
    "geometrierna": "geometri",
    "geometriernas": "geometri",
    "geometriers": "geometri",
    "geometrikern": "geometriker",
    "geometrikerna": "geometriker",
    "geometrikernas": "geometriker",
    "geometrikerns": "geometriker",
    "geometrikers": "geometriker",
    "geometrin": "geometri",
    "geometrins": "geometri",
    "geometris": "geometri",
    "geometriserad": "geometrisera",
    "geometriserade": "geometrisera",
    "geometriserades": "geometrisera",
    "geometriserads": "geometrisera",
    "geometriserande": "geometrisera",
    "geometriseranden": "geometriserande",
    "geometriserandena": "geometriserande",
    "geometriserandenas": "geometriserande",
    "geometriserandens": "geometriserande",
    "geometriserandes": "geometriserande",
    "geometriserandet": "geometriserande",
    "geometriserandets": "geometriserande",
    "geometriserar": "geometrisera",
    "geometriseras": "geometrisera",
    "geometriserat": "geometrisera",
    "geometriserats": "geometrisera",
    "geometriserbara": "geometriserbar",
    "geometriserbarare": "geometriserbar",
    "geometriserbarares": "geometriserbar",
    "geometriserbaras": "geometriserbar",
    "geometriserbarast": "geometriserbar",
    "geometriserbaraste": "geometriserbar",
    "geometriserbarastes": "geometriserbar",
    "geometriserbarasts": "geometriserbar",
    "geometriserbare": "geometriserbar",
    "geometriserbares": "geometriserbar",
    "geometriserbarheten": "geometriserbarhet",
    "geometriserbarhetens": "geometriserbarhet",
    "geometriserbarhets": "geometriserbarhet",
    "geometriserbars": "geometriserbar",
    "geometriserbart": "geometriserbar",
    "geometriserbarts": "geometriserbar",
    "geometriseringar": "geometrisering",
    "geometriseringarna": "geometrisering",
    "geometriseringarnas": "geometrisering",
    "geometriseringars": "geometrisering",
    "geometriseringen": "geometrisering",
    "geometriseringens": "geometrisering",
    "geometriserings": "geometrisering",
    "geometriska": "geometrisk",
    "geometriskare": "geometrisk",
    "geometriskares": "geometrisk",
    "geometriskas": "geometrisk",
    "geometriskast": "geometrisk",
    "geometriskaste": "geometrisk",
    "geometriskastes": "geometrisk",
    "geometriskasts": "geometrisk",
    "geometriske": "geometrisk",
    "geometriskes": "geometrisk",
    "geometrisks": "geometrisk",
    "geometriskt": "geometrisk",
    "geometriskts": "geometrisk",
    "geomorfologien": "geomorfologi",
    "geomorfologiens": "geomorfologi",
    "geomorfologin": "geomorfologi",
    "geomorfologins": "geomorfologi",
    "geomorfologis": "geomorfologi",
    "geomorfologiska": "geomorfologisk",
    "geomorfologiskare": "geomorfologisk",
    "geomorfologiskares": "geomorfologisk",
    "geomorfologiskas": "geomorfologisk",
    "geomorfologiskast": "geomorfologisk",
    "geomorfologiskaste": "geomorfologisk",
    "geomorfologiskastes": "geomorfologisk",
    "geomorfologiskasts": "geomorfologisk",
    "geomorfologiske": "geomorfologisk",
    "geomorfologiskes": "geomorfologisk",
    "geomorfologisks": "geomorfologisk",
    "geomorfologiskt": "geomorfologisk",
    "geomorfologiskts": "geomorfologisk",
    "geopolitiken": "geopolitik",
    "geopolitikens": "geopolitik",
    "geopolitiks": "geopolitik",
    "geopolitiska": "geopolitisk",
    "geopolitiskas": "geopolitisk",
    "geopolitiske": "geopolitisk",
    "geopolitiskes": "geopolitisk",
    "geopolitisks": "geopolitisk",
    "geopolitiskt": "geopolitisk",
    "geopolitiskts": "geopolitisk",
    "georgetten": "georgette",
    "georgettens": "georgette",
    "georgettes": "georgette",
    "georgiern": "georgier",
    "georgierna": "georgier",
    "georgiernas": "georgier",
    "georgierns": "georgier",
    "georgiers": "georgier",
    "georgisk": "georgiska",
    "georgiska": "georgisk",
    "georgiskan": "georgiska",
    "georgiskans": "georgiska",
    "georgiskare": "georgisk",
    "georgiskares": "georgisk",
    "georgiskas": "georgiska",
    "georgiskast": "georgisk",
    "georgiskaste": "georgisk",
    "georgiskastes": "georgisk",
    "georgiskasts": "georgisk",
    "georgiske": "georgiska",
    "georgiskes": "georgisk",
    "georgiskor": "georgiska",
    "georgiskorna": "georgiska",
    "georgiskornas": "georgiska",
    "georgiskors": "georgiska",
    "georgisks": "georgisk",
    "georgiskt": "georgisk",
    "georgiskts": "georgisk",
    "georgskorsen": "georgskors",
    "georgskorsens": "georgskors",
    "georgskorset": "georgskors",
    "georgskorsets": "georgskors",
    "geostationära": "geostationär",
    "geostationärare": "geostationär",
    "geostationärares": "geostationär",
    "geostationäras": "geostationär",
    "geostationärast": "geostationär",
    "geostationäraste": "geostationär",
    "geostationärastes": "geostationär",
    "geostationärasts": "geostationär",
    "geostationäre": "geostationär",
    "geostationäres": "geostationär",
    "geostationärs": "geostationär",
    "geostationärt": "geostationär",
    "geostationärts": "geostationär",
    "geosynklinalen": "geosynklinal",
    "geosynklinalens": "geosynklinal",
    "geosynklinaler": "geosynklinal",
    "geosynklinalerna": "geosynklinal",
    "geosynklinalernas": "geosynklinal",
    "geosynklinalers": "geosynklinal",
    "geosynklinals": "geosynklinal",
    "geotagg": "geotagga",
    "geotaggad": "geotagga",
    "geotaggade": "geotagga",
    "geotaggades": "geotagga",
    "geotaggads": "geotagga",
    "geotaggande": "geotagga",
    "geotagganden": "geotaggande",
    "geotaggandena": "geotaggande",
    "geotaggandenas": "geotaggande",
    "geotaggandens": "geotaggande",
    "geotaggandes": "geotaggande",
    "geotaggandet": "geotaggande",
    "geotaggandets": "geotaggande",
    "geotaggar": "geotagga",
    "geotaggas": "geotagga",
    "geotaggat": "geotagga",
    "geotaggats": "geotagga",
    "geotekniken": "geoteknik",
    "geoteknikens": "geoteknik",
    "geotekniks": "geoteknik",
    "geotermien": "geotermi",
    "geotermiens": "geotermi",
    "geotermin": "geotermi",
    "geotermins": "geotermi",
    "geotermis": "geotermi",
    "geotermiska": "geotermisk",
    "geotermiskare": "geotermisk",
    "geotermiskares": "geotermisk",
    "geotermiskas": "geotermisk",
    "geotermiskast": "geotermisk",
    "geotermiskaste": "geotermisk",
    "geotermiskastes": "geotermisk",
    "geotermiskasts": "geotermisk",
    "geotermiske": "geotermisk",
    "geotermiskes": "geotermisk",
    "geotermisks": "geotermisk",
    "geotermiskt": "geotermisk",
    "geotermiskts": "geotermisk",
    "geotropismen": "geotropism",
    "geotropismens": "geotropism",
    "geotropismer": "geotropism",
    "geotropismerna": "geotropism",
    "geotropismernas": "geotropism",
    "geotropismers": "geotropism",
    "geotropisms": "geotropism",
    "geovetar": "geovetare",
    "geovetaren": "geovetare",
    "geovetarens": "geovetare",
    "geovetares": "geovetare",
    "geovetarna": "geovetare",
    "geovetarnas": "geovetare",
    "geovetenskapen": "geovetenskap",
    "geovetenskapens": "geovetenskap",
    "geovetenskaper": "geovetenskap",
    "geovetenskaperna": "geovetenskap",
    "geovetenskapernas": "geovetenskap",
    "geovetenskapers": "geovetenskap",
    "geovetenskapliga": "geovetenskaplig",
    "geovetenskapligare": "geovetenskaplig",
    "geovetenskapligares": "geovetenskaplig",
    "geovetenskapligas": "geovetenskaplig",
    "geovetenskapligast": "geovetenskaplig",
    "geovetenskapligaste": "geovetenskaplig",
    "geovetenskapligastes": "geovetenskaplig",
    "geovetenskapligasts": "geovetenskaplig",
    "geovetenskaplige": "geovetenskaplig",
    "geovetenskapliges": "geovetenskaplig",
    "geovetenskapligs": "geovetenskaplig",
    "geovetenskapligt": "geovetenskaplig",
    "geovetenskapligts": "geovetenskaplig",
    "geovetenskaps": "geovetenskap",
    "geovärmen": "geovärme",
    "geovärmens": "geovärme",
    "geovärmes": "geovärme",
    "geparden": "gepard",
    "gepardens": "gepard",
    "geparder": "gepard",
    "geparderna": "gepard",
    "gepardernas": "gepard",
    "geparders": "gepard",
    "gepards": "gepard",
    "gepäcket": "gepäck",
    "gepäckets": "gepäck",
    "gepäcks": "gepäck",
    "ger": "ge",
    "geranien": "geranium",
    "geraniens": "geranium",
    "geranier": "geranium",
    "geranierna": "geranium",
    "geraniernas": "geranium",
    "geraniers": "geranium",
    "geraniums": "geranium",
    "geriatrien": "geriatri",
    "geriatriens": "geriatri",
    "geriatriken": "geriatrik",
    "geriatrikens": "geriatrik",
    "geriatriks": "geriatrik",
    "geriatrin": "geriatri",
    "geriatrins": "geriatri",
    "geriatris": "geriatri",
    "geriatriska": "geriatrisk",
    "geriatriskare": "geriatrisk",
    "geriatriskares": "geriatrisk",
    "geriatriskas": "geriatrisk",
    "geriatriskast": "geriatrisk",
    "geriatriskaste": "geriatrisk",
    "geriatriskastes": "geriatrisk",
    "geriatriskasts": "geriatrisk",
    "geriatriske": "geriatrisk",
    "geriatriskes": "geriatrisk",
    "geriatrisks": "geriatrisk",
    "geriatriskt": "geriatrisk",
    "geriatriskts": "geriatrisk",
    "geridonen": "geridon",
    "geridonens": "geridon",
    "geridoner": "geridon",
    "geridonerna": "geridon",
    "geridonernas": "geridon",
    "geridoners": "geridon",
    "geridongen": "geridong",
    "geridongens": "geridong",
    "geridonger": "geridong",
    "geridongerna": "geridong",
    "geridongernas": "geridong",
    "geridongers": "geridong",
    "geridongs": "geridong",
    "geridons": "geridon",
    "gerillaledar": "gerillaledare",
    "gerillaledaren": "gerillaledare",
    "gerillaledarens": "gerillaledare",
    "gerillaledares": "gerillaledare",
    "gerillaledarna": "gerillaledare",
    "gerillaledarnas": "gerillaledare",
    "gerillan": "gerilla",
    "gerillans": "gerilla",
    "gerillas": "gerilla",
    "gerillaveteranen": "gerillaveteran",
    "gerillaveteranens": "gerillaveteran",
    "gerillaveteraner": "gerillaveteran",
    "gerillaveteranerna": "gerillaveteran",
    "gerillaveteranernas": "gerillaveteran",
    "gerillaveteraners": "gerillaveteran",
    "gerillaveterans": "gerillaveteran",
    "gerillor": "gerilla",
    "gerillorna": "gerilla",
    "gerillornas": "gerilla",
    "gerillors": "gerilla",
    "geringar": "gering",
    "geringarna": "gering",
    "geringarnas": "gering",
    "geringars": "gering",
    "geringen": "gering",
    "geringens": "gering",
    "gerings": "gering",
    "geringssågar": "geringssåg",
    "geringssågarna": "geringssåg",
    "geringssågarnas": "geringssåg",
    "geringssågars": "geringssåg",
    "geringssågen": "geringssåg",
    "geringssågens": "geringssåg",
    "geringssågs": "geringssåg",
    "germanen": "german",
    "germanens": "german",
    "germaner": "german",
    "germanerna": "german",
    "germanernas": "german",
    "germaners": "german",
    "germanfolken": "germanfolk",
    "germanfolkens": "germanfolk",
    "germanfolket": "germanfolk",
    "germanfolkets": "germanfolk",
    "germanfolks": "germanfolk",
    "germaniet": "germanium",
    "germaniets": "germanium",
    "germaniserad": "germanisera",
    "germaniserade": "germanisera",
    "germaniserades": "germanisera",
    "germaniserads": "germanisera",
    "germaniserande": "germanisera",
    "germaniseranden": "germaniserande",
    "germaniserandena": "germaniserande",
    "germaniserandenas": "germaniserande",
    "germaniserandens": "germaniserande",
    "germaniserandes": "germaniserande",
    "germaniserandet": "germaniserande",
    "germaniserandets": "germaniserande",
    "germaniserar": "germanisera",
    "germaniseras": "germanisera",
    "germaniserat": "germanisera",
    "germaniserats": "germanisera",
    "germaniserbara": "germaniserbar",
    "germaniserbarare": "germaniserbar",
    "germaniserbarares": "germaniserbar",
    "germaniserbaras": "germaniserbar",
    "germaniserbarast": "germaniserbar",
    "germaniserbaraste": "germaniserbar",
    "germaniserbarastes": "germaniserbar",
    "germaniserbarasts": "germaniserbar",
    "germaniserbare": "germaniserbar",
    "germaniserbares": "germaniserbar",
    "germaniserbarheten": "germaniserbarhet",
    "germaniserbarhetens": "germaniserbarhet",
    "germaniserbarhets": "germaniserbarhet",
    "germaniserbars": "germaniserbar",
    "germaniserbart": "germaniserbar",
    "germaniserbarts": "germaniserbar",
    "germaniseringar": "germanisering",
    "germaniseringarna": "germanisering",
    "germaniseringarnas": "germanisering",
    "germaniseringars": "germanisering",
    "germaniseringen": "germanisering",
    "germaniseringens": "germanisering",
    "germaniserings": "germanisering",
    "germanismen": "germanism",
    "germanismens": "germanism",
    "germanismer": "germanism",
    "germanismerna": "germanism",
    "germanismernas": "germanism",
    "germanismers": "germanism",
    "germanisms": "germanism",
    "germanisten": "germanist",
    "germanistens": "germanist",
    "germanister": "germanist",
    "germanisterna": "germanist",
    "germanisternas": "germanist",
    "germanisters": "germanist",
    "germanistiken": "germanistik",
    "germanistikens": "germanistik",
    "germanistiks": "germanistik",
    "germanistiska": "germanistisk",
    "germanistiskare": "germanistisk",
    "germanistiskares": "germanistisk",
    "germanistiskas": "germanistisk",
    "germanistiskast": "germanistisk",
    "germanistiskaste": "germanistisk",
    "germanistiskastes": "germanistisk",
    "germanistiskasts": "germanistisk",
    "germanistiske": "germanistisk",
    "germanistiskes": "germanistisk",
    "germanistisks": "germanistisk",
    "germanistiskt": "germanistisk",
    "germanistiskts": "germanistisk",
    "germanists": "germanist",
    "germaniumet": "germanium",
    "germaniumets": "germanium",
    "germaniums": "germanium",
    "germankrigar": "germankrigare",
    "germankrigaren": "germankrigare",
    "germankrigarens": "germankrigare",
    "germankrigares": "germankrigare",
    "germankrigarna": "germankrigare",
    "germankrigarnas": "germankrigare",
    "germans": "german",
    "germanska": "germansk",
    "germanskare": "germansk",
    "germanskares": "germansk",
    "germanskas": "germansk",
    "germanskast": "germansk",
    "germanskaste": "germansk",
    "germanskastes": "germansk",
    "germanskasts": "germansk",
    "germanske": "germansk",
    "germanskes": "germansk",
    "germansks": "germansk",
    "germanskt": "germansk",
    "germanskts": "germansk",
    "germanstammar": "germanstam",
    "germanstammarna": "germanstam",
    "germanstammarnas": "germanstam",
    "germanstammars": "germanstam",
    "germanstammen": "germanstam",
    "germanstammens": "germanstam",
    "germanstams": "germanstam",
    "gerontologien": "gerontologi",
    "gerontologiens": "gerontologi",
    "gerontologin": "gerontologi",
    "gerontologins": "gerontologi",
    "gerontologis": "gerontologi",
    "gerontologiska": "gerontologisk",
    "gerontologiskare": "gerontologisk",
    "gerontologiskares": "gerontologisk",
    "gerontologiskas": "gerontologisk",
    "gerontologiskast": "gerontologisk",
    "gerontologiskaste": "gerontologisk",
    "gerontologiskastes": "gerontologisk",
    "gerontologiskasts": "gerontologisk",
    "gerontologiske": "gerontologisk",
    "gerontologiskes": "gerontologisk",
    "gerontologisks": "gerontologisk",
    "gerontologiskt": "gerontologisk",
    "gerontologiskts": "gerontologisk",
    "gersar": "gers",
    "gersarna": "gers",
    "gersarnas": "gers",
    "gersars": "gers",
    "gersen": "gers",
    "gersens": "gers",
    "gerundier": "gerundium",
    "gerundierna": "gerundium",
    "gerundiernas": "gerundium",
    "gerundiers": "gerundium",
    "gerundiumet": "gerundium",
    "gerundiumets": "gerundium",
    "gerundiums": "gerundium",
    "gerundiver": "gerundivum",
    "gerundiverna": "gerundivum",
    "gerundivernas": "gerundivum",
    "gerundivers": "gerundivum",
    "gerundivumet": "gerundivum",
    "gerundivumets": "gerundivum",
    "gerundivums": "gerundivum",
    "gesanten": "gesant",
    "gesantens": "gesant",
    "gesanter": "gesant",
    "gesanterna": "gesant",
    "gesanternas": "gesant",
    "gesanters": "gesant",
    "gesants": "gesant",
    "geschäften": "geschäft",
    "geschäftens": "geschäft",
    "geschäftet": "geschäft",
    "geschäftets": "geschäft",
    "geschäfts": "geschäft",
    "gesimsbåg": "gesimsbåge",
    "gesimsbågar": "gesimsbåge",
    "gesimsbågarna": "gesimsbåge",
    "gesimsbågarnas": "gesimsbåge",
    "gesimsbågars": "gesimsbåge",
    "gesimsbågen": "gesimsbåge",
    "gesimsbågens": "gesimsbåge",
    "gesimsbåges": "gesimsbåge",
    "gesimsbågs": "gesimsbåge",
    "gesimsen": "gesims",
    "gesimsens": "gesims",
    "gesimser": "gesims",
    "gesimserna": "gesims",
    "gesimsernas": "gesims",
    "gesimsers": "gesims",
    "gesimslisten": "gesimslist",
    "gesimslistens": "gesimslist",
    "gesimslister": "gesimslist",
    "gesimslisterna": "gesimslist",
    "gesimslisternas": "gesimslist",
    "gesimslisters": "gesimslist",
    "gesimslists": "gesimslist",
    "gestalt": "gestalta",
    "gestaltad": "gestalta",
    "gestaltade": "gestalta",
    "gestaltades": "gestalta",
    "gestaltads": "gestalta",
    "gestaltande": "gestalta",
    "gestaltanden": "gestaltande",
    "gestaltandena": "gestaltande",
    "gestaltandenas": "gestaltande",
    "gestaltandens": "gestaltande",
    "gestaltandes": "gestaltande",
    "gestaltandet": "gestaltande",
    "gestaltandets": "gestaltande",
    "gestaltar": "gestalta",
    "gestaltas": "gestalta",
    "gestaltat": "gestalta",
    "gestaltats": "gestalta",
    "gestalten": "gestalt",
    "gestaltens": "gestalt",
    "gestalter": "gestalt",
    "gestalterna": "gestalt",
    "gestalternas": "gestalt",
    "gestalters": "gestalt",
    "gestaltningar": "gestaltning",
    "gestaltningarna": "gestaltning",
    "gestaltningarnas": "gestaltning",
    "gestaltningars": "gestaltning",
    "gestaltningen": "gestaltning",
    "gestaltningens": "gestaltning",
    "gestaltnings": "gestaltning",
    "gestaltningsmässiga": "gestaltningsmässig",
    "gestaltningsmässigare": "gestaltningsmässig",
    "gestaltningsmässigares": "gestaltningsmässig",
    "gestaltningsmässigas": "gestaltningsmässig",
    "gestaltningsmässigast": "gestaltningsmässig",
    "gestaltningsmässigaste": "gestaltningsmässig",
    "gestaltningsmässigastes": "gestaltningsmässig",
    "gestaltningsmässigasts": "gestaltningsmässig",
    "gestaltningsmässige": "gestaltningsmässig",
    "gestaltningsmässiges": "gestaltningsmässig",
    "gestaltningsmässigs": "gestaltningsmässig",
    "gestaltningsmässigt": "gestaltningsmässig",
    "gestaltningsmässigts": "gestaltningsmässig",
    "gestaltpsykologien": "gestaltpsykologi",
    "gestaltpsykologiens": "gestaltpsykologi",
    "gestaltpsykologin": "gestaltpsykologi",
    "gestaltpsykologins": "gestaltpsykologi",
    "gestaltpsykologis": "gestaltpsykologi",
    "gestalts": "gestalt",
    "gesten": "gest",
    "gestens": "gest",
    "gester": "gest",
    "gesterna": "gest",
    "gesternas": "gest",
    "gesters": "gest",
    "gestiken": "gestik",
    "gestikens": "gestik",
    "gestiks": "gestik",
    "gestikulationen": "gestikulation",
    "gestikulationens": "gestikulation",
    "gestikulationer": "gestikulation",
    "gestikulationerna": "gestikulation",
    "gestikulationernas": "gestikulation",
    "gestikulationers": "gestikulation",
    "gestikulations": "gestikulation",
    "gestikulerade": "gestikulera",
    "gestikulerades": "gestikulera",
    "gestikulerande": "gestikulera",
    "gestikuleranden": "gestikulerande",
    "gestikulerandena": "gestikulerande",
    "gestikulerandenas": "gestikulerande",
    "gestikulerandens": "gestikulerande",
    "gestikulerandes": "gestikulerande",
    "gestikulerandet": "gestikulerande",
    "gestikulerandets": "gestikulerande",
    "gestikulerar": "gestikulera",
    "gestikuleras": "gestikulera",
    "gestikulerat": "gestikulera",
    "gestikulerats": "gestikulera",
    "gestikuleringar": "gestikulering",
    "gestikuleringarna": "gestikulering",
    "gestikuleringarnas": "gestikulering",
    "gestikuleringars": "gestikulering",
    "gestikuleringen": "gestikulering",
    "gestikuleringens": "gestikulering",
    "gestikulerings": "gestikulering",
    "gests": "gest",
    "gesällbreven": "gesällbrev",
    "gesällbrevens": "gesällbrev",
    "gesällbrevet": "gesällbrev",
    "gesällbrevets": "gesällbrev",
    "gesällbrevs": "gesällbrev",
    "gesällen": "gesäll",
    "gesällens": "gesäll",
    "gesäller": "gesäll",
    "gesällerna": "gesäll",
    "gesällernas": "gesäll",
    "gesällers": "gesäll",
    "gesällproven": "gesällprov",
    "gesällprovens": "gesällprov",
    "gesällprovet": "gesällprov",
    "gesällprovets": "gesällprov",
    "gesällprovs": "gesällprov",
    "gesälls": "gesäll",
    "gesällvandringar": "gesällvandring",
    "gesällvandringarna": "gesällvandring",
    "gesällvandringarnas": "gesällvandring",
    "gesällvandringars": "gesällvandring",
    "gesällvandringen": "gesällvandring",
    "gesällvandringens": "gesällvandring",
    "gesällvandrings": "gesällvandring",
    "getabockar": "getabock",
    "getabockarna": "getabock",
    "getabockarnas": "getabock",
    "getabockars": "getabock",
    "getabocken": "getabock",
    "getabockens": "getabock",
    "getabocks": "getabock",
    "getapeln": "getapel",
    "getapelns": "getapel",
    "getapels": "getapel",
    "getaplar": "getapel",
    "getaplarna": "getapel",
    "getaplarnas": "getapel",
    "getaplars": "getapel",
    "geten": "get",
    "getens": "get",
    "getfotar": "getfot",
    "getfotarna": "getfot",
    "getfotarnas": "getfot",
    "getfotars": "getfot",
    "getfoten": "getfot",
    "getfotens": "getfot",
    "getfots": "getfot",
    "getfötter": "getfot",
    "getfötterna": "getfot",
    "getfötternas": "getfot",
    "getfötters": "getfot",
    "getingar": "geting",
    "getingarna": "geting",
    "getingarnas": "geting",
    "getingars": "geting",
    "getingbill": "getingbilla",
    "getingbillan": "getingbilla",
    "getingbillans": "getingbilla",
    "getingbillas": "getingbilla",
    "getingbille": "getingbilla",
    "getingbillor": "getingbilla",
    "getingbillorna": "getingbilla",
    "getingbillornas": "getingbilla",
    "getingbillors": "getingbilla",
    "getingbills": "getingbilla",
    "getingboen": "getingbo",
    "getingboens": "getingbo",
    "getingboet": "getingbo",
    "getingboets": "getingbo",
    "getingbon": "getingbo",
    "getingbona": "getingbo",
    "getingbonas": "getingbo",
    "getingbons": "getingbo",
    "getingbos": "getingbo",
    "getingbot": "getingbo",
    "getingbots": "getingbo",
    "getingen": "geting",
    "getingens": "geting",
    "getingmidjan": "getingmidja",
    "getingmidjans": "getingmidja",
    "getingmidjas": "getingmidja",
    "getingmidje": "getingmidja",
    "getingmidjor": "getingmidja",
    "getingmidjorna": "getingmidja",
    "getingmidjornas": "getingmidja",
    "getingmidjors": "getingmidja",
    "getings": "geting",
    "getingsticken": "getingstick",
    "getingstickens": "getingstick",
    "getingsticket": "getingstick",
    "getingstickets": "getingstick",
    "getingsticks": "getingstick",
    "getingsvärmar": "getingsvärm",
    "getingsvärmarna": "getingsvärm",
    "getingsvärmarnas": "getingsvärm",
    "getingsvärmars": "getingsvärm",
    "getingsvärmen": "getingsvärm",
    "getingsvärmens": "getingsvärm",
    "getingsvärms": "getingsvärm",
    "getmjölken": "getmjölk",
    "getmjölkens": "getmjölk",
    "getmjölks": "getmjölk",
    "getmjölksostar": "getmjölksost",
    "getmjölksostarna": "getmjölksost",
    "getmjölksostarnas": "getmjölksost",
    "getmjölksostars": "getmjölksost",
    "getmjölksosten": "getmjölksost",
    "getmjölksostens": "getmjölksost",
    "getmjölksosts": "getmjölksost",
    "getostar": "getost",
    "getostarna": "getost",
    "getostarnas": "getost",
    "getostars": "getost",
    "getosten": "getost",
    "getostens": "getost",
    "getosts": "getost",
    "getporsen": "getpors",
    "getporsens": "getpors",
    "getramsen": "getrams",
    "getramsens": "getrams",
    "gets": "get",
    "getskinnen": "getskinn",
    "getskinnens": "getskinn",
    "getskinnet": "getskinn",
    "getskinnets": "getskinn",
    "getskinns": "getskinn",
    "getskäggen": "getskägg",
    "getskäggens": "getskägg",
    "getskägget": "getskägg",
    "getskäggets": "getskägg",
    "getskäggs": "getskägg",
    "gett": "ge",
    "getter": "get",
    "getterna": "get",
    "getternas": "get",
    "getters": "get",
    "getton": "getto",
    "gettona": "getto",
    "gettonas": "getto",
    "gettons": "getto",
    "gettos": "getto",
    "gettot": "getto",
    "gettots": "getto",
    "getts": "ge",
    "getväpplingar": "getväppling",
    "getväpplingarna": "getväppling",
    "getväpplingarnas": "getväppling",
    "getväpplingars": "getväppling",
    "getväpplingen": "getväppling",
    "getväpplingens": "getväppling",
    "getväpplings": "getväppling",
    "gevaldigern": "gevaldiger",
    "gevaldigerna": "gevaldiger",
    "gevaldigernas": "gevaldiger",
    "gevaldigerns": "gevaldiger",
    "gevaldigers": "gevaldiger",
    "gevären": "gevär",
    "gevärens": "gevär",
    "geväret": "gevär",
    "gevärets": "gevär",
    "gevärs": "gevär",
    "gevärsfaktorier": "gevärsfaktori",
    "gevärsfaktorierna": "gevärsfaktori",
    "gevärsfaktoriernas": "gevärsfaktori",
    "gevärsfaktoriers": "gevärsfaktori",
    "gevärsfaktoriet": "gevärsfaktori",
    "gevärsfaktoriets": "gevärsfaktori",
    "gevärsfaktoris": "gevärsfaktori",
    "gevärsfaktorit": "gevärsfaktori",
    "gevärsfaktorits": "gevärsfaktori",
    "gevärsgranaten": "gevärsgranat",
    "gevärsgranatens": "gevärsgranat",
    "gevärsgranater": "gevärsgranat",
    "gevärsgranaterna": "gevärsgranat",
    "gevärsgranaternas": "gevärsgranat",
    "gevärsgranaters": "gevärsgranat",
    "gevärsgranats": "gevärsgranat",
    "gevärskolvar": "gevärskolv",
    "gevärskolvarna": "gevärskolv",
    "gevärskolvarnas": "gevärskolv",
    "gevärskolvars": "gevärskolv",
    "gevärskolven": "gevärskolv",
    "gevärskolvens": "gevärskolv",
    "gevärskolvs": "gevärskolv",
    "gevärskompanier": "gevärskompani",
    "gevärskompanierna": "gevärskompani",
    "gevärskompaniernas": "gevärskompani",
    "gevärskompaniers": "gevärskompani",
    "gevärskompaniet": "gevärskompani",
    "gevärskompaniets": "gevärskompani",
    "gevärskompanis": "gevärskompani",
    "gevärskompanit": "gevärskompani",
    "gevärskompanits": "gevärskompani",
    "gevärskul": "gevärskula",
    "gevärskulan": "gevärskula",
    "gevärskulans": "gevärskula",
    "gevärskulas": "gevärskula",
    "gevärskule": "gevärskula",
    "gevärskulor": "gevärskula",
    "gevärskulorna": "gevärskula",
    "gevärskulornas": "gevärskula",
    "gevärskulors": "gevärskula",
    "gevärskuls": "gevärskula",
    "gevärsmynningar": "gevärsmynning",
    "gevärsmynningarna": "gevärsmynning",
    "gevärsmynningarnas": "gevärsmynning",
    "gevärsmynningars": "gevärsmynning",
    "gevärsmynningen": "gevärsmynning",
    "gevärsmynningens": "gevärsmynning",
    "gevärsmynnings": "gevärsmynning",
    "gevärsoljan": "gevärsolja",
    "gevärsoljans": "gevärsolja",
    "gevärsoljas": "gevärsolja",
    "gevärsolje": "gevärsolja",
    "gevärspatronen": "gevärspatron",
    "gevärspatronens": "gevärspatron",
    "gevärspatroner": "gevärspatron",
    "gevärspatronerna": "gevärspatron",
    "gevärspatronernas": "gevärspatron",
    "gevärspatroners": "gevärspatron",
    "gevärspatrons": "gevärspatron",
    "gevärspip": "gevärspipa",
    "gevärspipan": "gevärspipa",
    "gevärspipans": "gevärspipa",
    "gevärspipas": "gevärspipa",
    "gevärspipe": "gevärspipa",
    "gevärspipor": "gevärspipa",
    "gevärspiporna": "gevärspipa",
    "gevärspipornas": "gevärspipa",
    "gevärspipors": "gevärspipa",
    "gevärspips": "gevärspipa",
    "gevärsposten": "gevärspost",
    "gevärspostens": "gevärspost",
    "gevärsposter": "gevärspost",
    "gevärsposterna": "gevärspost",
    "gevärsposternas": "gevärspost",
    "gevärsposters": "gevärspost",
    "gevärsposts": "gevärspost",
    "gevärssikten": "gevärssikte",
    "gevärssiktena": "gevärssikte",
    "gevärssiktenas": "gevärssikte",
    "gevärssiktens": "gevärssikte",
    "gevärssiktes": "gevärssikte",
    "gevärssiktet": "gevärssikte",
    "gevärssiktets": "gevärssikte",
    "gevärssmeden": "gevärssmed",
    "gevärssmedens": "gevärssmed",
    "gevärssmeder": "gevärssmed",
    "gevärssmederna": "gevärssmed",
    "gevärssmedernas": "gevärssmed",
    "gevärssmeders": "gevärssmed",
    "gevärssmeds": "gevärssmed",
    "gevärssmiden": "gevärssmide",
    "gevärssmidena": "gevärssmide",
    "gevärssmidenas": "gevärssmide",
    "gevärssmidens": "gevärssmide",
    "gevärssmides": "gevärssmide",
    "gevärssmidet": "gevärssmide",
    "gevärssmidets": "gevärssmide",
    "gevärsstockar": "gevärsstock",
    "gevärsstockarna": "gevärsstock",
    "gevärsstockarnas": "gevärsstock",
    "gevärsstockars": "gevärsstock",
    "gevärsstocken": "gevärsstock",
    "gevärsstockens": "gevärsstock",
    "gevärsstocks": "gevärsstock",
    "gevärsväsk": "gevärsväska",
    "gevärsväskan": "gevärsväska",
    "gevärsväskans": "gevärsväska",
    "gevärsväskas": "gevärsväska",
    "gevärsväske": "gevärsväska",
    "gevärsväskor": "gevärsväska",
    "gevärsväskorna": "gevärsväska",
    "gevärsväskornas": "gevärsväska",
    "gevärsväskors": "gevärsväska",
    "ghananen": "ghanan",
    "ghananens": "ghanan",
    "ghananer": "ghanan",
    "ghananerna": "ghanan",
    "ghananernas": "ghanan",
    "ghananers": "ghanan",
    "ghanans": "ghanan",
    "ghananska": "ghanansk",
    "ghananskan": "ghananska",
    "ghananskans": "ghananska",
    "ghananskare": "ghanansk",
    "ghananskares": "ghanansk",
    "ghananskas": "ghananska",
    "ghananskast": "ghanansk",
    "ghananskaste": "ghanansk",
    "ghananskastes": "ghanansk",
    "ghananskasts": "ghanansk",
    "ghananske": "ghananska",
    "ghananskes": "ghanansk",
    "ghananskor": "ghananska",
    "ghananskorna": "ghananska",
    "ghananskornas": "ghananska",
    "ghananskors": "ghananska",
    "ghanansks": "ghanansk",
    "ghananskt": "ghanansk",
    "ghananskts": "ghanansk",
    "ghanesen": "ghanes",
    "ghanesens": "ghanes",
    "ghaneser": "ghanes",
    "ghaneserna": "ghanes",
    "ghanesernas": "ghanes",
    "ghanesers": "ghanes",
    "ghanesiska": "ghanesisk",
    "ghanesiskare": "ghanesisk",
    "ghanesiskares": "ghanesisk",
    "ghanesiskas": "ghanesisk",
    "ghanesiskast": "ghanesisk",
    "ghanesiskaste": "ghanesisk",
    "ghanesiskastes": "ghanesisk",
    "ghanesiskasts": "ghanesisk",
    "ghanesiske": "ghanesisk",
    "ghanesiskes": "ghanesisk",
    "ghanesisks": "ghanesisk",
    "ghanesiskt": "ghanesisk",
    "ghanesiskts": "ghanesisk",
    "ghaselen": "ghasel",
    "ghaselens": "ghasel",
    "ghaseler": "ghasel",
    "ghaselerna": "ghasel",
    "ghaselernas": "ghasel",
    "ghaselers": "ghasel",
    "ghasels": "ghasel",
    "ghetton": "ghetto",
    "ghettona": "ghetto",
    "ghettonas": "ghetto",
    "ghettons": "ghetto",
    "ghettos": "ghetto",
    "ghettot": "ghetto",
    "ghettots": "ghetto",
    "ghost-writern": "ghost-writer",
    "ghost-writerns": "ghost-writer",
    "ghost-writers": "ghost-writer",
    "ghost-writersarna": "ghost-writer",
    "ghost-writersarnas": "ghost-writer",
    "ghost-writersen": "ghost-writer",
    "ghost-writersens": "ghost-writer",
    "gibbonen": "gibbon",
    "gibbonens": "gibbon",
    "gibboner": "gibbon",
    "gibbonerna": "gibbon",
    "gibbonernas": "gibbon",
    "gibboners": "gibbon",
    "gibbons": "gibbon",
    "gick": "gå",
    "gicks": "gå",
    "giffeln": "giffel",
    "giffelns": "giffel",
    "giffels": "giffel",
    "gifflar": "giffel",
    "gifflarna": "giffel",
    "gifflarnas": "giffel",
    "gifflars": "giffel",
    "gifta": "gift",
    "giftapparaten": "giftapparat",
    "giftapparatens": "giftapparat",
    "giftapparater": "giftapparat",
    "giftapparaterna": "giftapparat",
    "giftapparaternas": "giftapparat",
    "giftapparaters": "giftapparat",
    "giftapparats": "giftapparat",
    "giftare": "gift",
    "giftares": "gift",
    "giftas": "gift",
    "giftast": "gift",
    "giftaste": "gift",
    "giftastes": "gift",
    "giftasts": "gift",
    "giftasvuxenheten": "giftasvuxenhet",
    "giftasvuxenhetens": "giftasvuxenhet",
    "giftasvuxenhets": "giftasvuxenhet",
    "giftasvuxens": "giftasvuxen",
    "giftasvuxet": "giftasvuxen",
    "giftasvuxets": "giftasvuxen",
    "giftasvuxna": "giftasvuxen",
    "giftasvuxnare": "giftasvuxen",
    "giftasvuxnares": "giftasvuxen",
    "giftasvuxnas": "giftasvuxen",
    "giftasvuxnast": "giftasvuxen",
    "giftasvuxnaste": "giftasvuxen",
    "giftasvuxnastes": "giftasvuxen",
    "giftasvuxnasts": "giftasvuxen",
    "giftasvuxne": "giftasvuxen",
    "giftasvuxnes": "giftasvuxen",
    "giftavdunstningar": "giftavdunstning",
    "giftavdunstningarna": "giftavdunstning",
    "giftavdunstningarnas": "giftavdunstning",
    "giftavdunstningars": "giftavdunstning",
    "giftavdunstningen": "giftavdunstning",
    "giftavdunstningens": "giftavdunstning",
    "giftavdunstnings": "giftavdunstning",
    "giftbetningar": "giftbetning",
    "giftbetningarna": "giftbetning",
    "giftbetningarnas": "giftbetning",
    "giftbetningars": "giftbetning",
    "giftbetningen": "giftbetning",
    "giftbetningens": "giftbetning",
    "giftbetnings": "giftbetning",
    "giftblandar": "giftblandare",
    "giftblandaren": "giftblandare",
    "giftblandarens": "giftblandare",
    "giftblandares": "giftblandare",
    "giftblandarna": "giftblandare",
    "giftblandarnas": "giftblandare",
    "giftblås": "giftblåsa",
    "giftblåsan": "giftblåsa",
    "giftblåsans": "giftblåsa",
    "giftblåsas": "giftblåsa",
    "giftblåse": "giftblåsa",
    "giftblåsor": "giftblåsa",
    "giftblåsorna": "giftblåsa",
    "giftblåsornas": "giftblåsa",
    "giftblåsors": "giftblåsa",
    "giftboken": "giftbok",
    "giftbokens": "giftbok",
    "giftboks": "giftbok",
    "giftbägar": "giftbägare",
    "giftbägaren": "giftbägare",
    "giftbägarens": "giftbägare",
    "giftbägares": "giftbägare",
    "giftbägarna": "giftbägare",
    "giftbägarnas": "giftbägare",
    "giftböcker": "giftbok",
    "giftböckerna": "giftbok",
    "giftböckernas": "giftbok",
    "giftböckers": "giftbok",
    "gifte": "gift",
    "giften": "gifte",
    "giftena": "gifte",
    "giftenas": "gifte",
    "giftens": "gifte",
    "gifter": "gift",
    "giftermålen": "giftermål",
    "giftermålens": "giftermål",
    "giftermålet": "giftermål",
    "giftermålets": "giftermål",
    "giftermåls": "giftermål",
    "giftermålsbalkar": "giftermålsbalk",
    "giftermålsbalkarna": "giftermålsbalk",
    "giftermålsbalkarnas": "giftermålsbalk",
    "giftermålsbalkars": "giftermålsbalk",
    "giftermålsbalken": "giftermålsbalk",
    "giftermålsbalkens": "giftermålsbalk",
    "giftermålsbalks": "giftermålsbalk",
    "gifterna": "gift",
    "gifternas": "gift",
    "gifters": "gift",
    "giftes": "gifte",
    "giftet": "gifte",
    "giftets": "gifte",
    "giftfria": "giftfri",
    "giftfriare": "giftfri",
    "giftfriares": "giftfri",
    "giftfrias": "giftfri",
    "giftfriast": "giftfri",
    "giftfriaste": "giftfri",
    "giftfriastes": "giftfri",
    "giftfriasts": "giftfri",
    "giftfrie": "giftfri",
    "giftfries": "giftfri",
    "giftfris": "giftfri",
    "giftfritt": "giftfri",
    "giftfritts": "giftfri",
    "giftgasen": "giftgas",
    "giftgasens": "giftgas",
    "giftgaser": "giftgas",
    "giftgaserna": "giftgas",
    "giftgasernas": "giftgas",
    "giftgasers": "giftgas",
    "giftgröna": "giftgrön",
    "giftgrönare": "giftgrön",
    "giftgrönares": "giftgrön",
    "giftgrönas": "giftgrön",
    "giftgrönast": "giftgrön",
    "giftgrönaste": "giftgrön",
    "giftgrönastes": "giftgrön",
    "giftgrönasts": "giftgrön",
    "giftgröne": "giftgrön",
    "giftgrönes": "giftgrön",
    "giftgröns": "giftgrön",
    "giftgrönt": "giftgrön",
    "giftgrönts": "giftgrön",
    "gifthalten": "gifthalt",
    "gifthaltens": "gifthalt",
    "gifthalter": "gifthalt",
    "gifthalterna": "gifthalt",
    "gifthalternas": "gifthalt",
    "gifthalters": "gifthalt",
    "gifthalts": "gifthalt",
    "giftiga": "giftig",
    "giftigare": "giftig",
    "giftigares": "giftig",
    "giftigas": "giftig",
    "giftigast": "giftig",
    "giftigaste": "giftig",
    "giftigastes": "giftig",
    "giftigasts": "giftig",
    "giftige": "giftig",
    "giftiges": "giftig",
    "giftigheten": "giftighet",
    "giftighetens": "giftighet",
    "giftigheter": "giftighet",
    "giftigheterna": "giftighet",
    "giftigheternas": "giftighet",
    "giftigheters": "giftighet",
    "giftighets": "giftighet",
    "giftigs": "giftig",
    "giftigt": "giftig",
    "giftigts": "giftig",
    "giftinjektionen": "giftinjektion",
    "giftinjektionens": "giftinjektion",
    "giftinjektioner": "giftinjektion",
    "giftinjektionerna": "giftinjektion",
    "giftinjektionernas": "giftinjektion",
    "giftinjektioners": "giftinjektion",
    "giftinjektions": "giftinjektion",
    "giftkapseln": "giftkapsel",
    "giftkapselns": "giftkapsel",
    "giftkapsels": "giftkapsel",
    "giftkapslar": "giftkapsel",
    "giftkapslarna": "giftkapsel",
    "giftkapslarnas": "giftkapsel",
    "giftkapslars": "giftkapsel",
    "giftkörteln": "giftkörtel",
    "giftkörtelns": "giftkörtel",
    "giftkörtels": "giftkörtel",
    "giftkörtlar": "giftkörtel",
    "giftkörtlarna": "giftkörtel",
    "giftkörtlarnas": "giftkörtel",
    "giftkörtlars": "giftkörtel",
    "giftläran": "giftlära",
    "giftlärans": "giftlära",
    "giftläras": "giftlära",
    "giftmolnen": "giftmoln",
    "giftmolnens": "giftmoln",
    "giftmolnet": "giftmoln",
    "giftmolnets": "giftmoln",
    "giftmolns": "giftmoln",
    "giftmorden": "giftmord",
    "giftmordens": "giftmord",
    "giftmordet": "giftmord",
    "giftmordets": "giftmord",
    "giftmords": "giftmord",
    "giftmängden": "giftmängd",
    "giftmängdens": "giftmängd",
    "giftmängder": "giftmängd",
    "giftmängderna": "giftmängd",
    "giftmängdernas": "giftmängd",
    "giftmängders": "giftmängd",
    "giftmängds": "giftmängd",
    "giftomannen": "giftoman",
    "giftomannens": "giftoman",
    "giftomans": "giftoman",
    "giftomän": "giftoman",
    "giftomännen": "giftoman",
    "giftomännens": "giftoman",
    "giftomäns": "giftoman",
    "giftormar": "giftorm",
    "giftormarna": "giftorm",
    "giftormarnas": "giftorm",
    "giftormars": "giftorm",
    "giftormen": "giftorm",
    "giftormens": "giftorm",
    "giftorms": "giftorm",
    "giftorätten": "giftorätt",
    "giftorättens": "giftorätt",
    "giftorätts": "giftorätt",
    "gifts": "gifte",
    "giftspindeln": "giftspindel",
    "giftspindelns": "giftspindel",
    "giftspindels": "giftspindel",
    "giftspindlar": "giftspindel",
    "giftspindlarna": "giftspindel",
    "giftspindlarnas": "giftspindel",
    "giftspindlars": "giftspindel",
    "giftsprut": "giftspruta",
    "giftsprutan": "giftspruta",
    "giftsprutans": "giftspruta",
    "giftsprutas": "giftspruta",
    "giftsprute": "giftspruta",
    "giftsprutor": "giftspruta",
    "giftsprutorna": "giftspruta",
    "giftsprutornas": "giftspruta",
    "giftsprutors": "giftspruta",
    "giftspruts": "giftspruta",
    "giftstadgan": "giftstadga",
    "giftstadgans": "giftstadga",
    "giftstadgas": "giftstadga",
    "giftstadge": "giftstadga",
    "giftstadgor": "giftstadga",
    "giftstadgorna": "giftstadga",
    "giftstadgornas": "giftstadga",
    "giftstadgors": "giftstadga",
    "gifttaggar": "gifttagg",
    "gifttaggarna": "gifttagg",
    "gifttaggarnas": "gifttagg",
    "gifttaggars": "gifttagg",
    "gifttaggen": "gifttagg",
    "gifttaggens": "gifttagg",
    "gifttaggs": "gifttagg",
    "gifttanden": "gifttand",
    "gifttandens": "gifttand",
    "gifttands": "gifttand",
    "gifttransporten": "gifttransport",
    "gifttransportens": "gifttransport",
    "gifttransporter": "gifttransport",
    "gifttransporterna": "gifttransport",
    "gifttransporternas": "gifttransport",
    "gifttransporters": "gifttransport",
    "gifttransports": "gifttransport",
    "gifttänder": "gifttand",
    "gifttänderna": "gifttand",
    "gifttändernas": "gifttand",
    "gifttänders": "gifttand",
    "giftutsläppen": "giftutsläpp",
    "giftutsläppens": "giftutsläpp",
    "giftutsläppet": "giftutsläpp",
    "giftutsläppets": "giftutsläpp",
    "giftutsläpps": "giftutsläpp",
    "giftverkans": "giftverkan",
    "giftverkningar": "giftverkan",
    "giftverkningarna": "giftverkan",
    "giftverkningarnas": "giftverkan",
    "giftverkningars": "giftverkan",
    "gig": "giga",
    "gigabyten": "gigabyte",
    "gigabytena": "gigabyte",
    "gigabytenas": "gigabyte",
    "gigabytens": "gigabyte",
    "gigabytes": "gigabyte",
    "gigad": "giga",
    "gigade": "giga",
    "gigades": "giga",
    "gigads": "giga",
    "gigan": "giga",
    "gigande": "giga",
    "giganden": "gigande",
    "gigandena": "gigande",
    "gigandenas": "gigande",
    "gigandens": "gigande",
    "gigandes": "gigande",
    "gigandet": "gigande",
    "gigandets": "gigande",
    "gigans": "giga",
    "giganten": "gigant",
    "gigantens": "gigant",
    "giganter": "gigant",
    "giganterna": "gigant",
    "giganternas": "gigant",
    "giganters": "gigant",
    "gigantiska": "gigantisk",
    "gigantiskare": "gigantisk",
    "gigantiskares": "gigantisk",
    "gigantiskas": "gigantisk",
    "gigantiskast": "gigantisk",
    "gigantiskaste": "gigantisk",
    "gigantiskastes": "gigantisk",
    "gigantiskasts": "gigantisk",
    "gigantiske": "gigantisk",
    "gigantiskes": "gigantisk",
    "gigantisks": "gigantisk",
    "gigantiskt": "gigantisk",
    "gigantiskts": "gigantisk",
    "gigants": "gigant",
    "gigar": "giga",
    "gigas": "giga",
    "gigat": "giga",
    "gigatonnen": "gigaton",
    "gigatonnens": "gigaton",
    "gigatonnet": "gigaton",
    "gigatonnets": "gigaton",
    "gigatons": "gigaton",
    "gigats": "giga",
    "gigawatten": "gigawatt",
    "gigawattens": "gigawatt",
    "gigawatts": "gigawatt",
    "gige": "giga",
    "gigen": "gig",
    "gigens": "gig",
    "giget": "gig",
    "gigets": "gig",
    "gigg": "gigga",
    "giggade": "gigga",
    "giggades": "gigga",
    "giggande": "gigga",
    "gigganden": "giggande",
    "giggandena": "giggande",
    "giggandenas": "giggande",
    "giggandens": "giggande",
    "giggandes": "giggande",
    "giggandet": "giggande",
    "giggandets": "giggande",
    "giggar": "gigga",
    "giggarna": "gigg",
    "giggarnas": "gigg",
    "giggars": "gigg",
    "giggas": "gigga",
    "giggat": "gigga",
    "giggats": "gigga",
    "giggen": "gigg",
    "giggens": "gigg",
    "giggs": "gigg",
    "gigolon": "gigolo",
    "gigolons": "gigolo",
    "gigolor": "gigolo",
    "gigolorna": "gigolo",
    "gigolornas": "gigolo",
    "gigolors": "gigolo",
    "gigolos": "gigolo",
    "gigolosen": "gigolo",
    "gigolosens": "gigolo",
    "gigor": "giga",
    "gigorna": "giga",
    "gigornas": "giga",
    "gigors": "giga",
    "gigs": "giga",
    "giguen": "gigue",
    "giguens": "gigue",
    "giguer": "gigue",
    "giguerna": "gigue",
    "giguernas": "gigue",
    "giguers": "gigue",
    "gigues": "gigue",
    "giktbrutenheten": "giktbrutenhet",
    "giktbrutenhetens": "giktbrutenhet",
    "giktbrutenhets": "giktbrutenhet",
    "giktbrutens": "giktbruten",
    "giktbrutet": "giktbruten",
    "giktbrutets": "giktbruten",
    "giktbrutna": "giktbruten",
    "giktbrutnare": "giktbruten",
    "giktbrutnares": "giktbruten",
    "giktbrutnas": "giktbruten",
    "giktbrutnast": "giktbruten",
    "giktbrutnaste": "giktbruten",
    "giktbrutnastes": "giktbruten",
    "giktbrutnasts": "giktbruten",
    "giktbrutne": "giktbruten",
    "giktbrutnes": "giktbruten",
    "gikten": "gikt",
    "giktens": "gikt",
    "giktringar": "giktring",
    "giktringarna": "giktring",
    "giktringarnas": "giktring",
    "giktringars": "giktring",
    "giktringen": "giktring",
    "giktringens": "giktring",
    "giktrings": "giktring",
    "gikts": "gikt",
    "giljade": "gilja",
    "giljades": "gilja",
    "giljande": "gilja",
    "giljanden": "giljande",
    "giljandena": "giljande",
    "giljandenas": "giljande",
    "giljandens": "giljande",
    "giljandes": "giljande",
    "giljandet": "giljande",
    "giljandets": "giljande",
    "giljar": "giljare",
    "giljaren": "giljare",
    "giljarens": "giljare",
    "giljares": "giljare",
    "giljarfärden": "giljarfärd",
    "giljarfärdens": "giljarfärd",
    "giljarfärder": "giljarfärd",
    "giljarfärderna": "giljarfärd",
    "giljarfärdernas": "giljarfärd",
    "giljarfärders": "giljarfärd",
    "giljarfärds": "giljarfärd",
    "giljarna": "giljare",
    "giljarnas": "giljare",
    "giljarstråten": "giljarstråt",
    "giljarstråtens": "giljarstråt",
    "giljarstråts": "giljarstråt",
    "giljas": "gilja",
    "giljat": "gilja",
    "giljats": "gilja",
    "giljotinen": "giljotin",
    "giljotinens": "giljotin",
    "giljotiner": "giljotin",
    "giljotinerad": "giljotinera",
    "giljotinerade": "giljotinera",
    "giljotinerades": "giljotinera",
    "giljotinerads": "giljotinera",
    "giljotinerande": "giljotinera",
    "giljotineranden": "giljotinerande",
    "giljotinerandena": "giljotinerande",
    "giljotinerandenas": "giljotinerande",
    "giljotinerandens": "giljotinerande",
    "giljotinerandes": "giljotinerande",
    "giljotinerandet": "giljotinerande",
    "giljotinerandets": "giljotinerande",
    "giljotinerar": "giljotinera",
    "giljotineras": "giljotinera",
    "giljotinerat": "giljotinera",
    "giljotinerats": "giljotinera",
    "giljotinerbara": "giljotinerbar",
    "giljotinerbarare": "giljotinerbar",
    "giljotinerbarares": "giljotinerbar",
    "giljotinerbaras": "giljotinerbar",
    "giljotinerbarast": "giljotinerbar",
    "giljotinerbaraste": "giljotinerbar",
    "giljotinerbarastes": "giljotinerbar",
    "giljotinerbarasts": "giljotinerbar",
    "giljotinerbare": "giljotinerbar",
    "giljotinerbares": "giljotinerbar",
    "giljotinerbarheten": "giljotinerbarhet",
    "giljotinerbarhetens": "giljotinerbarhet",
    "giljotinerbarhets": "giljotinerbarhet",
    "giljotinerbars": "giljotinerbar",
    "giljotinerbart": "giljotinerbar",
    "giljotinerbarts": "giljotinerbar",
    "giljotineringar": "giljotinering",
    "giljotineringarna": "giljotinering",
    "giljotineringarnas": "giljotinering",
    "giljotineringars": "giljotinering",
    "giljotineringen": "giljotinering",
    "giljotineringens": "giljotinering",
    "giljotinerings": "giljotinering",
    "giljotinerna": "giljotin",
    "giljotinernas": "giljotin",
    "giljotiners": "giljotin",
    "giljotins": "giljotin",
    "gill": "gilla",
    "gilla": "gill",
    "gillad": "gilla",
    "gillade": "gilla",
    "gillades": "gillas",
    "gillads": "gilla",
    "gillande": "gilla",
    "gillanden": "gillande",
    "gillandena": "gillande",
    "gillandenas": "gillande",
    "gillandens": "gillande",
    "gillandes": "gillande",
    "gillandet": "gillande",
    "gillandets": "gillande",
    "gillar": "gilla",
    "gillare": "gill",
    "gillares": "gill",
    "gillas": "gilla",
    "gillast": "gill",
    "gillaste": "gill",
    "gillastes": "gill",
    "gillasts": "gill",
    "gillat": "gilla",
    "gillats": "gillas",
    "gilldes": "gillas",
    "gille": "gill",
    "gillen": "gille",
    "gillena": "gille",
    "gillenas": "gille",
    "gillens": "gille",
    "gillerna": "giller",
    "gillernas": "giller",
    "gillers": "giller",
    "gilles": "gille",
    "gillesbrodern": "gillesbroder",
    "gillesbroderns": "gillesbroder",
    "gillesbroders": "gillesbroder",
    "gillesbröder": "gillesbroder",
    "gillesbröderna": "gillesbroder",
    "gillesbrödernas": "gillesbroder",
    "gillesbröders": "gillesbroder",
    "gillessocialismen": "gillessocialism",
    "gillessocialismens": "gillessocialism",
    "gillessocialismer": "gillessocialism",
    "gillessocialismerna": "gillessocialism",
    "gillessocialismernas": "gillessocialism",
    "gillessocialismers": "gillessocialism",
    "gillessocialisms": "gillessocialism",
    "gillesstugan": "gillesstuga",
    "gillesstugans": "gillesstuga",
    "gillesstugas": "gillesstuga",
    "gillesstuge": "gillesstuga",
    "gillesstugor": "gillesstuga",
    "gillesstugorna": "gillesstuga",
    "gillesstugornas": "gillesstuga",
    "gillesstugors": "gillesstuga",
    "gillesstugu": "gillesstuga",
    "gillestugan": "gillestuga",
    "gillestugans": "gillestuga",
    "gillestugas": "gillestuga",
    "gillestuge": "gillestuga",
    "gillestugor": "gillestuga",
    "gillestugorna": "gillestuga",
    "gillestugornas": "gillestuga",
    "gillestugors": "gillestuga",
    "gillestugu": "gillestuga",
    "gillet": "gille",
    "gillets": "gille",
    "gillheten": "gillhet",
    "gillhetens": "gillhet",
    "gillhets": "gillhet",
    "gillrad": "gillra",
    "gillrade": "gillra",
    "gillrades": "gillra",
    "gillrads": "gillra",
    "gillrande": "gillra",
    "gillranden": "gillrande",
    "gillrandena": "gillrande",
    "gillrandenas": "gillrande",
    "gillrandens": "gillrande",
    "gillrandes": "gillrande",
    "gillrandet": "gillrande",
    "gillrandets": "gillrande",
    "gillrar": "gillra",
    "gillras": "gillra",
    "gillrat": "gillra",
    "gillrats": "gillra",
    "gillren": "giller",
    "gillrens": "giller",
    "gillret": "giller",
    "gillrets": "giller",
    "gills": "gille",
    "gillt": "gill",
    "gillts": "gillas",
    "giltiga": "giltig",
    "giltigare": "giltig",
    "giltigares": "giltig",
    "giltigas": "giltig",
    "giltigast": "giltig",
    "giltigaste": "giltig",
    "giltigastes": "giltig",
    "giltigasts": "giltig",
    "giltige": "giltig",
    "giltiges": "giltig",
    "giltigheten": "giltighet",
    "giltighetens": "giltighet",
    "giltigheter": "giltighet",
    "giltigheterna": "giltighet",
    "giltigheternas": "giltighet",
    "giltigheters": "giltighet",
    "giltighets": "giltighet",
    "giltighetstiden": "giltighetstid",
    "giltighetstidens": "giltighetstid",
    "giltighetstider": "giltighetstid",
    "giltighetstiderna": "giltighetstid",
    "giltighetstidernas": "giltighetstid",
    "giltighetstiders": "giltighetstid",
    "giltighetstids": "giltighetstid",
    "giltigs": "giltig",
    "giltigt": "giltig",
    "giltigts": "giltig",
    "gimmickar": "gimmick",
    "gimmickarna": "gimmick",
    "gimmickarnas": "gimmick",
    "gimmickars": "gimmick",
    "gimmicken": "gimmick",
    "gimmickens": "gimmick",
    "gimmicks": "gimmick",
    "gimmicksarna": "gimmick",
    "gimmicksarnas": "gimmick",
    "gimmicksen": "gimmick",
    "gimmicksens": "gimmick",
    "gin": "gina",
    "gina": "gin",
    "ginade": "gina",
    "ginades": "gina",
    "ginan": "gina",
    "ginande": "gina",
    "ginanden": "ginande",
    "ginandena": "ginande",
    "ginandenas": "ginande",
    "ginandens": "ginande",
    "ginandes": "ginande",
    "ginandet": "ginande",
    "ginandets": "ginande",
    "ginans": "gina",
    "ginar": "gina",
    "ginare": "gin",
    "ginares": "gin",
    "ginas": "gina",
    "ginast": "gin",
    "ginaste": "gin",
    "ginastes": "gin",
    "ginasts": "gin",
    "ginat": "gina",
    "ginats": "gina",
    "ginbalkar": "ginbalk",
    "ginbalkarna": "ginbalk",
    "ginbalkarnas": "ginbalk",
    "ginbalkars": "ginbalk",
    "ginbalken": "ginbalk",
    "ginbalkens": "ginbalk",
    "ginbalks": "ginbalk",
    "gine": "gina",
    "ginen": "gin",
    "ginens": "gin",
    "gines": "gin",
    "ginet": "gin",
    "ginets": "gin",
    "ginge": "gå",
    "ginges": "gå",
    "ginghams": "gingham",
    "ginnungagapen": "ginnungagap",
    "ginnungagapens": "ginnungagap",
    "ginnungagapet": "ginnungagap",
    "ginnungagapets": "ginnungagap",
    "ginnungagaps": "ginnungagap",
    "ginor": "gina",
    "ginorna": "gina",
    "ginornas": "gina",
    "ginors": "gina",
    "gins": "gina",
    "ginsengen": "ginseng",
    "ginsengens": "ginseng",
    "ginsenger": "ginseng",
    "ginsengerna": "ginseng",
    "ginsengernas": "ginseng",
    "ginsengers": "ginseng",
    "ginsengs": "ginseng",
    "ginsten": "ginst",
    "ginstens": "ginst",
    "ginster": "ginst",
    "ginsterna": "ginst",
    "ginsternas": "ginst",
    "ginsters": "ginst",
    "ginstkatten": "ginstkatt",
    "ginstkattens": "ginstkatt",
    "ginstkatter": "ginstkatt",
    "ginstkatterna": "ginstkatt",
    "ginstkatternas": "ginstkatt",
    "ginstkatters": "ginstkatt",
    "ginstkatts": "ginstkatt",
    "ginsts": "ginst",
    "gint": "gin",
    "gints": "gin",
    "ginvägar": "ginväg",
    "ginvägarna": "ginväg",
    "ginvägarnas": "ginväg",
    "ginvägars": "ginväg",
    "ginvägen": "ginväg",
    "ginvägens": "ginväg",
    "ginvägs": "ginväg",
    "gip": "gipa",
    "gipade": "gipa",
    "gipades": "gipa",
    "gipan": "gipa",
    "gipande": "gipa",
    "gipanden": "gipande",
    "gipandena": "gipande",
    "gipandenas": "gipande",
    "gipandens": "gipande",
    "gipandes": "gipande",
    "gipandet": "gipande",
    "gipandets": "gipande",
    "gipans": "gipa",
    "gipar": "gipa",
    "giparna": "gip",
    "giparnas": "gip",
    "gipars": "gip",
    "gipas": "gipa",
    "gipat": "gipa",
    "gipats": "gipa",
    "gipe": "gipa",
    "gipen": "gip",
    "gipens": "gip",
    "gipor": "gipa",
    "giporna": "gipa",
    "gipornas": "gipa",
    "gipors": "gipa",
    "gipp": "gippa",
    "gippade": "gippa",
    "gippades": "gippa",
    "gippande": "gippa",
    "gippanden": "gippande",
    "gippandena": "gippande",
    "gippandenas": "gippande",
    "gippandens": "gippande",
    "gippandes": "gippande",
    "gippandet": "gippande",
    "gippandets": "gippande",
    "gippar": "gippa",
    "gipparna": "gipp",
    "gipparnas": "gipp",
    "gippars": "gipp",
    "gippas": "gippa",
    "gippat": "gippa",
    "gippats": "gippa",
    "gippen": "gipp",
    "gippens": "gipp",
    "gipps": "gipp",
    "gips": "gipsa",
    "gipsad": "gipsa",
    "gipsade": "gipsa",
    "gipsades": "gipsa",
    "gipsads": "gipsa",
    "gipsande": "gipsa",
    "gipsanden": "gipsande",
    "gipsandena": "gipsande",
    "gipsandenas": "gipsande",
    "gipsandens": "gipsande",
    "gipsandes": "gipsande",
    "gipsandet": "gipsande",
    "gipsandets": "gipsande",
    "gipsar": "gipsa",
    "gipsas": "gipsa",
    "gipsat": "gipsa",
    "gipsats": "gipsa",
    "gipsavgjutningar": "gipsavgjutning",
    "gipsavgjutningarna": "gipsavgjutning",
    "gipsavgjutningarnas": "gipsavgjutning",
    "gipsavgjutningars": "gipsavgjutning",
    "gipsavgjutningen": "gipsavgjutning",
    "gipsavgjutningens": "gipsavgjutning",
    "gipsavgjutnings": "gipsavgjutning",
    "gipsbruket": "gipsbruk",
    "gipsbrukets": "gipsbruk",
    "gipsbruks": "gipsbruk",
    "gipsen": "gips",
    "gipsens": "gips",
    "gipser": "gips",
    "gipserna": "gips",
    "gipsernas": "gips",
    "gipsers": "gips",
    "gipset": "gips",
    "gipsets": "gips",
    "gipsformar": "gipsform",
    "gipsformarna": "gipsform",
    "gipsformarnas": "gipsform",
    "gipsformars": "gipsform",
    "gipsformen": "gipsform",
    "gipsformens": "gipsform",
    "gipsforms": "gipsform",
    "gipsförbanden": "gipsförband",
    "gipsförbandens": "gipsförband",
    "gipsförbandet": "gipsförband",
    "gipsförbandets": "gipsförband",
    "gipsförbands": "gipsförband",
    "gipsklumpar": "gipsklump",
    "gipsklumparna": "gipsklump",
    "gipsklumparnas": "gipsklump",
    "gipsklumpars": "gipsklump",
    "gipsklumpen": "gipsklump",
    "gipsklumpens": "gipsklump",
    "gipsklumps": "gipsklump",
    "gipsmurbruket": "gipsmurbruk",
    "gipsmurbrukets": "gipsmurbruk",
    "gipsmurbruks": "gipsmurbruk",
    "gipsplatt": "gipsplatta",
    "gipsplattan": "gipsplatta",
    "gipsplattans": "gipsplatta",
    "gipsplattas": "gipsplatta",
    "gipsplatte": "gipsplatta",
    "gipsplattor": "gipsplatta",
    "gipsplattorna": "gipsplatta",
    "gipsplattornas": "gipsplatta",
    "gipsplattors": "gipsplatta",
    "gipsplatts": "gipsplatta",
    "gipsputsen": "gipsputs",
    "gipsputsens": "gipsputs",
    "gipsskivan": "gipsskiva",
    "gipsskivans": "gipsskiva",
    "gipsskivas": "gipsskiva",
    "gipsskive": "gipsskiva",
    "gipsskivor": "gipsskiva",
    "gipsskivorna": "gipsskiva",
    "gipsskivornas": "gipsskiva",
    "gipsskivors": "gipsskiva",
    "gipsväggar": "gipsvägg",
    "gipsväggarna": "gipsvägg",
    "gipsväggarnas": "gipsvägg",
    "gipsväggars": "gipsvägg",
    "gipsväggen": "gipsvägg",
    "gipsväggens": "gipsvägg",
    "gipsväggs": "gipsvägg",
    "gipyren": "gipyr",
    "gipyrens": "gipyr",
    "gipyrer": "gipyr",
    "gipyrerna": "gipyr",
    "gipyrernas": "gipyr",
    "gipyrers": "gipyr",
    "gipyrs": "gipyr",
    "gir": "gira",
    "girade": "gira",
    "girades": "gira",
    "giraffen": "giraff",
    "giraffens": "giraff",
    "giraffer": "giraff",
    "girafferna": "giraff",
    "giraffernas": "giraff",
    "giraffers": "giraff",
    "giraffs": "giraff",
    "girande": "gira",
    "giranden": "girande",
    "girandena": "girande",
    "girandenas": "girande",
    "girandens": "girande",
    "girandes": "girande",
    "girandet": "girande",
    "girandets": "girande",
    "girandolen": "girandole",
    "girandolens": "girandole",
    "girandoler": "girandole",
    "girandolerna": "girandole",
    "girandolernas": "girandole",
    "girandolers": "girandole",
    "girandoles": "girandole",
    "girar": "gira",
    "girarna": "gir",
    "girarnas": "gir",
    "girars": "gir",
    "giras": "gira",
    "girat": "gira",
    "girats": "gira",
    "giren": "gir",
    "girens": "gir",
    "girerad": "girera",
    "girerade": "girera",
    "girerades": "girera",
    "girerads": "girera",
    "girerande": "girera",
    "gireranden": "girerande",
    "girerandena": "girerande",
    "girerandenas": "girerande",
    "girerandens": "girerande",
    "girerandes": "girerande",
    "girerandet": "girerande",
    "girerandets": "girerande",
    "girerar": "girera",
    "gireras": "girera",
    "girerat": "girera",
    "girerats": "girera",
    "girerbara": "girerbar",
    "girerbarare": "girerbar",
    "girerbarares": "girerbar",
    "girerbaras": "girerbar",
    "girerbarast": "girerbar",
    "girerbaraste": "girerbar",
    "girerbarastes": "girerbar",
    "girerbarasts": "girerbar",
    "girerbare": "girerbar",
    "girerbares": "girerbar",
    "girerbarheten": "girerbarhet",
    "girerbarhetens": "girerbarhet",
    "girerbarhets": "girerbarhet",
    "girerbars": "girerbar",
    "girerbart": "girerbar",
    "girerbarts": "girerbar",
    "gireringar": "girering",
    "gireringarna": "girering",
    "gireringarnas": "girering",
    "gireringars": "girering",
    "gireringen": "girering",
    "gireringens": "girering",
    "girerings": "girering",
    "giriga": "girig",
    "girigare": "girig",
    "girigares": "girig",
    "girigas": "girig",
    "girigast": "girig",
    "girigaste": "girig",
    "girigastes": "girig",
    "girigasts": "girig",
    "girigbukar": "girigbuk",
    "girigbukarna": "girigbuk",
    "girigbukarnas": "girigbuk",
    "girigbukars": "girigbuk",
    "girigbuken": "girigbuk",
    "girigbukens": "girigbuk",
    "girigbuks": "girigbuk",
    "girige": "girig",
    "giriges": "girig",
    "girigs": "girig",
    "girigt": "girig",
    "girigts": "girig",
    "girlanden": "girland",
    "girlandens": "girland",
    "girlander": "girland",
    "girlanderna": "girland",
    "girlandernas": "girland",
    "girlanders": "girland",
    "girlands": "girland",
    "girlangen": "girlang",
    "girlangens": "girlang",
    "girlanger": "girlang",
    "girlangerna": "girlang",
    "girlangernas": "girlang",
    "girlangers": "girlang",
    "girlangs": "girlang",
    "girobeskeden": "girobesked",
    "girobeskedens": "girobesked",
    "girobeskedet": "girobesked",
    "girobeskedets": "girobesked",
    "girobeskeds": "girobesked",
    "giron": "giro",
    "girona": "giro",
    "gironas": "giro",
    "girons": "giro",
    "giros": "giro",
    "girot": "giro",
    "girots": "giro",
    "girs": "gir",
    "girvuxens": "girvuxen",
    "girvuxet": "girvuxen",
    "girvuxets": "girvuxen",
    "girvuxna": "girvuxen",
    "girvuxnare": "girvuxen",
    "girvuxnares": "girvuxen",
    "girvuxnas": "girvuxen",
    "girvuxnast": "girvuxen",
    "girvuxnaste": "girvuxen",
    "girvuxnastes": "girvuxen",
    "girvuxnasts": "girvuxen",
    "girvuxne": "girvuxen",
    "girvuxnes": "girvuxen",
    "girväxta": "girväxt",
    "girväxtare": "girväxt",
    "girväxtares": "girväxt",
    "girväxtas": "girväxt",
    "girväxtast": "girväxt",
    "girväxtaste": "girväxt",
    "girväxtastes": "girväxt",
    "girväxtasts": "girväxt",
    "girväxte": "girväxt",
    "girväxtes": "girväxt",
    "girväxts": "girväxt",
    "giss": "gissa",
    "gissad": "gissa",
    "gissade": "gissa",
    "gissades": "gissa",
    "gissads": "gissa",
    "gissande": "gissa",
    "gissanden": "gissande",
    "gissandena": "gissande",
    "gissandenas": "gissande",
    "gissandens": "gissande",
    "gissandes": "gissande",
    "gissandet": "gissande",
    "gissandets": "gissande",
    "gissar": "gissa",
    "gissas": "gissa",
    "gissat": "gissa",
    "gissats": "gissa",
    "gissel": "gissla",
    "gisseldjuren": "gisseldjur",
    "gisseldjurens": "gisseldjur",
    "gisseldjuret": "gisseldjur",
    "gisseldjurets": "gisseldjur",
    "gisseldjurs": "gisseldjur",
    "gissels": "gissel",
    "gisslad": "gissla",
    "gisslade": "gissla",
    "gisslades": "gissla",
    "gisslads": "gissla",
    "gisslande": "gissla",
    "gisslanden": "gisslande",
    "gisslandena": "gisslande",
    "gisslandenas": "gisslande",
    "gisslandens": "gisslande",
    "gisslandes": "gisslande",
    "gisslandet": "gisslande",
    "gisslandets": "gisslande",
    "gisslandraman": "gisslandrama",
    "gisslandramana": "gisslandrama",
    "gisslandramanas": "gisslandrama",
    "gisslandramans": "gisslandrama",
    "gisslandramas": "gisslandrama",
    "gisslandramat": "gisslandrama",
    "gisslandramats": "gisslandrama",
    "gisslandramer": "gisslandrama",
    "gisslandramerna": "gisslandrama",
    "gisslandramernas": "gisslandrama",
    "gisslandramers": "gisslandrama",
    "gisslans": "gisslan",
    "gisslantaganden": "gisslantagande",
    "gisslantagandena": "gisslantagande",
    "gisslantagandenas": "gisslantagande",
    "gisslantagandens": "gisslantagande",
    "gisslantagandes": "gisslantagande",
    "gisslantagandet": "gisslantagande",
    "gisslantagandets": "gisslantagande",
    "gisslantagar": "gisslantagare",
    "gisslantagaren": "gisslantagare",
    "gisslantagarens": "gisslantagare",
    "gisslantagares": "gisslantagare",
    "gisslantagarna": "gisslantagare",
    "gisslantagarnas": "gisslantagare",
    "gisslar": "gisslare",
    "gisslaren": "gisslare",
    "gisslarens": "gisslare",
    "gisslares": "gisslare",
    "gisslarna": "gisslare",
    "gisslarnas": "gisslare",
    "gisslas": "gissla",
    "gisslat": "gissla",
    "gisslats": "gissla",
    "gisslen": "gissel",
    "gisslens": "gissel",
    "gisslet": "gissel",
    "gisslets": "gissel",
    "gissningar": "gissning",
    "gissningarna": "gissning",
    "gissningarnas": "gissning",
    "gissningars": "gissning",
    "gissningen": "gissning",
    "gissningens": "gissning",
    "gissnings": "gissning",
    "gissningslekar": "gissningslek",
    "gissningslekarna": "gissningslek",
    "gissningslekarnas": "gissningslek",
    "gissningslekars": "gissningslek",
    "gissningsleken": "gissningslek",
    "gissningslekens": "gissningslek",
    "gissningsleks": "gissningslek",
    "gissningstävlingar": "gissningstävling",
    "gissningstävlingarna": "gissningstävling",
    "gissningstävlingarnas": "gissningstävling",
    "gissningstävlingars": "gissningstävling",
    "gissningstävlingen": "gissningstävling",
    "gissningstävlingens": "gissningstävling",
    "gissningstävlings": "gissningstävling",
    "gist": "gista",
    "gistad": "gista",
    "gistade": "gista",
    "gistades": "gista",
    "gistads": "gista",
    "gistande": "gista",
    "gistanden": "gistande",
    "gistandena": "gistande",
    "gistandenas": "gistande",
    "gistandens": "gistande",
    "gistandes": "gistande",
    "gistandet": "gistande",
    "gistandets": "gistande",
    "gistar": "gista",
    "gistas": "gista",
    "gistat": "gista",
    "gistats": "gista",
    "gistenheten": "gistenhet",
    "gistenhetens": "gistenhet",
    "gistenhets": "gistenhet",
    "gistens": "gisten",
    "gistet": "gisten",
    "gistets": "gisten",
    "gistgårdar": "gistgård",
    "gistgårdarna": "gistgård",
    "gistgårdarnas": "gistgård",
    "gistgårdars": "gistgård",
    "gistgården": "gistgård",
    "gistgårdens": "gistgård",
    "gistgårds": "gistgård",
    "gistna": "gisten",
    "gistnade": "gistna",
    "gistnades": "gistna",
    "gistnande": "gistna",
    "gistnanden": "gistnande",
    "gistnandena": "gistnande",
    "gistnandenas": "gistnande",
    "gistnandens": "gistnande",
    "gistnandes": "gistnande",
    "gistnandet": "gistnande",
    "gistnandets": "gistnande",
    "gistnar": "gistna",
    "gistnare": "gisten",
    "gistnares": "gisten",
    "gistnas": "gistna",
    "gistnast": "gisten",
    "gistnaste": "gisten",
    "gistnastes": "gisten",
    "gistnasts": "gisten",
    "gistnat": "gistna",
    "gistnats": "gistna",
    "gistne": "gisten",
    "gistnes": "gisten",
    "gitarren": "gitarr",
    "gitarrens": "gitarr",
    "gitarrer": "gitarr",
    "gitarrerna": "gitarr",
    "gitarrernas": "gitarr",
    "gitarrers": "gitarr",
    "gitarristen": "gitarrist",
    "gitarristens": "gitarrist",
    "gitarrister": "gitarrist",
    "gitarristerna": "gitarrist",
    "gitarristernas": "gitarrist",
    "gitarristers": "gitarrist",
    "gitarrists": "gitarrist",
    "gitarrs": "gitarr",
    "gitarrspelen": "gitarrspel",
    "gitarrspelens": "gitarrspel",
    "gitarrspelet": "gitarrspel",
    "gitarrspelets": "gitarrspel",
    "gitarrspels": "gitarrspel",
    "gitt": "gitta",
    "gittande": "gitta",
    "gittanden": "gittande",
    "gittandena": "gittande",
    "gittandenas": "gittande",
    "gittandens": "gittande",
    "gittandes": "gittande",
    "gittandet": "gittande",
    "gittandets": "gittande",
    "gittas": "gitta",
    "gittat": "gitta",
    "gittats": "gitta",
    "gitte": "gitta",
    "gitter": "gitta",
    "gitterna": "gitter",
    "gitternas": "gitter",
    "gitters": "gitter",
    "gittes": "gitta",
    "gittren": "gitter",
    "gittrens": "gitter",
    "gittret": "gitter",
    "gittrets": "gitter",
    "gitts": "gitta",
    "giv": "ge",
    "giva": "ge",
    "givakten": "givakt",
    "givaktens": "givakt",
    "givakter": "givakt",
    "givakterna": "givakt",
    "givakternas": "givakt",
    "givakters": "givakt",
    "givakts": "givakt",
    "givande": "ge",
    "givanden": "givande",
    "givandena": "givande",
    "givandenas": "givande",
    "givandens": "givande",
    "givandes": "givande",
    "givandet": "givande",
    "givandets": "givande",
    "givar": "givare",
    "givaren": "givare",
    "givarens": "givare",
    "givares": "givare",
    "givarna": "givare",
    "givarnas": "givare",
    "givars": "giv",
    "givas": "ge",
    "give": "ge",
    "given": "giv",
    "givenheten": "givenhet",
    "givenhetens": "givenhet",
    "givenhets": "givenhet",
    "givens": "given",
    "giver": "ge",
    "gives": "ge",
    "givet": "given",
    "givets": "given",
    "givit": "ge",
    "givits": "ge",
    "givkorten": "givkort",
    "givkortens": "givkort",
    "givkortet": "givkort",
    "givkortets": "givkort",
    "givkorts": "givkort",
    "givmilda": "givmild",
    "givmildare": "givmild",
    "givmildares": "givmild",
    "givmildas": "givmild",
    "givmildast": "givmild",
    "givmildaste": "givmild",
    "givmildastes": "givmild",
    "givmildasts": "givmild",
    "givmilde": "givmild",
    "givmildes": "givmild",
    "givmildheten": "givmildhet",
    "givmildhetens": "givmildhet",
    "givmildheter": "givmildhet",
    "givmildheterna": "givmildhet",
    "givmildheternas": "givmildhet",
    "givmildheters": "givmildhet",
    "givmildhets": "givmildhet",
    "givmilds": "givmild",
    "givmilt": "givmild",
    "givmilts": "givmild",
    "givna": "given",
    "givnare": "given",
    "givnares": "given",
    "givnas": "given",
    "givnast": "given",
    "givnaste": "given",
    "givnastes": "given",
    "givnasts": "given",
    "givne": "given",
    "givnes": "given",
    "givningar": "givning",
    "givningarna": "givning",
    "givningarnas": "givning",
    "givningars": "givning",
    "givningen": "givning",
    "givningens": "givning",
    "givnings": "givning",
    "givs": "giv",
    "gjord": "göra",
    "gjorda": "göra",
    "gjordad": "gjorda",
    "gjordade": "gjorda",
    "gjordades": "gjorda",
    "gjordads": "gjorda",
    "gjordande": "gjorda",
    "gjordanden": "gjordande",
    "gjordandena": "gjordande",
    "gjordandenas": "gjordande",
    "gjordandens": "gjordande",
    "gjordandes": "gjordande",
    "gjordandet": "gjordande",
    "gjordandets": "gjordande",
    "gjordar": "gjorda",
    "gjordarna": "gjord",
    "gjordarnas": "gjord",
    "gjordars": "gjord",
    "gjordas": "göra",
    "gjordat": "gjorda",
    "gjordats": "gjorda",
    "gjorde": "göra",
    "gjorden": "gjord",
    "gjordens": "gjord",
    "gjordes": "göra",
    "gjords": "göra",
    "gjort": "göra",
    "gjorts": "göra",
    "gjus": "gjuse",
    "gjusar": "gjuse",
    "gjusarna": "gjuse",
    "gjusarnas": "gjuse",
    "gjusars": "gjuse",
    "gjusen": "gjuse",
    "gjusens": "gjuse",
    "gjuses": "gjuse",
    "gjut": "gjuta",
    "gjutande": "gjuta",
    "gjutanden": "gjutande",
    "gjutandena": "gjutande",
    "gjutandenas": "gjutande",
    "gjutandens": "gjutande",
    "gjutandes": "gjutande",
    "gjutandet": "gjutande",
    "gjutandets": "gjutande",
    "gjutar": "gjutare",
    "gjutaren": "gjutare",
    "gjutarens": "gjutare",
    "gjutares": "gjutare",
    "gjutarna": "gjutare",
    "gjutarnas": "gjutare",
    "gjutas": "gjuta",
    "gjutbara": "gjutbar",
    "gjutbarare": "gjutbar",
    "gjutbarares": "gjutbar",
    "gjutbaras": "gjutbar",
    "gjutbarast": "gjutbar",
    "gjutbaraste": "gjutbar",
    "gjutbarastes": "gjutbar",
    "gjutbarasts": "gjutbar",
    "gjutbare": "gjutbar",
    "gjutbares": "gjutbar",
    "gjutbarheten": "gjutbarhet",
    "gjutbarhetens": "gjutbarhet",
    "gjutbarhets": "gjutbarhet",
    "gjutbars": "gjutbar",
    "gjutbart": "gjutbar",
    "gjutbarts": "gjutbar",
    "gjutbetongen": "gjutbetong",
    "gjutbetongens": "gjutbetong",
    "gjutbetongs": "gjutbetong",
    "gjute": "gjuta",
    "gjuten": "gjuta",
    "gjutens": "gjuta",
    "gjuter": "gjuta",
    "gjuterier": "gjuteri",
    "gjuterierna": "gjuteri",
    "gjuteriernas": "gjuteri",
    "gjuteriers": "gjuteri",
    "gjuteriet": "gjuteri",
    "gjuteriets": "gjuteri",
    "gjuteris": "gjuteri",
    "gjuterit": "gjuteri",
    "gjuterits": "gjuteri",
    "gjutes": "gjuta",
    "gjutet": "gjuta",
    "gjutets": "gjuta",
    "gjutflask": "gjutflaska",
    "gjutflaskan": "gjutflaska",
    "gjutflaskans": "gjutflaska",
    "gjutflaskas": "gjutflaska",
    "gjutflaske": "gjutflaska",
    "gjutflaskor": "gjutflaska",
    "gjutflaskorna": "gjutflaska",
    "gjutflaskornas": "gjutflaska",
    "gjutflaskors": "gjutflaska",
    "gjutformar": "gjutform",
    "gjutformarna": "gjutform",
    "gjutformarnas": "gjutform",
    "gjutformars": "gjutform",
    "gjutformen": "gjutform",
    "gjutformens": "gjutform",
    "gjutforms": "gjutform",
    "gjutgodset": "gjutgods",
    "gjutgodsets": "gjutgods",
    "gjutit": "gjuta",
    "gjutits": "gjuta",
    "gjutjärnet": "gjutjärn",
    "gjutjärnets": "gjutjärn",
    "gjutjärns": "gjutjärn",
    "gjutjärnsbroar": "gjutjärnsbro",
    "gjutjärnsbroarna": "gjutjärnsbro",
    "gjutjärnsbroarnas": "gjutjärnsbro",
    "gjutjärnsbroars": "gjutjärnsbro",
    "gjutjärnsbron": "gjutjärnsbro",
    "gjutjärnsbrons": "gjutjärnsbro",
    "gjutjärnsbros": "gjutjärnsbro",
    "gjutjärnsgryt": "gjutjärnsgryta",
    "gjutjärnsgrytan": "gjutjärnsgryta",
    "gjutjärnsgrytans": "gjutjärnsgryta",
    "gjutjärnsgrytas": "gjutjärnsgryta",
    "gjutjärnsgryte": "gjutjärnsgryta",
    "gjutjärnsgrytor": "gjutjärnsgryta",
    "gjutjärnsgrytorna": "gjutjärnsgryta",
    "gjutjärnsgrytornas": "gjutjärnsgryta",
    "gjutjärnsgrytors": "gjutjärnsgryta",
    "gjutjärnsgryts": "gjutjärnsgryta",
    "gjutmassan": "gjutmassa",
    "gjutmassans": "gjutmassa",
    "gjutmassas": "gjutmassa",
    "gjutmasse": "gjutmassa",
    "gjutmodellen": "gjutmodell",
    "gjutmodellens": "gjutmodell",
    "gjutmodeller": "gjutmodell",
    "gjutmodellerna": "gjutmodell",
    "gjutmodellernas": "gjutmodell",
    "gjutmodellers": "gjutmodell",
    "gjutmodells": "gjutmodell",
    "gjutna": "gjuta",
    "gjutnas": "gjuta",
    "gjutne": "gjuta",
    "gjutnes": "gjuta",
    "gjutningar": "gjutning",
    "gjutningarna": "gjutning",
    "gjutningarnas": "gjutning",
    "gjutningars": "gjutning",
    "gjutningen": "gjutning",
    "gjutningens": "gjutning",
    "gjutnings": "gjutning",
    "gjutranden": "gjutrand",
    "gjutrandens": "gjutrand",
    "gjutrands": "gjutrand",
    "gjutränder": "gjutrand",
    "gjutränderna": "gjutrand",
    "gjuträndernas": "gjutrand",
    "gjutränders": "gjutrand",
    "gjuts": "gjuta",
    "gjutsanden": "gjutsand",
    "gjutsandens": "gjutsand",
    "gjutsands": "gjutsand",
    "gjutstålet": "gjutstål",
    "gjutstålets": "gjutstål",
    "gjutståls": "gjutstål",
    "glacen": "glace",
    "glacens": "glace",
    "glaces": "glace",
    "glaciala": "glacial",
    "glacialare": "glacial",
    "glacialares": "glacial",
    "glacialas": "glacial",
    "glacialast": "glacial",
    "glacialaste": "glacial",
    "glacialastes": "glacial",
    "glacialasts": "glacial",
    "glaciale": "glacial",
    "glaciales": "glacial",
    "glacialperioden": "glacialperiod",
    "glacialperiodens": "glacialperiod",
    "glacialperioder": "glacialperiod",
    "glacialperioderna": "glacialperiod",
    "glacialperiodernas": "glacialperiod",
    "glacialperioders": "glacialperiod",
    "glacialperiods": "glacialperiod",
    "glacialräffel": "glacialräffla",
    "glacialräfflan": "glacialräffla",
    "glacialräfflans": "glacialräffla",
    "glacialräfflas": "glacialräffla",
    "glacialräffle": "glacialräffla",
    "glacialräfflor": "glacialräffla",
    "glacialräfflorna": "glacialräffla",
    "glacialräfflornas": "glacialräffla",
    "glacialräfflors": "glacialräffla",
    "glacials": "glacial",
    "glacialt": "glacial",
    "glacialts": "glacial",
    "glacien": "glaci",
    "glaciens": "glaci",
    "glacier": "glaci",
    "glacierna": "glaci",
    "glaciernas": "glaci",
    "glaciers": "glaci",
    "glacifluviala": "glacifluvial",
    "glacifluvialare": "glacifluvial",
    "glacifluvialares": "glacifluvial",
    "glacifluvialas": "glacifluvial",
    "glacifluvialast": "glacifluvial",
    "glacifluvialaste": "glacifluvial",
    "glacifluvialastes": "glacifluvial",
    "glacifluvialasts": "glacifluvial",
    "glacifluviale": "glacifluvial",
    "glacifluviales": "glacifluvial",
    "glacifluvials": "glacifluvial",
    "glacifluvialt": "glacifluvial",
    "glacifluvialts": "glacifluvial",
    "glacin": "glaci",
    "glacins": "glaci",
    "glaciologen": "glaciolog",
    "glaciologens": "glaciolog",
    "glaciologer": "glaciolog",
    "glaciologerna": "glaciolog",
    "glaciologernas": "glaciolog",
    "glaciologers": "glaciolog",
    "glaciologien": "glaciologi",
    "glaciologiens": "glaciologi",
    "glaciologin": "glaciologi",
    "glaciologins": "glaciologi",
    "glaciologis": "glaciologi",
    "glaciologiska": "glaciologisk",
    "glaciologiskare": "glaciologisk",
    "glaciologiskares": "glaciologisk",
    "glaciologiskas": "glaciologisk",
    "glaciologiskast": "glaciologisk",
    "glaciologiskaste": "glaciologisk",
    "glaciologiskastes": "glaciologisk",
    "glaciologiskasts": "glaciologisk",
    "glaciologiske": "glaciologisk",
    "glaciologiskes": "glaciologisk",
    "glaciologisks": "glaciologisk",
    "glaciologiskt": "glaciologisk",
    "glaciologiskts": "glaciologisk",
    "glaciologs": "glaciolog",
    "glacis": "glaci",
    "glaciärbrunnar": "glaciärbrunn",
    "glaciärbrunnarna": "glaciärbrunn",
    "glaciärbrunnarnas": "glaciärbrunn",
    "glaciärbrunnars": "glaciärbrunn",
    "glaciärbrunnen": "glaciärbrunn",
    "glaciärbrunnens": "glaciärbrunn",
    "glaciärbrunns": "glaciärbrunn",
    "glaciären": "glaciär",
    "glaciärens": "glaciär",
    "glaciärer": "glaciär",
    "glaciärerna": "glaciär",
    "glaciärernas": "glaciär",
    "glaciärers": "glaciär",
    "glaciärisar": "glaciäris",
    "glaciärisarna": "glaciäris",
    "glaciärisarnas": "glaciäris",
    "glaciärisars": "glaciäris",
    "glaciärisen": "glaciäris",
    "glaciärisens": "glaciäris",
    "glaciärnischen": "glaciärnisch",
    "glaciärnischens": "glaciärnisch",
    "glaciärnischer": "glaciärnisch",
    "glaciärnischerna": "glaciärnisch",
    "glaciärnischernas": "glaciärnisch",
    "glaciärnischers": "glaciärnisch",
    "glaciärnischs": "glaciärnisch",
    "glaciärportar": "glaciärport",
    "glaciärportarna": "glaciärport",
    "glaciärportarnas": "glaciärport",
    "glaciärportars": "glaciärport",
    "glaciärporten": "glaciärport",
    "glaciärportens": "glaciärport",
    "glaciärports": "glaciärport",
    "glaciärräffel": "glaciärräffla",
    "glaciärräfflan": "glaciärräffla",
    "glaciärräfflans": "glaciärräffla",
    "glaciärräfflas": "glaciärräffla",
    "glaciärräffle": "glaciärräffla",
    "glaciärräfflor": "glaciärräffla",
    "glaciärräfflorna": "glaciärräffla",
    "glaciärräfflornas": "glaciärräffla",
    "glaciärräfflors": "glaciärräffla",
    "glaciärs": "glaciär",
    "glaciärälvar": "glaciärälv",
    "glaciärälvarna": "glaciärälv",
    "glaciärälvarnas": "glaciärälv",
    "glaciärälvars": "glaciärälv",
    "glaciärälven": "glaciärälv",
    "glaciärälvens": "glaciärälv",
    "glaciärälvs": "glaciärälv",
    "glacéhandsk": "glacéhandske",
    "glacéhandskar": "glacéhandske",
    "glacéhandskarna": "glacéhandske",
    "glacéhandskarnas": "glacéhandske",
    "glacéhandskars": "glacéhandske",
    "glacéhandsken": "glacéhandske",
    "glacéhandskens": "glacéhandske",
    "glacéhandskes": "glacéhandske",
    "glad": "glada",
    "glada": "glad",
    "gladan": "glada",
    "gladans": "glada",
    "gladare": "glad",
    "gladares": "glad",
    "gladas": "glada",
    "gladast": "glad",
    "gladaste": "glad",
    "gladastes": "glad",
    "gladasts": "glad",
    "gladde": "glädja",
    "gladdes": "glädjas",
    "glade": "glada",
    "gladeliga": "gladelig",
    "gladeligare": "gladelig",
    "gladeligares": "gladelig",
    "gladeligas": "gladelig",
    "gladeligast": "gladelig",
    "gladeligaste": "gladelig",
    "gladeligastes": "gladelig",
    "gladeligasts": "gladelig",
    "gladelige": "gladelig",
    "gladeliges": "gladelig",
    "gladeligs": "gladelig",
    "gladeligt": "gladelig",
    "gladeligts": "gladelig",
    "gladen": "glad",
    "gladens": "glad",
    "glades": "glad",
    "gladet": "glad",
    "gladets": "glad",
    "gladheten": "gladhet",
    "gladhetens": "gladhet",
    "gladhets": "gladhet",
    "gladiatorer": "gladiator",
    "gladiatorerna": "gladiator",
    "gladiatorernas": "gladiator",
    "gladiatorers": "gladiator",
    "gladiatorgravar": "gladiatorgrav",
    "gladiatorgravarna": "gladiatorgrav",
    "gladiatorgravarnas": "gladiatorgrav",
    "gladiatorgravars": "gladiatorgrav",
    "gladiatorgraven": "gladiatorgrav",
    "gladiatorgravens": "gladiatorgrav",
    "gladiatorgravs": "gladiatorgrav",
    "gladiatorn": "gladiator",
    "gladiatorns": "gladiator",
    "gladiators": "gladiator",
    "gladiatorspelen": "gladiatorspel",
    "gladiatorspelens": "gladiatorspel",
    "gladiatorspelet": "gladiatorspel",
    "gladiatorspelets": "gladiatorspel",
    "gladiatorspels": "gladiatorspel",
    "gladioler": "gladiolus",
    "gladiolerna": "gladiolus",
    "gladiolernas": "gladiolus",
    "gladiolers": "gladiolus",
    "gladiolusar": "gladiolus",
    "gladiolusarna": "gladiolus",
    "gladiolusarnas": "gladiolus",
    "gladiolusars": "gladiolus",
    "gladiolusen": "gladiolus",
    "gladiolusens": "gladiolus",
    "gladliga": "gladlig",
    "gladligare": "gladlig",
    "gladligares": "gladlig",
    "gladligas": "gladlig",
    "gladligast": "gladlig",
    "gladligaste": "gladlig",
    "gladligastes": "gladlig",
    "gladligasts": "gladlig",
    "gladlige": "gladlig",
    "gladliges": "gladlig",
    "gladligs": "gladlig",
    "gladligt": "gladlig",
    "gladligts": "gladlig",
    "gladlynta": "gladlynt",
    "gladlyntare": "gladlynt",
    "gladlyntares": "gladlynt",
    "gladlyntas": "gladlynt",
    "gladlyntast": "gladlynt",
    "gladlyntaste": "gladlynt",
    "gladlyntastes": "gladlynt",
    "gladlyntasts": "gladlynt",
    "gladlynte": "gladlynt",
    "gladlyntes": "gladlynt",
    "gladlyntheten": "gladlynthet",
    "gladlynthetens": "gladlynthet",
    "gladlynthets": "gladlynthet",
    "gladlynts": "gladlynt",
    "glador": "glada",
    "gladorna": "glada",
    "gladornas": "glada",
    "gladors": "glada",
    "gladporren": "gladporr",
    "gladporrens": "gladporr",
    "gladporrs": "gladporr",
    "glads": "glada",
    "glagolitiska": "glagolitisk",
    "glagolitiskare": "glagolitisk",
    "glagolitiskares": "glagolitisk",
    "glagolitiskas": "glagolitisk",
    "glagolitiskast": "glagolitisk",
    "glagolitiskaste": "glagolitisk",
    "glagolitiskastes": "glagolitisk",
    "glagolitiskasts": "glagolitisk",
    "glagolitiske": "glagolitisk",
    "glagolitiskes": "glagolitisk",
    "glagolitisks": "glagolitisk",
    "glagolitiskt": "glagolitisk",
    "glagolitiskts": "glagolitisk",
    "glammade": "glamma",
    "glammades": "glamma",
    "glammande": "glamma",
    "glammanden": "glammande",
    "glammandena": "glammande",
    "glammandenas": "glammande",
    "glammandens": "glammande",
    "glammandes": "glammande",
    "glammandet": "glammande",
    "glammandets": "glammande",
    "glammar": "glamma",
    "glammas": "glamma",
    "glammat": "glamma",
    "glammats": "glamma",
    "glammet": "glam",
    "glammets": "glam",
    "glamoriserad": "glamorisera",
    "glamoriserade": "glamorisera",
    "glamoriserades": "glamorisera",
    "glamoriserads": "glamorisera",
    "glamoriserande": "glamorisera",
    "glamoriseranden": "glamoriserande",
    "glamoriserandena": "glamoriserande",
    "glamoriserandenas": "glamoriserande",
    "glamoriserandens": "glamoriserande",
    "glamoriserandes": "glamoriserande",
    "glamoriserandet": "glamoriserande",
    "glamoriserandets": "glamoriserande",
    "glamoriserar": "glamorisera",
    "glamoriseras": "glamorisera",
    "glamoriserat": "glamorisera",
    "glamoriserats": "glamorisera",
    "glamoriserbara": "glamoriserbar",
    "glamoriserbarare": "glamoriserbar",
    "glamoriserbarares": "glamoriserbar",
    "glamoriserbaras": "glamoriserbar",
    "glamoriserbarast": "glamoriserbar",
    "glamoriserbaraste": "glamoriserbar",
    "glamoriserbarastes": "glamoriserbar",
    "glamoriserbarasts": "glamoriserbar",
    "glamoriserbare": "glamoriserbar",
    "glamoriserbares": "glamoriserbar",
    "glamoriserbarheten": "glamoriserbarhet",
    "glamoriserbarhetens": "glamoriserbarhet",
    "glamoriserbarhets": "glamoriserbarhet",
    "glamoriserbars": "glamoriserbar",
    "glamoriserbart": "glamoriserbar",
    "glamoriserbarts": "glamoriserbar",
    "glamoriseringar": "glamorisering",
    "glamoriseringarna": "glamorisering",
    "glamoriseringarnas": "glamorisering",
    "glamoriseringars": "glamorisering",
    "glamoriseringen": "glamorisering",
    "glamoriseringens": "glamorisering",
    "glamoriserings": "glamorisering",
    "glamorösa": "glamorös",
    "glamorösare": "glamorös",
    "glamorösares": "glamorös",
    "glamorösas": "glamorös",
    "glamorösast": "glamorös",
    "glamorösaste": "glamorös",
    "glamorösastes": "glamorös",
    "glamorösasts": "glamorös",
    "glamoröse": "glamorös",
    "glamoröses": "glamorös",
    "glamoröst": "glamorös",
    "glamorösts": "glamorös",
    "glamouren": "glamour",
    "glamourens": "glamour",
    "glamouriserad": "glamourisera",
    "glamouriserade": "glamourisera",
    "glamouriserades": "glamourisera",
    "glamouriserads": "glamourisera",
    "glamouriserande": "glamourisera",
    "glamouriseranden": "glamouriserande",
    "glamouriserandena": "glamouriserande",
    "glamouriserandenas": "glamouriserande",
    "glamouriserandens": "glamouriserande",
    "glamouriserandes": "glamouriserande",
    "glamouriserandet": "glamouriserande",
    "glamouriserandets": "glamouriserande",
    "glamouriserar": "glamourisera",
    "glamouriseras": "glamourisera",
    "glamouriserat": "glamourisera",
    "glamouriserats": "glamourisera",
    "glamouriserbara": "glamouriserbar",
    "glamouriserbarare": "glamouriserbar",
    "glamouriserbarares": "glamouriserbar",
    "glamouriserbaras": "glamouriserbar",
    "glamouriserbarast": "glamouriserbar",
    "glamouriserbaraste": "glamouriserbar",
    "glamouriserbarastes": "glamouriserbar",
    "glamouriserbarasts": "glamouriserbar",
    "glamouriserbare": "glamouriserbar",
    "glamouriserbares": "glamouriserbar",
    "glamouriserbarheten": "glamouriserbarhet",
    "glamouriserbarhetens": "glamouriserbarhet",
    "glamouriserbarhets": "glamouriserbarhet",
    "glamouriserbars": "glamouriserbar",
    "glamouriserbart": "glamouriserbar",
    "glamouriserbarts": "glamouriserbar",
    "glamouriseringar": "glamourisering",
    "glamouriseringarna": "glamourisering",
    "glamouriseringarnas": "glamourisering",
    "glamouriseringars": "glamourisering",
    "glamouriseringen": "glamourisering",
    "glamouriseringens": "glamourisering",
    "glamouriserings": "glamourisering",
    "glamours": "glamour",
    "glamourösa": "glamourös",
    "glamourösare": "glamourös",
    "glamourösares": "glamourös",
    "glamourösas": "glamourös",
    "glamourösast": "glamourös",
    "glamourösaste": "glamourös",
    "glamourösastes": "glamourös",
    "glamourösasts": "glamourös",
    "glamouröse": "glamourös",
    "glamouröses": "glamourös",
    "glamouröst": "glamourös",
    "glamourösts": "glamourös",
    "glams": "glam",
    "glan": "glana",
    "glanade": "glana",
    "glanades": "glana",
    "glanande": "glana",
    "glananden": "glanande",
    "glanandena": "glanande",
    "glanandenas": "glanande",
    "glanandens": "glanande",
    "glanandes": "glanande",
    "glanandet": "glanande",
    "glanandets": "glanande",
    "glanar": "glana",
    "glanas": "glana",
    "glanat": "glana",
    "glanats": "glana",
    "glandeln": "glandel",
    "glandelns": "glandel",
    "glandels": "glandel",
    "glandler": "glandel",
    "glandlerna": "glandel",
    "glandlernas": "glandel",
    "glandlers": "glandel",
    "glandulösa": "glandulös",
    "glandulösare": "glandulös",
    "glandulösares": "glandulös",
    "glandulösas": "glandulös",
    "glandulösast": "glandulös",
    "glandulösaste": "glandulös",
    "glandulösastes": "glandulös",
    "glandulösasts": "glandulös",
    "glandulöse": "glandulös",
    "glandulöses": "glandulös",
    "glandulöst": "glandulös",
    "glandulösts": "glandulös",
    "glans": "glansa",
    "glansad": "glansa",
    "glansade": "glansa",
    "glansades": "glansa",
    "glansads": "glansa",
    "glansande": "glansa",
    "glansanden": "glansande",
    "glansandena": "glansande",
    "glansandenas": "glansande",
    "glansandens": "glansande",
    "glansandes": "glansande",
    "glansandet": "glansande",
    "glansandets": "glansande",
    "glansar": "glansa",
    "glansas": "glansa",
    "glansat": "glansa",
    "glansats": "glansa",
    "glansbagg": "glansbagge",
    "glansbaggar": "glansbagge",
    "glansbaggarna": "glansbagge",
    "glansbaggarnas": "glansbagge",
    "glansbaggars": "glansbagge",
    "glansbaggen": "glansbagge",
    "glansbaggens": "glansbagge",
    "glansbagges": "glansbagge",
    "glansbaggs": "glansbagge",
    "glansdagarna": "glansdagar",
    "glansdagarnas": "glansdagar",
    "glansdagars": "glansdagar",
    "glansdags": "glansdagar",
    "glansen": "glans",
    "glansens": "glans",
    "glansfulla": "glansfull",
    "glansfullare": "glansfull",
    "glansfullares": "glansfull",
    "glansfullas": "glansfull",
    "glansfullast": "glansfull",
    "glansfullaste": "glansfull",
    "glansfullastes": "glansfull",
    "glansfullasts": "glansfull",
    "glansfulle": "glansfull",
    "glansfulles": "glansfull",
    "glansfullheten": "glansfullhet",
    "glansfullhetens": "glansfullhet",
    "glansfullhets": "glansfullhet",
    "glansfulls": "glansfull",
    "glansfullt": "glansfull",
    "glansfullts": "glansfull",
    "glansiga": "glansig",
    "glansigare": "glansig",
    "glansigares": "glansig",
    "glansigas": "glansig",
    "glansigast": "glansig",
    "glansigaste": "glansig",
    "glansigastes": "glansig",
    "glansigasts": "glansig",
    "glansige": "glansig",
    "glansiges": "glansig",
    "glansigheten": "glansighet",
    "glansighetens": "glansighet",
    "glansighets": "glansighet",
    "glansigs": "glansig",
    "glansigt": "glansig",
    "glansigts": "glansig",
    "glansisen": "glansis",
    "glansisens": "glansis",
    "glansk": "glanska",
    "glanska": "glansk",
    "glanskad": "glanska",
    "glanskade": "glanska",
    "glanskades": "glanska",
    "glanskads": "glanska",
    "glanskande": "glanska",
    "glanskanden": "glanskande",
    "glanskandena": "glanskande",
    "glanskandenas": "glanskande",
    "glanskandens": "glanskande",
    "glanskandes": "glanskande",
    "glanskandet": "glanskande",
    "glanskandets": "glanskande",
    "glanskar": "glanska",
    "glanskare": "glansk",
    "glanskares": "glansk",
    "glanskas": "glanska",
    "glanskast": "glansk",
    "glanskaste": "glansk",
    "glanskastes": "glansk",
    "glanskasts": "glansk",
    "glanskat": "glanska",
    "glanskats": "glanska",
    "glanske": "glansk",
    "glanskes": "glansk",
    "glanskheten": "glanskhet",
    "glanskhetens": "glanskhet",
    "glanskhets": "glanskhet",
    "glanskisen": "glanskis",
    "glanskisens": "glanskis",
    "glansks": "glansk",
    "glanskt": "glansk",
    "glanskts": "glansk",
    "glanslösa": "glanslös",
    "glanslösare": "glanslös",
    "glanslösares": "glanslös",
    "glanslösas": "glanslös",
    "glanslösast": "glanslös",
    "glanslösaste": "glanslös",
    "glanslösastes": "glanslös",
    "glanslösasts": "glanslös",
    "glanslöse": "glanslös",
    "glanslöses": "glanslös",
    "glanslösheten": "glanslöshet",
    "glanslöshetens": "glanslöshet",
    "glanslöshets": "glanslöshet",
    "glanslöst": "glanslös",
    "glanslösts": "glanslös",
    "glansnummerna": "glansnummer",
    "glansnummernas": "glansnummer",
    "glansnummers": "glansnummer",
    "glansnumren": "glansnummer",
    "glansnumrens": "glansnummer",
    "glansnumret": "glansnummer",
    "glansnumrets": "glansnummer",
    "glanspapperen": "glanspapper",
    "glanspapperens": "glanspapper",
    "glanspapperet": "glanspapper",
    "glanspapperets": "glanspapper",
    "glanspapperna": "glanspapper",
    "glanspappernas": "glanspapper",
    "glanspappers": "glanspapper",
    "glanspappren": "glanspapper",
    "glanspapprens": "glanspapper",
    "glanspappret": "glanspapper",
    "glanspapprets": "glanspapper",
    "glansperioden": "glansperiod",
    "glansperiodens": "glansperiod",
    "glansperioder": "glansperiod",
    "glansperioderna": "glansperiod",
    "glansperiodernas": "glansperiod",
    "glansperioders": "glansperiod",
    "glansperiods": "glansperiod",
    "glansrollen": "glansroll",
    "glansrollens": "glansroll",
    "glansroller": "glansroll",
    "glansrollerna": "glansroll",
    "glansrollernas": "glansroll",
    "glansrollers": "glansroll",
    "glansrolls": "glansroll",
    "glanssotet": "glanssot",
    "glanssotets": "glanssot",
    "glanssots": "glanssot",
    "glanstiden": "glanstid",
    "glanstidens": "glanstid",
    "glanstider": "glanstid",
    "glanstiderna": "glanstid",
    "glanstidernas": "glanstid",
    "glanstiders": "glanstid",
    "glanstids": "glanstid",
    "glansullen": "glansull",
    "glansullens": "glansull",
    "glansulls": "glansull",
    "glapp": "glappa",
    "glappa": "glapp",
    "glappade": "glappa",
    "glappades": "glappa",
    "glappande": "glappa",
    "glappanden": "glappande",
    "glappandena": "glappande",
    "glappandenas": "glappande",
    "glappandens": "glappande",
    "glappandes": "glappande",
    "glappandet": "glappande",
    "glappandets": "glappande",
    "glappar": "glappa",
    "glappare": "glapp",
    "glappares": "glapp",
    "glappas": "glappa",
    "glappast": "glapp",
    "glappaste": "glapp",
    "glappastes": "glapp",
    "glappasts": "glapp",
    "glappat": "glappa",
    "glappats": "glappa",
    "glappe": "glapp",
    "glappen": "glapp",
    "glappens": "glapp",
    "glappes": "glapp",
    "glappet": "glapp",
    "glappets": "glapp",
    "glappheten": "glapphet",
    "glapphetens": "glapphet",
    "glapphets": "glapphet",
    "glapprummen": "glapprum",
    "glapprummens": "glapprum",
    "glapprummet": "glapprum",
    "glapprummets": "glapprum",
    "glapprums": "glapprum",
    "glapps": "glapp",
    "glappt": "glapp",
    "glappts": "glapp",
    "glarrar": "glarre",
    "glarrarna": "glarre",
    "glarrarnas": "glarre",
    "glarrars": "glarre",
    "glarren": "glarre",
    "glarrens": "glarre",
    "glarres": "glarre",
    "glas": "glasa",
    "glasad": "glasa",
    "glasade": "glasa",
    "glasades": "glasa",
    "glasads": "glasa",
    "glasande": "glasa",
    "glasanden": "glasande",
    "glasandena": "glasande",
    "glasandenas": "glasande",
    "glasandens": "glasande",
    "glasandes": "glasande",
    "glasandet": "glasande",
    "glasandets": "glasande",
    "glasar": "glasa",
    "glasartade": "glasartad",
    "glasartades": "glasartad",
    "glasartads": "glasartad",
    "glasartat": "glasartad",
    "glasartats": "glasartad",
    "glasas": "glasa",
    "glasat": "glasa",
    "glasats": "glasa",
    "glasbergen": "glasberg",
    "glasbergens": "glasberg",
    "glasberget": "glasberg",
    "glasbergets": "glasberg",
    "glasbergs": "glasberg",
    "glasbjörkar": "glasbjörk",
    "glasbjörkarna": "glasbjörk",
    "glasbjörkarnas": "glasbjörk",
    "glasbjörkars": "glasbjörk",
    "glasbjörken": "glasbjörk",
    "glasbjörkens": "glasbjörk",
    "glasbjörks": "glasbjörk",
    "glasblåsar": "glasblåsare",
    "glasblåsaren": "glasblåsare",
    "glasblåsarens": "glasblåsare",
    "glasblåsares": "glasblåsare",
    "glasblåsarna": "glasblåsare",
    "glasblåsarnas": "glasblåsare",
    "glasblåsarpip": "glasblåsarpipa",
    "glasblåsarpipan": "glasblåsarpipa",
    "glasblåsarpipans": "glasblåsarpipa",
    "glasblåsarpipas": "glasblåsarpipa",
    "glasblåsarpipe": "glasblåsarpipa",
    "glasblåsarpipor": "glasblåsarpipa",
    "glasblåsarpiporna": "glasblåsarpipa",
    "glasblåsarpipornas": "glasblåsarpipa",
    "glasblåsarpipors": "glasblåsarpipa",
    "glasblåsarpips": "glasblåsarpipa",
    "glasblåserier": "glasblåseri",
    "glasblåserierna": "glasblåseri",
    "glasblåseriernas": "glasblåseri",
    "glasblåseriers": "glasblåseri",
    "glasblåseriet": "glasblåseri",
    "glasblåseriets": "glasblåseri",
    "glasblåseris": "glasblåseri",
    "glasblåserit": "glasblåseri",
    "glasblåserits": "glasblåseri",
    "glasblåsningar": "glasblåsning",
    "glasblåsningarna": "glasblåsning",
    "glasblåsningarnas": "glasblåsning",
    "glasblåsningars": "glasblåsning",
    "glasblåsningen": "glasblåsning",
    "glasblåsningens": "glasblåsning",
    "glasblåsnings": "glasblåsning",
    "glasbruken": "glasbruk",
    "glasbrukens": "glasbruk",
    "glasbruket": "glasbruk",
    "glasbrukets": "glasbruk",
    "glasbruks": "glasbruk",
    "glasbultar": "glasbult",
    "glasbultarna": "glasbult",
    "glasbultarnas": "glasbult",
    "glasbultars": "glasbult",
    "glasbulten": "glasbult",
    "glasbultens": "glasbult",
    "glasbults": "glasbult",
    "glasburkar": "glasburk",
    "glasburkarna": "glasburk",
    "glasburkarnas": "glasburk",
    "glasburkars": "glasburk",
    "glasburken": "glasburk",
    "glasburkens": "glasburk",
    "glasburks": "glasburk",
    "glasdörrar": "glasdörr",
    "glasdörrarna": "glasdörr",
    "glasdörrarnas": "glasdörr",
    "glasdörrars": "glasdörr",
    "glasdörren": "glasdörr",
    "glasdörrens": "glasdörr",
    "glasdörrs": "glasdörr",
    "glasen": "glas",
    "glasens": "glas",
    "glaserad": "glasera",
    "glaserade": "glasera",
    "glaserades": "glasera",
    "glaserads": "glasera",
    "glaserande": "glasera",
    "glaseranden": "glaserande",
    "glaserandena": "glaserande",
    "glaserandenas": "glaserande",
    "glaserandens": "glaserande",
    "glaserandes": "glaserande",
    "glaserandet": "glaserande",
    "glaserandets": "glaserande",
    "glaserar": "glasera",
    "glaseras": "glasera",
    "glaserat": "glasera",
    "glaserats": "glasera",
    "glaserbara": "glaserbar",
    "glaserbarare": "glaserbar",
    "glaserbarares": "glaserbar",
    "glaserbaras": "glaserbar",
    "glaserbarast": "glaserbar",
    "glaserbaraste": "glaserbar",
    "glaserbarastes": "glaserbar",
    "glaserbarasts": "glaserbar",
    "glaserbare": "glaserbar",
    "glaserbares": "glaserbar",
    "glaserbarheten": "glaserbarhet",
    "glaserbarhetens": "glaserbarhet",
    "glaserbarhets": "glaserbarhet",
    "glaserbars": "glaserbar",
    "glaserbart": "glaserbar",
    "glaserbarts": "glaserbar",
    "glaseringar": "glasering",
    "glaseringarna": "glasering",
    "glaseringarnas": "glasering",
    "glaseringars": "glasering",
    "glaseringen": "glasering",
    "glaseringens": "glasering",
    "glaserings": "glasering",
    "glaset": "glas",
    "glasets": "glas",
    "glasfiberförstärkta": "glasfiberförstärkt",
    "glasfiberförstärktas": "glasfiberförstärkt",
    "glasfiberförstärkte": "glasfiberförstärkt",
    "glasfiberförstärktes": "glasfiberförstärkt",
    "glasfiberförstärkts": "glasfiberförstärkt",
    "glasfibern": "glasfiber",
    "glasfiberns": "glasfiber",
    "glasfibers": "glasfiber",
    "glasfiberullen": "glasfiberull",
    "glasfiberullens": "glasfiberull",
    "glasfiberulls": "glasfiberull",
    "glasfiberväven": "glasfiberväv",
    "glasfibervävens": "glasfiberväv",
    "glasfibervävs": "glasfiberväv",
    "glasfibrer": "glasfiber",
    "glasfibrerna": "glasfiber",
    "glasfibrernas": "glasfiber",
    "glasfibrers": "glasfiber",
    "glasflask": "glasflaska",
    "glasflaskan": "glasflaska",
    "glasflaskans": "glasflaska",
    "glasflaskas": "glasflaska",
    "glasflaske": "glasflaska",
    "glasflaskor": "glasflaska",
    "glasflaskorna": "glasflaska",
    "glasflaskornas": "glasflaska",
    "glasflaskors": "glasflaska",
    "glasflussen": "glasfluss",
    "glasflussens": "glasfluss",
    "glasframställningar": "glasframställning",
    "glasframställningarna": "glasframställning",
    "glasframställningarnas": "glasframställning",
    "glasframställningars": "glasframställning",
    "glasframställningen": "glasframställning",
    "glasframställningens": "glasframställning",
    "glasframställnings": "glasframställning",
    "glasföremålen": "glasföremål",
    "glasföremålens": "glasföremål",
    "glasföremålet": "glasföremål",
    "glasföremålets": "glasföremål",
    "glasföremåls": "glasföremål",
    "glashala": "glashal",
    "glashalare": "glashal",
    "glashalares": "glashal",
    "glashalas": "glashal",
    "glashalast": "glashal",
    "glashalaste": "glashal",
    "glashalastes": "glashal",
    "glashalasts": "glashal",
    "glashale": "glashal",
    "glashales": "glashal",
    "glashals": "glashal",
    "glashalt": "glashal",
    "glashalts": "glashal",
    "glashanddukar": "glashandduk",
    "glashanddukarna": "glashandduk",
    "glashanddukarnas": "glashandduk",
    "glashanddukars": "glashandduk",
    "glashandduken": "glashandduk",
    "glashanddukens": "glashandduk",
    "glashandduks": "glashandduk",
    "glasharmonik": "glasharmonika",
    "glasharmonikan": "glasharmonika",
    "glasharmonikans": "glasharmonika",
    "glasharmonikas": "glasharmonika",
    "glasharmonike": "glasharmonika",
    "glasharmonikor": "glasharmonika",
    "glasharmonikorna": "glasharmonika",
    "glasharmonikornas": "glasharmonika",
    "glasharmonikors": "glasharmonika",
    "glasharmoniks": "glasharmonika",
    "glashusen": "glashus",
    "glashusens": "glashus",
    "glashuset": "glashus",
    "glashusets": "glashus",
    "glashuvar": "glashuv",
    "glashuvarna": "glashuv",
    "glashuvarnas": "glashuv",
    "glashuvars": "glashuv",
    "glashuven": "glashuv",
    "glashuvens": "glashuv",
    "glashuvs": "glashuv",
    "glashyll": "glashylla",
    "glashyllan": "glashylla",
    "glashyllans": "glashylla",
    "glashyllas": "glashylla",
    "glashylle": "glashylla",
    "glashyllor": "glashylla",
    "glashyllorna": "glashylla",
    "glashyllornas": "glashylla",
    "glashyllors": "glashylla",
    "glashylls": "glashylla",
    "glashytt": "glashytta",
    "glashyttan": "glashytta",
    "glashyttans": "glashytta",
    "glashyttas": "glashytta",
    "glashytte": "glashytta",
    "glashyttor": "glashytta",
    "glashyttorna": "glashytta",
    "glashyttornas": "glashytta",
    "glashyttors": "glashytta",
    "glashytts": "glashytta",
    "glasiga": "glasig",
    "glasigare": "glasig",
    "glasigares": "glasig",
    "glasigas": "glasig",
    "glasigast": "glasig",
    "glasigaste": "glasig",
    "glasigastes": "glasig",
    "glasigasts": "glasig",
    "glasige": "glasig",
    "glasiges": "glasig",
    "glasigheten": "glasighet",
    "glasighetens": "glasighet",
    "glasigheter": "glasighet",
    "glasigheterna": "glasighet",
    "glasigheternas": "glasighet",
    "glasigheters": "glasighet",
    "glasighets": "glasighet",
    "glasigloer": "glasiglo",
    "glasigloerna": "glasiglo",
    "glasigloernas": "glasiglo",
    "glasigloers": "glasiglo",
    "glasiglon": "glasiglo",
    "glasiglons": "glasiglo",
    "glasiglor": "glasiglo",
    "glasiglorna": "glasiglo",
    "glasiglornas": "glasiglo",
    "glasiglors": "glasiglo",
    "glasiglos": "glasiglo",
    "glasiglosar": "glasiglo",
    "glasiglosarna": "glasiglo",
    "glasiglosarnas": "glasiglo",
    "glasiglosars": "glasiglo",
    "glasigs": "glasig",
    "glasigt": "glasig",
    "glasigts": "glasig",
    "glasiologiska": "glasiologisk",
    "glasiologiskare": "glasiologisk",
    "glasiologiskares": "glasiologisk",
    "glasiologiskas": "glasiologisk",
    "glasiologiskast": "glasiologisk",
    "glasiologiskaste": "glasiologisk",
    "glasiologiskastes": "glasiologisk",
    "glasiologiskasts": "glasiologisk",
    "glasiologiske": "glasiologisk",
    "glasiologiskes": "glasiologisk",
    "glasiologisks": "glasiologisk",
    "glasiologiskt": "glasiologisk",
    "glasiologiskts": "glasiologisk",
    "glaskannan": "glaskanna",
    "glaskannans": "glaskanna",
    "glaskannas": "glaskanna",
    "glaskanne": "glaskanna",
    "glaskannor": "glaskanna",
    "glaskannorna": "glaskanna",
    "glaskannornas": "glaskanna",
    "glaskannors": "glaskanna",
    "glasklara": "glasklar",
    "glasklarare": "glasklar",
    "glasklarares": "glasklar",
    "glasklaras": "glasklar",
    "glasklarast": "glasklar",
    "glasklaraste": "glasklar",
    "glasklarastes": "glasklar",
    "glasklarasts": "glasklar",
    "glasklare": "glasklar",
    "glasklares": "glasklar",
    "glasklars": "glasklar",
    "glasklart": "glasklar",
    "glasklarts": "glasklar",
    "glasklock": "glasklocka",
    "glasklockan": "glasklocka",
    "glasklockans": "glasklocka",
    "glasklockas": "glasklocka",
    "glasklocke": "glasklocka",
    "glasklockor": "glasklocka",
    "glasklockorna": "glasklocka",
    "glasklockornas": "glasklocka",
    "glasklockors": "glasklocka",
    "glasklocks": "glasklocka",
    "glaskloten": "glasklot",
    "glasklotens": "glasklot",
    "glasklotet": "glasklot",
    "glasklotets": "glasklot",
    "glasklots": "glasklot",
    "glaskolvar": "glaskolv",
    "glaskolvarna": "glaskolv",
    "glaskolvarnas": "glaskolv",
    "glaskolvars": "glaskolv",
    "glaskolven": "glaskolv",
    "glaskolvens": "glaskolv",
    "glaskolvs": "glaskolv",
    "glaskroppar": "glaskropp",
    "glaskropparna": "glaskropp",
    "glaskropparnas": "glaskropp",
    "glaskroppars": "glaskropp",
    "glaskroppen": "glaskropp",
    "glaskroppens": "glaskropp",
    "glaskropps": "glaskropp",
    "glaskul": "glaskula",
    "glaskulan": "glaskula",
    "glaskulans": "glaskula",
    "glaskulas": "glaskula",
    "glaskule": "glaskula",
    "glaskulor": "glaskula",
    "glaskulorna": "glaskula",
    "glaskulornas": "glaskula",
    "glaskulors": "glaskula",
    "glaskuls": "glaskula",
    "glasmassan": "glasmassa",
    "glasmassans": "glasmassa",
    "glasmassas": "glasmassa",
    "glasmasse": "glasmassa",
    "glasmontern": "glasmonter",
    "glasmonterns": "glasmonter",
    "glasmonters": "glasmonter",
    "glasmontrar": "glasmonter",
    "glasmontrarna": "glasmonter",
    "glasmontrarnas": "glasmonter",
    "glasmontrars": "glasmonter",
    "glasmästar": "glasmästare",
    "glasmästardiamanten": "glasmästardiamant",
    "glasmästardiamantens": "glasmästardiamant",
    "glasmästardiamanter": "glasmästardiamant",
    "glasmästardiamanterna": "glasmästardiamant",
    "glasmästardiamanternas": "glasmästardiamant",
    "glasmästardiamanters": "glasmästardiamant",
    "glasmästardiamants": "glasmästardiamant",
    "glasmästaren": "glasmästare",
    "glasmästarens": "glasmästare",
    "glasmästares": "glasmästare",
    "glasmästarna": "glasmästare",
    "glasmästarnas": "glasmästare",
    "glasmästarsillen": "glasmästarsill",
    "glasmästarsillens": "glasmästarsill",
    "glasmästarsills": "glasmästarsill",
    "glasmästerier": "glasmästeri",
    "glasmästerierna": "glasmästeri",
    "glasmästeriernas": "glasmästeri",
    "glasmästeriers": "glasmästeri",
    "glasmästeriet": "glasmästeri",
    "glasmästeriets": "glasmästeri",
    "glasmästeris": "glasmästeri",
    "glasmästerit": "glasmästeri",
    "glasmästerits": "glasmästeri",
    "glasmålningar": "glasmålning",
    "glasmålningarna": "glasmålning",
    "glasmålningarnas": "glasmålning",
    "glasmålningars": "glasmålning",
    "glasmålningen": "glasmålning",
    "glasmålningens": "glasmålning",
    "glasmålnings": "glasmålning",
    "glasnosten": "glasnost",
    "glasnostens": "glasnost",
    "glasnosts": "glasnost",
    "glasprisman": "glasprisma",
    "glasprismans": "glasprisma",
    "glasprismas": "glasprisma",
    "glasprismat": "glasprisma",
    "glasprismats": "glasprisma",
    "glasprismer": "glasprisma",
    "glasprismerna": "glasprisma",
    "glasprismernas": "glasprisma",
    "glasprismers": "glasprisma",
    "glasprismor": "glasprisma",
    "glasprismorna": "glasprisma",
    "glasprismornas": "glasprisma",
    "glasprismors": "glasprisma",
    "glasrengöringen": "glasrengöring",
    "glasrengöringens": "glasrengöring",
    "glasrengörings": "glasrengöring",
    "glasrutan": "glasruta",
    "glasrutans": "glasruta",
    "glasrutas": "glasruta",
    "glasrute": "glasruta",
    "glasrutor": "glasruta",
    "glasrutorna": "glasruta",
    "glasrutornas": "glasruta",
    "glasrutors": "glasruta",
    "glasrören": "glasrör",
    "glasrörens": "glasrör",
    "glasröret": "glasrör",
    "glasrörets": "glasrör",
    "glasrörs": "glasrör",
    "glassade": "glassa",
    "glassades": "glassa",
    "glassande": "glassa",
    "glassanden": "glassande",
    "glassandena": "glassande",
    "glassandenas": "glassande",
    "glassandens": "glassande",
    "glassandes": "glassande",
    "glassandet": "glassande",
    "glassandets": "glassande",
    "glassar": "glassa",
    "glassarna": "glass",
    "glassarnas": "glass",
    "glassars": "glass",
    "glassas": "glassa",
    "glassat": "glassa",
    "glassats": "glassa",
    "glassbomben": "glassbomb",
    "glassbombens": "glassbomb",
    "glassbomber": "glassbomb",
    "glassbomberna": "glassbomb",
    "glassbombernas": "glassbomb",
    "glassbombers": "glassbomb",
    "glassbombs": "glassbomb",
    "glassbägar": "glassbägare",
    "glassbägaren": "glassbägare",
    "glassbägarens": "glassbägare",
    "glassbägares": "glassbägare",
    "glassbägarna": "glassbägare",
    "glassbägarnas": "glassbägare",
    "glassdesserten": "glassdessert",
    "glassdessertens": "glassdessert",
    "glassdesserter": "glassdessert",
    "glassdesserterna": "glassdessert",
    "glassdesserternas": "glassdessert",
    "glassdesserters": "glassdessert",
    "glassdesserts": "glassdessert",
    "glassen": "glass",
    "glassens": "glass",
    "glasser": "glass",
    "glasserna": "glass",
    "glassernas": "glass",
    "glassers": "glass",
    "glassiga": "glassig",
    "glassigare": "glassig",
    "glassigares": "glassig",
    "glassigas": "glassig",
    "glassigast": "glassig",
    "glassigaste": "glassig",
    "glassigastes": "glassig",
    "glassigasts": "glassig",
    "glassige": "glassig",
    "glassiges": "glassig",
    "glassigheten": "glassighet",
    "glassighetens": "glassighet",
    "glassighets": "glassighet",
    "glassigs": "glassig",
    "glassigt": "glassig",
    "glassigts": "glassig",
    "glasskivan": "glasskiva",
    "glasskivans": "glasskiva",
    "glasskivas": "glasskiva",
    "glasskive": "glasskiva",
    "glasskivor": "glasskiva",
    "glasskivorna": "glasskiva",
    "glasskivornas": "glasskiva",
    "glasskivors": "glasskiva",
    "glasskärar": "glasskärare",
    "glasskärardiamanten": "glasskärardiamant",
    "glasskärardiamantens": "glasskärardiamant",
    "glasskärardiamanter": "glasskärardiamant",
    "glasskärardiamanterna": "glasskärardiamant",
    "glasskärardiamanternas": "glasskärardiamant",
    "glasskärardiamanters": "glasskärardiamant",
    "glasskärardiamants": "glasskärardiamant",
    "glasskäraren": "glasskärare",
    "glasskärarens": "glasskärare",
    "glasskärares": "glasskärare",
    "glasskärarna": "glasskärare",
    "glasskärarnas": "glasskärare",
    "glasslipar": "glasslipare",
    "glassliparen": "glasslipare",
    "glassliparens": "glasslipare",
    "glasslipares": "glasslipare",
    "glassliparna": "glasslipare",
    "glassliparnas": "glasslipare",
    "glassmaskinen": "glassmaskin",
    "glassmaskinens": "glassmaskin",
    "glassmaskiner": "glassmaskin",
    "glassmaskinerna": "glassmaskin",
    "glassmaskinernas": "glassmaskin",
    "glassmaskiners": "glassmaskin",
    "glassmaskins": "glassmaskin",
    "glasspinn": "glasspinne",
    "glasspinnar": "glasspinne",
    "glasspinnarna": "glasspinne",
    "glasspinnarnas": "glasspinne",
    "glasspinnars": "glasspinne",
    "glasspinnen": "glasspinne",
    "glasspinnens": "glasspinne",
    "glasspinnes": "glasspinne",
    "glasspinns": "glasspinne",
    "glassrecepten": "glassrecept",
    "glassreceptens": "glassrecept",
    "glassreceptet": "glassrecept",
    "glassreceptets": "glassrecept",
    "glassrecepts": "glassrecept",
    "glasstrutar": "glasstrut",
    "glasstrutarna": "glasstrut",
    "glasstrutarnas": "glasstrut",
    "glasstrutars": "glasstrut",
    "glasstruten": "glasstrut",
    "glasstrutens": "glasstrut",
    "glasstruts": "glasstrut",
    "glasstårt": "glasstårta",
    "glasstårtan": "glasstårta",
    "glasstårtans": "glasstårta",
    "glasstårtas": "glasstårta",
    "glasstårte": "glasstårta",
    "glasstårtor": "glasstårta",
    "glasstårtorna": "glasstårta",
    "glasstårtornas": "glasstårta",
    "glasstårtors": "glasstårta",
    "glasstårts": "glasstårta",
    "glasullen": "glasull",
    "glasullens": "glasull",
    "glasulls": "glasull",
    "glasvakten": "glasvakt",
    "glasvaktens": "glasvakt",
    "glasvakter": "glasvakt",
    "glasvakterna": "glasvakt",
    "glasvakternas": "glasvakt",
    "glasvakters": "glasvakt",
    "glasvakts": "glasvakt",
    "glasvarar": "glasvar",
    "glasvararna": "glasvar",
    "glasvararnas": "glasvar",
    "glasvarars": "glasvar",
    "glasvaren": "glasvar",
    "glasvarens": "glasvar",
    "glasvars": "glasvar",
    "glasverand": "glasveranda",
    "glasverandan": "glasveranda",
    "glasverandans": "glasveranda",
    "glasverandas": "glasveranda",
    "glasverande": "glasveranda",
    "glasverandor": "glasveranda",
    "glasverandorna": "glasveranda",
    "glasverandornas": "glasveranda",
    "glasverandors": "glasveranda",
    "glasverands": "glasveranda",
    "glasvetes": "glasvete",
    "glasvetet": "glasvete",
    "glasvetets": "glasvete",
    "glasvingefjärilar": "glasvingefjäril",
    "glasvingefjärilarna": "glasvingefjäril",
    "glasvingefjärilarnas": "glasvingefjäril",
    "glasvingefjärilars": "glasvingefjäril",
    "glasvingefjärilen": "glasvingefjäril",
    "glasvingefjärilens": "glasvingefjäril",
    "glasvingefjäriln": "glasvingefjäril",
    "glasvingefjärilns": "glasvingefjäril",
    "glasvingefjärils": "glasvingefjäril",
    "glasväggar": "glasvägg",
    "glasväggarna": "glasvägg",
    "glasväggarnas": "glasvägg",
    "glasväggars": "glasvägg",
    "glasväggen": "glasvägg",
    "glasväggens": "glasvägg",
    "glasväggs": "glasvägg",
    "glasvätskan": "glasvätska",
    "glasvätskans": "glasvätska",
    "glasvätskas": "glasvätska",
    "glasvätske": "glasvätska",
    "glasyren": "glasyr",
    "glasyrens": "glasyr",
    "glasyrer": "glasyr",
    "glasyrerna": "glasyr",
    "glasyrernas": "glasyr",
    "glasyrers": "glasyr",
    "glasyrs": "glasyr",
    "glasäpplen": "glasäpple",
    "glasäpplena": "glasäpple",
    "glasäpplenas": "glasäpple",
    "glasäpplens": "glasäpple",
    "glasäpples": "glasäpple",
    "glasäpplet": "glasäpple",
    "glasäpplets": "glasäpple",
    "glasäppls": "glasäpple",
    "glasålar": "glasål",
    "glasålarna": "glasål",
    "glasålarnas": "glasål",
    "glasålars": "glasål",
    "glasålen": "glasål",
    "glasålens": "glasål",
    "glasåls": "glasål",
    "glasögas": "glasöga",
    "glasögat": "glasöga",
    "glasögats": "glasöga",
    "glasögon": "glasöga",
    "glasögonbjörnar": "glasögonbjörn",
    "glasögonbjörnarna": "glasögonbjörn",
    "glasögonbjörnarnas": "glasögonbjörn",
    "glasögonbjörnars": "glasögonbjörn",
    "glasögonbjörnen": "glasögonbjörn",
    "glasögonbjörnens": "glasögonbjörn",
    "glasögonbjörns": "glasögonbjörn",
    "glasögonbåg": "glasögonbåge",
    "glasögonbågar": "glasögonbåge",
    "glasögonbågarna": "glasögonbåge",
    "glasögonbågarnas": "glasögonbåge",
    "glasögonbågars": "glasögonbåge",
    "glasögonbågen": "glasögonbåge",
    "glasögonbågens": "glasögonbåge",
    "glasögonbåges": "glasögonbåge",
    "glasögonbågs": "glasögonbåge",
    "glasögonen": "glasögon",
    "glasögonens": "glasögon",
    "glasögonfodralen": "glasögonfodral",
    "glasögonfodralens": "glasögonfodral",
    "glasögonfodralet": "glasögonfodral",
    "glasögonfodralets": "glasögonfodral",
    "glasögonfodrals": "glasögonfodral",
    "glasögonormar": "glasögonorm",
    "glasögonormarna": "glasögonorm",
    "glasögonormarnas": "glasögonorm",
    "glasögonormars": "glasögonorm",
    "glasögonormen": "glasögonorm",
    "glasögonormens": "glasögonorm",
    "glasögonorms": "glasögonorm",
    "glasögons": "glasögon",
    "glasörten": "glasört",
    "glasörtens": "glasört",
    "glasörts": "glasört",
    "glatt": "glatta",
    "glatta": "glatt",
    "glattad": "glatta",
    "glattade": "glatta",
    "glattades": "glatta",
    "glattads": "glatta",
    "glattande": "glatta",
    "glattanden": "glattande",
    "glattandena": "glattande",
    "glattandenas": "glattande",
    "glattandens": "glattande",
    "glattandes": "glattande",
    "glattandet": "glattande",
    "glattandets": "glattande",
    "glattar": "glatta",
    "glattare": "glatt",
    "glattares": "glatt",
    "glattas": "glatta",
    "glattast": "glatt",
    "glattaste": "glatt",
    "glattastes": "glatt",
    "glattasts": "glatt",
    "glattat": "glatta",
    "glattats": "glatta",
    "glatte": "glatt",
    "glattes": "glatt",
    "glattheten": "glatthet",
    "glatthetens": "glatthet",
    "glatthets": "glatthet",
    "glattisen": "glattis",
    "glattisens": "glattis",
    "glattmaskar": "glattmask",
    "glattmaskarna": "glattmask",
    "glattmaskarnas": "glattmask",
    "glattmaskars": "glattmask",
    "glattmasken": "glattmask",
    "glattmaskens": "glattmask",
    "glattmasks": "glattmask",
    "glattningar": "glattning",
    "glattningarna": "glattning",
    "glattningarnas": "glattning",
    "glattningars": "glattning",
    "glattningen": "glattning",
    "glattningens": "glattning",
    "glattnings": "glattning",
    "glatts": "glatt",
    "glaubersaltet": "glaubersalt",
    "glaubersaltets": "glaubersalt",
    "glaubersalts": "glaubersalt",
    "glaukomet": "glaukom",
    "glaukomets": "glaukom",
    "glaukoms": "glaukom",
    "glavar": "glav",
    "glavarna": "glav",
    "glavarnas": "glav",
    "glavars": "glav",
    "glaven": "glav",
    "glavens": "glav",
    "glavs": "glav",
    "gled": "glida",
    "gleds": "glida",
    "glenchecks": "glencheck",
    "gles": "glesa",
    "glesa": "gles",
    "glesad": "glesa",
    "glesade": "glesa",
    "glesades": "glesa",
    "glesads": "glesa",
    "glesande": "glesa",
    "glesanden": "glesande",
    "glesandena": "glesande",
    "glesandenas": "glesande",
    "glesandens": "glesande",
    "glesandes": "glesande",
    "glesandet": "glesande",
    "glesandets": "glesande",
    "glesar": "glesa",
    "glesare": "gles",
    "glesares": "gles",
    "glesas": "glesa",
    "glesast": "gles",
    "glesaste": "gles",
    "glesastes": "gles",
    "glesasts": "gles",
    "glesat": "glesa",
    "glesats": "glesa",
    "glesbygden": "glesbygd",
    "glesbygdens": "glesbygd",
    "glesbygder": "glesbygd",
    "glesbygderna": "glesbygd",
    "glesbygdernas": "glesbygd",
    "glesbygders": "glesbygd",
    "glesbygds": "glesbygd",
    "glesbygdsbodd": "glesbygdsbo",
    "glesbygdsbodda": "glesbygdsbo",
    "glesbygdsboddas": "glesbygdsbo",
    "glesbygdsbodde": "glesbygdsbo",
    "glesbygdsboddes": "glesbygdsbo",
    "glesbygdsbodds": "glesbygdsbo",
    "glesbygdsboende": "glesbygdsbo",
    "glesbygdsboendes": "glesbygdsbo",
    "glesbygdsbor": "glesbygdsbo",
    "glesbygdsbos": "glesbygdsbo",
    "glesbygdsbott": "glesbygdsbo",
    "glesbygdsbotts": "glesbygdsbo",
    "glese": "gles",
    "gleses": "gles",
    "glesheten": "gleshet",
    "gleshetens": "gleshet",
    "gleshets": "gleshet",
    "glesn": "glesna",
    "glesnad": "glesna",
    "glesnade": "glesna",
    "glesnades": "glesna",
    "glesnads": "glesna",
    "glesnande": "glesna",
    "glesnanden": "glesnande",
    "glesnandena": "glesnande",
    "glesnandenas": "glesnande",
    "glesnandens": "glesnande",
    "glesnandes": "glesnande",
    "glesnandet": "glesnande",
    "glesnandets": "glesnande",
    "glesnar": "glesna",
    "glesnas": "glesna",
    "glesnat": "glesna",
    "glesnats": "glesna",
    "glest": "gles",
    "glests": "gles",
    "gleten": "glete",
    "gletens": "glete",
    "gletes": "glete",
    "gletet": "glete",
    "gletets": "glete",
    "gletschern": "gletscher",
    "gletscherns": "gletscher",
    "gletschers": "gletscher",
    "gletschrar": "gletscher",
    "gletschrarna": "gletscher",
    "gletschrarnas": "gletscher",
    "gletschrars": "gletscher",
    "glian": "glia",
    "glians": "glia",
    "glias": "glia",
    "glid": "glida",
    "glidande": "glida",
    "glidanden": "glidande",
    "glidandena": "glidande",
    "glidandenas": "glidande",
    "glidandens": "glidande",
    "glidandes": "glidande",
    "glidandet": "glidande",
    "glidandets": "glidande",
    "glidas": "glida",
    "glide": "glida",
    "gliden": "glida",
    "glidens": "glida",
    "glider": "glida",
    "glides": "glida",
    "glidet": "glida",
    "glidets": "glida",
    "glidflykten": "glidflykt",
    "glidflyktens": "glidflykt",
    "glidflykts": "glidflykt",
    "glidfriktionen": "glidfriktion",
    "glidfriktionens": "glidfriktion",
    "glidfriktioner": "glidfriktion",
    "glidfriktionerna": "glidfriktion",
    "glidfriktionernas": "glidfriktion",
    "glidfriktioners": "glidfriktion",
    "glidfriktions": "glidfriktion",
    "glidit": "glida",
    "glidits": "glida",
    "glidkontakten": "glidkontakt",
    "glidkontaktens": "glidkontakt",
    "glidkontakter": "glidkontakt",
    "glidkontakterna": "glidkontakt",
    "glidkontakternas": "glidkontakt",
    "glidkontakters": "glidkontakt",
    "glidkontakts": "glidkontakt",
    "glidkrämen": "glidkräm",
    "glidkrämens": "glidkräm",
    "glidkrämer": "glidkräm",
    "glidkrämerna": "glidkräm",
    "glidkrämernas": "glidkräm",
    "glidkrämers": "glidkräm",
    "glidkräms": "glidkräm",
    "glidlagerna": "glidlager",
    "glidlagernas": "glidlager",
    "glidlagers": "glidlager",
    "glidlagren": "glidlager",
    "glidlagrens": "glidlager",
    "glidlagret": "glidlager",
    "glidlagrets": "glidlager",
    "glidljuden": "glidljud",
    "glidljudens": "glidljud",
    "glidljudet": "glidljud",
    "glidljudets": "glidljud",
    "glidljuds": "glidljud",
    "glidmedels": "glidmedel",
    "glidmedlen": "glidmedel",
    "glidmedlens": "glidmedel",
    "glidmedlet": "glidmedel",
    "glidmedlets": "glidmedel",
    "glidna": "glida",
    "glidnas": "glida",
    "glidne": "glida",
    "glidnes": "glida",
    "glidningar": "glidning",
    "glidningarna": "glidning",
    "glidningarnas": "glidning",
    "glidningars": "glidning",
    "glidningen": "glidning",
    "glidningens": "glidning",
    "glidnings": "glidning",
    "glids": "glida",
    "glidsalv": "glidsalva",
    "glidsalvan": "glidsalva",
    "glidsalvans": "glidsalva",
    "glidsalvas": "glidsalva",
    "glidsalve": "glidsalva",
    "glidsalvor": "glidsalva",
    "glidsalvorna": "glidsalva",
    "glidsalvornas": "glidsalva",
    "glidsalvors": "glidsalva",
    "glidsalvs": "glidsalva",
    "glidtacklingar": "glidtackling",
    "glidtacklingarna": "glidtackling",
    "glidtacklingarnas": "glidtackling",
    "glidtacklingars": "glidtackling",
    "glidtacklingen": "glidtackling",
    "glidtacklingens": "glidtackling",
    "glidtacklings": "glidtackling",
    "glien": "gli",
    "gliens": "gli",
    "gliet": "gli",
    "gliets": "gli",
    "glim": "glimma",
    "gliman": "glima",
    "glimans": "glima",
    "glimas": "glima",
    "glimlamp": "glimlampa",
    "glimlampan": "glimlampa",
    "glimlampans": "glimlampa",
    "glimlampas": "glimlampa",
    "glimlampe": "glimlampa",
    "glimlampor": "glimlampa",
    "glimlamporna": "glimlampa",
    "glimlampornas": "glimlampa",
    "glimlampors": "glimlampa",
    "glimlamps": "glimlampa",
    "glimljuset": "glimljus",
    "glimljusets": "glimljus",
    "glimmade": "glimma",
    "glimmades": "glimma",
    "glimmande": "glimma",
    "glimmanden": "glimmande",
    "glimmandena": "glimmande",
    "glimmandenas": "glimmande",
    "glimmandens": "glimmande",
    "glimmandes": "glimmande",
    "glimmandet": "glimmande",
    "glimmandets": "glimmande",
    "glimmar": "glimma",
    "glimmas": "glimma",
    "glimmat": "glimma",
    "glimmats": "glimma",
    "glimmen": "glim",
    "glimmens": "glim",
    "glimmer": "glimra",
    "glimmern": "glimmer",
    "glimmerns": "glimmer",
    "glimmers": "glimmer",
    "glimrade": "glimra",
    "glimrades": "glimra",
    "glimrande": "glimra",
    "glimranden": "glimrande",
    "glimrandena": "glimrande",
    "glimrandenas": "glimrande",
    "glimrandens": "glimrande",
    "glimrandes": "glimrande",
    "glimrandet": "glimrande",
    "glimrandets": "glimrande",
    "glimrar": "glimra",
    "glimras": "glimra",
    "glimrat": "glimra",
    "glimrats": "glimra",
    "glimret": "glimmer",
    "glimrets": "glimmer",
    "glims": "glim",
    "glimt": "glimta",
    "glimtade": "glimta",
    "glimtades": "glimta",
    "glimtande": "glimta",
    "glimtanden": "glimtande",
    "glimtandena": "glimtande",
    "glimtandenas": "glimtande",
    "glimtandens": "glimtande",
    "glimtandes": "glimtande",
    "glimtandet": "glimtande",
    "glimtandets": "glimtande",
    "glimtar": "glimta",
    "glimtarna": "glimt",
    "glimtarnas": "glimt",
    "glimtars": "glimt",
    "glimtas": "glimta",
    "glimtat": "glimta",
    "glimtats": "glimta",
    "glimten": "glimt",
    "glimtens": "glimt",
    "glimts": "glimt",
    "glimtändar": "glimtändare",
    "glimtändaren": "glimtändare",
    "glimtändarens": "glimtändare",
    "glimtändares": "glimtändare",
    "glimtändarna": "glimtändare",
    "glimtändarnas": "glimtändare",
    "glin": "gli",
    "glina": "gli",
    "glinas": "gli",
    "glinder": "glindra",
    "glinderna": "glinder",
    "glindernas": "glinder",
    "glinders": "glinder",
    "glindrade": "glindra",
    "glindrades": "glindra",
    "glindrande": "glindra",
    "glindranden": "glindrande",
    "glindrandena": "glindrande",
    "glindrandenas": "glindrande",
    "glindrandens": "glindrande",
    "glindrandes": "glindrande",
    "glindrandet": "glindrande",
    "glindrandets": "glindrande",
    "glindrar": "glindra",
    "glindras": "glindra",
    "glindrat": "glindra",
    "glindrats": "glindra",
    "glindren": "glinder",
    "glindrens": "glinder",
    "glindret": "glinder",
    "glindrets": "glinder",
    "glins": "gli",
    "gliomen": "gliom",
    "gliomens": "gliom",
    "gliomet": "gliom",
    "gliomets": "gliom",
    "glioms": "gliom",
    "glip": "glipa",
    "glipade": "glipa",
    "glipades": "glipa",
    "glipan": "glipa",
    "glipande": "glipa",
    "glipanden": "glipande",
    "glipandena": "glipande",
    "glipandenas": "glipande",
    "glipandens": "glipande",
    "glipandes": "glipande",
    "glipandet": "glipande",
    "glipandets": "glipande",
    "glipans": "glipa",
    "glipar": "glipa",
    "glipas": "glipa",
    "glipat": "glipa",
    "glipats": "glipa",
    "glipe": "glipa",
    "glipor": "glipa",
    "gliporna": "glipa",
    "glipornas": "glipa",
    "glipors": "glipa",
    "glips": "glipa",
    "gliringar": "gliring",
    "gliringarna": "gliring",
    "gliringarnas": "gliring",
    "gliringars": "gliring",
    "gliringen": "gliring",
    "gliringens": "gliring",
    "glirings": "gliring",
    "glis": "glisa",
    "glisande": "glisa",
    "glisanden": "glisande",
    "glisandena": "glisande",
    "glisandenas": "glisande",
    "glisandens": "glisande",
    "glisandes": "glisande",
    "glisandet": "glisande",
    "glisandets": "glisande",
    "glisar": "glis",
    "glisarna": "glis",
    "glisarnas": "glis",
    "glisars": "glis",
    "glisas": "glisa",
    "glisen": "glis",
    "glisens": "glis",
    "gliser": "glisa",
    "glises": "glisa",
    "glissandon": "glissando",
    "glissandona": "glissando",
    "glissandonas": "glissando",
    "glissandons": "glissando",
    "glissandos": "glissando",
    "glissandot": "glissando",
    "glissandots": "glissando",
    "glist": "glisa",
    "gliste": "glisa",
    "glistes": "glisa",
    "glists": "glisa",
    "glisörten": "glisört",
    "glisörtens": "glisört",
    "glisörter": "glisört",
    "glisörterna": "glisört",
    "glisörternas": "glisört",
    "glisörters": "glisört",
    "glisörts": "glisört",
    "glit": "gli",
    "glits": "gli",
    "glitter": "glittra",
    "glittergirlangen": "glittergirlang",
    "glittergirlangens": "glittergirlang",
    "glittergirlanger": "glittergirlang",
    "glittergirlangerna": "glittergirlang",
    "glittergirlangernas": "glittergirlang",
    "glittergirlangers": "glittergirlang",
    "glittergirlangs": "glittergirlang",
    "glitterglada": "glitterglad",
    "glittergladare": "glitterglad",
    "glittergladares": "glitterglad",
    "glittergladas": "glitterglad",
    "glittergladast": "glitterglad",
    "glittergladaste": "glitterglad",
    "glittergladastes": "glitterglad",
    "glittergladasts": "glitterglad",
    "glitterglade": "glitterglad",
    "glitterglades": "glitterglad",
    "glitterglads": "glitterglad",
    "glitterglatt": "glitterglad",
    "glitterglatts": "glitterglad",
    "glitterprydda": "glitterprydd",
    "glitterpryddare": "glitterprydd",
    "glitterpryddares": "glitterprydd",
    "glitterpryddas": "glitterprydd",
    "glitterpryddast": "glitterprydd",
    "glitterpryddaste": "glitterprydd",
    "glitterpryddastes": "glitterprydd",
    "glitterpryddasts": "glitterprydd",
    "glitterprydde": "glitterprydd",
    "glitterpryddes": "glitterprydd",
    "glitterprydds": "glitterprydd",
    "glitterprytt": "glitterprydd",
    "glitterprytts": "glitterprydd",
    "glitters": "glitter",
    "glittertrycket": "glittertryck",
    "glittertryckets": "glittertryck",
    "glittertrycks": "glittertryck",
    "glittrade": "glittra",
    "glittrades": "glittra",
    "glittrande": "glittra",
    "glittranden": "glittrande",
    "glittrandena": "glittrande",
    "glittrandenas": "glittrande",
    "glittrandens": "glittrande",
    "glittrandes": "glittrande",
    "glittrandet": "glittrande",
    "glittrandets": "glittrande",
    "glittrar": "glittra",
    "glittras": "glittra",
    "glittrat": "glittra",
    "glittrats": "glittra",
    "glittret": "glitter",
    "glittrets": "glitter",
    "glittriga": "glittrig",
    "glittrigare": "glittrig",
    "glittrigares": "glittrig",
    "glittrigas": "glittrig",
    "glittrigast": "glittrig",
    "glittrigaste": "glittrig",
    "glittrigastes": "glittrig",
    "glittrigasts": "glittrig",
    "glittrige": "glittrig",
    "glittriges": "glittrig",
    "glittrigheten": "glittrighet",
    "glittrighetens": "glittrighet",
    "glittrighets": "glittrighet",
    "glittrigs": "glittrig",
    "glittrigt": "glittrig",
    "glittrigts": "glittrig",
    "globala": "global",
    "globalare": "global",
    "globalares": "global",
    "globalas": "global",
    "globalast": "global",
    "globalaste": "global",
    "globalastes": "global",
    "globalasts": "global",
    "globale": "global",
    "globales": "global",
    "globals": "global",
    "globalt": "global",
    "globalts": "global",
    "globen": "glob",
    "globens": "glob",
    "glober": "glob",
    "globerna": "glob",
    "globernas": "glob",
    "globers": "glob",
    "globetrottern": "globetrotter",
    "globetrotterns": "globetrotter",
    "globetrotters": "globetrotter",
    "globetrottersarna": "globetrotter",
    "globetrottersarnas": "globetrotter",
    "globetrottersen": "globetrotter",
    "globetrottersens": "globetrotter",
    "globetrottrar": "globetrotter",
    "globetrottrarna": "globetrotter",
    "globetrottrarnas": "globetrotter",
    "globetrottrars": "globetrotter",
    "globs": "glob",
    "globulinen": "globulin",
    "globulinens": "globulin",
    "globuliner": "globulin",
    "globulinerna": "globulin",
    "globulinernas": "globulin",
    "globuliners": "globulin",
    "globulinet": "globulin",
    "globulinets": "globulin",
    "globulins": "globulin",
    "glodd": "glo",
    "glodda": "glo",
    "gloddas": "glo",
    "glodde": "glo",
    "gloddes": "glo",
    "glodds": "glo",
    "gloende": "glo",
    "gloenden": "gloende",
    "gloendena": "gloende",
    "gloendenas": "gloende",
    "gloendens": "gloende",
    "gloendes": "gloende",
    "gloendet": "gloende",
    "gloendets": "gloende",
    "glopar": "glop",
    "gloparna": "glop",
    "gloparnas": "glop",
    "glopars": "glop",
    "glopen": "glop",
    "glopens": "glop",
    "gloppet": "glopp",
    "gloppets": "glopp",
    "glopps": "glopp",
    "glops": "glop",
    "glor": "glo",
    "glori": "gloria",
    "glorian": "gloria",
    "glorians": "gloria",
    "glorias": "gloria",
    "glorie": "gloria",
    "glorifierad": "glorifiera",
    "glorifierade": "glorifiera",
    "glorifierades": "glorifiera",
    "glorifierads": "glorifiera",
    "glorifierande": "glorifiera",
    "glorifieranden": "glorifierande",
    "glorifierandena": "glorifierande",
    "glorifierandenas": "glorifierande",
    "glorifierandens": "glorifierande",
    "glorifierandes": "glorifierande",
    "glorifierandet": "glorifierande",
    "glorifierandets": "glorifierande",
    "glorifierar": "glorifiera",
    "glorifieras": "glorifiera",
    "glorifierat": "glorifiera",
    "glorifierats": "glorifiera",
    "glorifierbara": "glorifierbar",
    "glorifierbarare": "glorifierbar",
    "glorifierbarares": "glorifierbar",
    "glorifierbaras": "glorifierbar",
    "glorifierbarast": "glorifierbar",
    "glorifierbaraste": "glorifierbar",
    "glorifierbarastes": "glorifierbar",
    "glorifierbarasts": "glorifierbar",
    "glorifierbare": "glorifierbar",
    "glorifierbares": "glorifierbar",
    "glorifierbarheten": "glorifierbarhet",
    "glorifierbarhetens": "glorifierbarhet",
    "glorifierbarhets": "glorifierbarhet",
    "glorifierbars": "glorifierbar",
    "glorifierbart": "glorifierbar",
    "glorifierbarts": "glorifierbar",
    "glorifieringar": "glorifiering",
    "glorifieringarna": "glorifiering",
    "glorifieringarnas": "glorifiering",
    "glorifieringars": "glorifiering",
    "glorifieringen": "glorifiering",
    "glorifieringens": "glorifiering",
    "glorifierings": "glorifiering",
    "glorior": "gloria",
    "gloriorna": "gloria",
    "gloriornas": "gloria",
    "gloriors": "gloria",
    "gloris": "gloria",
    "gloriösa": "gloriös",
    "gloriösare": "gloriös",
    "gloriösares": "gloriös",
    "gloriösas": "gloriös",
    "gloriösast": "gloriös",
    "gloriösaste": "gloriös",
    "gloriösastes": "gloriös",
    "gloriösasts": "gloriös",
    "gloriöse": "gloriös",
    "gloriöses": "gloriös",
    "gloriöst": "gloriös",
    "gloriösts": "gloriös",
    "glos": "glosa",
    "glosan": "glosa",
    "glosans": "glosa",
    "glosas": "glosa",
    "glose": "glosa",
    "glosiga": "glosig",
    "glosigare": "glosig",
    "glosigares": "glosig",
    "glosigas": "glosig",
    "glosigast": "glosig",
    "glosigaste": "glosig",
    "glosigastes": "glosig",
    "glosigasts": "glosig",
    "glosige": "glosig",
    "glosiges": "glosig",
    "glosigs": "glosig",
    "glosigt": "glosig",
    "glosigts": "glosig",
    "glosor": "glosa",
    "glosorna": "glosa",
    "glosornas": "glosa",
    "glosors": "glosa",
    "gloss": "glossa",
    "glossan": "glossa",
    "glossans": "glossa",
    "glossaren": "glossar",
    "glossarens": "glossar",
    "glossarer": "glossar",
    "glossarerna": "glossar",
    "glossarernas": "glossar",
    "glossarers": "glossar",
    "glossaret": "glossar",
    "glossarets": "glossar",
    "glossarie": "glossarium",
    "glossarier": "glossarium",
    "glossarierna": "glossarium",
    "glossariernas": "glossarium",
    "glossariers": "glossarium",
    "glossariet": "glossarium",
    "glossariets": "glossarium",
    "glossariums": "glossarium",
    "glossars": "glossar",
    "glossas": "glossa",
    "glosse": "glossa",
    "glossematiken": "glossematik",
    "glossematikens": "glossematik",
    "glossematiker": "glossematik",
    "glossematikerna": "glossematik",
    "glossematikernas": "glossematik",
    "glossematikers": "glossematik",
    "glossematiks": "glossematik",
    "glossolalien": "glossolali",
    "glossolaliens": "glossolali",
    "glossolalier": "glossolali",
    "glossolalierna": "glossolali",
    "glossolaliernas": "glossolali",
    "glossolaliers": "glossolali",
    "glossolalin": "glossolali",
    "glossolalins": "glossolali",
    "glossolalis": "glossolali",
    "glossor": "glossa",
    "glossorna": "glossa",
    "glossornas": "glossa",
    "glossors": "glossa",
    "glosögda": "glosögd",
    "glosögdare": "glosögd",
    "glosögdares": "glosögd",
    "glosögdas": "glosögd",
    "glosögdast": "glosögd",
    "glosögdaste": "glosögd",
    "glosögdastes": "glosögd",
    "glosögdasts": "glosögd",
    "glosögde": "glosögd",
    "glosögdes": "glosögd",
    "glosögdheten": "glosögdhet",
    "glosögdhetens": "glosögdhet",
    "glosögdhets": "glosögdhet",
    "glosögds": "glosögd",
    "glosögonen": "glosögon",
    "glosögonens": "glosögon",
    "glosögons": "glosögon",
    "glosögt": "glosögd",
    "glosögts": "glosögd",
    "glott": "glo",
    "glottisstötar": "glottisstöt",
    "glottisstötarna": "glottisstöt",
    "glottisstötarnas": "glottisstöt",
    "glottisstötars": "glottisstöt",
    "glottisstöten": "glottisstöt",
    "glottisstötens": "glottisstöt",
    "glottisstöts": "glottisstöt",
    "glottokronologien": "glottokronologi",
    "glottokronologiens": "glottokronologi",
    "glottokronologin": "glottokronologi",
    "glottokronologins": "glottokronologi",
    "glottokronologis": "glottokronologi",
    "glotts": "glo",
    "gloxini": "gloxinia",
    "gloxinian": "gloxinia",
    "gloxinians": "gloxinia",
    "gloxinias": "gloxinia",
    "gloxinie": "gloxinia",
    "gloxinior": "gloxinia",
    "gloxiniorna": "gloxinia",
    "gloxiniornas": "gloxinia",
    "gloxiniors": "gloxinia",
    "gloxinis": "gloxinia",
    "gluggar": "glugg",
    "gluggarna": "glugg",
    "gluggarnas": "glugg",
    "gluggars": "glugg",
    "gluggen": "glugg",
    "gluggens": "glugg",
    "gluggs": "glugg",
    "glukosen": "glukos",
    "glukosens": "glukos",
    "glukoset": "glukos",
    "glukosets": "glukos",
    "glunkades": "glunkas",
    "glunkats": "glunkas",
    "gluntar": "glunt",
    "gluntarna": "glunt",
    "gluntarnas": "glunt",
    "gluntars": "glunt",
    "glunten": "glunt",
    "gluntens": "glunt",
    "glunts": "glunt",
    "glupska": "glupsk",
    "glupskare": "glupsk",
    "glupskares": "glupsk",
    "glupskas": "glupsk",
    "glupskast": "glupsk",
    "glupskaste": "glupsk",
    "glupskastes": "glupsk",
    "glupskasts": "glupsk",
    "glupske": "glupsk",
    "glupskes": "glupsk",
    "glupskheten": "glupskhet",
    "glupskhetens": "glupskhet",
    "glupskhets": "glupskhet",
    "glupsks": "glupsk",
    "glupskt": "glupsk",
    "glupskts": "glupsk",
    "glutamaten": "glutamat",
    "glutamatens": "glutamat",
    "glutamater": "glutamat",
    "glutamaterna": "glutamat",
    "glutamaternas": "glutamat",
    "glutamaters": "glutamat",
    "glutamatet": "glutamat",
    "glutamatets": "glutamat",
    "glutamats": "glutamat",
    "glutaminsyran": "glutaminsyra",
    "glutaminsyrans": "glutaminsyra",
    "glutaminsyras": "glutaminsyra",
    "glutaminsyre": "glutaminsyra",
    "glutenet": "gluten",
    "glutenets": "gluten",
    "glutenfria": "glutenfri",
    "glutenfriare": "glutenfri",
    "glutenfriares": "glutenfri",
    "glutenfrias": "glutenfri",
    "glutenfriast": "glutenfri",
    "glutenfriaste": "glutenfri",
    "glutenfriastes": "glutenfri",
    "glutenfriasts": "glutenfri",
    "glutenfrie": "glutenfri",
    "glutenfries": "glutenfri",
    "glutenfris": "glutenfri",
    "glutenfritt": "glutenfri",
    "glutenfritts": "glutenfri",
    "glutenintoleransen": "glutenintolerans",
    "glutenintoleransens": "glutenintolerans",
    "glutenintoleranta": "glutenintolerant",
    "glutenintolerantare": "glutenintolerant",
    "glutenintolerantares": "glutenintolerant",
    "glutenintolerantas": "glutenintolerant",
    "glutenintolerantast": "glutenintolerant",
    "glutenintolerantaste": "glutenintolerant",
    "glutenintolerantastes": "glutenintolerant",
    "glutenintolerantasts": "glutenintolerant",
    "glutenintolerante": "glutenintolerant",
    "glutenintolerantes": "glutenintolerant",
    "glutenintolerants": "glutenintolerant",
    "glutens": "gluten",
    "glutinösa": "glutinös",
    "glutinösare": "glutinös",
    "glutinösares": "glutinös",
    "glutinösas": "glutinös",
    "glutinösast": "glutinös",
    "glutinösaste": "glutinös",
    "glutinösastes": "glutinös",
    "glutinösasts": "glutinös",
    "glutinöse": "glutinös",
    "glutinöses": "glutinös",
    "glutinöst": "glutinös",
    "glutinösts": "glutinös",
    "glutt": "glutta",
    "gluttade": "glutta",
    "gluttades": "glutta",
    "gluttande": "glutta",
    "gluttanden": "gluttande",
    "gluttandena": "gluttande",
    "gluttandenas": "gluttande",
    "gluttandens": "gluttande",
    "gluttandes": "gluttande",
    "gluttandet": "gluttande",
    "gluttandets": "gluttande",
    "gluttar": "glutta",
    "gluttas": "glutta",
    "gluttat": "glutta",
    "gluttats": "glutta",
    "gluttsnäpp": "gluttsnäppa",
    "gluttsnäppan": "gluttsnäppa",
    "gluttsnäppans": "gluttsnäppa",
    "gluttsnäppas": "gluttsnäppa",
    "gluttsnäppe": "gluttsnäppa",
    "gluttsnäppor": "gluttsnäppa",
    "gluttsnäpporna": "gluttsnäppa",
    "gluttsnäppornas": "gluttsnäppa",
    "gluttsnäppors": "gluttsnäppa",
    "gluttsnäpps": "gluttsnäppa",
    "glyceriden": "glycerid",
    "glyceridens": "glycerid",
    "glycerider": "glycerid",
    "glyceriderna": "glycerid",
    "glyceridernas": "glycerid",
    "glyceriders": "glycerid",
    "glycerids": "glycerid",
    "glycerinen": "glycerin",
    "glycerinens": "glycerin",
    "glycerinet": "glycerin",
    "glycerinets": "glycerin",
    "glycerins": "glycerin",
    "glycerolen": "glycerol",
    "glycerolens": "glycerol",
    "glycerols": "glycerol",
    "glycerylnitratet": "glycerylnitrat",
    "glycerylnitratets": "glycerylnitrat",
    "glycerylnitrats": "glycerylnitrat",
    "glycinen": "glycin",
    "glycinens": "glycin",
    "glyciner": "glycin",
    "glycinerna": "glycin",
    "glycinernas": "glycin",
    "glyciners": "glycin",
    "glycins": "glycin",
    "glykogenet": "glykogen",
    "glykogenets": "glykogen",
    "glykogens": "glykogen",
    "glykolen": "glykol",
    "glykolens": "glykol",
    "glykoler": "glykol",
    "glykolerna": "glykol",
    "glykolernas": "glykol",
    "glykolers": "glykol",
    "glykols": "glykol",
    "glykolysen": "glykolys",
    "glykolysens": "glykolys",
    "glykopeptiden": "glykopeptid",
    "glykopeptidens": "glykopeptid",
    "glykopeptider": "glykopeptid",
    "glykopeptiderna": "glykopeptid",
    "glykopeptidernas": "glykopeptid",
    "glykopeptiders": "glykopeptid",
    "glykopeptids": "glykopeptid",
    "glykosen": "glykos",
    "glykosens": "glykos",
    "glykoset": "glykos",
    "glykosets": "glykos",
    "glyptiken": "glyptik",
    "glyptikens": "glyptik",
    "glyptiks": "glyptik",
    "glyptoteken": "glyptotek",
    "glyptotekens": "glyptotek",
    "glyptoteket": "glyptotek",
    "glyptotekets": "glyptotek",
    "glyptoteks": "glyptotek",
    "glyttar": "glytt",
    "glyttarna": "glytt",
    "glyttarnas": "glytt",
    "glyttars": "glytt",
    "glytten": "glytt",
    "glyttens": "glytt",
    "glyttiga": "glyttig",
    "glyttigare": "glyttig",
    "glyttigares": "glyttig",
    "glyttigas": "glyttig",
    "glyttigast": "glyttig",
    "glyttigaste": "glyttig",
    "glyttigastes": "glyttig",
    "glyttigasts": "glyttig",
    "glyttige": "glyttig",
    "glyttiges": "glyttig",
    "glyttigheten": "glyttighet",
    "glyttighetens": "glyttighet",
    "glyttighets": "glyttighet",
    "glyttigs": "glyttig",
    "glyttigt": "glyttig",
    "glyttigts": "glyttig",
    "glytts": "glytt",
    "gläd": "glädja",
    "glädes": "glädjas",
    "glädj": "glädja",
    "glädjande": "glädja",
    "glädjanden": "glädjande",
    "glädjandena": "glädjande",
    "glädjandenas": "glädjande",
    "glädjandens": "glädjande",
    "glädjandes": "glädjande",
    "glädjandet": "glädjande",
    "glädjandets": "glädjande",
    "glädjas": "glädja",
    "glädjebeskeden": "glädjebesked",
    "glädjebeskedens": "glädjebesked",
    "glädjebeskedet": "glädjebesked",
    "glädjebeskedets": "glädjebesked",
    "glädjebeskeds": "glädjebesked",
    "glädjebetygelsen": "glädjebetygelse",
    "glädjebetygelsens": "glädjebetygelse",
    "glädjebetygelser": "glädjebetygelse",
    "glädjebetygelserna": "glädjebetygelse",
    "glädjebetygelsernas": "glädjebetygelse",
    "glädjebetygelsers": "glädjebetygelse",
    "glädjebetygelses": "glädjebetygelse",
    "glädjedödar": "glädjedödare",
    "glädjedödaren": "glädjedödare",
    "glädjedödarens": "glädjedödare",
    "glädjedödares": "glädjedödare",
    "glädjedödarna": "glädjedödare",
    "glädjedödarnas": "glädjedödare",
    "glädjeflick": "glädjeflicka",
    "glädjeflickan": "glädjeflicka",
    "glädjeflickans": "glädjeflicka",
    "glädjeflickas": "glädjeflicka",
    "glädjeflicke": "glädjeflicka",
    "glädjeflickor": "glädjeflicka",
    "glädjeflickorna": "glädjeflicka",
    "glädjeflickornas": "glädjeflicka",
    "glädjeflickors": "glädjeflicka",
    "glädjeflicks": "glädjeflicka",
    "glädjefnatten": "glädjefnatt",
    "glädjefnattens": "glädjefnatt",
    "glädjefnattet": "glädjefnatt",
    "glädjefnattets": "glädjefnatt",
    "glädjefnatts": "glädjefnatt",
    "glädjefyllda": "glädjefylld",
    "glädjefylldare": "glädjefylld",
    "glädjefylldares": "glädjefylld",
    "glädjefylldas": "glädjefylld",
    "glädjefylldast": "glädjefylld",
    "glädjefylldaste": "glädjefylld",
    "glädjefylldastes": "glädjefylld",
    "glädjefylldasts": "glädjefylld",
    "glädjefyllde": "glädjefylld",
    "glädjefylldes": "glädjefylld",
    "glädjefylldheten": "glädjefylldhet",
    "glädjefylldhetens": "glädjefylldhet",
    "glädjefylldhets": "glädjefylldhet",
    "glädjefyllds": "glädjefylld",
    "glädjefyllt": "glädjefylld",
    "glädjefyllts": "glädjefylld",
    "glädjehusen": "glädjehus",
    "glädjehusens": "glädjehus",
    "glädjehuset": "glädjehus",
    "glädjehusets": "glädjehus",
    "glädjekalkylen": "glädjekalkyl",
    "glädjekalkylens": "glädjekalkyl",
    "glädjekalkyler": "glädjekalkyl",
    "glädjekalkylerna": "glädjekalkyl",
    "glädjekalkylernas": "glädjekalkyl",
    "glädjekalkylers": "glädjekalkyl",
    "glädjekalkyls": "glädjekalkyl",
    "glädjekvarteren": "glädjekvarter",
    "glädjekvarterens": "glädjekvarter",
    "glädjekvarteret": "glädjekvarter",
    "glädjekvarterets": "glädjekvarter",
    "glädjekvarters": "glädjekvarter",
    "glädjen": "glädje",
    "glädjens": "glädje",
    "glädjer": "glädja",
    "glädjerusen": "glädjerus",
    "glädjerusens": "glädjerus",
    "glädjeruset": "glädjerus",
    "glädjerusets": "glädjerus",
    "glädjerusiga": "glädjerusig",
    "glädjerusigare": "glädjerusig",
    "glädjerusigares": "glädjerusig",
    "glädjerusigas": "glädjerusig",
    "glädjerusigast": "glädjerusig",
    "glädjerusigaste": "glädjerusig",
    "glädjerusigastes": "glädjerusig",
    "glädjerusigasts": "glädjerusig",
    "glädjerusige": "glädjerusig",
    "glädjerusiges": "glädjerusig",
    "glädjerusigheten": "glädjerusighet",
    "glädjerusighetens": "glädjerusighet",
    "glädjerusighets": "glädjerusighet",
    "glädjerusigs": "glädjerusig",
    "glädjerusigt": "glädjerusig",
    "glädjerusigts": "glädjerusig",
    "glädjes": "glädje",
    "glädjetårar": "glädjetår",
    "glädjetårarna": "glädjetår",
    "glädjetårarnas": "glädjetår",
    "glädjetårars": "glädjetår",
    "glädjetåren": "glädjetår",
    "glädjetårens": "glädjetår",
    "glädjetårs": "glädjetår",
    "glädjeyran": "glädjeyra",
    "glädjeyrans": "glädjeyra",
    "glädjeyras": "glädjeyra",
    "glädjeyre": "glädjeyra",
    "glädjeyror": "glädjeyra",
    "glädjeyrorna": "glädjeyra",
    "glädjeyrornas": "glädjeyra",
    "glädjeyrors": "glädjeyra",
    "glädjeämnen": "glädjeämne",
    "glädjeämnena": "glädjeämne",
    "glädjeämnenas": "glädjeämne",
    "glädjeämnens": "glädjeämne",
    "glädjeämnes": "glädjeämne",
    "glädjeämnet": "glädjeämne",
    "glädjeämnets": "glädjeämne",
    "gläds": "glädjas",
    "gläfs": "gläfsa",
    "gläfsande": "gläfsa",
    "gläfsanden": "gläfsande",
    "gläfsandena": "gläfsande",
    "gläfsandenas": "gläfsande",
    "gläfsandens": "gläfsande",
    "gläfsandes": "gläfsande",
    "gläfsandet": "gläfsande",
    "gläfsandets": "gläfsande",
    "gläfsas": "gläfsa",
    "gläfser": "gläfsa",
    "gläfses": "gläfsa",
    "gläfset": "gläfs",
    "gläfsets": "gläfs",
    "gläfst": "gläfsa",
    "gläfste": "gläfsa",
    "gläfstes": "gläfsa",
    "gläfsts": "gläfsa",
    "gläns": "glänsa",
    "glänsande": "glänsa",
    "glänsanden": "glänsande",
    "glänsandena": "glänsande",
    "glänsandenas": "glänsande",
    "glänsandens": "glänsande",
    "glänsandes": "glänsande",
    "glänsandet": "glänsande",
    "glänsandets": "glänsande",
    "glänsas": "glänsa",
    "glänser": "glänsa",
    "glänses": "glänsa",
    "glänst": "glänsa",
    "glänste": "glänsa",
    "glänstes": "glänsa",
    "glänsts": "glänsa",
    "glänt": "glänta",
    "gläntad": "glänta",
    "gläntade": "glänta",
    "gläntades": "glänta",
    "gläntads": "glänta",
    "gläntan": "glänta",
    "gläntande": "glänta",
    "gläntanden": "gläntande",
    "gläntandena": "gläntande",
    "gläntandenas": "gläntande",
    "gläntandens": "gläntande",
    "gläntandes": "gläntande",
    "gläntandet": "gläntande",
    "gläntandets": "gläntande",
    "gläntans": "glänta",
    "gläntar": "glänta",
    "gläntas": "glänta",
    "gläntat": "glänta",
    "gläntats": "glänta",
    "glänte": "glänta",
    "gläntor": "glänta",
    "gläntorna": "glänta",
    "gläntornas": "glänta",
    "gläntors": "glänta",
    "glänts": "glänta",
    "glätt": "glätta",
    "glättad": "glätta",
    "glättade": "glättad",
    "glättades": "glättad",
    "glättads": "glättad",
    "glättande": "glätta",
    "glättanden": "glättande",
    "glättandena": "glättande",
    "glättandenas": "glättande",
    "glättandens": "glättande",
    "glättandes": "glättande",
    "glättandet": "glättande",
    "glättandets": "glättande",
    "glättar": "glätta",
    "glättas": "glätta",
    "glättat": "glättad",
    "glättats": "glättad",
    "glättiga": "glättig",
    "glättigare": "glättig",
    "glättigares": "glättig",
    "glättigas": "glättig",
    "glättigast": "glättig",
    "glättigaste": "glättig",
    "glättigastes": "glättig",
    "glättigasts": "glättig",
    "glättige": "glättig",
    "glättiges": "glättig",
    "glättigheten": "glättighet",
    "glättighetens": "glättighet",
    "glättigheter": "glättighet",
    "glättigheterna": "glättighet",
    "glättigheternas": "glättighet",
    "glättigheters": "glättighet",
    "glättighets": "glättighet",
    "glättigs": "glättig",
    "glättigt": "glättig",
    "glättigts": "glättig",
    "glättningar": "glättning",
    "glättningarna": "glättning",
    "glättningarnas": "glättning",
    "glättningars": "glättning",
    "glättningen": "glättning",
    "glättningens": "glättning",
    "glättnings": "glättning",
    "glättstenar": "glättsten",
    "glättstenarna": "glättsten",
    "glättstenarnas": "glättsten",
    "glättstenars": "glättsten",
    "glättstenen": "glättsten",
    "glättstenens": "glättsten",
    "glättstens": "glättsten",
    "glåmiga": "glåmig",
    "glåmigare": "glåmig",
    "glåmigares": "glåmig",
    "glåmigas": "glåmig",
    "glåmigast": "glåmig",
    "glåmigaste": "glåmig",
    "glåmigastes": "glåmig",
    "glåmigasts": "glåmig",
    "glåmige": "glåmig",
    "glåmiges": "glåmig",
    "glåmigheten": "glåmighet",
    "glåmighetens": "glåmighet",
    "glåmigheter": "glåmighet",
    "glåmigheterna": "glåmighet",
    "glåmigheternas": "glåmighet",
    "glåmigheters": "glåmighet",
    "glåmighets": "glåmighet",
    "glåmigs": "glåmig",
    "glåmigt": "glåmig",
    "glåmigts": "glåmig",
    "glåporden": "glåpord",
    "glåpordens": "glåpord",
    "glåpordet": "glåpord",
    "glåpordets": "glåpord",
    "glåpords": "glåpord",
    "glöd": "glöda",
    "glödande": "glöda",
    "glödanden": "glödande",
    "glödandena": "glödande",
    "glödandenas": "glödande",
    "glödandens": "glödande",
    "glödandes": "glödande",
    "glödandet": "glödande",
    "glödandets": "glödande",
    "glödas": "glöda",
    "glödbak": "glödbaka",
    "glödbakad": "glödbaka",
    "glödbakade": "glödbaka",
    "glödbakades": "glödbaka",
    "glödbakads": "glödbaka",
    "glödbakande": "glödbaka",
    "glödbakanden": "glödbakande",
    "glödbakandena": "glödbakande",
    "glödbakandenas": "glödbakande",
    "glödbakandens": "glödbakande",
    "glödbakandes": "glödbakande",
    "glödbakandet": "glödbakande",
    "glödbakandets": "glödbakande",
    "glödbakar": "glödbaka",
    "glödbakas": "glödbaka",
    "glödbakat": "glödbaka",
    "glödbakats": "glödbaka",
    "glödbaker": "glödbaka",
    "glödbakes": "glödbaka",
    "glödbaks": "glödbaka",
    "glödbakt": "glödbaka",
    "glödbakta": "glödbaka",
    "glödbaktas": "glödbaka",
    "glödbakte": "glödbaka",
    "glödbaktes": "glödbaka",
    "glödbakts": "glödbaka",
    "glödbäddar": "glödbädd",
    "glödbäddarna": "glödbädd",
    "glödbäddarnas": "glödbädd",
    "glödbäddars": "glödbädd",
    "glödbädden": "glödbädd",
    "glödbäddens": "glödbädd",
    "glödbädds": "glödbädd",
    "glödd": "glöda",
    "glödda": "glöda",
    "glöddas": "glöda",
    "glödde": "glöda",
    "glöddes": "glöda",
    "glödds": "glöda",
    "glöden": "glöd",
    "glödens": "glöd",
    "glöder": "glöda",
    "glöderna": "glöd",
    "glödernas": "glöd",
    "glöders": "glöd",
    "glödes": "glöda",
    "glödg": "glödga",
    "glödgad": "glödga",
    "glödgade": "glödga",
    "glödgades": "glödga",
    "glödgads": "glödga",
    "glödgande": "glödga",
    "glödganden": "glödgande",
    "glödgandena": "glödgande",
    "glödgandenas": "glödgande",
    "glödgandens": "glödgande",
    "glödgandes": "glödgande",
    "glödgandet": "glödgande",
    "glödgandets": "glödgande",
    "glödgar": "glödga",
    "glödgas": "glödga",
    "glödgat": "glödga",
    "glödgats": "glödga",
    "glödheta": "glödhet",
    "glödhetare": "glödhet",
    "glödhetares": "glödhet",
    "glödhetas": "glödhet",
    "glödhetast": "glödhet",
    "glödhetaste": "glödhet",
    "glödhetastes": "glödhet",
    "glödhetasts": "glödhet",
    "glödhete": "glödhet",
    "glödhetes": "glödhet",
    "glödhets": "glödhet",
    "glödhett": "glödhet",
    "glödhetts": "glödhet",
    "glödhopp": "glödhoppa",
    "glödhoppan": "glödhoppa",
    "glödhoppans": "glödhoppa",
    "glödhoppas": "glödhoppa",
    "glödhoppe": "glödhoppa",
    "glödhoppor": "glödhoppa",
    "glödhopporna": "glödhoppa",
    "glödhoppornas": "glödhoppa",
    "glödhoppors": "glödhoppa",
    "glödhopps": "glödhoppa",
    "glödhögar": "glödhög",
    "glödhögarna": "glödhög",
    "glödhögarnas": "glödhög",
    "glödhögars": "glödhög",
    "glödhögen": "glödhög",
    "glödhögens": "glödhög",
    "glödhögs": "glödhög",
    "glödkatoden": "glödkatod",
    "glödkatodens": "glödkatod",
    "glödkatoder": "glödkatod",
    "glödkatoderna": "glödkatod",
    "glödkatodernas": "glödkatod",
    "glödkatoders": "glödkatod",
    "glödkatods": "glödkatod",
    "glödkroppar": "glödkropp",
    "glödkropparna": "glödkropp",
    "glödkropparnas": "glödkropp",
    "glödkroppars": "glödkropp",
    "glödkroppen": "glödkropp",
    "glödkroppens": "glödkropp",
    "glödkropps": "glödkropp",
    "glödlamp": "glödlampa",
    "glödlampan": "glödlampa",
    "glödlampans": "glödlampa",
    "glödlampas": "glödlampa",
    "glödlampe": "glödlampa",
    "glödlampor": "glödlampa",
    "glödlamporna": "glödlampa",
    "glödlampornas": "glödlampa",
    "glödlampors": "glödlampa",
    "glödlamps": "glödlampa",
    "glödlampsfabriken": "glödlampsfabrik",
    "glödlampsfabrikens": "glödlampsfabrik",
    "glödlampsfabriker": "glödlampsfabrik",
    "glödlampsfabrikerna": "glödlampsfabrik",
    "glödlampsfabrikernas": "glödlampsfabrik",
    "glödlampsfabrikers": "glödlampsfabrik",
    "glödlampsfabriks": "glödlampsfabrik",
    "glödljuset": "glödljus",
    "glödljusets": "glödljus",
    "glödmjuka": "glödmjuk",
    "glödmjukare": "glödmjuk",
    "glödmjukares": "glödmjuk",
    "glödmjukas": "glödmjuk",
    "glödmjukast": "glödmjuk",
    "glödmjukaste": "glödmjuk",
    "glödmjukastes": "glödmjuk",
    "glödmjukasts": "glödmjuk",
    "glödmjuke": "glödmjuk",
    "glödmjukes": "glödmjuk",
    "glödmjuks": "glödmjuk",
    "glödmjukt": "glödmjuk",
    "glödmjukts": "glödmjuk",
    "glödningar": "glödning",
    "glödningarna": "glödning",
    "glödningarnas": "glödning",
    "glödningars": "glödning",
    "glödningen": "glödning",
    "glödningens": "glödning",
    "glödnings": "glödning",
    "glödrit": "glödrita",
    "glödritad": "glödrita",
    "glödritade": "glödrita",
    "glödritades": "glödrita",
    "glödritads": "glödrita",
    "glödritande": "glödrita",
    "glödritanden": "glödritande",
    "glödritandena": "glödritande",
    "glödritandenas": "glödritande",
    "glödritandens": "glödritande",
    "glödritandes": "glödritande",
    "glödritandet": "glödritande",
    "glödritandets": "glödritande",
    "glödritar": "glödrita",
    "glödritas": "glödrita",
    "glödritat": "glödrita",
    "glödritats": "glödrita",
    "glöds": "glöda",
    "glödstek": "glödsteka",
    "glödstekande": "glödsteka",
    "glödstekanden": "glödstekande",
    "glödstekandena": "glödstekande",
    "glödstekandenas": "glödstekande",
    "glödstekandens": "glödstekande",
    "glödstekandes": "glödstekande",
    "glödstekandet": "glödstekande",
    "glödstekandets": "glödstekande",
    "glödstekas": "glödsteka",
    "glödsteker": "glödsteka",
    "glödstekes": "glödsteka",
    "glödsteks": "glödsteka",
    "glödstekt": "glödsteka",
    "glödstekta": "glödsteka",
    "glödstektas": "glödsteka",
    "glödstekte": "glödsteka",
    "glödstektes": "glödsteka",
    "glödstekts": "glödsteka",
    "glödstrump": "glödstrumpa",
    "glödstrumpan": "glödstrumpa",
    "glödstrumpans": "glödstrumpa",
    "glödstrumpas": "glödstrumpa",
    "glödstrumpe": "glödstrumpa",
    "glödstrumpor": "glödstrumpa",
    "glödstrumporna": "glödstrumpa",
    "glödstrumpornas": "glödstrumpa",
    "glödstrumpors": "glödstrumpa",
    "glödstrumps": "glödstrumpa",
    "glödströmmar": "glödström",
    "glödströmmarna": "glödström",
    "glödströmmarnas": "glödström",
    "glödströmmars": "glödström",
    "glödströmmen": "glödström",
    "glödströmmens": "glödström",
    "glödströms": "glödström",
    "glödtrådar": "glödtråd",
    "glödtrådarna": "glödtråd",
    "glödtrådarnas": "glödtråd",
    "glödtrådars": "glödtråd",
    "glödtråden": "glödtråd",
    "glödtrådens": "glödtråd",
    "glödtråds": "glödtråd",
    "glödtänd": "glödtända",
    "glödtändande": "glödtända",
    "glödtändanden": "glödtändande",
    "glödtändandena": "glödtändande",
    "glödtändandenas": "glödtändande",
    "glödtändandens": "glödtändande",
    "glödtändandes": "glödtändande",
    "glödtändandet": "glödtändande",
    "glödtändandets": "glödtändande",
    "glödtändas": "glödtända",
    "glödtände": "glödtända",
    "glödtänder": "glödtända",
    "glödtändes": "glödtända",
    "glödtänds": "glödtända",
    "glödtänt": "glödtända",
    "glödtänts": "glödtända",
    "glödvarma": "glödvarm",
    "glödvarmare": "glödvarm",
    "glödvarmares": "glödvarm",
    "glödvarmas": "glödvarm",
    "glödvarmast": "glödvarm",
    "glödvarmaste": "glödvarm",
    "glödvarmastes": "glödvarm",
    "glödvarmasts": "glödvarm",
    "glödvarme": "glödvarm",
    "glödvarmes": "glödvarm",
    "glödvarms": "glödvarm",
    "glödvarmt": "glödvarm",
    "glödvarmts": "glödvarm",
    "glögg": "glögga",
    "glöggade": "glögga",
    "glöggades": "glögga",
    "glöggande": "glögga",
    "glögganden": "glöggande",
    "glöggandena": "glöggande",
    "glöggandenas": "glöggande",
    "glöggandens": "glöggande",
    "glöggandes": "glöggande",
    "glöggandet": "glöggande",
    "glöggandets": "glöggande",
    "glöggar": "glögga",
    "glöggarna": "glögg",
    "glöggarnas": "glögg",
    "glöggars": "glögg",
    "glöggas": "glögga",
    "glöggat": "glögga",
    "glöggats": "glögga",
    "glöggen": "glögg",
    "glöggens": "glögg",
    "glöggpannan": "glöggpanna",
    "glöggpannans": "glöggpanna",
    "glöggpannas": "glöggpanna",
    "glöggpanne": "glöggpanna",
    "glöggpannor": "glöggpanna",
    "glöggpannorna": "glöggpanna",
    "glöggpannornas": "glöggpanna",
    "glöggpannors": "glöggpanna",
    "glöggryt": "glöggryta",
    "glöggrytan": "glöggryta",
    "glöggrytans": "glöggryta",
    "glöggrytas": "glöggryta",
    "glöggryte": "glöggryta",
    "glöggrytor": "glöggryta",
    "glöggrytorna": "glöggryta",
    "glöggrytornas": "glöggryta",
    "glöggrytors": "glöggryta",
    "glöggryts": "glöggryta",
    "glöggs": "glögg",
    "glöggsörplingen": "glöggsörpling",
    "glöggsörplingens": "glöggsörpling",
    "glöggsörplings": "glöggsörpling",
    "glöggtesten": "glöggtest",
    "glöggtestens": "glöggtest",
    "glöggtester": "glöggtest",
    "glöggtesterna": "glöggtest",
    "glöggtesternas": "glöggtest",
    "glöggtesters": "glöggtest",
    "glöggtestet": "glöggtest",
    "glöggtestets": "glöggtest",
    "glöggtests": "glöggtest",
    "glöm": "glömma",
    "glömd": "glömma",
    "glömda": "glömma",
    "glömdas": "glömma",
    "glömde": "glömma",
    "glömdes": "glömma",
    "glömds": "glömma",
    "glömmande": "glömma",
    "glömmanden": "glömmande",
    "glömmandena": "glömmande",
    "glömmandenas": "glömmande",
    "glömmandens": "glömmande",
    "glömmandes": "glömmande",
    "glömmandet": "glömmande",
    "glömmandets": "glömmande",
    "glömmas": "glömma",
    "glömmer": "glömma",
    "glöms": "glömma",
    "glömska": "glömsk",
    "glömskan": "glömska",
    "glömskans": "glömska",
    "glömskare": "glömsk",
    "glömskares": "glömsk",
    "glömskas": "glömska",
    "glömskast": "glömsk",
    "glömskaste": "glömsk",
    "glömskastes": "glömsk",
    "glömskasts": "glömsk",
    "glömske": "glömsk",
    "glömskekurv": "glömskekurva",
    "glömskekurvan": "glömskekurva",
    "glömskekurvans": "glömskekurva",
    "glömskekurvas": "glömskekurva",
    "glömskekurve": "glömskekurva",
    "glömskekurvor": "glömskekurva",
    "glömskekurvorna": "glömskekurva",
    "glömskekurvornas": "glömskekurva",
    "glömskekurvors": "glömskekurva",
    "glömskekurvs": "glömskekurva",
    "glömskes": "glömsk",
    "glömskheten": "glömskhet",
    "glömskhetens": "glömskhet",
    "glömskhets": "glömskhet",
    "glömsks": "glömsk",
    "glömskt": "glömsk",
    "glömskts": "glömsk",
    "glömt": "glömma",
    "glömts": "glömma",
    "glöt": "glöta",
    "glötade": "glöta",
    "glötades": "glöta",
    "glötande": "glöta",
    "glötanden": "glötande",
    "glötandena": "glötande",
    "glötandenas": "glötande",
    "glötandens": "glötande",
    "glötandes": "glötande",
    "glötandet": "glötande",
    "glötandets": "glötande",
    "glötar": "glöta",
    "glötas": "glöta",
    "glötat": "glöta",
    "glötats": "glöta",
    "glött": "glöda",
    "glötts": "glöda",
    "gnabbades": "gnabbas",
    "gnabbats": "gnabbas",
    "gnabben": "gnabb",
    "gnabbens": "gnabb",
    "gnabbet": "gnabb",
    "gnabbets": "gnabb",
    "gnabbs": "gnabb",
    "gnag": "gnaga",
    "gnagande": "gnaga",
    "gnaganden": "gnagande",
    "gnagandena": "gnagande",
    "gnagandenas": "gnagande",
    "gnagandens": "gnagande",
    "gnagandes": "gnagande",
    "gnagandet": "gnagande",
    "gnagandets": "gnagande",
    "gnagar": "gnagare",
    "gnagaren": "gnagare",
    "gnagarens": "gnagare",
    "gnagares": "gnagare",
    "gnagarna": "gnagare",
    "gnagarnas": "gnagare",
    "gnagas": "gnaga",
    "gnagd": "gnaga",
    "gnagda": "gnaga",
    "gnagdas": "gnaga",
    "gnagde": "gnaga",
    "gnagdes": "gnaga",
    "gnagds": "gnaga",
    "gnager": "gnaga",
    "gnages": "gnaga",
    "gnaget": "gnag",
    "gnagets": "gnag",
    "gnags": "gnaga",
    "gnagt": "gnaga",
    "gnagtanden": "gnagtand",
    "gnagtandens": "gnagtand",
    "gnagtands": "gnagtand",
    "gnagts": "gnaga",
    "gnagtänder": "gnagtand",
    "gnagtänderna": "gnagtand",
    "gnagtändernas": "gnagtand",
    "gnagtänders": "gnagtand",
    "gnat": "gnata",
    "gnatade": "gnata",
    "gnatades": "gnata",
    "gnatande": "gnata",
    "gnatanden": "gnatande",
    "gnatandena": "gnatande",
    "gnatandenas": "gnatande",
    "gnatandens": "gnatande",
    "gnatandes": "gnatande",
    "gnatandet": "gnatande",
    "gnatandets": "gnatande",
    "gnatar": "gnata",
    "gnatas": "gnata",
    "gnatat": "gnata",
    "gnatats": "gnata",
    "gnatet": "gnat",
    "gnatets": "gnat",
    "gnatiga": "gnatig",
    "gnatigare": "gnatig",
    "gnatigares": "gnatig",
    "gnatigas": "gnatig",
    "gnatigast": "gnatig",
    "gnatigaste": "gnatig",
    "gnatigastes": "gnatig",
    "gnatigasts": "gnatig",
    "gnatige": "gnatig",
    "gnatiges": "gnatig",
    "gnatigs": "gnatig",
    "gnatigt": "gnatig",
    "gnatigts": "gnatig",
    "gnats": "gnat",
    "gnav": "gnava",
    "gnavande": "gnava",
    "gnavanden": "gnavande",
    "gnavandena": "gnavande",
    "gnavandenas": "gnavande",
    "gnavandens": "gnavande",
    "gnavandes": "gnavande",
    "gnavandet": "gnavande",
    "gnavandets": "gnavande",
    "gnavas": "gnava",
    "gnavd": "gnava",
    "gnavda": "gnava",
    "gnavdas": "gnava",
    "gnavde": "gnava",
    "gnavdes": "gnava",
    "gnavds": "gnava",
    "gnaver": "gnava",
    "gnaves": "gnava",
    "gnavs": "gnava",
    "gnavt": "gnava",
    "gnavts": "gnava",
    "gned": "gnida",
    "gneds": "gnida",
    "gnejsen": "gnejs",
    "gnejsens": "gnejs",
    "gnejser": "gnejs",
    "gnejserna": "gnejs",
    "gnejsernas": "gnejs",
    "gnejsers": "gnejs",
    "gnet": "gneta",
    "gnetade": "gneta",
    "gnetades": "gneta",
    "gnetande": "gneta",
    "gnetanden": "gnetande",
    "gnetandena": "gnetande",
    "gnetandenas": "gnetande",
    "gnetandens": "gnetande",
    "gnetandes": "gnetande",
    "gnetandet": "gnetande",
    "gnetandets": "gnetande",
    "gnetar": "gneta",
    "gnetarna": "gnet",
    "gnetarnas": "gnet",
    "gnetars": "gnet",
    "gnetas": "gneta",
    "gnetat": "gneta",
    "gnetats": "gneta",
    "gneten": "gnet",
    "gnetens": "gnet",
    "gnetiga": "gnetig",
    "gnetigare": "gnetig",
    "gnetigares": "gnetig",
    "gnetigas": "gnetig",
    "gnetigast": "gnetig",
    "gnetigaste": "gnetig",
    "gnetigastes": "gnetig",
    "gnetigasts": "gnetig",
    "gnetige": "gnetig",
    "gnetiges": "gnetig",
    "gnetigs": "gnetig",
    "gnetigt": "gnetig",
    "gnetigts": "gnetig",
    "gnets": "gnet",
    "gnetter": "gnet",
    "gnetterna": "gnet",
    "gnetternas": "gnet",
    "gnetters": "gnet",
    "gnid": "gnida",
    "gnidande": "gnida",
    "gnidanden": "gnidande",
    "gnidandena": "gnidande",
    "gnidandenas": "gnidande",
    "gnidandens": "gnidande",
    "gnidandes": "gnidande",
    "gnidandet": "gnidande",
    "gnidandets": "gnidande",
    "gnidar": "gnidare",
    "gnidaren": "gnidare",
    "gnidarens": "gnidare",
    "gnidares": "gnidare",
    "gnidarna": "gnidare",
    "gnidarnas": "gnidare",
    "gnidas": "gnida",
    "gnide": "gnida",
    "gniden": "gnida",
    "gnidenheten": "gnidenhet",
    "gnidenhetens": "gnidenhet",
    "gnidenhets": "gnidenhet",
    "gnidens": "gniden",
    "gnider": "gnida",
    "gnideriet": "gnideri",
    "gnideriets": "gnideri",
    "gnideris": "gnideri",
    "gniderit": "gnideri",
    "gniderits": "gnideri",
    "gnides": "gnida",
    "gnidet": "gniden",
    "gnidets": "gniden",
    "gnidiga": "gnidig",
    "gnidigare": "gnidig",
    "gnidigares": "gnidig",
    "gnidigas": "gnidig",
    "gnidigast": "gnidig",
    "gnidigaste": "gnidig",
    "gnidigastes": "gnidig",
    "gnidigasts": "gnidig",
    "gnidige": "gnidig",
    "gnidiges": "gnidig",
    "gnidigs": "gnidig",
    "gnidigt": "gnidig",
    "gnidigts": "gnidig",
    "gnidit": "gnida",
    "gnidits": "gnida",
    "gnidna": "gniden",
    "gnidnare": "gniden",
    "gnidnares": "gniden",
    "gnidnas": "gniden",
    "gnidnast": "gniden",
    "gnidnaste": "gniden",
    "gnidnastes": "gniden",
    "gnidnasts": "gniden",
    "gnidne": "gniden",
    "gnidnes": "gniden",
    "gnidningselektriciteten": "gnidningselektricitet",
    "gnidningselektricitetens": "gnidningselektricitet",
    "gnidningselektriciteter": "gnidningselektricitet",
    "gnidningselektriciteterna": "gnidningselektricitet",
    "gnidningselektriciteternas": "gnidningselektricitet",
    "gnidningselektriciteters": "gnidningselektricitet",
    "gnidningselektricitets": "gnidningselektricitet",
    "gnids": "gnida",
    "gnidstenen": "gnidsten",
    "gnidstenens": "gnidsten",
    "gnidstens": "gnidsten",
    "gnissel": "gnissla",
    "gnissels": "gnissel",
    "gnisslade": "gnissla",
    "gnisslades": "gnissla",
    "gnisslande": "gnissla",
    "gnisslanden": "gnisslande",
    "gnisslandena": "gnisslande",
    "gnisslandenas": "gnisslande",
    "gnisslandens": "gnisslande",
    "gnisslandes": "gnisslande",
    "gnisslandet": "gnisslande",
    "gnisslandets": "gnisslande",
    "gnisslar": "gnissla",
    "gnisslas": "gnissla",
    "gnisslat": "gnissla",
    "gnisslats": "gnissla",
    "gnisslet": "gnissel",
    "gnisslets": "gnissel",
    "gnist": "gnista",
    "gnistad": "gnista",
    "gnistade": "gnista",
    "gnistades": "gnista",
    "gnistads": "gnista",
    "gnistan": "gnista",
    "gnistande": "gnista",
    "gnistanden": "gnistande",
    "gnistandena": "gnistande",
    "gnistandenas": "gnistande",
    "gnistandens": "gnistande",
    "gnistandes": "gnistande",
    "gnistandet": "gnistande",
    "gnistandets": "gnistande",
    "gnistans": "gnista",
    "gnistar": "gnista",
    "gnistas": "gnista",
    "gnistat": "gnista",
    "gnistats": "gnista",
    "gniste": "gnista",
    "gnisten": "gnist",
    "gnistens": "gnist",
    "gnistfångar": "gnistfångare",
    "gnistfångaren": "gnistfångare",
    "gnistfångarens": "gnistfångare",
    "gnistfångares": "gnistfångare",
    "gnistfångarna": "gnistfångare",
    "gnistfångarnas": "gnistfångare",
    "gnistgallerna": "gnistgaller",
    "gnistgallernas": "gnistgaller",
    "gnistgallers": "gnistgaller",
    "gnistgallren": "gnistgaller",
    "gnistgallrens": "gnistgaller",
    "gnistgallret": "gnistgaller",
    "gnistgallrets": "gnistgaller",
    "gnistgapen": "gnistgap",
    "gnistgapens": "gnistgap",
    "gnistgapet": "gnistgap",
    "gnistgapets": "gnistgap",
    "gnistgaps": "gnistgap",
    "gnistinduktorer": "gnistinduktor",
    "gnistinduktorerna": "gnistinduktor",
    "gnistinduktorernas": "gnistinduktor",
    "gnistinduktorers": "gnistinduktor",
    "gnistinduktorn": "gnistinduktor",
    "gnistinduktorns": "gnistinduktor",
    "gnistinduktors": "gnistinduktor",
    "gnistkammar": "gnistkammare",
    "gnistkammaren": "gnistkammare",
    "gnistkammarens": "gnistkammare",
    "gnistkammares": "gnistkammare",
    "gnistkamrar": "gnistkammare",
    "gnistkamrarna": "gnistkammare",
    "gnistkamrarnas": "gnistkammare",
    "gnistkamrars": "gnistkammare",
    "gnistor": "gnista",
    "gnistorna": "gnista",
    "gnistornas": "gnista",
    "gnistors": "gnista",
    "gnistrade": "gnistra",
    "gnistrades": "gnistra",
    "gnistrande": "gnistra",
    "gnistranden": "gnistrande",
    "gnistrandena": "gnistrande",
    "gnistrandenas": "gnistrande",
    "gnistrandens": "gnistrande",
    "gnistrandes": "gnistrande",
    "gnistrandet": "gnistrande",
    "gnistrandets": "gnistrande",
    "gnistrar": "gnistra",
    "gnistras": "gnistra",
    "gnistrat": "gnistra",
    "gnistrats": "gnistra",
    "gnistregnet": "gnistregn",
    "gnistregnets": "gnistregn",
    "gnistregns": "gnistregn",
    "gnistriga": "gnistrig",
    "gnistrigare": "gnistrig",
    "gnistrigares": "gnistrig",
    "gnistrigas": "gnistrig",
    "gnistrigast": "gnistrig",
    "gnistrigaste": "gnistrig",
    "gnistrigastes": "gnistrig",
    "gnistrigasts": "gnistrig",
    "gnistrige": "gnistrig",
    "gnistriges": "gnistrig",
    "gnistrigheten": "gnistrighet",
    "gnistrighetens": "gnistrighet",
    "gnistrighets": "gnistrighet",
    "gnistrigs": "gnistrig",
    "gnistrigt": "gnistrig",
    "gnistrigts": "gnistrig",
    "gnists": "gnist",
    "gnistskydden": "gnistskydd",
    "gnistskyddens": "gnistskydd",
    "gnistskyddet": "gnistskydd",
    "gnistskyddets": "gnistskydd",
    "gnistskydds": "gnistskydd",
    "gniststationen": "gniststation",
    "gniststationens": "gniststation",
    "gniststationer": "gniststation",
    "gniststationerna": "gniststation",
    "gniststationernas": "gniststation",
    "gniststationers": "gniststation",
    "gniststations": "gniststation",
    "gniststräck": "gniststräcka",
    "gniststräckan": "gniststräcka",
    "gniststräckans": "gniststräcka",
    "gniststräckas": "gniststräcka",
    "gniststräcke": "gniststräcka",
    "gniststräckor": "gniststräcka",
    "gniststräckorna": "gniststräcka",
    "gniststräckornas": "gniststräcka",
    "gniststräckors": "gniststräcka",
    "gniststräcks": "gniststräcka",
    "gnistsändar": "gnistsändare",
    "gnistsändaren": "gnistsändare",
    "gnistsändarens": "gnistsändare",
    "gnistsändares": "gnistsändare",
    "gnistsändarna": "gnistsändare",
    "gnistsändarnas": "gnistsändare",
    "gnisttändningar": "gnisttändning",
    "gnisttändningarna": "gnisttändning",
    "gnisttändningarnas": "gnisttändning",
    "gnisttändningars": "gnisttändning",
    "gnisttändningen": "gnisttändning",
    "gnisttändningens": "gnisttändning",
    "gnisttändnings": "gnisttändning",
    "gnodd": "gno",
    "gnodda": "gno",
    "gnoddas": "gno",
    "gnodde": "gno",
    "gnoddes": "gno",
    "gnodds": "gno",
    "gnodingar": "gnoding",
    "gnodingarna": "gnoding",
    "gnodingarnas": "gnoding",
    "gnodingars": "gnoding",
    "gnodingen": "gnoding",
    "gnodingens": "gnoding",
    "gnodings": "gnoding",
    "gnoende": "gno",
    "gnoenden": "gnoende",
    "gnoendena": "gnoende",
    "gnoendenas": "gnoende",
    "gnoendens": "gnoende",
    "gnoendes": "gnoende",
    "gnoendet": "gnoende",
    "gnoendets": "gnoende",
    "gnol": "gnola",
    "gnolad": "gnola",
    "gnolade": "gnola",
    "gnolades": "gnola",
    "gnolads": "gnola",
    "gnolande": "gnola",
    "gnolanden": "gnolande",
    "gnolandena": "gnolande",
    "gnolandenas": "gnolande",
    "gnolandens": "gnolande",
    "gnolandes": "gnolande",
    "gnolandet": "gnolande",
    "gnolandets": "gnolande",
    "gnolar": "gnola",
    "gnolas": "gnola",
    "gnolat": "gnola",
    "gnolats": "gnola",
    "gnomen": "gnom",
    "gnomens": "gnom",
    "gnomer": "gnom",
    "gnomerna": "gnom",
    "gnomernas": "gnom",
    "gnomers": "gnom",
    "gnomikern": "gnomiker",
    "gnomikerna": "gnomiker",
    "gnomikernas": "gnomiker",
    "gnomikerns": "gnomiker",
    "gnomikers": "gnomiker",
    "gnomonen": "gnomon",
    "gnomonens": "gnomon",
    "gnomoner": "gnomon",
    "gnomonerna": "gnomon",
    "gnomonernas": "gnomon",
    "gnomoners": "gnomon",
    "gnomons": "gnomon",
    "gnoms": "gnom",
    "gnor": "gno",
    "gnos": "gno",
    "gnosticismen": "gnosticism",
    "gnosticismens": "gnosticism",
    "gnosticismer": "gnosticism",
    "gnosticismerna": "gnosticism",
    "gnosticismernas": "gnosticism",
    "gnosticismers": "gnosticism",
    "gnosticisms": "gnosticism",
    "gnostikern": "gnostiker",
    "gnostikerna": "gnostiker",
    "gnostikernas": "gnostiker",
    "gnostikerns": "gnostiker",
    "gnostikers": "gnostiker",
    "gnott": "gno",
    "gnotts": "gno",
    "gnuer": "gnu",
    "gnuerna": "gnu",
    "gnuernas": "gnu",
    "gnuers": "gnu",
    "gnugg": "gnugga",
    "gnuggad": "gnugga",
    "gnuggade": "gnugga",
    "gnuggades": "gnugga",
    "gnuggads": "gnugga",
    "gnuggande": "gnugga",
    "gnugganden": "gnuggande",
    "gnuggandena": "gnuggande",
    "gnuggandenas": "gnuggande",
    "gnuggandens": "gnuggande",
    "gnuggandes": "gnuggande",
    "gnuggandet": "gnuggande",
    "gnuggandets": "gnuggande",
    "gnuggar": "gnugga",
    "gnuggas": "gnugga",
    "gnuggat": "gnugga",
    "gnuggats": "gnugga",
    "gnuggbilden": "gnuggbild",
    "gnuggbildens": "gnuggbild",
    "gnuggbilder": "gnuggbild",
    "gnuggbilderna": "gnuggbild",
    "gnuggbildernas": "gnuggbild",
    "gnuggbilders": "gnuggbild",
    "gnuggbilds": "gnuggbild",
    "gnuggstenen": "gnuggsten",
    "gnuggstenens": "gnuggsten",
    "gnuggstens": "gnuggsten",
    "gnun": "gnu",
    "gnuns": "gnu",
    "gnus": "gnu",
    "gnussade": "gnussa",
    "gnussades": "gnussa",
    "gnussande": "gnussa",
    "gnussanden": "gnussande",
    "gnussandena": "gnussande",
    "gnussandenas": "gnussande",
    "gnussandens": "gnussande",
    "gnussandes": "gnussande",
    "gnussandet": "gnussande",
    "gnussandets": "gnussande",
    "gnussar": "gnussare",
    "gnussaren": "gnussare",
    "gnussarens": "gnussare",
    "gnussares": "gnussare",
    "gnussarna": "gnussare",
    "gnussarnas": "gnussare",
    "gnussas": "gnussa",
    "gnussat": "gnussa",
    "gnussats": "gnussa",
    "gnussen": "gnuss",
    "gnussens": "gnuss",
    "gnuttan": "gnutta",
    "gnuttans": "gnutta",
    "gnuttas": "gnutta",
    "gnydd": "gny",
    "gnydda": "gny",
    "gnyddas": "gny",
    "gnydde": "gny",
    "gnyddes": "gny",
    "gnydds": "gny",
    "gnyende": "gny",
    "gnyenden": "gnyende",
    "gnyendena": "gnyende",
    "gnyendenas": "gnyende",
    "gnyendens": "gnyende",
    "gnyendes": "gnyende",
    "gnyendet": "gnyende",
    "gnyendets": "gnyende",
    "gnyet": "gny",
    "gnyets": "gny",
    "gnyr": "gny",
    "gnys": "gny",
    "gnyt": "gny",
    "gnyts": "gny",
    "gnytt": "gny",
    "gnytts": "gny",
    "gnäggade": "gnägga",
    "gnäggades": "gnägga",
    "gnäggande": "gnägga",
    "gnägganden": "gnäggande",
    "gnäggandena": "gnäggande",
    "gnäggandenas": "gnäggande",
    "gnäggandens": "gnäggande",
    "gnäggandes": "gnäggande",
    "gnäggandet": "gnäggande",
    "gnäggandets": "gnäggande",
    "gnäggar": "gnägga",
    "gnäggas": "gnägga",
    "gnäggat": "gnägga",
    "gnäggats": "gnägga",
    "gnägget": "gnägg",
    "gnäggets": "gnägg",
    "gnäggs": "gnägg",
    "gnäll": "gnälla",
    "gnällande": "gnälla",
    "gnällanden": "gnällande",
    "gnällandena": "gnällande",
    "gnällandenas": "gnällande",
    "gnällandens": "gnällande",
    "gnällandes": "gnällande",
    "gnällandet": "gnällande",
    "gnällandets": "gnällande",
    "gnällde": "gnälla",
    "gnäller": "gnälla",
    "gnället": "gnäll",
    "gnällets": "gnäll",
    "gnälliga": "gnällig",
    "gnälligare": "gnällig",
    "gnälligares": "gnällig",
    "gnälligas": "gnällig",
    "gnälligast": "gnällig",
    "gnälligaste": "gnällig",
    "gnälligastes": "gnällig",
    "gnälligasts": "gnällig",
    "gnällige": "gnällig",
    "gnälliges": "gnällig",
    "gnälligheten": "gnällighet",
    "gnällighetens": "gnällighet",
    "gnällighets": "gnällighet",
    "gnälligs": "gnällig",
    "gnälligt": "gnällig",
    "gnälligts": "gnällig",
    "gnällmånsar": "gnällmåns",
    "gnällmånsarna": "gnällmåns",
    "gnällmånsarnas": "gnällmåns",
    "gnällmånsars": "gnällmåns",
    "gnällmånsen": "gnällmåns",
    "gnällmånsens": "gnällmåns",
    "gnälls": "gnäll",
    "gnällspikar": "gnällspik",
    "gnällspikarna": "gnällspik",
    "gnällspikarnas": "gnällspik",
    "gnällspikars": "gnällspik",
    "gnällspiken": "gnällspik",
    "gnällspikens": "gnällspik",
    "gnällspiks": "gnällspik",
    "gnällt": "gnälla",
    "gnöl": "gnöla",
    "gnölade": "gnöla",
    "gnölades": "gnöla",
    "gnölande": "gnöla",
    "gnölanden": "gnölande",
    "gnölandena": "gnölande",
    "gnölandenas": "gnölande",
    "gnölandens": "gnölande",
    "gnölandes": "gnölande",
    "gnölandet": "gnölande",
    "gnölandets": "gnölande",
    "gnölar": "gnöla",
    "gnölas": "gnöla",
    "gnölat": "gnöla",
    "gnölats": "gnöla",
    "gnölet": "gnöl",
    "gnölets": "gnöl",
    "gnöls": "gnöl",
    "go-carten": "go-cart",
    "go-cartens": "go-cart",
    "go-carts": "go-cart",
    "go-cartsarna": "go-cart",
    "go-cartsarnas": "go-cart",
    "go-cartsen": "go-cart",
    "go-cartsens": "go-cart",
    "go-go-flick": "go-go-flicka",
    "go-go-flickan": "go-go-flicka",
    "go-go-flickans": "go-go-flicka",
    "go-go-flickas": "go-go-flicka",
    "go-go-flicke": "go-go-flicka",
    "go-go-flickor": "go-go-flicka",
    "go-go-flickorna": "go-go-flicka",
    "go-go-flickornas": "go-go-flicka",
    "go-go-flickors": "go-go-flicka",
    "go-go-flicks": "go-go-flicka",
    "goa": "go",
    "goare": "go",
    "goares": "go",
    "goas": "go",
    "goast": "go",
    "goaste": "go",
    "goastes": "go",
    "goasts": "go",
    "gobelängbroderier": "gobelängbroderi",
    "gobelängbroderierna": "gobelängbroderi",
    "gobelängbroderiernas": "gobelängbroderi",
    "gobelängbroderiers": "gobelängbroderi",
    "gobelängbroderiet": "gobelängbroderi",
    "gobelängbroderiets": "gobelängbroderi",
    "gobelängbroderis": "gobelängbroderi",
    "gobelängbroderit": "gobelängbroderi",
    "gobelängbroderits": "gobelängbroderi",
    "gobelängen": "gobeläng",
    "gobelängens": "gobeläng",
    "gobelänger": "gobeläng",
    "gobelängerna": "gobeläng",
    "gobelängernas": "gobeläng",
    "gobelängers": "gobeläng",
    "gobelängs": "gobeläng",
    "god": "gode",
    "goda": "god",
    "godar": "gode",
    "godare": "god",
    "godares": "god",
    "godarna": "gode",
    "godarnas": "gode",
    "godars": "gode",
    "godartade": "godartad",
    "godartades": "godartad",
    "godartads": "godartad",
    "godartat": "godartad",
    "godartats": "godartad",
    "godas": "god",
    "godast": "god",
    "godaste": "god",
    "godastes": "god",
    "godasts": "god",
    "godbitar": "godbit",
    "godbitarna": "godbit",
    "godbitarnas": "godbit",
    "godbitars": "godbit",
    "godbiten": "godbit",
    "godbitens": "godbit",
    "godbits": "godbit",
    "goddagarna": "goddagar",
    "goddagarnas": "goddagar",
    "goddagars": "goddagar",
    "goddags": "goddagar",
    "goddagspiltar": "goddagspilt",
    "goddagspiltarna": "goddagspilt",
    "goddagspiltarnas": "goddagspilt",
    "goddagspiltars": "goddagspilt",
    "goddagspilten": "goddagspilt",
    "goddagspiltens": "goddagspilt",
    "goddagspilts": "goddagspilt",
    "gode": "god",
    "godemanskapet": "godemanskap",
    "godemanskapets": "godemanskap",
    "godemanskaps": "godemanskap",
    "goden": "gode",
    "godens": "gode",
    "godes": "gode",
    "godheten": "godhet",
    "godhetens": "godhet",
    "godheter": "godhet",
    "godheterna": "godhet",
    "godheternas": "godhet",
    "godheters": "godhet",
    "godhets": "godhet",
    "godhetsfulla": "godhetsfull",
    "godhetsfullare": "godhetsfull",
    "godhetsfullares": "godhetsfull",
    "godhetsfullas": "godhetsfull",
    "godhetsfullast": "godhetsfull",
    "godhetsfullaste": "godhetsfull",
    "godhetsfullastes": "godhetsfull",
    "godhetsfullasts": "godhetsfull",
    "godhetsfulle": "godhetsfull",
    "godhetsfulles": "godhetsfull",
    "godhetsfullheten": "godhetsfullhet",
    "godhetsfullhetens": "godhetsfullhet",
    "godhetsfullhets": "godhetsfullhet",
    "godhetsfulls": "godhetsfull",
    "godhetsfullt": "godhetsfull",
    "godhetsfullts": "godhetsfull",
    "godhjärtade": "godhjärtad",
    "godhjärtades": "godhjärtad",
    "godhjärtads": "godhjärtad",
    "godhjärtat": "godhjärtad",
    "godhjärtats": "godhjärtad",
    "godhjärtenheten": "godhjärtenhet",
    "godhjärtenhetens": "godhjärtenhet",
    "godhjärtenheter": "godhjärtenhet",
    "godhjärtenheterna": "godhjärtenhet",
    "godhjärtenheternas": "godhjärtenhet",
    "godhjärtenheters": "godhjärtenhet",
    "godhjärtenhets": "godhjärtenhet",
    "godhälliga": "godhällig",
    "godhälligare": "godhällig",
    "godhälligares": "godhällig",
    "godhälligas": "godhällig",
    "godhälligast": "godhällig",
    "godhälligaste": "godhällig",
    "godhälligastes": "godhällig",
    "godhälligasts": "godhällig",
    "godhällige": "godhällig",
    "godhälliges": "godhällig",
    "godhälligheten": "godhällighet",
    "godhällighetens": "godhällighet",
    "godhällighets": "godhällighet",
    "godhälligs": "godhällig",
    "godhälligt": "godhällig",
    "godhälligts": "godhällig",
    "godingar": "goding",
    "godingarna": "goding",
    "godingarnas": "goding",
    "godingars": "goding",
    "godingen": "goding",
    "godingens": "goding",
    "godings": "goding",
    "godisar": "godis",
    "godisarna": "godis",
    "godisarnas": "godis",
    "godisars": "godis",
    "godisen": "godis",
    "godisens": "godis",
    "godiset": "godis",
    "godisets": "godis",
    "godispaniken": "godispanik",
    "godispanikens": "godispanik",
    "godispaniks": "godispanik",
    "godissugenheten": "godissugenhet",
    "godissugenhetens": "godissugenhet",
    "godissugenhets": "godissugenhet",
    "godissugens": "godissugen",
    "godissuget": "godissugen",
    "godissugets": "godissugen",
    "godissugna": "godissugen",
    "godissugnare": "godissugen",
    "godissugnares": "godissugen",
    "godissugnas": "godissugen",
    "godissugnast": "godissugen",
    "godissugnaste": "godissugen",
    "godissugnastes": "godissugen",
    "godissugnasts": "godissugen",
    "godissugne": "godissugen",
    "godissugnes": "godissugen",
    "godkänd": "godkänna",
    "godkända": "godkänna",
    "godkändare": "godkänd",
    "godkändares": "godkänd",
    "godkändas": "godkänna",
    "godkändast": "godkänd",
    "godkändaste": "godkänd",
    "godkändastes": "godkänd",
    "godkändasts": "godkänd",
    "godkände": "godkänna",
    "godkändes": "godkänna",
    "godkänds": "godkänna",
    "godkänn": "godkänna",
    "godkännande": "godkänna",
    "godkännanden": "godkännande",
    "godkännandena": "godkännande",
    "godkännandenas": "godkännande",
    "godkännandens": "godkännande",
    "godkännandes": "godkännande",
    "godkännandet": "godkännande",
    "godkännandets": "godkännande",
    "godkännas": "godkänna",
    "godkänner": "godkänna",
    "godkännes": "godkänna",
    "godkänns": "godkänna",
    "godkänt": "godkänna",
    "godkänts": "godkänna",
    "godlynta": "godlynt",
    "godlyntare": "godlynt",
    "godlyntares": "godlynt",
    "godlyntas": "godlynt",
    "godlyntast": "godlynt",
    "godlyntaste": "godlynt",
    "godlyntastes": "godlynt",
    "godlyntasts": "godlynt",
    "godlynte": "godlynt",
    "godlyntes": "godlynt",
    "godlyntheten": "godlynthet",
    "godlynthetens": "godlynthet",
    "godlynthets": "godlynthet",
    "godlynts": "godlynt",
    "godmanskapen": "godmanskap",
    "godmanskapens": "godmanskap",
    "godmanskapet": "godmanskap",
    "godmanskapets": "godmanskap",
    "godmanskaps": "godmanskap",
    "godmodiga": "godmodig",
    "godmodigare": "godmodig",
    "godmodigares": "godmodig",
    "godmodigas": "godmodig",
    "godmodigast": "godmodig",
    "godmodigaste": "godmodig",
    "godmodigastes": "godmodig",
    "godmodigasts": "godmodig",
    "godmodige": "godmodig",
    "godmodiges": "godmodig",
    "godmodigheten": "godmodighet",
    "godmodighetens": "godmodighet",
    "godmodighets": "godmodighet",
    "godmodigs": "godmodig",
    "godmodigt": "godmodig",
    "godmodigts": "godmodig",
    "godnattsagan": "godnattsaga",
    "godnattsagans": "godnattsaga",
    "godnattsagas": "godnattsaga",
    "godnattsage": "godnattsaga",
    "godnattsago": "godnattsaga",
    "godnattsagor": "godnattsaga",
    "godnattsagorna": "godnattsaga",
    "godnattsagornas": "godnattsaga",
    "godnattsagors": "godnattsaga",
    "gods": "gode",
    "godsaken": "godsak",
    "godsakens": "godsak",
    "godsaker": "godsak",
    "godsakerna": "godsak",
    "godsakernas": "godsak",
    "godsakers": "godsak",
    "godsaks": "godsak",
    "godsen": "gods",
    "godsens": "gods",
    "godset": "gods",
    "godsets": "gods",
    "godsexpeditionen": "godsexpedition",
    "godsexpeditionens": "godsexpedition",
    "godsexpeditioner": "godsexpedition",
    "godsexpeditionerna": "godsexpedition",
    "godsexpeditionernas": "godsexpedition",
    "godsexpeditioners": "godsexpedition",
    "godsexpeditions": "godsexpedition",
    "godsfink": "godsfinka",
    "godsfinkan": "godsfinka",
    "godsfinkans": "godsfinka",
    "godsfinkas": "godsfinka",
    "godsfinke": "godsfinka",
    "godsfinkor": "godsfinka",
    "godsfinkorna": "godsfinka",
    "godsfinkornas": "godsfinka",
    "godsfinkors": "godsfinka",
    "godsfinks": "godsfinka",
    "godsherrar": "godsherre",
    "godsherrarna": "godsherre",
    "godsherrarnas": "godsherre",
    "godsherrars": "godsherre",
    "godsherren": "godsherre",
    "godsherrens": "godsherre",
    "godsherres": "godsherre",
    "godsinta": "godsint",
    "godsintare": "godsint",
    "godsintares": "godsint",
    "godsintas": "godsint",
    "godsintast": "godsint",
    "godsintaste": "godsint",
    "godsintastes": "godsint",
    "godsintasts": "godsint",
    "godsinte": "godsint",
    "godsintes": "godsint",
    "godsintheten": "godsinthet",
    "godsinthetens": "godsinthet",
    "godsinthets": "godsinthet",
    "godsints": "godsint",
    "godsmottagningar": "godsmottagning",
    "godsmottagningarna": "godsmottagning",
    "godsmottagningarnas": "godsmottagning",
    "godsmottagningars": "godsmottagning",
    "godsmottagningen": "godsmottagning",
    "godsmottagningens": "godsmottagning",
    "godsmottagnings": "godsmottagning",
    "godstrafiken": "godstrafik",
    "godstrafikens": "godstrafik",
    "godstrafiks": "godstrafik",
    "godstransporten": "godstransport",
    "godstransportens": "godstransport",
    "godstransporter": "godstransport",
    "godstransporterna": "godstransport",
    "godstransporternas": "godstransport",
    "godstransporters": "godstransport",
    "godstransports": "godstransport",
    "godstågen": "godståg",
    "godstågens": "godståg",
    "godståget": "godståg",
    "godstågets": "godståg",
    "godstågs": "godståg",
    "godsvagnar": "godsvagn",
    "godsvagnarna": "godsvagn",
    "godsvagnarnas": "godsvagn",
    "godsvagnars": "godsvagn",
    "godsvagnen": "godsvagn",
    "godsvagnens": "godsvagn",
    "godsvagns": "godsvagn",
    "godsägar": "godsägare",
    "godsägaren": "godsägare",
    "godsägarens": "godsägare",
    "godsägares": "godsägare",
    "godsägarna": "godsägare",
    "godsägarnas": "godsägare",
    "godtag": "godta",
    "godtaga": "godta",
    "godtagande": "godta",
    "godtaganden": "godtagande",
    "godtagandena": "godtagande",
    "godtagandenas": "godtagande",
    "godtagandens": "godtagande",
    "godtagandes": "godtagande",
    "godtagandet": "godtagande",
    "godtagandets": "godtagande",
    "godtagas": "godta",
    "godtagbara": "godtagbar",
    "godtagbarare": "godtagbar",
    "godtagbarares": "godtagbar",
    "godtagbaras": "godtagbar",
    "godtagbarast": "godtagbar",
    "godtagbaraste": "godtagbar",
    "godtagbarastes": "godtagbar",
    "godtagbarasts": "godtagbar",
    "godtagbare": "godtagbar",
    "godtagbares": "godtagbar",
    "godtagbarheten": "godtagbarhet",
    "godtagbarhetens": "godtagbarhet",
    "godtagbarhets": "godtagbarhet",
    "godtagbars": "godtagbar",
    "godtagbart": "godtagbar",
    "godtagbarts": "godtagbar",
    "godtage": "godta",
    "godtagen": "godta",
    "godtagens": "godta",
    "godtager": "godta",
    "godtages": "godta",
    "godtaget": "godta",
    "godtagets": "godta",
    "godtagit": "godta",
    "godtagits": "godta",
    "godtagna": "godta",
    "godtagnas": "godta",
    "godtagne": "godta",
    "godtagnes": "godta",
    "godtags": "godta",
    "godtar": "godta",
    "godtas": "godta",
    "godtemplar": "godtemplare",
    "godtemplaren": "godtemplare",
    "godtemplarens": "godtemplare",
    "godtemplares": "godtemplare",
    "godtemplarna": "godtemplare",
    "godtemplarnas": "godtemplare",
    "godtemplarordens": "godtemplarorden",
    "godtemplarordnar": "godtemplarorden",
    "godtemplarordnarna": "godtemplarorden",
    "godtemplarordnarnas": "godtemplarorden",
    "godtemplarordnars": "godtemplarorden",
    "godtemplarordnen": "godtemplarorden",
    "godtemplarordnens": "godtemplarorden",
    "godtog": "godta",
    "godtoge": "godta",
    "godtoges": "godta",
    "godtogs": "godta",
    "godtrogenheten": "godtrogenhet",
    "godtrogenhetens": "godtrogenhet",
    "godtrogenhets": "godtrogenhet",
    "godtrogens": "godtrogen",
    "godtroget": "godtrogen",
    "godtrogets": "godtrogen",
    "godtrogna": "godtrogen",
    "godtrognare": "godtrogen",
    "godtrognares": "godtrogen",
    "godtrognas": "godtrogen",
    "godtrognast": "godtrogen",
    "godtrognaste": "godtrogen",
    "godtrognastes": "godtrogen",
    "godtrognasts": "godtrogen",
    "godtrogne": "godtrogen",
    "godtrognes": "godtrogen",
    "godtrosförvärven": "godtrosförvärv",
    "godtrosförvärvens": "godtrosförvärv",
    "godtrosförvärvet": "godtrosförvärv",
    "godtrosförvärvets": "godtrosförvärv",
    "godtrosförvärvs": "godtrosförvärv",
    "godtyckes": "godtycke",
    "godtycket": "godtycke",
    "godtyckets": "godtycke",
    "godtyckliga": "godtycklig",
    "godtyckligare": "godtycklig",
    "godtyckligares": "godtycklig",
    "godtyckligas": "godtycklig",
    "godtyckligast": "godtycklig",
    "godtyckligaste": "godtycklig",
    "godtyckligastes": "godtycklig",
    "godtyckligasts": "godtycklig",
    "godtycklige": "godtycklig",
    "godtyckliges": "godtycklig",
    "godtyckligheten": "godtycklighet",
    "godtycklighetens": "godtycklighet",
    "godtyckligheter": "godtycklighet",
    "godtyckligheterna": "godtycklighet",
    "godtyckligheternas": "godtycklighet",
    "godtyckligheters": "godtycklighet",
    "godtycklighets": "godtycklighet",
    "godtyckligs": "godtycklig",
    "godtyckligt": "godtycklig",
    "godtyckligts": "godtycklig",
    "godvikten": "godvikt",
    "godviktens": "godvikt",
    "godvikter": "godvikt",
    "godvikterna": "godvikt",
    "godvikternas": "godvikt",
    "godvikters": "godvikt",
    "godvikts": "godvikt",
    "godvilliga": "godvillig",
    "godvilligare": "godvillig",
    "godvilligares": "godvillig",
    "godvilligas": "godvillig",
    "godvilligast": "godvillig",
    "godvilligaste": "godvillig",
    "godvilligastes": "godvillig",
    "godvilligasts": "godvillig",
    "godvillige": "godvillig",
    "godvilliges": "godvillig",
    "godvilligheten": "godvillighet",
    "godvillighetens": "godvillighet",
    "godvillighets": "godvillighet",
    "godvilligs": "godvillig",
    "godvilligt": "godvillig",
    "godvilligts": "godvillig",
    "goe": "go",
    "goes": "go",
    "goffrerad": "goffrera",
    "goffrerade": "goffrera",
    "goffrerades": "goffrera",
    "goffrerads": "goffrera",
    "goffrerande": "goffrera",
    "goffreranden": "goffrerande",
    "goffrerandena": "goffrerande",
    "goffrerandenas": "goffrerande",
    "goffrerandens": "goffrerande",
    "goffrerandes": "goffrerande",
    "goffrerandet": "goffrerande",
    "goffrerandets": "goffrerande",
    "goffrerar": "goffrera",
    "goffreras": "goffrera",
    "goffrerat": "goffrera",
    "goffrerats": "goffrera",
    "goffrerbara": "goffrerbar",
    "goffrerbarare": "goffrerbar",
    "goffrerbarares": "goffrerbar",
    "goffrerbaras": "goffrerbar",
    "goffrerbarast": "goffrerbar",
    "goffrerbaraste": "goffrerbar",
    "goffrerbarastes": "goffrerbar",
    "goffrerbarasts": "goffrerbar",
    "goffrerbare": "goffrerbar",
    "goffrerbares": "goffrerbar",
    "goffrerbarheten": "goffrerbarhet",
    "goffrerbarhetens": "goffrerbarhet",
    "goffrerbarhets": "goffrerbarhet",
    "goffrerbars": "goffrerbar",
    "goffrerbart": "goffrerbar",
    "goffrerbarts": "goffrerbar",
    "goffreringar": "goffrering",
    "goffreringarna": "goffrering",
    "goffreringarnas": "goffrering",
    "goffreringars": "goffrering",
    "goffreringen": "goffrering",
    "goffreringens": "goffrering",
    "goffrerings": "goffrering",
    "gogglesen": "goggles",
    "gogglesens": "goggles",
    "goj": "goja",
    "gojan": "goja",
    "gojans": "goja",
    "gojas": "goja",
    "goje": "goja",
    "gojor": "goja",
    "gojorna": "goja",
    "gojornas": "goja",
    "gojors": "goja",
    "gojs": "goja",
    "gol": "gala",
    "gold-diggern": "gold-digger",
    "gold-diggerns": "gold-digger",
    "gold-diggers": "gold-digger",
    "gold-diggersarna": "gold-digger",
    "gold-diggersarnas": "gold-digger",
    "gold-diggersen": "gold-digger",
    "gold-diggersens": "gold-digger",
    "gole": "gala",
    "goles": "gala",
    "golfade": "golfa",
    "golfades": "golfa",
    "golfande": "golfa",
    "golfanden": "golfande",
    "golfandena": "golfande",
    "golfandenas": "golfande",
    "golfandens": "golfande",
    "golfandes": "golfande",
    "golfandet": "golfande",
    "golfandets": "golfande",
    "golfar": "golfare",
    "golfaren": "golfare",
    "golfarens": "golfare",
    "golfares": "golfare",
    "golfarna": "golfare",
    "golfarnas": "golfare",
    "golfas": "golfa",
    "golfat": "golfa",
    "golfats": "golfa",
    "golfbanan": "golfbana",
    "golfbanans": "golfbana",
    "golfbanas": "golfbana",
    "golfbane": "golfbana",
    "golfbanor": "golfbana",
    "golfbanorna": "golfbana",
    "golfbanornas": "golfbana",
    "golfbanors": "golfbana",
    "golfbollar": "golfboll",
    "golfbollarna": "golfboll",
    "golfbollarnas": "golfboll",
    "golfbollars": "golfboll",
    "golfbollen": "golfboll",
    "golfbollens": "golfboll",
    "golfbolls": "golfboll",
    "golfbyx": "golfbyxa",
    "golfbyxan": "golfbyxa",
    "golfbyxans": "golfbyxa",
    "golfbyxas": "golfbyxa",
    "golfbyxe": "golfbyxa",
    "golfbyxor": "golfbyxa",
    "golfbyxorna": "golfbyxa",
    "golfbyxornas": "golfbyxa",
    "golfbyxors": "golfbyxa",
    "golfen": "golf",
    "golfens": "golf",
    "golfer": "golf",
    "golferna": "golf",
    "golfernas": "golf",
    "golfers": "golf",
    "golfklubb": "golfklubba",
    "golfklubban": "golfklubba",
    "golfklubbans": "golfklubba",
    "golfklubbas": "golfklubba",
    "golfklubbe": "golfklubba",
    "golfklubbor": "golfklubba",
    "golfklubborna": "golfklubba",
    "golfklubbornas": "golfklubba",
    "golfklubbors": "golfklubba",
    "golfklubbs": "golfklubba",
    "golfmässiga": "golfmässig",
    "golfmässigare": "golfmässig",
    "golfmässigares": "golfmässig",
    "golfmässigas": "golfmässig",
    "golfmässigast": "golfmässig",
    "golfmässigaste": "golfmässig",
    "golfmässigastes": "golfmässig",
    "golfmässigasts": "golfmässig",
    "golfmässige": "golfmässig",
    "golfmässiges": "golfmässig",
    "golfmässigs": "golfmässig",
    "golfmässigt": "golfmässig",
    "golfmässigts": "golfmässig",
    "golfresan": "golfresa",
    "golfresans": "golfresa",
    "golfresas": "golfresa",
    "golfrese": "golfresa",
    "golfresor": "golfresa",
    "golfresorna": "golfresa",
    "golfresornas": "golfresa",
    "golfresors": "golfresa",
    "golfs": "golf",
    "golfskjort": "golfskjorta",
    "golfskjortan": "golfskjorta",
    "golfskjortans": "golfskjorta",
    "golfskjortas": "golfskjorta",
    "golfskjorte": "golfskjorta",
    "golfskjortor": "golfskjorta",
    "golfskjortorna": "golfskjorta",
    "golfskjortornas": "golfskjorta",
    "golfskjortors": "golfskjorta",
    "golfskjorts": "golfskjorta",
    "golfspelen": "golfspel",
    "golfspelens": "golfspel",
    "golfspelet": "golfspel",
    "golfspelets": "golfspel",
    "golfspels": "golfspel",
    "golfstjärnan": "golfstjärna",
    "golfstjärnans": "golfstjärna",
    "golfstjärnas": "golfstjärna",
    "golfstjärne": "golfstjärna",
    "golfstjärnor": "golfstjärna",
    "golfstjärnorna": "golfstjärna",
    "golfstjärnornas": "golfstjärna",
    "golfstjärnors": "golfstjärna",
    "golfturneringar": "golfturnering",
    "golfturneringarna": "golfturnering",
    "golfturneringarnas": "golfturnering",
    "golfturneringars": "golfturnering",
    "golfturneringen": "golfturnering",
    "golfturneringens": "golfturnering",
    "golfturnerings": "golfturnering",
    "golgiapparaten": "golgiapparat",
    "golgiapparatens": "golgiapparat",
    "golgiapparater": "golgiapparat",
    "golgiapparaterna": "golgiapparat",
    "golgiapparaternas": "golgiapparat",
    "golgiapparaters": "golgiapparat",
    "golgiapparats": "golgiapparat",
    "gols": "gala",
    "golv": "golva",
    "golvad": "golva",
    "golvade": "golva",
    "golvades": "golva",
    "golvads": "golva",
    "golvande": "golva",
    "golvanden": "golvande",
    "golvandena": "golvande",
    "golvandenas": "golvande",
    "golvandens": "golvande",
    "golvandes": "golvande",
    "golvandet": "golvande",
    "golvandets": "golvande",
    "golvar": "golva",
    "golvas": "golva",
    "golvat": "golva",
    "golvats": "golva",
    "golvbeläggningar": "golvbeläggning",
    "golvbeläggningarna": "golvbeläggning",
    "golvbeläggningarnas": "golvbeläggning",
    "golvbeläggningars": "golvbeläggning",
    "golvbeläggningen": "golvbeläggning",
    "golvbeläggningens": "golvbeläggning",
    "golvbeläggnings": "golvbeläggning",
    "golvbjälk": "golvbjälke",
    "golvbjälkar": "golvbjälke",
    "golvbjälkarna": "golvbjälke",
    "golvbjälkarnas": "golvbjälke",
    "golvbjälkars": "golvbjälke",
    "golvbjälken": "golvbjälke",
    "golvbjälkens": "golvbjälke",
    "golvbjälkes": "golvbjälke",
    "golvbjälks": "golvbjälke",
    "golvbrunnar": "golvbrunn",
    "golvbrunnarna": "golvbrunn",
    "golvbrunnarnas": "golvbrunn",
    "golvbrunnars": "golvbrunn",
    "golvbrunnen": "golvbrunn",
    "golvbrunnens": "golvbrunn",
    "golvbrunns": "golvbrunn",
    "golvbrunnssilar": "golvbrunnssil",
    "golvbrunnssilarna": "golvbrunnssil",
    "golvbrunnssilarnas": "golvbrunnssil",
    "golvbrunnssilars": "golvbrunnssil",
    "golvbrunnssilen": "golvbrunnssil",
    "golvbrunnssilens": "golvbrunnssil",
    "golvbrunnssils": "golvbrunnssil",
    "golvbrädan": "golvbräda",
    "golvbrädans": "golvbräda",
    "golvbrädas": "golvbräda",
    "golvbräder": "golvbräda",
    "golvbräderna": "golvbräda",
    "golvbrädernas": "golvbräda",
    "golvbräders": "golvbräda",
    "golvbrädor": "golvbräda",
    "golvbrädorna": "golvbräda",
    "golvbrädornas": "golvbräda",
    "golvbrädors": "golvbräda",
    "golvdraget": "golvdrag",
    "golvdragets": "golvdrag",
    "golvdrags": "golvdrag",
    "golven": "golv",
    "golvens": "golv",
    "golvet": "golv",
    "golvets": "golv",
    "golvfasta": "golvfast",
    "golvfastare": "golvfast",
    "golvfastares": "golvfast",
    "golvfastas": "golvfast",
    "golvfastast": "golvfast",
    "golvfastaste": "golvfast",
    "golvfastastes": "golvfast",
    "golvfastasts": "golvfast",
    "golvfaste": "golvfast",
    "golvfastes": "golvfast",
    "golvfasts": "golvfast",
    "golvfärgen": "golvfärg",
    "golvfärgens": "golvfärg",
    "golvfärger": "golvfärg",
    "golvfärgerna": "golvfärg",
    "golvfärgernas": "golvfärg",
    "golvfärgers": "golvfärg",
    "golvfärgs": "golvfärg",
    "golvkalla": "golvkall",
    "golvkallare": "golvkall",
    "golvkallares": "golvkall",
    "golvkallas": "golvkall",
    "golvkallast": "golvkall",
    "golvkallaste": "golvkall",
    "golvkallastes": "golvkall",
    "golvkallasts": "golvkall",
    "golvkalle": "golvkall",
    "golvkalles": "golvkall",
    "golvkalls": "golvkall",
    "golvkallt": "golvkall",
    "golvkallts": "golvkall",
    "golvklock": "golvklocka",
    "golvklockan": "golvklocka",
    "golvklockans": "golvklocka",
    "golvklockas": "golvklocka",
    "golvklocke": "golvklocka",
    "golvklockor": "golvklocka",
    "golvklockorna": "golvklocka",
    "golvklockornas": "golvklocka",
    "golvklockors": "golvklocka",
    "golvklocks": "golvklocka",
    "golvlacker": "golvlack",
    "golvlackerna": "golvlack",
    "golvlackernas": "golvlack",
    "golvlackers": "golvlack",
    "golvlacket": "golvlack",
    "golvlackets": "golvlack",
    "golvlacks": "golvlack",
    "golvlamp": "golvlampa",
    "golvlampan": "golvlampa",
    "golvlampans": "golvlampa",
    "golvlampas": "golvlampa",
    "golvlampe": "golvlampa",
    "golvlampor": "golvlampa",
    "golvlamporna": "golvlampa",
    "golvlampornas": "golvlampa",
    "golvlampors": "golvlampa",
    "golvlamps": "golvlampa",
    "golvläggar": "golvläggare",
    "golvläggaren": "golvläggare",
    "golvläggarens": "golvläggare",
    "golvläggares": "golvläggare",
    "golvläggarna": "golvläggare",
    "golvläggarnas": "golvläggare",
    "golvrampen": "golvramp",
    "golvrampens": "golvramp",
    "golvramper": "golvramp",
    "golvramperna": "golvramp",
    "golvrampernas": "golvramp",
    "golvrampers": "golvramp",
    "golvramps": "golvramp",
    "golvs": "golv",
    "golvsilar": "golvsil",
    "golvsilarna": "golvsil",
    "golvsilarnas": "golvsil",
    "golvsilars": "golvsil",
    "golvsilen": "golvsil",
    "golvsilens": "golvsil",
    "golvsils": "golvsil",
    "golvskyddspapperen": "golvskyddspapper",
    "golvskyddspapperens": "golvskyddspapper",
    "golvskyddspapperet": "golvskyddspapper",
    "golvskyddspapperets": "golvskyddspapper",
    "golvskyddspapperna": "golvskyddspapper",
    "golvskyddspappernas": "golvskyddspapper",
    "golvskyddspappers": "golvskyddspapper",
    "golvskyddspappren": "golvskyddspapper",
    "golvskyddspapprens": "golvskyddspapper",
    "golvskyddspappret": "golvskyddspapper",
    "golvskyddspapprets": "golvskyddspapper",
    "golvuren": "golvur",
    "golvurens": "golvur",
    "golvuret": "golvur",
    "golvurets": "golvur",
    "golvurs": "golvur",
    "golvvaxer": "golvvax",
    "golvvaxerna": "golvvax",
    "golvvaxernas": "golvvax",
    "golvvaxers": "golvvax",
    "golvvaxet": "golvvax",
    "golvvaxets": "golvvax",
    "golvvärmen": "golvvärme",
    "golvvärmens": "golvvärme",
    "golvvärmes": "golvvärme",
    "golvväxeln": "golvväxel",
    "golvväxelns": "golvväxel",
    "golvväxels": "golvväxel",
    "golvväxlar": "golvväxel",
    "golvväxlarna": "golvväxel",
    "golvväxlarnas": "golvväxel",
    "golvväxlars": "golvväxel",
    "golvvårdar": "golvvårdare",
    "golvvårdaren": "golvvårdare",
    "golvvårdarens": "golvvårdare",
    "golvvårdares": "golvvårdare",
    "golvvårdarna": "golvvårdare",
    "golvvårdarnas": "golvvårdare",
    "golvytan": "golvyta",
    "golvytans": "golvyta",
    "golvytas": "golvyta",
    "golvyte": "golvyta",
    "golvytor": "golvyta",
    "golvytorna": "golvyta",
    "golvytornas": "golvyta",
    "golvytors": "golvyta",
    "gombenen": "gomben",
    "gombenens": "gomben",
    "gombenet": "gomben",
    "gombenets": "gomben",
    "gombens": "gomben",
    "gombåg": "gombåge",
    "gombågar": "gombåge",
    "gombågarna": "gombåge",
    "gombågarnas": "gombåge",
    "gombågars": "gombåge",
    "gombågen": "gombåge",
    "gombågens": "gombåge",
    "gombåges": "gombåge",
    "gombågs": "gombåge",
    "gomklyvningar": "gomklyvning",
    "gomklyvningarna": "gomklyvning",
    "gomklyvningarnas": "gomklyvning",
    "gomklyvningars": "gomklyvning",
    "gomklyvningen": "gomklyvning",
    "gomklyvningens": "gomklyvning",
    "gomklyvnings": "gomklyvning",
    "gomljuden": "gomljud",
    "gomljudens": "gomljud",
    "gomljudet": "gomljud",
    "gomljudets": "gomljud",
    "gomljuds": "gomljud",
    "gommar": "gom",
    "gommarna": "gom",
    "gommarnas": "gom",
    "gommars": "gom",
    "gommen": "gom",
    "gommens": "gom",
    "goms": "gom",
    "gomsegels": "gomsegel",
    "gomseglen": "gomsegel",
    "gomseglens": "gomsegel",
    "gomseglet": "gomsegel",
    "gomseglets": "gomsegel",
    "gomspalten": "gomspalt",
    "gomspaltens": "gomspalt",
    "gomspalts": "gomspalt",
    "gomspen": "gomspene",
    "gomspenar": "gomspene",
    "gomspenarna": "gomspene",
    "gomspenarnas": "gomspene",
    "gomspenars": "gomspene",
    "gomspenen": "gomspene",
    "gomspenens": "gomspene",
    "gomspenes": "gomspene",
    "gomspens": "gomspene",
    "gonaden": "gonad",
    "gonadens": "gonad",
    "gonader": "gonad",
    "gonaderna": "gonad",
    "gonadernas": "gonad",
    "gonaders": "gonad",
    "gonads": "gonad",
    "gondolen": "gondol",
    "gondolens": "gondol",
    "gondoler": "gondol",
    "gondolerna": "gondol",
    "gondolernas": "gondol",
    "gondolers": "gondol",
    "gondoljären": "gondoljär",
    "gondoljärens": "gondoljär",
    "gondoljärer": "gondoljär",
    "gondoljärerna": "gondoljär",
    "gondoljärernas": "gondoljär",
    "gondoljärers": "gondoljär",
    "gondoljärs": "gondoljär",
    "gondols": "gondol",
    "gonen": "gon",
    "gonens": "gon",
    "goner": "gon",
    "gonerna": "gon",
    "gonernas": "gon",
    "goners": "gon",
    "gonfaloniären": "gonfaloniär",
    "gonfaloniärens": "gonfaloniär",
    "gonfaloniärer": "gonfaloniär",
    "gonfaloniärerna": "gonfaloniär",
    "gonfaloniärernas": "gonfaloniär",
    "gonfaloniärers": "gonfaloniär",
    "gonfaloniärs": "gonfaloniär",
    "gonggongar": "gonggong",
    "gonggongarna": "gonggong",
    "gonggongarnas": "gonggong",
    "gonggongars": "gonggong",
    "gonggongen": "gonggong",
    "gonggongens": "gonggong",
    "gonggonger": "gonggong",
    "gonggongerna": "gonggong",
    "gonggongernas": "gonggong",
    "gonggongers": "gonggong",
    "gonggongs": "gonggong",
    "gonokocken": "gonokock",
    "gonokockens": "gonokock",
    "gonokocker": "gonokock",
    "gonokockerna": "gonokock",
    "gonokockernas": "gonokock",
    "gonokockers": "gonokock",
    "gonokocks": "gonokock",
    "gonorréer": "gonorré",
    "gonorréerna": "gonorré",
    "gonorréernas": "gonorré",
    "gonorréers": "gonorré",
    "gonorrén": "gonorré",
    "gonorréns": "gonorré",
    "gonorrés": "gonorré",
    "gons": "gon",
    "goodwillen": "goodwill",
    "goodwillens": "goodwill",
    "goodwills": "goodwill",
    "googlad": "googla",
    "googlade": "googla",
    "googlades": "googla",
    "googlads": "googla",
    "googlande": "googla",
    "googlanden": "googlande",
    "googlandena": "googlande",
    "googlandenas": "googlande",
    "googlandens": "googlande",
    "googlandes": "googlande",
    "googlandet": "googlande",
    "googlandets": "googlande",
    "googlar": "googla",
    "googlas": "googla",
    "googlat": "googla",
    "googlats": "googla",
    "googlingar": "googling",
    "googlingarna": "googling",
    "googlingarnas": "googling",
    "googlingars": "googling",
    "googlingen": "googling",
    "googlingens": "googling",
    "googlings": "googling",
    "gordonsettern": "gordonsetter",
    "gordonsetterns": "gordonsetter",
    "gordonsetters": "gordonsetter",
    "gordonsettrar": "gordonsetter",
    "gordonsettrarna": "gordonsetter",
    "gordonsettrarnas": "gordonsetter",
    "gordonsettrars": "gordonsetter",
    "gorgonen": "gorgon",
    "gorgonens": "gorgon",
    "gorgoner": "gorgon",
    "gorgonerna": "gorgon",
    "gorgonernas": "gorgon",
    "gorgoners": "gorgon",
    "gorgons": "gorgon",
    "gorgonzol": "gorgonzola",
    "gorgonzolan": "gorgonzola",
    "gorgonzolans": "gorgonzola",
    "gorgonzolas": "gorgonzola",
    "gorgonzole": "gorgonzola",
    "gorgonzolor": "gorgonzola",
    "gorgonzolorna": "gorgonzola",
    "gorgonzolornas": "gorgonzola",
    "gorgonzolors": "gorgonzola",
    "gorgonzols": "gorgonzola",
    "gorill": "gorilla",
    "gorillan": "gorilla",
    "gorillans": "gorilla",
    "gorillas": "gorilla",
    "gorillaungar": "gorillaunge",
    "gorillaungarna": "gorillaunge",
    "gorillaungarnas": "gorillaunge",
    "gorillaungars": "gorillaunge",
    "gorillaungen": "gorillaunge",
    "gorillaungens": "gorillaunge",
    "gorillaunges": "gorillaunge",
    "gorille": "gorilla",
    "gorillor": "gorilla",
    "gorillorna": "gorilla",
    "gorillornas": "gorilla",
    "gorillors": "gorilla",
    "gorills": "gorilla",
    "gorm": "gorma",
    "gormade": "gorma",
    "gormades": "gorma",
    "gormande": "gorma",
    "gormanden": "gormande",
    "gormandena": "gormande",
    "gormandenas": "gormande",
    "gormandens": "gormande",
    "gormandes": "gormande",
    "gormandet": "gormande",
    "gormandets": "gormande",
    "gormar": "gorma",
    "gormas": "gorma",
    "gormat": "gorma",
    "gormats": "gorma",
    "gorret": "gorr",
    "gorrets": "gorr",
    "gorrs": "gorr",
    "gorån": "gorå",
    "goråna": "gorå",
    "gorånas": "gorå",
    "gorånen": "gorån",
    "gorånens": "gorån",
    "gorånet": "gorån",
    "gorånets": "gorån",
    "goråns": "gorån",
    "gorås": "gorå",
    "goråt": "gorå",
    "goråts": "gorå",
    "gos": "gosa",
    "gosade": "gosa",
    "gosades": "gosa",
    "gosande": "gosa",
    "gosanden": "gosande",
    "gosandena": "gosande",
    "gosandenas": "gosande",
    "gosandens": "gosande",
    "gosandes": "gosande",
    "gosandet": "gosande",
    "gosandets": "gosande",
    "gosar": "gosa",
    "gosas": "gosa",
    "gosat": "gosa",
    "gosats": "gosa",
    "gosiga": "gosig",
    "gosigare": "gosig",
    "gosigares": "gosig",
    "gosigas": "gosig",
    "gosigast": "gosig",
    "gosigaste": "gosig",
    "gosigastes": "gosig",
    "gosigasts": "gosig",
    "gosige": "gosig",
    "gosiges": "gosig",
    "gosigs": "gosig",
    "gosigt": "gosig",
    "gosigts": "gosig",
    "gospeln": "gospel",
    "gospelna": "gospel",
    "gospelnas": "gospel",
    "gospelns": "gospel",
    "gospels": "gospel",
    "gospelsarna": "gospel",
    "gospelsarnas": "gospel",
    "gospelsen": "gospel",
    "gospelsens": "gospel",
    "goss": "gosse",
    "gossamern": "gossamer",
    "gossamerns": "gossamer",
    "gossamers": "gossamer",
    "gossar": "gosse",
    "gossarna": "gosse",
    "gossarnas": "gosse",
    "gossars": "gosse",
    "gossen": "gosse",
    "gossens": "gosse",
    "gosses": "gosse",
    "gosskören": "gosskör",
    "gosskörens": "gosskör",
    "gosskörer": "gosskör",
    "gosskörerna": "gosskör",
    "gosskörernas": "gosskör",
    "gosskörers": "gosskör",
    "gosskörs": "gosskör",
    "goten": "got",
    "gotens": "got",
    "goter": "got",
    "goterna": "got",
    "goternas": "got",
    "goters": "got",
    "gotiken": "gotik",
    "gotikens": "gotik",
    "gotiks": "gotik",
    "gotisk": "gotiska",
    "gotiska": "gotisk",
    "gotiskan": "gotiska",
    "gotiskans": "gotiska",
    "gotiskare": "gotisk",
    "gotiskares": "gotisk",
    "gotiskas": "gotiska",
    "gotiskast": "gotisk",
    "gotiskaste": "gotisk",
    "gotiskastes": "gotisk",
    "gotiskasts": "gotisk",
    "gotiske": "gotisk",
    "gotiskes": "gotisk",
    "gotisks": "gotisk",
    "gotiskt": "gotisk",
    "gotiskts": "gotisk",
    "gotlandsmarmorn": "gotlandsmarmor",
    "gotlandsmarmorns": "gotlandsmarmor",
    "gotlandsmarmors": "gotlandsmarmor",
    "gotlandsrussen": "gotlandsruss",
    "gotlandsrussens": "gotlandsruss",
    "gotlandsrusset": "gotlandsruss",
    "gotlandsrussets": "gotlandsruss",
    "gotländsk": "gotländska",
    "gotländska": "gotländsk",
    "gotländskan": "gotländska",
    "gotländskans": "gotländska",
    "gotländskare": "gotländsk",
    "gotländskares": "gotländsk",
    "gotländskas": "gotländska",
    "gotländskast": "gotländsk",
    "gotländskaste": "gotländsk",
    "gotländskastes": "gotländsk",
    "gotländskasts": "gotländsk",
    "gotländske": "gotländska",
    "gotländskes": "gotländsk",
    "gotländskheten": "gotländskhet",
    "gotländskhetens": "gotländskhet",
    "gotländskhets": "gotländskhet",
    "gotländskor": "gotländska",
    "gotländskorna": "gotländska",
    "gotländskornas": "gotländska",
    "gotländskors": "gotländska",
    "gotländsks": "gotländsk",
    "gotländskt": "gotländsk",
    "gotländskts": "gotländsk",
    "gotlänningar": "gotlänning",
    "gotlänningarna": "gotlänning",
    "gotlänningarnas": "gotlänning",
    "gotlänningars": "gotlänning",
    "gotlänningen": "gotlänning",
    "gotlänningens": "gotlänning",
    "gotlännings": "gotlänning",
    "gots": "got",
    "gotska": "gotsk",
    "gotskare": "gotsk",
    "gotskares": "gotsk",
    "gotskas": "gotsk",
    "gotskast": "gotsk",
    "gotskaste": "gotsk",
    "gotskastes": "gotsk",
    "gotskasts": "gotsk",
    "gotske": "gotsk",
    "gotskes": "gotsk",
    "gotskheten": "gotskhet",
    "gotskhetens": "gotskhet",
    "gotskhets": "gotskhet",
    "gotsks": "gotsk",
    "gotskt": "gotsk",
    "gotskts": "gotsk",
    "gott": "gotter",
    "gotterna": "gotter",
    "gotternas": "gotter",
    "gotters": "gotter",
    "gottfinnandes": "gottfinnande",
    "gottfinnandet": "gottfinnande",
    "gottfinnandets": "gottfinnande",
    "gottgjord": "gottgöra",
    "gottgjorda": "gottgöra",
    "gottgjordas": "gottgöra",
    "gottgjorde": "gottgöra",
    "gottgjordes": "gottgöra",
    "gottgjords": "gottgöra",
    "gottgjort": "gottgöra",
    "gottgjorts": "gottgöra",
    "gottgör": "gottgöra",
    "gottgörande": "gottgöra",
    "gottgöranden": "gottgörande",
    "gottgörandena": "gottgörande",
    "gottgörandenas": "gottgörande",
    "gottgörandens": "gottgörande",
    "gottgörandes": "gottgörande",
    "gottgörandet": "gottgörande",
    "gottgörandets": "gottgörande",
    "gottgöras": "gottgöra",
    "gottgörelsen": "gottgörelse",
    "gottgörelsens": "gottgörelse",
    "gottgörelser": "gottgörelse",
    "gottgörelserna": "gottgörelse",
    "gottgörelsernas": "gottgörelse",
    "gottgörelsers": "gottgörelse",
    "gottgörelses": "gottgörelse",
    "gottgöres": "gottgöra",
    "gottgörs": "gottgöra",
    "gottiset": "gottis",
    "gottisets": "gottis",
    "gottköpsförklaringar": "gottköpsförklaring",
    "gottköpsförklaringarna": "gottköpsförklaring",
    "gottköpsförklaringarnas": "gottköpsförklaring",
    "gottköpsförklaringars": "gottköpsförklaring",
    "gottköpsförklaringen": "gottköpsförklaring",
    "gottköpsförklaringens": "gottköpsförklaring",
    "gottköpsförklarings": "gottköpsförklaring",
    "gottköpsvar": "gottköpsvara",
    "gottköpsvaran": "gottköpsvara",
    "gottköpsvarans": "gottköpsvara",
    "gottköpsvaras": "gottköpsvara",
    "gottköpsvare": "gottköpsvara",
    "gottköpsvaror": "gottköpsvara",
    "gottköpsvarorna": "gottköpsvara",
    "gottköpsvarornas": "gottköpsvara",
    "gottköpsvarors": "gottköpsvara",
    "gottköpsvars": "gottköpsvara",
    "gotts": "gotter",
    "gottskrev": "gottskriva",
    "gottskrevs": "gottskriva",
    "gottskriv": "gottskriva",
    "gottskrivande": "gottskriva",
    "gottskrivanden": "gottskrivande",
    "gottskrivandena": "gottskrivande",
    "gottskrivandenas": "gottskrivande",
    "gottskrivandens": "gottskrivande",
    "gottskrivandes": "gottskrivande",
    "gottskrivandet": "gottskrivande",
    "gottskrivandets": "gottskrivande",
    "gottskrivas": "gottskriva",
    "gottskrive": "gottskriva",
    "gottskriven": "gottskriva",
    "gottskrivens": "gottskriva",
    "gottskriver": "gottskriva",
    "gottskrives": "gottskriva",
    "gottskrivet": "gottskriva",
    "gottskrivets": "gottskriva",
    "gottskrivit": "gottskriva",
    "gottskrivits": "gottskriva",
    "gottskrivna": "gottskriva",
    "gottskrivnas": "gottskriva",
    "gottskrivne": "gottskriva",
    "gottskrivnes": "gottskriva",
    "gottskrivs": "gottskriva",
    "gouachen": "gouache",
    "gouachens": "gouache",
    "gouacher": "gouache",
    "gouacherna": "gouache",
    "gouachernas": "gouache",
    "gouachers": "gouache",
    "gouaches": "gouache",
    "gourmanden": "gourmand",
    "gourmandens": "gourmand",
    "gourmander": "gourmand",
    "gourmanderna": "gourmand",
    "gourmandernas": "gourmand",
    "gourmanders": "gourmand",
    "gourmands": "gourmand",
    "gourmeten": "gourmet",
    "gourmetens": "gourmet",
    "gourmeter": "gourmet",
    "gourmeterna": "gourmet",
    "gourmeternas": "gourmet",
    "gourmeters": "gourmet",
    "gourmets": "gourmet",
    "gourméer": "gourmé",
    "gourméerna": "gourmé",
    "gourméernas": "gourmé",
    "gourméers": "gourmé",
    "gourmén": "gourmé",
    "gourméns": "gourmé",
    "gourmés": "gourmé",
    "gouterad": "goutera",
    "gouterade": "goutera",
    "gouterades": "goutera",
    "gouterads": "goutera",
    "gouterande": "goutera",
    "gouteranden": "gouterande",
    "gouterandena": "gouterande",
    "gouterandenas": "gouterande",
    "gouterandens": "gouterande",
    "gouterandes": "gouterande",
    "gouterandet": "gouterande",
    "gouterandets": "gouterande",
    "gouterar": "goutera",
    "gouteras": "goutera",
    "gouterat": "goutera",
    "gouterats": "goutera",
    "gouterbara": "gouterbar",
    "gouterbarare": "gouterbar",
    "gouterbarares": "gouterbar",
    "gouterbaras": "gouterbar",
    "gouterbarast": "gouterbar",
    "gouterbaraste": "gouterbar",
    "gouterbarastes": "gouterbar",
    "gouterbarasts": "gouterbar",
    "gouterbare": "gouterbar",
    "gouterbares": "gouterbar",
    "gouterbarheten": "gouterbarhet",
    "gouterbarhetens": "gouterbarhet",
    "gouterbarhets": "gouterbarhet",
    "gouterbars": "gouterbar",
    "gouterbart": "gouterbar",
    "gouterbarts": "gouterbar",
    "gouteringar": "goutering",
    "gouteringarna": "goutering",
    "gouteringarnas": "goutering",
    "gouteringars": "goutering",
    "gouteringen": "goutering",
    "gouteringens": "goutering",
    "gouterings": "goutering",
    "gps-ad": "gps-a",
    "gps-ads": "gps-a",
    "gps-ande": "gps-a",
    "gps-andes": "gps-a",
    "gps:ade": "gps:a",
    "gps:ads": "gps:a",
    "gps:andes": "gps:a",
    "gps:arna": "gps",
    "gps:as": "gps:a",
    "gps:at": "gps:a",
    "gps:er": "gps",
    "gps:ernas": "gps",
    "gps:n": "gps",
    "gps:s": "gps",
    "gpsade": "gpsa",
    "gpsades": "gpsa",
    "gpsads": "gpsa",
    "gpsande": "gpsa",
    "gpsandes": "gpsa",
    "gpsar": "gpsa",
    "gpsas": "gpsa",
    "gpsat": "gpsa",
    "gpsats": "gpsa",
    "gpser": "gps",
    "gpsernas": "gps",
    "gpsn": "gps",
    "gpss": "gps",
    "grabb": "grabba",
    "grabbad": "grabba",
    "grabbade": "grabba",
    "grabbades": "grabba",
    "grabbads": "grabba",
    "grabbande": "grabba",
    "grabbanden": "grabbande",
    "grabbandena": "grabbande",
    "grabbandenas": "grabbande",
    "grabbandens": "grabbande",
    "grabbandes": "grabbande",
    "grabbandet": "grabbande",
    "grabbandets": "grabbande",
    "grabbar": "grabba",
    "grabbarna": "grabb",
    "grabbarnas": "grabb",
    "grabbars": "grabb",
    "grabbas": "grabba",
    "grabbat": "grabba",
    "grabbatagen": "grabbatag",
    "grabbatagens": "grabbatag",
    "grabbataget": "grabbatag",
    "grabbatagets": "grabbatag",
    "grabbatags": "grabbatag",
    "grabbats": "grabba",
    "grabben": "grabb",
    "grabbens": "grabb",
    "grabbnäv": "grabbnäve",
    "grabbnävar": "grabbnäve",
    "grabbnävarna": "grabbnäve",
    "grabbnävarnas": "grabbnäve",
    "grabbnävars": "grabbnäve",
    "grabbnäven": "grabbnäve",
    "grabbnävens": "grabbnäve",
    "grabbnäves": "grabbnäve",
    "grabbnävs": "grabbnäve",
    "grabbs": "grabb",
    "gracen": "grace",
    "gracens": "grace",
    "gracer": "grace",
    "gracerna": "gracer",
    "gracernas": "gracer",
    "gracers": "gracer",
    "graces": "grace",
    "gracila": "gracil",
    "gracilare": "gracil",
    "gracilares": "gracil",
    "gracilas": "gracil",
    "gracilast": "gracil",
    "gracilaste": "gracil",
    "gracilastes": "gracil",
    "gracilasts": "gracil",
    "gracile": "gracil",
    "graciles": "gracil",
    "gracils": "gracil",
    "gracilt": "gracil",
    "gracilts": "gracil",
    "graciösa": "graciös",
    "graciösare": "graciös",
    "graciösares": "graciös",
    "graciösas": "graciös",
    "graciösast": "graciös",
    "graciösaste": "graciös",
    "graciösastes": "graciös",
    "graciösasts": "graciös",
    "graciöse": "graciös",
    "graciöses": "graciös",
    "graciöst": "graciös",
    "graciösts": "graciös",
    "grada": "grad",
    "gradad": "grada",
    "gradade": "grada",
    "gradades": "grada",
    "gradads": "grada",
    "gradande": "grada",
    "gradanden": "gradande",
    "gradandena": "gradande",
    "gradandenas": "gradande",
    "gradandens": "gradande",
    "gradandes": "gradande",
    "gradandet": "gradande",
    "gradandets": "gradande",
    "gradar": "grada",
    "gradare": "grad",
    "gradares": "grad",
    "gradas": "grada",
    "gradast": "grad",
    "gradaste": "grad",
    "gradastes": "grad",
    "gradasts": "grad",
    "gradat": "grada",
    "gradationen": "gradation",
    "gradationens": "gradation",
    "gradationer": "gradation",
    "gradationerna": "gradation",
    "gradationernas": "gradation",
    "gradationers": "gradation",
    "gradations": "gradation",
    "gradats": "grada",
    "gradbeteckningar": "gradbeteckning",
    "gradbeteckningarna": "gradbeteckning",
    "gradbeteckningarnas": "gradbeteckning",
    "gradbeteckningars": "gradbeteckning",
    "gradbeteckningen": "gradbeteckning",
    "gradbeteckningens": "gradbeteckning",
    "gradbetecknings": "gradbeteckning",
    "gradböjningar": "gradböjning",
    "gradböjningarna": "gradböjning",
    "gradböjningarnas": "gradböjning",
    "gradböjningars": "gradböjning",
    "gradböjningen": "gradböjning",
    "gradböjningens": "gradböjning",
    "gradböjnings": "gradböjning",
    "grade": "grad",
    "graden": "grad",
    "gradens": "grad",
    "grader": "grad",
    "graderad": "gradera",
    "graderade": "gradera",
    "graderades": "gradera",
    "graderads": "gradera",
    "graderande": "gradera",
    "graderanden": "graderande",
    "graderandena": "graderande",
    "graderandenas": "graderande",
    "graderandens": "graderande",
    "graderandes": "graderande",
    "graderandet": "graderande",
    "graderandets": "graderande",
    "graderar": "gradera",
    "graderas": "gradera",
    "graderat": "gradera",
    "graderats": "gradera",
    "graderbara": "graderbar",
    "graderbarare": "graderbar",
    "graderbarares": "graderbar",
    "graderbaras": "graderbar",
    "graderbarast": "graderbar",
    "graderbaraste": "graderbar",
    "graderbarastes": "graderbar",
    "graderbarasts": "graderbar",
    "graderbare": "graderbar",
    "graderbares": "graderbar",
    "graderbarheten": "graderbarhet",
    "graderbarhetens": "graderbarhet",
    "graderbarhets": "graderbarhet",
    "graderbars": "graderbar",
    "graderbart": "graderbar",
    "graderbarts": "graderbar",
    "graderingar": "gradering",
    "graderingarna": "gradering",
    "graderingarnas": "gradering",
    "graderingars": "gradering",
    "graderingen": "gradering",
    "graderingens": "gradering",
    "graderings": "gradering",
    "graderna": "grad",
    "gradernas": "grad",
    "graders": "grad",
    "graderverken": "graderverk",
    "graderverkens": "graderverk",
    "graderverket": "graderverk",
    "graderverkets": "graderverk",
    "graderverks": "graderverk",
    "grades": "grad",
    "gradheten": "gradhet",
    "gradhetens": "gradhet",
    "gradhets": "gradhet",
    "gradienten": "gradient",
    "gradientens": "gradient",
    "gradienter": "gradient",
    "gradienterna": "gradient",
    "gradienternas": "gradient",
    "gradienters": "gradient",
    "gradients": "gradient",
    "gradlisten": "gradlist",
    "gradlistens": "gradlist",
    "gradlister": "gradlist",
    "gradlisterna": "gradlist",
    "gradlisternas": "gradlist",
    "gradlisters": "gradlist",
    "gradlists": "gradlist",
    "gradmejseln": "gradmejsel",
    "gradmejselns": "gradmejsel",
    "gradmejsels": "gradmejsel",
    "gradmejslar": "gradmejsel",
    "gradmejslarna": "gradmejsel",
    "gradmejslarnas": "gradmejsel",
    "gradmejslars": "gradmejsel",
    "gradmätar": "gradmätare",
    "gradmätaren": "gradmätare",
    "gradmätarens": "gradmätare",
    "gradmätares": "gradmätare",
    "gradmätarna": "gradmätare",
    "gradmätarnas": "gradmätare",
    "gradmätningar": "gradmätning",
    "gradmätningarna": "gradmätning",
    "gradmätningarnas": "gradmätning",
    "gradmätningars": "gradmätning",
    "gradmätningen": "gradmätning",
    "gradmätningens": "gradmätning",
    "gradmätnings": "gradmätning",
    "gradnäten": "gradnät",
    "gradnätens": "gradnät",
    "gradnätet": "gradnät",
    "gradnätets": "gradnät",
    "gradnäts": "gradnät",
    "grads": "grad",
    "gradskillnaden": "gradskillnad",
    "gradskillnadens": "gradskillnad",
    "gradskillnader": "gradskillnad",
    "gradskillnaderna": "gradskillnad",
    "gradskillnadernas": "gradskillnad",
    "gradskillnaders": "gradskillnad",
    "gradskillnads": "gradskillnad",
    "gradskivan": "gradskiva",
    "gradskivans": "gradskiva",
    "gradskivas": "gradskiva",
    "gradskive": "gradskiva",
    "gradskivor": "gradskiva",
    "gradskivorna": "gradskiva",
    "gradskivornas": "gradskiva",
    "gradskivors": "gradskiva",
    "gradstrecken": "gradstreck",
    "gradstreckens": "gradstreck",
    "gradstrecket": "gradstreck",
    "gradstreckets": "gradstreck",
    "gradstrecks": "gradstreck",
    "gradsågar": "gradsåg",
    "gradsågarna": "gradsåg",
    "gradsågarnas": "gradsåg",
    "gradsågars": "gradsåg",
    "gradsågen": "gradsåg",
    "gradsågens": "gradsåg",
    "gradsågs": "gradsåg",
    "gradtalen": "gradtal",
    "gradtalens": "gradtal",
    "gradtalet": "gradtal",
    "gradtalets": "gradtal",
    "gradtals": "gradtal",
    "gradtappar": "gradtapp",
    "gradtapparna": "gradtapp",
    "gradtapparnas": "gradtapp",
    "gradtappars": "gradtapp",
    "gradtappen": "gradtapp",
    "gradtappens": "gradtapp",
    "gradtapps": "gradtapp",
    "gradteckens": "gradtecken",
    "gradtecknen": "gradtecken",
    "gradtecknens": "gradtecken",
    "gradtecknet": "gradtecken",
    "gradtecknets": "gradtecken",
    "gradualavhandlingar": "gradualavhandling",
    "gradualavhandlingarna": "gradualavhandling",
    "gradualavhandlingarnas": "gradualavhandling",
    "gradualavhandlingars": "gradualavhandling",
    "gradualavhandlingen": "gradualavhandling",
    "gradualavhandlingens": "gradualavhandling",
    "gradualavhandlings": "gradualavhandling",
    "gradualpsalmen": "gradualpsalm",
    "gradualpsalmens": "gradualpsalm",
    "gradualpsalmer": "gradualpsalm",
    "gradualpsalmerna": "gradualpsalm",
    "gradualpsalmernas": "gradualpsalm",
    "gradualpsalmers": "gradualpsalm",
    "gradualpsalms": "gradualpsalm",
    "graduella": "graduell",
    "graduellare": "graduell",
    "graduellares": "graduell",
    "graduellas": "graduell",
    "graduellast": "graduell",
    "graduellaste": "graduell",
    "graduellastes": "graduell",
    "graduellasts": "graduell",
    "graduelle": "graduell",
    "graduelles": "graduell",
    "graduells": "graduell",
    "graduellt": "graduell",
    "graduellts": "graduell",
    "graduerad": "graduera",
    "graduerade": "graduera",
    "graduerades": "graduera",
    "graduerads": "graduera",
    "graduerande": "graduera",
    "gradueranden": "graduerande",
    "graduerandena": "graduerande",
    "graduerandenas": "graduerande",
    "graduerandens": "graduerande",
    "graduerandes": "graduerande",
    "graduerandet": "graduerande",
    "graduerandets": "graduerande",
    "graduerar": "graduera",
    "gradueras": "graduera",
    "graduerat": "graduera",
    "graduerats": "graduera",
    "graduerbara": "graduerbar",
    "graduerbarare": "graduerbar",
    "graduerbarares": "graduerbar",
    "graduerbaras": "graduerbar",
    "graduerbarast": "graduerbar",
    "graduerbaraste": "graduerbar",
    "graduerbarastes": "graduerbar",
    "graduerbarasts": "graduerbar",
    "graduerbare": "graduerbar",
    "graduerbares": "graduerbar",
    "graduerbarheten": "graduerbarhet",
    "graduerbarhetens": "graduerbarhet",
    "graduerbarhets": "graduerbarhet",
    "graduerbars": "graduerbar",
    "graduerbart": "graduerbar",
    "graduerbarts": "graduerbar",
    "gradueringar": "graduering",
    "gradueringarna": "graduering",
    "gradueringarnas": "graduering",
    "gradueringars": "graduering",
    "gradueringen": "graduering",
    "gradueringens": "graduering",
    "graduerings": "graduering",
    "gradvisa": "gradvis",
    "gradvisare": "gradvis",
    "gradvisares": "gradvis",
    "gradvisas": "gradvis",
    "gradvisast": "gradvis",
    "gradvisaste": "gradvis",
    "gradvisastes": "gradvis",
    "gradvisasts": "gradvis",
    "gradvise": "gradvis",
    "gradvises": "gradvis",
    "gradvist": "gradvis",
    "gradvists": "gradvis",
    "gradängen": "gradäng",
    "gradängens": "gradäng",
    "gradänger": "gradäng",
    "gradängerna": "gradäng",
    "gradängernas": "gradäng",
    "gradängers": "gradäng",
    "gradängs": "gradäng",
    "grafematiska": "grafematisk",
    "grafematiskare": "grafematisk",
    "grafematiskares": "grafematisk",
    "grafematiskas": "grafematisk",
    "grafematiskast": "grafematisk",
    "grafematiskaste": "grafematisk",
    "grafematiskastes": "grafematisk",
    "grafematiskasts": "grafematisk",
    "grafematiske": "grafematisk",
    "grafematiskes": "grafematisk",
    "grafematisks": "grafematisk",
    "grafematiskt": "grafematisk",
    "grafematiskts": "grafematisk",
    "grafemen": "grafem",
    "grafemens": "grafem",
    "grafemet": "grafem",
    "grafemets": "grafem",
    "grafems": "grafem",
    "grafen": "graf",
    "grafenen": "grafen",
    "grafenens": "grafen",
    "grafener": "grafen",
    "grafenerna": "grafen",
    "grafenernas": "grafen",
    "grafeners": "grafen",
    "grafens": "grafen",
    "grafer": "graf",
    "graferna": "graf",
    "grafernas": "graf",
    "grafers": "graf",
    "graffitin": "graffiti",
    "graffitins": "graffiti",
    "graffitis": "graffiti",
    "grafiken": "grafik",
    "grafikens": "grafik",
    "grafikern": "grafiker",
    "grafikerna": "grafiker",
    "grafikernas": "grafiker",
    "grafikerns": "grafiker",
    "grafikers": "grafiker",
    "grafiks": "grafik",
    "grafiska": "grafisk",
    "grafiskare": "grafisk",
    "grafiskares": "grafisk",
    "grafiskas": "grafisk",
    "grafiskast": "grafisk",
    "grafiskaste": "grafisk",
    "grafiskastes": "grafisk",
    "grafiskasts": "grafisk",
    "grafiske": "grafisk",
    "grafiskes": "grafisk",
    "grafisks": "grafisk",
    "grafiskt": "grafisk",
    "grafiskts": "grafisk",
    "grafitdegeln": "grafitdegel",
    "grafitdegelns": "grafitdegel",
    "grafitdegels": "grafitdegel",
    "grafitdeglar": "grafitdegel",
    "grafitdeglarna": "grafitdegel",
    "grafitdeglarnas": "grafitdegel",
    "grafitdeglars": "grafitdegel",
    "grafiten": "grafit",
    "grafitens": "grafit",
    "grafiter": "grafit",
    "grafiterad": "grafitera",
    "grafiterade": "grafitera",
    "grafiterades": "grafitera",
    "grafiterads": "grafitera",
    "grafiterande": "grafitera",
    "grafiteranden": "grafiterande",
    "grafiterandena": "grafiterande",
    "grafiterandenas": "grafiterande",
    "grafiterandens": "grafiterande",
    "grafiterandes": "grafiterande",
    "grafiterandet": "grafiterande",
    "grafiterandets": "grafiterande",
    "grafiterar": "grafitera",
    "grafiteras": "grafitera",
    "grafiterat": "grafitera",
    "grafiterats": "grafitera",
    "grafiterbara": "grafiterbar",
    "grafiterbarare": "grafiterbar",
    "grafiterbarares": "grafiterbar",
    "grafiterbaras": "grafiterbar",
    "grafiterbarast": "grafiterbar",
    "grafiterbaraste": "grafiterbar",
    "grafiterbarastes": "grafiterbar",
    "grafiterbarasts": "grafiterbar",
    "grafiterbare": "grafiterbar",
    "grafiterbares": "grafiterbar",
    "grafiterbarheten": "grafiterbarhet",
    "grafiterbarhetens": "grafiterbarhet",
    "grafiterbarhets": "grafiterbarhet",
    "grafiterbars": "grafiterbar",
    "grafiterbart": "grafiterbar",
    "grafiterbarts": "grafiterbar",
    "grafiteringar": "grafitering",
    "grafiteringarna": "grafitering",
    "grafiteringarnas": "grafitering",
    "grafiteringars": "grafitering",
    "grafiteringen": "grafitering",
    "grafiteringens": "grafitering",
    "grafiterings": "grafitering",
    "grafiterna": "grafit",
    "grafiternas": "grafit",
    "grafiters": "grafit",
    "grafitgråa": "grafitgrå",
    "grafitgråare": "grafitgrå",
    "grafitgråares": "grafitgrå",
    "grafitgråas": "grafitgrå",
    "grafitgråast": "grafitgrå",
    "grafitgråaste": "grafitgrå",
    "grafitgråastes": "grafitgrå",
    "grafitgråasts": "grafitgrå",
    "grafitgråe": "grafitgrå",
    "grafitgråes": "grafitgrå",
    "grafitgrås": "grafitgrå",
    "grafitgrått": "grafitgrå",
    "grafitgråtts": "grafitgrå",
    "grafits": "grafit",
    "grafologen": "grafolog",
    "grafologens": "grafolog",
    "grafologer": "grafolog",
    "grafologerna": "grafolog",
    "grafologernas": "grafolog",
    "grafologers": "grafolog",
    "grafologien": "grafologi",
    "grafologiens": "grafologi",
    "grafologin": "grafologi",
    "grafologins": "grafologi",
    "grafologis": "grafologi",
    "grafologs": "grafolog",
    "grafonomien": "grafonomi",
    "grafonomiens": "grafonomi",
    "grafonomin": "grafonomi",
    "grafonomins": "grafonomi",
    "grafonomis": "grafonomi",
    "grafonomiska": "grafonomisk",
    "grafonomiskare": "grafonomisk",
    "grafonomiskares": "grafonomisk",
    "grafonomiskas": "grafonomisk",
    "grafonomiskast": "grafonomisk",
    "grafonomiskaste": "grafonomisk",
    "grafonomiskastes": "grafonomisk",
    "grafonomiskasts": "grafonomisk",
    "grafonomiske": "grafonomisk",
    "grafonomiskes": "grafonomisk",
    "grafonomisks": "grafonomisk",
    "grafonomiskt": "grafonomisk",
    "grafonomiskts": "grafonomisk",
    "grafs": "graf",
    "grafteorien": "grafteori",
    "grafteoriens": "grafteori",
    "grafteorier": "grafteori",
    "grafteorierna": "grafteori",
    "grafteoriernas": "grafteori",
    "grafteoriers": "grafteori",
    "grafteorin": "grafteori",
    "grafteorins": "grafteori",
    "grafteoris": "grafteori",
    "grahamsbröden": "grahamsbröd",
    "grahamsbrödens": "grahamsbröd",
    "grahamsbrödet": "grahamsbröd",
    "grahamsbrödets": "grahamsbröd",
    "grahamsbröds": "grahamsbröd",
    "grahamsmjölet": "grahamsmjöl",
    "grahamsmjölets": "grahamsmjöl",
    "grahamsmjöls": "grahamsmjöl",
    "grainen": "grain",
    "grainens": "grain",
    "grains": "grain",
    "graman": "gramaner",
    "gramanerna": "gramaner",
    "gramanernas": "gramaner",
    "gramaners": "gramaner",
    "gramans": "gramaner",
    "gramkalorien": "gramkalori",
    "gramkaloriens": "gramkalori",
    "gramkalorier": "gramkalori",
    "gramkalorierna": "gramkalori",
    "gramkaloriernas": "gramkalori",
    "gramkaloriers": "gramkalori",
    "gramkalorin": "gramkalori",
    "gramkalorins": "gramkalori",
    "gramkaloris": "gramkalori",
    "grammatik": "grammatika",
    "grammatikaliska": "grammatikalisk",
    "grammatikaliskare": "grammatikalisk",
    "grammatikaliskares": "grammatikalisk",
    "grammatikaliskas": "grammatikalisk",
    "grammatikaliskast": "grammatikalisk",
    "grammatikaliskaste": "grammatikalisk",
    "grammatikaliskastes": "grammatikalisk",
    "grammatikaliskasts": "grammatikalisk",
    "grammatikaliske": "grammatikalisk",
    "grammatikaliskes": "grammatikalisk",
    "grammatikalisks": "grammatikalisk",
    "grammatikaliskt": "grammatikalisk",
    "grammatikaliskts": "grammatikalisk",
    "grammatikan": "grammatika",
    "grammatikans": "grammatika",
    "grammatikas": "grammatika",
    "grammatikboken": "grammatikbok",
    "grammatikbokens": "grammatikbok",
    "grammatikboks": "grammatikbok",
    "grammatikböcker": "grammatikbok",
    "grammatikböckerna": "grammatikbok",
    "grammatikböckernas": "grammatikbok",
    "grammatikböckers": "grammatikbok",
    "grammatike": "grammatika",
    "grammatiken": "grammatik",
    "grammatikens": "grammatik",
    "grammatiker": "grammatik",
    "grammatikern": "grammatiker",
    "grammatikerna": "grammatiker",
    "grammatikernas": "grammatiker",
    "grammatikerns": "grammatiker",
    "grammatikers": "grammatiker",
    "grammatikor": "grammatika",
    "grammatikorna": "grammatika",
    "grammatikornas": "grammatika",
    "grammatikors": "grammatika",
    "grammatikregeln": "grammatikregel",
    "grammatikregelns": "grammatikregel",
    "grammatikregels": "grammatikregel",
    "grammatikregler": "grammatikregel",
    "grammatikreglerna": "grammatikregel",
    "grammatikreglernas": "grammatikregel",
    "grammatikreglers": "grammatikregel",
    "grammatiks": "grammatika",
    "grammatiska": "grammatisk",
    "grammatiskare": "grammatisk",
    "grammatiskares": "grammatisk",
    "grammatiskas": "grammatisk",
    "grammatiskast": "grammatisk",
    "grammatiskaste": "grammatisk",
    "grammatiskastes": "grammatisk",
    "grammatiskasts": "grammatisk",
    "grammatiske": "grammatisk",
    "grammatiskes": "grammatisk",
    "grammatisks": "grammatisk",
    "grammatiskt": "grammatisk",
    "grammatiskts": "grammatisk",
    "grammen": "gram",
    "grammens": "gram",
    "grammet": "gram",
    "grammets": "gram",
    "grammofonarkiven": "grammofonarkiv",
    "grammofonarkivens": "grammofonarkiv",
    "grammofonarkivet": "grammofonarkiv",
    "grammofonarkivets": "grammofonarkiv",
    "grammofonarkivs": "grammofonarkiv",
    "grammofonen": "grammofon",
    "grammofonens": "grammofon",
    "grammofoner": "grammofon",
    "grammofonerna": "grammofon",
    "grammofonernas": "grammofon",
    "grammofoners": "grammofon",
    "grammofons": "grammofon",
    "grammofonskivan": "grammofonskiva",
    "grammofonskivans": "grammofonskiva",
    "grammofonskivas": "grammofonskiva",
    "grammofonskive": "grammofonskiva",
    "grammofonskivor": "grammofonskiva",
    "grammofonskivorna": "grammofonskiva",
    "grammofonskivornas": "grammofonskiva",
    "grammofonskivors": "grammofonskiva",
    "grammofonstiften": "grammofonstift",
    "grammofonstiftens": "grammofonstift",
    "grammofonstiftet": "grammofonstift",
    "grammofonstiftets": "grammofonstift",
    "grammofonstifts": "grammofonstift",
    "grammolekylen": "grammolekyl",
    "grammolekylens": "grammolekyl",
    "grammolekyler": "grammolekyl",
    "grammolekylerna": "grammolekyl",
    "grammolekylernas": "grammolekyl",
    "grammolekylers": "grammolekyl",
    "grammolekyls": "grammolekyl",
    "grams": "gram",
    "granar": "gran",
    "granarna": "gran",
    "granarnas": "gran",
    "granars": "gran",
    "granatattacken": "granatattack",
    "granatattackens": "granatattack",
    "granatattacker": "granatattack",
    "granatattackerna": "granatattack",
    "granatattackernas": "granatattack",
    "granatattackers": "granatattack",
    "granatattacks": "granatattack",
    "granatelden": "granateld",
    "granateldens": "granateld",
    "granatelds": "granateld",
    "granaten": "granat",
    "granatens": "granat",
    "granater": "granat",
    "granaterna": "granat",
    "granaternas": "granat",
    "granaters": "granat",
    "granatgevären": "granatgevär",
    "granatgevärens": "granatgevär",
    "granatgeväret": "granatgevär",
    "granatgevärets": "granatgevär",
    "granatgevärs": "granatgevär",
    "granatkarteschen": "granatkartesch",
    "granatkarteschens": "granatkartesch",
    "granatkartescher": "granatkartesch",
    "granatkartescherna": "granatkartesch",
    "granatkarteschernas": "granatkartesch",
    "granatkarteschers": "granatkartesch",
    "granatkarteschs": "granatkartesch",
    "granats": "granat",
    "granatskärv": "granatskärva",
    "granatskärvan": "granatskärva",
    "granatskärvans": "granatskärva",
    "granatskärvas": "granatskärva",
    "granatskärve": "granatskärva",
    "granatskärvor": "granatskärva",
    "granatskärvorna": "granatskärva",
    "granatskärvornas": "granatskärva",
    "granatskärvors": "granatskärva",
    "granatskärvs": "granatskärva",
    "granatträffar": "granatträff",
    "granatträffarna": "granatträff",
    "granatträffarnas": "granatträff",
    "granatträffars": "granatträff",
    "granatträffen": "granatträff",
    "granatträffens": "granatträff",
    "granatträffs": "granatträff",
    "granatäppelkärn": "granatäppelkärna",
    "granatäppelkärnan": "granatäppelkärna",
    "granatäppelkärnans": "granatäppelkärna",
    "granatäppelkärnas": "granatäppelkärna",
    "granatäppelkärne": "granatäppelkärna",
    "granatäppelkärnor": "granatäppelkärna",
    "granatäppelkärnorna": "granatäppelkärna",
    "granatäppelkärnornas": "granatäppelkärna",
    "granatäppelkärnors": "granatäppelkärna",
    "granatäppelkärns": "granatäppelkärna",
    "granatäpplen": "granatäpple",
    "granatäpplena": "granatäpple",
    "granatäpplenas": "granatäpple",
    "granatäpplens": "granatäpple",
    "granatäpples": "granatäpple",
    "granatäpplet": "granatäpple",
    "granatäpplets": "granatäpple",
    "granatäppls": "granatäpple",
    "granbarren": "granbarr",
    "granbarrens": "granbarr",
    "granbarret": "granbarr",
    "granbarrets": "granbarr",
    "granbarrlusen": "granbarrlus",
    "granbarrlusens": "granbarrlus",
    "granbarrlöss": "granbarrlus",
    "granbarrlössen": "granbarrlus",
    "granbarrlössens": "granbarrlus",
    "granbarrs": "granbarr",
    "grand-guignols": "grand-guignol",
    "granden": "grand",
    "grandens": "grand",
    "grander": "grand",
    "granderna": "grand",
    "grandernas": "grand",
    "granders": "grand",
    "grandet": "grand",
    "grandets": "grand",
    "grandezzan": "grandezza",
    "grandezzans": "grandezza",
    "grandezzas": "grandezza",
    "grandiosa": "grandios",
    "grandiosare": "grandios",
    "grandiosares": "grandios",
    "grandiosas": "grandios",
    "grandiosast": "grandios",
    "grandiosaste": "grandios",
    "grandiosastes": "grandios",
    "grandiosasts": "grandios",
    "grandiose": "grandios",
    "grandioses": "grandios",
    "grandiosheten": "grandioshet",
    "grandioshetens": "grandioshet",
    "grandioshets": "grandioshet",
    "grandiost": "grandios",
    "grandiosts": "grandios",
    "grands": "grand",
    "grandseigneuren": "grandseigneur",
    "grandseigneurens": "grandseigneur",
    "grandseigneurer": "grandseigneur",
    "grandseigneurerna": "grandseigneur",
    "grandseigneurernas": "grandseigneur",
    "grandseigneurers": "grandseigneur",
    "grandseigneurs": "grandseigneur",
    "granen": "gran",
    "granens": "gran",
    "granet": "gran",
    "granets": "gran",
    "grangirlangen": "grangirlang",
    "grangirlangens": "grangirlang",
    "grangirlanger": "grangirlang",
    "grangirlangerna": "grangirlang",
    "grangirlangernas": "grangirlang",
    "grangirlangers": "grangirlang",
    "grangirlangs": "grangirlang",
    "grangrenar": "grangren",
    "grangrenarna": "grangren",
    "grangrenarnas": "grangren",
    "grangrenars": "grangren",
    "grangrenen": "grangren",
    "grangrenens": "grangren",
    "grangrens": "grangren",
    "granhäckar": "granhäck",
    "granhäckarna": "granhäck",
    "granhäckarnas": "granhäck",
    "granhäckars": "granhäck",
    "granhäcken": "granhäck",
    "granhäckens": "granhäck",
    "granhäcks": "granhäck",
    "granimitationen": "granimitation",
    "granimitationens": "granimitation",
    "granimitationer": "granimitation",
    "granimitationerna": "granimitation",
    "granimitationernas": "granimitation",
    "granimitationers": "granimitation",
    "granimitations": "granimitation",
    "graniten": "granit",
    "granitens": "granit",
    "graniter": "granit",
    "graniterna": "granit",
    "graniternas": "granit",
    "graniters": "granit",
    "granitkeramiken": "granitkeramik",
    "granitkeramikens": "granitkeramik",
    "granitkeramiks": "granitkeramik",
    "granitkeramikskärar": "granitkeramikskärare",
    "granitkeramikskäraren": "granitkeramikskärare",
    "granitkeramikskärarens": "granitkeramikskärare",
    "granitkeramikskärares": "granitkeramikskärare",
    "granitkeramikskärarna": "granitkeramikskärare",
    "granitkeramikskärarnas": "granitkeramikskärare",
    "granits": "granit",
    "grann": "granne",
    "granna": "grann",
    "grannar": "granne",
    "grannare": "grann",
    "grannares": "grann",
    "grannarna": "granne",
    "grannarnas": "granne",
    "grannars": "granne",
    "grannas": "grann",
    "grannast": "grann",
    "grannaste": "grann",
    "grannastes": "grann",
    "grannasts": "grann",
    "granne": "grann",
    "grannelaget": "grannelag",
    "grannelagets": "grannelag",
    "grannelags": "grannelag",
    "grannen": "granne",
    "grannens": "granne",
    "grannes": "granne",
    "grannet": "grann",
    "grannets": "grann",
    "grannfastigheten": "grannfastighet",
    "grannfastighetens": "grannfastighet",
    "grannfastigheter": "grannfastighet",
    "grannfastigheterna": "grannfastighet",
    "grannfastigheternas": "grannfastighet",
    "grannfastigheters": "grannfastighet",
    "grannfastighets": "grannfastighet",
    "grannfejden": "grannfejd",
    "grannfejdens": "grannfejd",
    "grannfejder": "grannfejd",
    "grannfejderna": "grannfejd",
    "grannfejdernas": "grannfejd",
    "grannfejders": "grannfejd",
    "grannfejds": "grannfejd",
    "grannheten": "grannhet",
    "grannhetens": "grannhet",
    "grannhets": "grannhet",
    "grannkungar": "grannkung",
    "grannkungarna": "grannkung",
    "grannkungarnas": "grannkung",
    "grannkungars": "grannkung",
    "grannkungen": "grannkung",
    "grannkungens": "grannkung",
    "grannkungs": "grannkung",
    "grannlandet": "grannland",
    "grannlandets": "grannland",
    "grannlands": "grannland",
    "grannländer": "grannland",
    "grannländerna": "grannland",
    "grannländernas": "grannland",
    "grannländers": "grannland",
    "grannlåten": "grannlåt",
    "grannlåtens": "grannlåt",
    "grannlåter": "grannlåt",
    "grannlåterna": "grannlåt",
    "grannlåternas": "grannlåt",
    "grannlåters": "grannlåt",
    "grannlåts": "grannlåt",
    "grannpojk": "grannpojke",
    "grannpojkar": "grannpojke",
    "grannpojkarna": "grannpojke",
    "grannpojkarnas": "grannpojke",
    "grannpojkars": "grannpojke",
    "grannpojken": "grannpojke",
    "grannpojkens": "grannpojke",
    "grannpojkes": "grannpojke",
    "grannpojks": "grannpojke",
    "grannräcken": "grannräcke",
    "grannräckena": "grannräcke",
    "grannräckenas": "grannräcke",
    "grannräckens": "grannräcke",
    "grannräckes": "grannräcke",
    "grannräcket": "grannräcke",
    "grannräckets": "grannräcke",
    "granns": "granne",
    "grannskapen": "grannskap",
    "grannskapens": "grannskap",
    "grannskapet": "grannskap",
    "grannskapets": "grannskap",
    "grannskaps": "grannskap",
    "grannstaten": "grannstat",
    "grannstatens": "grannstat",
    "grannstater": "grannstat",
    "grannstaterna": "grannstat",
    "grannstaternas": "grannstat",
    "grannstaters": "grannstat",
    "grannstats": "grannstat",
    "grannstjärnan": "grannstjärna",
    "grannstjärnans": "grannstjärna",
    "grannstjärnas": "grannstjärna",
    "grannstjärne": "grannstjärna",
    "grannstjärnor": "grannstjärna",
    "grannstjärnorna": "grannstjärna",
    "grannstjärnornas": "grannstjärna",
    "grannstjärnors": "grannstjärna",
    "grannstugan": "grannstuga",
    "grannstugans": "grannstuga",
    "grannstugas": "grannstuga",
    "grannstuge": "grannstuga",
    "grannstugor": "grannstuga",
    "grannstugorna": "grannstuga",
    "grannstugornas": "grannstuga",
    "grannstugors": "grannstuga",
    "grannstugu": "grannstuga",
    "grannsynta": "grannsynt",
    "grannsyntare": "grannsynt",
    "grannsyntares": "grannsynt",
    "grannsyntas": "grannsynt",
    "grannsyntast": "grannsynt",
    "grannsyntaste": "grannsynt",
    "grannsyntastes": "grannsynt",
    "grannsyntasts": "grannsynt",
    "grannsynte": "grannsynt",
    "grannsyntes": "grannsynt",
    "grannsynts": "grannsynt",
    "grannsämjan": "grannsämja",
    "grannsämjans": "grannsämja",
    "grannsämjas": "grannsämja",
    "granntyckta": "granntyckt",
    "granntycktare": "granntyckt",
    "granntycktares": "granntyckt",
    "granntycktas": "granntyckt",
    "granntycktast": "granntyckt",
    "granntycktaste": "granntyckt",
    "granntycktastes": "granntyckt",
    "granntycktasts": "granntyckt",
    "granntyckte": "granntyckt",
    "granntycktes": "granntyckt",
    "granntycktheten": "granntyckthet",
    "granntyckthetens": "granntyckthet",
    "granntyckthets": "granntyckthet",
    "granntyckts": "granntyckt",
    "granplant": "granplanta",
    "granplantan": "granplanta",
    "granplantans": "granplanta",
    "granplantas": "granplanta",
    "granplante": "granplanta",
    "granplantor": "granplanta",
    "granplantorna": "granplanta",
    "granplantornas": "granplanta",
    "granplantors": "granplanta",
    "granplants": "granplanta",
    "grans": "gran",
    "gransk": "granska",
    "granskad": "granska",
    "granskade": "granska",
    "granskades": "granska",
    "granskads": "granska",
    "granskande": "granska",
    "granskanden": "granskande",
    "granskandena": "granskande",
    "granskandenas": "granskande",
    "granskandens": "granskande",
    "granskandes": "granskande",
    "granskandet": "granskande",
    "granskandets": "granskande",
    "granskar": "granskare",
    "granskaren": "granskare",
    "granskarens": "granskare",
    "granskares": "granskare",
    "granskarna": "granskare",
    "granskarnas": "granskare",
    "granskas": "granska",
    "granskat": "granska",
    "granskats": "granska",
    "granskningar": "granskning",
    "granskningarna": "granskning",
    "granskningarnas": "granskning",
    "granskningars": "granskning",
    "granskningen": "granskning",
    "granskningens": "granskning",
    "gransknings": "granskning",
    "granskningsexemplaren": "granskningsexemplar",
    "granskningsexemplarens": "granskningsexemplar",
    "granskningsexemplaret": "granskningsexemplar",
    "granskningsexemplarets": "granskningsexemplar",
    "granskningsexemplars": "granskningsexemplar",
    "granskningskommissionen": "granskningskommission",
    "granskningskommissionens": "granskningskommission",
    "granskningskommissioner": "granskningskommission",
    "granskningskommissionerna": "granskningskommission",
    "granskningskommissionernas": "granskningskommission",
    "granskningskommissioners": "granskningskommission",
    "granskningskommissions": "granskningskommission",
    "granskningsmannen": "granskningsman",
    "granskningsmannens": "granskningsman",
    "granskningsmans": "granskningsman",
    "granskningsmän": "granskningsman",
    "granskningsmännen": "granskningsman",
    "granskningsmännens": "granskningsman",
    "granskningsmäns": "granskningsman",
    "granskogar": "granskog",
    "granskogarna": "granskog",
    "granskogarnas": "granskog",
    "granskogars": "granskog",
    "granskogen": "granskog",
    "granskogens": "granskog",
    "granskogs": "granskog",
    "gransorten": "gransort",
    "gransortens": "gransort",
    "gransorter": "gransort",
    "gransorterna": "gransort",
    "gransorternas": "gransort",
    "gransorters": "gransort",
    "gransorts": "gransort",
    "granspir": "granspira",
    "granspiran": "granspira",
    "granspirans": "granspira",
    "granspiras": "granspira",
    "granspire": "granspira",
    "granspiror": "granspira",
    "granspirorna": "granspira",
    "granspirornas": "granspira",
    "granspirors": "granspira",
    "granspirs": "granspira",
    "gransångar": "gransångare",
    "gransångaren": "gransångare",
    "gransångarens": "gransångare",
    "gransångares": "gransångare",
    "gransångarna": "gransångare",
    "gransångarnas": "gransångare",
    "grant": "grann",
    "grants": "grann",
    "granula": "granulum",
    "granulana": "granulum",
    "granulanas": "granulum",
    "granulas": "granulum",
    "granulaten": "granulat",
    "granulatens": "granulat",
    "granulatet": "granulat",
    "granulatets": "granulat",
    "granulationen": "granulation",
    "granulationens": "granulation",
    "granulationer": "granulation",
    "granulationerna": "granulation",
    "granulationernas": "granulation",
    "granulationers": "granulation",
    "granulations": "granulation",
    "granulationsvävnaden": "granulationsvävnad",
    "granulationsvävnadens": "granulationsvävnad",
    "granulationsvävnader": "granulationsvävnad",
    "granulationsvävnaderna": "granulationsvävnad",
    "granulationsvävnadernas": "granulationsvävnad",
    "granulationsvävnaders": "granulationsvävnad",
    "granulationsvävnads": "granulationsvävnad",
    "granulats": "granulat",
    "granulerad": "granulera",
    "granulerade": "granulera",
    "granulerades": "granulera",
    "granulerads": "granulera",
    "granulerande": "granulera",
    "granuleranden": "granulerande",
    "granulerandena": "granulerande",
    "granulerandenas": "granulerande",
    "granulerandens": "granulerande",
    "granulerandes": "granulerande",
    "granulerandet": "granulerande",
    "granulerandets": "granulerande",
    "granulerar": "granulera",
    "granuleras": "granulera",
    "granulerat": "granulera",
    "granulerats": "granulera",
    "granulerbara": "granulerbar",
    "granulerbarare": "granulerbar",
    "granulerbarares": "granulerbar",
    "granulerbaras": "granulerbar",
    "granulerbarast": "granulerbar",
    "granulerbaraste": "granulerbar",
    "granulerbarastes": "granulerbar",
    "granulerbarasts": "granulerbar",
    "granulerbare": "granulerbar",
    "granulerbares": "granulerbar",
    "granulerbarheten": "granulerbarhet",
    "granulerbarhetens": "granulerbarhet",
    "granulerbarhets": "granulerbarhet",
    "granulerbars": "granulerbar",
    "granulerbart": "granulerbar",
    "granulerbarts": "granulerbar",
    "granuleringar": "granulering",
    "granuleringarna": "granulering",
    "granuleringarnas": "granulering",
    "granuleringars": "granulering",
    "granuleringen": "granulering",
    "granuleringens": "granulering",
    "granulerings": "granulering",
    "granulomet": "granulom",
    "granulomets": "granulom",
    "granuloms": "granulom",
    "granulumet": "granulum",
    "granulumets": "granulum",
    "granulums": "granulum",
    "grapefrukten": "grapefrukt",
    "grapefruktens": "grapefrukt",
    "grapefrukter": "grapefrukt",
    "grapefrukterna": "grapefrukt",
    "grapefrukternas": "grapefrukt",
    "grapefrukters": "grapefrukt",
    "grapefrukts": "grapefrukt",
    "grasserade": "grassera",
    "grasserades": "grassera",
    "grasserande": "grassera",
    "grasseranden": "grasserande",
    "grasserandena": "grasserande",
    "grasserandenas": "grasserande",
    "grasserandens": "grasserande",
    "grasserandes": "grasserande",
    "grasserandet": "grasserande",
    "grasserandets": "grasserande",
    "grasserar": "grassera",
    "grasseras": "grassera",
    "grasserat": "grassera",
    "grasserats": "grassera",
    "grasseringar": "grassering",
    "grasseringarna": "grassering",
    "grasseringarnas": "grassering",
    "grasseringars": "grassering",
    "grasseringen": "grassering",
    "grasseringens": "grassering",
    "grasserings": "grassering",
    "gratialen": "gratial",
    "gratialens": "gratial",
    "gratialer": "gratial",
    "gratialerna": "gratial",
    "gratialernas": "gratial",
    "gratialers": "gratial",
    "gratialisten": "gratialist",
    "gratialistens": "gratialist",
    "gratialister": "gratialist",
    "gratialisterna": "gratialist",
    "gratialisternas": "gratialist",
    "gratialisters": "gratialist",
    "gratialists": "gratialist",
    "gratials": "gratial",
    "gratie": "gratier",
    "gratien": "gratie",
    "gratiens": "gratie",
    "gratier": "gratie",
    "gratierna": "gratier",
    "gratiernas": "gratier",
    "gratiers": "gratier",
    "graties": "gratie",
    "gratifikationen": "gratifikation",
    "gratifikationens": "gratifikation",
    "gratifikationer": "gratifikation",
    "gratifikationerna": "gratifikation",
    "gratifikationernas": "gratifikation",
    "gratifikationers": "gratifikation",
    "gratifikations": "gratifikation",
    "gratinen": "gratin",
    "gratinens": "gratin",
    "gratiner": "gratin",
    "gratinerad": "gratinera",
    "gratinerade": "gratinera",
    "gratinerades": "gratinera",
    "gratinerads": "gratinera",
    "gratinerande": "gratinera",
    "gratineranden": "gratinerande",
    "gratinerandena": "gratinerande",
    "gratinerandenas": "gratinerande",
    "gratinerandens": "gratinerande",
    "gratinerandes": "gratinerande",
    "gratinerandet": "gratinerande",
    "gratinerandets": "gratinerande",
    "gratinerar": "gratinera",
    "gratineras": "gratinera",
    "gratinerat": "gratinera",
    "gratinerats": "gratinera",
    "gratinerbara": "gratinerbar",
    "gratinerbarare": "gratinerbar",
    "gratinerbarares": "gratinerbar",
    "gratinerbaras": "gratinerbar",
    "gratinerbarast": "gratinerbar",
    "gratinerbaraste": "gratinerbar",
    "gratinerbarastes": "gratinerbar",
    "gratinerbarasts": "gratinerbar",
    "gratinerbare": "gratinerbar",
    "gratinerbares": "gratinerbar",
    "gratinerbarheten": "gratinerbarhet",
    "gratinerbarhetens": "gratinerbarhet",
    "gratinerbarhets": "gratinerbarhet",
    "gratinerbars": "gratinerbar",
    "gratinerbart": "gratinerbar",
    "gratinerbarts": "gratinerbar",
    "gratineringar": "gratinering",
    "gratineringarna": "gratinering",
    "gratineringarnas": "gratinering",
    "gratineringars": "gratinering",
    "gratineringen": "gratinering",
    "gratineringens": "gratinering",
    "gratinerings": "gratinering",
    "gratinerna": "gratin",
    "gratinernas": "gratin",
    "gratiners": "gratin",
    "gratins": "gratin",
    "gratisa": "gratis",
    "gratisaktien": "gratisaktie",
    "gratisaktiens": "gratisaktie",
    "gratisaktier": "gratisaktie",
    "gratisaktierna": "gratisaktie",
    "gratisaktiernas": "gratisaktie",
    "gratisaktiers": "gratisaktie",
    "gratisakties": "gratisaktie",
    "gratisare": "gratis",
    "gratisares": "gratis",
    "gratisas": "gratis",
    "gratisast": "gratis",
    "gratisaste": "gratis",
    "gratisastes": "gratis",
    "gratisasts": "gratis",
    "gratise": "gratis",
    "gratises": "gratis",
    "gratisnöjen": "gratisnöje",
    "gratisnöjena": "gratisnöje",
    "gratisnöjenas": "gratisnöje",
    "gratisnöjens": "gratisnöje",
    "gratisnöjes": "gratisnöje",
    "gratisnöjet": "gratisnöje",
    "gratisnöjets": "gratisnöje",
    "gratispassagerar": "gratispassagerare",
    "gratispassageraren": "gratispassagerare",
    "gratispassagerarens": "gratispassagerare",
    "gratispassagerares": "gratispassagerare",
    "gratispassagerarna": "gratispassagerare",
    "gratispassagerarnas": "gratispassagerare",
    "gratisskjuten": "gratisskjut",
    "gratisskjutens": "gratisskjut",
    "gratisskjutet": "gratisskjut",
    "gratisskjutets": "gratisskjut",
    "gratisskjuts": "gratisskjut",
    "gratisskjutsar": "gratisskjuts",
    "gratisskjutsarna": "gratisskjuts",
    "gratisskjutsarnas": "gratisskjuts",
    "gratisskjutsars": "gratisskjuts",
    "gratisskjutsen": "gratisskjuts",
    "gratisskjutsens": "gratisskjuts",
    "gratisspelen": "gratisspel",
    "gratisspelens": "gratisspel",
    "gratisspelet": "gratisspel",
    "gratisspelets": "gratisspel",
    "gratisspels": "gratisspel",
    "gratist": "gratis",
    "gratistidningar": "gratistidning",
    "gratistidningarna": "gratistidning",
    "gratistidningarnas": "gratistidning",
    "gratistidningars": "gratistidning",
    "gratistidningen": "gratistidning",
    "gratistidningens": "gratistidning",
    "gratistidnings": "gratistidning",
    "gratists": "gratis",
    "gratt": "gratta",
    "grattad": "gratta",
    "grattade": "gratta",
    "grattades": "gratta",
    "grattads": "gratta",
    "grattande": "gratta",
    "grattanden": "grattande",
    "grattandena": "grattande",
    "grattandenas": "grattande",
    "grattandens": "grattande",
    "grattandes": "grattande",
    "grattandet": "grattande",
    "grattandets": "grattande",
    "grattar": "gratta",
    "grattas": "gratta",
    "grattat": "gratta",
    "grattats": "gratta",
    "gratulanten": "gratulant",
    "gratulantens": "gratulant",
    "gratulanter": "gratulant",
    "gratulanterna": "gratulant",
    "gratulanternas": "gratulant",
    "gratulanters": "gratulant",
    "gratulants": "gratulant",
    "gratulationen": "gratulation",
    "gratulationens": "gratulation",
    "gratulationer": "gratulation",
    "gratulationerna": "gratulation",
    "gratulationernas": "gratulation",
    "gratulationers": "gratulation",
    "gratulations": "gratulation",
    "gratulerad": "gratulera",
    "gratulerade": "gratulera",
    "gratulerades": "gratulera",
    "gratulerads": "gratulera",
    "gratulerande": "gratulera",
    "gratuleranden": "gratulerande",
    "gratulerandena": "gratulerande",
    "gratulerandenas": "gratulerande",
    "gratulerandens": "gratulerande",
    "gratulerandes": "gratulerande",
    "gratulerandet": "gratulerande",
    "gratulerandets": "gratulerande",
    "gratulerar": "gratulera",
    "gratuleras": "gratulera",
    "gratulerat": "gratulera",
    "gratulerats": "gratulera",
    "gratulerbara": "gratulerbar",
    "gratulerbarare": "gratulerbar",
    "gratulerbarares": "gratulerbar",
    "gratulerbaras": "gratulerbar",
    "gratulerbarast": "gratulerbar",
    "gratulerbaraste": "gratulerbar",
    "gratulerbarastes": "gratulerbar",
    "gratulerbarasts": "gratulerbar",
    "gratulerbare": "gratulerbar",
    "gratulerbares": "gratulerbar",
    "gratulerbarheten": "gratulerbarhet",
    "gratulerbarhetens": "gratulerbarhet",
    "gratulerbarhets": "gratulerbarhet",
    "gratulerbars": "gratulerbar",
    "gratulerbart": "gratulerbar",
    "gratulerbarts": "gratulerbar",
    "gratuleringar": "gratulering",
    "gratuleringarna": "gratulering",
    "gratuleringarnas": "gratulering",
    "gratuleringars": "gratulering",
    "gratuleringen": "gratulering",
    "gratuleringens": "gratulering",
    "gratulerings": "gratulering",
    "gratängen": "gratäng",
    "gratängens": "gratäng",
    "gratänger": "gratäng",
    "gratängerna": "gratäng",
    "gratängernas": "gratäng",
    "gratängers": "gratäng",
    "gratängs": "gratäng",
    "grav": "grava",
    "grava": "grav",
    "gravad": "grava",
    "gravade": "grava",
    "gravades": "grava",
    "gravads": "grava",
    "gravallvaret": "gravallvar",
    "gravallvarets": "gravallvar",
    "gravallvarliga": "gravallvarlig",
    "gravallvarligare": "gravallvarlig",
    "gravallvarligares": "gravallvarlig",
    "gravallvarligas": "gravallvarlig",
    "gravallvarligast": "gravallvarlig",
    "gravallvarligaste": "gravallvarlig",
    "gravallvarligastes": "gravallvarlig",
    "gravallvarligasts": "gravallvarlig",
    "gravallvarlige": "gravallvarlig",
    "gravallvarliges": "gravallvarlig",
    "gravallvarligheten": "gravallvarlighet",
    "gravallvarlighetens": "gravallvarlighet",
    "gravallvarlighets": "gravallvarlighet",
    "gravallvarligs": "gravallvarlig",
    "gravallvarligt": "gravallvarlig",
    "gravallvarligts": "gravallvarlig",
    "gravallvars": "gravallvar",
    "gravamenet": "gravamen",
    "gravamenets": "gravamen",
    "gravamens": "gravamen",
    "gravamina": "gravamen",
    "gravaminas": "gravamen",
    "gravande": "grava",
    "gravanden": "gravande",
    "gravandena": "gravande",
    "gravandenas": "gravande",
    "gravandens": "gravande",
    "gravandes": "gravande",
    "gravandet": "gravande",
    "gravandets": "gravande",
    "gravands": "gravand",
    "gravar": "grava",
    "gravare": "grav",
    "gravares": "grav",
    "gravarna": "grav",
    "gravarnas": "grav",
    "gravars": "grav",
    "gravas": "grava",
    "gravast": "grav",
    "gravaste": "grav",
    "gravastes": "grav",
    "gravasts": "grav",
    "gravat": "grava",
    "gravationen": "gravation",
    "gravationens": "gravation",
    "gravationer": "gravation",
    "gravationerna": "gravation",
    "gravationernas": "gravation",
    "gravationers": "gravation",
    "gravations": "gravation",
    "gravats": "grava",
    "gravbreven": "gravbrev",
    "gravbrevens": "gravbrev",
    "gravbrevet": "gravbrev",
    "gravbrevets": "gravbrev",
    "gravbrevs": "gravbrev",
    "gravbyggnaden": "gravbyggnad",
    "gravbyggnadens": "gravbyggnad",
    "gravbyggnader": "gravbyggnad",
    "gravbyggnaderna": "gravbyggnad",
    "gravbyggnadernas": "gravbyggnad",
    "gravbyggnaders": "gravbyggnad",
    "gravbyggnads": "gravbyggnad",
    "gravdikten": "gravdikt",
    "gravdiktens": "gravdikt",
    "gravdikter": "gravdikt",
    "gravdikterna": "gravdikt",
    "gravdikternas": "gravdikt",
    "gravdikters": "gravdikt",
    "gravdikts": "gravdikt",
    "grave": "grav",
    "graven": "grav",
    "gravens": "grav",
    "gravensteinen": "gravenstein",
    "gravensteinens": "gravenstein",
    "gravensteiner": "gravenstein",
    "gravensteinern": "gravensteiner",
    "gravensteinerna": "gravensteiner",
    "gravensteinernas": "gravensteiner",
    "gravensteinerns": "gravensteiner",
    "gravensteiners": "gravensteiner",
    "gravensteins": "gravenstein",
    "graverad": "gravera",
    "graverade": "gravera",
    "graverades": "gravera",
    "graverads": "gravera",
    "graverande": "gravera",
    "graveranden": "graverande",
    "graverandena": "graverande",
    "graverandenas": "graverande",
    "graverandens": "graverande",
    "graverandes": "graverande",
    "graverandet": "graverande",
    "graverandets": "graverande",
    "graverar": "gravera",
    "graveras": "gravera",
    "graverat": "gravera",
    "graverats": "gravera",
    "graverbara": "graverbar",
    "graverbarare": "graverbar",
    "graverbarares": "graverbar",
    "graverbaras": "graverbar",
    "graverbarast": "graverbar",
    "graverbaraste": "graverbar",
    "graverbarastes": "graverbar",
    "graverbarasts": "graverbar",
    "graverbare": "graverbar",
    "graverbares": "graverbar",
    "graverbarheten": "graverbarhet",
    "graverbarhetens": "graverbarhet",
    "graverbarhets": "graverbarhet",
    "graverbars": "graverbar",
    "graverbart": "graverbar",
    "graverbarts": "graverbar",
    "graveringar": "gravering",
    "graveringarna": "gravering",
    "graveringarnas": "gravering",
    "graveringars": "gravering",
    "graveringen": "gravering",
    "graveringens": "gravering",
    "graverings": "gravering",
    "graves": "grav",
    "gravfynden": "gravfynd",
    "gravfyndens": "gravfynd",
    "gravfyndet": "gravfynd",
    "gravfyndets": "gravfynd",
    "gravfynds": "gravfynd",
    "gravfälten": "gravfält",
    "gravfältens": "gravfält",
    "gravfältet": "gravfält",
    "gravfältets": "gravfält",
    "gravfälts": "gravfält",
    "gravgodset": "gravgods",
    "gravgodsets": "gravgods",
    "gravgäss": "gravgås",
    "gravgässen": "gravgås",
    "gravgässens": "gravgås",
    "gravgåsen": "gravgås",
    "gravgåsens": "gravgås",
    "gravgåvan": "gravgåva",
    "gravgåvans": "gravgåva",
    "gravgåvas": "gravgåva",
    "gravgåve": "gravgåva",
    "gravgåvo": "gravgåva",
    "gravgåvor": "gravgåva",
    "gravgåvorna": "gravgåva",
    "gravgåvornas": "gravgåva",
    "gravgåvors": "gravgåva",
    "gravheten": "gravhet",
    "gravhetens": "gravhet",
    "gravhets": "gravhet",
    "gravhällar": "gravhäll",
    "gravhällarna": "gravhäll",
    "gravhällarnas": "gravhäll",
    "gravhällars": "gravhäll",
    "gravhällen": "gravhäll",
    "gravhällens": "gravhäll",
    "gravhälls": "gravhäll",
    "gravhögar": "gravhög",
    "gravhögarna": "gravhög",
    "gravhögarnas": "gravhög",
    "gravhögars": "gravhög",
    "gravhögen": "gravhög",
    "gravhögens": "gravhög",
    "gravhögs": "gravhög",
    "gravida": "gravid",
    "gravidare": "gravid",
    "gravidares": "gravid",
    "gravidas": "gravid",
    "gravidast": "gravid",
    "gravidaste": "gravid",
    "gravidastes": "gravid",
    "gravidasts": "gravid",
    "gravide": "gravid",
    "gravides": "gravid",
    "graviditeten": "graviditet",
    "graviditetens": "graviditet",
    "graviditeter": "graviditet",
    "graviditeterna": "graviditet",
    "graviditeternas": "graviditet",
    "graviditeters": "graviditet",
    "graviditets": "graviditet",
    "graviditetsdagboken": "graviditetsdagbok",
    "graviditetsdagbokens": "graviditetsdagbok",
    "graviditetsdagboks": "graviditetsdagbok",
    "graviditetsdagböcker": "graviditetsdagbok",
    "graviditetsdagböckerna": "graviditetsdagbok",
    "graviditetsdagböckernas": "graviditetsdagbok",
    "graviditetsdagböckers": "graviditetsdagbok",
    "graviditetskilon": "graviditetskilo",
    "graviditetskilona": "graviditetskilo",
    "graviditetskilonas": "graviditetskilo",
    "graviditetskilons": "graviditetskilo",
    "graviditetskilos": "graviditetskilo",
    "graviditetskilot": "graviditetskilo",
    "graviditetskilots": "graviditetskilo",
    "graviditetstesten": "graviditetstest",
    "graviditetstestens": "graviditetstest",
    "graviditetstester": "graviditetstest",
    "graviditetstesterna": "graviditetstest",
    "graviditetstesternas": "graviditetstest",
    "graviditetstesters": "graviditetstest",
    "graviditetstestet": "graviditetstest",
    "graviditetstestets": "graviditetstest",
    "graviditetstests": "graviditetstest",
    "graviditetsveck": "graviditetsvecka",
    "graviditetsveckan": "graviditetsvecka",
    "graviditetsveckans": "graviditetsvecka",
    "graviditetsveckas": "graviditetsvecka",
    "graviditetsvecke": "graviditetsvecka",
    "graviditetsvecko": "graviditetsvecka",
    "graviditetsveckor": "graviditetsvecka",
    "graviditetsveckorna": "graviditetsvecka",
    "graviditetsveckornas": "graviditetsvecka",
    "graviditetsveckors": "graviditetsvecka",
    "graviditetsvecks": "graviditetsvecka",
    "gravids": "gravid",
    "gravimetern": "gravimeter",
    "gravimeterns": "gravimeter",
    "gravimeters": "gravimeter",
    "gravimetrar": "gravimeter",
    "gravimetrarna": "gravimeter",
    "gravimetrarnas": "gravimeter",
    "gravimetrars": "gravimeter",
    "gravitationen": "gravitation",
    "gravitationens": "gravitation",
    "gravitationer": "gravitation",
    "gravitationerna": "gravitation",
    "gravitationernas": "gravitation",
    "gravitationers": "gravitation",
    "gravitations": "gravitation",
    "gravitationskollapsen": "gravitationskollaps",
    "gravitationskollapsens": "gravitationskollaps",
    "gravitationskollapser": "gravitationskollaps",
    "gravitationskollapserna": "gravitationskollaps",
    "gravitationskollapsernas": "gravitationskollaps",
    "gravitationskollapsers": "gravitationskollaps",
    "gravitationskonstanten": "gravitationskonstant",
    "gravitationskonstantens": "gravitationskonstant",
    "gravitationskonstanter": "gravitationskonstant",
    "gravitationskonstanterna": "gravitationskonstant",
    "gravitationskonstanternas": "gravitationskonstant",
    "gravitationskonstanters": "gravitationskonstant",
    "gravitationskonstants": "gravitationskonstant",
    "gravitationskraften": "gravitationskraft",
    "gravitationskraftens": "gravitationskraft",
    "gravitationskrafter": "gravitationskraft",
    "gravitationskrafterna": "gravitationskraft",
    "gravitationskrafternas": "gravitationskraft",
    "gravitationskrafters": "gravitationskraft",
    "gravitationskrafts": "gravitationskraft",
    "gravitationslagar": "gravitationslag",
    "gravitationslagarna": "gravitationslag",
    "gravitationslagarnas": "gravitationslag",
    "gravitationslagars": "gravitationslag",
    "gravitationslagen": "gravitationslag",
    "gravitationslagens": "gravitationslag",
    "gravitationslags": "gravitationslag",
    "gravitationsstrålningar": "gravitationsstrålning",
    "gravitationsstrålningarna": "gravitationsstrålning",
    "gravitationsstrålningarnas": "gravitationsstrålning",
    "gravitationsstrålningars": "gravitationsstrålning",
    "gravitationsstrålningen": "gravitationsstrålning",
    "gravitationsstrålningens": "gravitationsstrålning",
    "gravitationsstrålnings": "gravitationsstrålning",
    "gravitationsvågen": "gravitationsvåg",
    "gravitationsvågens": "gravitationsvåg",
    "gravitationsvågor": "gravitationsvåg",
    "gravitationsvågorna": "gravitationsvåg",
    "gravitationsvågornas": "gravitationsvåg",
    "gravitationsvågors": "gravitationsvåg",
    "gravitationsvågs": "gravitationsvåg",
    "graviterade": "gravitera",
    "graviterades": "gravitera",
    "graviterande": "gravitera",
    "graviteranden": "graviterande",
    "graviterandena": "graviterande",
    "graviterandenas": "graviterande",
    "graviterandens": "graviterande",
    "graviterandes": "graviterande",
    "graviterandet": "graviterande",
    "graviterandets": "graviterande",
    "graviterar": "gravitera",
    "graviteras": "gravitera",
    "graviterat": "gravitera",
    "graviterats": "gravitera",
    "graviteringar": "gravitering",
    "graviteringarna": "gravitering",
    "graviteringarnas": "gravitering",
    "graviteringars": "gravitering",
    "graviteringen": "gravitering",
    "graviteringens": "gravitering",
    "graviterings": "gravitering",
    "graviteten": "gravitet",
    "gravitetens": "gravitet",
    "graviteter": "gravitet",
    "graviteterna": "gravitet",
    "graviteternas": "gravitet",
    "graviteters": "gravitet",
    "gravitetiska": "gravitetisk",
    "gravitetiskare": "gravitetisk",
    "gravitetiskares": "gravitetisk",
    "gravitetiskas": "gravitetisk",
    "gravitetiskast": "gravitetisk",
    "gravitetiskaste": "gravitetisk",
    "gravitetiskastes": "gravitetisk",
    "gravitetiskasts": "gravitetisk",
    "gravitetiske": "gravitetisk",
    "gravitetiskes": "gravitetisk",
    "gravitetisks": "gravitetisk",
    "gravitetiskt": "gravitetisk",
    "gravitetiskts": "gravitetisk",
    "gravitets": "gravitet",
    "gravitonen": "graviton",
    "gravitonens": "graviton",
    "gravitoner": "graviton",
    "gravitonerna": "graviton",
    "gravitonernas": "graviton",
    "gravitoners": "graviton",
    "gravitons": "graviton",
    "gravkammar": "gravkammare",
    "gravkammaren": "gravkammare",
    "gravkammarens": "gravkammare",
    "gravkammares": "gravkammare",
    "gravkamrar": "gravkammare",
    "gravkamrarna": "gravkammare",
    "gravkamrarnas": "gravkammare",
    "gravkamrars": "gravkammare",
    "gravkapellen": "gravkapell",
    "gravkapellens": "gravkapell",
    "gravkapellet": "gravkapell",
    "gravkapellets": "gravkapell",
    "gravkapells": "gravkapell",
    "gravkist": "gravkista",
    "gravkistan": "gravkista",
    "gravkistans": "gravkista",
    "gravkistas": "gravkista",
    "gravkiste": "gravkista",
    "gravkistor": "gravkista",
    "gravkistorna": "gravkista",
    "gravkistornas": "gravkista",
    "gravkistors": "gravkista",
    "gravkoren": "gravkor",
    "gravkorens": "gravkor",
    "gravkoret": "gravkor",
    "gravkorets": "gravkor",
    "gravkors": "gravkor",
    "gravkumlen": "gravkummel",
    "gravkumlens": "gravkummel",
    "gravkumlet": "gravkummel",
    "gravkumlets": "gravkummel",
    "gravkummels": "gravkummel",
    "gravkyrk": "gravkyrka",
    "gravkyrkan": "gravkyrka",
    "gravkyrkans": "gravkyrka",
    "gravkyrkas": "gravkyrka",
    "gravkyrke": "gravkyrka",
    "gravkyrko": "gravkyrka",
    "gravkyrkor": "gravkyrka",
    "gravkyrkorna": "gravkyrka",
    "gravkyrkornas": "gravkyrka",
    "gravkyrkors": "gravkyrka",
    "gravkyrks": "gravkyrka",
    "gravla": "gravlägga",
    "gravlade": "gravlägga",
    "gravlades": "gravlägga",
    "gravlagd": "gravlägga",
    "gravlagda": "gravlägga",
    "gravlagdas": "gravlägga",
    "gravlagde": "gravlägga",
    "gravlagdes": "gravlägga",
    "gravlagds": "gravlägga",
    "gravlagt": "gravlägga",
    "gravlagts": "gravlägga",
    "gravlas": "gravlägga",
    "gravlaxar": "gravlax",
    "gravlaxarna": "gravlax",
    "gravlaxarnas": "gravlax",
    "gravlaxars": "gravlax",
    "gravlaxen": "gravlax",
    "gravlaxens": "gravlax",
    "gravlika": "gravlik",
    "gravlikare": "gravlik",
    "gravlikares": "gravlik",
    "gravlikas": "gravlik",
    "gravlikast": "gravlik",
    "gravlikaste": "gravlik",
    "gravlikastes": "gravlik",
    "gravlikasts": "gravlik",
    "gravlike": "gravlik",
    "gravlikes": "gravlik",
    "gravlikheten": "gravlikhet",
    "gravlikhetens": "gravlikhet",
    "gravlikhets": "gravlikhet",
    "gravliks": "gravlik",
    "gravlikt": "gravlik",
    "gravlikts": "gravlik",
    "gravlägg": "gravlägga",
    "gravläggande": "gravlägga",
    "gravlägganden": "gravläggande",
    "gravläggandena": "gravläggande",
    "gravläggandenas": "gravläggande",
    "gravläggandens": "gravläggande",
    "gravläggandes": "gravläggande",
    "gravläggandet": "gravläggande",
    "gravläggandets": "gravläggande",
    "gravläggas": "gravlägga",
    "gravlägger": "gravlägga",
    "gravlägges": "gravlägga",
    "gravläggs": "gravlägga",
    "gravmaterialen": "gravmaterial",
    "gravmaterialens": "gravmaterial",
    "gravmaterialet": "gravmaterial",
    "gravmaterialets": "gravmaterial",
    "gravmaterials": "gravmaterial",
    "gravmonumenten": "gravmonument",
    "gravmonumentens": "gravmonument",
    "gravmonumentet": "gravmonument",
    "gravmonumentets": "gravmonument",
    "gravmonuments": "gravmonument",
    "gravors": "gravor",
    "gravplatsen": "gravplats",
    "gravplatsens": "gravplats",
    "gravplatser": "gravplats",
    "gravplatserna": "gravplats",
    "gravplatsernas": "gravplats",
    "gravplatsers": "gravplats",
    "gravreliefen": "gravrelief",
    "gravreliefens": "gravrelief",
    "gravreliefer": "gravrelief",
    "gravrelieferna": "gravrelief",
    "gravreliefernas": "gravrelief",
    "gravreliefers": "gravrelief",
    "gravreliefs": "gravrelief",
    "gravrosten": "gravrost",
    "gravrostens": "gravrost",
    "gravrosts": "gravrost",
    "gravrös": "gravröse",
    "gravrösen": "gravröse",
    "gravrösena": "gravröse",
    "gravrösenas": "gravröse",
    "gravrösens": "gravröse",
    "gravröses": "gravröse",
    "gravröset": "gravröse",
    "gravrösets": "gravröse",
    "gravs": "grav",
    "gravsatt": "gravsätta",
    "gravsatta": "gravsätta",
    "gravsattas": "gravsätta",
    "gravsatte": "gravsätta",
    "gravsattes": "gravsätta",
    "gravsatts": "gravsätta",
    "gravseden": "gravsed",
    "gravsedens": "gravsed",
    "gravseder": "gravsed",
    "gravsederna": "gravsed",
    "gravsedernas": "gravsed",
    "gravseders": "gravsed",
    "gravseds": "gravsed",
    "gravskicken": "gravskick",
    "gravskickens": "gravskick",
    "gravskicket": "gravskick",
    "gravskickets": "gravskick",
    "gravskicks": "gravskick",
    "gravskändningar": "gravskändning",
    "gravskändningarna": "gravskändning",
    "gravskändningarnas": "gravskändning",
    "gravskändningars": "gravskändning",
    "gravskändningen": "gravskändning",
    "gravskändningens": "gravskändning",
    "gravskändnings": "gravskändning",
    "gravstenar": "gravsten",
    "gravstenarna": "gravsten",
    "gravstenarnas": "gravsten",
    "gravstenars": "gravsten",
    "gravstenen": "gravsten",
    "gravstenens": "gravsten",
    "gravstens": "gravsten",
    "gravstickeln": "gravstickel",
    "gravstickelns": "gravstickel",
    "gravstickels": "gravstickel",
    "gravsticklar": "gravstickel",
    "gravsticklarna": "gravstickel",
    "gravsticklarnas": "gravstickel",
    "gravsticklars": "gravstickel",
    "gravsvepningar": "gravsvepning",
    "gravsvepningarna": "gravsvepning",
    "gravsvepningarnas": "gravsvepning",
    "gravsvepningars": "gravsvepning",
    "gravsvepningen": "gravsvepning",
    "gravsvepningens": "gravsvepning",
    "gravsvepnings": "gravsvepning",
    "gravsänk": "gravsänka",
    "gravsänkan": "gravsänka",
    "gravsänkans": "gravsänka",
    "gravsänkas": "gravsänka",
    "gravsänke": "gravsänka",
    "gravsänkor": "gravsänka",
    "gravsänkorna": "gravsänka",
    "gravsänkornas": "gravsänka",
    "gravsänkors": "gravsänka",
    "gravsänks": "gravsänka",
    "gravsätt": "gravsätta",
    "gravsättande": "gravsätta",
    "gravsättanden": "gravsättande",
    "gravsättandena": "gravsättande",
    "gravsättandenas": "gravsättande",
    "gravsättandens": "gravsättande",
    "gravsättandes": "gravsättande",
    "gravsättandet": "gravsättande",
    "gravsättandets": "gravsättande",
    "gravsättas": "gravsätta",
    "gravsätter": "gravsätta",
    "gravsättes": "gravsätta",
    "gravsättningar": "gravsättning",
    "gravsättningarna": "gravsättning",
    "gravsättningarnas": "gravsättning",
    "gravsättningars": "gravsättning",
    "gravsättningen": "gravsättning",
    "gravsättningens": "gravsättning",
    "gravsättnings": "gravsättning",
    "gravsätts": "gravsätta",
    "gravt": "grav",
    "gravtalen": "gravtal",
    "gravtalens": "gravtal",
    "gravtalet": "gravtal",
    "gravtalets": "gravtal",
    "gravtals": "gravtal",
    "gravts": "grav",
    "gravurn": "gravurna",
    "gravurnan": "gravurna",
    "gravurnans": "gravurna",
    "gravurnas": "gravurna",
    "gravurne": "gravurna",
    "gravurnor": "gravurna",
    "gravurnorna": "gravurna",
    "gravurnornas": "gravurna",
    "gravurnors": "gravurna",
    "gravurns": "gravurna",
    "gravvalven": "gravvalv",
    "gravvalvens": "gravvalv",
    "gravvalvet": "gravvalv",
    "gravvalvets": "gravvalv",
    "gravvalvs": "gravvalv",
    "gravvårdar": "gravvård",
    "gravvårdarna": "gravvård",
    "gravvårdarnas": "gravvård",
    "gravvårdars": "gravvård",
    "gravvården": "gravvård",
    "gravvårdens": "gravvård",
    "gravvårds": "gravvård",
    "gravyren": "gravyr",
    "gravyrens": "gravyr",
    "gravyrer": "gravyr",
    "gravyrerna": "gravyr",
    "gravyrernas": "gravyr",
    "gravyrers": "gravyr",
    "gravyrmaskinen": "gravyrmaskin",
    "gravyrmaskinens": "gravyrmaskin",
    "gravyrmaskiner": "gravyrmaskin",
    "gravyrmaskinerna": "gravyrmaskin",
    "gravyrmaskinernas": "gravyrmaskin",
    "gravyrmaskiners": "gravyrmaskin",
    "gravyrmaskins": "gravyrmaskin",
    "gravyrs": "gravyr",
    "gravänder": "gravand",
    "gravänderna": "gravand",
    "gravändernas": "gravand",
    "gravänders": "gravand",
    "gravölen": "gravöl",
    "gravölens": "gravöl",
    "gravölet": "gravöl",
    "gravölets": "gravöl",
    "gravöls": "gravöl",
    "gravöppningar": "gravöppning",
    "gravöppningarna": "gravöppning",
    "gravöppningarnas": "gravöppning",
    "gravöppningars": "gravöppning",
    "gravöppningen": "gravöppning",
    "gravöppningens": "gravöppning",
    "gravöppnings": "gravöppning",
    "gravören": "gravör",
    "gravörens": "gravör",
    "gravörer": "gravör",
    "gravörerna": "gravör",
    "gravörernas": "gravör",
    "gravörers": "gravör",
    "gravörs": "gravör",
    "grayen": "gray",
    "grayens": "gray",
    "grays": "gray",
    "grecismen": "grecism",
    "grecismens": "grecism",
    "grecismer": "grecism",
    "grecismerna": "grecism",
    "grecismernas": "grecism",
    "grecismers": "grecism",
    "grecisms": "grecism",
    "gredelina": "gredelin",
    "gredelinare": "gredelin",
    "gredelinares": "gredelin",
    "gredelinas": "gredelin",
    "gredelinast": "gredelin",
    "gredelinaste": "gredelin",
    "gredelinastes": "gredelin",
    "gredelinasts": "gredelin",
    "gredeline": "gredelin",
    "gredelines": "gredelin",
    "gredelins": "gredelin",
    "gredelint": "gredelin",
    "gredelints": "gredelin",
    "greenen": "green",
    "greenens": "green",
    "greener": "green",
    "greenerna": "green",
    "greenernas": "green",
    "greeners": "green",
    "greens": "green",
    "gregorianska": "gregoriansk",
    "gregorianskare": "gregoriansk",
    "gregorianskares": "gregoriansk",
    "gregorianskas": "gregoriansk",
    "gregorianskast": "gregoriansk",
    "gregorianskaste": "gregoriansk",
    "gregorianskastes": "gregoriansk",
    "gregorianskasts": "gregoriansk",
    "gregorianske": "gregoriansk",
    "gregorianskes": "gregoriansk",
    "gregoriansks": "gregoriansk",
    "gregorianskt": "gregoriansk",
    "gregorianskts": "gregoriansk",
    "grej": "greja",
    "grejad": "greja",
    "grejade": "greja",
    "grejades": "greja",
    "grejads": "greja",
    "grejan": "greja",
    "grejande": "greja",
    "grejanden": "grejande",
    "grejandena": "grejande",
    "grejandenas": "grejande",
    "grejandens": "grejande",
    "grejandes": "grejande",
    "grejandet": "grejande",
    "grejandets": "grejande",
    "grejans": "greja",
    "grejar": "greja",
    "grejas": "greja",
    "grejat": "greja",
    "grejats": "greja",
    "greje": "greja",
    "grejen": "grej",
    "grejens": "grej",
    "grejer": "grej",
    "grejerna": "grej",
    "grejernas": "grej",
    "grejers": "grej",
    "grejor": "greja",
    "grejorna": "greja",
    "grejornas": "greja",
    "grejors": "greja",
    "grejs": "greja",
    "grejset": "grejs",
    "grejsets": "grejs",
    "grekcyprioten": "grekcypriot",
    "grekcypriotens": "grekcypriot",
    "grekcyprioter": "grekcypriot",
    "grekcyprioterna": "grekcypriot",
    "grekcyprioternas": "grekcypriot",
    "grekcyprioters": "grekcypriot",
    "grekcypriots": "grekcypriot",
    "greken": "grek",
    "grekens": "grek",
    "greker": "grek",
    "grekerna": "grek",
    "grekernas": "grek",
    "grekers": "grek",
    "grekinnan": "grekinna",
    "grekinnans": "grekinna",
    "grekinnas": "grekinna",
    "grekinne": "grekinna",
    "grekinnor": "grekinna",
    "grekinnorna": "grekinna",
    "grekinnornas": "grekinna",
    "grekinnors": "grekinna",
    "grekisk": "grekiska",
    "grekisk-katolska": "grekisk-katolsk",
    "grekisk-katolskare": "grekisk-katolsk",
    "grekisk-katolskares": "grekisk-katolsk",
    "grekisk-katolskas": "grekisk-katolsk",
    "grekisk-katolskast": "grekisk-katolsk",
    "grekisk-katolskaste": "grekisk-katolsk",
    "grekisk-katolskastes": "grekisk-katolsk",
    "grekisk-katolskasts": "grekisk-katolsk",
    "grekisk-katolske": "grekisk-katolsk",
    "grekisk-katolskes": "grekisk-katolsk",
    "grekisk-katolsks": "grekisk-katolsk",
    "grekisk-katolskt": "grekisk-katolsk",
    "grekisk-katolskts": "grekisk-katolsk",
    "grekisk-ortodoxa": "grekisk-ortodox",
    "grekisk-ortodoxare": "grekisk-ortodox",
    "grekisk-ortodoxares": "grekisk-ortodox",
    "grekisk-ortodoxas": "grekisk-ortodox",
    "grekisk-ortodoxast": "grekisk-ortodox",
    "grekisk-ortodoxaste": "grekisk-ortodox",
    "grekisk-ortodoxastes": "grekisk-ortodox",
    "grekisk-ortodoxasts": "grekisk-ortodox",
    "grekisk-ortodoxe": "grekisk-ortodox",
    "grekisk-ortodoxes": "grekisk-ortodox",
    "grekisk-ortodoxt": "grekisk-ortodox",
    "grekisk-ortodoxts": "grekisk-ortodox",
    "grekisk-romerska": "grekisk-romersk",
    "grekisk-romerskare": "grekisk-romersk",
    "grekisk-romerskares": "grekisk-romersk",
    "grekisk-romerskas": "grekisk-romersk",
    "grekisk-romerskast": "grekisk-romersk",
    "grekisk-romerskaste": "grekisk-romersk",
    "grekisk-romerskastes": "grekisk-romersk",
    "grekisk-romerskasts": "grekisk-romersk",
    "grekisk-romerske": "grekisk-romersk",
    "grekisk-romerskes": "grekisk-romersk",
    "grekisk-romersks": "grekisk-romersk",
    "grekisk-romerskt": "grekisk-romersk",
    "grekisk-romerskts": "grekisk-romersk",
    "grekiska": "grekisk",
    "grekiskan": "grekiska",
    "grekiskans": "grekiska",
    "grekiskare": "grekisk",
    "grekiskares": "grekisk",
    "grekiskas": "grekiska",
    "grekiskast": "grekisk",
    "grekiskaste": "grekisk",
    "grekiskastes": "grekisk",
    "grekiskasts": "grekisk",
    "grekiske": "grekiska",
    "grekiskes": "grekisk",
    "grekiskor": "grekiska",
    "grekiskorna": "grekiska",
    "grekiskornas": "grekiska",
    "grekiskors": "grekiska",
    "grekisks": "grekisk",
    "grekiskt": "grekisk",
    "grekiskts": "grekisk",
    "greks": "grek",
    "grenade": "grenad",
    "grenades": "grenad",
    "grenadiern": "grenadier",
    "grenadierna": "grenadier",
    "grenadiernas": "grenadier",
    "grenadierns": "grenadier",
    "grenadiers": "grenadier",
    "grenadinen": "grenadin",
    "grenadinens": "grenadin",
    "grenadiner": "grenadin",
    "grenadinerna": "grenadin",
    "grenadinernas": "grenadin",
    "grenadiners": "grenadin",
    "grenadinet": "grenadin",
    "grenadinets": "grenadin",
    "grenadins": "grenadin",
    "grenadiska": "grenadisk",
    "grenadiskan": "grenadiska",
    "grenadiskans": "grenadiska",
    "grenadiskare": "grenadisk",
    "grenadiskares": "grenadisk",
    "grenadiskas": "grenadiska",
    "grenadiskast": "grenadisk",
    "grenadiskaste": "grenadisk",
    "grenadiskastes": "grenadisk",
    "grenadiskasts": "grenadisk",
    "grenadiske": "grenadiska",
    "grenadiskes": "grenadisk",
    "grenadiskor": "grenadiska",
    "grenadiskorna": "grenadiska",
    "grenadiskornas": "grenadiska",
    "grenadiskors": "grenadiska",
    "grenadisks": "grenadisk",
    "grenadiskt": "grenadisk",
    "grenadiskts": "grenadisk",
    "grenadjären": "grenadjär",
    "grenadjärens": "grenadjär",
    "grenadjärer": "grenadjär",
    "grenadjärerna": "grenadjär",
    "grenadjärernas": "grenadjär",
    "grenadjärers": "grenadjär",
    "grenadjärs": "grenadjär",
    "grenads": "grenad",
    "grenar": "gren",
    "grenarna": "gren",
    "grenarnas": "gren",
    "grenars": "gren",
    "grenat": "grenad",
    "grenats": "grenad",
    "grenen": "gren",
    "grenens": "gren",
    "grenhoppen": "grenhopp",
    "grenhoppens": "grenhopp",
    "grenhoppet": "grenhopp",
    "grenhoppets": "grenhopp",
    "grenhopps": "grenhopp",
    "greniga": "grenig",
    "grenigare": "grenig",
    "grenigares": "grenig",
    "grenigas": "grenig",
    "grenigast": "grenig",
    "grenigaste": "grenig",
    "grenigastes": "grenig",
    "grenigasts": "grenig",
    "grenige": "grenig",
    "greniges": "grenig",
    "grenigs": "grenig",
    "grenigt": "grenig",
    "grenigts": "grenig",
    "grenklyk": "grenklyka",
    "grenklykan": "grenklyka",
    "grenklykans": "grenklyka",
    "grenklykas": "grenklyka",
    "grenklyke": "grenklyka",
    "grenklykor": "grenklyka",
    "grenklykorna": "grenklyka",
    "grenklykornas": "grenklyka",
    "grenklykors": "grenklyka",
    "grenklyks": "grenklyka",
    "grenledningar": "grenledning",
    "grenledningarna": "grenledning",
    "grenledningarnas": "grenledning",
    "grenledningars": "grenledning",
    "grenledningen": "grenledning",
    "grenledningens": "grenledning",
    "grenlednings": "grenledning",
    "grenljusen": "grenljus",
    "grenljusens": "grenljus",
    "grenljuset": "grenljus",
    "grenljusets": "grenljus",
    "grensel": "grensla",
    "grenslad": "grensla",
    "grenslade": "grensla",
    "grenslades": "grensla",
    "grenslads": "grensla",
    "grenslande": "grensla",
    "grenslanden": "grenslande",
    "grenslandena": "grenslande",
    "grenslandenas": "grenslande",
    "grenslandens": "grenslande",
    "grenslandes": "grenslande",
    "grenslandet": "grenslande",
    "grenslandets": "grenslande",
    "grenslar": "grensla",
    "grenslas": "grensla",
    "grenslat": "grensla",
    "grenslats": "grensla",
    "grenspetsar": "grenspets",
    "grenspetsarna": "grenspets",
    "grenspetsarnas": "grenspets",
    "grenspetsars": "grenspets",
    "grenspetsen": "grenspets",
    "grenspetsens": "grenspets",
    "grenuttagen": "grenuttag",
    "grenuttagens": "grenuttag",
    "grenuttaget": "grenuttag",
    "grenuttagets": "grenuttag",
    "grenuttags": "grenuttag",
    "grenvecken": "grenveck",
    "grenveckens": "grenveck",
    "grenvecket": "grenveck",
    "grenveckets": "grenveck",
    "grenvecks": "grenveck",
    "grenverket": "grenverk",
    "grenverkets": "grenverk",
    "grenverks": "grenverk",
    "grenvinkeln": "grenvinkel",
    "grenvinkelns": "grenvinkel",
    "grenvinkels": "grenvinkel",
    "grenvinklar": "grenvinkel",
    "grenvinklarna": "grenvinkel",
    "grenvinklarnas": "grenvinkel",
    "grenvinklars": "grenvinkel",
    "grep": "gripa",
    "grepar": "grepe",
    "greparna": "grepe",
    "greparnas": "grepe",
    "grepars": "grepe",
    "grepen": "grepe",
    "grepens": "grepe",
    "grepes": "grepe",
    "grepp": "greppa",
    "greppad": "greppa",
    "greppade": "greppa",
    "greppades": "greppa",
    "greppads": "greppa",
    "greppande": "greppa",
    "greppanden": "greppande",
    "greppandena": "greppande",
    "greppandenas": "greppande",
    "greppandens": "greppande",
    "greppandes": "greppande",
    "greppandet": "greppande",
    "greppandets": "greppande",
    "greppar": "greppa",
    "greppas": "greppa",
    "greppat": "greppa",
    "greppats": "greppa",
    "greppbräden": "greppbräde",
    "greppbrädena": "greppbräde",
    "greppbrädenas": "greppbräde",
    "greppbrädens": "greppbräde",
    "greppbrädes": "greppbräde",
    "greppbrädet": "greppbräde",
    "greppbrädets": "greppbräde",
    "greppen": "grepp",
    "greppens": "grepp",
    "greppet": "grepp",
    "greppets": "grepp",
    "greppmatt": "greppmatta",
    "greppmattan": "greppmatta",
    "greppmattans": "greppmatta",
    "greppmattas": "greppmatta",
    "greppmatte": "greppmatta",
    "greppmattor": "greppmatta",
    "greppmattorna": "greppmatta",
    "greppmattornas": "greppmatta",
    "greppmattors": "greppmatta",
    "greppmatts": "greppmatta",
    "greppriktiga": "greppriktig",
    "greppriktigare": "greppriktig",
    "greppriktigares": "greppriktig",
    "greppriktigas": "greppriktig",
    "greppriktigast": "greppriktig",
    "greppriktigaste": "greppriktig",
    "greppriktigastes": "greppriktig",
    "greppriktigasts": "greppriktig",
    "greppriktige": "greppriktig",
    "greppriktiges": "greppriktig",
    "greppriktigheten": "greppriktighet",
    "greppriktighetens": "greppriktighet",
    "greppriktighets": "greppriktighet",
    "greppriktigs": "greppriktig",
    "greppriktigt": "greppriktig",
    "greppriktigts": "greppriktig",
    "grepps": "grepp",
    "greppvänliga": "greppvänlig",
    "greppvänligare": "greppvänlig",
    "greppvänligares": "greppvänlig",
    "greppvänligas": "greppvänlig",
    "greppvänligast": "greppvänlig",
    "greppvänligaste": "greppvänlig",
    "greppvänligastes": "greppvänlig",
    "greppvänligasts": "greppvänlig",
    "greppvänlige": "greppvänlig",
    "greppvänliges": "greppvänlig",
    "greppvänligheten": "greppvänlighet",
    "greppvänlighetens": "greppvänlighet",
    "greppvänlighets": "greppvänlighet",
    "greppvänligs": "greppvänlig",
    "greppvänligt": "greppvänlig",
    "greppvänligts": "greppvänlig",
    "greppytan": "greppyta",
    "greppytans": "greppyta",
    "greppytas": "greppyta",
    "greppyte": "greppyta",
    "greppytor": "greppyta",
    "greppytorna": "greppyta",
    "greppytornas": "greppyta",
    "greppytors": "greppyta",
    "greps": "gripa",
    "grev": "greve",
    "grevar": "greve",
    "grevarna": "greve",
    "grevarnas": "greve",
    "grevars": "greve",
    "greven": "greve",
    "grevens": "greve",
    "greves": "greve",
    "grevinnan": "grevinna",
    "grevinnans": "grevinna",
    "grevinnas": "grevinna",
    "grevinne": "grevinna",
    "grevinnor": "grevinna",
    "grevinnorna": "grevinna",
    "grevinnornas": "grevinna",
    "grevinnors": "grevinna",
    "grevliga": "grevlig",
    "grevligare": "grevlig",
    "grevligares": "grevlig",
    "grevligas": "grevlig",
    "grevligast": "grevlig",
    "grevligaste": "grevlig",
    "grevligastes": "grevlig",
    "grevligasts": "grevlig",
    "grevlige": "grevlig",
    "grevliges": "grevlig",
    "grevligheten": "grevlighet",
    "grevlighetens": "grevlighet",
    "grevlighets": "grevlighet",
    "grevligs": "grevlig",
    "grevligt": "grevlig",
    "grevligts": "grevlig",
    "grevs": "greve",
    "grevskapen": "grevskap",
    "grevskapens": "grevskap",
    "grevskapet": "grevskap",
    "grevskapets": "grevskap",
    "grevskaps": "grevskap",
    "grevysebran": "grevysebra",
    "grevysebrans": "grevysebra",
    "grevysebras": "grevysebra",
    "grevysebror": "grevysebra",
    "grevysebrorna": "grevysebra",
    "grevysebrornas": "grevysebra",
    "grevysebrors": "grevysebra",
    "grevyzebran": "grevyzebra",
    "grevyzebrans": "grevyzebra",
    "grevyzebras": "grevyzebra",
    "grevyzebror": "grevyzebra",
    "grevyzebrorna": "grevyzebra",
    "grevyzebrornas": "grevyzebra",
    "grevyzebrors": "grevyzebra",
    "greyhounden": "greyhound",
    "greyhoundens": "greyhound",
    "greyhounds": "greyhound",
    "greyhoundsarna": "greyhound",
    "greyhoundsarnas": "greyhound",
    "greyhoundsen": "greyhound",
    "greyhoundsens": "greyhound",
    "griffeln": "griffel",
    "griffelns": "griffel",
    "griffels": "griffel",
    "griffeltavel": "griffeltavla",
    "griffeltavlan": "griffeltavla",
    "griffeltavlans": "griffeltavla",
    "griffeltavlas": "griffeltavla",
    "griffeltavle": "griffeltavla",
    "griffeltavlor": "griffeltavla",
    "griffeltavlorna": "griffeltavla",
    "griffeltavlornas": "griffeltavla",
    "griffeltavlors": "griffeltavla",
    "grifflar": "griffel",
    "grifflarna": "griffel",
    "grifflarnas": "griffel",
    "grifflars": "griffel",
    "griftefriden": "griftefrid",
    "griftefridens": "griftefrid",
    "griftefrids": "griftefrid",
    "griften": "grift",
    "griftens": "grift",
    "grifter": "grift",
    "grifterna": "grift",
    "grifternas": "grift",
    "grifters": "grift",
    "griftetalen": "griftetal",
    "griftetalens": "griftetal",
    "griftetalet": "griftetal",
    "griftetalets": "griftetal",
    "griftetals": "griftetal",
    "grifts": "grift",
    "griljerad": "griljera",
    "griljerade": "griljera",
    "griljerades": "griljera",
    "griljerads": "griljera",
    "griljerande": "griljera",
    "griljeranden": "griljerande",
    "griljerandena": "griljerande",
    "griljerandenas": "griljerande",
    "griljerandens": "griljerande",
    "griljerandes": "griljerande",
    "griljerandet": "griljerande",
    "griljerandets": "griljerande",
    "griljerar": "griljera",
    "griljeras": "griljera",
    "griljerat": "griljera",
    "griljerats": "griljera",
    "griljerbara": "griljerbar",
    "griljerbarare": "griljerbar",
    "griljerbarares": "griljerbar",
    "griljerbaras": "griljerbar",
    "griljerbarast": "griljerbar",
    "griljerbaraste": "griljerbar",
    "griljerbarastes": "griljerbar",
    "griljerbarasts": "griljerbar",
    "griljerbare": "griljerbar",
    "griljerbares": "griljerbar",
    "griljerbarheten": "griljerbarhet",
    "griljerbarhetens": "griljerbarhet",
    "griljerbarhets": "griljerbarhet",
    "griljerbars": "griljerbar",
    "griljerbart": "griljerbar",
    "griljerbarts": "griljerbar",
    "griljeringar": "griljering",
    "griljeringarna": "griljering",
    "griljeringarnas": "griljering",
    "griljeringars": "griljering",
    "griljeringen": "griljering",
    "griljeringens": "griljering",
    "griljerings": "griljering",
    "grill": "grillor",
    "grillad": "grilla",
    "grillade": "grilla",
    "grillades": "grilla",
    "grillads": "grilla",
    "grillande": "grilla",
    "grillanden": "grillande",
    "grillandena": "grillande",
    "grillandenas": "grillande",
    "grillandens": "grillande",
    "grillandes": "grillande",
    "grillandet": "grillande",
    "grillandets": "grillande",
    "grillar": "grilla",
    "grillarna": "grill",
    "grillarnas": "grill",
    "grillars": "grill",
    "grillas": "grilla",
    "grillat": "grilla",
    "grillats": "grilla",
    "grillbaren": "grillbar",
    "grillbarens": "grillbar",
    "grillbarer": "grillbar",
    "grillbarerna": "grillbar",
    "grillbarernas": "grillbar",
    "grillbarers": "grillbar",
    "grillbars": "grillbar",
    "grillen": "grill",
    "grillens": "grill",
    "grillerna": "griller",
    "grillernas": "griller",
    "grillers": "griller",
    "grillfängerier": "grillfängeri",
    "grillfängerierna": "grillfängeri",
    "grillfängeriernas": "grillfängeri",
    "grillfängeriers": "grillfängeri",
    "grillfängeriet": "grillfängeri",
    "grillfängeriets": "grillfängeri",
    "grillfängeris": "grillfängeri",
    "grillfängerit": "grillfängeri",
    "grillfängerits": "grillfängeri",
    "grilljann": "grilljanne",
    "grilljannar": "grilljanne",
    "grilljannarna": "grilljanne",
    "grilljannarnas": "grilljanne",
    "grilljannars": "grilljanne",
    "grilljannen": "grilljanne",
    "grilljannens": "grilljanne",
    "grilljannes": "grilljanne",
    "grilljanns": "grilljanne",
    "grillorna": "grillor",
    "grillornas": "grillor",
    "grillors": "grillor",
    "grills": "grillor",
    "grillspetten": "grillspett",
    "grillspettens": "grillspett",
    "grillspettet": "grillspett",
    "grillspettets": "grillspett",
    "grillspetts": "grillspett",
    "grim": "grimma",
    "grimasen": "grimas",
    "grimasens": "grimas",
    "grimaser": "grimas",
    "grimaserade": "grimasera",
    "grimaserades": "grimasera",
    "grimaserande": "grimasera",
    "grimaseranden": "grimaserande",
    "grimaserandena": "grimaserande",
    "grimaserandenas": "grimaserande",
    "grimaserandens": "grimaserande",
    "grimaserandes": "grimaserande",
    "grimaserandet": "grimaserande",
    "grimaserandets": "grimaserande",
    "grimaserar": "grimasera",
    "grimaseras": "grimasera",
    "grimaserat": "grimasera",
    "grimaserats": "grimasera",
    "grimaseringar": "grimasering",
    "grimaseringarna": "grimasering",
    "grimaseringarnas": "grimasering",
    "grimaseringars": "grimasering",
    "grimaseringen": "grimasering",
    "grimaseringens": "grimasering",
    "grimaserings": "grimasering",
    "grimaserna": "grimas",
    "grimasernas": "grimas",
    "grimasers": "grimas",
    "grimerad": "grimera",
    "grimerade": "grimera",
    "grimerades": "grimera",
    "grimerads": "grimera",
    "grimerande": "grimera",
    "grimeranden": "grimerande",
    "grimerandena": "grimerande",
    "grimerandenas": "grimerande",
    "grimerandens": "grimerande",
    "grimerandes": "grimerande",
    "grimerandet": "grimerande",
    "grimerandets": "grimerande",
    "grimerar": "grimera",
    "grimeras": "grimera",
    "grimerat": "grimera",
    "grimerats": "grimera",
    "grimerbara": "grimerbar",
    "grimerbarare": "grimerbar",
    "grimerbarares": "grimerbar",
    "grimerbaras": "grimerbar",
    "grimerbarast": "grimerbar",
    "grimerbaraste": "grimerbar",
    "grimerbarastes": "grimerbar",
    "grimerbarasts": "grimerbar",
    "grimerbare": "grimerbar",
    "grimerbares": "grimerbar",
    "grimerbarheten": "grimerbarhet",
    "grimerbarhetens": "grimerbarhet",
    "grimerbarhets": "grimerbarhet",
    "grimerbars": "grimerbar",
    "grimerbart": "grimerbar",
    "grimerbarts": "grimerbar",
    "grimeringar": "grimering",
    "grimeringarna": "grimering",
    "grimeringarnas": "grimering",
    "grimeringars": "grimering",
    "grimeringen": "grimering",
    "grimeringens": "grimering",
    "grimerings": "grimering",
    "grimman": "grimma",
    "grimmans": "grimma",
    "grimmas": "grimma",
    "grimme": "grimma",
    "grimmor": "grimma",
    "grimmorna": "grimma",
    "grimmornas": "grimma",
    "grimmors": "grimma",
    "grims": "grimma",
    "grimskaften": "grimskaft",
    "grimskaftens": "grimskaft",
    "grimskaftet": "grimskaft",
    "grimskaftets": "grimskaft",
    "grimskafts": "grimskaft",
    "grin": "grina",
    "grinade": "grina",
    "grinades": "grina",
    "grinande": "grina",
    "grinanden": "grinande",
    "grinandena": "grinande",
    "grinandenas": "grinande",
    "grinandens": "grinande",
    "grinandes": "grinande",
    "grinandet": "grinande",
    "grinandets": "grinande",
    "grinar": "grina",
    "grinas": "grina",
    "grinat": "grina",
    "grinats": "grina",
    "grindar": "grind",
    "grindarna": "grind",
    "grindarnas": "grind",
    "grindars": "grind",
    "grindbeslagen": "grindbeslag",
    "grindbeslagens": "grindbeslag",
    "grindbeslaget": "grindbeslag",
    "grindbeslagets": "grindbeslag",
    "grindbeslags": "grindbeslag",
    "grinden": "grind",
    "grindens": "grind",
    "grinds": "grind",
    "grindslantar": "grindslant",
    "grindslantarna": "grindslant",
    "grindslantarnas": "grindslant",
    "grindslantars": "grindslant",
    "grindslanten": "grindslant",
    "grindslantens": "grindslant",
    "grindslants": "grindslant",
    "grindstugan": "grindstuga",
    "grindstugans": "grindstuga",
    "grindstugas": "grindstuga",
    "grindstuge": "grindstuga",
    "grindstugor": "grindstuga",
    "grindstugorna": "grindstuga",
    "grindstugornas": "grindstuga",
    "grindstugors": "grindstuga",
    "grindstugu": "grindstuga",
    "grindvalar": "grindval",
    "grindvalarna": "grindval",
    "grindvalarnas": "grindval",
    "grindvalars": "grindval",
    "grindvalen": "grindval",
    "grindvalens": "grindval",
    "grindvals": "grindval",
    "grindöppningar": "grindöppning",
    "grindöppningarna": "grindöppning",
    "grindöppningarnas": "grindöppning",
    "grindöppningars": "grindöppning",
    "grindöppningen": "grindöppning",
    "grindöppningens": "grindöppning",
    "grindöppnings": "grindöppning",
    "grinen": "grin",
    "grinens": "grin",
    "grinet": "grin",
    "grinets": "grin",
    "gringon": "gringo",
    "gringons": "gringo",
    "gringor": "gringo",
    "gringorna": "gringo",
    "gringornas": "gringo",
    "gringors": "gringo",
    "gringos": "gringo",
    "gringosen": "gringo",
    "gringosens": "gringo",
    "griniga": "grinig",
    "grinigare": "grinig",
    "grinigares": "grinig",
    "grinigas": "grinig",
    "grinigast": "grinig",
    "grinigaste": "grinig",
    "grinigastes": "grinig",
    "grinigasts": "grinig",
    "grinige": "grinig",
    "griniges": "grinig",
    "grinigheten": "grinighet",
    "grinighetens": "grinighet",
    "grinigheter": "grinighet",
    "grinigheterna": "grinighet",
    "grinigheternas": "grinighet",
    "grinigheters": "grinighet",
    "grinighets": "grinighet",
    "grinigs": "grinig",
    "grinigt": "grinig",
    "grinigts": "grinig",
    "grinoll": "grinolle",
    "grinollar": "grinolle",
    "grinollarna": "grinolle",
    "grinollarnas": "grinolle",
    "grinollars": "grinolle",
    "grinollen": "grinolle",
    "grinollens": "grinolle",
    "grinolles": "grinolle",
    "grinolls": "grinolle",
    "grins": "grin",
    "grip": "gripa",
    "gripande": "gripa",
    "gripanden": "gripande",
    "gripandena": "gripande",
    "gripandenas": "gripande",
    "gripandens": "gripande",
    "gripandes": "gripande",
    "gripandet": "gripande",
    "gripandets": "gripande",
    "gripar": "grip",
    "griparna": "grip",
    "griparnas": "grip",
    "gripars": "grip",
    "gripas": "gripa",
    "gripbara": "gripbar",
    "gripbarare": "gripbar",
    "gripbarares": "gripbar",
    "gripbaras": "gripbar",
    "gripbarast": "gripbar",
    "gripbaraste": "gripbar",
    "gripbarastes": "gripbar",
    "gripbarasts": "gripbar",
    "gripbare": "gripbar",
    "gripbares": "gripbar",
    "gripbarheten": "gripbarhet",
    "gripbarhetens": "gripbarhet",
    "gripbarhets": "gripbarhet",
    "gripbars": "gripbar",
    "gripbart": "gripbar",
    "gripbarts": "gripbar",
    "gripe": "gripa",
    "gripen": "gripa",
    "gripenheten": "gripenhet",
    "gripenhetens": "gripenhet",
    "gripenhets": "gripenhet",
    "gripens": "gripen",
    "griper": "gripa",
    "gripes": "gripa",
    "gripet": "gripen",
    "gripets": "gripen",
    "gripfoten": "gripfot",
    "gripfotens": "gripfot",
    "gripfots": "gripfot",
    "gripfötter": "gripfot",
    "gripfötterna": "gripfot",
    "gripfötternas": "gripfot",
    "gripfötters": "gripfot",
    "gripit": "gripa",
    "gripits": "gripa",
    "gripna": "gripen",
    "gripnare": "gripen",
    "gripnares": "gripen",
    "gripnas": "gripen",
    "gripnast": "gripen",
    "gripnaste": "gripen",
    "gripnastes": "gripen",
    "gripnasts": "gripen",
    "gripne": "gripen",
    "gripnes": "gripen",
    "gripreflexen": "gripreflex",
    "gripreflexens": "gripreflex",
    "grips": "gripa",
    "grisade": "grisa",
    "grisades": "grisa",
    "grisaillen": "grisaille",
    "grisaillens": "grisaille",
    "grisailler": "grisaille",
    "grisaillerna": "grisaille",
    "grisaillernas": "grisaille",
    "grisaillers": "grisaille",
    "grisailles": "grisaille",
    "grisande": "grisa",
    "grisanden": "grisande",
    "grisandena": "grisande",
    "grisandenas": "grisande",
    "grisandens": "grisande",
    "grisandes": "grisande",
    "grisandet": "grisande",
    "grisandets": "grisande",
    "grisar": "grisa",
    "grisarna": "gris",
    "grisarnas": "gris",
    "grisars": "gris",
    "grisas": "grisa",
    "grisat": "grisa",
    "grisats": "grisa",
    "grisbond": "grisbonde",
    "grisbonden": "grisbonde",
    "grisbondens": "grisbonde",
    "grisbondes": "grisbonde",
    "grisbonds": "grisbonde",
    "grisbönder": "grisbonde",
    "grisbönderna": "grisbonde",
    "grisböndernas": "grisbonde",
    "grisbönders": "grisbonde",
    "grisen": "gris",
    "grisens": "gris",
    "griserier": "griseri",
    "griserierna": "griseri",
    "griseriernas": "griseri",
    "griseriers": "griseri",
    "griseriet": "griseri",
    "griseriets": "griseri",
    "griseris": "griseri",
    "griserit": "griseri",
    "griserits": "griseri",
    "grisetten": "grisett",
    "grisettens": "grisett",
    "grisetter": "grisett",
    "grisetterna": "grisett",
    "grisetternas": "grisett",
    "grisetters": "grisett",
    "grisetts": "grisett",
    "grisfesten": "grisfest",
    "grisfestens": "grisfest",
    "grisfester": "grisfest",
    "grisfesterna": "grisfest",
    "grisfesternas": "grisfest",
    "grisfesters": "grisfest",
    "grisfests": "grisfest",
    "grisfösar": "grisfösare",
    "grisfösaren": "grisfösare",
    "grisfösarens": "grisfösare",
    "grisfösares": "grisfösare",
    "grisfösarna": "grisfösare",
    "grisfösarnas": "grisfösare",
    "grisiga": "grisig",
    "grisigare": "grisig",
    "grisigares": "grisig",
    "grisigas": "grisig",
    "grisigast": "grisig",
    "grisigaste": "grisig",
    "grisigastes": "grisig",
    "grisigasts": "grisig",
    "grisige": "grisig",
    "grisiges": "grisig",
    "grisigs": "grisig",
    "grisigt": "grisig",
    "grisigts": "grisig",
    "grisinsulinen": "grisinsulin",
    "grisinsulinens": "grisinsulin",
    "grisinsuliner": "grisinsulin",
    "grisinsulinerna": "grisinsulin",
    "grisinsulinernas": "grisinsulin",
    "grisinsuliners": "grisinsulin",
    "grisinsulinet": "grisinsulin",
    "grisinsulinets": "grisinsulin",
    "grisinsulins": "grisinsulin",
    "griskultingar": "griskulting",
    "griskultingarna": "griskulting",
    "griskultingarnas": "griskulting",
    "griskultingars": "griskulting",
    "griskultingen": "griskulting",
    "griskultingens": "griskulting",
    "griskultings": "griskulting",
    "grismaten": "grismat",
    "grismatens": "grismat",
    "grismats": "grismat",
    "grisningar": "grisning",
    "grisningarna": "grisning",
    "grisningarnas": "grisning",
    "grisningars": "grisning",
    "grisningen": "grisning",
    "grisningens": "grisning",
    "grisnings": "grisning",
    "grisningsboen": "grisningsbo",
    "grisningsboens": "grisningsbo",
    "grisningsboet": "grisningsbo",
    "grisningsboets": "grisningsbo",
    "grisningsbon": "grisningsbo",
    "grisningsbona": "grisningsbo",
    "grisningsbonas": "grisningsbo",
    "grisningsbons": "grisningsbo",
    "grisningsbos": "grisningsbo",
    "grisningsbot": "grisningsbo",
    "grisningsbots": "grisningsbo",
    "grisplågerier": "grisplågeri",
    "grisplågerierna": "grisplågeri",
    "grisplågeriernas": "grisplågeri",
    "grisplågeriers": "grisplågeri",
    "grisplågeriet": "grisplågeri",
    "grisplågeriets": "grisplågeri",
    "grisplågeris": "grisplågeri",
    "grisplågerit": "grisplågeri",
    "grisplågerits": "grisplågeri",
    "grisseln": "grissel",
    "grisselns": "grissel",
    "grissels": "grissel",
    "grisskandalen": "grisskandal",
    "grisskandalens": "grisskandal",
    "grisskandaler": "grisskandal",
    "grisskandalerna": "grisskandal",
    "grisskandalernas": "grisskandal",
    "grisskandalers": "grisskandal",
    "grisskandals": "grisskandal",
    "grissl": "grissla",
    "grisslan": "grissla",
    "grisslans": "grissla",
    "grisslar": "grissel",
    "grisslarna": "grissel",
    "grisslarnas": "grissel",
    "grisslars": "grissel",
    "grisslas": "grissla",
    "grissle": "grissla",
    "grisslor": "grissla",
    "grisslorna": "grissla",
    "grisslornas": "grissla",
    "grisslors": "grissla",
    "grissvansar": "grissvans",
    "grissvansarna": "grissvans",
    "grissvansarnas": "grissvans",
    "grissvansars": "grissvans",
    "grissvansen": "grissvans",
    "grissvansens": "grissvans",
    "grisungar": "grisunge",
    "grisungarna": "grisunge",
    "grisungarnas": "grisunge",
    "grisungars": "grisunge",
    "grisungen": "grisunge",
    "grisungens": "grisunge",
    "grisunges": "grisunge",
    "grisuppfödningen": "grisuppfödning",
    "grisuppfödningens": "grisuppfödning",
    "grisuppfödnings": "grisuppfödning",
    "grisögas": "grisöga",
    "grisögat": "grisöga",
    "grisögats": "grisöga",
    "grisögon": "grisöga",
    "grisögonen": "grisöga",
    "grisögonens": "grisöga",
    "grisögons": "grisöga",
    "grizzlybjörnar": "grizzlybjörn",
    "grizzlybjörnarna": "grizzlybjörn",
    "grizzlybjörnarnas": "grizzlybjörn",
    "grizzlybjörnars": "grizzlybjörn",
    "grizzlybjörnen": "grizzlybjörn",
    "grizzlybjörnens": "grizzlybjörn",
    "grizzlybjörns": "grizzlybjörn",
    "grobarheten": "grobarhet",
    "grobarhetens": "grobarhet",
    "grobarheter": "grobarhet",
    "grobarheterna": "grobarhet",
    "grobarheternas": "grobarhet",
    "grobarheters": "grobarhet",
    "grobarhets": "grobarhet",
    "grobianen": "grobian",
    "grobianens": "grobian",
    "grobianer": "grobian",
    "grobianerna": "grobian",
    "grobianernas": "grobian",
    "grobianers": "grobian",
    "grobians": "grobian",
    "grobladen": "groblad",
    "grobladens": "groblad",
    "grobladet": "groblad",
    "grobladets": "groblad",
    "groblads": "groblad",
    "grod": "groda",
    "grodan": "groda",
    "grodans": "groda",
    "grodas": "groda",
    "grodd": "grodda",
    "grodda": "gro",
    "groddad": "grodda",
    "groddade": "grodda",
    "groddades": "grodda",
    "groddads": "grodda",
    "groddande": "grodda",
    "groddanden": "groddande",
    "groddandena": "groddande",
    "groddandenas": "groddande",
    "groddandens": "groddande",
    "groddandes": "groddande",
    "groddandet": "groddande",
    "groddandets": "groddande",
    "groddar": "grodda",
    "groddarna": "grodd",
    "groddarnas": "grodd",
    "groddars": "grodd",
    "groddas": "grodda",
    "groddat": "grodda",
    "groddats": "grodda",
    "groddbladen": "groddblad",
    "groddbladens": "groddblad",
    "groddbladet": "groddblad",
    "groddbladets": "groddblad",
    "groddblads": "groddblad",
    "grodde": "gro",
    "grodden": "grodd",
    "groddens": "grodd",
    "groddes": "gro",
    "groddjuren": "groddjur",
    "groddjurens": "groddjur",
    "groddjuret": "groddjur",
    "groddjurets": "groddjur",
    "groddjurs": "groddjur",
    "groddknoppar": "groddknopp",
    "groddknopparna": "groddknopp",
    "groddknopparnas": "groddknopp",
    "groddknoppars": "groddknopp",
    "groddknoppen": "groddknopp",
    "groddknoppens": "groddknopp",
    "groddknopps": "groddknopp",
    "groddplant": "groddplanta",
    "groddplantan": "groddplanta",
    "groddplantans": "groddplanta",
    "groddplantas": "groddplanta",
    "groddplante": "groddplanta",
    "groddplantor": "groddplanta",
    "groddplantorna": "groddplanta",
    "groddplantornas": "groddplanta",
    "groddplantors": "groddplanta",
    "groddplants": "groddplanta",
    "grodds": "grodd",
    "grode": "groda",
    "grodfiskar": "grodfisk",
    "grodfiskarna": "grodfisk",
    "grodfiskarnas": "grodfisk",
    "grodfiskars": "grodfisk",
    "grodfisken": "grodfisk",
    "grodfiskens": "grodfisk",
    "grodfisks": "grodfisk",
    "grodlåren": "grodlår",
    "grodlårens": "grodlår",
    "grodlåret": "grodlår",
    "grodlårets": "grodlår",
    "grodlårs": "grodlår",
    "grodmannen": "grodman",
    "grodmannens": "grodman",
    "grodmans": "grodman",
    "grodmän": "grodman",
    "grodmännen": "grodman",
    "grodmännens": "grodman",
    "grodmäns": "grodman",
    "grodnaten": "grodnate",
    "grodnatens": "grodnate",
    "grodnates": "grodnate",
    "grodor": "groda",
    "grodorna": "groda",
    "grodornas": "groda",
    "grodors": "groda",
    "grodperspektivet": "grodperspektiv",
    "grodperspektivets": "grodperspektiv",
    "grodperspektivs": "grodperspektiv",
    "grods": "groda",
    "grodsimmet": "grodsim",
    "grodsimmets": "grodsim",
    "grodsims": "grodsim",
    "grodspottet": "grodspott",
    "grodspottets": "grodspott",
    "grodspotts": "grodspott",
    "grodyngels": "grodyngel",
    "grodynglen": "grodyngel",
    "grodynglens": "grodyngel",
    "grodynglet": "grodyngel",
    "grodynglets": "grodyngel",
    "grodäggen": "grodägg",
    "grodäggens": "grodägg",
    "grodägget": "grodägg",
    "grodäggets": "grodägg",
    "grodäggs": "grodägg",
    "groende": "gro",
    "groenden": "groende",
    "groendena": "groende",
    "groendenas": "groende",
    "groendens": "groende",
    "groendes": "groende",
    "groendet": "groende",
    "groendets": "groende",
    "groggade": "grogga",
    "groggades": "grogga",
    "groggande": "grogga",
    "grogganden": "groggande",
    "groggandena": "groggande",
    "groggandenas": "groggande",
    "groggandens": "groggande",
    "groggandes": "groggande",
    "groggandet": "groggande",
    "groggandets": "groggande",
    "groggar": "grogga",
    "groggarna": "grogg",
    "groggarnas": "grogg",
    "groggars": "grogg",
    "groggas": "grogga",
    "groggat": "grogga",
    "groggats": "grogga",
    "groggen": "grogg",
    "groggens": "grogg",
    "groggs": "grogg",
    "groggvirkes": "groggvirke",
    "groggvirket": "groggvirke",
    "groggvirkets": "groggvirke",
    "grogrunden": "grogrund",
    "grogrundens": "grogrund",
    "grogrunder": "grogrund",
    "grogrunderna": "grogrund",
    "grogrundernas": "grogrund",
    "grogrunders": "grogrund",
    "grogrunds": "grogrund",
    "grollet": "groll",
    "grollets": "groll",
    "grolls": "groll",
    "groningar": "groning",
    "groningarna": "groning",
    "groningarnas": "groning",
    "groningars": "groning",
    "groningen": "groning",
    "groningens": "groning",
    "gronings": "groning",
    "gropar": "grop",
    "groparna": "grop",
    "groparnas": "grop",
    "gropars": "grop",
    "gropemaljen": "gropemalj",
    "gropemaljens": "gropemalj",
    "gropemaljs": "gropemalj",
    "gropen": "grop",
    "gropens": "grop",
    "gropiga": "gropig",
    "gropigare": "gropig",
    "gropigares": "gropig",
    "gropigas": "gropig",
    "gropigast": "gropig",
    "gropigaste": "gropig",
    "gropigastes": "gropig",
    "gropigasts": "gropig",
    "gropige": "gropig",
    "gropiges": "gropig",
    "gropigs": "gropig",
    "gropigt": "gropig",
    "gropigts": "gropig",
    "groplöj": "groplöja",
    "groplöjan": "groplöja",
    "groplöjans": "groplöja",
    "groplöjas": "groplöja",
    "groplöje": "groplöja",
    "groplöjor": "groplöja",
    "groplöjorna": "groplöja",
    "groplöjornas": "groplöja",
    "groplöjors": "groplöja",
    "groplöjs": "groplöja",
    "grops": "grop",
    "gror": "gro",
    "gros": "gro",
    "groschenen": "groschen",
    "groschenens": "groschen",
    "groschens": "groschen",
    "grossen": "gross",
    "grossens": "gross",
    "grossessen": "grossess",
    "grossessens": "grossess",
    "grossesser": "grossess",
    "grossesserna": "grossess",
    "grossessernas": "grossess",
    "grossessers": "grossess",
    "grosset": "gross",
    "grossets": "gross",
    "grosshandeln": "grosshandel",
    "grosshandelns": "grosshandel",
    "grosshandels": "grosshandel",
    "grosshandlar": "grosshandlare",
    "grosshandlaren": "grosshandlare",
    "grosshandlarens": "grosshandlare",
    "grosshandlares": "grosshandlare",
    "grosshandlarna": "grosshandlare",
    "grosshandlarnas": "grosshandlare",
    "grossisten": "grossist",
    "grossistens": "grossist",
    "grossister": "grossist",
    "grossisterna": "grossist",
    "grossisternas": "grossist",
    "grossisters": "grossist",
    "grossistprisen": "grossistpris",
    "grossistprisens": "grossistpris",
    "grossistpriser": "grossistpris",
    "grossistpriserna": "grossistpris",
    "grossistprisernas": "grossistpris",
    "grossistprisers": "grossistpris",
    "grossistpriset": "grossistpris",
    "grossistprisets": "grossistpris",
    "grossists": "grossist",
    "grossören": "grossör",
    "grossörens": "grossör",
    "grossörer": "grossör",
    "grossörerna": "grossör",
    "grossörernas": "grossör",
    "grossörers": "grossör",
    "grossörs": "grossör",
    "groteska": "grotesk",
    "groteskare": "grotesk",
    "groteskares": "grotesk",
    "groteskas": "grotesk",
    "groteskast": "grotesk",
    "groteskaste": "grotesk",
    "groteskastes": "grotesk",
    "groteskasts": "grotesk",
    "groteske": "grotesk",
    "grotesken": "grotesk",
    "groteskens": "grotesk",
    "grotesker": "grotesk",
    "groteskerier": "groteskeri",
    "groteskerierna": "groteskeri",
    "groteskeriernas": "groteskeri",
    "groteskeriers": "groteskeri",
    "groteskeriet": "groteskeri",
    "groteskeriets": "groteskeri",
    "groteskeris": "groteskeri",
    "groteskerit": "groteskeri",
    "groteskerits": "groteskeri",
    "groteskerna": "grotesk",
    "groteskernas": "grotesk",
    "groteskers": "grotesk",
    "groteskes": "grotesk",
    "grotesks": "grotesk",
    "groteskt": "grotesk",
    "groteskts": "grotesk",
    "grott": "grotta",
    "grottan": "grotta",
    "grottans": "grotta",
    "grottas": "grotta",
    "grottbjörnar": "grottbjörn",
    "grottbjörnarna": "grottbjörn",
    "grottbjörnarnas": "grottbjörn",
    "grottbjörnars": "grottbjörn",
    "grottbjörnen": "grottbjörn",
    "grottbjörnens": "grottbjörn",
    "grottbjörns": "grottbjörn",
    "grotte": "grotta",
    "grottekvarnen": "grottekvarn",
    "grottekvarnens": "grottekvarn",
    "grottekvarns": "grottekvarn",
    "grottforskar": "grottforskare",
    "grottforskaren": "grottforskare",
    "grottforskarens": "grottforskare",
    "grottforskares": "grottforskare",
    "grottforskarna": "grottforskare",
    "grottforskarnas": "grottforskare",
    "grottforskningar": "grottforskning",
    "grottforskningarna": "grottforskning",
    "grottforskningarnas": "grottforskning",
    "grottforskningars": "grottforskning",
    "grottforskningen": "grottforskning",
    "grottforskningens": "grottforskning",
    "grottforsknings": "grottforskning",
    "grottgångar": "grottgång",
    "grottgångarna": "grottgång",
    "grottgångarnas": "grottgång",
    "grottgångars": "grottgång",
    "grottgången": "grottgång",
    "grottgångens": "grottgång",
    "grottgångs": "grottgång",
    "grottingångar": "grottingång",
    "grottingångarna": "grottingång",
    "grottingångarnas": "grottingång",
    "grottingångars": "grottingång",
    "grottingången": "grottingång",
    "grottingångens": "grottingång",
    "grottingångs": "grottingång",
    "grottinnevånar": "grottinnevånare",
    "grottinnevånaren": "grottinnevånare",
    "grottinnevånarens": "grottinnevånare",
    "grottinnevånares": "grottinnevånare",
    "grottinnevånarna": "grottinnevånare",
    "grottinnevånarnas": "grottinnevånare",
    "grottinvånar": "grottinvånare",
    "grottinvånaren": "grottinvånare",
    "grottinvånarens": "grottinvånare",
    "grottinvånares": "grottinvånare",
    "grottinvånarna": "grottinvånare",
    "grottinvånarnas": "grottinvånare",
    "grottmänniskan": "grottmänniska",
    "grottmänniskans": "grottmänniska",
    "grottmänniskas": "grottmänniska",
    "grottmännisko": "grottmänniska",
    "grottmänniskor": "grottmänniska",
    "grottmänniskorna": "grottmänniska",
    "grottmänniskornas": "grottmänniska",
    "grottmänniskors": "grottmänniska",
    "grottmålningar": "grottmålning",
    "grottmålningarna": "grottmålning",
    "grottmålningarnas": "grottmålning",
    "grottmålningars": "grottmålning",
    "grottmålningen": "grottmålning",
    "grottmålningens": "grottmålning",
    "grottmålnings": "grottmålning",
    "grottor": "grotta",
    "grottorna": "grotta",
    "grottornas": "grotta",
    "grottors": "grotta",
    "grotts": "grotta",
    "grottskrev": "grottskreva",
    "grottskrevan": "grottskreva",
    "grottskrevans": "grottskreva",
    "grottskrevas": "grottskreva",
    "grottskreve": "grottskreva",
    "grottskrevor": "grottskreva",
    "grottskrevorna": "grottskreva",
    "grottskrevornas": "grottskreva",
    "grottskrevors": "grottskreva",
    "grottskrevs": "grottskreva",
    "groupien": "groupie",
    "groupiens": "groupie",
    "groupies": "groupie",
    "groupiesarna": "groupie",
    "groupiesarnas": "groupie",
    "groupiesen": "groupie",
    "groupiesens": "groupie",
    "grova": "grov",
    "grovarbetar": "grovarbetare",
    "grovarbetaren": "grovarbetare",
    "grovarbetarens": "grovarbetare",
    "grovarbetares": "grovarbetare",
    "grovarbetarna": "grovarbetare",
    "grovarbetarnas": "grovarbetare",
    "grovarbeten": "grovarbete",
    "grovarbetena": "grovarbete",
    "grovarbetenas": "grovarbete",
    "grovarbetens": "grovarbete",
    "grovarbetes": "grovarbete",
    "grovarbetet": "grovarbete",
    "grovarbetets": "grovarbete",
    "grovarbets": "grovarbete",
    "grovas": "grov",
    "grovbruken": "grovbruk",
    "grovbrukens": "grovbruk",
    "grovbruket": "grovbruk",
    "grovbrukets": "grovbruk",
    "grovbruks": "grovbruk",
    "grove": "grov",
    "groves": "grov",
    "grovfoders": "grovfoder",
    "grovfodret": "grovfoder",
    "grovfodrets": "grovfoder",
    "grovgöras": "grovgöra",
    "grovgörat": "grovgöra",
    "grovgörats": "grovgöra",
    "grovheten": "grovhet",
    "grovhetens": "grovhet",
    "grovheter": "grovhet",
    "grovheterna": "grovhet",
    "grovheternas": "grovhet",
    "grovheters": "grovhet",
    "grovhets": "grovhet",
    "grovhuggenheten": "grovhuggenhet",
    "grovhuggenhetens": "grovhuggenhet",
    "grovhuggenhets": "grovhuggenhet",
    "grovhuggens": "grovhuggen",
    "grovhugget": "grovhuggen",
    "grovhuggets": "grovhuggen",
    "grovhuggna": "grovhuggen",
    "grovhuggnare": "grovhuggen",
    "grovhuggnares": "grovhuggen",
    "grovhuggnas": "grovhuggen",
    "grovhuggnast": "grovhuggen",
    "grovhuggnaste": "grovhuggen",
    "grovhuggnastes": "grovhuggen",
    "grovhuggnasts": "grovhuggen",
    "grovhuggne": "grovhuggen",
    "grovhuggnes": "grovhuggen",
    "grovhyade": "grovhyad",
    "grovhyades": "grovhyad",
    "grovhyads": "grovhyad",
    "grovhyat": "grovhyad",
    "grovhyats": "grovhyad",
    "grovkorniga": "grovkornig",
    "grovkornigare": "grovkornig",
    "grovkornigares": "grovkornig",
    "grovkornigas": "grovkornig",
    "grovkornigast": "grovkornig",
    "grovkornigaste": "grovkornig",
    "grovkornigastes": "grovkornig",
    "grovkornigasts": "grovkornig",
    "grovkornige": "grovkornig",
    "grovkorniges": "grovkornig",
    "grovkornigheten": "grovkornighet",
    "grovkornighetens": "grovkornighet",
    "grovkornigheter": "grovkornighet",
    "grovkornigheterna": "grovkornighet",
    "grovkornigheternas": "grovkornighet",
    "grovkornigheters": "grovkornighet",
    "grovkornighets": "grovkornighet",
    "grovkornigs": "grovkornig",
    "grovkornigt": "grovkornig",
    "grovkornigts": "grovkornig",
    "grovköken": "grovkök",
    "grovkökens": "grovkök",
    "grovköket": "grovkök",
    "grovkökets": "grovkök",
    "grovköks": "grovkök",
    "grovlekar": "grovlek",
    "grovlekarna": "grovlek",
    "grovlekarnas": "grovlek",
    "grovlekars": "grovlek",
    "grovleken": "grovlek",
    "grovlekens": "grovlek",
    "grovleks": "grovlek",
    "grovnade": "grovna",
    "grovnades": "grovna",
    "grovnande": "grovna",
    "grovnanden": "grovnande",
    "grovnandena": "grovnande",
    "grovnandenas": "grovnande",
    "grovnandens": "grovnande",
    "grovnandes": "grovnande",
    "grovnandet": "grovnande",
    "grovnandets": "grovnande",
    "grovnar": "grovna",
    "grovnas": "grovna",
    "grovnat": "grovna",
    "grovnats": "grovna",
    "grovplanerad": "grovplanera",
    "grovplanerade": "grovplanera",
    "grovplanerades": "grovplanera",
    "grovplanerads": "grovplanera",
    "grovplanerande": "grovplanera",
    "grovplaneranden": "grovplanerande",
    "grovplanerandena": "grovplanerande",
    "grovplanerandenas": "grovplanerande",
    "grovplanerandens": "grovplanerande",
    "grovplanerandes": "grovplanerande",
    "grovplanerandet": "grovplanerande",
    "grovplanerandets": "grovplanerande",
    "grovplanerar": "grovplanera",
    "grovplaneras": "grovplanera",
    "grovplanerat": "grovplanera",
    "grovplanerats": "grovplanera",
    "grovplanerbara": "grovplanerbar",
    "grovplanerbarare": "grovplanerbar",
    "grovplanerbarares": "grovplanerbar",
    "grovplanerbaras": "grovplanerbar",
    "grovplanerbarast": "grovplanerbar",
    "grovplanerbaraste": "grovplanerbar",
    "grovplanerbarastes": "grovplanerbar",
    "grovplanerbarasts": "grovplanerbar",
    "grovplanerbare": "grovplanerbar",
    "grovplanerbares": "grovplanerbar",
    "grovplanerbarheten": "grovplanerbarhet",
    "grovplanerbarhetens": "grovplanerbarhet",
    "grovplanerbarhets": "grovplanerbarhet",
    "grovplanerbars": "grovplanerbar",
    "grovplanerbart": "grovplanerbar",
    "grovplanerbarts": "grovplanerbar",
    "grovplaneringar": "grovplanering",
    "grovplaneringarna": "grovplanering",
    "grovplaneringarnas": "grovplanering",
    "grovplaneringars": "grovplanering",
    "grovplaneringen": "grovplanering",
    "grovplaneringens": "grovplanering",
    "grovplanerings": "grovplanering",
    "grovs": "grov",
    "grovsaltet": "grovsalt",
    "grovsaltets": "grovsalt",
    "grovsalts": "grovsalt",
    "grovsmides": "grovsmide",
    "grovsmidet": "grovsmide",
    "grovsmidets": "grovsmide",
    "grovsorterad": "grovsortera",
    "grovsorterade": "grovsortera",
    "grovsorterades": "grovsortera",
    "grovsorterads": "grovsortera",
    "grovsorterande": "grovsortera",
    "grovsorteranden": "grovsorterande",
    "grovsorterandena": "grovsorterande",
    "grovsorterandenas": "grovsorterande",
    "grovsorterandens": "grovsorterande",
    "grovsorterandes": "grovsorterande",
    "grovsorterandet": "grovsorterande",
    "grovsorterandets": "grovsorterande",
    "grovsorterar": "grovsortera",
    "grovsorteras": "grovsortera",
    "grovsorterat": "grovsortera",
    "grovsorterats": "grovsortera",
    "grovsorterbara": "grovsorterbar",
    "grovsorterbarare": "grovsorterbar",
    "grovsorterbarares": "grovsorterbar",
    "grovsorterbaras": "grovsorterbar",
    "grovsorterbarast": "grovsorterbar",
    "grovsorterbaraste": "grovsorterbar",
    "grovsorterbarastes": "grovsorterbar",
    "grovsorterbarasts": "grovsorterbar",
    "grovsorterbare": "grovsorterbar",
    "grovsorterbares": "grovsorterbar",
    "grovsorterbarheten": "grovsorterbarhet",
    "grovsorterbarhetens": "grovsorterbarhet",
    "grovsorterbarhets": "grovsorterbarhet",
    "grovsorterbars": "grovsorterbar",
    "grovsorterbart": "grovsorterbar",
    "grovsorterbarts": "grovsorterbar",
    "grovsorteringar": "grovsortering",
    "grovsorteringarna": "grovsortering",
    "grovsorteringarnas": "grovsortering",
    "grovsorteringars": "grovsortering",
    "grovsorteringen": "grovsortering",
    "grovsorteringens": "grovsortering",
    "grovsorterings": "grovsortering",
    "grovspackels": "grovspackel",
    "grovspacklet": "grovspackel",
    "grovspacklets": "grovspackel",
    "grovsyssl": "grovsyssla",
    "grovsysslan": "grovsyssla",
    "grovsysslans": "grovsyssla",
    "grovsysslas": "grovsyssla",
    "grovsyssle": "grovsyssla",
    "grovsysslo": "grovsyssla",
    "grovsysslor": "grovsyssla",
    "grovsysslorna": "grovsyssla",
    "grovsysslornas": "grovsyssla",
    "grovsysslors": "grovsyssla",
    "grovt": "grov",
    "grovtarmar": "grovtarm",
    "grovtarmarna": "grovtarm",
    "grovtarmarnas": "grovtarm",
    "grovtarmars": "grovtarm",
    "grovtarmen": "grovtarm",
    "grovtarmens": "grovtarm",
    "grovtarms": "grovtarm",
    "grovts": "grov",
    "grovyxade": "grovyxad",
    "grovyxades": "grovyxad",
    "grovyxads": "grovyxad",
    "grovyxat": "grovyxad",
    "grovyxats": "grovyxad",
    "grubb": "grubba",
    "grubban": "grubba",
    "grubbans": "grubba",
    "grubbas": "grubba",
    "grubbe": "grubba",
    "grubbel": "grubbla",
    "grubbels": "grubbel",
    "grubblade": "grubbla",
    "grubblades": "grubbla",
    "grubblande": "grubbla",
    "grubblanden": "grubblande",
    "grubblandena": "grubblande",
    "grubblandenas": "grubblande",
    "grubblandens": "grubblande",
    "grubblandes": "grubblande",
    "grubblandet": "grubblande",
    "grubblandets": "grubblande",
    "grubblar": "grubblare",
    "grubblaren": "grubblare",
    "grubblarens": "grubblare",
    "grubblares": "grubblare",
    "grubblarna": "grubblare",
    "grubblarnas": "grubblare",
    "grubblas": "grubbla",
    "grubblat": "grubbla",
    "grubblats": "grubbla",
    "grubblerier": "grubbleri",
    "grubblerierna": "grubbleri",
    "grubbleriernas": "grubbleri",
    "grubbleriers": "grubbleri",
    "grubbleriet": "grubbleri",
    "grubbleriets": "grubbleri",
    "grubbleris": "grubbleri",
    "grubblerit": "grubbleri",
    "grubblerits": "grubbleri",
    "grubblet": "grubbel",
    "grubblets": "grubbel",
    "grubbor": "grubba",
    "grubborna": "grubba",
    "grubbornas": "grubba",
    "grubbors": "grubba",
    "grubbs": "grubba",
    "gruff": "gruffa",
    "gruffade": "gruffa",
    "gruffades": "gruffa",
    "gruffande": "gruffa",
    "gruffanden": "gruffande",
    "gruffandena": "gruffande",
    "gruffandenas": "gruffande",
    "gruffandens": "gruffande",
    "gruffandes": "gruffande",
    "gruffandet": "gruffande",
    "gruffandets": "gruffande",
    "gruffar": "gruffa",
    "gruffas": "gruffa",
    "gruffat": "gruffa",
    "gruffats": "gruffa",
    "gruffen": "gruff",
    "gruffens": "gruff",
    "gruffet": "gruff",
    "gruffets": "gruff",
    "gruffs": "gruff",
    "grumlad": "grumla",
    "grumlade": "grumla",
    "grumlades": "grumla",
    "grumlads": "grumla",
    "grumlande": "grumla",
    "grumlanden": "grumlande",
    "grumlandena": "grumlande",
    "grumlandenas": "grumlande",
    "grumlandens": "grumlande",
    "grumlandes": "grumlande",
    "grumlandet": "grumlande",
    "grumlandets": "grumlande",
    "grumlar": "grumla",
    "grumlas": "grumla",
    "grumlat": "grumla",
    "grumlats": "grumla",
    "grumlet": "grummel",
    "grumlets": "grummel",
    "grumliga": "grumlig",
    "grumligare": "grumlig",
    "grumligares": "grumlig",
    "grumligas": "grumlig",
    "grumligast": "grumlig",
    "grumligaste": "grumlig",
    "grumligastes": "grumlig",
    "grumligasts": "grumlig",
    "grumlige": "grumlig",
    "grumliges": "grumlig",
    "grumligheten": "grumlighet",
    "grumlighetens": "grumlighet",
    "grumligheter": "grumlighet",
    "grumligheterna": "grumlighet",
    "grumligheternas": "grumlighet",
    "grumligheters": "grumlighet",
    "grumlighets": "grumlighet",
    "grumligs": "grumlig",
    "grumligt": "grumlig",
    "grumligts": "grumlig",
    "grumlingar": "grumling",
    "grumlingarna": "grumling",
    "grumlingarnas": "grumling",
    "grumlingars": "grumling",
    "grumlingen": "grumling",
    "grumlingens": "grumling",
    "grumlings": "grumling",
    "grummel": "grumla",
    "grummels": "grummel",
    "grums": "grumsa",
    "grumsad": "grumsa",
    "grumsade": "grumsa",
    "grumsades": "grumsa",
    "grumsads": "grumsa",
    "grumsande": "grumsa",
    "grumsanden": "grumsande",
    "grumsandena": "grumsande",
    "grumsandenas": "grumsande",
    "grumsandens": "grumsande",
    "grumsandes": "grumsande",
    "grumsandet": "grumsande",
    "grumsandets": "grumsande",
    "grumsar": "grumsa",
    "grumsas": "grumsa",
    "grumsat": "grumsa",
    "grumsats": "grumsa",
    "grumset": "grums",
    "grumsets": "grums",
    "grumsiga": "grumsig",
    "grumsigare": "grumsig",
    "grumsigares": "grumsig",
    "grumsigas": "grumsig",
    "grumsigast": "grumsig",
    "grumsigaste": "grumsig",
    "grumsigastes": "grumsig",
    "grumsigasts": "grumsig",
    "grumsige": "grumsig",
    "grumsiges": "grumsig",
    "grumsigheten": "grumsighet",
    "grumsighetens": "grumsighet",
    "grumsighets": "grumsighet",
    "grumsigs": "grumsig",
    "grumsigt": "grumsig",
    "grumsigts": "grumsig",
    "grund": "grunda",
    "grunda": "grund",
    "grundackorden": "grundackord",
    "grundackordens": "grundackord",
    "grundackordet": "grundackord",
    "grundackordets": "grundackord",
    "grundackords": "grundackord",
    "grundad": "grunda",
    "grundade": "grundad",
    "grundades": "grundad",
    "grundads": "grundad",
    "grundande": "grunda",
    "grundanden": "grundande",
    "grundandena": "grundande",
    "grundandenas": "grundande",
    "grundandens": "grundande",
    "grundandes": "grundande",
    "grundandet": "grundande",
    "grundandets": "grundande",
    "grundar": "grundare",
    "grundarduon": "grundarduo",
    "grundarduons": "grundarduo",
    "grundarduor": "grundarduo",
    "grundarduorna": "grundarduo",
    "grundarduornas": "grundarduo",
    "grundarduors": "grundarduo",
    "grundarduos": "grundarduo",
    "grundarduosen": "grundarduo",
    "grundarduosens": "grundarduo",
    "grundare": "grund",
    "grundaren": "grundare",
    "grundarens": "grundare",
    "grundares": "grundare",
    "grundarna": "grundare",
    "grundarnas": "grundare",
    "grundas": "grunda",
    "grundast": "grund",
    "grundaste": "grund",
    "grundastes": "grund",
    "grundasts": "grund",
    "grundat": "grundad",
    "grundats": "grundad",
    "grundavdragen": "grundavdrag",
    "grundavdragens": "grundavdrag",
    "grundavdraget": "grundavdrag",
    "grundavdragets": "grundavdrag",
    "grundavdrags": "grundavdrag",
    "grundavgiften": "grundavgift",
    "grundavgiftens": "grundavgift",
    "grundavgifter": "grundavgift",
    "grundavgifterna": "grundavgift",
    "grundavgifternas": "grundavgift",
    "grundavgifters": "grundavgift",
    "grundavgifts": "grundavgift",
    "grundbehandlad": "grundbehandla",
    "grundbehandlade": "grundbehandla",
    "grundbehandlades": "grundbehandla",
    "grundbehandlads": "grundbehandla",
    "grundbehandlande": "grundbehandla",
    "grundbehandlanden": "grundbehandlande",
    "grundbehandlandena": "grundbehandlande",
    "grundbehandlandenas": "grundbehandlande",
    "grundbehandlandens": "grundbehandlande",
    "grundbehandlandes": "grundbehandlande",
    "grundbehandlandet": "grundbehandlande",
    "grundbehandlandets": "grundbehandlande",
    "grundbehandlar": "grundbehandla",
    "grundbehandlas": "grundbehandla",
    "grundbehandlat": "grundbehandla",
    "grundbehandlats": "grundbehandla",
    "grundbeloppen": "grundbelopp",
    "grundbeloppens": "grundbelopp",
    "grundbeloppet": "grundbelopp",
    "grundbeloppets": "grundbelopp",
    "grundbelopps": "grundbelopp",
    "grundbetydelsen": "grundbetydelse",
    "grundbetydelsens": "grundbetydelse",
    "grundbetydelser": "grundbetydelse",
    "grundbetydelserna": "grundbetydelse",
    "grundbetydelsernas": "grundbetydelse",
    "grundbetydelsers": "grundbetydelse",
    "grundbetydelses": "grundbetydelse",
    "grundboken": "grundbok",
    "grundbokens": "grundbok",
    "grundboks": "grundbok",
    "grundbrotten": "grundbrott",
    "grundbrottens": "grundbrott",
    "grundbrottet": "grundbrott",
    "grundbrottets": "grundbrott",
    "grundbrotts": "grundbrott",
    "grundbultar": "grundbult",
    "grundbultarna": "grundbult",
    "grundbultarnas": "grundbult",
    "grundbultars": "grundbult",
    "grundbulten": "grundbult",
    "grundbultens": "grundbult",
    "grundbults": "grundbult",
    "grundböcker": "grundbok",
    "grundböckerna": "grundbok",
    "grundböckernas": "grundbok",
    "grundböckers": "grundbok",
    "grunddragen": "grunddrag",
    "grunddragens": "grunddrag",
    "grunddraget": "grunddrag",
    "grunddragets": "grunddrag",
    "grunddrags": "grunddrag",
    "grunde": "grund",
    "grunden": "grund",
    "grundenheten": "grundenhet",
    "grundenhetens": "grundenhet",
    "grundenheter": "grundenhet",
    "grundenheterna": "grundenhet",
    "grundenheternas": "grundenhet",
    "grundenheters": "grundenhet",
    "grundenhets": "grundenhet",
    "grundens": "grund",
    "grunder": "grund",
    "grunderad": "grundera",
    "grunderade": "grundera",
    "grunderades": "grundera",
    "grunderads": "grundera",
    "grunderande": "grundera",
    "grunderanden": "grunderande",
    "grunderandena": "grunderande",
    "grunderandenas": "grunderande",
    "grunderandens": "grunderande",
    "grunderandes": "grunderande",
    "grunderandet": "grunderande",
    "grunderandets": "grunderande",
    "grunderar": "grundera",
    "grunderas": "grundera",
    "grunderat": "grundera",
    "grunderats": "grundera",
    "grunderbara": "grunderbar",
    "grunderbarare": "grunderbar",
    "grunderbarares": "grunderbar",
    "grunderbaras": "grunderbar",
    "grunderbarast": "grunderbar",
    "grunderbaraste": "grunderbar",
    "grunderbarastes": "grunderbar",
    "grunderbarasts": "grunderbar",
    "grunderbare": "grunderbar",
    "grunderbares": "grunderbar",
    "grunderbarheten": "grunderbarhet",
    "grunderbarhetens": "grunderbarhet",
    "grunderbarhets": "grunderbarhet",
    "grunderbars": "grunderbar",
    "grunderbart": "grunderbar",
    "grunderbarts": "grunderbar",
    "grunderingar": "grundering",
    "grunderingarna": "grundering",
    "grunderingarnas": "grundering",
    "grunderingars": "grundering",
    "grunderingen": "grundering",
    "grunderingens": "grundering",
    "grunderings": "grundering",
    "grunderna": "grund",
    "grundernas": "grund",
    "grunders": "grund",
    "grundes": "grund",
    "grundet": "grund",
    "grundets": "grund",
    "grundfalska": "grundfalsk",
    "grundfalskare": "grundfalsk",
    "grundfalskares": "grundfalsk",
    "grundfalskas": "grundfalsk",
    "grundfalskast": "grundfalsk",
    "grundfalskaste": "grundfalsk",
    "grundfalskastes": "grundfalsk",
    "grundfalskasts": "grundfalsk",
    "grundfalske": "grundfalsk",
    "grundfalskes": "grundfalsk",
    "grundfalsks": "grundfalsk",
    "grundfalskt": "grundfalsk",
    "grundfalskts": "grundfalsk",
    "grundformen": "grundform",
    "grundformens": "grundform",
    "grundformer": "grundform",
    "grundformerna": "grundform",
    "grundformernas": "grundform",
    "grundformers": "grundform",
    "grundforms": "grundform",
    "grundforskningar": "grundforskning",
    "grundforskningarna": "grundforskning",
    "grundforskningarnas": "grundforskning",
    "grundforskningars": "grundforskning",
    "grundforskningen": "grundforskning",
    "grundforskningens": "grundforskning",
    "grundforsknings": "grundforskning",
    "grundfärgen": "grundfärg",
    "grundfärgens": "grundfärg",
    "grundfärger": "grundfärg",
    "grundfärgerna": "grundfärg",
    "grundfärgernas": "grundfärg",
    "grundfärgers": "grundfärg",
    "grundfärgs": "grundfärg",
    "grundförbättringar": "grundförbättring",
    "grundförbättringarna": "grundförbättring",
    "grundförbättringarnas": "grundförbättring",
    "grundförbättringars": "grundförbättring",
    "grundförbättringen": "grundförbättring",
    "grundförbättringens": "grundförbättring",
    "grundförbättrings": "grundförbättring",
    "grundförsörjningen": "grundförsörjning",
    "grundförsörjningens": "grundförsörjning",
    "grundförsörjnings": "grundförsörjning",
    "grundhaven": "grundhav",
    "grundhavens": "grundhav",
    "grundhavet": "grundhav",
    "grundhavets": "grundhav",
    "grundhavs": "grundhav",
    "grundheten": "grundhet",
    "grundhetens": "grundhet",
    "grundhets": "grundhet",
    "grundhyr": "grundhyra",
    "grundhyran": "grundhyra",
    "grundhyrans": "grundhyra",
    "grundhyras": "grundhyra",
    "grundhyre": "grundhyra",
    "grundhyror": "grundhyra",
    "grundhyrorna": "grundhyra",
    "grundhyrornas": "grundhyra",
    "grundhyrors": "grundhyra",
    "grundhyrs": "grundhyra",
    "grundkraften": "grundkraft",
    "grundkraftens": "grundkraft",
    "grundkrafter": "grundkraft",
    "grundkrafterna": "grundkraft",
    "grundkrafternas": "grundkraft",
    "grundkrafters": "grundkraft",
    "grundkrafts": "grundkraft",
    "grundkursen": "grundkurs",
    "grundkursens": "grundkurs",
    "grundkurser": "grundkurs",
    "grundkurserna": "grundkurs",
    "grundkursernas": "grundkurs",
    "grundkursers": "grundkurs",
    "grundkänningar": "grundkänning",
    "grundkänningarna": "grundkänning",
    "grundkänningarnas": "grundkänning",
    "grundkänningars": "grundkänning",
    "grundkänningen": "grundkänning",
    "grundkänningens": "grundkänning",
    "grundkännings": "grundkänning",
    "grundla": "grundlägga",
    "grundlade": "grundlägga",
    "grundlades": "grundlägga",
    "grundlagar": "grundlag",
    "grundlagarna": "grundlag",
    "grundlagarnas": "grundlag",
    "grundlagars": "grundlag",
    "grundlagd": "grundlägga",
    "grundlagda": "grundlägga",
    "grundlagdas": "grundlägga",
    "grundlagde": "grundlägga",
    "grundlagdes": "grundlägga",
    "grundlagds": "grundlägga",
    "grundlagen": "grundlag",
    "grundlagens": "grundlag",
    "grundlaget": "grundlag",
    "grundlagets": "grundlag",
    "grundlags": "grundlag",
    "grundlagsmässiga": "grundlagsmässig",
    "grundlagsmässigare": "grundlagsmässig",
    "grundlagsmässigares": "grundlagsmässig",
    "grundlagsmässigas": "grundlagsmässig",
    "grundlagsmässigast": "grundlagsmässig",
    "grundlagsmässigaste": "grundlagsmässig",
    "grundlagsmässigastes": "grundlagsmässig",
    "grundlagsmässigasts": "grundlagsmässig",
    "grundlagsmässige": "grundlagsmässig",
    "grundlagsmässiges": "grundlagsmässig",
    "grundlagsmässigs": "grundlagsmässig",
    "grundlagsmässigt": "grundlagsmässig",
    "grundlagsmässigts": "grundlagsmässig",
    "grundlagsskyddade": "grundlagsskyddad",
    "grundlagsskyddades": "grundlagsskyddad",
    "grundlagsskyddads": "grundlagsskyddad",
    "grundlagsskyddat": "grundlagsskyddad",
    "grundlagsskyddats": "grundlagsskyddad",
    "grundlagt": "grundlägga",
    "grundlagts": "grundlägga",
    "grundlas": "grundlägga",
    "grundliga": "grundlig",
    "grundligare": "grundlig",
    "grundligares": "grundlig",
    "grundligas": "grundlig",
    "grundligast": "grundlig",
    "grundligaste": "grundlig",
    "grundligastes": "grundlig",
    "grundligasts": "grundlig",
    "grundlige": "grundlig",
    "grundliges": "grundlig",
    "grundligheten": "grundlighet",
    "grundlighetens": "grundlighet",
    "grundligheter": "grundlighet",
    "grundligheterna": "grundlighet",
    "grundligheternas": "grundlighet",
    "grundligheters": "grundlighet",
    "grundlighets": "grundlighet",
    "grundligs": "grundlig",
    "grundligt": "grundlig",
    "grundligts": "grundlig",
    "grundlinjen": "grundlinje",
    "grundlinjens": "grundlinje",
    "grundlinjer": "grundlinje",
    "grundlinjerna": "grundlinje",
    "grundlinjernas": "grundlinje",
    "grundlinjers": "grundlinje",
    "grundlinjes": "grundlinje",
    "grundlur": "grundlura",
    "grundlurad": "grundlura",
    "grundlurade": "grundlura",
    "grundlurades": "grundlura",
    "grundlurads": "grundlura",
    "grundlurande": "grundlura",
    "grundluranden": "grundlurande",
    "grundlurandena": "grundlurande",
    "grundlurandenas": "grundlurande",
    "grundlurandens": "grundlurande",
    "grundlurandes": "grundlurande",
    "grundlurandet": "grundlurande",
    "grundlurandets": "grundlurande",
    "grundlurar": "grundlura",
    "grundluras": "grundlura",
    "grundlurat": "grundlura",
    "grundlurats": "grundlura",
    "grundlägg": "grundlägga",
    "grundläggande": "grundlägga",
    "grundlägganden": "grundläggande",
    "grundläggandena": "grundläggande",
    "grundläggandenas": "grundläggande",
    "grundläggandens": "grundläggande",
    "grundläggandes": "grundläggande",
    "grundläggandet": "grundläggande",
    "grundläggandets": "grundläggande",
    "grundläggar": "grundläggare",
    "grundläggaren": "grundläggare",
    "grundläggarens": "grundläggare",
    "grundläggares": "grundläggare",
    "grundläggarna": "grundläggare",
    "grundläggarnas": "grundläggare",
    "grundläggas": "grundlägga",
    "grundlägger": "grundlägga",
    "grundlägges": "grundlägga",
    "grundläggningar": "grundläggning",
    "grundläggningarna": "grundläggning",
    "grundläggningarnas": "grundläggning",
    "grundläggningars": "grundläggning",
    "grundläggningen": "grundläggning",
    "grundläggningens": "grundläggning",
    "grundläggnings": "grundläggning",
    "grundläggs": "grundlägga",
    "grundlönen": "grundlön",
    "grundlönens": "grundlön",
    "grundlöner": "grundlön",
    "grundlönerna": "grundlön",
    "grundlönernas": "grundlön",
    "grundlöners": "grundlön",
    "grundlöns": "grundlön",
    "grundlösa": "grundlös",
    "grundlösare": "grundlös",
    "grundlösares": "grundlös",
    "grundlösas": "grundlös",
    "grundlösast": "grundlös",
    "grundlösaste": "grundlös",
    "grundlösastes": "grundlös",
    "grundlösasts": "grundlös",
    "grundlöse": "grundlös",
    "grundlöses": "grundlös",
    "grundlösheten": "grundlöshet",
    "grundlöshetens": "grundlöshet",
    "grundlöshets": "grundlöshet",
    "grundlöst": "grundlös",
    "grundlösts": "grundlös",
    "grundmurade": "grundmurad",
    "grundmurades": "grundmurad",
    "grundmurads": "grundmurad",
    "grundmurat": "grundmurad",
    "grundmurats": "grundmurad",
    "grundmål": "grundmåla",
    "grundmålad": "grundmåla",
    "grundmålade": "grundmåla",
    "grundmålades": "grundmåla",
    "grundmålads": "grundmåla",
    "grundmålande": "grundmåla",
    "grundmålanden": "grundmålande",
    "grundmålandena": "grundmålande",
    "grundmålandenas": "grundmålande",
    "grundmålandens": "grundmålande",
    "grundmålandes": "grundmålande",
    "grundmålandet": "grundmålande",
    "grundmålandets": "grundmålande",
    "grundmålar": "grundmåla",
    "grundmålas": "grundmåla",
    "grundmålat": "grundmåla",
    "grundmålats": "grundmåla",
    "grundmåtten": "grundmått",
    "grundmåttens": "grundmått",
    "grundmåttet": "grundmått",
    "grundmåttets": "grundmått",
    "grundmåtts": "grundmått",
    "grundningar": "grundning",
    "grundningarna": "grundning",
    "grundningarnas": "grundning",
    "grundningars": "grundning",
    "grundningen": "grundning",
    "grundningens": "grundning",
    "grundnings": "grundning",
    "grundorden": "grundord",
    "grundordens": "grundord",
    "grundordet": "grundord",
    "grundordets": "grundord",
    "grundords": "grundord",
    "grundorsaken": "grundorsak",
    "grundorsakens": "grundorsak",
    "grundorsaker": "grundorsak",
    "grundorsakerna": "grundorsak",
    "grundorsakernas": "grundorsak",
    "grundorsakers": "grundorsak",
    "grundorsaks": "grundorsak",
    "grundpelar": "grundpelare",
    "grundpelaren": "grundpelare",
    "grundpelarens": "grundpelare",
    "grundpelares": "grundpelare",
    "grundpelarna": "grundpelare",
    "grundpelarnas": "grundpelare",
    "grundperioden": "grundperiod",
    "grundperiodens": "grundperiod",
    "grundperioder": "grundperiod",
    "grundperioderna": "grundperiod",
    "grundperiodernas": "grundperiod",
    "grundperioders": "grundperiod",
    "grundperiods": "grundperiod",
    "grundplåtar": "grundplåt",
    "grundplåtarna": "grundplåt",
    "grundplåtarnas": "grundplåt",
    "grundplåtars": "grundplåt",
    "grundplåten": "grundplåt",
    "grundplåtens": "grundplåt",
    "grundplåts": "grundplåt",
    "grunds": "grund",
    "grundsatsen": "grundsats",
    "grundsatsens": "grundsats",
    "grundsatser": "grundsats",
    "grundsatserna": "grundsats",
    "grundsatsernas": "grundsats",
    "grundsatsers": "grundsats",
    "grundskolan": "grundskola",
    "grundskolans": "grundskola",
    "grundskolas": "grundskola",
    "grundskole": "grundskola",
    "grundskolebarnen": "grundskolebarn",
    "grundskolebarnens": "grundskolebarn",
    "grundskolebarnet": "grundskolebarn",
    "grundskolebarnets": "grundskolebarn",
    "grundskolebarns": "grundskolebarn",
    "grundskolelärar": "grundskolelärare",
    "grundskoleläraren": "grundskolelärare",
    "grundskolelärarens": "grundskolelärare",
    "grundskolelärares": "grundskolelärare",
    "grundskolelärarna": "grundskolelärare",
    "grundskolelärarnas": "grundskolelärare",
    "grundskolor": "grundskola",
    "grundskolorna": "grundskola",
    "grundskolornas": "grundskola",
    "grundskolors": "grundskola",
    "grundskotten": "grundskott",
    "grundskottens": "grundskott",
    "grundskottet": "grundskott",
    "grundskottets": "grundskott",
    "grundskotts": "grundskott",
    "grundspråken": "grundspråk",
    "grundspråkens": "grundspråk",
    "grundspråket": "grundspråk",
    "grundspråkets": "grundspråk",
    "grundspråks": "grundspråk",
    "grundstammar": "grundstam",
    "grundstammarna": "grundstam",
    "grundstammarnas": "grundstam",
    "grundstammars": "grundstam",
    "grundstammen": "grundstam",
    "grundstammens": "grundstam",
    "grundstams": "grundstam",
    "grundstenar": "grundsten",
    "grundstenarna": "grundsten",
    "grundstenarnas": "grundsten",
    "grundstenars": "grundsten",
    "grundstenen": "grundsten",
    "grundstenens": "grundsten",
    "grundstens": "grundsten",
    "grundstöt": "grundstöta",
    "grundstötande": "grundstöta",
    "grundstötanden": "grundstötande",
    "grundstötandena": "grundstötande",
    "grundstötandenas": "grundstötande",
    "grundstötandens": "grundstötande",
    "grundstötandes": "grundstötande",
    "grundstötandet": "grundstötande",
    "grundstötandets": "grundstötande",
    "grundstötas": "grundstöta",
    "grundstöter": "grundstöta",
    "grundstötes": "grundstöta",
    "grundstötningar": "grundstötning",
    "grundstötningarna": "grundstötning",
    "grundstötningarnas": "grundstötning",
    "grundstötningars": "grundstötning",
    "grundstötningen": "grundstötning",
    "grundstötningens": "grundstötning",
    "grundstötnings": "grundstötning",
    "grundstöts": "grundstöta",
    "grundstött": "grundstöta",
    "grundstötta": "grundstöta",
    "grundstöttas": "grundstöta",
    "grundstötte": "grundstöta",
    "grundstöttes": "grundstöta",
    "grundstötts": "grundstöta",
    "grundsynen": "grundsyn",
    "grundsynens": "grundsyn",
    "grundsyns": "grundsyn",
    "grundsärskolan": "grundsärskola",
    "grundsärskolans": "grundsärskola",
    "grundsärskolas": "grundsärskola",
    "grundsärskole": "grundsärskola",
    "grundsärskolor": "grundsärskola",
    "grundsärskolorna": "grundsärskola",
    "grundsärskolornas": "grundsärskola",
    "grundsärskolors": "grundsärskola",
    "grundtalen": "grundtal",
    "grundtalens": "grundtal",
    "grundtalet": "grundtal",
    "grundtalets": "grundtal",
    "grundtals": "grundtal",
    "grundtank": "grundtanke",
    "grundtankar": "grundtanke",
    "grundtankarna": "grundtanke",
    "grundtankarnas": "grundtanke",
    "grundtankars": "grundtanke",
    "grundtanken": "grundtanke",
    "grundtankens": "grundtanke",
    "grundtankes": "grundtanke",
    "grundtanks": "grundtanke",
    "grundteorien": "grundteori",
    "grundteoriens": "grundteori",
    "grundteorier": "grundteori",
    "grundteorierna": "grundteori",
    "grundteoriernas": "grundteori",
    "grundteoriers": "grundteori",
    "grundteorin": "grundteori",
    "grundteorins": "grundteori",
    "grundteoris": "grundteori",
    "grundtesen": "grundtes",
    "grundtesens": "grundtes",
    "grundteser": "grundtes",
    "grundteserna": "grundtes",
    "grundtesernas": "grundtes",
    "grundtesers": "grundtes",
    "grundtillstånden": "grundtillstånd",
    "grundtillståndens": "grundtillstånd",
    "grundtillståndet": "grundtillstånd",
    "grundtillståndets": "grundtillstånd",
    "grundtillstånds": "grundtillstånd",
    "grundtonen": "grundton",
    "grundtonens": "grundton",
    "grundtoner": "grundton",
    "grundtonerna": "grundton",
    "grundtonernas": "grundton",
    "grundtoners": "grundton",
    "grundtons": "grundton",
    "grundutbildningar": "grundutbildning",
    "grundutbildningarna": "grundutbildning",
    "grundutbildningarnas": "grundutbildning",
    "grundutbildningars": "grundutbildning",
    "grundutbildningen": "grundutbildning",
    "grundutbildningens": "grundutbildning",
    "grundutbildnings": "grundutbildning",
    "grundvalar": "grundval",
    "grundvalarna": "grundval",
    "grundvalarnas": "grundval",
    "grundvalars": "grundval",
    "grundvalen": "grundval",
    "grundvalens": "grundval",
    "grundvals": "grundval",
    "grundvattens": "grundvatten",
    "grundvattnen": "grundvatten",
    "grundvattnens": "grundvatten",
    "grundvattnet": "grundvatten",
    "grundvattnets": "grundvatten",
    "grundämnen": "grundämne",
    "grundämnena": "grundämne",
    "grundämnenas": "grundämne",
    "grundämnens": "grundämne",
    "grundämnes": "grundämne",
    "grundämnet": "grundämne",
    "grundämnets": "grundämne",
    "grungen": "grunge",
    "grungens": "grunge",
    "grunges": "grunge",
    "grunk": "grunka",
    "grunkan": "grunka",
    "grunkans": "grunka",
    "grunkas": "grunka",
    "grunke": "grunka",
    "grunkor": "grunka",
    "grunkorna": "grunka",
    "grunkornas": "grunka",
    "grunkors": "grunka",
    "grunks": "grunka",
    "grunn": "grunna",
    "grunnade": "grunna",
    "grunnades": "grunna",
    "grunnande": "grunna",
    "grunnanden": "grunnande",
    "grunnandena": "grunnande",
    "grunnandenas": "grunnande",
    "grunnandens": "grunnande",
    "grunnandes": "grunnande",
    "grunnandet": "grunnande",
    "grunnandets": "grunnande",
    "grunnar": "grunna",
    "grunnas": "grunna",
    "grunnat": "grunna",
    "grunnats": "grunna",
    "grunt": "grund",
    "grunts": "grund",
    "grupparbeten": "grupparbete",
    "grupparbetena": "grupparbete",
    "grupparbetenas": "grupparbete",
    "grupparbetens": "grupparbete",
    "grupparbetes": "grupparbete",
    "grupparbetet": "grupparbete",
    "grupparbetets": "grupparbete",
    "grupparbets": "grupparbete",
    "gruppbilden": "gruppbild",
    "gruppbildens": "gruppbild",
    "gruppbilder": "gruppbild",
    "gruppbilderna": "gruppbild",
    "gruppbildernas": "gruppbild",
    "gruppbilders": "gruppbild",
    "gruppbilds": "gruppbild",
    "gruppchefen": "gruppchef",
    "gruppchefens": "gruppchef",
    "gruppchefer": "gruppchef",
    "gruppcheferna": "gruppchef",
    "gruppchefernas": "gruppchef",
    "gruppchefers": "gruppchef",
    "gruppchefs": "gruppchef",
    "gruppdynamiken": "gruppdynamik",
    "gruppdynamikens": "gruppdynamik",
    "gruppdynamiks": "gruppdynamik",
    "gruppdynamiska": "gruppdynamisk",
    "gruppdynamiskare": "gruppdynamisk",
    "gruppdynamiskares": "gruppdynamisk",
    "gruppdynamiskas": "gruppdynamisk",
    "gruppdynamiskast": "gruppdynamisk",
    "gruppdynamiskaste": "gruppdynamisk",
    "gruppdynamiskastes": "gruppdynamisk",
    "gruppdynamiskasts": "gruppdynamisk",
    "gruppdynamiske": "gruppdynamisk",
    "gruppdynamiskes": "gruppdynamisk",
    "gruppdynamisks": "gruppdynamisk",
    "gruppdynamiskt": "gruppdynamisk",
    "gruppdynamiskts": "gruppdynamisk",
    "gruppen": "grupp",
    "gruppens": "grupp",
    "grupper": "grupp",
    "grupperad": "gruppera",
    "grupperade": "gruppera",
    "grupperades": "gruppera",
    "grupperads": "gruppera",
    "grupperande": "gruppera",
    "grupperanden": "grupperande",
    "grupperandena": "grupperande",
    "grupperandenas": "grupperande",
    "grupperandens": "grupperande",
    "grupperandes": "grupperande",
    "grupperandet": "grupperande",
    "grupperandets": "grupperande",
    "grupperar": "gruppera",
    "grupperas": "gruppera",
    "grupperat": "gruppera",
    "grupperats": "gruppera",
    "grupperbara": "grupperbar",
    "grupperbarare": "grupperbar",
    "grupperbarares": "grupperbar",
    "grupperbaras": "grupperbar",
    "grupperbarast": "grupperbar",
    "grupperbaraste": "grupperbar",
    "grupperbarastes": "grupperbar",
    "grupperbarasts": "grupperbar",
    "grupperbare": "grupperbar",
    "grupperbares": "grupperbar",
    "grupperbarheten": "grupperbarhet",
    "grupperbarhetens": "grupperbarhet",
    "grupperbarhets": "grupperbarhet",
    "grupperbars": "grupperbar",
    "grupperbart": "grupperbar",
    "grupperbarts": "grupperbar",
    "grupperingar": "gruppering",
    "grupperingarna": "gruppering",
    "grupperingarnas": "gruppering",
    "grupperingars": "gruppering",
    "grupperingen": "gruppering",
    "grupperingens": "gruppering",
    "grupperings": "gruppering",
    "grupperna": "grupp",
    "gruppernas": "grupp",
    "gruppers": "grupp",
    "gruppförsäkringar": "gruppförsäkring",
    "gruppförsäkringarna": "gruppförsäkring",
    "gruppförsäkringarnas": "gruppförsäkring",
    "gruppförsäkringars": "gruppförsäkring",
    "gruppförsäkringen": "gruppförsäkring",
    "gruppförsäkringens": "gruppförsäkring",
    "gruppförsäkrings": "gruppförsäkring",
    "gruppgenitiven": "gruppgenitiv",
    "gruppgenitivens": "gruppgenitiv",
    "gruppgenitiver": "gruppgenitiv",
    "gruppgenitiverna": "gruppgenitiv",
    "gruppgenitivernas": "gruppgenitiv",
    "gruppgenitivers": "gruppgenitiv",
    "gruppgenitivs": "gruppgenitiv",
    "grupphusen": "grupphus",
    "grupphusens": "grupphus",
    "grupphuset": "grupphus",
    "grupphusets": "grupphus",
    "gruppkorsbanden": "gruppkorsband",
    "gruppkorsbandens": "gruppkorsband",
    "gruppkorsbandet": "gruppkorsband",
    "gruppkorsbandets": "gruppkorsband",
    "gruppkorsbands": "gruppkorsband",
    "gruppresan": "gruppresa",
    "gruppresans": "gruppresa",
    "gruppresas": "gruppresa",
    "grupprese": "gruppresa",
    "gruppresor": "gruppresa",
    "gruppresorna": "gruppresa",
    "gruppresornas": "gruppresa",
    "gruppresors": "gruppresa",
    "grupps": "grupp",
    "gruppsamtalen": "gruppsamtal",
    "gruppsamtalens": "gruppsamtal",
    "gruppsamtalet": "gruppsamtal",
    "gruppsamtalets": "gruppsamtal",
    "gruppsamtals": "gruppsamtal",
    "gruppsexet": "gruppsex",
    "gruppsexets": "gruppsex",
    "gruppsmörjningar": "gruppsmörjning",
    "gruppsmörjningarna": "gruppsmörjning",
    "gruppsmörjningarnas": "gruppsmörjning",
    "gruppsmörjningars": "gruppsmörjning",
    "gruppsmörjningen": "gruppsmörjning",
    "gruppsmörjningens": "gruppsmörjning",
    "gruppsmörjnings": "gruppsmörjning",
    "gruppsykologien": "gruppsykologi",
    "gruppsykologiens": "gruppsykologi",
    "gruppsykologin": "gruppsykologi",
    "gruppsykologins": "gruppsykologi",
    "gruppsykologis": "gruppsykologi",
    "gruppsådd": "gruppså",
    "gruppsådda": "gruppså",
    "gruppsåddas": "gruppså",
    "gruppsådde": "gruppså",
    "gruppsåddes": "gruppså",
    "gruppsådds": "gruppså",
    "gruppsående": "gruppså",
    "gruppsåenden": "gruppsående",
    "gruppsåendena": "gruppsående",
    "gruppsåendenas": "gruppsående",
    "gruppsåendens": "gruppsående",
    "gruppsåendes": "gruppsående",
    "gruppsåendet": "gruppsående",
    "gruppsåendets": "gruppsående",
    "gruppsår": "gruppså",
    "gruppsås": "gruppså",
    "gruppsått": "gruppså",
    "gruppsåtts": "gruppså",
    "grupptalans": "grupptalan",
    "gruppterapien": "gruppterapi",
    "gruppterapiens": "gruppterapi",
    "gruppterapier": "gruppterapi",
    "gruppterapierna": "gruppterapi",
    "gruppterapiernas": "gruppterapi",
    "gruppterapiers": "gruppterapi",
    "gruppterapin": "gruppterapi",
    "gruppterapins": "gruppterapi",
    "gruppterapis": "gruppterapi",
    "grupptesten": "grupptest",
    "grupptestens": "grupptest",
    "grupptester": "grupptest",
    "grupptesterna": "grupptest",
    "grupptesternas": "grupptest",
    "grupptesters": "grupptest",
    "grupptestet": "grupptest",
    "grupptestets": "grupptest",
    "grupptests": "grupptest",
    "grupptillhörigheten": "grupptillhörighet",
    "grupptillhörighetens": "grupptillhörighet",
    "grupptillhörighets": "grupptillhörighet",
    "grupptrycket": "grupptryck",
    "grupptryckets": "grupptryck",
    "grupptrycks": "grupptryck",
    "grus": "grusa",
    "grusad": "grusa",
    "grusade": "grusa",
    "grusades": "grusa",
    "grusads": "grusa",
    "grusande": "grusa",
    "grusanden": "grusande",
    "grusandena": "grusande",
    "grusandenas": "grusande",
    "grusandens": "grusande",
    "grusandes": "grusande",
    "grusandet": "grusande",
    "grusandets": "grusande",
    "grusar": "grusa",
    "grusas": "grusa",
    "grusat": "grusa",
    "grusats": "grusa",
    "gruset": "grus",
    "grusets": "grus",
    "grusgropar": "grusgrop",
    "grusgroparna": "grusgrop",
    "grusgroparnas": "grusgrop",
    "grusgropars": "grusgrop",
    "grusgropen": "grusgrop",
    "grusgropens": "grusgrop",
    "grusgrops": "grusgrop",
    "grusgångar": "grusgång",
    "grusgångarna": "grusgång",
    "grusgångarnas": "grusgång",
    "grusgångars": "grusgång",
    "grusgången": "grusgång",
    "grusgångens": "grusgång",
    "grusgångs": "grusgång",
    "grusiga": "grusig",
    "grusigare": "grusig",
    "grusigares": "grusig",
    "grusigas": "grusig",
    "grusigast": "grusig",
    "grusigaste": "grusig",
    "grusigastes": "grusig",
    "grusigasts": "grusig",
    "grusige": "grusig",
    "grusiges": "grusig",
    "grusigs": "grusig",
    "grusigt": "grusig",
    "grusigts": "grusig",
    "grusplanen": "grusplan",
    "grusplanens": "grusplan",
    "grusplaner": "grusplan",
    "grusplanerna": "grusplan",
    "grusplanernas": "grusplan",
    "grusplaners": "grusplan",
    "grusplans": "grusplan",
    "grustagen": "grustag",
    "grustagens": "grustag",
    "grustaget": "grustag",
    "grustagets": "grustag",
    "grustags": "grustag",
    "grustäkten": "grustäkt",
    "grustäktens": "grustäkt",
    "grustäkter": "grustäkt",
    "grustäkterna": "grustäkt",
    "grustäkternas": "grustäkt",
    "grustäkters": "grustäkt",
    "grustäkts": "grustäkt",
    "grusvägar": "grusväg",
    "grusvägarna": "grusväg",
    "grusvägarnas": "grusväg",
    "grusvägars": "grusväg",
    "grusvägen": "grusväg",
    "grusvägens": "grusväg",
    "grusvägs": "grusväg",
    "gruv": "gruva",
    "gruvan": "gruva",
    "gruvans": "gruva",
    "gruvarbetar": "gruvarbetare",
    "gruvarbetardottern": "gruvarbetardotter",
    "gruvarbetardotterns": "gruvarbetardotter",
    "gruvarbetardotters": "gruvarbetardotter",
    "gruvarbetardöttrar": "gruvarbetardotter",
    "gruvarbetardöttrarna": "gruvarbetardotter",
    "gruvarbetardöttrarnas": "gruvarbetardotter",
    "gruvarbetardöttrars": "gruvarbetardotter",
    "gruvarbetaren": "gruvarbetare",
    "gruvarbetarens": "gruvarbetare",
    "gruvarbetares": "gruvarbetare",
    "gruvarbetarna": "gruvarbetare",
    "gruvarbetarnas": "gruvarbetare",
    "gruvarbetarstöveln": "gruvarbetarstövel",
    "gruvarbetarstövelns": "gruvarbetarstövel",
    "gruvarbetarstövels": "gruvarbetarstövel",
    "gruvarbetarstövlar": "gruvarbetarstövel",
    "gruvarbetarstövlarna": "gruvarbetarstövel",
    "gruvarbetarstövlarnas": "gruvarbetarstövel",
    "gruvarbetarstövlars": "gruvarbetarstövel",
    "gruvas": "gruva",
    "gruvbolagen": "gruvbolag",
    "gruvbolagens": "gruvbolag",
    "gruvbolaget": "gruvbolag",
    "gruvbolagets": "gruvbolag",
    "gruvbolags": "gruvbolag",
    "gruvbrytningar": "gruvbrytning",
    "gruvbrytningarna": "gruvbrytning",
    "gruvbrytningarnas": "gruvbrytning",
    "gruvbrytningars": "gruvbrytning",
    "gruvbrytningen": "gruvbrytning",
    "gruvbrytningens": "gruvbrytning",
    "gruvbrytnings": "gruvbrytning",
    "gruvdraman": "gruvdrama",
    "gruvdramana": "gruvdrama",
    "gruvdramanas": "gruvdrama",
    "gruvdramans": "gruvdrama",
    "gruvdramas": "gruvdrama",
    "gruvdramat": "gruvdrama",
    "gruvdramats": "gruvdrama",
    "gruvdramer": "gruvdrama",
    "gruvdramerna": "gruvdrama",
    "gruvdramernas": "gruvdrama",
    "gruvdramers": "gruvdrama",
    "gruvdriften": "gruvdrift",
    "gruvdriftens": "gruvdrift",
    "gruvdrifter": "gruvdrift",
    "gruvdrifterna": "gruvdrift",
    "gruvdrifternas": "gruvdrift",
    "gruvdrifters": "gruvdrift",
    "gruvdrifts": "gruvdrift",
    "gruve": "gruva",
    "gruvexplosionen": "gruvexplosion",
    "gruvexplosionens": "gruvexplosion",
    "gruvexplosioner": "gruvexplosion",
    "gruvexplosionerna": "gruvexplosion",
    "gruvexplosionernas": "gruvexplosion",
    "gruvexplosioners": "gruvexplosion",
    "gruvexplosions": "gruvexplosion",
    "gruvfogd": "gruvfogde",
    "gruvfogdar": "gruvfogde",
    "gruvfogdarna": "gruvfogde",
    "gruvfogdarnas": "gruvfogde",
    "gruvfogdars": "gruvfogde",
    "gruvfogden": "gruvfogde",
    "gruvfogdens": "gruvfogde",
    "gruvfogdes": "gruvfogde",
    "gruvfogds": "gruvfogde",
    "gruvfälten": "gruvfält",
    "gruvfältens": "gruvfält",
    "gruvfältet": "gruvfält",
    "gruvfältets": "gruvfält",
    "gruvfälts": "gruvfält",
    "gruvgasen": "gruvgas",
    "gruvgasens": "gruvgas",
    "gruvgångar": "gruvgång",
    "gruvgångarna": "gruvgång",
    "gruvgångarnas": "gruvgång",
    "gruvgångars": "gruvgång",
    "gruvgången": "gruvgång",
    "gruvgångens": "gruvgång",
    "gruvgångs": "gruvgång",
    "gruvhundar": "gruvhund",
    "gruvhundarna": "gruvhund",
    "gruvhundarnas": "gruvhund",
    "gruvhundars": "gruvhund",
    "gruvhunden": "gruvhund",
    "gruvhundens": "gruvhund",
    "gruvhunds": "gruvhund",
    "gruvhålen": "gruvhål",
    "gruvhålens": "gruvhål",
    "gruvhålet": "gruvhål",
    "gruvhålets": "gruvhål",
    "gruvhåls": "gruvhål",
    "gruvkompassen": "gruvkompass",
    "gruvkompassens": "gruvkompass",
    "gruvkompasser": "gruvkompass",
    "gruvkompasserna": "gruvkompass",
    "gruvkompassernas": "gruvkompass",
    "gruvkompassers": "gruvkompass",
    "gruvlav": "gruvlave",
    "gruvlavar": "gruvlave",
    "gruvlavarna": "gruvlave",
    "gruvlavarnas": "gruvlave",
    "gruvlavars": "gruvlave",
    "gruvlaven": "gruvlave",
    "gruvlavens": "gruvlave",
    "gruvlaves": "gruvlave",
    "gruvlavs": "gruvlave",
    "gruvliga": "gruvlig",
    "gruvligare": "gruvlig",
    "gruvligares": "gruvlig",
    "gruvligas": "gruvlig",
    "gruvligast": "gruvlig",
    "gruvligaste": "gruvlig",
    "gruvligastes": "gruvlig",
    "gruvligasts": "gruvlig",
    "gruvlige": "gruvlig",
    "gruvliges": "gruvlig",
    "gruvligheten": "gruvlighet",
    "gruvlighetens": "gruvlighet",
    "gruvligheter": "gruvlighet",
    "gruvligheterna": "gruvlighet",
    "gruvligheternas": "gruvlighet",
    "gruvligheters": "gruvlighet",
    "gruvlighets": "gruvlighet",
    "gruvligs": "gruvlig",
    "gruvligt": "gruvlig",
    "gruvligts": "gruvlig",
    "gruvoffers": "gruvoffer",
    "gruvoffren": "gruvoffer",
    "gruvoffrens": "gruvoffer",
    "gruvoffret": "gruvoffer",
    "gruvoffrets": "gruvoffer",
    "gruvolyck": "gruvolycka",
    "gruvolyckan": "gruvolycka",
    "gruvolyckans": "gruvolycka",
    "gruvolyckas": "gruvolycka",
    "gruvolycke": "gruvolycka",
    "gruvolyckor": "gruvolycka",
    "gruvolyckorna": "gruvolycka",
    "gruvolyckornas": "gruvolycka",
    "gruvolyckors": "gruvolycka",
    "gruvolycks": "gruvolycka",
    "gruvor": "gruva",
    "gruvorna": "gruva",
    "gruvornas": "gruva",
    "gruvors": "gruva",
    "gruvrasen": "gruvras",
    "gruvrasens": "gruvras",
    "gruvraset": "gruvras",
    "gruvrasets": "gruvras",
    "gruvrået": "gruvrå",
    "gruvråets": "gruvrå",
    "gruvrån": "gruvrå",
    "gruvråna": "gruvrå",
    "gruvrånas": "gruvrå",
    "gruvråns": "gruvrå",
    "gruvrår": "gruvrå",
    "gruvrårna": "gruvrå",
    "gruvrårnas": "gruvrå",
    "gruvrårs": "gruvrå",
    "gruvrås": "gruvrå",
    "gruvråt": "gruvrå",
    "gruvråts": "gruvrå",
    "gruvs": "gruva",
    "gruvsamheten": "gruvsamhet",
    "gruvsamhetens": "gruvsamhet",
    "gruvsamhets": "gruvsamhet",
    "gruvsamma": "gruvsam",
    "gruvsammare": "gruvsam",
    "gruvsammares": "gruvsam",
    "gruvsammas": "gruvsam",
    "gruvsammast": "gruvsam",
    "gruvsammaste": "gruvsam",
    "gruvsammastes": "gruvsam",
    "gruvsammasts": "gruvsam",
    "gruvsamme": "gruvsam",
    "gruvsammes": "gruvsam",
    "gruvsams": "gruvsam",
    "gruvsamt": "gruvsam",
    "gruvsamts": "gruvsam",
    "gruvschakten": "gruvschakt",
    "gruvschaktens": "gruvschakt",
    "gruvschaktet": "gruvschakt",
    "gruvschaktets": "gruvschakt",
    "gruvschakts": "gruvschakt",
    "gruvstigar": "gruvstigare",
    "gruvstigaren": "gruvstigare",
    "gruvstigarens": "gruvstigare",
    "gruvstigares": "gruvstigare",
    "gruvstigarna": "gruvstigare",
    "gruvstigarnas": "gruvstigare",
    "gruvstrejken": "gruvstrejk",
    "gruvstrejkens": "gruvstrejk",
    "gruvstrejker": "gruvstrejk",
    "gruvstrejkerna": "gruvstrejk",
    "gruvstrejkernas": "gruvstrejk",
    "gruvstrejkers": "gruvstrejk",
    "gruvstrejks": "gruvstrejk",
    "gruvstöttan": "gruvstötta",
    "gruvstöttans": "gruvstötta",
    "gruvstöttas": "gruvstötta",
    "gruvstötte": "gruvstötta",
    "gruvstöttor": "gruvstötta",
    "gruvstöttorna": "gruvstötta",
    "gruvstöttornas": "gruvstötta",
    "gruvstöttors": "gruvstötta",
    "gruvöppningar": "gruvöppning",
    "gruvöppningarna": "gruvöppning",
    "gruvöppningarnas": "gruvöppning",
    "gruvöppningars": "gruvöppning",
    "gruvöppningen": "gruvöppning",
    "gruvöppningens": "gruvöppning",
    "gruvöppnings": "gruvöppning",
    "gruyeren": "gruyere",
    "gruyerens": "gruyere",
    "gruyeres": "gruyere",
    "grydd": "gry",
    "grydda": "gry",
    "gryddas": "gry",
    "grydde": "gry",
    "gryddes": "gry",
    "grydds": "gry",
    "gryende": "gry",
    "gryenden": "gryende",
    "gryendena": "gryende",
    "gryendenas": "gryende",
    "gryendens": "gryende",
    "gryendes": "gryende",
    "gryendet": "gryende",
    "gryendets": "gryende",
    "gryet": "gry",
    "gryets": "gry",
    "grymheten": "grymhet",
    "grymhetens": "grymhet",
    "grymheter": "grymhet",
    "grymheterna": "grymhet",
    "grymheternas": "grymhet",
    "grymheters": "grymhet",
    "grymhets": "grymhet",
    "grymma": "grym",
    "grymmare": "grym",
    "grymmares": "grym",
    "grymmas": "grym",
    "grymmast": "grym",
    "grymmaste": "grym",
    "grymmastes": "grym",
    "grymmasts": "grym",
    "grymme": "grym",
    "grymmes": "grym",
    "gryms": "grym",
    "grymt": "grym",
    "grymtade": "grymta",
    "grymtades": "grymta",
    "grymtande": "grymta",
    "grymtanden": "grymtande",
    "grymtandena": "grymtande",
    "grymtandenas": "grymtande",
    "grymtandens": "grymtande",
    "grymtandes": "grymtande",
    "grymtandet": "grymtande",
    "grymtandets": "grymtande",
    "grymtar": "grymta",
    "grymtas": "grymta",
    "grymtat": "grymta",
    "grymtats": "grymta",
    "grymtet": "grymt",
    "grymtets": "grymt",
    "grymthastigheten": "grymthastighet",
    "grymthastighetens": "grymthastighet",
    "grymthastigheter": "grymthastighet",
    "grymthastigheterna": "grymthastighet",
    "grymthastigheternas": "grymthastighet",
    "grymthastigheters": "grymthastighet",
    "grymthastighets": "grymthastighet",
    "grymtningar": "grymtning",
    "grymtningarna": "grymtning",
    "grymtningarnas": "grymtning",
    "grymtningars": "grymtning",
    "grymtningen": "grymtning",
    "grymtningens": "grymtning",
    "grymtnings": "grymtning",
    "grymtox": "grymtoxe",
    "grymtoxar": "grymtoxe",
    "grymtoxarna": "grymtoxe",
    "grymtoxarnas": "grymtoxe",
    "grymtoxars": "grymtoxe",
    "grymtoxen": "grymtoxe",
    "grymtoxens": "grymtoxe",
    "grymtoxes": "grymtoxe",
    "grymts": "grymt",
    "grynade": "gryna",
    "grynades": "gryna",
    "grynande": "gryna",
    "grynanden": "grynande",
    "grynandena": "grynande",
    "grynandenas": "grynande",
    "grynandens": "grynande",
    "grynandes": "grynande",
    "grynandet": "grynande",
    "grynandets": "grynande",
    "grynar": "gryna",
    "grynas": "gryna",
    "grynat": "gryna",
    "grynats": "gryna",
    "grynen": "gryn",
    "grynens": "gryn",
    "gryner": "gryn",
    "grynerna": "gryn",
    "grynernas": "gryn",
    "gryners": "gryn",
    "grynes": "gryne",
    "grynet": "gryne",
    "grynets": "gryne",
    "gryniga": "grynig",
    "grynigare": "grynig",
    "grynigares": "grynig",
    "grynigas": "grynig",
    "grynigast": "grynig",
    "grynigaste": "grynig",
    "grynigastes": "grynig",
    "grynigasts": "grynig",
    "grynige": "grynig",
    "gryniges": "grynig",
    "grynigs": "grynig",
    "grynigt": "grynig",
    "grynigts": "grynig",
    "gryningar": "gryning",
    "gryningarna": "gryning",
    "gryningarnas": "gryning",
    "gryningars": "gryning",
    "gryningen": "gryning",
    "gryningens": "gryning",
    "grynings": "gryning",
    "gryningstim": "gryningstimme",
    "gryningstimmar": "gryningstimme",
    "gryningstimmarna": "gryningstimme",
    "gryningstimmarnas": "gryningstimme",
    "gryningstimmars": "gryningstimme",
    "gryningstimmen": "gryningstimme",
    "gryningstimmens": "gryningstimme",
    "gryningstimmes": "gryningstimme",
    "gryningstims": "gryningstimme",
    "grynkorvar": "grynkorv",
    "grynkorvarna": "grynkorv",
    "grynkorvarnas": "grynkorv",
    "grynkorvars": "grynkorv",
    "grynkorven": "grynkorv",
    "grynkorvens": "grynkorv",
    "grynkorvs": "grynkorv",
    "grynn": "grynna",
    "grynnan": "grynna",
    "grynnans": "grynna",
    "grynnas": "grynna",
    "grynne": "grynna",
    "grynnor": "grynna",
    "grynnorna": "grynna",
    "grynnornas": "grynna",
    "grynnors": "grynna",
    "grynns": "grynna",
    "grynpipiga": "grynpipig",
    "grynpipigare": "grynpipig",
    "grynpipigares": "grynpipig",
    "grynpipigas": "grynpipig",
    "grynpipigast": "grynpipig",
    "grynpipigaste": "grynpipig",
    "grynpipigastes": "grynpipig",
    "grynpipigasts": "grynpipig",
    "grynpipige": "grynpipig",
    "grynpipiges": "grynpipig",
    "grynpipigs": "grynpipig",
    "grynpipigt": "grynpipig",
    "grynpipigts": "grynpipig",
    "gryns": "gryn",
    "grynvällingar": "grynvälling",
    "grynvällingarna": "grynvälling",
    "grynvällingarnas": "grynvälling",
    "grynvällingars": "grynvälling",
    "grynvällingen": "grynvälling",
    "grynvällingens": "grynvälling",
    "grynvällings": "grynvälling",
    "gryr": "gry",
    "grys": "gry",
    "gryt": "gryta",
    "grytan": "gryta",
    "grytans": "gryta",
    "grytas": "gryta",
    "grytbitarna": "grytbitar",
    "grytbitarnas": "grytbitar",
    "grytbitars": "grytbitar",
    "grytbits": "grytbitar",
    "gryte": "gryta",
    "gryten": "gryt",
    "grytens": "gryt",
    "grytet": "gryt",
    "grytets": "gryt",
    "grytfoten": "grytfot",
    "grytfotens": "grytfot",
    "grytfots": "grytfot",
    "grythundar": "grythund",
    "grythundarna": "grythund",
    "grythundarnas": "grythund",
    "grythundars": "grythund",
    "grythunden": "grythund",
    "grythundens": "grythund",
    "grythunds": "grythund",
    "grytlappar": "grytlapp",
    "grytlapparna": "grytlapp",
    "grytlapparnas": "grytlapp",
    "grytlappars": "grytlapp",
    "grytlappen": "grytlapp",
    "grytlappens": "grytlapp",
    "grytlapps": "grytlapp",
    "grytor": "gryta",
    "grytorna": "gryta",
    "grytornas": "gryta",
    "grytors": "gryta",
    "gryts": "gryta",
    "grytskåpen": "grytskåp",
    "grytskåpens": "grytskåp",
    "grytskåpet": "grytskåp",
    "grytskåpets": "grytskåp",
    "grytskåps": "grytskåp",
    "grytstekar": "grytstek",
    "grytstekarna": "grytstek",
    "grytstekarnas": "grytstek",
    "grytstekars": "grytstek",
    "grytsteken": "grytstek",
    "grytstekens": "grytstek",
    "grytsteks": "grytstek",
    "grytt": "gry",
    "grytts": "gry",
    "grytvant": "grytvante",
    "grytvantar": "grytvante",
    "grytvantarna": "grytvante",
    "grytvantarnas": "grytvante",
    "grytvantars": "grytvante",
    "grytvanten": "grytvante",
    "grytvantens": "grytvante",
    "grytvantes": "grytvante",
    "grytvants": "grytvante",
    "gräbb": "gräbba",
    "gräbban": "gräbba",
    "gräbbans": "gräbba",
    "gräbbas": "gräbba",
    "gräbbe": "gräbba",
    "gräbbor": "gräbba",
    "gräbborna": "gräbba",
    "gräbbornas": "gräbba",
    "gräbbors": "gräbba",
    "gräbbs": "gräbba",
    "grädd": "grädde",
    "grädda": "grädde",
    "gräddad": "grädda",
    "gräddade": "grädda",
    "gräddades": "grädda",
    "gräddads": "grädda",
    "gräddan": "grädda",
    "gräddande": "grädda",
    "gräddanden": "gräddande",
    "gräddandena": "gräddande",
    "gräddandenas": "gräddande",
    "gräddandens": "gräddande",
    "gräddandes": "gräddande",
    "gräddandet": "gräddande",
    "gräddandets": "gräddande",
    "gräddans": "grädda",
    "gräddar": "grädda",
    "gräddas": "grädda",
    "gräddat": "grädda",
    "gräddats": "grädda",
    "gräddbakelsen": "gräddbakelse",
    "gräddbakelsens": "gräddbakelse",
    "gräddbakelser": "gräddbakelse",
    "gräddbakelserna": "gräddbakelse",
    "gräddbakelsernas": "gräddbakelse",
    "gräddbakelsers": "gräddbakelse",
    "gräddbakelses": "gräddbakelse",
    "grädden": "grädde",
    "gräddens": "grädde",
    "gräddes": "grädde",
    "gräddfilen": "gräddfil",
    "gräddfilens": "gräddfil",
    "gräddfiler": "gräddfil",
    "gräddfilerna": "gräddfil",
    "gräddfilernas": "gräddfil",
    "gräddfilers": "gräddfil",
    "gräddfils": "gräddfil",
    "gräddfärgade": "gräddfärgad",
    "gräddfärgades": "gräddfärgad",
    "gräddfärgads": "gräddfärgad",
    "gräddfärgat": "gräddfärgad",
    "gräddfärgats": "gräddfärgad",
    "gräddhalten": "gräddhalt",
    "gräddhaltens": "gräddhalt",
    "gräddhalter": "gräddhalt",
    "gräddhalterna": "gräddhalt",
    "gräddhalternas": "gräddhalt",
    "gräddhalters": "gräddhalt",
    "gräddhalts": "gräddhalt",
    "gräddiga": "gräddig",
    "gräddigare": "gräddig",
    "gräddigares": "gräddig",
    "gräddigas": "gräddig",
    "gräddigast": "gräddig",
    "gräddigaste": "gräddig",
    "gräddigastes": "gräddig",
    "gräddigasts": "gräddig",
    "gräddige": "gräddig",
    "gräddiges": "gräddig",
    "gräddigheten": "gräddighet",
    "gräddighetens": "gräddighet",
    "gräddighets": "gräddighet",
    "gräddigs": "gräddig",
    "gräddigt": "gräddig",
    "gräddigts": "gräddig",
    "gräddmätar": "gräddmätare",
    "gräddmätaren": "gräddmätare",
    "gräddmätarens": "gräddmätare",
    "gräddmätares": "gräddmätare",
    "gräddmätarna": "gräddmätare",
    "gräddmätarnas": "gräddmätare",
    "gräddskummet": "gräddskum",
    "gräddskummets": "gräddskum",
    "gräddskums": "gräddskum",
    "gräddsnip": "gräddsnipa",
    "gräddsnipan": "gräddsnipa",
    "gräddsnipans": "gräddsnipa",
    "gräddsnipas": "gräddsnipa",
    "gräddsnipe": "gräddsnipa",
    "gräddsnipor": "gräddsnipa",
    "gräddsniporna": "gräddsnipa",
    "gräddsnipornas": "gräddsnipa",
    "gräddsnipors": "gräddsnipa",
    "gräddsnips": "gräddsnipa",
    "gräddsättningar": "gräddsättning",
    "gräddsättningarna": "gräddsättning",
    "gräddsättningarnas": "gräddsättning",
    "gräddsättningars": "gräddsättning",
    "gräddsättningen": "gräddsättning",
    "gräddsättningens": "gräddsättning",
    "gräddsättnings": "gräddsättning",
    "gräddtårt": "gräddtårta",
    "gräddtårtan": "gräddtårta",
    "gräddtårtans": "gräddtårta",
    "gräddtårtas": "gräddtårta",
    "gräddtårte": "gräddtårta",
    "gräddtårtor": "gräddtårta",
    "gräddtårtorna": "gräddtårta",
    "gräddtårtornas": "gräddtårta",
    "gräddtårtors": "gräddtårta",
    "gräddtårts": "gräddtårta",
    "gräddvispar": "gräddvisp",
    "gräddvisparna": "gräddvisp",
    "gräddvisparnas": "gräddvisp",
    "gräddvispars": "gräddvisp",
    "gräddvispen": "gräddvisp",
    "gräddvispens": "gräddvisp",
    "gräddvispet": "gräddvisp",
    "gräddvispets": "gräddvisp",
    "gräddvisps": "gräddvisp",
    "gräft": "gräfta",
    "gräftad": "gräfta",
    "gräftade": "gräfta",
    "gräftades": "gräfta",
    "gräftads": "gräfta",
    "gräftan": "gräfta",
    "gräftande": "gräfta",
    "gräftanden": "gräftande",
    "gräftandena": "gräftande",
    "gräftandenas": "gräftande",
    "gräftandens": "gräftande",
    "gräftandes": "gräftande",
    "gräftandet": "gräftande",
    "gräftandets": "gräftande",
    "gräftans": "gräfta",
    "gräftar": "gräfta",
    "gräftas": "gräfta",
    "gräftat": "gräfta",
    "gräftats": "gräfta",
    "gräfte": "gräfta",
    "gräftor": "gräfta",
    "gräftorna": "gräfta",
    "gräftornas": "gräfta",
    "gräftors": "gräfta",
    "gräfts": "gräfta",
    "grälade": "gräla",
    "grälades": "gräla",
    "grälaktiga": "grälaktig",
    "grälaktigare": "grälaktig",
    "grälaktigares": "grälaktig",
    "grälaktigas": "grälaktig",
    "grälaktigast": "grälaktig",
    "grälaktigaste": "grälaktig",
    "grälaktigastes": "grälaktig",
    "grälaktigasts": "grälaktig",
    "grälaktige": "grälaktig",
    "grälaktiges": "grälaktig",
    "grälaktigheten": "grälaktighet",
    "grälaktighetens": "grälaktighet",
    "grälaktighets": "grälaktighet",
    "grälaktigs": "grälaktig",
    "grälaktigt": "grälaktig",
    "grälaktigts": "grälaktig",
    "grälande": "gräla",
    "grälanden": "grälande",
    "grälandena": "grälande",
    "grälandenas": "grälande",
    "grälandens": "grälande",
    "grälandes": "grälande",
    "grälandet": "grälande",
    "grälandets": "grälande",
    "grälar": "gräla",
    "grälas": "gräla",
    "grälat": "gräla",
    "grälats": "gräla",
    "grälen": "gräl",
    "grälens": "gräl",
    "grälet": "gräl",
    "grälets": "gräl",
    "gräliga": "grälig",
    "gräligare": "grälig",
    "gräligares": "grälig",
    "gräligas": "grälig",
    "gräligast": "grälig",
    "gräligaste": "grälig",
    "gräligastes": "grälig",
    "gräligasts": "grälig",
    "grälige": "grälig",
    "gräliges": "grälig",
    "gräligheten": "grälighet",
    "grälighetens": "grälighet",
    "grälighets": "grälighet",
    "gräligs": "grälig",
    "gräligt": "grälig",
    "gräligts": "grälig",
    "grälla": "gräll",
    "grällare": "gräll",
    "grällares": "gräll",
    "grällas": "gräll",
    "grällast": "gräll",
    "grällaste": "gräll",
    "grällastes": "gräll",
    "grällasts": "gräll",
    "grälle": "gräll",
    "grälles": "gräll",
    "grällheten": "grällhet",
    "grällhetens": "grällhet",
    "grällhets": "grällhet",
    "grälls": "gräll",
    "grällt": "gräll",
    "grällts": "gräll",
    "grälmakar": "grälmakare",
    "grälmakaren": "grälmakare",
    "grälmakarens": "grälmakare",
    "grälmakares": "grälmakare",
    "grälmakarna": "grälmakare",
    "grälmakarnas": "grälmakare",
    "grälmånsar": "grälmåns",
    "grälmånsarna": "grälmåns",
    "grälmånsarnas": "grälmåns",
    "grälmånsars": "grälmåns",
    "grälmånsen": "grälmåns",
    "grälmånsens": "grälmåns",
    "gräls": "gräl",
    "grälsjuka": "grälsjuk",
    "grälsjukare": "grälsjuk",
    "grälsjukares": "grälsjuk",
    "grälsjukas": "grälsjuk",
    "grälsjukast": "grälsjuk",
    "grälsjukaste": "grälsjuk",
    "grälsjukastes": "grälsjuk",
    "grälsjukasts": "grälsjuk",
    "grälsjuke": "grälsjuk",
    "grälsjukes": "grälsjuk",
    "grälsjukheten": "grälsjukhet",
    "grälsjukhetens": "grälsjukhet",
    "grälsjukhets": "grälsjukhet",
    "grälsjuks": "grälsjuk",
    "grälsjukt": "grälsjuk",
    "grälsjukts": "grälsjuk",
    "gräm": "gräma",
    "grämande": "gräma",
    "grämanden": "grämande",
    "grämandena": "grämande",
    "grämandenas": "grämande",
    "grämandens": "grämande",
    "grämandes": "grämande",
    "grämandet": "grämande",
    "grämandets": "grämande",
    "grämde": "gräma",
    "grämelsen": "grämelse",
    "grämelsens": "grämelse",
    "grämelser": "grämelse",
    "grämelserna": "grämelse",
    "grämelsernas": "grämelse",
    "grämelsers": "grämelse",
    "grämelses": "grämelse",
    "grämer": "gräma",
    "grämt": "gräma",
    "gränden": "gränd",
    "grändens": "gränd",
    "gränder": "gränd",
    "gränderna": "gränd",
    "grändernas": "gränd",
    "gränders": "gränd",
    "grändhusen": "grändhus",
    "grändhusens": "grändhus",
    "grändhuset": "grändhus",
    "grändhusets": "grändhus",
    "gränds": "gränd",
    "gränen": "grän",
    "gränens": "grän",
    "gränet": "grän",
    "gränets": "grän",
    "grängen": "gräng",
    "grängens": "gräng",
    "grängs": "gräng",
    "gräns": "grän",
    "gränsade": "gränsa",
    "gränsades": "gränsa",
    "gränsande": "gränsa",
    "gränsandes": "gränsa",
    "gränsar": "gränsa",
    "gränsas": "gränsa",
    "gränsat": "gränsa",
    "gränsats": "gränsa",
    "gränsbevakningar": "gränsbevakning",
    "gränsbevakningarna": "gränsbevakning",
    "gränsbevakningarnas": "gränsbevakning",
    "gränsbevakningars": "gränsbevakning",
    "gränsbevakningen": "gränsbevakning",
    "gränsbevakningens": "gränsbevakning",
    "gränsbevaknings": "gränsbevakning",
    "gränsbon": "gränsbo",
    "gränsbons": "gränsbo",
    "gränsbor": "gränsbo",
    "gränsborna": "gränsbo",
    "gränsbornas": "gränsbo",
    "gränsbors": "gränsbo",
    "gränsbos": "gränsbo",
    "gränsbråken": "gränsbråk",
    "gränsbråkens": "gränsbråk",
    "gränsbråket": "gränsbråk",
    "gränsbråkets": "gränsbråk",
    "gränsbråks": "gränsbråk",
    "gränsdragningar": "gränsdragning",
    "gränsdragningarna": "gränsdragning",
    "gränsdragningarnas": "gränsdragning",
    "gränsdragningars": "gränsdragning",
    "gränsdragningen": "gränsdragning",
    "gränsdragningens": "gränsdragning",
    "gränsdragnings": "gränsdragning",
    "gränsel": "gränsla",
    "gränsen": "gräns",
    "gränsens": "gräns",
    "gränser": "gräns",
    "gränserna": "gräns",
    "gränsernas": "gräns",
    "gränsers": "gräns",
    "gränsfallen": "gränsfall",
    "gränsfallens": "gränsfall",
    "gränsfallet": "gränsfall",
    "gränsfallets": "gränsfall",
    "gränsfalls": "gränsfall",
    "gränsintäkten": "gränsintäkt",
    "gränsintäktens": "gränsintäkt",
    "gränsintäkter": "gränsintäkt",
    "gränsintäkterna": "gränsintäkt",
    "gränsintäkternas": "gränsintäkt",
    "gränsintäkters": "gränsintäkt",
    "gränsintäkts": "gränsintäkt",
    "gränsjägar": "gränsjägare",
    "gränsjägaren": "gränsjägare",
    "gränsjägarens": "gränsjägare",
    "gränsjägares": "gränsjägare",
    "gränsjägarna": "gränsjägare",
    "gränsjägarnas": "gränsjägare",
    "gränskontrollen": "gränskontroll",
    "gränskontrollens": "gränskontroll",
    "gränskontroller": "gränskontroll",
    "gränskontrollerna": "gränskontroll",
    "gränskontrollernas": "gränskontroll",
    "gränskontrollers": "gränskontroll",
    "gränskontrolls": "gränskontroll",
    "gränskostnaden": "gränskostnad",
    "gränskostnadens": "gränskostnad",
    "gränskostnader": "gränskostnad",
    "gränskostnaderna": "gränskostnad",
    "gränskostnadernas": "gränskostnad",
    "gränskostnaders": "gränskostnad",
    "gränskostnads": "gränskostnad",
    "gränslad": "gränsla",
    "gränslade": "gränsla",
    "gränslades": "gränsla",
    "gränslads": "gränsla",
    "gränslande": "gränsla",
    "gränslanden": "gränslande",
    "gränslandena": "gränslande",
    "gränslandenas": "gränslande",
    "gränslandens": "gränslande",
    "gränslandes": "gränslande",
    "gränslandet": "gränslande",
    "gränslandets": "gränslande",
    "gränslar": "gränsla",
    "gränslas": "gränsla",
    "gränslat": "gränsla",
    "gränslats": "gränsla",
    "gränslinjen": "gränslinje",
    "gränslinjens": "gränslinje",
    "gränslinjer": "gränslinje",
    "gränslinjerna": "gränslinje",
    "gränslinjernas": "gränslinje",
    "gränslinjers": "gränslinje",
    "gränslinjes": "gränslinje",
    "gränslösa": "gränslös",
    "gränslösare": "gränslös",
    "gränslösares": "gränslös",
    "gränslösas": "gränslös",
    "gränslösast": "gränslös",
    "gränslösaste": "gränslös",
    "gränslösastes": "gränslös",
    "gränslösasts": "gränslös",
    "gränslöse": "gränslös",
    "gränslöses": "gränslös",
    "gränslösheten": "gränslöshet",
    "gränslöshetens": "gränslöshet",
    "gränslöshets": "gränslöshet",
    "gränslöst": "gränslös",
    "gränslösts": "gränslös",
    "gränsnyttan": "gränsnytta",
    "gränsnyttans": "gränsnytta",
    "gränsnyttas": "gränsnytta",
    "gränsnytte": "gränsnytta",
    "gränsnytto": "gränsnytta",
    "gränsnyttor": "gränsnytta",
    "gränsnyttorna": "gränsnytta",
    "gränsnyttornas": "gränsnytta",
    "gränsnyttors": "gränsnytta",
    "gränsområden": "gränsområde",
    "gränsområdena": "gränsområde",
    "gränsområdenas": "gränsområde",
    "gränsområdens": "gränsområde",
    "gränsområdes": "gränsområde",
    "gränsområdet": "gränsområde",
    "gränsområdets": "gränsområde",
    "gränspolisen": "gränspolis",
    "gränspolisens": "gränspolis",
    "gränspoliser": "gränspolis",
    "gränspoliserna": "gränspolis",
    "gränspolisernas": "gränspolis",
    "gränspolisers": "gränspolis",
    "gränsposteringar": "gränspostering",
    "gränsposteringarna": "gränspostering",
    "gränsposteringarnas": "gränspostering",
    "gränsposteringars": "gränspostering",
    "gränsposteringen": "gränspostering",
    "gränsposteringens": "gränspostering",
    "gränsposterings": "gränspostering",
    "gränspål": "gränspåle",
    "gränspålar": "gränspåle",
    "gränspålarna": "gränspåle",
    "gränspålarnas": "gränspåle",
    "gränspålars": "gränspåle",
    "gränspålen": "gränspåle",
    "gränspålens": "gränspåle",
    "gränspåles": "gränspåle",
    "gränspåls": "gränspåle",
    "gränsskikten": "gränsskikt",
    "gränsskiktens": "gränsskikt",
    "gränsskiktet": "gränsskikt",
    "gränsskiktets": "gränsskikt",
    "gränsskikts": "gränsskikt",
    "gränssnitten": "gränssnitt",
    "gränssnittens": "gränssnitt",
    "gränssnittet": "gränssnitt",
    "gränssnittets": "gränssnitt",
    "gränssnitts": "gränssnitt",
    "gränsstaden": "gränsstad",
    "gränsstadens": "gränsstad",
    "gränsstads": "gränsstad",
    "gränsstan": "gränsstad",
    "gränsstans": "gränsstad",
    "gränsstäder": "gränsstad",
    "gränsstäderna": "gränsstad",
    "gränsstädernas": "gränsstad",
    "gränsstäders": "gränsstad",
    "gränssättningar": "gränssättning",
    "gränssättningarna": "gränssättning",
    "gränssättningarnas": "gränssättning",
    "gränssättningars": "gränssättning",
    "gränssättningen": "gränssättning",
    "gränssättningens": "gränssättning",
    "gränssättnings": "gränssättning",
    "gränstrakten": "gränstrakt",
    "gränstraktens": "gränstrakt",
    "gränstrakter": "gränstrakt",
    "gränstrakterna": "gränstrakt",
    "gränstrakternas": "gränstrakt",
    "gränstrakters": "gränstrakt",
    "gränstrakts": "gränstrakt",
    "gränsvärden": "gränsvärde",
    "gränsvärdena": "gränsvärde",
    "gränsvärdenas": "gränsvärde",
    "gränsvärdens": "gränsvärde",
    "gränsvärdes": "gränsvärde",
    "gränsvärdet": "gränsvärde",
    "gränsvärdets": "gränsvärde",
    "gränsvågen": "gränsvåg",
    "gränsvågens": "gränsvåg",
    "gränsvågs": "gränsvåg",
    "gränsöverskridanden": "gränsöverskridande",
    "gränsöverskridandena": "gränsöverskridande",
    "gränsöverskridandenas": "gränsöverskridande",
    "gränsöverskridandens": "gränsöverskridande",
    "gränsöverskridandes": "gränsöverskridande",
    "gränsöverskridandet": "gränsöverskridande",
    "gränsöverskridandets": "gränsöverskridande",
    "gräsade": "gräsad",
    "gräsades": "gräsad",
    "gräsads": "gräsad",
    "gräsande": "gräsa",
    "gräsanden": "gräsande",
    "gräsandena": "gräsande",
    "gräsandenas": "gräsande",
    "gräsandens": "gräsande",
    "gräsandes": "gräsande",
    "gräsandet": "gräsande",
    "gräsandets": "gräsande",
    "gräsands": "gräsand",
    "gräsar": "gräsa",
    "gräsas": "gräsa",
    "gräsat": "gräsad",
    "gräsats": "gräsad",
    "gräsbetäckta": "gräsbetäckt",
    "gräsbetäcktas": "gräsbetäckt",
    "gräsbetäckte": "gräsbetäckt",
    "gräsbetäcktes": "gräsbetäckt",
    "gräsbetäckts": "gräsbetäckt",
    "gräsen": "gräs",
    "gräsens": "gräs",
    "gräset": "gräs",
    "gräsets": "gräs",
    "gräsfjärilar": "gräsfjäril",
    "gräsfjärilarna": "gräsfjäril",
    "gräsfjärilarnas": "gräsfjäril",
    "gräsfjärilars": "gräsfjäril",
    "gräsfjärilen": "gräsfjäril",
    "gräsfjärilens": "gräsfjäril",
    "gräsfjäriln": "gräsfjäril",
    "gräsfjärilns": "gräsfjäril",
    "gräsfjärils": "gräsfjäril",
    "gräsflyen": "gräsfly",
    "gräsflyens": "gräsfly",
    "gräsflyet": "gräsfly",
    "gräsflyets": "gräsfly",
    "gräsflyn": "gräsfly",
    "gräsflyna": "gräsfly",
    "gräsflynas": "gräsfly",
    "gräsflyns": "gräsfly",
    "gräsflys": "gräsfly",
    "gräsflyt": "gräsfly",
    "gräsflyts": "gräsfly",
    "gräshalmen": "gräshalm",
    "gräshalmens": "gräshalm",
    "gräshalms": "gräshalm",
    "gräshopp": "gräshoppa",
    "gräshoppan": "gräshoppa",
    "gräshoppans": "gräshoppa",
    "gräshoppas": "gräshoppa",
    "gräshoppe": "gräshoppa",
    "gräshoppor": "gräshoppa",
    "gräshopporna": "gräshoppa",
    "gräshoppornas": "gräshoppa",
    "gräshoppors": "gräshoppa",
    "gräshopps": "gräshoppa",
    "gräshoppssvärmar": "gräshoppssvärm",
    "gräshoppssvärmarna": "gräshoppssvärm",
    "gräshoppssvärmarnas": "gräshoppssvärm",
    "gräshoppssvärmars": "gräshoppssvärm",
    "gräshoppssvärmen": "gräshoppssvärm",
    "gräshoppssvärmens": "gräshoppssvärm",
    "gräshoppssvärms": "gräshoppssvärm",
    "gräsklippar": "gräsklippare",
    "gräsklipparen": "gräsklippare",
    "gräsklipparens": "gräsklippare",
    "gräsklippares": "gräsklippare",
    "gräsklipparna": "gräsklippare",
    "gräsklipparnas": "gräsklippare",
    "gräsklippningar": "gräsklippning",
    "gräsklippningarna": "gräsklippning",
    "gräsklippningarnas": "gräsklippning",
    "gräsklippningars": "gräsklippning",
    "gräsklippningen": "gräsklippning",
    "gräsklippningens": "gräsklippning",
    "gräsklippnings": "gräsklippning",
    "gräsliga": "gräslig",
    "gräsligare": "gräslig",
    "gräsligares": "gräslig",
    "gräsligas": "gräslig",
    "gräsligast": "gräslig",
    "gräsligaste": "gräslig",
    "gräsligastes": "gräslig",
    "gräsligasts": "gräslig",
    "gräslige": "gräslig",
    "gräsliges": "gräslig",
    "gräsligheten": "gräslighet",
    "gräslighetens": "gräslighet",
    "gräsligheter": "gräslighet",
    "gräsligheterna": "gräslighet",
    "gräsligheternas": "gräslighet",
    "gräsligheters": "gräslighet",
    "gräslighets": "gräslighet",
    "gräsligs": "gräslig",
    "gräsligt": "gräslig",
    "gräsligts": "gräslig",
    "gräslöken": "gräslök",
    "gräslökens": "gräslök",
    "gräslöks": "gräslök",
    "gräsmaskar": "gräsmask",
    "gräsmaskarna": "gräsmask",
    "gräsmaskarnas": "gräsmask",
    "gräsmaskars": "gräsmask",
    "gräsmasken": "gräsmask",
    "gräsmaskens": "gräsmask",
    "gräsmasks": "gräsmask",
    "gräsmatt": "gräsmatta",
    "gräsmattan": "gräsmatta",
    "gräsmattans": "gräsmatta",
    "gräsmattas": "gräsmatta",
    "gräsmatte": "gräsmatta",
    "gräsmattor": "gräsmatta",
    "gräsmattorna": "gräsmatta",
    "gräsmattornas": "gräsmatta",
    "gräsmattors": "gräsmatta",
    "gräsmatts": "gräsmatta",
    "gräsmånaden": "gräsmånad",
    "gräsmånadens": "gräsmånad",
    "gräsmånader": "gräsmånad",
    "gräsmånaderna": "gräsmånad",
    "gräsmånadernas": "gräsmånad",
    "gräsmånaders": "gräsmånad",
    "gräsmånads": "gräsmånad",
    "gräsnejlik": "gräsnejlika",
    "gräsnejlikan": "gräsnejlika",
    "gräsnejlikans": "gräsnejlika",
    "gräsnejlikas": "gräsnejlika",
    "gräsnejlike": "gräsnejlika",
    "gräsnejlikor": "gräsnejlika",
    "gräsnejlikorna": "gräsnejlika",
    "gräsnejlikornas": "gräsnejlika",
    "gräsnejlikors": "gräsnejlika",
    "gräsnejliks": "gräsnejlika",
    "gräsplanen": "gräsplan",
    "gräsplanens": "gräsplan",
    "gräsplaner": "gräsplan",
    "gräsplanerna": "gräsplan",
    "gräsplanernas": "gräsplan",
    "gräsplaners": "gräsplan",
    "gräsplans": "gräsplan",
    "gräsroten": "gräsrot",
    "gräsrotens": "gräsrot",
    "gräsrots": "gräsrot",
    "gräsrotskampanjen": "gräsrotskampanj",
    "gräsrotskampanjens": "gräsrotskampanj",
    "gräsrotskampanjer": "gräsrotskampanj",
    "gräsrotskampanjerna": "gräsrotskampanj",
    "gräsrotskampanjernas": "gräsrotskampanj",
    "gräsrotskampanjers": "gräsrotskampanj",
    "gräsrotskampanjs": "gräsrotskampanj",
    "gräsrotsnivån": "gräsrotsnivå",
    "gräsrotsnivåns": "gräsrotsnivå",
    "gräsrotsnivås": "gräsrotsnivå",
    "gräsrötter": "gräsrot",
    "gräsrötterna": "gräsrot",
    "gräsrötternas": "gräsrot",
    "gräsrötters": "gräsrot",
    "grässtrået": "grässtrå",
    "grässtråets": "grässtrå",
    "grässtrån": "grässtrå",
    "grässtråna": "grässtrå",
    "grässtrånas": "grässtrå",
    "grässtråns": "grässtrå",
    "grässtrås": "grässtrå",
    "grässtråt": "grässtrå",
    "grässtråts": "grässtrå",
    "grässvålen": "grässvål",
    "grässvålens": "grässvål",
    "grässvåls": "grässvål",
    "grästorv": "grästorva",
    "grästorvan": "grästorva",
    "grästorvans": "grästorva",
    "grästorvas": "grästorva",
    "grästorve": "grästorva",
    "grästorven": "grästorv",
    "grästorvens": "grästorv",
    "grästorvor": "grästorva",
    "grästorvorna": "grästorva",
    "grästorvornas": "grästorva",
    "grästorvors": "grästorva",
    "grästorvs": "grästorva",
    "grästrimmern": "grästrimmer",
    "grästrimmerns": "grästrimmer",
    "grästrimmers": "grästrimmer",
    "grästrimmersarna": "grästrimmer",
    "grästrimmersarnas": "grästrimmer",
    "grästrimmersen": "grästrimmer",
    "grästrimmersens": "grästrimmer",
    "grästrimrar": "grästrimmer",
    "grästrimrarna": "grästrimmer",
    "grästrimrarnas": "grästrimmer",
    "grästrimrars": "grästrimmer",
    "grästuv": "grästuva",
    "grästuvan": "grästuva",
    "grästuvans": "grästuva",
    "grästuvas": "grästuva",
    "grästuve": "grästuva",
    "grästuvor": "grästuva",
    "grästuvorna": "grästuva",
    "grästuvornas": "grästuva",
    "grästuvors": "grästuva",
    "grästuvs": "grästuva",
    "gräsvallar": "gräsvall",
    "gräsvallarna": "gräsvall",
    "gräsvallarnas": "gräsvall",
    "gräsvallars": "gräsvall",
    "gräsvallen": "gräsvall",
    "gräsvallens": "gräsvall",
    "gräsvalls": "gräsvall",
    "gräsänder": "gräsand",
    "gräsänderna": "gräsand",
    "gräsändernas": "gräsand",
    "gräsänders": "gräsand",
    "gräsänk": "gräsänka",
    "gräsänkan": "gräsänka",
    "gräsänkans": "gräsänka",
    "gräsänkas": "gräsänka",
    "gräsänke": "gräsänka",
    "gräsänklingar": "gräsänkling",
    "gräsänklingarna": "gräsänkling",
    "gräsänklingarnas": "gräsänkling",
    "gräsänklingars": "gräsänkling",
    "gräsänklingen": "gräsänkling",
    "gräsänklingens": "gräsänkling",
    "gräsänklings": "gräsänkling",
    "gräsänkor": "gräsänka",
    "gräsänkorna": "gräsänka",
    "gräsänkornas": "gräsänka",
    "gräsänkors": "gräsänka",
    "gräsänks": "gräsänka",
    "gräsätar": "gräsätare",
    "gräsätaren": "gräsätare",
    "gräsätarens": "gräsätare",
    "gräsätares": "gräsätare",
    "gräsätarna": "gräsätare",
    "gräsätarnas": "gräsätare",
    "grät": "gråta",
    "gräte": "gråta",
    "grätes": "gråta",
    "gräts": "gråta",
    "grättenheten": "grättenhet",
    "grättenhetens": "grättenhet",
    "grättenhets": "grättenhet",
    "grättens": "grätten",
    "grättet": "grätten",
    "grättets": "grätten",
    "grättna": "grätten",
    "grättnare": "grätten",
    "grättnares": "grätten",
    "grättnas": "grätten",
    "grättnast": "grätten",
    "grättnaste": "grätten",
    "grättnastes": "grätten",
    "grättnasts": "grätten",
    "grättne": "grätten",
    "grättnes": "grätten",
    "gräv": "gräva",
    "grävande": "gräva",
    "grävanden": "grävande",
    "grävandena": "grävande",
    "grävandenas": "grävande",
    "grävandens": "grävande",
    "grävandes": "grävande",
    "grävandet": "grävande",
    "grävandets": "grävande",
    "grävargenerationen": "grävargeneration",
    "grävargenerationens": "grävargeneration",
    "grävargenerationer": "grävargeneration",
    "grävargenerationerna": "grävargeneration",
    "grävargenerationernas": "grävargeneration",
    "grävargenerationers": "grävargeneration",
    "grävargenerations": "grävargeneration",
    "grävas": "gräva",
    "grävbloggar": "grävblogg",
    "grävbloggarna": "grävblogg",
    "grävbloggarnas": "grävblogg",
    "grävbloggars": "grävblogg",
    "grävbloggen": "grävblogg",
    "grävbloggens": "grävblogg",
    "grävbloggs": "grävblogg",
    "grävd": "gräva",
    "grävda": "gräva",
    "grävdas": "gräva",
    "grävde": "gräva",
    "grävdes": "gräva",
    "grävds": "gräva",
    "gräver": "gräva",
    "gräves": "gräva",
    "grävgruppen": "grävgrupp",
    "grävgruppens": "grävgrupp",
    "grävgrupper": "grävgrupp",
    "grävgrupperna": "grävgrupp",
    "grävgruppernas": "grävgrupp",
    "grävgruppers": "grävgrupp",
    "grävgrupps": "grävgrupp",
    "grävlingar": "grävling",
    "grävlingarna": "grävling",
    "grävlingarnas": "grävling",
    "grävlingars": "grävling",
    "grävlingen": "grävling",
    "grävlingens": "grävling",
    "grävlings": "grävling",
    "grävlingsgryten": "grävlingsgryt",
    "grävlingsgrytens": "grävlingsgryt",
    "grävlingsgrytet": "grävlingsgryt",
    "grävlingsgrytets": "grävlingsgryt",
    "grävlingsgryts": "grävlingsgryt",
    "grävlingshundar": "grävlingshund",
    "grävlingshundarna": "grävlingshund",
    "grävlingshundarnas": "grävlingshund",
    "grävlingshundars": "grävlingshund",
    "grävlingshunden": "grävlingshund",
    "grävlingshundens": "grävlingshund",
    "grävlingshunds": "grävlingshund",
    "grävlingsjakten": "grävlingsjakt",
    "grävlingsjaktens": "grävlingsjakt",
    "grävlingsjakts": "grävlingsjakt",
    "grävmaskinen": "grävmaskin",
    "grävmaskinens": "grävmaskin",
    "grävmaskiner": "grävmaskin",
    "grävmaskinerna": "grävmaskin",
    "grävmaskinernas": "grävmaskin",
    "grävmaskiners": "grävmaskin",
    "grävmaskins": "grävmaskin",
    "grävningar": "grävning",
    "grävningarna": "grävning",
    "grävningarnas": "grävning",
    "grävningars": "grävning",
    "grävningen": "grävning",
    "grävningens": "grävning",
    "grävnings": "grävning",
    "grävs": "gräva",
    "grävschakten": "grävschakt",
    "grävschaktens": "grävschakt",
    "grävschaktet": "grävschakt",
    "grävschaktets": "grävschakt",
    "grävschakts": "grävschakt",
    "grävskop": "grävskopa",
    "grävskopan": "grävskopa",
    "grävskopans": "grävskopa",
    "grävskopas": "grävskopa",
    "grävskope": "grävskopa",
    "grävskopor": "grävskopa",
    "grävskoporna": "grävskopa",
    "grävskopornas": "grävskopa",
    "grävskopors": "grävskopa",
    "grävskops": "grävskopa",
    "grävsvinen": "grävsvin",
    "grävsvinens": "grävsvin",
    "grävsvinet": "grävsvin",
    "grävsvinets": "grävsvin",
    "grävsvins": "grävsvin",
    "grävt": "gräva",
    "grävts": "gräva",
    "gråa": "grå",
    "gråaktiga": "gråaktig",
    "gråaktigare": "gråaktig",
    "gråaktigares": "gråaktig",
    "gråaktigas": "gråaktig",
    "gråaktigast": "gråaktig",
    "gråaktigaste": "gråaktig",
    "gråaktigastes": "gråaktig",
    "gråaktigasts": "gråaktig",
    "gråaktige": "gråaktig",
    "gråaktiges": "gråaktig",
    "gråaktigheten": "gråaktighet",
    "gråaktighetens": "gråaktighet",
    "gråaktighets": "gråaktighet",
    "gråaktigs": "gråaktig",
    "gråaktigt": "gråaktig",
    "gråaktigts": "gråaktig",
    "gråalar": "gråal",
    "gråalarna": "gråal",
    "gråalarnas": "gråal",
    "gråalars": "gråal",
    "gråalen": "gråal",
    "gråalens": "gråal",
    "gråals": "gråal",
    "gråare": "grå",
    "gråares": "grå",
    "gråas": "grå",
    "gråast": "grå",
    "gråaste": "grå",
    "gråastes": "grå",
    "gråasts": "grå",
    "gråberget": "gråberg",
    "gråbergets": "gråberg",
    "gråbergs": "gråberg",
    "gråbleka": "gråblek",
    "gråblekare": "gråblek",
    "gråblekares": "gråblek",
    "gråblekas": "gråblek",
    "gråblekast": "gråblek",
    "gråblekaste": "gråblek",
    "gråblekastes": "gråblek",
    "gråblekasts": "gråblek",
    "gråbleke": "gråblek",
    "gråblekes": "gråblek",
    "gråblekheten": "gråblekhet",
    "gråblekhetens": "gråblekhet",
    "gråblekhets": "gråblekhet",
    "gråbleks": "gråblek",
    "gråblekt": "gråblek",
    "gråblekts": "gråblek",
    "gråblåa": "gråblå",
    "gråblåare": "gråblå",
    "gråblåares": "gråblå",
    "gråblåas": "gråblå",
    "gråblåast": "gråblå",
    "gråblåaste": "gråblå",
    "gråblåastes": "gråblå",
    "gråblåasts": "gråblå",
    "gråblåe": "gråblå",
    "gråblåes": "gråblå",
    "gråblås": "gråblå",
    "gråblått": "gråblå",
    "gråblåtts": "gråblå",
    "gråbon": "gråbo",
    "gråbons": "gråbo",
    "gråbor": "gråbo",
    "gråborna": "gråbo",
    "gråbornas": "gråbo",
    "gråbors": "gråbo",
    "gråbos": "gråbo",
    "gråbrodern": "gråbroder",
    "gråbroderns": "gråbroder",
    "gråbroders": "gråbroder",
    "gråbröder": "gråbroder",
    "gråbröderna": "gråbroder",
    "gråbrödernas": "gråbroder",
    "gråbröders": "gråbroder",
    "grådasket": "grådask",
    "grådaskets": "grådask",
    "grådaskiga": "grådaskig",
    "grådaskigare": "grådaskig",
    "grådaskigares": "grådaskig",
    "grådaskigas": "grådaskig",
    "grådaskigast": "grådaskig",
    "grådaskigaste": "grådaskig",
    "grådaskigastes": "grådaskig",
    "grådaskigasts": "grådaskig",
    "grådaskige": "grådaskig",
    "grådaskiges": "grådaskig",
    "grådaskigheten": "grådaskighet",
    "grådaskighetens": "grådaskighet",
    "grådaskighets": "grådaskighet",
    "grådaskigs": "grådaskig",
    "grådaskigt": "grådaskig",
    "grådaskigts": "grådaskig",
    "grådasks": "grådask",
    "gråe": "grå",
    "gråes": "grå",
    "gråfläckiga": "gråfläckig",
    "gråfläckigare": "gråfläckig",
    "gråfläckigares": "gråfläckig",
    "gråfläckigas": "gråfläckig",
    "gråfläckigast": "gråfläckig",
    "gråfläckigaste": "gråfläckig",
    "gråfläckigastes": "gråfläckig",
    "gråfläckigasts": "gråfläckig",
    "gråfläckige": "gråfläckig",
    "gråfläckiges": "gråfläckig",
    "gråfläckigs": "gråfläckig",
    "gråfläckigt": "gråfläckig",
    "gråfläckigts": "gråfläckig",
    "grågoss": "grågosse",
    "grågossar": "grågosse",
    "grågossarna": "grågosse",
    "grågossarnas": "grågosse",
    "grågossars": "grågosse",
    "grågossen": "grågosse",
    "grågossens": "grågosse",
    "grågosses": "grågosse",
    "grågröna": "grågrön",
    "grågrönare": "grågrön",
    "grågrönares": "grågrön",
    "grågrönas": "grågrön",
    "grågrönast": "grågrön",
    "grågrönaste": "grågrön",
    "grågrönastes": "grågrön",
    "grågrönasts": "grågrön",
    "grågröne": "grågrön",
    "grågrönes": "grågrön",
    "grågröns": "grågrön",
    "grågrönt": "grågrön",
    "grågrönts": "grågrön",
    "grågyllena": "grågyllen",
    "grågyllenas": "grågyllen",
    "grågyllens": "grågyllen",
    "grågäss": "grågås",
    "grågässen": "grågås",
    "grågässens": "grågås",
    "grågåsen": "grågås",
    "grågåsens": "grågås",
    "gråhundar": "gråhund",
    "gråhundarna": "gråhund",
    "gråhundarnas": "gråhund",
    "gråhundars": "gråhund",
    "gråhunden": "gråhund",
    "gråhundens": "gråhund",
    "gråhunds": "gråhund",
    "gråhägern": "gråhäger",
    "gråhägerns": "gråhäger",
    "gråhägers": "gråhäger",
    "gråhägrar": "gråhäger",
    "gråhägrarna": "gråhäger",
    "gråhägrarnas": "gråhäger",
    "gråhägrars": "gråhäger",
    "gråhåriga": "gråhårig",
    "gråhårigare": "gråhårig",
    "gråhårigares": "gråhårig",
    "gråhårigas": "gråhårig",
    "gråhårigast": "gråhårig",
    "gråhårigaste": "gråhårig",
    "gråhårigastes": "gråhårig",
    "gråhårigasts": "gråhårig",
    "gråhårige": "gråhårig",
    "gråhåriges": "gråhårig",
    "gråhårigheten": "gråhårighet",
    "gråhårighetens": "gråhårighet",
    "gråhårighets": "gråhårighet",
    "gråhårigs": "gråhårig",
    "gråhårigt": "gråhårig",
    "gråhårigts": "gråhårig",
    "gråkalla": "gråkall",
    "gråkallare": "gråkall",
    "gråkallares": "gråkall",
    "gråkallas": "gråkall",
    "gråkallast": "gråkall",
    "gråkallaste": "gråkall",
    "gråkallastes": "gråkall",
    "gråkallasts": "gråkall",
    "gråkalle": "gråkall",
    "gråkalles": "gråkall",
    "gråkallheten": "gråkallhet",
    "gråkallhetens": "gråkallhet",
    "gråkallhets": "gråkallhet",
    "gråkalls": "gråkall",
    "gråkallt": "gråkall",
    "gråkallts": "gråkall",
    "gråkilen": "gråkil",
    "gråkilens": "gråkil",
    "gråkils": "gråkil",
    "grålaxar": "grålax",
    "grålaxarna": "grålax",
    "grålaxarnas": "grålax",
    "grålaxars": "grålax",
    "grålaxen": "grålax",
    "grålaxens": "grålax",
    "gråll": "grålle",
    "grållan": "grålla",
    "grållans": "grålla",
    "grållar": "grålle",
    "grållarna": "grålle",
    "grållarnas": "grålle",
    "grållars": "grålle",
    "grållas": "grålla",
    "grålle": "grålla",
    "grållen": "grålle",
    "grållens": "grålle",
    "grålles": "grålle",
    "grållor": "grålla",
    "grållorna": "grålla",
    "grållornas": "grålla",
    "grållors": "grålla",
    "grålls": "grålle",
    "gråmesar": "gråmes",
    "gråmesarna": "gråmes",
    "gråmesarnas": "gråmes",
    "gråmesars": "gråmes",
    "gråmesen": "gråmes",
    "gråmesens": "gråmes",
    "gråmunkar": "gråmunk",
    "gråmunkarna": "gråmunk",
    "gråmunkarnas": "gråmunk",
    "gråmunkars": "gråmunk",
    "gråmunken": "gråmunk",
    "gråmunkens": "gråmunk",
    "gråmunks": "gråmunk",
    "gråmålade": "gråmålad",
    "gråmålades": "gråmålad",
    "gråmålads": "gråmålad",
    "gråmålat": "gråmålad",
    "gråmålats": "gråmålad",
    "grån": "gråna",
    "grånad": "gråna",
    "grånade": "gråna",
    "grånaden": "grånad",
    "grånadens": "grånad",
    "grånader": "grånad",
    "grånaderna": "grånad",
    "grånadernas": "grånad",
    "grånaders": "grånad",
    "grånades": "gråna",
    "grånads": "grånad",
    "grånande": "gråna",
    "grånanden": "grånande",
    "grånandena": "grånande",
    "grånandenas": "grånande",
    "grånandens": "grånande",
    "grånandes": "grånande",
    "grånandet": "grånande",
    "grånandets": "grånande",
    "grånar": "gråna",
    "grånas": "gråna",
    "grånat": "gråna",
    "grånats": "gråna",
    "gråpapperet": "gråpapper",
    "gråpapperets": "gråpapper",
    "gråpappers": "gråpapper",
    "gråpappret": "gråpapper",
    "gråpapprets": "gråpapper",
    "gråpäronen": "gråpäron",
    "gråpäronens": "gråpäron",
    "gråpäronet": "gråpäron",
    "gråpäronets": "gråpäron",
    "gråpärons": "gråpäron",
    "grås": "grå",
    "gråsalv": "gråsalva",
    "gråsalvan": "gråsalva",
    "gråsalvans": "gråsalva",
    "gråsalvas": "gråsalva",
    "gråsalve": "gråsalva",
    "gråsalvor": "gråsalva",
    "gråsalvorna": "gråsalva",
    "gråsalvornas": "gråsalva",
    "gråsalvors": "gråsalva",
    "gråsalvs": "gråsalva",
    "gråsejar": "gråsej",
    "gråsejarna": "gråsej",
    "gråsejarnas": "gråsej",
    "gråsejars": "gråsej",
    "gråsejen": "gråsej",
    "gråsejens": "gråsej",
    "gråsejs": "gråsej",
    "gråsid": "gråsida",
    "gråsidan": "gråsida",
    "gråsidans": "gråsida",
    "gråsidas": "gråsida",
    "gråside": "gråsida",
    "gråsidor": "gråsida",
    "gråsidorna": "gråsida",
    "gråsidornas": "gråsida",
    "gråsidors": "gråsida",
    "gråsids": "gråsida",
    "gråsiskan": "gråsiska",
    "gråsiskans": "gråsiska",
    "gråsiskas": "gråsiska",
    "gråsiske": "gråsiska",
    "gråsiskor": "gråsiska",
    "gråsiskorna": "gråsiska",
    "gråsiskornas": "gråsiska",
    "gråsiskors": "gråsiska",
    "gråskalan": "gråskala",
    "gråskalans": "gråskala",
    "gråskalas": "gråskala",
    "gråskimlar": "gråskimmel",
    "gråskimlarna": "gråskimmel",
    "gråskimlarnas": "gråskimmel",
    "gråskimlars": "gråskimmel",
    "gråskimliga": "gråskimlig",
    "gråskimligare": "gråskimlig",
    "gråskimligares": "gråskimlig",
    "gråskimligas": "gråskimlig",
    "gråskimligast": "gråskimlig",
    "gråskimligaste": "gråskimlig",
    "gråskimligastes": "gråskimlig",
    "gråskimligasts": "gråskimlig",
    "gråskimlige": "gråskimlig",
    "gråskimliges": "gråskimlig",
    "gråskimligheten": "gråskimlighet",
    "gråskimlighetens": "gråskimlighet",
    "gråskimlighets": "gråskimlighet",
    "gråskimligs": "gråskimlig",
    "gråskimligt": "gråskimlig",
    "gråskimligts": "gråskimlig",
    "gråskimmeln": "gråskimmel",
    "gråskimmelns": "gråskimmel",
    "gråskimmels": "gråskimmel",
    "gråskimmlar": "gråskimmel",
    "gråskimmlarna": "gråskimmel",
    "gråskimmlarnas": "gråskimmel",
    "gråskimmlars": "gråskimmel",
    "gråskäckiga": "gråskäckig",
    "gråskäckigare": "gråskäckig",
    "gråskäckigares": "gråskäckig",
    "gråskäckigas": "gråskäckig",
    "gråskäckigast": "gråskäckig",
    "gråskäckigaste": "gråskäckig",
    "gråskäckigastes": "gråskäckig",
    "gråskäckigasts": "gråskäckig",
    "gråskäckige": "gråskäckig",
    "gråskäckiges": "gråskäckig",
    "gråskäckigs": "gråskäckig",
    "gråskäckigt": "gråskäckig",
    "gråskäckigts": "gråskäckig",
    "gråskäggen": "gråskägg",
    "gråskäggens": "gråskägg",
    "gråskägget": "gråskägg",
    "gråskäggets": "gråskägg",
    "gråskäggs": "gråskägg",
    "gråsoss": "gråsosse",
    "gråsossar": "gråsosse",
    "gråsossarna": "gråsosse",
    "gråsossarnas": "gråsosse",
    "gråsossars": "gråsosse",
    "gråsossen": "gråsosse",
    "gråsossens": "gråsosse",
    "gråsosses": "gråsosse",
    "gråsparvar": "gråsparv",
    "gråsparvarna": "gråsparv",
    "gråsparvarnas": "gråsparv",
    "gråsparvars": "gråsparv",
    "gråsparven": "gråsparv",
    "gråsparvens": "gråsparv",
    "gråsparvs": "gråsparv",
    "gråspettar": "gråspett",
    "gråspettarna": "gråspett",
    "gråspettarnas": "gråspett",
    "gråspettars": "gråspett",
    "gråspetten": "gråspett",
    "gråspettens": "gråspett",
    "gråspetts": "gråspett",
    "gråsprängda": "gråsprängd",
    "gråsprängdare": "gråsprängd",
    "gråsprängdares": "gråsprängd",
    "gråsprängdas": "gråsprängd",
    "gråsprängdast": "gråsprängd",
    "gråsprängdaste": "gråsprängd",
    "gråsprängdastes": "gråsprängd",
    "gråsprängdasts": "gråsprängd",
    "gråsprängde": "gråsprängd",
    "gråsprängdes": "gråsprängd",
    "gråsprängdheten": "gråsprängdhet",
    "gråsprängdhetens": "gråsprängdhet",
    "gråsprängdhets": "gråsprängdhet",
    "gråsprängds": "gråsprängd",
    "gråsprängt": "gråsprängd",
    "gråsprängts": "gråsprängd",
    "gråstarren": "gråstarr",
    "gråstarrens": "gråstarr",
    "gråstarrs": "gråstarr",
    "gråstenar": "gråsten",
    "gråstenarna": "gråsten",
    "gråstenarnas": "gråsten",
    "gråstenars": "gråsten",
    "gråstenen": "gråsten",
    "gråstenens": "gråsten",
    "gråstens": "gråsten",
    "gråsugg": "gråsugga",
    "gråsuggan": "gråsugga",
    "gråsuggans": "gråsugga",
    "gråsuggas": "gråsugga",
    "gråsugge": "gråsugga",
    "gråsuggor": "gråsugga",
    "gråsuggorna": "gråsugga",
    "gråsuggornas": "gråsugga",
    "gråsuggors": "gråsugga",
    "gråsuggs": "gråsugga",
    "gråsvarta": "gråsvart",
    "gråsvartare": "gråsvart",
    "gråsvartares": "gråsvart",
    "gråsvartas": "gråsvart",
    "gråsvartast": "gråsvart",
    "gråsvartaste": "gråsvart",
    "gråsvartastes": "gråsvart",
    "gråsvartasts": "gråsvart",
    "gråsvarte": "gråsvart",
    "gråsvartes": "gråsvart",
    "gråsvarts": "gråsvart",
    "gråsälar": "gråsäl",
    "gråsälarna": "gråsäl",
    "gråsälarnas": "gråsäl",
    "gråsälars": "gråsäl",
    "gråsälen": "gråsäl",
    "gråsälens": "gråsäl",
    "gråsäls": "gråsäl",
    "gråt": "gråta",
    "gråtande": "gråta",
    "gråtanden": "gråtande",
    "gråtandena": "gråtande",
    "gråtandenas": "gråtande",
    "gråtandens": "gråtande",
    "gråtandes": "gråtande",
    "gråtandet": "gråtande",
    "gråtandets": "gråtande",
    "gråtas": "gråta",
    "gråtattacken": "gråtattack",
    "gråtattackens": "gråtattack",
    "gråtattacker": "gråtattack",
    "gråtattackerna": "gråtattack",
    "gråtattackernas": "gråtattack",
    "gråtattackers": "gråtattack",
    "gråtattacks": "gråtattack",
    "gråte": "gråta",
    "gråten": "gråt",
    "gråtens": "gråt",
    "gråter": "gråta",
    "gråterskan": "gråterska",
    "gråterskans": "gråterska",
    "gråterskas": "gråterska",
    "gråterske": "gråterska",
    "gråterskor": "gråterska",
    "gråterskorna": "gråterska",
    "gråterskornas": "gråterska",
    "gråterskors": "gråterska",
    "gråtes": "gråta",
    "gråtfärdiga": "gråtfärdig",
    "gråtfärdigare": "gråtfärdig",
    "gråtfärdigares": "gråtfärdig",
    "gråtfärdigas": "gråtfärdig",
    "gråtfärdigast": "gråtfärdig",
    "gråtfärdigaste": "gråtfärdig",
    "gråtfärdigastes": "gråtfärdig",
    "gråtfärdigasts": "gråtfärdig",
    "gråtfärdige": "gråtfärdig",
    "gråtfärdiges": "gråtfärdig",
    "gråtfärdigheten": "gråtfärdighet",
    "gråtfärdighetens": "gråtfärdighet",
    "gråtfärdighets": "gråtfärdighet",
    "gråtfärdigs": "gråtfärdig",
    "gråtfärdigt": "gråtfärdig",
    "gråtfärdigts": "gråtfärdig",
    "gråtit": "gråta",
    "gråtits": "gråta",
    "gråtmilda": "gråtmild",
    "gråtmildare": "gråtmild",
    "gråtmildares": "gråtmild",
    "gråtmildas": "gråtmild",
    "gråtmildast": "gråtmild",
    "gråtmildaste": "gråtmild",
    "gråtmildastes": "gråtmild",
    "gråtmildasts": "gråtmild",
    "gråtmilde": "gråtmild",
    "gråtmildes": "gråtmild",
    "gråtmildheten": "gråtmildhet",
    "gråtmildhetens": "gråtmildhet",
    "gråtmildhets": "gråtmildhet",
    "gråtmilds": "gråtmild",
    "gråtmilt": "gråtmild",
    "gråtmilts": "gråtmild",
    "gråtonen": "gråton",
    "gråtonens": "gråton",
    "gråtoner": "gråton",
    "gråtonerna": "gråton",
    "gråtonernas": "gråton",
    "gråtoners": "gråton",
    "gråtons": "gråton",
    "gråtonsskal": "gråtonsskala",
    "gråtonsskalan": "gråtonsskala",
    "gråtonsskalans": "gråtonsskala",
    "gråtonsskalas": "gråtonsskala",
    "gråtonsskale": "gråtonsskala",
    "gråtonsskalor": "gråtonsskala",
    "gråtonsskalorna": "gråtonsskala",
    "gråtonsskalornas": "gråtonsskala",
    "gråtonsskalors": "gråtonsskala",
    "gråtonsskals": "gråtonsskala",
    "gråtrutar": "gråtrut",
    "gråtrutarna": "gråtrut",
    "gråtrutarnas": "gråtrut",
    "gråtrutars": "gråtrut",
    "gråtruten": "gråtrut",
    "gråtrutens": "gråtrut",
    "gråtruts": "gråtrut",
    "gråts": "gråta",
    "grått": "grå",
    "gråtts": "grå",
    "gråvack": "gråvacka",
    "gråvackan": "gråvacka",
    "gråvackans": "gråvacka",
    "gråvackas": "gråvacka",
    "gråvacke": "gråvacka",
    "gråvackor": "gråvacka",
    "gråvackorna": "gråvacka",
    "gråvackornas": "gråvacka",
    "gråvackors": "gråvacka",
    "gråvacks": "gråvacka",
    "gråvalar": "gråval",
    "gråvalarna": "gråval",
    "gråvalarnas": "gråval",
    "gråvalars": "gråval",
    "gråvalen": "gråval",
    "gråvalens": "gråval",
    "gråvals": "gråval",
    "gråverket": "gråverk",
    "gråverkets": "gråverk",
    "gråverks": "gråverk",
    "gråvides": "gråvide",
    "gråvidet": "gråvide",
    "gråvidets": "gråvide",
    "gråvita": "gråvit",
    "gråvitare": "gråvit",
    "gråvitares": "gråvit",
    "gråvitas": "gråvit",
    "gråvitast": "gråvit",
    "gråvitaste": "gråvit",
    "gråvitastes": "gråvit",
    "gråvitasts": "gråvit",
    "gråvite": "gråvit",
    "gråvites": "gråvit",
    "gråvits": "gråvit",
    "gråvitt": "gråvit",
    "gråvitts": "gråvit",
    "gråväderna": "gråväder",
    "gråvädernas": "gråväder",
    "gråväders": "gråväder",
    "gråvädersmolnen": "gråvädersmoln",
    "gråvädersmolnens": "gråvädersmoln",
    "gråvädersmolnet": "gråvädersmoln",
    "gråvädersmolnets": "gråvädersmoln",
    "gråvädersmolns": "gråvädersmoln",
    "gråvädren": "gråväder",
    "gråvädrens": "gråväder",
    "gråvädret": "gråväder",
    "gråvädrets": "gråväder",
    "gråzonen": "gråzon",
    "gråzonens": "gråzon",
    "gråzoner": "gråzon",
    "gråzonerna": "gråzon",
    "gråzonernas": "gråzon",
    "gråzoners": "gråzon",
    "gråzons": "gråzon",
    "gråärten": "gråärt",
    "gråärtens": "gråärt",
    "gråärts": "gråärt",
    "gröd": "gröda",
    "grödan": "gröda",
    "grödans": "gröda",
    "grödas": "gröda",
    "gröde": "gröda",
    "grödor": "gröda",
    "grödorna": "gröda",
    "grödornas": "gröda",
    "grödors": "gröda",
    "gröds": "gröda",
    "gröen": "gröe",
    "gröens": "gröe",
    "gröes": "gröe",
    "gröna": "grön",
    "grönaktiga": "grönaktig",
    "grönaktigare": "grönaktig",
    "grönaktigares": "grönaktig",
    "grönaktigas": "grönaktig",
    "grönaktigast": "grönaktig",
    "grönaktigaste": "grönaktig",
    "grönaktigastes": "grönaktig",
    "grönaktigasts": "grönaktig",
    "grönaktige": "grönaktig",
    "grönaktiges": "grönaktig",
    "grönaktigheten": "grönaktighet",
    "grönaktighetens": "grönaktighet",
    "grönaktighets": "grönaktighet",
    "grönaktigs": "grönaktig",
    "grönaktigt": "grönaktig",
    "grönaktigts": "grönaktig",
    "grönalgen": "grönalg",
    "grönalgens": "grönalg",
    "grönalger": "grönalg",
    "grönalgerna": "grönalg",
    "grönalgernas": "grönalg",
    "grönalgers": "grönalg",
    "grönalgs": "grönalg",
    "grönare": "grön",
    "grönares": "grön",
    "grönas": "grön",
    "grönast": "grön",
    "grönaste": "grön",
    "grönastes": "grön",
    "grönasts": "grön",
    "grönben": "grönbena",
    "grönbenan": "grönbena",
    "grönbenans": "grönbena",
    "grönbenas": "grönbena",
    "grönbene": "grönbena",
    "grönbenor": "grönbena",
    "grönbenorna": "grönbena",
    "grönbenornas": "grönbena",
    "grönbenors": "grönbena",
    "grönbens": "grönbena",
    "grönbetes": "grönbete",
    "grönbetet": "grönbete",
    "grönbetets": "grönbete",
    "grönbleka": "grönblek",
    "grönblekare": "grönblek",
    "grönblekares": "grönblek",
    "grönblekas": "grönblek",
    "grönblekast": "grönblek",
    "grönblekaste": "grönblek",
    "grönblekastes": "grönblek",
    "grönblekasts": "grönblek",
    "grönbleke": "grönblek",
    "grönblekes": "grönblek",
    "grönblekheten": "grönblekhet",
    "grönblekhetens": "grönblekhet",
    "grönblekhets": "grönblekhet",
    "grönbleks": "grönblek",
    "grönblekt": "grönblek",
    "grönblekts": "grönblek",
    "grönblinda": "grönblind",
    "grönblindare": "grönblind",
    "grönblindares": "grönblind",
    "grönblindas": "grönblind",
    "grönblindast": "grönblind",
    "grönblindaste": "grönblind",
    "grönblindastes": "grönblind",
    "grönblindasts": "grönblind",
    "grönblinde": "grönblind",
    "grönblindes": "grönblind",
    "grönblindheten": "grönblindhet",
    "grönblindhetens": "grönblindhet",
    "grönblindhets": "grönblindhet",
    "grönblinds": "grönblind",
    "grönblint": "grönblind",
    "grönblints": "grönblind",
    "gröne": "grön",
    "grönes": "grön",
    "grönfinkar": "grönfink",
    "grönfinkarna": "grönfink",
    "grönfinkarnas": "grönfink",
    "grönfinkars": "grönfink",
    "grönfinken": "grönfink",
    "grönfinkens": "grönfink",
    "grönfinks": "grönfink",
    "grönfoders": "grönfoder",
    "grönfodret": "grönfoder",
    "grönfodrets": "grönfoder",
    "gröngräset": "gröngräs",
    "gröngräsets": "gröngräs",
    "gröngula": "gröngul",
    "gröngulare": "gröngul",
    "gröngulares": "gröngul",
    "gröngulas": "gröngul",
    "gröngulast": "gröngul",
    "gröngulaste": "gröngul",
    "gröngulastes": "gröngul",
    "gröngulasts": "gröngul",
    "gröngule": "gröngul",
    "gröngules": "gröngul",
    "grönguls": "gröngul",
    "gröngult": "gröngul",
    "gröngults": "gröngul",
    "gröngödsel": "gröngödsla",
    "gröngödslad": "gröngödsla",
    "gröngödslade": "gröngödsla",
    "gröngödslades": "gröngödsla",
    "gröngödslads": "gröngödsla",
    "gröngödslande": "gröngödsla",
    "gröngödslanden": "gröngödslande",
    "gröngödslandena": "gröngödslande",
    "gröngödslandenas": "gröngödslande",
    "gröngödslandens": "gröngödslande",
    "gröngödslandes": "gröngödslande",
    "gröngödslandet": "gröngödslande",
    "gröngödslandets": "gröngödslande",
    "gröngödslar": "gröngödsla",
    "gröngödslas": "gröngödsla",
    "gröngödslat": "gröngödsla",
    "gröngödslats": "gröngödsla",
    "gröngödslingar": "gröngödsling",
    "gröngödslingarna": "gröngödsling",
    "gröngödslingarnas": "gröngödsling",
    "gröngödslingars": "gröngödsling",
    "gröngödslingen": "gröngödsling",
    "gröngödslingens": "gröngödsling",
    "gröngödslings": "gröngödsling",
    "gröngölingar": "gröngöling",
    "gröngölingarna": "gröngöling",
    "gröngölingarnas": "gröngöling",
    "gröngölingars": "gröngöling",
    "gröngölingen": "gröngöling",
    "gröngölingens": "gröngöling",
    "gröngölings": "gröngöling",
    "grönheten": "grönhet",
    "grönhetens": "grönhet",
    "grönhets": "grönhet",
    "gröningar": "gröning",
    "gröningarna": "gröning",
    "gröningarnas": "gröning",
    "gröningars": "gröning",
    "gröningen": "gröning",
    "gröningens": "gröning",
    "grönings": "gröning",
    "grönkull": "grönkulla",
    "grönkullan": "grönkulla",
    "grönkullans": "grönkulla",
    "grönkullas": "grönkulla",
    "grönkulle": "grönkulla",
    "grönkullor": "grönkulla",
    "grönkullorna": "grönkulla",
    "grönkullornas": "grönkulla",
    "grönkullors": "grönkulla",
    "grönkulls": "grönkulla",
    "grönkålen": "grönkål",
    "grönkålens": "grönkål",
    "grönkåls": "grönkål",
    "grönköpings": "grönköping",
    "grönköpingsmässiga": "grönköpingsmässig",
    "grönköpingsmässigare": "grönköpingsmässig",
    "grönköpingsmässigares": "grönköpingsmässig",
    "grönköpingsmässigas": "grönköpingsmässig",
    "grönköpingsmässigast": "grönköpingsmässig",
    "grönköpingsmässigaste": "grönköpingsmässig",
    "grönköpingsmässigastes": "grönköpingsmässig",
    "grönköpingsmässigasts": "grönköpingsmässig",
    "grönköpingsmässige": "grönköpingsmässig",
    "grönköpingsmässiges": "grönköpingsmässig",
    "grönköpingsmässigheten": "grönköpingsmässighet",
    "grönköpingsmässighetens": "grönköpingsmässighet",
    "grönköpingsmässighets": "grönköpingsmässighet",
    "grönköpingsmässigs": "grönköpingsmässig",
    "grönköpingsmässigt": "grönköpingsmässig",
    "grönköpingsmässigts": "grönköpingsmässig",
    "grönlandsvalar": "grönlandsval",
    "grönlandsvalarna": "grönlandsval",
    "grönlandsvalarnas": "grönlandsval",
    "grönlandsvalars": "grönlandsval",
    "grönlandsvalen": "grönlandsval",
    "grönlandsvalens": "grönlandsval",
    "grönlandsvals": "grönlandsval",
    "grönlingar": "grönling",
    "grönlingarna": "grönling",
    "grönlingarnas": "grönling",
    "grönlingars": "grönling",
    "grönlingen": "grönling",
    "grönlingens": "grönling",
    "grönlings": "grönling",
    "grönländar": "grönländare",
    "grönländaren": "grönländare",
    "grönländarens": "grönländare",
    "grönländares": "grönländare",
    "grönländarna": "grönländare",
    "grönländarnas": "grönländare",
    "grönländsk": "grönländska",
    "grönländska": "grönländsk",
    "grönländskan": "grönländska",
    "grönländskans": "grönländska",
    "grönländskare": "grönländsk",
    "grönländskares": "grönländsk",
    "grönländskas": "grönländska",
    "grönländskast": "grönländsk",
    "grönländskaste": "grönländsk",
    "grönländskastes": "grönländsk",
    "grönländskasts": "grönländsk",
    "grönländske": "grönländska",
    "grönländskes": "grönländsk",
    "grönländskor": "grönländska",
    "grönländskorna": "grönländska",
    "grönländskornas": "grönländska",
    "grönländskors": "grönländska",
    "grönländsks": "grönländsk",
    "grönländskt": "grönländsk",
    "grönländskts": "grönländsk",
    "grönmalten": "grönmalt",
    "grönmaltens": "grönmalt",
    "grönmaltet": "grönmalt",
    "grönmaltets": "grönmalt",
    "grönmalts": "grönmalt",
    "grönmogens": "grönmogen",
    "grönmoget": "grönmogen",
    "grönmogets": "grönmogen",
    "grönmogna": "grönmogen",
    "grönmognaden": "grönmognad",
    "grönmognadens": "grönmognad",
    "grönmognader": "grönmognad",
    "grönmognaderna": "grönmognad",
    "grönmognadernas": "grönmognad",
    "grönmognaders": "grönmognad",
    "grönmognads": "grönmognad",
    "grönmognare": "grönmogen",
    "grönmognares": "grönmogen",
    "grönmognas": "grönmogen",
    "grönmognast": "grönmogen",
    "grönmognaste": "grönmogen",
    "grönmognastes": "grönmogen",
    "grönmognasts": "grönmogen",
    "grönmogne": "grönmogen",
    "grönmognes": "grönmogen",
    "grönmålade": "grönmålad",
    "grönmålades": "grönmålad",
    "grönmålads": "grönmålad",
    "grönmålat": "grönmålad",
    "grönmålats": "grönmålad",
    "grönmögelostar": "grönmögelost",
    "grönmögelostarna": "grönmögelost",
    "grönmögelostarnas": "grönmögelost",
    "grönmögelostars": "grönmögelost",
    "grönmögelosten": "grönmögelost",
    "grönmögelostens": "grönmögelost",
    "grönmögelosts": "grönmögelost",
    "grönmögels": "grönmögel",
    "grönmöglet": "grönmögel",
    "grönmöglets": "grönmögel",
    "grönmörka": "grönmörk",
    "grönmörkare": "grönmörk",
    "grönmörkares": "grönmörk",
    "grönmörkas": "grönmörk",
    "grönmörkast": "grönmörk",
    "grönmörkaste": "grönmörk",
    "grönmörkastes": "grönmörk",
    "grönmörkasts": "grönmörk",
    "grönmörke": "grönmörk",
    "grönmörkes": "grönmörk",
    "grönmörks": "grönmörk",
    "grönmörkt": "grönmörk",
    "grönmörkts": "grönmörk",
    "grönområden": "grönområde",
    "grönområdena": "grönområde",
    "grönområdenas": "grönområde",
    "grönområdens": "grönområde",
    "grönområdes": "grönområde",
    "grönområdet": "grönområde",
    "grönområdets": "grönområde",
    "grönpepparn": "grönpeppar",
    "grönpepparns": "grönpeppar",
    "grönpeppars": "grönpeppar",
    "grönrätten": "grönrätt",
    "grönrättens": "grönrätt",
    "grönrätter": "grönrätt",
    "grönrätterna": "grönrätt",
    "grönrätternas": "grönrätt",
    "grönrätters": "grönrätt",
    "grönrätts": "grönrätt",
    "gröns": "grön",
    "grönsaken": "grönsak",
    "grönsakens": "grönsak",
    "grönsaker": "grönsak",
    "grönsakerna": "grönsaker",
    "grönsakernas": "grönsaker",
    "grönsakers": "grönsaker",
    "grönsaks": "grönsaker",
    "grönsaksblandningar": "grönsaksblandning",
    "grönsaksblandningarna": "grönsaksblandning",
    "grönsaksblandningarnas": "grönsaksblandning",
    "grönsaksblandningars": "grönsaksblandning",
    "grönsaksblandningen": "grönsaksblandning",
    "grönsaksblandningens": "grönsaksblandning",
    "grönsaksblandnings": "grönsaksblandning",
    "grönsakssopp": "grönsakssoppa",
    "grönsakssoppan": "grönsakssoppa",
    "grönsakssoppans": "grönsakssoppa",
    "grönsakssoppas": "grönsakssoppa",
    "grönsakssoppe": "grönsakssoppa",
    "grönsakssoppor": "grönsakssoppa",
    "grönsakssopporna": "grönsakssoppa",
    "grönsakssoppornas": "grönsakssoppa",
    "grönsakssoppors": "grönsakssoppa",
    "grönsakssopps": "grönsakssoppa",
    "grönsakstallrikar": "grönsakstallrik",
    "grönsakstallrikarna": "grönsakstallrik",
    "grönsakstallrikarnas": "grönsakstallrik",
    "grönsakstallrikars": "grönsakstallrik",
    "grönsakstallriken": "grönsakstallrik",
    "grönsakstallrikens": "grönsakstallrik",
    "grönsakstallriks": "grönsakstallrik",
    "grönsalladen": "grönsallad",
    "grönsalladens": "grönsallad",
    "grönsallader": "grönsallad",
    "grönsalladerna": "grönsallad",
    "grönsalladernas": "grönsallad",
    "grönsalladers": "grönsallad",
    "grönsallads": "grönsallad",
    "grönsiskan": "grönsiska",
    "grönsiskans": "grönsiska",
    "grönsiskas": "grönsiska",
    "grönsiske": "grönsiska",
    "grönsiskor": "grönsiska",
    "grönsiskorna": "grönsiska",
    "grönsiskornas": "grönsiska",
    "grönsiskors": "grönsiska",
    "grönskade": "grönska",
    "grönskades": "grönska",
    "grönskan": "grönska",
    "grönskande": "grönska",
    "grönskanden": "grönskande",
    "grönskandena": "grönskande",
    "grönskandenas": "grönskande",
    "grönskandens": "grönskande",
    "grönskandes": "grönskande",
    "grönskandet": "grönskande",
    "grönskandets": "grönskande",
    "grönskans": "grönska",
    "grönskar": "grönska",
    "grönskas": "grönska",
    "grönskat": "grönska",
    "grönskats": "grönska",
    "grönsoppan": "grönsoppa",
    "grönsoppans": "grönsoppa",
    "grönsoppas": "grönsoppa",
    "grönspettar": "grönspett",
    "grönspettarna": "grönspett",
    "grönspettarnas": "grönspett",
    "grönspettars": "grönspett",
    "grönspetten": "grönspett",
    "grönspettens": "grönspett",
    "grönspetts": "grönspett",
    "grönt": "grön",
    "grönts": "grön",
    "grönytan": "grönyta",
    "grönytans": "grönyta",
    "grönytas": "grönyta",
    "grönyte": "grönyta",
    "grönytor": "grönyta",
    "grönytorna": "grönyta",
    "grönytornas": "grönyta",
    "grönytors": "grönyta",
    "gröp": "gröpa",
    "gröpad": "gröpa",
    "gröpade": "gröpa",
    "gröpades": "gröpa",
    "gröpads": "gröpa",
    "gröpande": "gröpa",
    "gröpanden": "gröpande",
    "gröpandena": "gröpande",
    "gröpandenas": "gröpande",
    "gröpandens": "gröpande",
    "gröpandes": "gröpande",
    "gröpandet": "gröpande",
    "gröpandets": "gröpande",
    "gröpar": "gröpa",
    "gröpas": "gröpa",
    "gröpat": "gröpa",
    "gröpats": "gröpa",
    "gröpes": "gröpe",
    "gröpet": "gröpe",
    "gröpets": "gröpe",
    "gröpningar": "gröpning",
    "gröpningarna": "gröpning",
    "gröpningarnas": "gröpning",
    "gröpningars": "gröpning",
    "gröpningen": "gröpning",
    "gröpningens": "gröpning",
    "gröpnings": "gröpning",
    "grötade": "gröta",
    "grötades": "gröta",
    "grötande": "gröta",
    "grötanden": "grötande",
    "grötandena": "grötande",
    "grötandenas": "grötande",
    "grötandens": "grötande",
    "grötandes": "grötande",
    "grötandet": "grötande",
    "grötandets": "grötande",
    "grötar": "gröta",
    "grötarna": "gröt",
    "grötarnas": "gröt",
    "grötars": "gröt",
    "grötas": "gröta",
    "grötat": "gröta",
    "grötats": "gröta",
    "gröten": "gröt",
    "grötens": "gröt",
    "grötfrukostar": "grötfrukost",
    "grötfrukostarna": "grötfrukost",
    "grötfrukostarnas": "grötfrukost",
    "grötfrukostars": "grötfrukost",
    "grötfrukosten": "grötfrukost",
    "grötfrukostens": "grötfrukost",
    "grötfrukosts": "grötfrukost",
    "grötiga": "grötig",
    "grötigare": "grötig",
    "grötigares": "grötig",
    "grötigas": "grötig",
    "grötigast": "grötig",
    "grötigaste": "grötig",
    "grötigastes": "grötig",
    "grötigasts": "grötig",
    "grötige": "grötig",
    "grötiges": "grötig",
    "grötigs": "grötig",
    "grötigt": "grötig",
    "grötigts": "grötig",
    "grötlunken": "grötlunk",
    "grötlunkens": "grötlunk",
    "grötlunks": "grötlunk",
    "grötmyndiga": "grötmyndig",
    "grötmyndigare": "grötmyndig",
    "grötmyndigares": "grötmyndig",
    "grötmyndigas": "grötmyndig",
    "grötmyndigast": "grötmyndig",
    "grötmyndigaste": "grötmyndig",
    "grötmyndigastes": "grötmyndig",
    "grötmyndigasts": "grötmyndig",
    "grötmyndige": "grötmyndig",
    "grötmyndiges": "grötmyndig",
    "grötmyndigheten": "grötmyndighet",
    "grötmyndighetens": "grötmyndighet",
    "grötmyndighets": "grötmyndighet",
    "grötmyndigs": "grötmyndig",
    "grötmyndigt": "grötmyndig",
    "grötmyndigts": "grötmyndig",
    "grötomslagen": "grötomslag",
    "grötomslagens": "grötomslag",
    "grötomslaget": "grötomslag",
    "grötomslagets": "grötomslag",
    "grötomslags": "grötomslag",
    "grötrimmen": "grötrim",
    "grötrimmens": "grötrim",
    "grötrimmet": "grötrim",
    "grötrimmets": "grötrim",
    "grötrims": "grötrim",
    "grötrockar": "grötrock",
    "grötrockarna": "grötrock",
    "grötrockarnas": "grötrock",
    "grötrockars": "grötrock",
    "grötrocken": "grötrock",
    "grötrockens": "grötrock",
    "grötrocks": "grötrock",
    "gröts": "gröt",
    "grövre": "grov",
    "grövres": "grov",
    "grövst": "grov",
    "grövsta": "grov",
    "grövstas": "grov",
    "grövste": "grov",
    "grövstes": "grov",
    "grövsts": "grov",
    "guaniner": "guanin",
    "guaninerna": "guanin",
    "guaninernas": "guanin",
    "guaniners": "guanin",
    "guaninet": "guanin",
    "guaninets": "guanin",
    "guanins": "guanin",
    "guanon": "guano",
    "guanons": "guano",
    "guanos": "guano",
    "guanot": "guano",
    "guanots": "guano",
    "guaranis": "guarani",
    "guatemalanen": "guatemalan",
    "guatemalanens": "guatemalan",
    "guatemalaner": "guatemalan",
    "guatemalanerna": "guatemalan",
    "guatemalanernas": "guatemalan",
    "guatemalaners": "guatemalan",
    "guatemalans": "guatemalan",
    "guatemalanska": "guatemalansk",
    "guatemalanskan": "guatemalanska",
    "guatemalanskans": "guatemalanska",
    "guatemalanskare": "guatemalansk",
    "guatemalanskares": "guatemalansk",
    "guatemalanskas": "guatemalanska",
    "guatemalanskast": "guatemalansk",
    "guatemalanskaste": "guatemalansk",
    "guatemalanskastes": "guatemalansk",
    "guatemalanskasts": "guatemalansk",
    "guatemalanske": "guatemalanska",
    "guatemalanskes": "guatemalansk",
    "guatemalanskor": "guatemalanska",
    "guatemalanskorna": "guatemalanska",
    "guatemalanskornas": "guatemalanska",
    "guatemalanskors": "guatemalanska",
    "guatemalansks": "guatemalansk",
    "guatemalanskt": "guatemalansk",
    "guatemalanskts": "guatemalansk",
    "guatemalteken": "guatemaltek",
    "guatemaltekens": "guatemaltek",
    "guatemalteker": "guatemaltek",
    "guatemaltekerna": "guatemaltek",
    "guatemaltekernas": "guatemaltek",
    "guatemaltekers": "guatemaltek",
    "guatemaltekiska": "guatemaltekisk",
    "guatemaltekiskare": "guatemaltekisk",
    "guatemaltekiskares": "guatemaltekisk",
    "guatemaltekiskas": "guatemaltekisk",
    "guatemaltekiskast": "guatemaltekisk",
    "guatemaltekiskaste": "guatemaltekisk",
    "guatemaltekiskastes": "guatemaltekisk",
    "guatemaltekiskasts": "guatemaltekisk",
    "guatemaltekiske": "guatemaltekisk",
    "guatemaltekiskes": "guatemaltekisk",
    "guatemaltekisks": "guatemaltekisk",
    "guatemaltekiskt": "guatemaltekisk",
    "guatemaltekiskts": "guatemaltekisk",
    "guatemalteks": "guatemaltek",
    "guayananen": "guayanan",
    "guayananens": "guayanan",
    "guayananer": "guayanan",
    "guayananerna": "guayanan",
    "guayananernas": "guayanan",
    "guayananers": "guayanan",
    "guayanans": "guayanan",
    "guayanska": "guayansk",
    "guayanskare": "guayansk",
    "guayanskares": "guayansk",
    "guayanskas": "guayansk",
    "guayanskast": "guayansk",
    "guayanskaste": "guayansk",
    "guayanskastes": "guayansk",
    "guayanskasts": "guayansk",
    "guayanske": "guayansk",
    "guayanskes": "guayansk",
    "guayansks": "guayansk",
    "guayanskt": "guayansk",
    "guayanskts": "guayansk",
    "gubb": "gubbe",
    "gubbar": "gubbe",
    "gubbarna": "gubbe",
    "gubbarnas": "gubbe",
    "gubbars": "gubbe",
    "gubben": "gubbe",
    "gubbens": "gubbe",
    "gubbes": "gubbe",
    "gubbiga": "gubbig",
    "gubbigare": "gubbig",
    "gubbigares": "gubbig",
    "gubbigas": "gubbig",
    "gubbigast": "gubbig",
    "gubbigaste": "gubbig",
    "gubbigastes": "gubbig",
    "gubbigasts": "gubbig",
    "gubbige": "gubbig",
    "gubbiges": "gubbig",
    "gubbigheten": "gubbighet",
    "gubbighetens": "gubbighet",
    "gubbighets": "gubbighet",
    "gubbigs": "gubbig",
    "gubbigt": "gubbig",
    "gubbigts": "gubbig",
    "gubbkalsong": "gubbkalsonger",
    "gubbkalsongerna": "gubbkalsonger",
    "gubbkalsongernas": "gubbkalsonger",
    "gubbkalsongers": "gubbkalsonger",
    "gubbkalsongs": "gubbkalsonger",
    "gubbs": "gubbe",
    "gubbsen": "gubbs",
    "gubbsens": "gubbs",
    "gubbsjuka": "gubbsjuk",
    "gubbsjukan": "gubbsjuka",
    "gubbsjukans": "gubbsjuka",
    "gubbsjukare": "gubbsjuk",
    "gubbsjukares": "gubbsjuk",
    "gubbsjukas": "gubbsjuka",
    "gubbsjukast": "gubbsjuk",
    "gubbsjukaste": "gubbsjuk",
    "gubbsjukastes": "gubbsjuk",
    "gubbsjukasts": "gubbsjuk",
    "gubbsjuke": "gubbsjuka",
    "gubbsjukes": "gubbsjuk",
    "gubbsjukheten": "gubbsjukhet",
    "gubbsjukhetens": "gubbsjukhet",
    "gubbsjukhets": "gubbsjukhet",
    "gubbsjuks": "gubbsjuka",
    "gubbsjukt": "gubbsjuk",
    "gubbsjukts": "gubbsjuk",
    "gubbstruttar": "gubbstrutt",
    "gubbstruttarna": "gubbstrutt",
    "gubbstruttarnas": "gubbstrutt",
    "gubbstruttars": "gubbstrutt",
    "gubbstrutten": "gubbstrutt",
    "gubbstruttens": "gubbstrutt",
    "gubbstrutts": "gubbstrutt",
    "gubbträsken": "gubbträsk",
    "gubbträskens": "gubbträsk",
    "gubbträsket": "gubbträsk",
    "gubbträskets": "gubbträsk",
    "gubbträsks": "gubbträsk",
    "gubbvälden": "gubbvälde",
    "gubbväldena": "gubbvälde",
    "gubbväldenas": "gubbvälde",
    "gubbväldens": "gubbvälde",
    "gubbväldes": "gubbvälde",
    "gubbväldet": "gubbvälde",
    "gubbväldets": "gubbvälde",
    "guckuskon": "guckusko",
    "guckuskons": "guckusko",
    "guckuskor": "guckusko",
    "guckuskorna": "guckusko",
    "guckuskornas": "guckusko",
    "guckuskors": "guckusko",
    "guckuskos": "guckusko",
    "gudabeläten": "gudabeläte",
    "gudabelätena": "gudabeläte",
    "gudabelätenas": "gudabeläte",
    "gudabelätens": "gudabeläte",
    "gudabelätes": "gudabeläte",
    "gudabelätet": "gudabeläte",
    "gudabelätets": "gudabeläte",
    "gudabeläts": "gudabeläte",
    "gudabenådade": "gudabenådad",
    "gudabenådades": "gudabenådad",
    "gudabenådads": "gudabenådad",
    "gudabenådat": "gudabenådad",
    "gudabenådats": "gudabenådad",
    "gudabilden": "gudabild",
    "gudabildens": "gudabild",
    "gudabilder": "gudabild",
    "gudabilderna": "gudabild",
    "gudabildernas": "gudabild",
    "gudabilders": "gudabild",
    "gudabilds": "gudabild",
    "gudagåvan": "gudagåva",
    "gudagåvans": "gudagåva",
    "gudagåvas": "gudagåva",
    "gudagåve": "gudagåva",
    "gudagåvo": "gudagåva",
    "gudagåvor": "gudagåva",
    "gudagåvorna": "gudagåva",
    "gudagåvornas": "gudagåva",
    "gudagåvors": "gudagåva",
    "gudaktiga": "gudaktig",
    "gudaktigare": "gudaktig",
    "gudaktigares": "gudaktig",
    "gudaktigas": "gudaktig",
    "gudaktigast": "gudaktig",
    "gudaktigaste": "gudaktig",
    "gudaktigastes": "gudaktig",
    "gudaktigasts": "gudaktig",
    "gudaktige": "gudaktig",
    "gudaktiges": "gudaktig",
    "gudaktigheten": "gudaktighet",
    "gudaktighetens": "gudaktighet",
    "gudaktighets": "gudaktighet",
    "gudaktigs": "gudaktig",
    "gudaktigt": "gudaktig",
    "gudaktigts": "gudaktig",
    "gudaläran": "gudalära",
    "gudalärans": "gudalära",
    "gudaläras": "gudalära",
    "gudaläre": "gudalära",
    "gudaläro": "gudalära",
    "gudaläror": "gudalära",
    "gudalärorna": "gudalära",
    "gudalärornas": "gudalära",
    "gudalärors": "gudalära",
    "gudar": "gud",
    "gudarna": "gud",
    "gudarnas": "gud",
    "gudars": "gud",
    "gudasagan": "gudasaga",
    "gudasagans": "gudasaga",
    "gudasagas": "gudasaga",
    "gudasage": "gudasaga",
    "gudasago": "gudasaga",
    "gudasagor": "gudasaga",
    "gudasagorna": "gudasaga",
    "gudasagornas": "gudasaga",
    "gudasagors": "gudasaga",
    "gudaskymningar": "gudaskymning",
    "gudaskymningarna": "gudaskymning",
    "gudaskymningarnas": "gudaskymning",
    "gudaskymningars": "gudaskymning",
    "gudaskymningen": "gudaskymning",
    "gudaskymningens": "gudaskymning",
    "gudaskymnings": "gudaskymning",
    "gudasända": "gudasänd",
    "gudasändare": "gudasänd",
    "gudasändares": "gudasänd",
    "gudasändas": "gudasänd",
    "gudasändast": "gudasänd",
    "gudasändaste": "gudasänd",
    "gudasändastes": "gudasänd",
    "gudasändasts": "gudasänd",
    "gudasände": "gudasänd",
    "gudasändes": "gudasänd",
    "gudasänds": "gudasänd",
    "gudasänt": "gudasänd",
    "gudasänts": "gudasänd",
    "gudbarnen": "gudbarn",
    "gudbarnens": "gudbarn",
    "gudbarnet": "gudbarn",
    "gudbarnets": "gudbarn",
    "gudbarns": "gudbarn",
    "guddottern": "guddotter",
    "guddotterns": "guddotter",
    "guddotters": "guddotter",
    "guddöttrar": "guddotter",
    "guddöttrarna": "guddotter",
    "guddöttrarnas": "guddotter",
    "guddöttrars": "guddotter",
    "gudeliga": "gudelig",
    "gudeligare": "gudelig",
    "gudeligares": "gudelig",
    "gudeligas": "gudelig",
    "gudeligast": "gudelig",
    "gudeligaste": "gudelig",
    "gudeligastes": "gudelig",
    "gudeligasts": "gudelig",
    "gudelige": "gudelig",
    "gudeliges": "gudelig",
    "gudeligheten": "gudelighet",
    "gudelighetens": "gudelighet",
    "gudelighets": "gudelighet",
    "gudeligs": "gudelig",
    "gudeligt": "gudelig",
    "gudeligts": "gudelig",
    "guden": "gud",
    "gudens": "gud",
    "gudfader": "gudfar",
    "gudfadern": "gudfar",
    "gudfaderns": "gudfar",
    "gudfaders": "gudfar",
    "gudfars": "gudfar",
    "gudfasder": "gudfar",
    "gudfruktiga": "gudfruktig",
    "gudfruktigare": "gudfruktig",
    "gudfruktigares": "gudfruktig",
    "gudfruktigas": "gudfruktig",
    "gudfruktigast": "gudfruktig",
    "gudfruktigaste": "gudfruktig",
    "gudfruktigastes": "gudfruktig",
    "gudfruktigasts": "gudfruktig",
    "gudfruktige": "gudfruktig",
    "gudfruktiges": "gudfruktig",
    "gudfruktigheten": "gudfruktighet",
    "gudfruktighetens": "gudfruktighet",
    "gudfruktighets": "gudfruktighet",
    "gudfruktigs": "gudfruktig",
    "gudfruktigt": "gudfruktig",
    "gudfruktigts": "gudfruktig",
    "gudfäder": "gudfar",
    "gudfäderna": "gudfar",
    "gudfädernas": "gudfar",
    "gudfäders": "gudfar",
    "gudingar": "guding",
    "gudingarna": "guding",
    "gudingarnas": "guding",
    "gudingars": "guding",
    "gudingen": "guding",
    "gudingens": "guding",
    "gudings": "guding",
    "gudinnan": "gudinna",
    "gudinnans": "gudinna",
    "gudinnas": "gudinna",
    "gudinne": "gudinna",
    "gudinnor": "gudinna",
    "gudinnorna": "gudinna",
    "gudinnornas": "gudinna",
    "gudinnors": "gudinna",
    "gudliga": "gudlig",
    "gudligare": "gudlig",
    "gudligares": "gudlig",
    "gudligas": "gudlig",
    "gudligast": "gudlig",
    "gudligaste": "gudlig",
    "gudligastes": "gudlig",
    "gudligasts": "gudlig",
    "gudlige": "gudlig",
    "gudliges": "gudlig",
    "gudligheten": "gudlighet",
    "gudlighetens": "gudlighet",
    "gudlighets": "gudlighet",
    "gudligs": "gudlig",
    "gudligt": "gudlig",
    "gudligts": "gudlig",
    "gudlösa": "gudlös",
    "gudlösare": "gudlös",
    "gudlösares": "gudlös",
    "gudlösas": "gudlös",
    "gudlösast": "gudlös",
    "gudlösaste": "gudlös",
    "gudlösastes": "gudlös",
    "gudlösasts": "gudlös",
    "gudlöse": "gudlös",
    "gudlöses": "gudlös",
    "gudlösheten": "gudlöshet",
    "gudlöshetens": "gudlöshet",
    "gudlöshets": "gudlöshet",
    "gudlöst": "gudlös",
    "gudlösts": "gudlös",
    "gudmodern": "gudmoder",
    "gudmoderns": "gudmoder",
    "gudmoders": "gudmoder",
    "gudmor": "gudmoder",
    "gudmors": "gudmoder",
    "gudmödrar": "gudmoder",
    "gudmödrarna": "gudmoder",
    "gudmödrarnas": "gudmoder",
    "gudmödrars": "gudmoder",
    "gudomar": "gudom",
    "gudomarna": "gudom",
    "gudomarnas": "gudom",
    "gudomars": "gudom",
    "gudomen": "gudom",
    "gudomens": "gudom",
    "gudomliga": "gudomlig",
    "gudomligare": "gudomlig",
    "gudomligares": "gudomlig",
    "gudomligas": "gudomlig",
    "gudomligast": "gudomlig",
    "gudomligaste": "gudomlig",
    "gudomligastes": "gudomlig",
    "gudomligasts": "gudomlig",
    "gudomlige": "gudomlig",
    "gudomliges": "gudomlig",
    "gudomligheten": "gudomlighet",
    "gudomlighetens": "gudomlighet",
    "gudomligheter": "gudomlighet",
    "gudomligheterna": "gudomlighet",
    "gudomligheternas": "gudomlighet",
    "gudomligheters": "gudomlighet",
    "gudomlighets": "gudomlighet",
    "gudomligs": "gudomlig",
    "gudomligt": "gudomlig",
    "gudomligts": "gudomlig",
    "gudoms": "gudom",
    "gudsbevisen": "gudsbevis",
    "gudsbevisens": "gudsbevis",
    "gudsbeviset": "gudsbevis",
    "gudsbevisets": "gudsbevis",
    "gudsbilden": "gudsbild",
    "gudsbildens": "gudsbild",
    "gudsbilder": "gudsbild",
    "gudsbilderna": "gudsbild",
    "gudsbildernas": "gudsbild",
    "gudsbilders": "gudsbild",
    "gudsbilds": "gudsbild",
    "gudsdomar": "gudsdom",
    "gudsdomarna": "gudsdom",
    "gudsdomarnas": "gudsdom",
    "gudsdomars": "gudsdom",
    "gudsdomen": "gudsdom",
    "gudsdomens": "gudsdom",
    "gudsdoms": "gudsdom",
    "gudsfreden": "gudsfred",
    "gudsfredens": "gudsfred",
    "gudsfreds": "gudsfred",
    "gudsfruktans": "gudsfruktan",
    "gudsförgätenheten": "gudsförgätenhet",
    "gudsförgätenhetens": "gudsförgätenhet",
    "gudsförgätenhets": "gudsförgätenhet",
    "gudsförgätens": "gudsförgäten",
    "gudsförgätet": "gudsförgäten",
    "gudsförgätets": "gudsförgäten",
    "gudsförgätna": "gudsförgäten",
    "gudsförgätnare": "gudsförgäten",
    "gudsförgätnares": "gudsförgäten",
    "gudsförgätnas": "gudsförgäten",
    "gudsförgätnast": "gudsförgäten",
    "gudsförgätnaste": "gudsförgäten",
    "gudsförgätnastes": "gudsförgäten",
    "gudsförgätnasts": "gudsförgäten",
    "gudsförgätne": "gudsförgäten",
    "gudsförgätnes": "gudsförgäten",
    "gudsförnekar": "gudsförnekare",
    "gudsförnekaren": "gudsförnekare",
    "gudsförnekarens": "gudsförnekare",
    "gudsförnekares": "gudsförnekare",
    "gudsförnekarna": "gudsförnekare",
    "gudsförnekarnas": "gudsförnekare",
    "gudsförnekelsen": "gudsförnekelse",
    "gudsförnekelsens": "gudsförnekelse",
    "gudsförnekelser": "gudsförnekelse",
    "gudsförnekelserna": "gudsförnekelse",
    "gudsförnekelsernas": "gudsförnekelse",
    "gudsförnekelsers": "gudsförnekelse",
    "gudsförnekelses": "gudsförnekelse",
    "gudslånen": "gudslån",
    "gudslånens": "gudslån",
    "gudslånet": "gudslån",
    "gudslånets": "gudslån",
    "gudslåns": "gudslån",
    "gudsmannen": "gudsman",
    "gudsmannens": "gudsman",
    "gudsmans": "gudsman",
    "gudsmän": "gudsman",
    "gudsmännen": "gudsman",
    "gudsmännens": "gudsman",
    "gudsmäns": "gudsman",
    "gudsnådeliga": "gudsnådelig",
    "gudsnådeligare": "gudsnådelig",
    "gudsnådeligares": "gudsnådelig",
    "gudsnådeligas": "gudsnådelig",
    "gudsnådeligast": "gudsnådelig",
    "gudsnådeligaste": "gudsnådelig",
    "gudsnådeligastes": "gudsnådelig",
    "gudsnådeligasts": "gudsnådelig",
    "gudsnådelige": "gudsnådelig",
    "gudsnådeliges": "gudsnådelig",
    "gudsnådeligheten": "gudsnådelighet",
    "gudsnådelighetens": "gudsnådelighet",
    "gudsnådelighets": "gudsnådelighet",
    "gudsnådeligs": "gudsnådelig",
    "gudsnådeligt": "gudsnådelig",
    "gudsnådeligts": "gudsnådelig",
    "gudsnådliga": "gudsnådlig",
    "gudsnådligare": "gudsnådlig",
    "gudsnådligares": "gudsnådlig",
    "gudsnådligas": "gudsnådlig",
    "gudsnådligast": "gudsnådlig",
    "gudsnådligaste": "gudsnådlig",
    "gudsnådligastes": "gudsnådlig",
    "gudsnådligasts": "gudsnådlig",
    "gudsnådlige": "gudsnådlig",
    "gudsnådliges": "gudsnådlig",
    "gudsnådligheten": "gudsnådlighet",
    "gudsnådlighetens": "gudsnådlighet",
    "gudsnådlighets": "gudsnådlighet",
    "gudsnådligs": "gudsnådlig",
    "gudsnådligt": "gudsnådlig",
    "gudsnådligts": "gudsnådlig",
    "gudsonen": "gudson",
    "gudsonens": "gudson",
    "gudsons": "gudson",
    "gudsorden": "gudsord",
    "gudsordens": "gudsord",
    "gudsordet": "gudsord",
    "gudsordets": "gudsord",
    "gudsords": "gudsord",
    "gudstjänstbesökar": "gudstjänstbesökare",
    "gudstjänstbesökaren": "gudstjänstbesökare",
    "gudstjänstbesökarens": "gudstjänstbesökare",
    "gudstjänstbesökares": "gudstjänstbesökare",
    "gudstjänstbesökarna": "gudstjänstbesökare",
    "gudstjänstbesökarnas": "gudstjänstbesökare",
    "gudstjänstdagar": "gudstjänstdag",
    "gudstjänstdagarna": "gudstjänstdag",
    "gudstjänstdagarnas": "gudstjänstdag",
    "gudstjänstdagars": "gudstjänstdag",
    "gudstjänstdagen": "gudstjänstdag",
    "gudstjänstdagens": "gudstjänstdag",
    "gudstjänstdags": "gudstjänstdag",
    "gudstjänstdan": "gudstjänstdag",
    "gudstjänstdans": "gudstjänstdag",
    "gudstjänstdar": "gudstjänstdag",
    "gudstjänstdarna": "gudstjänstdag",
    "gudstjänstdarnas": "gudstjänstdag",
    "gudstjänstdars": "gudstjänstdag",
    "gudstjänsten": "gudstjänst",
    "gudstjänstens": "gudstjänst",
    "gudstjänster": "gudstjänst",
    "gudstjänsterna": "gudstjänst",
    "gudstjänsternas": "gudstjänst",
    "gudstjänsters": "gudstjänst",
    "gudstjänstfrekvensen": "gudstjänstfrekvens",
    "gudstjänstfrekvensens": "gudstjänstfrekvens",
    "gudstjänstfrekvenser": "gudstjänstfrekvens",
    "gudstjänstfrekvenserna": "gudstjänstfrekvens",
    "gudstjänstfrekvensernas": "gudstjänstfrekvens",
    "gudstjänstfrekvensers": "gudstjänstfrekvens",
    "gudstjänstritualen": "gudstjänstritual",
    "gudstjänstritualens": "gudstjänstritual",
    "gudstjänstritualer": "gudstjänstritual",
    "gudstjänstritualerna": "gudstjänstritual",
    "gudstjänstritualernas": "gudstjänstritual",
    "gudstjänstritualers": "gudstjänstritual",
    "gudstjänstritualet": "gudstjänstritual",
    "gudstjänstritualets": "gudstjänstritual",
    "gudstjänstrituals": "gudstjänstritual",
    "gudstjänsts": "gudstjänst",
    "gudstron": "gudstro",
    "gudstrons": "gudstro",
    "gudstros": "gudstro",
    "gudsupplevelsen": "gudsupplevelse",
    "gudsupplevelsens": "gudsupplevelse",
    "gudsupplevelser": "gudsupplevelse",
    "gudsupplevelserna": "gudsupplevelse",
    "gudsupplevelsernas": "gudsupplevelse",
    "gudsupplevelsers": "gudsupplevelse",
    "gudsupplevelses": "gudsupplevelse",
    "gudsöner": "gudson",
    "gudsönerna": "gudson",
    "gudsönernas": "gudson",
    "gudsöners": "gudson",
    "gudungar": "gudunge",
    "gudungarna": "gudunge",
    "gudungarnas": "gudunge",
    "gudungars": "gudunge",
    "gudungen": "gudunge",
    "gudungens": "gudunge",
    "gudunges": "gudunge",
    "guid": "guida",
    "guidad": "guida",
    "guidade": "guida",
    "guidades": "guida",
    "guidads": "guida",
    "guidande": "guida",
    "guidanden": "guidande",
    "guidandena": "guidande",
    "guidandenas": "guidande",
    "guidandens": "guidande",
    "guidandes": "guidande",
    "guidandet": "guidande",
    "guidandets": "guidande",
    "guidar": "guida",
    "guidas": "guida",
    "guidat": "guida",
    "guidats": "guida",
    "guiden": "guide",
    "guidens": "guide",
    "guider": "guide",
    "guiderna": "guide",
    "guidernas": "guide",
    "guiders": "guide",
    "guides": "guide",
    "guinean": "guinea",
    "guineanen": "guinean",
    "guineanens": "guinean",
    "guineaner": "guinean",
    "guineanerna": "guinean",
    "guineanernas": "guinean",
    "guineaners": "guinean",
    "guineans": "guinean",
    "guineanska": "guineansk",
    "guineanskan": "guineanska",
    "guineanskans": "guineanska",
    "guineanskare": "guineansk",
    "guineanskares": "guineansk",
    "guineanskas": "guineanska",
    "guineanskast": "guineansk",
    "guineanskaste": "guineansk",
    "guineanskastes": "guineansk",
    "guineanskasts": "guineansk",
    "guineanske": "guineanska",
    "guineanskes": "guineansk",
    "guineanskor": "guineanska",
    "guineanskorna": "guineanska",
    "guineanskornas": "guineanska",
    "guineanskors": "guineanska",
    "guineansks": "guineansk",
    "guineanskt": "guineansk",
    "guineanskts": "guineansk",
    "guineas": "guinea",
    "guineasarna": "guinea",
    "guineasarnas": "guinea",
    "guineasen": "guinea",
    "guineasens": "guinea",
    "gujaratis": "gujarati",
    "gul": "gula",
    "gula": "gul",
    "gulaktiga": "gulaktig",
    "gulaktigare": "gulaktig",
    "gulaktigares": "gulaktig",
    "gulaktigas": "gulaktig",
    "gulaktigast": "gulaktig",
    "gulaktigaste": "gulaktig",
    "gulaktigastes": "gulaktig",
    "gulaktigasts": "gulaktig",
    "gulaktige": "gulaktig",
    "gulaktiges": "gulaktig",
    "gulaktigheten": "gulaktighet",
    "gulaktighetens": "gulaktighet",
    "gulaktighets": "gulaktighet",
    "gulaktigs": "gulaktig",
    "gulaktigt": "gulaktig",
    "gulaktigts": "gulaktig",
    "gulan": "gula",
    "gulans": "gula",
    "gulare": "gul",
    "gulares": "gul",
    "gulas": "gula",
    "gulaschbaronen": "gulaschbaron",
    "gulaschbaronens": "gulaschbaron",
    "gulaschbaroner": "gulaschbaron",
    "gulaschbaronerna": "gulaschbaron",
    "gulaschbaronernas": "gulaschbaron",
    "gulaschbaroners": "gulaschbaron",
    "gulaschbarons": "gulaschbaron",
    "gulaschen": "gulasch",
    "gulaschens": "gulasch",
    "gulascher": "gulasch",
    "gulascherna": "gulasch",
    "gulaschernas": "gulasch",
    "gulaschers": "gulasch",
    "gulaschs": "gulasch",
    "gulast": "gul",
    "gulaste": "gul",
    "gulastes": "gul",
    "gulasts": "gul",
    "gulbleka": "gulblek",
    "gulblekare": "gulblek",
    "gulblekares": "gulblek",
    "gulblekas": "gulblek",
    "gulblekast": "gulblek",
    "gulblekaste": "gulblek",
    "gulblekastes": "gulblek",
    "gulblekasts": "gulblek",
    "gulbleke": "gulblek",
    "gulblekes": "gulblek",
    "gulblekheten": "gulblekhet",
    "gulblekhetens": "gulblekhet",
    "gulblekhets": "gulblekhet",
    "gulbleks": "gulblek",
    "gulblekt": "gulblek",
    "gulblekts": "gulblek",
    "gulblommiga": "gulblommig",
    "gulblommigare": "gulblommig",
    "gulblommigares": "gulblommig",
    "gulblommigas": "gulblommig",
    "gulblommigast": "gulblommig",
    "gulblommigaste": "gulblommig",
    "gulblommigastes": "gulblommig",
    "gulblommigasts": "gulblommig",
    "gulblommige": "gulblommig",
    "gulblommiges": "gulblommig",
    "gulblommigs": "gulblommig",
    "gulblommigt": "gulblommig",
    "gulblommigts": "gulblommig",
    "gulblås": "gulblåsa",
    "gulblåsan": "gulblåsa",
    "gulblåsans": "gulblåsa",
    "gulblåsas": "gulblåsa",
    "gulblåse": "gulblåsa",
    "gulblåsor": "gulblåsa",
    "gulblåsorna": "gulblåsa",
    "gulblåsornas": "gulblåsa",
    "gulblåsors": "gulblåsa",
    "gulbruna": "gulbrun",
    "gulbrunare": "gulbrun",
    "gulbrunares": "gulbrun",
    "gulbrunas": "gulbrun",
    "gulbrunast": "gulbrun",
    "gulbrunaste": "gulbrun",
    "gulbrunastes": "gulbrun",
    "gulbrunasts": "gulbrun",
    "gulbrune": "gulbrun",
    "gulbrunes": "gulbrun",
    "gulbruns": "gulbrun",
    "gulbrunt": "gulbrun",
    "gulbrunts": "gulbrun",
    "guldbagg": "guldbagge",
    "guldbaggar": "guldbagge",
    "guldbaggarna": "guldbagge",
    "guldbaggarnas": "guldbagge",
    "guldbaggars": "guldbagge",
    "guldbaggen": "guldbagge",
    "guldbaggens": "guldbagge",
    "guldbagges": "guldbagge",
    "guldbaggs": "guldbagge",
    "guldbarren": "guldbarr",
    "guldbarrens": "guldbarr",
    "guldbarrer": "guldbarr",
    "guldbarrerna": "guldbarr",
    "guldbarrernas": "guldbarr",
    "guldbarrers": "guldbarr",
    "guldbarrs": "guldbarr",
    "guldberlocken": "guldberlock",
    "guldberlockens": "guldberlock",
    "guldberlocker": "guldberlock",
    "guldberlockerna": "guldberlock",
    "guldberlockernas": "guldberlock",
    "guldberlockers": "guldberlock",
    "guldberlocks": "guldberlock",
    "guldbröllopen": "guldbröllop",
    "guldbröllopens": "guldbröllop",
    "guldbröllopet": "guldbröllop",
    "guldbröllopets": "guldbröllop",
    "guldbröllops": "guldbröllop",
    "guldbären": "guldbär",
    "guldbärens": "guldbär",
    "guldbäret": "guldbär",
    "guldbärets": "guldbär",
    "guldbärs": "guldbär",
    "guldbågade": "guldbågad",
    "guldbågades": "guldbågad",
    "guldbågads": "guldbågad",
    "guldbågat": "guldbågad",
    "guldbågats": "guldbågad",
    "gulddoublén": "gulddoublé",
    "gulddoubléns": "gulddoublé",
    "gulddoublés": "gulddoublé",
    "gulddragerier": "gulddrageri",
    "gulddragerierna": "gulddrageri",
    "gulddrageriernas": "gulddrageri",
    "gulddrageriers": "gulddrageri",
    "gulddrageriet": "gulddrageri",
    "gulddrageriets": "gulddrageri",
    "gulddrageris": "gulddrageri",
    "gulddragerit": "gulddrageri",
    "gulddragerits": "gulddrageri",
    "gulddubblén": "gulddubblé",
    "gulddubbléns": "gulddubblé",
    "gulddubblés": "gulddubblé",
    "gulde": "gälda",
    "gulden": "guld",
    "guldenen": "gulden",
    "guldenens": "gulden",
    "guldens": "gulden",
    "guldes": "gälda",
    "guldet": "guld",
    "guldets": "guld",
    "guldfasanen": "guldfasan",
    "guldfasanens": "guldfasan",
    "guldfasaner": "guldfasan",
    "guldfasanerna": "guldfasan",
    "guldfasanernas": "guldfasan",
    "guldfasaners": "guldfasan",
    "guldfasans": "guldfasan",
    "guldfebern": "guldfeber",
    "guldfeberns": "guldfeber",
    "guldfebers": "guldfeber",
    "guldfiskar": "guldfisk",
    "guldfiskarna": "guldfisk",
    "guldfiskarnas": "guldfisk",
    "guldfiskars": "guldfisk",
    "guldfisken": "guldfisk",
    "guldfiskens": "guldfisk",
    "guldfisks": "guldfisk",
    "guldfuxar": "guldfux",
    "guldfuxarna": "guldfux",
    "guldfuxarnas": "guldfux",
    "guldfuxars": "guldfux",
    "guldfuxen": "guldfux",
    "guldfuxens": "guldfux",
    "guldfynden": "guldfynd",
    "guldfyndens": "guldfynd",
    "guldfyndet": "guldfynd",
    "guldfyndets": "guldfynd",
    "guldfynds": "guldfynd",
    "guldföremålen": "guldföremål",
    "guldföremålens": "guldföremål",
    "guldföremålet": "guldföremål",
    "guldföremålets": "guldföremål",
    "guldföremåls": "guldföremål",
    "guldgruv": "guldgruva",
    "guldgruvan": "guldgruva",
    "guldgruvans": "guldgruva",
    "guldgruvas": "guldgruva",
    "guldgruve": "guldgruva",
    "guldgruvor": "guldgruva",
    "guldgruvorna": "guldgruva",
    "guldgruvornas": "guldgruva",
    "guldgruvors": "guldgruva",
    "guldgruvs": "guldgruva",
    "guldgrävar": "guldgrävare",
    "guldgrävaren": "guldgrävare",
    "guldgrävarens": "guldgrävare",
    "guldgrävares": "guldgrävare",
    "guldgrävarna": "guldgrävare",
    "guldgrävarnas": "guldgrävare",
    "guldhalten": "guldhalt",
    "guldhaltens": "guldhalt",
    "guldhalter": "guldhalt",
    "guldhalterna": "guldhalt",
    "guldhalternas": "guldhalt",
    "guldhalters": "guldhalt",
    "guldhalts": "guldhalt",
    "guldhönan": "guldhöna",
    "guldhönans": "guldhöna",
    "guldhönas": "guldhöna",
    "guldhöne": "guldhöna",
    "guldhönor": "guldhöna",
    "guldhönorna": "guldhöna",
    "guldhönornas": "guldhöna",
    "guldhönors": "guldhöna",
    "guldkalvar": "guldkalv",
    "guldkalvarna": "guldkalv",
    "guldkalvarnas": "guldkalv",
    "guldkalvars": "guldkalv",
    "guldkalven": "guldkalv",
    "guldkalvens": "guldkalv",
    "guldkalvs": "guldkalv",
    "guldkantade": "guldkantad",
    "guldkantades": "guldkantad",
    "guldkantads": "guldkantad",
    "guldkantat": "guldkantad",
    "guldkantats": "guldkantad",
    "guldkanten": "guldkant",
    "guldkantens": "guldkant",
    "guldkanter": "guldkant",
    "guldkanterna": "guldkant",
    "guldkanternas": "guldkant",
    "guldkanters": "guldkant",
    "guldkants": "guldkant",
    "guldkedjan": "guldkedja",
    "guldkedjans": "guldkedja",
    "guldkedjas": "guldkedja",
    "guldkedje": "guldkedja",
    "guldkedjor": "guldkedja",
    "guldkedjorna": "guldkedja",
    "guldkedjornas": "guldkedja",
    "guldkedjors": "guldkedja",
    "guldklimpar": "guldklimp",
    "guldklimparna": "guldklimp",
    "guldklimparnas": "guldklimp",
    "guldklimpars": "guldklimp",
    "guldklimpen": "guldklimp",
    "guldklimpens": "guldklimp",
    "guldklimps": "guldklimp",
    "guldklock": "guldklocka",
    "guldklockan": "guldklocka",
    "guldklockans": "guldklocka",
    "guldklockas": "guldklocka",
    "guldklocke": "guldklocka",
    "guldklockor": "guldklocka",
    "guldklockorna": "guldklocka",
    "guldklockornas": "guldklocka",
    "guldklockors": "guldklocka",
    "guldklocks": "guldklocka",
    "guldkornen": "guldkorn",
    "guldkornens": "guldkorn",
    "guldkornet": "guldkorn",
    "guldkornets": "guldkorn",
    "guldkorns": "guldkorn",
    "guldkranar": "guldkran",
    "guldkranarna": "guldkran",
    "guldkranarnas": "guldkran",
    "guldkranars": "guldkran",
    "guldkranen": "guldkran",
    "guldkranens": "guldkran",
    "guldkrans": "guldkran",
    "guldkrogar": "guldkrog",
    "guldkrogarna": "guldkrog",
    "guldkrogarnas": "guldkrog",
    "guldkrogars": "guldkrog",
    "guldkrogen": "guldkrog",
    "guldkrogens": "guldkrog",
    "guldkrogs": "guldkrog",
    "guldkron": "guldkrona",
    "guldkronan": "guldkrona",
    "guldkronans": "guldkrona",
    "guldkronas": "guldkrona",
    "guldkrone": "guldkrona",
    "guldkronor": "guldkrona",
    "guldkronorna": "guldkrona",
    "guldkronornas": "guldkrona",
    "guldkronors": "guldkrona",
    "guldkrons": "guldkrona",
    "guldlegeringar": "guldlegering",
    "guldlegeringarna": "guldlegering",
    "guldlegeringarnas": "guldlegering",
    "guldlegeringars": "guldlegering",
    "guldlegeringen": "guldlegering",
    "guldlegeringens": "guldlegering",
    "guldlegerings": "guldlegering",
    "guldmakar": "guldmakare",
    "guldmakaren": "guldmakare",
    "guldmakarens": "guldmakare",
    "guldmakares": "guldmakare",
    "guldmakarna": "guldmakare",
    "guldmakarnas": "guldmakare",
    "guldmakerier": "guldmakeri",
    "guldmakerierna": "guldmakeri",
    "guldmakeriernas": "guldmakeri",
    "guldmakeriers": "guldmakeri",
    "guldmakeriet": "guldmakeri",
    "guldmakeriets": "guldmakeri",
    "guldmakeris": "guldmakeri",
    "guldmakerit": "guldmakeri",
    "guldmakerits": "guldmakeri",
    "guldmakrillar": "guldmakrill",
    "guldmakrillarna": "guldmakrill",
    "guldmakrillarnas": "guldmakrill",
    "guldmakrillars": "guldmakrill",
    "guldmakrillen": "guldmakrill",
    "guldmakrillens": "guldmakrill",
    "guldmakrills": "guldmakrill",
    "guldmedaljen": "guldmedalj",
    "guldmedaljens": "guldmedalj",
    "guldmedaljer": "guldmedalj",
    "guldmedaljerna": "guldmedalj",
    "guldmedaljernas": "guldmedalj",
    "guldmedaljers": "guldmedalj",
    "guldmedaljs": "guldmedalj",
    "guldmedaljören": "guldmedaljör",
    "guldmedaljörens": "guldmedaljör",
    "guldmedaljörer": "guldmedaljör",
    "guldmedaljörerna": "guldmedaljör",
    "guldmedaljörernas": "guldmedaljör",
    "guldmedaljörers": "guldmedaljör",
    "guldmedaljörs": "guldmedaljör",
    "guldmynten": "guldmynt",
    "guldmyntens": "guldmynt",
    "guldmyntet": "guldmynt",
    "guldmyntets": "guldmynt",
    "guldmyntfoten": "guldmyntfot",
    "guldmyntfotens": "guldmyntfot",
    "guldmyntfots": "guldmyntfot",
    "guldmynts": "guldmynt",
    "guldna": "gälda",
    "guldnas": "gälda",
    "guldne": "gälda",
    "guldnes": "gälda",
    "guldpenn": "guldpenna",
    "guldpennan": "guldpenna",
    "guldpennans": "guldpenna",
    "guldpennas": "guldpenna",
    "guldpenne": "guldpenna",
    "guldpennor": "guldpenna",
    "guldpennorna": "guldpenna",
    "guldpennornas": "guldpenna",
    "guldpennors": "guldpenna",
    "guldpenns": "guldpenna",
    "guldplantsar": "guldplants",
    "guldplantsarna": "guldplants",
    "guldplantsarnas": "guldplants",
    "guldplantsars": "guldplants",
    "guldplantsen": "guldplants",
    "guldplantsens": "guldplants",
    "guldpressningar": "guldpressning",
    "guldpressningarna": "guldpressning",
    "guldpressningarnas": "guldpressning",
    "guldpressningars": "guldpressning",
    "guldpressningen": "guldpressning",
    "guldpressningens": "guldpressning",
    "guldpressnings": "guldpressning",
    "guldprisen": "guldpris",
    "guldprisens": "guldpris",
    "guldpriser": "guldpris",
    "guldpriserna": "guldpris",
    "guldprisernas": "guldpris",
    "guldprisers": "guldpris",
    "guldpriset": "guldpris",
    "guldprisets": "guldpris",
    "guldproven": "guldprov",
    "guldprovens": "guldprov",
    "guldprovet": "guldprov",
    "guldprovets": "guldprov",
    "guldprovs": "guldprov",
    "guldpunkten": "guldpunkt",
    "guldpunktens": "guldpunkt",
    "guldpunkts": "guldpunkt",
    "guldpärl": "guldpärla",
    "guldpärlan": "guldpärla",
    "guldpärlans": "guldpärla",
    "guldpärlas": "guldpärla",
    "guldpärle": "guldpärla",
    "guldpärlor": "guldpärla",
    "guldpärlorna": "guldpärla",
    "guldpärlornas": "guldpärla",
    "guldpärlors": "guldpärla",
    "guldpärls": "guldpärla",
    "guldregnet": "guldregn",
    "guldregnets": "guldregn",
    "guldregns": "guldregn",
    "guldreserven": "guldreserv",
    "guldreservens": "guldreserv",
    "guldreserver": "guldreserv",
    "guldreserverna": "guldreserv",
    "guldreservernas": "guldreserv",
    "guldreservers": "guldreserv",
    "guldreservs": "guldreserv",
    "guldruschen": "guldrusch",
    "guldruschens": "guldrusch",
    "guldruscher": "guldrusch",
    "guldruscherna": "guldrusch",
    "guldruschernas": "guldrusch",
    "guldruschers": "guldrusch",
    "guldruschs": "guldrusch",
    "guldrushen": "guldrush",
    "guldrushens": "guldrush",
    "guldrusher": "guldrush",
    "guldrusherna": "guldrush",
    "guldrushernas": "guldrush",
    "guldrushers": "guldrush",
    "guldrushs": "guldrush",
    "gulds": "guld",
    "guldsanden": "guldsand",
    "guldsandens": "guldsand",
    "guldsands": "guldsand",
    "guldslagar": "guldslagare",
    "guldslagaren": "guldslagare",
    "guldslagarens": "guldslagare",
    "guldslagares": "guldslagare",
    "guldslagarna": "guldslagare",
    "guldslagarnas": "guldslagare",
    "guldslagerier": "guldslageri",
    "guldslagerierna": "guldslageri",
    "guldslageriernas": "guldslageri",
    "guldslageriers": "guldslageri",
    "guldslageriet": "guldslageri",
    "guldslageriets": "guldslageri",
    "guldslageris": "guldslageri",
    "guldslagerit": "guldslageri",
    "guldslagerits": "guldslageri",
    "guldsmeden": "guldsmed",
    "guldsmedens": "guldsmed",
    "guldsmeder": "guldsmed",
    "guldsmederna": "guldsmed",
    "guldsmedernas": "guldsmed",
    "guldsmeders": "guldsmed",
    "guldsmeds": "guldsmed",
    "guldsmidda": "guldsmidd",
    "guldsmiddare": "guldsmidd",
    "guldsmiddares": "guldsmidd",
    "guldsmiddas": "guldsmidd",
    "guldsmiddast": "guldsmidd",
    "guldsmiddaste": "guldsmidd",
    "guldsmiddastes": "guldsmidd",
    "guldsmiddasts": "guldsmidd",
    "guldsmidde": "guldsmidd",
    "guldsmiddes": "guldsmidd",
    "guldsmidds": "guldsmidd",
    "guldsmiden": "guldsmide",
    "guldsmidena": "guldsmide",
    "guldsmidenas": "guldsmide",
    "guldsmidens": "guldsmide",
    "guldsmides": "guldsmide",
    "guldsmidet": "guldsmide",
    "guldsmidets": "guldsmide",
    "guldsmitt": "guldsmidd",
    "guldsmitts": "guldsmidd",
    "guldsnitten": "guldsnitt",
    "guldsnittens": "guldsnitt",
    "guldsnittet": "guldsnitt",
    "guldsnittets": "guldsnitt",
    "guldsnitts": "guldsnitt",
    "guldstekeln": "guldstekel",
    "guldstekelns": "guldstekel",
    "guldstekels": "guldstekel",
    "guldsteklar": "guldstekel",
    "guldsteklarna": "guldstekel",
    "guldsteklarnas": "guldstekel",
    "guldsteklars": "guldstekel",
    "guldstickade": "guldstickad",
    "guldstickades": "guldstickad",
    "guldstickads": "guldstickad",
    "guldstickat": "guldstickad",
    "guldstickats": "guldstickad",
    "guldstriden": "guldstrid",
    "guldstridens": "guldstrid",
    "guldstrider": "guldstrid",
    "guldstriderna": "guldstrid",
    "guldstridernas": "guldstrid",
    "guldstriders": "guldstrid",
    "guldstrids": "guldstrid",
    "guldstämpeln": "guldstämpel",
    "guldstämpelns": "guldstämpel",
    "guldstämpels": "guldstämpel",
    "guldstämplar": "guldstämpel",
    "guldstämplarna": "guldstämpel",
    "guldstämplarnas": "guldstämpel",
    "guldstämplars": "guldstämpel",
    "guldtack": "guldtacka",
    "guldtackan": "guldtacka",
    "guldtackans": "guldtacka",
    "guldtackas": "guldtacka",
    "guldtacke": "guldtacka",
    "guldtackor": "guldtacka",
    "guldtackorna": "guldtacka",
    "guldtackornas": "guldtacka",
    "guldtackors": "guldtacka",
    "guldtacks": "guldtacka",
    "guldtanden": "guldtand",
    "guldtandens": "guldtand",
    "guldtands": "guldtand",
    "guldtrådar": "guldtråd",
    "guldtrådarna": "guldtråd",
    "guldtrådarnas": "guldtråd",
    "guldtrådars": "guldtråd",
    "guldtråden": "guldtråd",
    "guldtrådens": "guldtråd",
    "guldtråds": "guldtråd",
    "guldtäckningar": "guldtäckning",
    "guldtäckningarna": "guldtäckning",
    "guldtäckningarnas": "guldtäckning",
    "guldtäckningars": "guldtäckning",
    "guldtäckningen": "guldtäckning",
    "guldtäckningens": "guldtäckning",
    "guldtäcknings": "guldtäckning",
    "guldtänder": "guldtand",
    "guldtänderna": "guldtand",
    "guldtändernas": "guldtand",
    "guldtänders": "guldtand",
    "guldtörsten": "guldtörst",
    "guldtörstens": "guldtörst",
    "guldtörsts": "guldtörst",
    "guldvaskningar": "guldvaskning",
    "guldvaskningarna": "guldvaskning",
    "guldvaskningarnas": "guldvaskning",
    "guldvaskningars": "guldvaskning",
    "guldvaskningen": "guldvaskning",
    "guldvaskningens": "guldvaskning",
    "guldvasknings": "guldvaskning",
    "guldvågar": "guldvåg",
    "guldvågarna": "guldvåg",
    "guldvågarnas": "guldvåg",
    "guldvågars": "guldvåg",
    "guldvågen": "guldvåg",
    "guldvågens": "guldvåg",
    "guldvågs": "guldvåg",
    "guldäpplen": "guldäpple",
    "guldäpplena": "guldäpple",
    "guldäpplenas": "guldäpple",
    "guldäpplens": "guldäpple",
    "guldäpples": "guldäpple",
    "guldäpplet": "guldäpple",
    "guldäpplets": "guldäpple",
    "guldäppls": "guldäpple",
    "guldåldern": "guldålder",
    "guldålderns": "guldålder",
    "guldålders": "guldålder",
    "guldåldrar": "guldålder",
    "guldåldrarna": "guldålder",
    "guldåldrarnas": "guldålder",
    "guldåldrars": "guldålder",
    "gule": "gula",
    "gules": "gul",
    "gulesäckar": "gulesäck",
    "gulesäckarna": "gulesäck",
    "gulesäckarnas": "gulesäck",
    "gulesäckars": "gulesäck",
    "gulesäcken": "gulesäck",
    "gulesäckens": "gulesäck",
    "gulesäcks": "gulesäck",
    "gulfilterna": "gulfilter",
    "gulfilternas": "gulfilter",
    "gulfilters": "gulfilter",
    "gulfiltren": "gulfilter",
    "gulfiltrens": "gulfilter",
    "gulfiltret": "gulfilter",
    "gulfiltrets": "gulfilter",
    "gulfärg": "gulfärga",
    "gulfärgad": "gulfärga",
    "gulfärgade": "gulfärgad",
    "gulfärgades": "gulfärgad",
    "gulfärgads": "gulfärgad",
    "gulfärgande": "gulfärga",
    "gulfärganden": "gulfärgande",
    "gulfärgandena": "gulfärgande",
    "gulfärgandenas": "gulfärgande",
    "gulfärgandens": "gulfärgande",
    "gulfärgandes": "gulfärgande",
    "gulfärgandet": "gulfärgande",
    "gulfärgandets": "gulfärgande",
    "gulfärgar": "gulfärga",
    "gulfärgas": "gulfärga",
    "gulfärgat": "gulfärgad",
    "gulfärgats": "gulfärgad",
    "gulfärgningar": "gulfärgning",
    "gulfärgningarna": "gulfärgning",
    "gulfärgningarnas": "gulfärgning",
    "gulfärgningars": "gulfärgning",
    "gulfärgningen": "gulfärgning",
    "gulfärgningens": "gulfärgning",
    "gulfärgnings": "gulfärgning",
    "gulgråa": "gulgrå",
    "gulgråare": "gulgrå",
    "gulgråares": "gulgrå",
    "gulgråas": "gulgrå",
    "gulgråast": "gulgrå",
    "gulgråaste": "gulgrå",
    "gulgråastes": "gulgrå",
    "gulgråasts": "gulgrå",
    "gulgråe": "gulgrå",
    "gulgråes": "gulgrå",
    "gulgrås": "gulgrå",
    "gulgrått": "gulgrå",
    "gulgråtts": "gulgrå",
    "gulingar": "guling",
    "gulingarna": "guling",
    "gulingarnas": "guling",
    "gulingars": "guling",
    "gulingen": "guling",
    "gulingens": "guling",
    "gulings": "guling",
    "gulkroppar": "gulkropp",
    "gulkropparna": "gulkropp",
    "gulkropparnas": "gulkropp",
    "gulkroppars": "gulkropp",
    "gulkroppen": "gulkropp",
    "gulkroppens": "gulkropp",
    "gulkropps": "gulkropp",
    "gull": "gulla",
    "gullade": "gulla",
    "gullades": "gulla",
    "gullande": "gulla",
    "gullanden": "gullande",
    "gullandena": "gullande",
    "gullandenas": "gullande",
    "gullandens": "gullande",
    "gullandes": "gullande",
    "gullandet": "gullande",
    "gullandets": "gullande",
    "gullar": "gulla",
    "gullas": "gulla",
    "gullat": "gulla",
    "gullats": "gulla",
    "gullebrands": "gullebrand",
    "gullegrisar": "gullegris",
    "gullegrisarna": "gullegris",
    "gullegrisarnas": "gullegris",
    "gullegrisars": "gullegris",
    "gullegrisen": "gullegris",
    "gullegrisens": "gullegris",
    "gullen": "gull",
    "gullens": "gull",
    "gullet": "gull",
    "gullets": "gull",
    "gullgoss": "gullgosse",
    "gullgossar": "gullgosse",
    "gullgossarna": "gullgosse",
    "gullgossarnas": "gullgosse",
    "gullgossars": "gullgosse",
    "gullgossen": "gullgosse",
    "gullgossens": "gullgosse",
    "gullgosses": "gullgosse",
    "gullgrisar": "gullgris",
    "gullgrisarna": "gullgris",
    "gullgrisarnas": "gullgris",
    "gullgrisars": "gullgris",
    "gullgrisen": "gullgris",
    "gullgrisens": "gullgris",
    "gullhönan": "gullhöna",
    "gullhönans": "gullhöna",
    "gullhönas": "gullhöna",
    "gullhöne": "gullhöna",
    "gullhönor": "gullhöna",
    "gullhönorna": "gullhöna",
    "gullhönornas": "gullhöna",
    "gullhönors": "gullhöna",
    "gulliga": "gullig",
    "gulligare": "gullig",
    "gulligares": "gullig",
    "gulligas": "gullig",
    "gulligast": "gullig",
    "gulligaste": "gullig",
    "gulligastes": "gullig",
    "gulligasts": "gullig",
    "gullige": "gullig",
    "gulliges": "gullig",
    "gulligheten": "gullighet",
    "gullighetens": "gullighet",
    "gulligheter": "gullighet",
    "gulligheterna": "gullighet",
    "gulligheternas": "gullighet",
    "gulligheters": "gullighet",
    "gullighets": "gullighet",
    "gulligs": "gullig",
    "gulligt": "gullig",
    "gulligts": "gullig",
    "gullpudr": "gullpudra",
    "gullpudran": "gullpudra",
    "gullpudrans": "gullpudra",
    "gullpudras": "gullpudra",
    "gullpudre": "gullpudra",
    "gullpudror": "gullpudra",
    "gullpudrorna": "gullpudra",
    "gullpudrornas": "gullpudra",
    "gullpudrors": "gullpudra",
    "gullpudrs": "gullpudra",
    "gullregnet": "gullregn",
    "gullregnets": "gullregn",
    "gullregns": "gullregn",
    "gullriset": "gullris",
    "gullrisets": "gullris",
    "gulls": "gull",
    "gulltraven": "gulltrav",
    "gulltravens": "gulltrav",
    "gulltravs": "gulltrav",
    "gullviv": "gullviva",
    "gullvivan": "gullviva",
    "gullvivans": "gullviva",
    "gullvivas": "gullviva",
    "gullvive": "gullviva",
    "gullvivor": "gullviva",
    "gullvivorna": "gullviva",
    "gullvivornas": "gullviva",
    "gullvivors": "gullviva",
    "gullvivs": "gullviva",
    "gulmetallen": "gulmetall",
    "gulmetallens": "gulmetall",
    "gulmetalls": "gulmetall",
    "gulmålade": "gulmålad",
    "gulmålades": "gulmålad",
    "gulmålads": "gulmålad",
    "gulmålat": "gulmålad",
    "gulmålats": "gulmålad",
    "gulmåran": "gulmåra",
    "gulmårans": "gulmåra",
    "gulmåras": "gulmåra",
    "gulmåre": "gulmåra",
    "gulmåror": "gulmåra",
    "gulmårorna": "gulmåra",
    "gulmårornas": "gulmåra",
    "gulmårors": "gulmåra",
    "gulnad": "gulna",
    "gulnade": "gulna",
    "gulnaden": "gulnad",
    "gulnadens": "gulnad",
    "gulnader": "gulnad",
    "gulnaderna": "gulnad",
    "gulnadernas": "gulnad",
    "gulnaders": "gulnad",
    "gulnades": "gulna",
    "gulnads": "gulnad",
    "gulnande": "gulna",
    "gulnanden": "gulnande",
    "gulnandena": "gulnande",
    "gulnandenas": "gulnande",
    "gulnandens": "gulnande",
    "gulnandes": "gulnande",
    "gulnandet": "gulnande",
    "gulnandets": "gulnande",
    "gulnar": "gulna",
    "gulnas": "gulna",
    "gulnat": "gulna",
    "gulnats": "gulna",
    "gulningar": "gulning",
    "gulningarna": "gulning",
    "gulningarnas": "gulning",
    "gulningars": "gulning",
    "gulningen": "gulning",
    "gulningens": "gulning",
    "gulnings": "gulning",
    "gulor": "gula",
    "gulorna": "gula",
    "gulornas": "gula",
    "gulors": "gula",
    "gulrutiga": "gulrutig",
    "gulrutigare": "gulrutig",
    "gulrutigares": "gulrutig",
    "gulrutigas": "gulrutig",
    "gulrutigast": "gulrutig",
    "gulrutigaste": "gulrutig",
    "gulrutigastes": "gulrutig",
    "gulrutigasts": "gulrutig",
    "gulrutige": "gulrutig",
    "gulrutiges": "gulrutig",
    "gulrutigs": "gulrutig",
    "gulrutigt": "gulrutig",
    "gulrutigts": "gulrutig",
    "gulröda": "gulröd",
    "gulrödare": "gulröd",
    "gulrödares": "gulröd",
    "gulrödas": "gulröd",
    "gulrödast": "gulröd",
    "gulrödaste": "gulröd",
    "gulrödastes": "gulröd",
    "gulrödasts": "gulröd",
    "gulröde": "gulröd",
    "gulrödes": "gulröd",
    "gulröds": "gulröd",
    "gulrött": "gulröd",
    "gulrötts": "gulröd",
    "guls": "gula",
    "gulsiktiga": "gulsiktig",
    "gulsiktigare": "gulsiktig",
    "gulsiktigares": "gulsiktig",
    "gulsiktigas": "gulsiktig",
    "gulsiktigast": "gulsiktig",
    "gulsiktigaste": "gulsiktig",
    "gulsiktigastes": "gulsiktig",
    "gulsiktigasts": "gulsiktig",
    "gulsiktige": "gulsiktig",
    "gulsiktiges": "gulsiktig",
    "gulsiktigheten": "gulsiktighet",
    "gulsiktighetens": "gulsiktighet",
    "gulsiktighets": "gulsiktighet",
    "gulsiktigs": "gulsiktig",
    "gulsiktigt": "gulsiktig",
    "gulsiktigts": "gulsiktig",
    "gulsipp": "gulsippa",
    "gulsippan": "gulsippa",
    "gulsippans": "gulsippa",
    "gulsippas": "gulsippa",
    "gulsippe": "gulsippa",
    "gulsippor": "gulsippa",
    "gulsipporna": "gulsippa",
    "gulsippornas": "gulsippa",
    "gulsippors": "gulsippa",
    "gulsipps": "gulsippa",
    "gulskivan": "gulskiva",
    "gulskivans": "gulskiva",
    "gulskivas": "gulskiva",
    "gulskive": "gulskiva",
    "gulskivor": "gulskiva",
    "gulskivorna": "gulskiva",
    "gulskivornas": "gulskiva",
    "gulskivors": "gulskiva",
    "gulsoten": "gulsot",
    "gulsotens": "gulsot",
    "gulsots": "gulsot",
    "gulsparvar": "gulsparv",
    "gulsparvarna": "gulsparv",
    "gulsparvarnas": "gulsparv",
    "gulsparvars": "gulsparv",
    "gulsparven": "gulsparv",
    "gulsparvens": "gulsparv",
    "gulsparvs": "gulsparv",
    "gulsporr": "gulsporre",
    "gulsporrar": "gulsporre",
    "gulsporrarna": "gulsporre",
    "gulsporrarnas": "gulsporre",
    "gulsporrars": "gulsporre",
    "gulsporren": "gulsporre",
    "gulsporrens": "gulsporre",
    "gulsporres": "gulsporre",
    "gulsporrs": "gulsporre",
    "gulsäckar": "gulsäck",
    "gulsäckarna": "gulsäck",
    "gulsäckarnas": "gulsäck",
    "gulsäckars": "gulsäck",
    "gulsäcken": "gulsäck",
    "gulsäckens": "gulsäck",
    "gulsäcks": "gulsäck",
    "gult": "gul",
    "gults": "gul",
    "gultörnes": "gultörne",
    "gultörnet": "gultörne",
    "gultörnets": "gultörne",
    "gulvialen": "gulvial",
    "gulvialens": "gulvial",
    "gulvials": "gulvial",
    "gulvita": "gulvit",
    "gulvitare": "gulvit",
    "gulvitares": "gulvit",
    "gulvitas": "gulvit",
    "gulvitast": "gulvit",
    "gulvitaste": "gulvit",
    "gulvitastes": "gulvit",
    "gulvitasts": "gulvit",
    "gulvite": "gulvit",
    "gulvites": "gulvit",
    "gulvits": "gulvit",
    "gulvitt": "gulvit",
    "gulvitts": "gulvit",
    "gum": "gumma",
    "gumman": "gumma",
    "gummans": "gumma",
    "gummas": "gumma",
    "gumme": "gumma",
    "gummerad": "gummera",
    "gummerade": "gummera",
    "gummerades": "gummera",
    "gummerads": "gummera",
    "gummerande": "gummera",
    "gummeranden": "gummerande",
    "gummerandena": "gummerande",
    "gummerandenas": "gummerande",
    "gummerandens": "gummerande",
    "gummerandes": "gummerande",
    "gummerandet": "gummerande",
    "gummerandets": "gummerande",
    "gummerar": "gummera",
    "gummeras": "gummera",
    "gummerat": "gummera",
    "gummerats": "gummera",
    "gummerbara": "gummerbar",
    "gummerbarare": "gummerbar",
    "gummerbarares": "gummerbar",
    "gummerbaras": "gummerbar",
    "gummerbarast": "gummerbar",
    "gummerbaraste": "gummerbar",
    "gummerbarastes": "gummerbar",
    "gummerbarasts": "gummerbar",
    "gummerbare": "gummerbar",
    "gummerbares": "gummerbar",
    "gummerbarheten": "gummerbarhet",
    "gummerbarhetens": "gummerbarhet",
    "gummerbarhets": "gummerbarhet",
    "gummerbars": "gummerbar",
    "gummerbart": "gummerbar",
    "gummerbarts": "gummerbar",
    "gummeringar": "gummering",
    "gummeringarna": "gummering",
    "gummeringarnas": "gummering",
    "gummeringars": "gummering",
    "gummeringen": "gummering",
    "gummeringens": "gummering",
    "gummerings": "gummering",
    "gummibanden": "gummiband",
    "gummibandens": "gummiband",
    "gummibandet": "gummiband",
    "gummibandets": "gummiband",
    "gummibands": "gummiband",
    "gummibeklädda": "gummibeklädd",
    "gummibekläddare": "gummibeklädd",
    "gummibekläddares": "gummibeklädd",
    "gummibekläddas": "gummibeklädd",
    "gummibekläddast": "gummibeklädd",
    "gummibekläddaste": "gummibeklädd",
    "gummibekläddastes": "gummibeklädd",
    "gummibekläddasts": "gummibeklädd",
    "gummibeklädde": "gummibeklädd",
    "gummibekläddes": "gummibeklädd",
    "gummibeklädds": "gummibeklädd",
    "gummibeklätt": "gummibeklädd",
    "gummibeklätts": "gummibeklädd",
    "gummibåtar": "gummibåt",
    "gummibåtarna": "gummibåt",
    "gummibåtarnas": "gummibåt",
    "gummibåtars": "gummibåt",
    "gummibåten": "gummibåt",
    "gummibåtens": "gummibåt",
    "gummibåts": "gummibåt",
    "gummidäcken": "gummidäck",
    "gummidäckens": "gummidäck",
    "gummidäcket": "gummidäck",
    "gummidäckets": "gummidäck",
    "gummidäcks": "gummidäck",
    "gummiguttan": "gummigutta",
    "gummiguttans": "gummigutta",
    "gummiguttas": "gummigutta",
    "gummihandsk": "gummihandske",
    "gummihandskar": "gummihandske",
    "gummihandskarna": "gummihandske",
    "gummihandskarnas": "gummihandske",
    "gummihandskars": "gummihandske",
    "gummihandsken": "gummihandske",
    "gummihandskens": "gummihandske",
    "gummihandskes": "gummihandske",
    "gummihartser": "gummiharts",
    "gummihartserna": "gummiharts",
    "gummihartsernas": "gummiharts",
    "gummihartsers": "gummiharts",
    "gummihartset": "gummiharts",
    "gummihartsets": "gummiharts",
    "gummihjulen": "gummihjul",
    "gummihjulens": "gummihjul",
    "gummihjulet": "gummihjul",
    "gummihjulets": "gummihjul",
    "gummihjuls": "gummihjul",
    "gummikabeln": "gummikabel",
    "gummikabelns": "gummikabel",
    "gummikabels": "gummikabel",
    "gummikablar": "gummikabel",
    "gummikablarna": "gummikabel",
    "gummikablarnas": "gummikabel",
    "gummikablars": "gummikabel",
    "gummimaterialen": "gummimaterial",
    "gummimaterialens": "gummimaterial",
    "gummimaterialet": "gummimaterial",
    "gummimaterialets": "gummimaterial",
    "gummimaterials": "gummimaterial",
    "gummin": "gummi",
    "gummina": "gummi",
    "gumminas": "gummi",
    "gummins": "gummi",
    "gummiparagrafen": "gummiparagraf",
    "gummiparagrafens": "gummiparagraf",
    "gummiparagrafer": "gummiparagraf",
    "gummiparagraferna": "gummiparagraf",
    "gummiparagrafernas": "gummiparagraf",
    "gummiparagrafers": "gummiparagraf",
    "gummiparagrafs": "gummiparagraf",
    "gummiplantagen": "gummiplantage",
    "gummiplantagens": "gummiplantage",
    "gummiplantager": "gummiplantage",
    "gummiplantagerna": "gummiplantage",
    "gummiplantagernas": "gummiplantage",
    "gummiplantagers": "gummiplantage",
    "gummiplantages": "gummiplantage",
    "gummiplatt": "gummiplatta",
    "gummiplattan": "gummiplatta",
    "gummiplattans": "gummiplatta",
    "gummiplattas": "gummiplatta",
    "gummiplatte": "gummiplatta",
    "gummiplattor": "gummiplatta",
    "gummiplattorna": "gummiplatta",
    "gummiplattornas": "gummiplatta",
    "gummiplattors": "gummiplatta",
    "gummiplatts": "gummiplatta",
    "gummiproppar": "gummipropp",
    "gummipropparna": "gummipropp",
    "gummipropparnas": "gummipropp",
    "gummiproppars": "gummipropp",
    "gummiproppen": "gummipropp",
    "gummiproppens": "gummipropp",
    "gummipropps": "gummipropp",
    "gummiräfflade": "gummiräfflad",
    "gummiräfflades": "gummiräfflad",
    "gummiräfflads": "gummiräfflad",
    "gummiräfflat": "gummiräfflad",
    "gummiräfflats": "gummiräfflad",
    "gummis": "gummi",
    "gummiskydden": "gummiskydd",
    "gummiskyddens": "gummiskydd",
    "gummiskyddet": "gummiskydd",
    "gummiskyddets": "gummiskydd",
    "gummiskydds": "gummiskydd",
    "gummislangar": "gummislang",
    "gummislangarna": "gummislang",
    "gummislangarnas": "gummislang",
    "gummislangars": "gummislang",
    "gummislangen": "gummislang",
    "gummislangens": "gummislang",
    "gummislangs": "gummislang",
    "gummislägg": "gummislägga",
    "gummisläggan": "gummislägga",
    "gummisläggans": "gummislägga",
    "gummisläggas": "gummislägga",
    "gummislägge": "gummislägga",
    "gummisläggor": "gummislägga",
    "gummisläggorna": "gummislägga",
    "gummisläggornas": "gummislägga",
    "gummisläggors": "gummislägga",
    "gummisläggs": "gummislägga",
    "gummisnoddar": "gummisnodd",
    "gummisnoddarna": "gummisnodd",
    "gummisnoddarnas": "gummisnodd",
    "gummisnoddars": "gummisnodd",
    "gummisnodden": "gummisnodd",
    "gummisnoddens": "gummisnodd",
    "gummisnodds": "gummisnodd",
    "gummistöveln": "gummistövel",
    "gummistövelns": "gummistövel",
    "gummistövels": "gummistövel",
    "gummistövlar": "gummistövel",
    "gummistövlarna": "gummistövel",
    "gummistövlarnas": "gummistövel",
    "gummistövlars": "gummistövel",
    "gummit": "gummi",
    "gummiträden": "gummiträd",
    "gummiträdens": "gummiträd",
    "gummiträdet": "gummiträd",
    "gummiträdets": "gummiträd",
    "gummiträds": "gummiträd",
    "gummits": "gummi",
    "gummor": "gumma",
    "gummorna": "gumma",
    "gummornas": "gumma",
    "gummors": "gumma",
    "gummösa": "gummös",
    "gummösare": "gummös",
    "gummösares": "gummös",
    "gummösas": "gummös",
    "gummösast": "gummös",
    "gummösaste": "gummös",
    "gummösastes": "gummös",
    "gummösasts": "gummös",
    "gummöse": "gummös",
    "gummöses": "gummös",
    "gummöst": "gummös",
    "gummösts": "gummös",
    "gump": "gumpa",
    "gumpade": "gumpa",
    "gumpades": "gumpa",
    "gumpande": "gumpa",
    "gumpanden": "gumpande",
    "gumpandena": "gumpande",
    "gumpandenas": "gumpande",
    "gumpandens": "gumpande",
    "gumpandes": "gumpande",
    "gumpandet": "gumpande",
    "gumpandets": "gumpande",
    "gumpar": "gumpa",
    "gumparna": "gump",
    "gumparnas": "gump",
    "gumpars": "gump",
    "gumpas": "gumpa",
    "gumpat": "gumpa",
    "gumpats": "gumpa",
    "gumpen": "gump",
    "gumpens": "gump",
    "gumphön": "gumphöna",
    "gumphönan": "gumphöna",
    "gumphönans": "gumphöna",
    "gumphönas": "gumphöna",
    "gumphöne": "gumphöna",
    "gumphönor": "gumphöna",
    "gumphönorna": "gumphöna",
    "gumphönornas": "gumphöna",
    "gumphönors": "gumphöna",
    "gumphöns": "gumphöna",
    "gumpkörteln": "gumpkörtel",
    "gumpkörtelns": "gumpkörtel",
    "gumpkörtels": "gumpkörtel",
    "gumpkörtlar": "gumpkörtel",
    "gumpkörtlarna": "gumpkörtel",
    "gumpkörtlarnas": "gumpkörtel",
    "gumpkörtlars": "gumpkörtel",
    "gumps": "gump",
    "gums": "gumse",
    "gumsar": "gumse",
    "gumsarna": "gumse",
    "gumsarnas": "gumse",
    "gumsars": "gumse",
    "gumsen": "gumse",
    "gumsens": "gumse",
    "gumses": "gumse",
    "gung": "gunga",
    "gungad": "gunga",
    "gungade": "gunga",
    "gungades": "gunga",
    "gungads": "gunga",
    "gungan": "gunga",
    "gungande": "gunga",
    "gunganden": "gungande",
    "gungandena": "gungande",
    "gungandenas": "gungande",
    "gungandens": "gungande",
    "gungandes": "gungande",
    "gungandet": "gungande",
    "gungandets": "gungande",
    "gungans": "gunga",
    "gungar": "gunga",
    "gungas": "gunga",
    "gungat": "gunga",
    "gungats": "gunga",
    "gungbräd": "gungbräda",
    "gungbrädan": "gungbräda",
    "gungbrädans": "gungbräda",
    "gungbrädas": "gungbräda",
    "gungbräde": "gungbräda",
    "gungbräden": "gungbräde",
    "gungbrädena": "gungbräde",
    "gungbrädenas": "gungbräde",
    "gungbrädens": "gungbräde",
    "gungbrädes": "gungbräde",
    "gungbrädet": "gungbräde",
    "gungbrädets": "gungbräde",
    "gungbrädor": "gungbräda",
    "gungbrädorna": "gungbräda",
    "gungbrädornas": "gungbräda",
    "gungbrädors": "gungbräda",
    "gungbräds": "gungbräda",
    "gunge": "gunga",
    "gunget": "gung",
    "gungets": "gung",
    "gungflyen": "gungfly",
    "gungflyens": "gungfly",
    "gungflyet": "gungfly",
    "gungflyets": "gungfly",
    "gungflyn": "gungfly",
    "gungflyna": "gungfly",
    "gungflynas": "gungfly",
    "gungflyns": "gungfly",
    "gungflys": "gungfly",
    "gungflyt": "gungfly",
    "gungflyts": "gungfly",
    "gunghästar": "gunghäst",
    "gunghästarna": "gunghäst",
    "gunghästarnas": "gunghäst",
    "gunghästars": "gunghäst",
    "gunghästen": "gunghäst",
    "gunghästens": "gunghäst",
    "gunghästs": "gunghäst",
    "gungiga": "gungig",
    "gungigare": "gungig",
    "gungigares": "gungig",
    "gungigas": "gungig",
    "gungigast": "gungig",
    "gungigaste": "gungig",
    "gungigastes": "gungig",
    "gungigasts": "gungig",
    "gungige": "gungig",
    "gungiges": "gungig",
    "gungigheten": "gungighet",
    "gungighetens": "gungighet",
    "gungighets": "gungighet",
    "gungigs": "gungig",
    "gungigt": "gungig",
    "gungigts": "gungig",
    "gungningar": "gungning",
    "gungningarna": "gungning",
    "gungningarnas": "gungning",
    "gungningars": "gungning",
    "gungningen": "gungning",
    "gungningens": "gungning",
    "gungnings": "gungning",
    "gungor": "gunga",
    "gungorna": "gunga",
    "gungornas": "gunga",
    "gungors": "gunga",
    "gungs": "gunga",
    "gungstolar": "gungstol",
    "gungstolarna": "gungstol",
    "gungstolarnas": "gungstol",
    "gungstolars": "gungstol",
    "gungstolen": "gungstol",
    "gungstolens": "gungstol",
    "gungstols": "gungstol",
    "gungställningar": "gungställning",
    "gungställningarna": "gungställning",
    "gungställningarnas": "gungställning",
    "gungställningars": "gungställning",
    "gungställningen": "gungställning",
    "gungställningens": "gungställning",
    "gungställnings": "gungställning",
    "gunrummen": "gunrum",
    "gunrummens": "gunrum",
    "gunrummet": "gunrum",
    "gunrummets": "gunrum",
    "gunrums": "gunrum",
    "gunstbenägenheten": "gunstbenägenhet",
    "gunstbenägenhetens": "gunstbenägenhet",
    "gunstbenägenhets": "gunstbenägenhet",
    "gunstbenägens": "gunstbenägen",
    "gunstbenäget": "gunstbenägen",
    "gunstbenägets": "gunstbenägen",
    "gunstbenägna": "gunstbenägen",
    "gunstbenägnare": "gunstbenägen",
    "gunstbenägnares": "gunstbenägen",
    "gunstbenägnas": "gunstbenägen",
    "gunstbenägnast": "gunstbenägen",
    "gunstbenägnaste": "gunstbenägen",
    "gunstbenägnastes": "gunstbenägen",
    "gunstbenägnasts": "gunstbenägen",
    "gunstbenägne": "gunstbenägen",
    "gunstbenägnes": "gunstbenägen",
    "gunsten": "gunst",
    "gunstens": "gunst",
    "gunster": "gunst",
    "gunsterna": "gunst",
    "gunsternas": "gunst",
    "gunsters": "gunst",
    "gunstiga": "gunstig",
    "gunstigare": "gunstig",
    "gunstigares": "gunstig",
    "gunstigas": "gunstig",
    "gunstigast": "gunstig",
    "gunstigaste": "gunstig",
    "gunstigastes": "gunstig",
    "gunstigasts": "gunstig",
    "gunstige": "gunstig",
    "gunstiges": "gunstig",
    "gunstigheten": "gunstighet",
    "gunstighetens": "gunstighet",
    "gunstighets": "gunstighet",
    "gunstigs": "gunstig",
    "gunstigt": "gunstig",
    "gunstigts": "gunstig",
    "gunstlingar": "gunstling",
    "gunstlingarna": "gunstling",
    "gunstlingarnas": "gunstling",
    "gunstlingars": "gunstling",
    "gunstlingen": "gunstling",
    "gunstlingens": "gunstling",
    "gunstlings": "gunstling",
    "gunsts": "gunst",
    "guppade": "guppa",
    "guppades": "guppa",
    "guppande": "guppa",
    "guppanden": "guppande",
    "guppandena": "guppande",
    "guppandenas": "guppande",
    "guppandens": "guppande",
    "guppandes": "guppande",
    "guppandet": "guppande",
    "guppandets": "guppande",
    "guppar": "guppa",
    "guppas": "guppa",
    "guppat": "guppa",
    "guppats": "guppa",
    "guppen": "gupp",
    "guppens": "gupp",
    "guppet": "gupp",
    "guppets": "gupp",
    "guppier": "guppy",
    "guppierna": "guppy",
    "guppiernas": "guppy",
    "guppiers": "guppy",
    "guppies": "guppy",
    "guppiesarna": "guppy",
    "guppiesarnas": "guppy",
    "guppiga": "guppig",
    "guppigare": "guppig",
    "guppigares": "guppig",
    "guppigas": "guppig",
    "guppigast": "guppig",
    "guppigaste": "guppig",
    "guppigastes": "guppig",
    "guppigasts": "guppig",
    "guppige": "guppig",
    "guppiges": "guppig",
    "guppigheten": "guppighet",
    "guppighetens": "guppighet",
    "guppighets": "guppighet",
    "guppigs": "guppig",
    "guppigt": "guppig",
    "guppigts": "guppig",
    "gupps": "gupp",
    "guppyer": "guppy",
    "guppyerna": "guppy",
    "guppyernas": "guppy",
    "guppyers": "guppy",
    "guppyn": "guppy",
    "guppyns": "guppy",
    "guppys": "guppy",
    "guppysar": "guppy",
    "guppysarna": "guppy",
    "guppysarnas": "guppy",
    "guppysars": "guppy",
    "guramier": "gurami",
    "guramierna": "gurami",
    "guramiernas": "gurami",
    "guramiers": "gurami",
    "guramin": "gurami",
    "guramins": "gurami",
    "guramis": "gurami",
    "guran": "gura",
    "gurans": "gura",
    "guras": "gura",
    "gurgel": "gurgla",
    "gurgels": "gurgel",
    "gurglad": "gurgla",
    "gurglade": "gurgla",
    "gurglades": "gurgla",
    "gurglads": "gurgla",
    "gurglande": "gurgla",
    "gurglanden": "gurglande",
    "gurglandena": "gurglande",
    "gurglandenas": "gurglande",
    "gurglandens": "gurglande",
    "gurglandes": "gurglande",
    "gurglandet": "gurglande",
    "gurglandets": "gurglande",
    "gurglar": "gurgla",
    "gurglas": "gurgla",
    "gurglat": "gurgla",
    "gurglats": "gurgla",
    "gurglen": "gurgel",
    "gurglens": "gurgel",
    "gurglet": "gurgel",
    "gurglets": "gurgel",
    "gurk": "gurka",
    "gurkan": "gurka",
    "gurkans": "gurka",
    "gurkas": "gurka",
    "gurke": "gurka",
    "gurkhan": "gurkha",
    "gurkhans": "gurkha",
    "gurkhas": "gurkha",
    "gurkhor": "gurkha",
    "gurkhorna": "gurkha",
    "gurkhornas": "gurkha",
    "gurkhors": "gurkha",
    "gurklisten": "gurklist",
    "gurklistens": "gurklist",
    "gurklister": "gurklist",
    "gurklisterna": "gurklist",
    "gurklisternas": "gurklist",
    "gurklisters": "gurklist",
    "gurklists": "gurklist",
    "gurkmej": "gurkmeja",
    "gurkmejan": "gurkmeja",
    "gurkmejans": "gurkmeja",
    "gurkmejas": "gurkmeja",
    "gurkmeje": "gurkmeja",
    "gurkmejor": "gurkmeja",
    "gurkmejorna": "gurkmeja",
    "gurkmejornas": "gurkmeja",
    "gurkmejors": "gurkmeja",
    "gurkmejpapperet": "gurkmejpapper",
    "gurkmejpapperets": "gurkmejpapper",
    "gurkmejpappers": "gurkmejpapper",
    "gurkmejpappret": "gurkmejpapper",
    "gurkmejpapprets": "gurkmejpapper",
    "gurkmejs": "gurkmeja",
    "gurkor": "gurka",
    "gurkorna": "gurka",
    "gurkornas": "gurka",
    "gurkors": "gurka",
    "gurks": "gurka",
    "gurkskivan": "gurkskiva",
    "gurkskivans": "gurkskiva",
    "gurkskivas": "gurkskiva",
    "gurkskive": "gurkskiva",
    "gurkskivor": "gurkskiva",
    "gurkskivorna": "gurkskiva",
    "gurkskivornas": "gurkskiva",
    "gurkskivors": "gurkskiva",
    "gurkstavar": "gurkstav",
    "gurkstavarna": "gurkstav",
    "gurkstavarnas": "gurkstav",
    "gurkstavars": "gurkstav",
    "gurkstaven": "gurkstav",
    "gurkstavens": "gurkstav",
    "gurkstavs": "gurkstav",
    "gurkväxten": "gurkväxt",
    "gurkväxtens": "gurkväxt",
    "gurkväxter": "gurkväxt",
    "gurkväxterna": "gurkväxt",
    "gurkväxternas": "gurkväxt",
    "gurkväxters": "gurkväxt",
    "gurkväxts": "gurkväxt",
    "guror": "gura",
    "gurorna": "gura",
    "gurornas": "gura",
    "gurors": "gura",
    "guruer": "guru",
    "guruerna": "guru",
    "guruernas": "guru",
    "guruers": "guru",
    "gurun": "guru",
    "guruns": "guru",
    "gurus": "guru",
    "gurusarna": "guru",
    "gurusarnas": "guru",
    "gusk": "guska",
    "guskad": "guska",
    "guskade": "guska",
    "guskades": "guska",
    "guskads": "guska",
    "guskande": "guska",
    "guskanden": "guskande",
    "guskandena": "guskande",
    "guskandenas": "guskande",
    "guskandens": "guskande",
    "guskandes": "guskande",
    "guskandet": "guskande",
    "guskandets": "guskande",
    "guskar": "guska",
    "guskas": "guska",
    "guskat": "guska",
    "guskats": "guska",
    "gustavadolfsbakelsen": "gustavadolfsbakelse",
    "gustavadolfsbakelsens": "gustavadolfsbakelse",
    "gustavadolfsbakelser": "gustavadolfsbakelse",
    "gustavadolfsbakelserna": "gustavadolfsbakelse",
    "gustavadolfsbakelsernas": "gustavadolfsbakelse",
    "gustavadolfsbakelsers": "gustavadolfsbakelse",
    "gustavadolfsbakelses": "gustavadolfsbakelse",
    "gustavianen": "gustavian",
    "gustavianens": "gustavian",
    "gustavianer": "gustavian",
    "gustavianerna": "gustavian",
    "gustavianernas": "gustavian",
    "gustavianers": "gustavian",
    "gustavians": "gustavian",
    "gustavianska": "gustaviansk",
    "gustavianskare": "gustaviansk",
    "gustavianskares": "gustaviansk",
    "gustavianskas": "gustaviansk",
    "gustavianskast": "gustaviansk",
    "gustavianskaste": "gustaviansk",
    "gustavianskastes": "gustaviansk",
    "gustavianskasts": "gustaviansk",
    "gustavianske": "gustaviansk",
    "gustavianskes": "gustaviansk",
    "gustaviansks": "gustaviansk",
    "gustavianskt": "gustaviansk",
    "gustavianskts": "gustaviansk",
    "gut": "gute",
    "gutar": "gute",
    "gutarna": "gute",
    "gutarnas": "gute",
    "gutars": "gute",
    "guten": "gute",
    "gutens": "gute",
    "guterad": "gutera",
    "guterade": "gutera",
    "guterades": "gutera",
    "guterads": "gutera",
    "guterande": "gutera",
    "guteranden": "guterande",
    "guterandena": "guterande",
    "guterandenas": "guterande",
    "guterandens": "guterande",
    "guterandes": "guterande",
    "guterandet": "guterande",
    "guterandets": "guterande",
    "guterar": "gutera",
    "guteras": "gutera",
    "guterat": "gutera",
    "guterats": "gutera",
    "guterbara": "guterbar",
    "guterbarare": "guterbar",
    "guterbarares": "guterbar",
    "guterbaras": "guterbar",
    "guterbarast": "guterbar",
    "guterbaraste": "guterbar",
    "guterbarastes": "guterbar",
    "guterbarasts": "guterbar",
    "guterbare": "guterbar",
    "guterbares": "guterbar",
    "guterbarheten": "guterbarhet",
    "guterbarhetens": "guterbarhet",
    "guterbarhets": "guterbarhet",
    "guterbars": "guterbar",
    "guterbart": "guterbar",
    "guterbarts": "guterbar",
    "guteringar": "gutering",
    "guteringarna": "gutering",
    "guteringarnas": "gutering",
    "guteringars": "gutering",
    "guteringen": "gutering",
    "guteringens": "gutering",
    "guterings": "gutering",
    "gutes": "gute",
    "gutnisk": "gutniska",
    "gutniska": "gutnisk",
    "gutniskan": "gutniska",
    "gutniskans": "gutniska",
    "gutniskare": "gutnisk",
    "gutniskares": "gutnisk",
    "gutniskas": "gutniska",
    "gutniskast": "gutnisk",
    "gutniskaste": "gutnisk",
    "gutniskastes": "gutnisk",
    "gutniskasts": "gutnisk",
    "gutniske": "gutnisk",
    "gutniskes": "gutnisk",
    "gutnisks": "gutnisk",
    "gutniskt": "gutnisk",
    "gutniskts": "gutnisk",
    "guts": "gute",
    "guttaperkan": "guttaperka",
    "guttaperkans": "guttaperka",
    "guttaperkas": "guttaperka",
    "gutten": "gutt",
    "guttens": "gutt",
    "gutts": "gutt",
    "gutturala": "guttural",
    "gutturalare": "guttural",
    "gutturalares": "guttural",
    "gutturalas": "guttural",
    "gutturalast": "guttural",
    "gutturalaste": "guttural",
    "gutturalastes": "guttural",
    "gutturalasts": "guttural",
    "gutturale": "guttural",
    "gutturales": "guttural",
    "gutturals": "guttural",
    "gutturalt": "guttural",
    "gutturalts": "guttural",
    "guvernanten": "guvernant",
    "guvernantens": "guvernant",
    "guvernanter": "guvernant",
    "guvernanterna": "guvernant",
    "guvernanternas": "guvernant",
    "guvernanters": "guvernant",
    "guvernants": "guvernant",
    "guvernementen": "guvernement",
    "guvernementens": "guvernement",
    "guvernementet": "guvernement",
    "guvernementets": "guvernement",
    "guvernements": "guvernement",
    "guvernören": "guvernör",
    "guvernörens": "guvernör",
    "guvernörer": "guvernör",
    "guvernörerna": "guvernör",
    "guvernörernas": "guvernör",
    "guvernörers": "guvernör",
    "guvernörn": "guvernör",
    "guvernörns": "guvernör",
    "guvernörs": "guvernör",
    "guyananen": "guyanan",
    "guyananens": "guyanan",
    "guyananer": "guyanan",
    "guyananerna": "guyanan",
    "guyananernas": "guyanan",
    "guyananers": "guyanan",
    "guyanans": "guyanan",
    "guyananska": "guyanansk",
    "guyananskan": "guyananska",
    "guyananskans": "guyananska",
    "guyananskare": "guyanansk",
    "guyananskares": "guyanansk",
    "guyananskas": "guyananska",
    "guyananskast": "guyanansk",
    "guyananskaste": "guyanansk",
    "guyananskastes": "guyanansk",
    "guyananskasts": "guyanansk",
    "guyananske": "guyananska",
    "guyananskes": "guyanansk",
    "guyananskor": "guyananska",
    "guyananskorna": "guyananska",
    "guyananskornas": "guyananska",
    "guyananskors": "guyananska",
    "guyanansks": "guyanansk",
    "guyananskt": "guyanansk",
    "guyananskts": "guyanansk",
    "gyckel": "gyckla",
    "gyckelbilden": "gyckelbild",
    "gyckelbildens": "gyckelbild",
    "gyckelbilder": "gyckelbild",
    "gyckelbilderna": "gyckelbild",
    "gyckelbildernas": "gyckelbild",
    "gyckelbilders": "gyckelbild",
    "gyckelbilds": "gyckelbild",
    "gyckels": "gyckel",
    "gyckelspelen": "gyckelspel",
    "gyckelspelens": "gyckelspel",
    "gyckelspelet": "gyckelspel",
    "gyckelspelets": "gyckelspel",
    "gyckelspels": "gyckelspel",
    "gycklade": "gyckla",
    "gycklades": "gyckla",
    "gycklande": "gyckla",
    "gycklanden": "gycklande",
    "gycklandena": "gycklande",
    "gycklandenas": "gycklande",
    "gycklandens": "gycklande",
    "gycklandes": "gycklande",
    "gycklandet": "gycklande",
    "gycklandets": "gycklande",
    "gycklar": "gycklare",
    "gycklaren": "gycklare",
    "gycklarens": "gycklare",
    "gycklares": "gycklare",
    "gycklarna": "gycklare",
    "gycklarnas": "gycklare",
    "gycklas": "gyckla",
    "gycklat": "gyckla",
    "gycklats": "gyckla",
    "gycklerier": "gyckleri",
    "gycklerierna": "gyckleri",
    "gyckleriernas": "gyckleri",
    "gyckleriers": "gyckleri",
    "gyckleriet": "gyckleri",
    "gyckleriets": "gyckleri",
    "gyckleris": "gyckleri",
    "gycklerit": "gyckleri",
    "gycklerits": "gyckleri",
    "gycklet": "gyckel",
    "gycklets": "gyckel",
    "gydjan": "gydja",
    "gydjans": "gydja",
    "gydjas": "gydja",
    "gydje": "gydja",
    "gydjor": "gydja",
    "gydjorna": "gydja",
    "gydjornas": "gydja",
    "gydjors": "gydja",
    "gylfar": "gylf",
    "gylfarna": "gylf",
    "gylfarnas": "gylf",
    "gylfars": "gylf",
    "gylfen": "gylf",
    "gylfens": "gylf",
    "gylfs": "gylf",
    "gyllena": "gyllen",
    "gyllenas": "gyllen",
    "gyllenbruna": "gyllenbrun",
    "gyllenbrunare": "gyllenbrun",
    "gyllenbrunares": "gyllenbrun",
    "gyllenbrunas": "gyllenbrun",
    "gyllenbrunast": "gyllenbrun",
    "gyllenbrunaste": "gyllenbrun",
    "gyllenbrunastes": "gyllenbrun",
    "gyllenbrunasts": "gyllenbrun",
    "gyllenbrune": "gyllenbrun",
    "gyllenbrunes": "gyllenbrun",
    "gyllenbruns": "gyllenbrun",
    "gyllenbrunt": "gyllenbrun",
    "gyllenbrunts": "gyllenbrun",
    "gyllenduken": "gyllenduk",
    "gyllendukens": "gyllenduk",
    "gyllenduks": "gyllenduk",
    "gyllenen": "gyllen",
    "gyllenens": "gyllen",
    "gyllenet": "gyllen",
    "gyllenets": "gyllen",
    "gyllenlacken": "gyllenlack",
    "gyllenlackens": "gyllenlack",
    "gyllenlacks": "gyllenlack",
    "gyllenläders": "gyllenläder",
    "gyllenlädret": "gyllenläder",
    "gyllenlädrets": "gyllenläder",
    "gyllens": "gyllen",
    "gyllentalen": "gyllental",
    "gyllentalens": "gyllental",
    "gyllentalet": "gyllental",
    "gyllentalets": "gyllental",
    "gyllentals": "gyllental",
    "gyllingar": "gylling",
    "gyllingarna": "gylling",
    "gyllingarnas": "gylling",
    "gyllingars": "gylling",
    "gyllingen": "gylling",
    "gyllingens": "gylling",
    "gyllings": "gylling",
    "gylt": "gylta",
    "gyltan": "gylta",
    "gyltans": "gylta",
    "gyltas": "gylta",
    "gylte": "gylta",
    "gyltor": "gylta",
    "gyltorna": "gylta",
    "gyltornas": "gylta",
    "gyltors": "gylta",
    "gylts": "gylta",
    "gymmen": "gym",
    "gymmens": "gym",
    "gymmet": "gym",
    "gymmets": "gym",
    "gymnasiala": "gymnasial",
    "gymnasialare": "gymnasial",
    "gymnasialares": "gymnasial",
    "gymnasialas": "gymnasial",
    "gymnasialast": "gymnasial",
    "gymnasialaste": "gymnasial",
    "gymnasialastes": "gymnasial",
    "gymnasialasts": "gymnasial",
    "gymnasiale": "gymnasial",
    "gymnasiales": "gymnasial",
    "gymnasials": "gymnasial",
    "gymnasialt": "gymnasial",
    "gymnasialts": "gymnasial",
    "gymnasie": "gymnasium",
    "gymnasieekonomen": "gymnasieekonom",
    "gymnasieekonomens": "gymnasieekonom",
    "gymnasieekonomer": "gymnasieekonom",
    "gymnasieekonomerna": "gymnasieekonom",
    "gymnasieekonomernas": "gymnasieekonom",
    "gymnasieekonomers": "gymnasieekonom",
    "gymnasieekonoms": "gymnasieekonom",
    "gymnasieingenjören": "gymnasieingenjör",
    "gymnasieingenjörens": "gymnasieingenjör",
    "gymnasieingenjörer": "gymnasieingenjör",
    "gymnasieingenjörerna": "gymnasieingenjör",
    "gymnasieingenjörernas": "gymnasieingenjör",
    "gymnasieingenjörers": "gymnasieingenjör",
    "gymnasieingenjörn": "gymnasieingenjör",
    "gymnasieingenjörns": "gymnasieingenjör",
    "gymnasieingenjörs": "gymnasieingenjör",
    "gymnasieinspektören": "gymnasieinspektör",
    "gymnasieinspektörens": "gymnasieinspektör",
    "gymnasieinspektörer": "gymnasieinspektör",
    "gymnasieinspektörerna": "gymnasieinspektör",
    "gymnasieinspektörernas": "gymnasieinspektör",
    "gymnasieinspektörers": "gymnasieinspektör",
    "gymnasieinspektörn": "gymnasieinspektör",
    "gymnasieinspektörns": "gymnasieinspektör",
    "gymnasieinspektörs": "gymnasieinspektör",
    "gymnasielinjen": "gymnasielinje",
    "gymnasielinjens": "gymnasielinje",
    "gymnasielinjer": "gymnasielinje",
    "gymnasielinjerna": "gymnasielinje",
    "gymnasielinjernas": "gymnasielinje",
    "gymnasielinjers": "gymnasielinje",
    "gymnasielinjes": "gymnasielinje",
    "gymnasier": "gymnasium",
    "gymnasierna": "gymnasium",
    "gymnasiernas": "gymnasium",
    "gymnasiers": "gymnasium",
    "gymnasieskolan": "gymnasieskola",
    "gymnasieskolans": "gymnasieskola",
    "gymnasieskolas": "gymnasieskola",
    "gymnasieskole": "gymnasieskola",
    "gymnasieskolor": "gymnasieskola",
    "gymnasieskolorna": "gymnasieskola",
    "gymnasieskolornas": "gymnasieskola",
    "gymnasieskolors": "gymnasieskola",
    "gymnasiet": "gymnasium",
    "gymnasiets": "gymnasium",
    "gymnasieutbildningar": "gymnasieutbildning",
    "gymnasieutbildningarna": "gymnasieutbildning",
    "gymnasieutbildningarnas": "gymnasieutbildning",
    "gymnasieutbildningars": "gymnasieutbildning",
    "gymnasieutbildningen": "gymnasieutbildning",
    "gymnasieutbildningens": "gymnasieutbildning",
    "gymnasieutbildnings": "gymnasieutbildning",
    "gymnasievalen": "gymnasieval",
    "gymnasievalens": "gymnasieval",
    "gymnasievalet": "gymnasieval",
    "gymnasievalets": "gymnasieval",
    "gymnasievals": "gymnasieval",
    "gymnasisten": "gymnasist",
    "gymnasistens": "gymnasist",
    "gymnasister": "gymnasist",
    "gymnasisterna": "gymnasist",
    "gymnasisternas": "gymnasist",
    "gymnasisters": "gymnasist",
    "gymnasists": "gymnasist",
    "gymnasiums": "gymnasium",
    "gymnasten": "gymnast",
    "gymnastens": "gymnast",
    "gymnaster": "gymnast",
    "gymnasterna": "gymnast",
    "gymnasternas": "gymnast",
    "gymnasters": "gymnast",
    "gymnastikdirektören": "gymnastikdirektör",
    "gymnastikdirektörens": "gymnastikdirektör",
    "gymnastikdirektörer": "gymnastikdirektör",
    "gymnastikdirektörerna": "gymnastikdirektör",
    "gymnastikdirektörernas": "gymnastikdirektör",
    "gymnastikdirektörers": "gymnastikdirektör",
    "gymnastikdirektörn": "gymnastikdirektör",
    "gymnastikdirektörns": "gymnastikdirektör",
    "gymnastikdirektörs": "gymnastikdirektör",
    "gymnastikdräkten": "gymnastikdräkt",
    "gymnastikdräktens": "gymnastikdräkt",
    "gymnastikdräkter": "gymnastikdräkt",
    "gymnastikdräkterna": "gymnastikdräkt",
    "gymnastikdräkternas": "gymnastikdräkt",
    "gymnastikdräkters": "gymnastikdräkt",
    "gymnastikdräkts": "gymnastikdräkt",
    "gymnastiken": "gymnastik",
    "gymnastikens": "gymnastik",
    "gymnastikhoppen": "gymnastikhopp",
    "gymnastikhoppens": "gymnastikhopp",
    "gymnastikhoppet": "gymnastikhopp",
    "gymnastikhoppets": "gymnastikhopp",
    "gymnastikhopps": "gymnastikhopp",
    "gymnastikhusen": "gymnastikhus",
    "gymnastikhusens": "gymnastikhus",
    "gymnastikhuset": "gymnastikhus",
    "gymnastikhusets": "gymnastikhus",
    "gymnastiklektionen": "gymnastiklektion",
    "gymnastiklektionens": "gymnastiklektion",
    "gymnastiklektioner": "gymnastiklektion",
    "gymnastiklektionerna": "gymnastiklektion",
    "gymnastiklektionernas": "gymnastiklektion",
    "gymnastiklektioners": "gymnastiklektion",
    "gymnastiklektions": "gymnastiklektion",
    "gymnastikredskapen": "gymnastikredskap",
    "gymnastikredskapens": "gymnastikredskap",
    "gymnastikredskapet": "gymnastikredskap",
    "gymnastikredskapets": "gymnastikredskap",
    "gymnastikredskaps": "gymnastikredskap",
    "gymnastiks": "gymnastik",
    "gymnastiksalar": "gymnastiksal",
    "gymnastiksalarna": "gymnastiksal",
    "gymnastiksalarnas": "gymnastiksal",
    "gymnastiksalars": "gymnastiksal",
    "gymnastiksalen": "gymnastiksal",
    "gymnastiksalens": "gymnastiksal",
    "gymnastiksals": "gymnastiksal",
    "gymnastikskon": "gymnastiksko",
    "gymnastikskons": "gymnastiksko",
    "gymnastikskor": "gymnastiksko",
    "gymnastikskorna": "gymnastiksko",
    "gymnastikskornas": "gymnastiksko",
    "gymnastikskors": "gymnastiksko",
    "gymnastikskos": "gymnastiksko",
    "gymnastiserad": "gymnastisera",
    "gymnastiserade": "gymnastiserad",
    "gymnastiserades": "gymnastiserad",
    "gymnastiserads": "gymnastiserad",
    "gymnastiserande": "gymnastisera",
    "gymnastiseranden": "gymnastiserande",
    "gymnastiserandena": "gymnastiserande",
    "gymnastiserandenas": "gymnastiserande",
    "gymnastiserandens": "gymnastiserande",
    "gymnastiserandes": "gymnastiserande",
    "gymnastiserandet": "gymnastiserande",
    "gymnastiserandets": "gymnastiserande",
    "gymnastiserar": "gymnastisera",
    "gymnastiseras": "gymnastisera",
    "gymnastiserat": "gymnastiserad",
    "gymnastiserats": "gymnastiserad",
    "gymnastiserbara": "gymnastiserbar",
    "gymnastiserbarare": "gymnastiserbar",
    "gymnastiserbarares": "gymnastiserbar",
    "gymnastiserbaras": "gymnastiserbar",
    "gymnastiserbarast": "gymnastiserbar",
    "gymnastiserbaraste": "gymnastiserbar",
    "gymnastiserbarastes": "gymnastiserbar",
    "gymnastiserbarasts": "gymnastiserbar",
    "gymnastiserbare": "gymnastiserbar",
    "gymnastiserbares": "gymnastiserbar",
    "gymnastiserbarheten": "gymnastiserbarhet",
    "gymnastiserbarhetens": "gymnastiserbarhet",
    "gymnastiserbarhets": "gymnastiserbarhet",
    "gymnastiserbars": "gymnastiserbar",
    "gymnastiserbart": "gymnastiserbar",
    "gymnastiserbarts": "gymnastiserbar",
    "gymnastiseringar": "gymnastisering",
    "gymnastiseringarna": "gymnastisering",
    "gymnastiseringarnas": "gymnastisering",
    "gymnastiseringars": "gymnastisering",
    "gymnastiseringen": "gymnastisering",
    "gymnastiseringens": "gymnastisering",
    "gymnastiserings": "gymnastisering",
    "gymnastiska": "gymnastisk",
    "gymnastiskare": "gymnastisk",
    "gymnastiskares": "gymnastisk",
    "gymnastiskas": "gymnastisk",
    "gymnastiskast": "gymnastisk",
    "gymnastiskaste": "gymnastisk",
    "gymnastiskastes": "gymnastisk",
    "gymnastiskasts": "gymnastisk",
    "gymnastiske": "gymnastisk",
    "gymnastiskes": "gymnastisk",
    "gymnastisks": "gymnastisk",
    "gymnastiskt": "gymnastisk",
    "gymnastiskts": "gymnastisk",
    "gymnasts": "gymnast",
    "gymniska": "gymnisk",
    "gymniskare": "gymnisk",
    "gymniskares": "gymnisk",
    "gymniskas": "gymnisk",
    "gymniskast": "gymnisk",
    "gymniskaste": "gymnisk",
    "gymniskastes": "gymnisk",
    "gymniskasts": "gymnisk",
    "gymniske": "gymnisk",
    "gymniskes": "gymnisk",
    "gymnisks": "gymnisk",
    "gymniskt": "gymnisk",
    "gymniskts": "gymnisk",
    "gymnospermen": "gymnosperm",
    "gymnospermens": "gymnosperm",
    "gymnospermer": "gymnosperm",
    "gymnospermerna": "gymnosperm",
    "gymnospermernas": "gymnosperm",
    "gymnospermers": "gymnosperm",
    "gymnosperms": "gymnosperm",
    "gympade": "gympa",
    "gympades": "gympa",
    "gympan": "gympa",
    "gympande": "gympa",
    "gympanden": "gympande",
    "gympandena": "gympande",
    "gympandenas": "gympande",
    "gympandens": "gympande",
    "gympandes": "gympande",
    "gympandet": "gympande",
    "gympandets": "gympande",
    "gympans": "gympa",
    "gympar": "gympa",
    "gympas": "gympa",
    "gympat": "gympa",
    "gympats": "gympa",
    "gympingen": "gymping",
    "gympingens": "gymping",
    "gympings": "gymping",
    "gyms": "gym",
    "gynekologen": "gynekolog",
    "gynekologens": "gynekolog",
    "gynekologer": "gynekolog",
    "gynekologerna": "gynekolog",
    "gynekologernas": "gynekolog",
    "gynekologers": "gynekolog",
    "gynekologien": "gynekologi",
    "gynekologiens": "gynekologi",
    "gynekologin": "gynekologi",
    "gynekologins": "gynekologi",
    "gynekologis": "gynekologi",
    "gynekologiska": "gynekologisk",
    "gynekologiskare": "gynekologisk",
    "gynekologiskares": "gynekologisk",
    "gynekologiskas": "gynekologisk",
    "gynekologiskast": "gynekologisk",
    "gynekologiskaste": "gynekologisk",
    "gynekologiskastes": "gynekologisk",
    "gynekologiskasts": "gynekologisk",
    "gynekologiske": "gynekologisk",
    "gynekologiskes": "gynekologisk",
    "gynekologisks": "gynekologisk",
    "gynekologiskt": "gynekologisk",
    "gynekologiskts": "gynekologisk",
    "gynekologs": "gynekolog",
    "gynn": "gynna",
    "gynnad": "gynna",
    "gynnade": "gynna",
    "gynnades": "gynna",
    "gynnads": "gynna",
    "gynnande": "gynna",
    "gynnanden": "gynnande",
    "gynnandena": "gynnande",
    "gynnandenas": "gynnande",
    "gynnandens": "gynnande",
    "gynnandes": "gynnande",
    "gynnandet": "gynnande",
    "gynnandets": "gynnande",
    "gynnar": "gynnare",
    "gynnaren": "gynnare",
    "gynnarens": "gynnare",
    "gynnares": "gynnare",
    "gynnarna": "gynnare",
    "gynnarnas": "gynnare",
    "gynnas": "gynna",
    "gynnat": "gynna",
    "gynnats": "gynna",
    "gynnsamheten": "gynnsamhet",
    "gynnsamhetens": "gynnsamhet",
    "gynnsamhets": "gynnsamhet",
    "gynnsamma": "gynnsam",
    "gynnsammare": "gynnsam",
    "gynnsammares": "gynnsam",
    "gynnsammas": "gynnsam",
    "gynnsammast": "gynnsam",
    "gynnsammaste": "gynnsam",
    "gynnsammastes": "gynnsam",
    "gynnsammasts": "gynnsam",
    "gynnsamme": "gynnsam",
    "gynnsammes": "gynnsam",
    "gynnsams": "gynnsam",
    "gynnsamt": "gynnsam",
    "gynnsamts": "gynnsam",
    "gyrohorisonten": "gyrohorisont",
    "gyrohorisontens": "gyrohorisont",
    "gyrohorisonter": "gyrohorisont",
    "gyrohorisonterna": "gyrohorisont",
    "gyrohorisonternas": "gyrohorisont",
    "gyrohorisonters": "gyrohorisont",
    "gyrohorisonts": "gyrohorisont",
    "gyrokompassen": "gyrokompass",
    "gyrokompassens": "gyrokompass",
    "gyrokompasser": "gyrokompass",
    "gyrokompasserna": "gyrokompass",
    "gyrokompassernas": "gyrokompass",
    "gyrokompassers": "gyrokompass",
    "gyron": "gyro",
    "gyrona": "gyro",
    "gyronas": "gyro",
    "gyrons": "gyro",
    "gyroprincipen": "gyroprincip",
    "gyroprincipens": "gyroprincip",
    "gyroprincips": "gyroprincip",
    "gyros": "gyro",
    "gyroskopen": "gyroskop",
    "gyroskopens": "gyroskop",
    "gyroskopet": "gyroskop",
    "gyroskopets": "gyroskop",
    "gyroskopkompassen": "gyroskopkompass",
    "gyroskopkompassens": "gyroskopkompass",
    "gyroskopkompasser": "gyroskopkompass",
    "gyroskopkompasserna": "gyroskopkompass",
    "gyroskopkompassernas": "gyroskopkompass",
    "gyroskopkompassers": "gyroskopkompass",
    "gyroskops": "gyroskop",
    "gyrostabilisatorer": "gyrostabilisator",
    "gyrostabilisatorerna": "gyrostabilisator",
    "gyrostabilisatorernas": "gyrostabilisator",
    "gyrostabilisatorers": "gyrostabilisator",
    "gyrostabilisatorn": "gyrostabilisator",
    "gyrostabilisatorns": "gyrostabilisator",
    "gyrostabilisators": "gyrostabilisator",
    "gyrot": "gyro",
    "gyrots": "gyro",
    "gytter": "gyttra",
    "gytters": "gytter",
    "gyttjan": "gyttja",
    "gyttjans": "gyttja",
    "gyttjas": "gyttja",
    "gyttje": "gyttja",
    "gyttjebaden": "gyttjebad",
    "gyttjebadens": "gyttjebad",
    "gyttjebadet": "gyttjebad",
    "gyttjebadets": "gyttjebad",
    "gyttjebads": "gyttjebad",
    "gyttjiga": "gyttjig",
    "gyttjigare": "gyttjig",
    "gyttjigares": "gyttjig",
    "gyttjigas": "gyttjig",
    "gyttjigast": "gyttjig",
    "gyttjigaste": "gyttjig",
    "gyttjigastes": "gyttjig",
    "gyttjigasts": "gyttjig",
    "gyttjige": "gyttjig",
    "gyttjiges": "gyttjig",
    "gyttjigheten": "gyttjighet",
    "gyttjighetens": "gyttjighet",
    "gyttjighets": "gyttjighet",
    "gyttjigs": "gyttjig",
    "gyttjigt": "gyttjig",
    "gyttjigts": "gyttjig",
    "gyttrade": "gyttra",
    "gyttrades": "gyttra",
    "gyttrande": "gyttra",
    "gyttranden": "gyttrande",
    "gyttrandena": "gyttrande",
    "gyttrandenas": "gyttrande",
    "gyttrandens": "gyttrande",
    "gyttrandes": "gyttrande",
    "gyttrandet": "gyttrande",
    "gyttrandets": "gyttrande",
    "gyttrar": "gyttra",
    "gyttras": "gyttra",
    "gyttrat": "gyttra",
    "gyttrats": "gyttra",
    "gyttret": "gytter",
    "gyttrets": "gytter",
    "gyttriga": "gyttrig",
    "gyttrigare": "gyttrig",
    "gyttrigares": "gyttrig",
    "gyttrigas": "gyttrig",
    "gyttrigast": "gyttrig",
    "gyttrigaste": "gyttrig",
    "gyttrigastes": "gyttrig",
    "gyttrigasts": "gyttrig",
    "gyttrige": "gyttrig",
    "gyttriges": "gyttrig",
    "gyttrigheten": "gyttrighet",
    "gyttrighetens": "gyttrighet",
    "gyttrighets": "gyttrighet",
    "gyttrigs": "gyttrig",
    "gyttrigt": "gyttrig",
    "gyttrigts": "gyttrig",
    "gyttringar": "gyttring",
    "gyttringarna": "gyttring",
    "gyttringarnas": "gyttring",
    "gyttringars": "gyttring",
    "gyttringen": "gyttring",
    "gyttringens": "gyttring",
    "gyttrings": "gyttring",
    "gäck": "gäcka",
    "gäckad": "gäcka",
    "gäckade": "gäcka",
    "gäckades": "gäckas",
    "gäckads": "gäcka",
    "gäckande": "gäcka",
    "gäckanden": "gäckande",
    "gäckandena": "gäckande",
    "gäckandenas": "gäckande",
    "gäckandens": "gäckande",
    "gäckandes": "gäckande",
    "gäckandet": "gäckande",
    "gäckandets": "gäckande",
    "gäckar": "gäcka",
    "gäckas": "gäcka",
    "gäckat": "gäcka",
    "gäckats": "gäckas",
    "gäckerier": "gäckeri",
    "gäckerierna": "gäckeri",
    "gäckeriernas": "gäckeri",
    "gäckeriers": "gäckeri",
    "gäckeriet": "gäckeri",
    "gäckeriets": "gäckeri",
    "gäckeris": "gäckeri",
    "gäckerit": "gäckeri",
    "gäckerits": "gäckeri",
    "gäckmasten": "gäckmast",
    "gäckmastens": "gäckmast",
    "gäckmaster": "gäckmast",
    "gäckmasterna": "gäckmast",
    "gäckmasternas": "gäckmast",
    "gäckmasters": "gäckmast",
    "gäckmasts": "gäckmast",
    "gäcksamheten": "gäcksamhet",
    "gäcksamhetens": "gäcksamhet",
    "gäcksamhets": "gäcksamhet",
    "gäcksamma": "gäcksam",
    "gäcksammare": "gäcksam",
    "gäcksammares": "gäcksam",
    "gäcksammas": "gäcksam",
    "gäcksammast": "gäcksam",
    "gäcksammaste": "gäcksam",
    "gäcksammastes": "gäcksam",
    "gäcksammasts": "gäcksam",
    "gäcksamme": "gäcksam",
    "gäcksammes": "gäcksam",
    "gäcksams": "gäcksam",
    "gäcksamt": "gäcksam",
    "gäcksamts": "gäcksam",
    "gädd": "gädda",
    "gäddan": "gädda",
    "gäddans": "gädda",
    "gäddas": "gädda",
    "gädde": "gädda",
    "gäddnaten": "gäddnate",
    "gäddnatens": "gäddnate",
    "gäddnates": "gäddnate",
    "gäddor": "gädda",
    "gäddorna": "gädda",
    "gäddornas": "gädda",
    "gäddors": "gädda",
    "gädds": "gädda",
    "gäddsaxar": "gäddsax",
    "gäddsaxarna": "gäddsax",
    "gäddsaxarnas": "gäddsax",
    "gäddsaxars": "gäddsax",
    "gäddsaxen": "gäddsax",
    "gäddsaxens": "gäddsax",
    "gäl": "gäla",
    "gälad": "gäla",
    "gälade": "gäla",
    "gälades": "gäla",
    "gälads": "gäla",
    "gälande": "gäla",
    "gälanden": "gälande",
    "gälandena": "gälande",
    "gälandenas": "gälande",
    "gälandens": "gälande",
    "gälandes": "gälande",
    "gälandet": "gälande",
    "gälandets": "gälande",
    "gälar": "gäla",
    "gälarna": "gäl",
    "gälarnas": "gäl",
    "gälars": "gäl",
    "gälas": "gäla",
    "gälat": "gäla",
    "gälats": "gäla",
    "gälbgjutar": "gälbgjutare",
    "gälbgjutaren": "gälbgjutare",
    "gälbgjutarens": "gälbgjutare",
    "gälbgjutares": "gälbgjutare",
    "gälbgjutarna": "gälbgjutare",
    "gälbgjutarnas": "gälbgjutare",
    "gälbgjuterier": "gälbgjuteri",
    "gälbgjuterierna": "gälbgjuteri",
    "gälbgjuteriernas": "gälbgjuteri",
    "gälbgjuteriers": "gälbgjuteri",
    "gälbgjuteriet": "gälbgjuteri",
    "gälbgjuteriets": "gälbgjuteri",
    "gälbgjuteris": "gälbgjuteri",
    "gälbgjuterit": "gälbgjuteri",
    "gälbgjuterits": "gälbgjuteri",
    "gälbladen": "gälblad",
    "gälbladens": "gälblad",
    "gälbladet": "gälblad",
    "gälbladets": "gälblad",
    "gälblads": "gälblad",
    "gälbåg": "gälbåge",
    "gälbågar": "gälbåge",
    "gälbågarna": "gälbåge",
    "gälbågarnas": "gälbåge",
    "gälbågars": "gälbåge",
    "gälbågen": "gälbåge",
    "gälbågens": "gälbåge",
    "gälbåges": "gälbåge",
    "gälbågs": "gälbåge",
    "gäld": "gälda",
    "gäldad": "gälda",
    "gäldade": "gälda",
    "gäldades": "gälda",
    "gäldads": "gälda",
    "gäldande": "gälda",
    "gäldanden": "gäldande",
    "gäldandena": "gäldande",
    "gäldandenas": "gäldande",
    "gäldandens": "gäldande",
    "gäldandes": "gäldande",
    "gäldandet": "gäldande",
    "gäldandets": "gäldande",
    "gäldar": "gälda",
    "gäldas": "gälda",
    "gäldat": "gälda",
    "gäldats": "gälda",
    "gäldbundens": "gäldbunden",
    "gäldbundet": "gäldbunden",
    "gäldbundets": "gäldbunden",
    "gäldbundna": "gäldbunden",
    "gäldbundnare": "gäldbunden",
    "gäldbundnares": "gäldbunden",
    "gäldbundnas": "gäldbunden",
    "gäldbundnast": "gäldbunden",
    "gäldbundnaste": "gäldbunden",
    "gäldbundnastes": "gäldbunden",
    "gäldbundnasts": "gäldbunden",
    "gäldbundne": "gäldbunden",
    "gäldbundnes": "gäldbunden",
    "gälde": "gälda",
    "gälden": "gäld",
    "gäldens": "gäld",
    "gäldenären": "gäldenär",
    "gäldenärens": "gäldenär",
    "gäldenärer": "gäldenär",
    "gäldenärerna": "gäldenär",
    "gäldenärernas": "gäldenär",
    "gäldenärers": "gäldenär",
    "gäldenärs": "gäldenär",
    "gäldes": "gälda",
    "gälds": "gäld",
    "gäldstugan": "gäldstuga",
    "gäldstugans": "gäldstuga",
    "gäldstugas": "gäldstuga",
    "gäldstuge": "gäldstuga",
    "gäldstugor": "gäldstuga",
    "gäldstugorna": "gäldstuga",
    "gäldstugornas": "gäldstuga",
    "gäldstugors": "gäldstuga",
    "gäldstugu": "gäldstuga",
    "gälen": "gäl",
    "gälens": "gäl",
    "gäler": "gäl",
    "gälerna": "gäl",
    "gälernas": "gäl",
    "gälers": "gäl",
    "gälisk": "gäliska",
    "gäliska": "gälisk",
    "gäliskan": "gäliska",
    "gäliskans": "gäliska",
    "gäliskare": "gälisk",
    "gäliskares": "gälisk",
    "gäliskas": "gäliska",
    "gäliskast": "gälisk",
    "gäliskaste": "gälisk",
    "gäliskastes": "gälisk",
    "gäliskasts": "gälisk",
    "gäliske": "gäliska",
    "gäliskes": "gälisk",
    "gäliskor": "gäliska",
    "gäliskorna": "gäliska",
    "gäliskornas": "gäliska",
    "gäliskors": "gäliska",
    "gälisks": "gälisk",
    "gäliskt": "gälisk",
    "gäliskts": "gälisk",
    "gäll": "gälla",
    "gälla": "gäll",
    "gällad": "gälla",
    "gällade": "gälla",
    "gällades": "gälla",
    "gällads": "gälla",
    "gällande": "gälla",
    "gällanden": "gällande",
    "gällandena": "gällande",
    "gällandenas": "gällande",
    "gällandens": "gällande",
    "gällandes": "gällande",
    "gällandet": "gällande",
    "gällandets": "gällande",
    "gällare": "gäll",
    "gällares": "gäll",
    "gällas": "gälla",
    "gällast": "gäll",
    "gällaste": "gäll",
    "gällastes": "gäll",
    "gällasts": "gäll",
    "gällat": "gälla",
    "gällats": "gälla",
    "gälld": "gälla",
    "gällda": "gälla",
    "gälldas": "gälla",
    "gällde": "gälla",
    "gälldes": "gälla",
    "gällds": "gälla",
    "gälle": "gäll",
    "gällenheten": "gällenhet",
    "gällenhetens": "gällenhet",
    "gällenhets": "gällenhet",
    "gällens": "gällen",
    "gäller": "gälla",
    "gälles": "gälla",
    "gället": "gällen",
    "gällets": "gällen",
    "gällheten": "gällhet",
    "gällhetens": "gällhet",
    "gällhets": "gällhet",
    "gällna": "gällen",
    "gällnare": "gällen",
    "gällnares": "gällen",
    "gällnas": "gällen",
    "gällnast": "gällen",
    "gällnaste": "gällen",
    "gällnastes": "gällen",
    "gällnasts": "gällen",
    "gällne": "gällen",
    "gällnes": "gällen",
    "gälls": "gälla",
    "gällt": "gälla",
    "gällts": "gälla",
    "gäls": "gäl",
    "gälspring": "gälspringa",
    "gälspringan": "gälspringa",
    "gälspringans": "gälspringa",
    "gälspringas": "gälspringa",
    "gälspringe": "gälspringa",
    "gälspringor": "gälspringa",
    "gälspringorna": "gälspringa",
    "gälspringornas": "gälspringa",
    "gälspringors": "gälspringa",
    "gälsprings": "gälspringa",
    "gämsen": "gäms",
    "gämsens": "gäms",
    "gämser": "gäms",
    "gämserna": "gäms",
    "gämsernas": "gäms",
    "gämsers": "gäms",
    "gäng": "gänga",
    "gängad": "gänga",
    "gängade": "gängad",
    "gängades": "gängad",
    "gängads": "gängad",
    "gängan": "gänga",
    "gängande": "gänga",
    "gänganden": "gängande",
    "gängandena": "gängande",
    "gängandenas": "gängande",
    "gängandens": "gängande",
    "gängandes": "gängande",
    "gängandet": "gängande",
    "gängandets": "gängande",
    "gängans": "gänga",
    "gängar": "gänga",
    "gängas": "gänga",
    "gängat": "gängad",
    "gängats": "gängad",
    "gängbackar": "gängback",
    "gängbackarna": "gängback",
    "gängbackarnas": "gängback",
    "gängbackars": "gängback",
    "gängbacken": "gängback",
    "gängbackens": "gängback",
    "gängbacks": "gängback",
    "gänge": "gänga",
    "gängen": "gänge",
    "gängena": "gänge",
    "gängenas": "gänge",
    "gängens": "gänge",
    "gänges": "gänge",
    "gänget": "gänge",
    "gängets": "gänge",
    "gänginsatsen": "gänginsats",
    "gänginsatsens": "gänginsats",
    "gänginsatser": "gänginsats",
    "gänginsatserna": "gänginsats",
    "gänginsatsernas": "gänginsats",
    "gänginsatsers": "gänginsats",
    "gängklopp": "gängkloppa",
    "gängkloppan": "gängkloppa",
    "gängkloppans": "gängkloppa",
    "gängkloppas": "gängkloppa",
    "gängkloppe": "gängkloppa",
    "gängkloppor": "gängkloppa",
    "gängklopporna": "gängkloppa",
    "gängkloppornas": "gängkloppa",
    "gängkloppors": "gängkloppa",
    "gängklopps": "gängkloppa",
    "gängkrigen": "gängkrig",
    "gängkrigens": "gängkrig",
    "gängkriget": "gängkrig",
    "gängkrigets": "gängkrig",
    "gängkrigs": "gängkrig",
    "gängledar": "gängledare",
    "gängledaren": "gängledare",
    "gängledarens": "gängledare",
    "gängledares": "gängledare",
    "gängledarna": "gängledare",
    "gängledarnas": "gängledare",
    "gängliga": "gänglig",
    "gängligare": "gänglig",
    "gängligares": "gänglig",
    "gängligas": "gänglig",
    "gängligast": "gänglig",
    "gängligaste": "gänglig",
    "gängligastes": "gänglig",
    "gängligasts": "gänglig",
    "gänglige": "gänglig",
    "gängliges": "gänglig",
    "gängligheten": "gänglighet",
    "gänglighetens": "gänglighet",
    "gänglighets": "gänglighet",
    "gängligs": "gänglig",
    "gängligt": "gänglig",
    "gängligts": "gänglig",
    "gängningar": "gängning",
    "gängningarna": "gängning",
    "gängningarnas": "gängning",
    "gängningars": "gängning",
    "gängningen": "gängning",
    "gängningens": "gängning",
    "gängnings": "gängning",
    "gängor": "gänga",
    "gängorna": "gänga",
    "gängornas": "gänga",
    "gängors": "gänga",
    "gängs": "gänge",
    "gängstålen": "gängstål",
    "gängstålens": "gängstål",
    "gängstålet": "gängstål",
    "gängstålets": "gängstål",
    "gängståls": "gängstål",
    "gängtappar": "gängtapp",
    "gängtapparna": "gängtapp",
    "gängtapparnas": "gängtapp",
    "gängtappars": "gängtapp",
    "gängtappen": "gängtapp",
    "gängtappens": "gängtapp",
    "gängtapps": "gängtapp",
    "gängtappshållar": "gängtappshållare",
    "gängtappshållaren": "gängtappshållare",
    "gängtappshållarens": "gängtappshållare",
    "gängtappshållares": "gängtappshållare",
    "gängtappshållarna": "gängtappshållare",
    "gängtappshållarnas": "gängtappshållare",
    "gängtatueringar": "gängtatuering",
    "gängtatueringarna": "gängtatuering",
    "gängtatueringarnas": "gängtatuering",
    "gängtatueringars": "gängtatuering",
    "gängtatueringen": "gängtatuering",
    "gängtatueringens": "gängtatuering",
    "gängtatuerings": "gängtatuering",
    "gängtolkar": "gängtolk",
    "gängtolkarna": "gängtolk",
    "gängtolkarnas": "gängtolk",
    "gängtolkars": "gängtolk",
    "gängtolken": "gängtolk",
    "gängtolkens": "gängtolk",
    "gängtolks": "gängtolk",
    "gängverktygen": "gängverktyg",
    "gängverktygens": "gängverktyg",
    "gängverktyget": "gängverktyg",
    "gängverktygets": "gängverktyg",
    "gängverktygs": "gängverktyg",
    "gängverktygssatsen": "gängverktygssats",
    "gängverktygssatsens": "gängverktygssats",
    "gängverktygssatser": "gängverktygssats",
    "gängverktygssatserna": "gängverktygssats",
    "gängverktygssatsernas": "gängverktygssats",
    "gängverktygssatsers": "gängverktygssats",
    "gärd": "gärda",
    "gärdad": "gärda",
    "gärdade": "gärda",
    "gärdades": "gärda",
    "gärdads": "gärda",
    "gärdande": "gärda",
    "gärdanden": "gärdande",
    "gärdandena": "gärdande",
    "gärdandenas": "gärdande",
    "gärdandens": "gärdande",
    "gärdandes": "gärdande",
    "gärdandet": "gärdande",
    "gärdandets": "gärdande",
    "gärdar": "gärda",
    "gärdas": "gärda",
    "gärdat": "gärda",
    "gärdats": "gärda",
    "gärden": "gärde",
    "gärdena": "gärde",
    "gärdenas": "gärde",
    "gärdens": "gärde",
    "gärder": "gärd",
    "gärderna": "gärd",
    "gärdernas": "gärd",
    "gärders": "gärd",
    "gärdes": "gärde",
    "gärdesgårdar": "gärdesgård",
    "gärdesgårdarna": "gärdesgård",
    "gärdesgårdarnas": "gärdesgård",
    "gärdesgårdars": "gärdesgård",
    "gärdesgården": "gärdesgård",
    "gärdesgårdens": "gärdesgård",
    "gärdesgårds": "gärdesgård",
    "gärdet": "gärde",
    "gärdets": "gärde",
    "gärdningar": "gärdning",
    "gärdningarna": "gärdning",
    "gärdningarnas": "gärdning",
    "gärdningars": "gärdning",
    "gärdningen": "gärdning",
    "gärdningens": "gärdning",
    "gärdnings": "gärdning",
    "gärds": "gärd",
    "gärdsel": "gärdsla",
    "gärdsels": "gärdsel",
    "gärdsgårdar": "gärdsgård",
    "gärdsgårdarna": "gärdsgård",
    "gärdsgårdarnas": "gärdsgård",
    "gärdsgårdars": "gärdsgård",
    "gärdsgården": "gärdsgård",
    "gärdsgårdens": "gärdsgård",
    "gärdsgårds": "gärdsgård",
    "gärdsgårdsstörar": "gärdsgårdsstör",
    "gärdsgårdsstörarna": "gärdsgårdsstör",
    "gärdsgårdsstörarnas": "gärdsgårdsstör",
    "gärdsgårdsstörars": "gärdsgårdsstör",
    "gärdsgårdsstören": "gärdsgårdsstör",
    "gärdsgårdsstörens": "gärdsgårdsstör",
    "gärdsgårdsstörs": "gärdsgårdsstör",
    "gärdsl": "gärdsle",
    "gärdslad": "gärdsla",
    "gärdslade": "gärdsla",
    "gärdslades": "gärdsla",
    "gärdslads": "gärdsla",
    "gärdslande": "gärdsla",
    "gärdslanden": "gärdslande",
    "gärdslandena": "gärdslande",
    "gärdslandenas": "gärdslande",
    "gärdslandens": "gärdslande",
    "gärdslandes": "gärdslande",
    "gärdslandet": "gärdslande",
    "gärdslandets": "gärdslande",
    "gärdslar": "gärdsla",
    "gärdslas": "gärdsla",
    "gärdslat": "gärdsla",
    "gärdslats": "gärdsla",
    "gärdslen": "gärdsle",
    "gärdslena": "gärdsle",
    "gärdslenas": "gärdsle",
    "gärdslens": "gärdsle",
    "gärdsles": "gärdsle",
    "gärdslet": "gärdsle",
    "gärdslets": "gärdsle",
    "gärdsmygar": "gärdsmyg",
    "gärdsmygarna": "gärdsmyg",
    "gärdsmygarnas": "gärdsmyg",
    "gärdsmygars": "gärdsmyg",
    "gärdsmygen": "gärdsmyg",
    "gärdsmygens": "gärdsmyg",
    "gärdsmygs": "gärdsmyg",
    "gärningar": "gärning",
    "gärningarna": "gärning",
    "gärningarnas": "gärning",
    "gärningars": "gärning",
    "gärningen": "gärning",
    "gärningens": "gärning",
    "gärnings": "gärning",
    "gärningsläran": "gärningslära",
    "gärningslärans": "gärningslära",
    "gärningsläras": "gärningslära",
    "gärningsmannaprofilen": "gärningsmannaprofil",
    "gärningsmannaprofilens": "gärningsmannaprofil",
    "gärningsmannaprofiler": "gärningsmannaprofil",
    "gärningsmannaprofilerna": "gärningsmannaprofil",
    "gärningsmannaprofilernas": "gärningsmannaprofil",
    "gärningsmannaprofilers": "gärningsmannaprofil",
    "gärningsmannaprofils": "gärningsmannaprofil",
    "gärningsmannen": "gärningsman",
    "gärningsmannens": "gärningsman",
    "gärningsmans": "gärningsman",
    "gärningsmän": "gärningsman",
    "gärningsmännen": "gärningsman",
    "gärningsmännens": "gärningsman",
    "gärningsmäns": "gärningsman",
    "gärningsorten": "gärningsort",
    "gärningsortens": "gärningsort",
    "gärningsorter": "gärningsort",
    "gärningsorterna": "gärningsort",
    "gärningsorternas": "gärningsort",
    "gärningsorters": "gärningsort",
    "gärningsorts": "gärningsort",
    "gärningspersonen": "gärningsperson",
    "gärningspersonens": "gärningsperson",
    "gärningspersoner": "gärningsperson",
    "gärningspersonerna": "gärningsperson",
    "gärningspersonernas": "gärningsperson",
    "gärningspersoners": "gärningsperson",
    "gärningspersons": "gärningsperson",
    "gärsar": "gärs",
    "gärsarna": "gärs",
    "gärsarnas": "gärs",
    "gärsars": "gärs",
    "gärsen": "gärs",
    "gärsens": "gärs",
    "gäsp": "gäspa",
    "gäspade": "gäspa",
    "gäspades": "gäspa",
    "gäspande": "gäspa",
    "gäspanden": "gäspande",
    "gäspandena": "gäspande",
    "gäspandenas": "gäspande",
    "gäspandens": "gäspande",
    "gäspandes": "gäspande",
    "gäspandet": "gäspande",
    "gäspandets": "gäspande",
    "gäspar": "gäspa",
    "gäspas": "gäspa",
    "gäspat": "gäspa",
    "gäspats": "gäspa",
    "gäspen": "gäsp",
    "gäspens": "gäsp",
    "gäspet": "gäsp",
    "gäspets": "gäsp",
    "gäspiga": "gäspig",
    "gäspigare": "gäspig",
    "gäspigares": "gäspig",
    "gäspigas": "gäspig",
    "gäspigast": "gäspig",
    "gäspigaste": "gäspig",
    "gäspigastes": "gäspig",
    "gäspigasts": "gäspig",
    "gäspige": "gäspig",
    "gäspiges": "gäspig",
    "gäspigheten": "gäspighet",
    "gäspighetens": "gäspighet",
    "gäspighets": "gäspighet",
    "gäspigs": "gäspig",
    "gäspigt": "gäspig",
    "gäspigts": "gäspig",
    "gäspningar": "gäspning",
    "gäspningarna": "gäspning",
    "gäspningarnas": "gäspning",
    "gäspningars": "gäspning",
    "gäspningen": "gäspning",
    "gäspningens": "gäspning",
    "gäspnings": "gäspning",
    "gäsps": "gäsp",
    "gäss": "gås",
    "gässen": "gås",
    "gässens": "gås",
    "gässlingar": "gässling",
    "gässlingarna": "gässling",
    "gässlingarnas": "gässling",
    "gässlingars": "gässling",
    "gässlingen": "gässling",
    "gässlingens": "gässling",
    "gässlings": "gässling",
    "gäst": "gästa",
    "gästabuden": "gästabud",
    "gästabudens": "gästabud",
    "gästabudet": "gästabud",
    "gästabudets": "gästabud",
    "gästabuds": "gästabud",
    "gästad": "gästa",
    "gästade": "gästa",
    "gästades": "gästa",
    "gästads": "gästa",
    "gästande": "gästa",
    "gästanden": "gästande",
    "gästandena": "gästande",
    "gästandenas": "gästande",
    "gästandens": "gästande",
    "gästandes": "gästande",
    "gästandet": "gästande",
    "gästandets": "gästande",
    "gästar": "gästa",
    "gästarbetar": "gästarbetare",
    "gästarbetaren": "gästarbetare",
    "gästarbetarens": "gästarbetare",
    "gästarbetares": "gästarbetare",
    "gästarbetarna": "gästarbetare",
    "gästarbetarnas": "gästarbetare",
    "gästas": "gästa",
    "gästat": "gästa",
    "gästatomen": "gästatom",
    "gästatomens": "gästatom",
    "gästatomer": "gästatom",
    "gästatomerna": "gästatom",
    "gästatomernas": "gästatom",
    "gästatomers": "gästatom",
    "gästatoms": "gästatom",
    "gästats": "gästa",
    "gästboken": "gästbok",
    "gästbokens": "gästbok",
    "gästboks": "gästbok",
    "gästböcker": "gästbok",
    "gästböckerna": "gästbok",
    "gästböckernas": "gästbok",
    "gästböckers": "gästbok",
    "gästen": "gäst",
    "gästens": "gäst",
    "gäster": "gäst",
    "gästerna": "gäst",
    "gästernas": "gäst",
    "gästers": "gäst",
    "gästflagg": "gästflagga",
    "gästflaggan": "gästflagga",
    "gästflaggans": "gästflagga",
    "gästflaggas": "gästflagga",
    "gästflagge": "gästflagga",
    "gästflaggor": "gästflagga",
    "gästflaggorna": "gästflagga",
    "gästflaggornas": "gästflagga",
    "gästflaggors": "gästflagga",
    "gästflaggs": "gästflagga",
    "gästforskar": "gästforskare",
    "gästforskaren": "gästforskare",
    "gästforskarens": "gästforskare",
    "gästforskares": "gästforskare",
    "gästforskarna": "gästforskare",
    "gästforskarnas": "gästforskare",
    "gästfria": "gästfri",
    "gästfriare": "gästfri",
    "gästfriares": "gästfri",
    "gästfrias": "gästfri",
    "gästfriast": "gästfri",
    "gästfriaste": "gästfri",
    "gästfriastes": "gästfri",
    "gästfriasts": "gästfri",
    "gästfrie": "gästfri",
    "gästfries": "gästfri",
    "gästfris": "gästfri",
    "gästfritt": "gästfri",
    "gästfritts": "gästfri",
    "gästgivar": "gästgivare",
    "gästgivaren": "gästgivare",
    "gästgivarens": "gästgivare",
    "gästgivares": "gästgivare",
    "gästgivargårdar": "gästgivargård",
    "gästgivargårdarna": "gästgivargård",
    "gästgivargårdarnas": "gästgivargård",
    "gästgivargårdars": "gästgivargård",
    "gästgivargården": "gästgivargård",
    "gästgivargårdens": "gästgivargård",
    "gästgivargårds": "gästgivargård",
    "gästgivarna": "gästgivare",
    "gästgivarnas": "gästgivare",
    "gästgiverier": "gästgiveri",
    "gästgiverierna": "gästgiveri",
    "gästgiveriernas": "gästgiveri",
    "gästgiveriers": "gästgiveri",
    "gästgiveriet": "gästgiveri",
    "gästgiveriets": "gästgiveri",
    "gästgiveris": "gästgiveri",
    "gästgiverit": "gästgiveri",
    "gästgiverits": "gästgiveri",
    "gästhanddukar": "gästhandduk",
    "gästhanddukarna": "gästhandduk",
    "gästhanddukarnas": "gästhandduk",
    "gästhanddukars": "gästhandduk",
    "gästhandduken": "gästhandduk",
    "gästhanddukens": "gästhandduk",
    "gästhandduks": "gästhandduk",
    "gästlistan": "gästlista",
    "gästlistans": "gästlista",
    "gästlistas": "gästlista",
    "gästliste": "gästlista",
    "gästlistor": "gästlista",
    "gästlistorna": "gästlista",
    "gästlistornas": "gästlista",
    "gästlistors": "gästlista",
    "gästmolekylen": "gästmolekyl",
    "gästmolekylens": "gästmolekyl",
    "gästmolekyler": "gästmolekyl",
    "gästmolekylerna": "gästmolekyl",
    "gästmolekylernas": "gästmolekyl",
    "gästmolekylers": "gästmolekyl",
    "gästmolekyls": "gästmolekyl",
    "gästnatn": "gästnatt",
    "gästnatns": "gästnatt",
    "gästnatten": "gästnatt",
    "gästnattens": "gästnatt",
    "gästnatts": "gästnatt",
    "gästningar": "gästning",
    "gästningarna": "gästning",
    "gästningarnas": "gästning",
    "gästningars": "gästning",
    "gästningen": "gästning",
    "gästningens": "gästning",
    "gästnings": "gästning",
    "gästnätter": "gästnatt",
    "gästnätterna": "gästnatt",
    "gästnätternas": "gästnatt",
    "gästnätters": "gästnatt",
    "gästrik": "gästrike",
    "gästrikar": "gästrike",
    "gästrikarna": "gästrike",
    "gästrikarnas": "gästrike",
    "gästrikars": "gästrike",
    "gästriken": "gästrike",
    "gästrikens": "gästrike",
    "gästrikes": "gästrike",
    "gästrikingar": "gästriking",
    "gästrikingarna": "gästriking",
    "gästrikingarnas": "gästriking",
    "gästrikingars": "gästriking",
    "gästrikingen": "gästriking",
    "gästrikingens": "gästriking",
    "gästrikings": "gästriking",
    "gästrikländska": "gästrikländsk",
    "gästrikländskan": "gästrikländska",
    "gästrikländskans": "gästrikländska",
    "gästrikländskare": "gästrikländsk",
    "gästrikländskares": "gästrikländsk",
    "gästrikländskas": "gästrikländska",
    "gästrikländskast": "gästrikländsk",
    "gästrikländskaste": "gästrikländsk",
    "gästrikländskastes": "gästrikländsk",
    "gästrikländskasts": "gästrikländsk",
    "gästrikländske": "gästrikländska",
    "gästrikländskes": "gästrikländsk",
    "gästrikländskor": "gästrikländska",
    "gästrikländskorna": "gästrikländska",
    "gästrikländskornas": "gästrikländska",
    "gästrikländskors": "gästrikländska",
    "gästrikländsks": "gästrikländsk",
    "gästrikländskt": "gästrikländsk",
    "gästrikländskts": "gästrikländsk",
    "gästriklänningar": "gästriklänning",
    "gästriklänningarna": "gästriklänning",
    "gästriklänningarnas": "gästriklänning",
    "gästriklänningars": "gästriklänning",
    "gästriklänningen": "gästriklänning",
    "gästriklänningens": "gästriklänning",
    "gästriklännings": "gästriklänning",
    "gästriks": "gästrike",
    "gästriksk": "gästrikska",
    "gästrikskan": "gästrikska",
    "gästrikskans": "gästrikska",
    "gästrikskas": "gästrikska",
    "gästringar": "gästring",
    "gästringarna": "gästring",
    "gästringarnas": "gästring",
    "gästringars": "gästring",
    "gästringen": "gästring",
    "gästringens": "gästring",
    "gästrings": "gästring",
    "gästriska": "gästrisk",
    "gästriskare": "gästrisk",
    "gästriskares": "gästrisk",
    "gästriskas": "gästrisk",
    "gästriskast": "gästrisk",
    "gästriskaste": "gästrisk",
    "gästriskastes": "gästrisk",
    "gästriskasts": "gästrisk",
    "gästriske": "gästrisk",
    "gästriskes": "gästrisk",
    "gästrisks": "gästrisk",
    "gästriskt": "gästrisk",
    "gästriskts": "gästrisk",
    "gästrummen": "gästrum",
    "gästrummens": "gästrum",
    "gästrummet": "gästrum",
    "gästrummets": "gästrum",
    "gästrums": "gästrum",
    "gästrumsdörrar": "gästrumsdörr",
    "gästrumsdörrarna": "gästrumsdörr",
    "gästrumsdörrarnas": "gästrumsdörr",
    "gästrumsdörrars": "gästrumsdörr",
    "gästrumsdörren": "gästrumsdörr",
    "gästrumsdörrens": "gästrumsdörr",
    "gästrumsdörrs": "gästrumsdörr",
    "gästs": "gäst",
    "gästspel": "gästspela",
    "gästspelad": "gästspela",
    "gästspelade": "gästspela",
    "gästspelades": "gästspela",
    "gästspelads": "gästspela",
    "gästspelande": "gästspela",
    "gästspelanden": "gästspelande",
    "gästspelandena": "gästspelande",
    "gästspelandenas": "gästspelande",
    "gästspelandens": "gästspelande",
    "gästspelandes": "gästspelande",
    "gästspelandet": "gästspelande",
    "gästspelandets": "gästspelande",
    "gästspelar": "gästspela",
    "gästspelas": "gästspela",
    "gästspelat": "gästspela",
    "gästspelats": "gästspela",
    "gästspelen": "gästspel",
    "gästspelens": "gästspel",
    "gästspelet": "gästspel",
    "gästspelets": "gästspel",
    "gästspels": "gästspel",
    "gästvänliga": "gästvänlig",
    "gästvänligare": "gästvänlig",
    "gästvänligares": "gästvänlig",
    "gästvänligas": "gästvänlig",
    "gästvänligast": "gästvänlig",
    "gästvänligaste": "gästvänlig",
    "gästvänligastes": "gästvänlig",
    "gästvänligasts": "gästvänlig",
    "gästvänlige": "gästvänlig",
    "gästvänliges": "gästvänlig",
    "gästvänligheten": "gästvänlighet",
    "gästvänlighetens": "gästvänlighet",
    "gästvänlighets": "gästvänlighet",
    "gästvänligs": "gästvänlig",
    "gästvänligt": "gästvänlig",
    "gästvänligts": "gästvänlig",
    "gåbockar": "gåbock",
    "gåbockarna": "gåbock",
    "gåbockarnas": "gåbock",
    "gåbockars": "gåbock",
    "gåbocken": "gåbock",
    "gåbockens": "gåbock",
    "gåbocks": "gåbock",
    "gåbortskostymen": "gåbortskostym",
    "gåbortskostymens": "gåbortskostym",
    "gåbortskostymer": "gåbortskostym",
    "gåbortskostymerna": "gåbortskostym",
    "gåbortskostymernas": "gåbortskostym",
    "gåbortskostymers": "gåbortskostym",
    "gåbortskostyms": "gåbortskostym",
    "gående": "gå",
    "gåenden": "gående",
    "gåendena": "gående",
    "gåendenas": "gående",
    "gåendens": "gående",
    "gåendes": "gående",
    "gåendet": "gående",
    "gåendets": "gående",
    "gågat": "gågata",
    "gågatan": "gågata",
    "gågatans": "gågata",
    "gågatas": "gågata",
    "gågate": "gågata",
    "gågator": "gågata",
    "gågatorna": "gågata",
    "gågatornas": "gågata",
    "gågators": "gågata",
    "gågats": "gågata",
    "gågoss": "gågosse",
    "gågossar": "gågosse",
    "gågossarna": "gågosse",
    "gågossarnas": "gågosse",
    "gågossars": "gågosse",
    "gågossen": "gågosse",
    "gågossens": "gågosse",
    "gågosses": "gågosse",
    "gåhjälpmedels": "gåhjälpmedel",
    "gåhjälpmedlen": "gåhjälpmedel",
    "gåhjälpmedlens": "gåhjälpmedel",
    "gåhjälpmedlet": "gåhjälpmedel",
    "gåhjälpmedlets": "gåhjälpmedel",
    "gångade": "gånga",
    "gångades": "gånga",
    "gångande": "gånga",
    "gånganden": "gångande",
    "gångandena": "gångande",
    "gångandenas": "gångande",
    "gångandens": "gångande",
    "gångandes": "gångande",
    "gångandet": "gångande",
    "gångandets": "gångande",
    "gångar": "gångare",
    "gångaren": "gångare",
    "gångarens": "gångare",
    "gångares": "gångare",
    "gångarna": "gångare",
    "gångarnas": "gångare",
    "gångars": "gång",
    "gångarten": "gångart",
    "gångartens": "gångart",
    "gångarter": "gångart",
    "gångarterna": "gångart",
    "gångarternas": "gångart",
    "gångarters": "gångart",
    "gångarts": "gångart",
    "gångas": "gånga",
    "gångat": "gånga",
    "gångats": "gånga",
    "gångavstånden": "gångavstånd",
    "gångavståndens": "gångavstånd",
    "gångavståndet": "gångavstånd",
    "gångavståndets": "gångavstånd",
    "gångavstånds": "gångavstånd",
    "gångbanan": "gångbana",
    "gångbanans": "gångbana",
    "gångbanas": "gångbana",
    "gångbane": "gångbana",
    "gångbanor": "gångbana",
    "gångbanorna": "gångbana",
    "gångbanornas": "gångbana",
    "gångbanors": "gångbana",
    "gångbara": "gångbar",
    "gångbarare": "gångbar",
    "gångbarares": "gångbar",
    "gångbaras": "gångbar",
    "gångbarast": "gångbar",
    "gångbaraste": "gångbar",
    "gångbarastes": "gångbar",
    "gångbarasts": "gångbar",
    "gångbare": "gångbar",
    "gångbares": "gångbar",
    "gångbarheten": "gångbarhet",
    "gångbarhetens": "gångbarhet",
    "gångbarhets": "gångbarhet",
    "gångbars": "gångbar",
    "gångbart": "gångbar",
    "gångbarts": "gångbar",
    "gångbergarten": "gångbergart",
    "gångbergartens": "gångbergart",
    "gångbergarter": "gångbergart",
    "gångbergarterna": "gångbergart",
    "gångbergarternas": "gångbergart",
    "gångbergarters": "gångbergart",
    "gångbergarts": "gångbergart",
    "gångbockar": "gångbock",
    "gångbockarna": "gångbock",
    "gångbockarnas": "gångbock",
    "gångbockars": "gångbock",
    "gångbocken": "gångbock",
    "gångbockens": "gångbock",
    "gångbocks": "gångbock",
    "gångborden": "gångbord",
    "gångbordens": "gångbord",
    "gångbordet": "gångbord",
    "gångbordets": "gångbord",
    "gångbords": "gångbord",
    "gångbroar": "gångbro",
    "gångbroarna": "gångbro",
    "gångbroarnas": "gångbro",
    "gångbroars": "gångbro",
    "gångbron": "gångbro",
    "gångbrons": "gångbro",
    "gångbros": "gångbro",
    "gånge": "gå",
    "gången": "gång",
    "gångens": "gång",
    "gånger": "gång",
    "gångerna": "gång",
    "gångernas": "gång",
    "gångers": "gång",
    "gånges": "gå",
    "gånget": "gå",
    "gångets": "gå",
    "gångfoten": "gångfot",
    "gångfotens": "gångfot",
    "gångfots": "gångfot",
    "gångfötter": "gångfot",
    "gångfötterna": "gångfot",
    "gångfötternas": "gångfot",
    "gångfötters": "gångfot",
    "gånggat": "gånggata",
    "gånggatan": "gånggata",
    "gånggatans": "gånggata",
    "gånggatas": "gånggata",
    "gånggate": "gånggata",
    "gånggator": "gånggata",
    "gånggatorna": "gånggata",
    "gånggatornas": "gånggata",
    "gånggators": "gånggata",
    "gånggats": "gånggata",
    "gånggriften": "gånggrift",
    "gånggriftens": "gånggrift",
    "gånggrifter": "gånggrift",
    "gånggrifterna": "gånggrift",
    "gånggrifternas": "gånggrift",
    "gånggrifters": "gånggrift",
    "gånggrifts": "gånggrift",
    "gånghjälpmedels": "gånghjälpmedel",
    "gånghjälpmedlen": "gånghjälpmedel",
    "gånghjälpmedlens": "gånghjälpmedel",
    "gånghjälpmedlet": "gånghjälpmedel",
    "gånghjälpmedlets": "gånghjälpmedel",
    "gångjärnen": "gångjärn",
    "gångjärnens": "gångjärn",
    "gångjärnet": "gångjärn",
    "gångjärnets": "gångjärn",
    "gångjärns": "gångjärn",
    "gångjärnsleden": "gångjärnsled",
    "gångjärnsledens": "gångjärnsled",
    "gångjärnsleder": "gångjärnsled",
    "gångjärnslederna": "gångjärnsled",
    "gångjärnsledernas": "gångjärnsled",
    "gångjärnsleders": "gångjärnsled",
    "gångjärnsleds": "gångjärnsled",
    "gångkläderna": "gångkläder",
    "gångklädernas": "gångkläder",
    "gångkläders": "gångkläder",
    "gångklädes": "gångkläder",
    "gångkläds": "gångkläder",
    "gångleden": "gångled",
    "gångledens": "gångled",
    "gångleder": "gångled",
    "gånglederna": "gångled",
    "gångledernas": "gångled",
    "gångleders": "gångled",
    "gångleds": "gångled",
    "gånglåtar": "gånglåt",
    "gånglåtarna": "gånglåt",
    "gånglåtarnas": "gånglåt",
    "gånglåtars": "gånglåt",
    "gånglåten": "gånglåt",
    "gånglåtens": "gånglåt",
    "gånglåts": "gånglåt",
    "gångna": "gå",
    "gångnas": "gå",
    "gångne": "gå",
    "gångnes": "gå",
    "gångrad": "gångra",
    "gångrade": "gångra",
    "gångrades": "gångra",
    "gångrads": "gångra",
    "gångrande": "gångra",
    "gångranden": "gångrande",
    "gångrandena": "gångrande",
    "gångrandenas": "gångrande",
    "gångrandens": "gångrande",
    "gångrandes": "gångrande",
    "gångrandet": "gångrande",
    "gångrandets": "gångrande",
    "gångrar": "gångra",
    "gångras": "gångra",
    "gångrat": "gångra",
    "gångrats": "gångra",
    "gångs": "gång",
    "gångspelen": "gångspel",
    "gångspelens": "gångspel",
    "gångspelet": "gångspel",
    "gångspelets": "gångspel",
    "gångspels": "gångspel",
    "gångstolar": "gångstol",
    "gångstolarna": "gångstol",
    "gångstolarnas": "gångstol",
    "gångstolars": "gångstol",
    "gångstolen": "gångstol",
    "gångstolens": "gångstol",
    "gångstols": "gångstol",
    "gångtrafikanten": "gångtrafikant",
    "gångtrafikantens": "gångtrafikant",
    "gångtrafikanter": "gångtrafikant",
    "gångtrafikanterna": "gångtrafikant",
    "gångtrafikanternas": "gångtrafikant",
    "gångtrafikanters": "gångtrafikant",
    "gångtrafikants": "gångtrafikant",
    "gångvägar": "gångväg",
    "gångvägarna": "gångväg",
    "gångvägarnas": "gångväg",
    "gångvägars": "gångväg",
    "gångvägen": "gångväg",
    "gångvägens": "gångväg",
    "gångvägs": "gångväg",
    "gåpåar": "gåpåare",
    "gåpåaren": "gåpåare",
    "gåpåarens": "gåpåare",
    "gåpåares": "gåpåare",
    "gåpåarna": "gåpåare",
    "gåpåarnas": "gåpåare",
    "gåpåiga": "gåpåig",
    "gåpåigare": "gåpåig",
    "gåpåigares": "gåpåig",
    "gåpåigas": "gåpåig",
    "gåpåigast": "gåpåig",
    "gåpåigaste": "gåpåig",
    "gåpåigastes": "gåpåig",
    "gåpåigasts": "gåpåig",
    "gåpåige": "gåpåig",
    "gåpåiges": "gåpåig",
    "gåpåigheten": "gåpåighet",
    "gåpåighetens": "gåpåighet",
    "gåpåighets": "gåpåighet",
    "gåpåigs": "gåpåig",
    "gåpåigt": "gåpåig",
    "gåpåigts": "gåpåig",
    "går": "gå",
    "gårdagar": "gårdag",
    "gårdagarna": "gårdag",
    "gårdagarnas": "gårdag",
    "gårdagars": "gårdag",
    "gårdagen": "gårdag",
    "gårdagens": "gårdag",
    "gårdags": "gårdag",
    "gårdagskvällar": "gårdagskväll",
    "gårdagskvällarna": "gårdagskväll",
    "gårdagskvällarnas": "gårdagskväll",
    "gårdagskvällars": "gårdagskväll",
    "gårdagskvällen": "gårdagskväll",
    "gårdagskvällens": "gårdagskväll",
    "gårdagskvälls": "gårdagskväll",
    "gårdar": "gård",
    "gårdarna": "gård",
    "gårdarnas": "gård",
    "gårdars": "gård",
    "gården": "gård",
    "gårdens": "gård",
    "gårdfarihandeln": "gårdfarihandel",
    "gårdfarihandelns": "gårdfarihandel",
    "gårdfarihandels": "gårdfarihandel",
    "gårdfarihandlanden": "gårdfarihandlande",
    "gårdfarihandlandena": "gårdfarihandlande",
    "gårdfarihandlandenas": "gårdfarihandlande",
    "gårdfarihandlandens": "gårdfarihandlande",
    "gårdfarihandlandes": "gårdfarihandlande",
    "gårdfarihandlar": "gårdfarihandlare",
    "gårdfarihandlaren": "gårdfarihandlare",
    "gårdfarihandlarens": "gårdfarihandlare",
    "gårdfarihandlares": "gårdfarihandlare",
    "gårdfarihandlarna": "gårdfarihandlare",
    "gårdfarihandlarnas": "gårdfarihandlare",
    "gårdingar": "gårding",
    "gårdingarna": "gårding",
    "gårdingarnas": "gårding",
    "gårdingars": "gårding",
    "gårdingen": "gårding",
    "gårdingens": "gårding",
    "gårdings": "gårding",
    "gårds": "gård",
    "gårdsfolket": "gårdsfolk",
    "gårdsfolkets": "gårdsfolk",
    "gårdsfolks": "gårdsfolk",
    "gårdsförsäljningen": "gårdsförsäljning",
    "gårdsförsäljningens": "gårdsförsäljning",
    "gårdsförsäljnings": "gårdsförsäljning",
    "gårdshusen": "gårdshus",
    "gårdshusens": "gårdshus",
    "gårdshuset": "gårdshus",
    "gårdshusets": "gårdshus",
    "gårdskarlar": "gårdskarl",
    "gårdskarlarna": "gårdskarl",
    "gårdskarlarnas": "gårdskarl",
    "gårdskarlars": "gårdskarl",
    "gårdskarlen": "gårdskarl",
    "gårdskarlens": "gårdskarl",
    "gårdskarls": "gårdskarl",
    "gårdskull": "gårdskulle",
    "gårdskullar": "gårdskulle",
    "gårdskullarna": "gårdskulle",
    "gårdskullarnas": "gårdskulle",
    "gårdskullars": "gårdskulle",
    "gårdskullen": "gårdskulle",
    "gårdskullens": "gårdskulle",
    "gårdskulles": "gårdskulle",
    "gårdskulls": "gårdskulle",
    "gårdslykt": "gårdslykta",
    "gårdslyktan": "gårdslykta",
    "gårdslyktans": "gårdslykta",
    "gårdslyktas": "gårdslykta",
    "gårdslykte": "gårdslykta",
    "gårdslyktor": "gårdslykta",
    "gårdslyktorna": "gårdslykta",
    "gårdslyktornas": "gårdslykta",
    "gårdslyktors": "gårdslykta",
    "gårdslykts": "gårdslykta",
    "gårdsmusikanten": "gårdsmusikant",
    "gårdsmusikantens": "gårdsmusikant",
    "gårdsmusikanter": "gårdsmusikant",
    "gårdsmusikanterna": "gårdsmusikant",
    "gårdsmusikanternas": "gårdsmusikant",
    "gårdsmusikanters": "gårdsmusikant",
    "gårdsmusikants": "gårdsmusikant",
    "gårdsområden": "gårdsområde",
    "gårdsområdena": "gårdsområde",
    "gårdsområdenas": "gårdsområde",
    "gårdsområdens": "gårdsområde",
    "gårdsområdes": "gårdsområde",
    "gårdsområdet": "gårdsområde",
    "gårdsområdets": "gårdsområde",
    "gårdsplanen": "gårdsplan",
    "gårdsplanens": "gårdsplan",
    "gårdsplaner": "gårdsplan",
    "gårdsplanerna": "gårdsplan",
    "gårdsplanernas": "gårdsplan",
    "gårdsplaners": "gårdsplan",
    "gårdsplans": "gårdsplan",
    "gårdsplatsen": "gårdsplats",
    "gårdsplatsens": "gårdsplats",
    "gårdsplatser": "gårdsplats",
    "gårdsplatserna": "gårdsplats",
    "gårdsplatsernas": "gårdsplats",
    "gårdsplatsers": "gårdsplats",
    "gårdsrummen": "gårdsrum",
    "gårdsrummens": "gårdsrum",
    "gårdsrummet": "gårdsrum",
    "gårdsrummets": "gårdsrum",
    "gårdsrums": "gårdsrum",
    "gårdsstädningen": "gårdsstädning",
    "gårdsstädningens": "gårdsstädning",
    "gårdsstädnings": "gårdsstädning",
    "gårdvarar": "gårdvar",
    "gårdvararna": "gårdvar",
    "gårdvararnas": "gårdvar",
    "gårdvarars": "gårdvar",
    "gårdvaren": "gårdvar",
    "gårdvarens": "gårdvar",
    "gårdvars": "gårdvar",
    "gås": "gåse",
    "gåsar": "gåse",
    "gåsarna": "gåse",
    "gåsarnas": "gåse",
    "gåsars": "gåse",
    "gåsbrösten": "gåsbröst",
    "gåsbröstens": "gåsbröst",
    "gåsbröstet": "gåsbröst",
    "gåsbröstets": "gåsbröst",
    "gåsbrösts": "gåsbröst",
    "gåsen": "gåse",
    "gåsens": "gåse",
    "gåses": "gåse",
    "gåsfjädern": "gåsfjäder",
    "gåsfjäderns": "gåsfjäder",
    "gåsfjäders": "gåsfjäder",
    "gåsfjädrar": "gåsfjäder",
    "gåsfjädrarna": "gåsfjäder",
    "gåsfjädrarnas": "gåsfjäder",
    "gåsfjädrars": "gåsfjäder",
    "gåsfoten": "gåsfot",
    "gåsfotens": "gåsfot",
    "gåsfots": "gåsfot",
    "gåsfötter": "gåsfot",
    "gåsfötterna": "gåsfot",
    "gåsfötternas": "gåsfot",
    "gåsfötters": "gåsfot",
    "gåshuden": "gåshud",
    "gåshudens": "gåshud",
    "gåshuds": "gåshud",
    "gåskarlar": "gåskarl",
    "gåskarlarna": "gåskarl",
    "gåskarlarnas": "gåskarl",
    "gåskarlars": "gåskarl",
    "gåskarlen": "gåskarl",
    "gåskarlens": "gåskarl",
    "gåskarls": "gåskarl",
    "gåslevern": "gåslever",
    "gåsleverns": "gåslever",
    "gåslevers": "gåslever",
    "gåsmarschen": "gåsmarsch",
    "gåsmarschens": "gåsmarsch",
    "gåsmarschs": "gåsmarsch",
    "gåspenn": "gåspenna",
    "gåspennan": "gåspenna",
    "gåspennans": "gåspenna",
    "gåspennas": "gåspenna",
    "gåspenne": "gåspenna",
    "gåspennor": "gåspenna",
    "gåspennorna": "gåspenna",
    "gåspennornas": "gåspenna",
    "gåspennors": "gåspenna",
    "gåspenns": "gåspenna",
    "gåstavar": "gåstav",
    "gåstavarna": "gåstav",
    "gåstavarnas": "gåstav",
    "gåstavars": "gåstav",
    "gåstaven": "gåstav",
    "gåstavens": "gåstav",
    "gåstavs": "gåstav",
    "gåstolar": "gåstol",
    "gåstolarna": "gåstol",
    "gåstolarnas": "gåstol",
    "gåstolars": "gåstol",
    "gåstolen": "gåstol",
    "gåstolens": "gåstol",
    "gåstols": "gåstol",
    "gåsungar": "gåsunge",
    "gåsungarna": "gåsunge",
    "gåsungarnas": "gåsunge",
    "gåsungars": "gåsunge",
    "gåsungen": "gåsunge",
    "gåsungens": "gåsunge",
    "gåsunges": "gåsunge",
    "gåsögonen": "gåsögon",
    "gåsögonens": "gåsögon",
    "gåsögons": "gåsögon",
    "gåsörten": "gåsört",
    "gåsörtens": "gåsört",
    "gåsörts": "gåsört",
    "gåt": "gåta",
    "gåtan": "gåta",
    "gåtans": "gåta",
    "gåtar": "gåt",
    "gåtarna": "gåt",
    "gåtarnas": "gåt",
    "gåtars": "gåt",
    "gåtas": "gåta",
    "gåte": "gåta",
    "gåten": "gåt",
    "gåtens": "gåt",
    "gåtfulla": "gåtfull",
    "gåtfullare": "gåtfull",
    "gåtfullares": "gåtfull",
    "gåtfullas": "gåtfull",
    "gåtfullast": "gåtfull",
    "gåtfullaste": "gåtfull",
    "gåtfullastes": "gåtfull",
    "gåtfullasts": "gåtfull",
    "gåtfulle": "gåtfull",
    "gåtfulles": "gåtfull",
    "gåtfullheten": "gåtfullhet",
    "gåtfullhetens": "gåtfullhet",
    "gåtfullheter": "gåtfullhet",
    "gåtfullheterna": "gåtfullhet",
    "gåtfullheternas": "gåtfullhet",
    "gåtfullheters": "gåtfullhet",
    "gåtfullhets": "gåtfullhet",
    "gåtfulls": "gåtfull",
    "gåtfullt": "gåtfull",
    "gåtfullts": "gåtfull",
    "gåtor": "gåta",
    "gåtorna": "gåta",
    "gåtornas": "gåta",
    "gåtors": "gåta",
    "gåts": "gåta",
    "gått": "gå",
    "gåtts": "gå",
    "gåv": "gåva",
    "gåvan": "gåva",
    "gåvans": "gåva",
    "gåvas": "gåva",
    "gåve": "ge",
    "gåves": "ge",
    "gåvo": "gåva",
    "gåvoavtalen": "gåvoavtal",
    "gåvoavtalens": "gåvoavtal",
    "gåvoavtalet": "gåvoavtal",
    "gåvoavtalets": "gåvoavtal",
    "gåvoavtals": "gåvoavtal",
    "gåvobreven": "gåvobrev",
    "gåvobrevens": "gåvobrev",
    "gåvobrevet": "gåvobrev",
    "gåvobrevets": "gåvobrev",
    "gåvobrevs": "gåvobrev",
    "gåvodiplomatien": "gåvodiplomati",
    "gåvodiplomatiens": "gåvodiplomati",
    "gåvodiplomatin": "gåvodiplomati",
    "gåvodiplomatins": "gåvodiplomati",
    "gåvodiplomatis": "gåvodiplomati",
    "gåvohandlingar": "gåvohandling",
    "gåvohandlingarna": "gåvohandling",
    "gåvohandlingarnas": "gåvohandling",
    "gåvohandlingars": "gåvohandling",
    "gåvohandlingen": "gåvohandling",
    "gåvohandlingens": "gåvohandling",
    "gåvohandlings": "gåvohandling",
    "gåvor": "gåva",
    "gåvorna": "gåva",
    "gåvornas": "gåva",
    "gåvors": "gåva",
    "gåvoskatten": "gåvoskatt",
    "gåvoskattens": "gåvoskatt",
    "gåvoskatter": "gåvoskatt",
    "gåvoskatterna": "gåvoskatt",
    "gåvoskatternas": "gåvoskatt",
    "gåvoskatters": "gåvoskatt",
    "gåvoskatts": "gåvoskatt",
    "gåvs": "gåva",
    "göd": "göda",
    "gödande": "göda",
    "gödanden": "gödande",
    "gödandena": "gödande",
    "gödandenas": "gödande",
    "gödandens": "gödande",
    "gödandes": "gödande",
    "gödandet": "gödande",
    "gödandets": "gödande",
    "gödas": "göda",
    "gödd": "göda",
    "gödda": "göda",
    "göddas": "göda",
    "gödde": "göda",
    "göddes": "göda",
    "göddjuren": "göddjur",
    "göddjurens": "göddjur",
    "göddjuret": "göddjur",
    "göddjurets": "göddjur",
    "göddjurs": "göddjur",
    "gödds": "göda",
    "göder": "göda",
    "gödes": "göda",
    "gödkycklingar": "gödkyckling",
    "gödkycklingarna": "gödkyckling",
    "gödkycklingarnas": "gödkyckling",
    "gödkycklingars": "gödkyckling",
    "gödkycklingen": "gödkyckling",
    "gödkycklingens": "gödkyckling",
    "gödkycklings": "gödkyckling",
    "gödningar": "gödning",
    "gödningarna": "gödning",
    "gödningarnas": "gödning",
    "gödningars": "gödning",
    "gödningen": "gödning",
    "gödningens": "gödning",
    "gödnings": "gödning",
    "gödningsmedels": "gödningsmedel",
    "gödningsmedlen": "gödningsmedel",
    "gödningsmedlens": "gödningsmedel",
    "gödningsmedlet": "gödningsmedel",
    "gödningsmedlets": "gödningsmedel",
    "göds": "göda",
    "gödsel": "gödsla",
    "gödselmedels": "gödselmedel",
    "gödselmedlen": "gödselmedel",
    "gödselmedlens": "gödselmedel",
    "gödselmedlet": "gödselmedel",
    "gödselmedlets": "gödselmedel",
    "gödseln": "gödsel",
    "gödselns": "gödsel",
    "gödselränn": "gödselränna",
    "gödselrännan": "gödselränna",
    "gödselrännans": "gödselränna",
    "gödselrännas": "gödselränna",
    "gödselränne": "gödselränna",
    "gödselrännor": "gödselränna",
    "gödselrännorna": "gödselränna",
    "gödselrännornas": "gödselränna",
    "gödselrännors": "gödselränna",
    "gödselränns": "gödselränna",
    "gödsels": "gödsel",
    "gödselspridar": "gödselspridare",
    "gödselspridaren": "gödselspridare",
    "gödselspridarens": "gödselspridare",
    "gödselspridares": "gödselspridare",
    "gödselspridarna": "gödselspridare",
    "gödselspridarnas": "gödselspridare",
    "gödselstackar": "gödselstack",
    "gödselstackarna": "gödselstack",
    "gödselstackarnas": "gödselstack",
    "gödselstackars": "gödselstack",
    "gödselstacken": "gödselstack",
    "gödselstackens": "gödselstack",
    "gödselstacks": "gödselstack",
    "gödselstaden": "gödselstad",
    "gödselstadens": "gödselstad",
    "gödselstads": "gödselstad",
    "gödselstäder": "gödselstad",
    "gödselstäderna": "gödselstad",
    "gödselstädernas": "gödselstad",
    "gödselstäders": "gödselstad",
    "gödselvattens": "gödselvatten",
    "gödselvattnet": "gödselvatten",
    "gödselvattnets": "gödselvatten",
    "gödslad": "gödsla",
    "gödslade": "gödsla",
    "gödslades": "gödsla",
    "gödslads": "gödsla",
    "gödslande": "gödsla",
    "gödslanden": "gödslande",
    "gödslandena": "gödslande",
    "gödslandenas": "gödslande",
    "gödslandens": "gödslande",
    "gödslandes": "gödslande",
    "gödslandet": "gödslande",
    "gödslandets": "gödslande",
    "gödslar": "gödsla",
    "gödslas": "gödsla",
    "gödslat": "gödsla",
    "gödslats": "gödsla",
    "gödslingar": "gödsling",
    "gödslingarna": "gödsling",
    "gödslingarnas": "gödsling",
    "gödslingars": "gödsling",
    "gödslingen": "gödsling",
    "gödslingens": "gödsling",
    "gödslings": "gödsling",
    "göjemånaden": "göjemånad",
    "göjemånadens": "göjemånad",
    "göjemånader": "göjemånad",
    "göjemånaderna": "göjemånad",
    "göjemånadernas": "göjemånad",
    "göjemånaders": "göjemånad",
    "göjemånads": "göjemånad",
    "gök": "göka",
    "gökad": "göka",
    "gökade": "göka",
    "gökades": "göka",
    "gökads": "göka",
    "gökande": "göka",
    "gökanden": "gökande",
    "gökandena": "gökande",
    "gökandenas": "gökande",
    "gökandens": "gökande",
    "gökandes": "gökande",
    "gökandet": "gökande",
    "gökandets": "gökande",
    "gökar": "göka",
    "gökarna": "gök",
    "gökarnas": "gök",
    "gökars": "gök",
    "gökas": "göka",
    "gökat": "göka",
    "gökats": "göka",
    "gökblom": "gökblomma",
    "gökblomman": "gökblomma",
    "gökblommans": "gökblomma",
    "gökblommas": "gökblomma",
    "gökblomme": "gökblomma",
    "gökblommor": "gökblomma",
    "gökblommorna": "gökblomma",
    "gökblommornas": "gökblomma",
    "gökblommors": "gökblomma",
    "gökbloms": "gökblomma",
    "gökblomsterna": "gökblomster",
    "gökblomsternas": "gökblomster",
    "gökblomsters": "gökblomster",
    "gökblomstren": "gökblomster",
    "gökblomstrens": "gökblomster",
    "gökblomstret": "gökblomster",
    "gökblomstrets": "gökblomster",
    "göken": "gök",
    "gökens": "gök",
    "gökklock": "gökklocka",
    "gökklockan": "gökklocka",
    "gökklockans": "gökklocka",
    "gökklockas": "gökklocka",
    "gökklocke": "gökklocka",
    "gökklockor": "gökklocka",
    "gökklockorna": "gökklocka",
    "gökklockornas": "gökklocka",
    "gökklockors": "gökklocka",
    "gökklocks": "gökklocka",
    "gökmaten": "gökmat",
    "gökmatens": "gökmat",
    "gökmats": "gökmat",
    "göknyckel": "göknycklar",
    "göknyckels": "göknycklar",
    "göknycklarna": "göknycklar",
    "göknycklarnas": "göknycklar",
    "göknycklars": "göknycklar",
    "gökott": "gökotta",
    "gökottan": "gökotta",
    "gökottans": "gökotta",
    "gökottas": "gökotta",
    "gökotte": "gökotta",
    "gökottor": "gökotta",
    "gökottorna": "gökotta",
    "gökottornas": "gökotta",
    "gökottors": "gökotta",
    "gökotts": "gökotta",
    "göks": "gök",
    "göktyt": "göktyta",
    "göktytan": "göktyta",
    "göktytans": "göktyta",
    "göktytas": "göktyta",
    "göktyte": "göktyta",
    "göktytor": "göktyta",
    "göktytorna": "göktyta",
    "göktytornas": "göktyta",
    "göktytors": "göktyta",
    "göktyts": "göktyta",
    "gökungar": "gökunge",
    "gökungarna": "gökunge",
    "gökungarnas": "gökunge",
    "gökungars": "gökunge",
    "gökungen": "gökunge",
    "gökungens": "gökunge",
    "gökunges": "gökunge",
    "gökuren": "gökur",
    "gökurens": "gökur",
    "gökuret": "gökur",
    "gökurets": "gökur",
    "gökurs": "gökur",
    "gökärten": "gökärt",
    "gökärtens": "gökärt",
    "gökärts": "gökärt",
    "gölar": "göl",
    "gölarna": "göl",
    "gölarnas": "göl",
    "gölars": "göl",
    "gölen": "göl",
    "gölens": "göl",
    "gölingar": "göling",
    "gölingarna": "göling",
    "gölingarnas": "göling",
    "gölingars": "göling",
    "gölingen": "göling",
    "gölingens": "göling",
    "gölings": "göling",
    "göls": "göl",
    "göm": "gömma",
    "gömd": "gömma",
    "gömda": "gömma",
    "gömdas": "gömma",
    "gömde": "gömma",
    "gömdes": "gömma",
    "gömds": "gömma",
    "gömfröiga": "gömfröig",
    "gömfröigare": "gömfröig",
    "gömfröigares": "gömfröig",
    "gömfröigas": "gömfröig",
    "gömfröigast": "gömfröig",
    "gömfröigaste": "gömfröig",
    "gömfröigastes": "gömfröig",
    "gömfröigasts": "gömfröig",
    "gömfröige": "gömfröig",
    "gömfröiges": "gömfröig",
    "gömfröigs": "gömfröig",
    "gömfröigt": "gömfröig",
    "gömfröigts": "gömfröig",
    "gömman": "gömma",
    "gömmande": "gömma",
    "gömmanden": "gömmande",
    "gömmandena": "gömmande",
    "gömmandenas": "gömmande",
    "gömmandens": "gömmande",
    "gömmandes": "gömmande",
    "gömmandet": "gömmande",
    "gömmandets": "gömmande",
    "gömmans": "gömma",
    "gömmas": "gömma",
    "gömme": "gömma",
    "gömmen": "gömme",
    "gömmena": "gömme",
    "gömmenas": "gömme",
    "gömmens": "gömme",
    "gömmer": "gömma",
    "gömmes": "gömme",
    "gömmet": "gömme",
    "gömmets": "gömme",
    "gömmor": "gömma",
    "gömmorna": "gömma",
    "gömmornas": "gömma",
    "gömmors": "gömma",
    "göms": "gömme",
    "gömsl": "gömsle",
    "gömslen": "gömsle",
    "gömslena": "gömsle",
    "gömslenas": "gömsle",
    "gömslens": "gömsle",
    "gömsles": "gömsle",
    "gömslet": "gömsle",
    "gömslets": "gömsle",
    "gömställen": "gömställe",
    "gömställena": "gömställe",
    "gömställenas": "gömställe",
    "gömställens": "gömställe",
    "gömställes": "gömställe",
    "gömstället": "gömställe",
    "gömställets": "gömställe",
    "gömt": "gömma",
    "gömts": "gömma",
    "göpenn": "göpen",
    "göpenns": "göpen",
    "göpens": "göpen",
    "göpnar": "göpen",
    "göpnarna": "göpen",
    "göpnarnas": "göpen",
    "göpnars": "göpen",
    "gör": "göra",
    "görande": "göra",
    "göranden": "görande",
    "görandena": "görande",
    "görandenas": "görande",
    "görandens": "görande",
    "görandes": "görande",
    "görandet": "görande",
    "görandets": "görande",
    "görar": "görare",
    "göraren": "görare",
    "görarens": "görare",
    "görares": "görare",
    "görarna": "görare",
    "görarnas": "görare",
    "göras": "göra",
    "görat": "göra",
    "görats": "göra",
    "gördel": "gördla",
    "gördelbåg": "gördelbåge",
    "gördelbågar": "gördelbåge",
    "gördelbågarna": "gördelbåge",
    "gördelbågarnas": "gördelbåge",
    "gördelbågars": "gördelbåge",
    "gördelbågen": "gördelbåge",
    "gördelbågens": "gördelbåge",
    "gördelbåges": "gördelbåge",
    "gördelbågs": "gördelbåge",
    "gördeldäcken": "gördeldäck",
    "gördeldäckens": "gördeldäck",
    "gördeldäcket": "gördeldäck",
    "gördeldäckets": "gördeldäck",
    "gördeldäcks": "gördeldäck",
    "gördelfästningar": "gördelfästning",
    "gördelfästningarna": "gördelfästning",
    "gördelfästningarnas": "gördelfästning",
    "gördelfästningars": "gördelfästning",
    "gördelfästningen": "gördelfästning",
    "gördelfästningens": "gördelfästning",
    "gördelfästnings": "gördelfästning",
    "gördelmakar": "gördelmakare",
    "gördelmakaren": "gördelmakare",
    "gördelmakarens": "gördelmakare",
    "gördelmakares": "gördelmakare",
    "gördelmakarna": "gördelmakare",
    "gördelmakarnas": "gördelmakare",
    "gördeln": "gördel",
    "gördelns": "gördel",
    "gördels": "gördel",
    "gördlad": "gördla",
    "gördlade": "gördla",
    "gördlades": "gördla",
    "gördlads": "gördla",
    "gördlande": "gördla",
    "gördlanden": "gördlande",
    "gördlandena": "gördlande",
    "gördlandenas": "gördlande",
    "gördlandens": "gördlande",
    "gördlandes": "gördlande",
    "gördlandet": "gördlande",
    "gördlandets": "gördlande",
    "gördlar": "gördla",
    "gördlarna": "gördel",
    "gördlarnas": "gördel",
    "gördlars": "gördel",
    "gördlas": "gördla",
    "gördlat": "gördla",
    "gördlats": "gördla",
    "göres": "göra",
    "görliga": "görlig",
    "görligare": "görlig",
    "görligares": "görlig",
    "görligas": "görlig",
    "görligast": "görlig",
    "görligaste": "görlig",
    "görligastes": "görlig",
    "görligasts": "görlig",
    "görlige": "görlig",
    "görliges": "görlig",
    "görligheten": "görlighet",
    "görlighetens": "görlighet",
    "görlighets": "görlighet",
    "görligs": "görlig",
    "görligt": "görlig",
    "görligts": "görlig",
    "göromålen": "göromål",
    "göromålens": "göromål",
    "göromålet": "göromål",
    "göromålets": "göromål",
    "göromåls": "göromål",
    "görs": "göra",
    "gösar": "gös",
    "gösarna": "gös",
    "gösarnas": "gös",
    "gösars": "gös",
    "gösen": "gös",
    "gösens": "gös",
    "gösstak": "gösstake",
    "gösstakar": "gösstake",
    "gösstakarna": "gösstake",
    "gösstakarnas": "gösstake",
    "gösstakars": "gösstake",
    "gösstaken": "gösstake",
    "gösstakens": "gösstake",
    "gösstakes": "gösstake",
    "gösstaks": "gösstake",
    "göt": "gjuta",
    "götamålen": "götamål",
    "götamålens": "götamål",
    "götamålet": "götamål",
    "götamålets": "götamål",
    "götamåls": "götamål",
    "götar": "göt",
    "götarna": "göt",
    "götarnas": "göt",
    "götars": "göt",
    "göte": "gjuta",
    "göteborgar": "göteborgare",
    "göteborgaren": "göteborgare",
    "göteborgarens": "göteborgare",
    "göteborgares": "göteborgare",
    "göteborgarna": "göteborgare",
    "göteborgarnas": "göteborgare",
    "göteborgsk": "göteborgska",
    "göteborgska": "göteborgsk",
    "göteborgskan": "göteborgska",
    "göteborgskans": "göteborgska",
    "göteborgskare": "göteborgsk",
    "göteborgskares": "göteborgsk",
    "göteborgskas": "göteborgska",
    "göteborgskast": "göteborgsk",
    "göteborgskaste": "göteborgsk",
    "göteborgskastes": "göteborgsk",
    "göteborgskasts": "göteborgsk",
    "göteborgske": "göteborgska",
    "göteborgskes": "göteborgsk",
    "göteborgskor": "göteborgska",
    "göteborgskorna": "göteborgska",
    "göteborgskornas": "göteborgska",
    "göteborgskors": "göteborgska",
    "göteborgsks": "göteborgsk",
    "göteborgskt": "göteborgsk",
    "göteborgskts": "göteborgsk",
    "göteborgsvitsar": "göteborgsvits",
    "göteborgsvitsarna": "göteborgsvits",
    "göteborgsvitsarnas": "göteborgsvits",
    "göteborgsvitsars": "göteborgsvits",
    "göteborgsvitsen": "göteborgsvits",
    "göteborgsvitsens": "göteborgsvits",
    "göten": "göte",
    "götena": "göte",
    "götenas": "göte",
    "götens": "göte",
    "göter": "göt",
    "göterna": "göt",
    "göternas": "göt",
    "göters": "göt",
    "götes": "göte",
    "götet": "göte",
    "götets": "göte",
    "göticismen": "göticism",
    "göticismens": "göticism",
    "göticismer": "göticism",
    "göticismerna": "göticism",
    "göticismernas": "göticism",
    "göticismers": "göticism",
    "göticisms": "göticism",
    "göticistiska": "göticistisk",
    "göticistiskare": "göticistisk",
    "göticistiskares": "göticistisk",
    "göticistiskas": "göticistisk",
    "göticistiskast": "göticistisk",
    "göticistiskaste": "göticistisk",
    "göticistiskastes": "göticistisk",
    "göticistiskasts": "göticistisk",
    "göticistiske": "göticistisk",
    "göticistiskes": "göticistisk",
    "göticistisks": "göticistisk",
    "göticistiskt": "göticistisk",
    "göticistiskts": "göticistisk",
    "götiska": "götisk",
    "götiskare": "götisk",
    "götiskares": "götisk",
    "götiskas": "götisk",
    "götiskast": "götisk",
    "götiskaste": "götisk",
    "götiskastes": "götisk",
    "götiskasts": "götisk",
    "götiske": "götisk",
    "götiskes": "götisk",
    "götisks": "götisk",
    "götiskt": "götisk",
    "götiskts": "götisk",
    "götmetallen": "götmetall",
    "götmetallens": "götmetall",
    "götmetalls": "götmetall",
    "göts": "göt",
    "gött": "göda",
    "götterdämmerungen": "götterdämmerung",
    "götterdämmerungens": "götterdämmerung",
    "götterdämmerungs": "götterdämmerung",
    "götts": "göda",
    "götvalsverken": "götvalsverk",
    "götvalsverkens": "götvalsverk",
    "götvalsverket": "götvalsverk",
    "götvalsverkets": "götvalsverk",
    "götvalsverks": "götvalsverk",
    "h-et": "h",
    "h-ets": "h",
    "h-n": "h",
    "h-na": "h",
    "h-nas": "h",
    "h-ns": "h",
    "h-t": "h",
    "h-ts": "h",
    "h:et": "h",
    "h:ets": "h",
    "h:n": "h",
    "h:na": "h",
    "h:nas": "h",
    "h:ns": "h",
    "h:s": "h",
    "h:t": "h",
    "h:ts": "h",
    "habegäret": "habegär",
    "habegärets": "habegär",
    "habegärs": "habegär",
    "habila": "habil",
    "habilare": "habil",
    "habilares": "habil",
    "habilas": "habil",
    "habilast": "habil",
    "habilaste": "habil",
    "habilastes": "habil",
    "habilasts": "habil",
    "habile": "habil",
    "habiles": "habil",
    "habiliteringar": "habilitering",
    "habiliteringarna": "habilitering",
    "habiliteringarnas": "habilitering",
    "habiliteringars": "habilitering",
    "habiliteringen": "habilitering",
    "habiliteringens": "habilitering",
    "habiliterings": "habilitering",
    "habiliteten": "habilitet",
    "habilitetens": "habilitet",
    "habiliteter": "habilitet",
    "habiliteterna": "habilitet",
    "habiliteternas": "habilitet",
    "habiliteters": "habilitet",
    "habilitets": "habilitet",
    "habils": "habil",
    "habilt": "habil",
    "habilts": "habil",
    "habiten": "habit",
    "habitens": "habit",
    "habiter": "habit",
    "habiterna": "habit",
    "habiternas": "habit",
    "habiters": "habit",
    "habits": "habit",
    "habituella": "habituell",
    "habituellare": "habituell",
    "habituellares": "habituell",
    "habituellas": "habituell",
    "habituellast": "habituell",
    "habituellaste": "habituell",
    "habituellastes": "habituell",
    "habituellasts": "habituell",
    "habituelle": "habituell",
    "habituelles": "habituell",
    "habituells": "habituell",
    "habituellt": "habituell",
    "habituellts": "habituell",
    "habitusar": "habitus",
    "habitusarna": "habitus",
    "habitusarnas": "habitus",
    "habitusars": "habitus",
    "habitusen": "habitus",
    "habitusens": "habitus",
    "habituéen": "habitué",
    "habituéens": "habitué",
    "habituéer": "habitué",
    "habituéerna": "habitué",
    "habituéernas": "habitué",
    "habituéers": "habitué",
    "habituén": "habitué",
    "habituéns": "habitué",
    "habitués": "habitué",
    "habsburgska": "habsburgsk",
    "habsburgskare": "habsburgsk",
    "habsburgskares": "habsburgsk",
    "habsburgskas": "habsburgsk",
    "habsburgskast": "habsburgsk",
    "habsburgskaste": "habsburgsk",
    "habsburgskastes": "habsburgsk",
    "habsburgskasts": "habsburgsk",
    "habsburgske": "habsburgsk",
    "habsburgskes": "habsburgsk",
    "habsburgsks": "habsburgsk",
    "habsburgskt": "habsburgsk",
    "habsburgskts": "habsburgsk",
    "hack": "hacka",
    "hackad": "hacka",
    "hackade": "hacka",
    "hackades": "hacka",
    "hackads": "hacka",
    "hackan": "hacka",
    "hackande": "hacka",
    "hackanden": "hackande",
    "hackandena": "hackande",
    "hackandenas": "hackande",
    "hackandens": "hackande",
    "hackandes": "hackande",
    "hackandet": "hackande",
    "hackandets": "hackande",
    "hackans": "hacka",
    "hackar": "hackare",
    "hackaren": "hackare",
    "hackarens": "hackare",
    "hackares": "hackare",
    "hackarna": "hackare",
    "hackarnas": "hackare",
    "hackas": "hacka",
    "hackat": "hacka",
    "hackats": "hacka",
    "hackbräden": "hackbräde",
    "hackbrädena": "hackbräde",
    "hackbrädenas": "hackbräde",
    "hackbrädens": "hackbräde",
    "hackbrädes": "hackbräde",
    "hackbrädet": "hackbräde",
    "hackbrädets": "hackbräde",
    "hacke": "hacka",
    "hackelsen": "hackelse",
    "hackelsens": "hackelse",
    "hackelses": "hackelse",
    "hacken": "hack",
    "hackens": "hack",
    "hackern": "hacker",
    "hackerns": "hacker",
    "hackers": "hacker",
    "hackersarna": "hacker",
    "hackersarnas": "hacker",
    "hackersen": "hacker",
    "hackersens": "hacker",
    "hacket": "hack",
    "hackets": "hack",
    "hackhost": "hackhosta",
    "hackhostan": "hackhosta",
    "hackhostans": "hackhosta",
    "hackhostas": "hackhosta",
    "hackhoste": "hackhosta",
    "hackiga": "hackig",
    "hackigare": "hackig",
    "hackigares": "hackig",
    "hackigas": "hackig",
    "hackigast": "hackig",
    "hackigaste": "hackig",
    "hackigastes": "hackig",
    "hackigasts": "hackig",
    "hackige": "hackig",
    "hackiges": "hackig",
    "hackigheten": "hackighet",
    "hackighetens": "hackighet",
    "hackighets": "hackighet",
    "hackigs": "hackig",
    "hackigt": "hackig",
    "hackigts": "hackig",
    "hackkycklingar": "hackkyckling",
    "hackkycklingarna": "hackkyckling",
    "hackkycklingarnas": "hackkyckling",
    "hackkycklingars": "hackkyckling",
    "hackkycklingen": "hackkyckling",
    "hackkycklingens": "hackkyckling",
    "hackkycklings": "hackkyckling",
    "hackmaten": "hackmat",
    "hackmatens": "hackmat",
    "hackmats": "hackmat",
    "hackningsförsöken": "hackningsförsök",
    "hackningsförsökens": "hackningsförsök",
    "hackningsförsöket": "hackningsförsök",
    "hackningsförsökets": "hackningsförsök",
    "hackningsförsöks": "hackningsförsök",
    "hackor": "hacka",
    "hackordningar": "hackordning",
    "hackordningarna": "hackordning",
    "hackordningarnas": "hackordning",
    "hackordningars": "hackordning",
    "hackordningen": "hackordning",
    "hackordningens": "hackordning",
    "hackordnings": "hackordning",
    "hackorna": "hacka",
    "hackornas": "hacka",
    "hackors": "hacka",
    "hacks": "hacka",
    "hackspettar": "hackspett",
    "hackspettarna": "hackspett",
    "hackspettarnas": "hackspett",
    "hackspettars": "hackspett",
    "hackspetten": "hackspett",
    "hackspettens": "hackspett",
    "hackspetts": "hackspett",
    "hade": "ha",
    "hades": "ha",
    "haff": "haffa",
    "haffad": "haffa",
    "haffade": "haffa",
    "haffades": "haffa",
    "haffads": "haffa",
    "haffande": "haffa",
    "haffanden": "haffande",
    "haffandena": "haffande",
    "haffandenas": "haffande",
    "haffandens": "haffande",
    "haffandes": "haffande",
    "haffandet": "haffande",
    "haffandets": "haffande",
    "haffar": "haffa",
    "haffas": "haffa",
    "haffat": "haffa",
    "haffats": "haffa",
    "hafniet": "hafnium",
    "hafniets": "hafnium",
    "hafniumet": "hafnium",
    "hafniumets": "hafnium",
    "hafniums": "hafnium",
    "hafs": "hafsa",
    "hafsade": "hafsa",
    "hafsades": "hafsa",
    "hafsande": "hafsa",
    "hafsanden": "hafsande",
    "hafsandena": "hafsande",
    "hafsandenas": "hafsande",
    "hafsandens": "hafsande",
    "hafsandes": "hafsande",
    "hafsandet": "hafsande",
    "hafsandets": "hafsande",
    "hafsar": "hafsa",
    "hafsas": "hafsa",
    "hafsat": "hafsa",
    "hafsats": "hafsa",
    "hafsiga": "hafsig",
    "hafsigare": "hafsig",
    "hafsigares": "hafsig",
    "hafsigas": "hafsig",
    "hafsigast": "hafsig",
    "hafsigaste": "hafsig",
    "hafsigastes": "hafsig",
    "hafsigasts": "hafsig",
    "hafsige": "hafsig",
    "hafsiges": "hafsig",
    "hafsigheten": "hafsighet",
    "hafsighetens": "hafsighet",
    "hafsighets": "hafsighet",
    "hafsigs": "hafsig",
    "hafsigt": "hafsig",
    "hafsigts": "hafsig",
    "hafsverken": "hafsverk",
    "hafsverkens": "hafsverk",
    "hafsverket": "hafsverk",
    "hafsverkets": "hafsverk",
    "hafsverks": "hafsverk",
    "haft": "ha",
    "hafts": "ha",
    "hag": "hage",
    "hagalenheten": "hagalenhet",
    "hagalenhetens": "hagalenhet",
    "hagalenhets": "hagalenhet",
    "hagalens": "hagalen",
    "hagalet": "hagalen",
    "hagalets": "hagalen",
    "hagalna": "hagalen",
    "hagalnare": "hagalen",
    "hagalnares": "hagalen",
    "hagalnas": "hagalen",
    "hagalnast": "hagalen",
    "hagalnaste": "hagalen",
    "hagalnastes": "hagalen",
    "hagalnasts": "hagalen",
    "hagalne": "hagalen",
    "hagalnes": "hagalen",
    "hagar": "hage",
    "hagarna": "hage",
    "hagarnas": "hage",
    "hagars": "hage",
    "hagel": "hagla",
    "hagelböss": "hagelbössa",
    "hagelbössan": "hagelbössa",
    "hagelbössans": "hagelbössa",
    "hagelbössas": "hagelbössa",
    "hagelbösse": "hagelbössa",
    "hagelbösseskotten": "hagelbösseskott",
    "hagelbösseskottens": "hagelbösseskott",
    "hagelbösseskottet": "hagelbösseskott",
    "hagelbösseskottets": "hagelbösseskott",
    "hagelbösseskotts": "hagelbösseskott",
    "hagelbössor": "hagelbössa",
    "hagelbössorna": "hagelbössa",
    "hagelbössornas": "hagelbössa",
    "hagelbössors": "hagelbössa",
    "hagelgevären": "hagelgevär",
    "hagelgevärens": "hagelgevär",
    "hagelgeväret": "hagelgevär",
    "hagelgevärets": "hagelgevär",
    "hagelgevärs": "hagelgevär",
    "hagelkornen": "hagelkorn",
    "hagelkornens": "hagelkorn",
    "hagelkornet": "hagelkorn",
    "hagelkornets": "hagelkorn",
    "hagelkorns": "hagelkorn",
    "hagels": "hagel",
    "hagen": "hage",
    "hagens": "hage",
    "hages": "hage",
    "hagg": "hagga",
    "haggan": "hagga",
    "haggans": "hagga",
    "haggas": "hagga",
    "hagge": "hagga",
    "haggor": "hagga",
    "haggorna": "hagga",
    "haggornas": "hagga",
    "haggors": "hagga",
    "haggs": "hagga",
    "haglade": "hagla",
    "haglades": "hagla",
    "haglande": "hagla",
    "haglanden": "haglande",
    "haglandena": "haglande",
    "haglandenas": "haglande",
    "haglandens": "haglande",
    "haglandes": "haglande",
    "haglandet": "haglande",
    "haglandets": "haglande",
    "haglar": "hagla",
    "haglas": "hagla",
    "haglat": "hagla",
    "haglats": "hagla",
    "haglen": "hagel",
    "haglens": "hagel",
    "haglet": "hagel",
    "haglets": "hagel",
    "hagmarken": "hagmark",
    "hagmarkens": "hagmark",
    "hagmarker": "hagmark",
    "hagmarkerna": "hagmark",
    "hagmarkernas": "hagmark",
    "hagmarkers": "hagmark",
    "hagmarks": "hagmark",
    "hags": "hage",
    "hagtornar": "hagtorn",
    "hagtornarna": "hagtorn",
    "hagtornarnas": "hagtorn",
    "hagtornars": "hagtorn",
    "hagtornen": "hagtorn",
    "hagtornens": "hagtorn",
    "hagtorns": "hagtorn",
    "haikuer": "haiku",
    "haikuerna": "haiku",
    "haikuernas": "haiku",
    "haikuers": "haiku",
    "haikun": "haiku",
    "haikuns": "haiku",
    "haikus": "haiku",
    "haitiern": "haitier",
    "haitierna": "haitier",
    "haitiernas": "haitier",
    "haitierns": "haitier",
    "haitiers": "haitier",
    "haitisk": "haitiska",
    "haitiska": "haitisk",
    "haitiskan": "haitiska",
    "haitiskans": "haitiska",
    "haitiskare": "haitisk",
    "haitiskares": "haitisk",
    "haitiskas": "haitiska",
    "haitiskast": "haitisk",
    "haitiskaste": "haitisk",
    "haitiskastes": "haitisk",
    "haitiskasts": "haitisk",
    "haitiske": "haitiska",
    "haitiskes": "haitisk",
    "haitiskor": "haitiska",
    "haitiskorna": "haitiska",
    "haitiskornas": "haitiska",
    "haitiskors": "haitiska",
    "haitisks": "haitisk",
    "haitiskt": "haitisk",
    "haitiskts": "haitisk",
    "haj": "haja",
    "hajad": "haja",
    "hajade": "haja",
    "hajades": "haja",
    "hajads": "haja",
    "hajande": "haja",
    "hajanden": "hajande",
    "hajandena": "hajande",
    "hajandenas": "hajande",
    "hajandens": "hajande",
    "hajandes": "hajande",
    "hajandet": "hajande",
    "hajandets": "hajande",
    "hajar": "haja",
    "hajarna": "haj",
    "hajarnas": "haj",
    "hajars": "haj",
    "hajas": "haja",
    "hajat": "haja",
    "hajats": "haja",
    "hajen": "haj",
    "hajens": "haj",
    "hajfen": "hajfena",
    "hajfenan": "hajfena",
    "hajfenans": "hajfena",
    "hajfenas": "hajfena",
    "hajfene": "hajfena",
    "hajfenor": "hajfena",
    "hajfenorna": "hajfena",
    "hajfenornas": "hajfena",
    "hajfenors": "hajfena",
    "hajfens": "hajfena",
    "hajjen": "hajj",
    "hajjens": "hajj",
    "hajjs": "hajj",
    "hajkade": "hajka",
    "hajkades": "hajka",
    "hajkande": "hajka",
    "hajkanden": "hajkande",
    "hajkandena": "hajkande",
    "hajkandenas": "hajkande",
    "hajkandens": "hajkande",
    "hajkandes": "hajkande",
    "hajkandet": "hajkande",
    "hajkandets": "hajkande",
    "hajkar": "hajka",
    "hajkarna": "hajk",
    "hajkarnas": "hajk",
    "hajkars": "hajk",
    "hajkas": "hajka",
    "hajkat": "hajka",
    "hajkats": "hajka",
    "hajken": "hajk",
    "hajkens": "hajk",
    "hajks": "hajk",
    "hajkännar": "hajkännare",
    "hajkännaren": "hajkännare",
    "hajkännarens": "hajkännare",
    "hajkännares": "hajkännare",
    "hajkännarna": "hajkännare",
    "hajkännarnas": "hajkännare",
    "hajmalar": "hajmal",
    "hajmalarna": "hajmal",
    "hajmalarnas": "hajmal",
    "hajmalars": "hajmal",
    "hajmalen": "hajmal",
    "hajmalens": "hajmal",
    "hajmals": "hajmal",
    "hajs": "haj",
    "hak": "hake",
    "hakad": "haka",
    "hakade": "haka",
    "hakades": "haka",
    "hakads": "haka",
    "hakan": "haka",
    "hakande": "haka",
    "hakanden": "hakande",
    "hakandena": "hakande",
    "hakandenas": "hakande",
    "hakandens": "hakande",
    "hakandes": "hakande",
    "hakandet": "hakande",
    "hakandets": "hakande",
    "hakans": "haka",
    "hakar": "hake",
    "hakarna": "hake",
    "hakarnas": "hake",
    "hakars": "hake",
    "hakas": "haka",
    "hakat": "haka",
    "hakats": "haka",
    "hake": "haka",
    "hakeböss": "hakebössa",
    "hakebössan": "hakebössa",
    "hakebössans": "hakebössa",
    "hakebössas": "hakebössa",
    "hakebösse": "hakebössa",
    "hakebössor": "hakebössa",
    "hakebössorna": "hakebössa",
    "hakebössornas": "hakebössa",
    "hakebössors": "hakebössa",
    "haken": "hake",
    "hakens": "hake",
    "hakes": "hake",
    "haket": "hak",
    "hakets": "hak",
    "hakkorsen": "hakkors",
    "hakkorsens": "hakkors",
    "hakkorset": "hakkors",
    "hakkorsets": "hakkors",
    "hakkorsflagg": "hakkorsflagga",
    "hakkorsflaggan": "hakkorsflagga",
    "hakkorsflaggans": "hakkorsflagga",
    "hakkorsflaggas": "hakkorsflagga",
    "hakkorsflagge": "hakkorsflagga",
    "hakkorsflaggor": "hakkorsflagga",
    "hakkorsflaggorna": "hakkorsflagga",
    "hakkorsflaggornas": "hakkorsflagga",
    "hakkorsflaggors": "hakkorsflagga",
    "hakkorsflaggs": "hakkorsflagga",
    "haklappar": "haklapp",
    "haklapparna": "haklapp",
    "haklapparnas": "haklapp",
    "haklappars": "haklapp",
    "haklappen": "haklapp",
    "haklappens": "haklapp",
    "haklapps": "haklapp",
    "hakningar": "hakning",
    "hakningarna": "hakning",
    "hakningarnas": "hakning",
    "hakningars": "hakning",
    "hakningen": "hakning",
    "hakningens": "hakning",
    "haknings": "hakning",
    "hakor": "haka",
    "hakorna": "haka",
    "hakornas": "haka",
    "hakors": "haka",
    "hakparentesen": "hakparentes",
    "hakparentesens": "hakparentes",
    "hakparenteser": "hakparentes",
    "hakparenteserna": "hakparentes",
    "hakparentesernas": "hakparentes",
    "hakparentesers": "hakparentes",
    "haks": "hake",
    "hakspetsar": "hakspets",
    "hakspetsarna": "hakspets",
    "hakspetsarnas": "hakspets",
    "hakspetsars": "hakspets",
    "hakspetsen": "hakspets",
    "hakspetsens": "hakspets",
    "hal": "hala",
    "hala": "hal",
    "halad": "hala",
    "halade": "hala",
    "halades": "hala",
    "halads": "hala",
    "halande": "hala",
    "halanden": "halande",
    "halandena": "halande",
    "halandenas": "halande",
    "halandens": "halande",
    "halandes": "halande",
    "halandet": "halande",
    "halandets": "halande",
    "halar": "hala",
    "halare": "hal",
    "halares": "hal",
    "halas": "hala",
    "halast": "hal",
    "halaste": "hal",
    "halastes": "hal",
    "halasts": "hal",
    "halat": "hala",
    "halats": "hala",
    "hale": "hal",
    "hales": "hal",
    "halgatten": "halgatt",
    "halgattens": "halgatt",
    "halgattet": "halgatt",
    "halgattets": "halgatt",
    "halgatts": "halgatt",
    "halheten": "halhet",
    "halhetens": "halhet",
    "halhets": "halhet",
    "halk": "halka",
    "halkade": "halka",
    "halkades": "halka",
    "halkan": "halka",
    "halkande": "halka",
    "halkanden": "halkande",
    "halkandena": "halkande",
    "halkandenas": "halkande",
    "halkandens": "halkande",
    "halkandes": "halkande",
    "halkandet": "halkande",
    "halkandets": "halkande",
    "halkans": "halka",
    "halkar": "halka",
    "halkas": "halka",
    "halkat": "halka",
    "halkats": "halka",
    "halkbanan": "halkbana",
    "halkbanans": "halkbana",
    "halkbanas": "halkbana",
    "halkbane": "halkbana",
    "halkbanor": "halkbana",
    "halkbanorna": "halkbana",
    "halkbanornas": "halkbana",
    "halkbanors": "halkbana",
    "halkfria": "halkfri",
    "halkfriare": "halkfri",
    "halkfriares": "halkfri",
    "halkfrias": "halkfri",
    "halkfriast": "halkfri",
    "halkfriaste": "halkfri",
    "halkfriastes": "halkfri",
    "halkfriasts": "halkfri",
    "halkfrie": "halkfri",
    "halkfries": "halkfri",
    "halkfris": "halkfri",
    "halkfritt": "halkfri",
    "halkfritts": "halkfri",
    "halkiga": "halkig",
    "halkigare": "halkig",
    "halkigares": "halkig",
    "halkigas": "halkig",
    "halkigast": "halkig",
    "halkigaste": "halkig",
    "halkigastes": "halkig",
    "halkigasts": "halkig",
    "halkige": "halkig",
    "halkiges": "halkig",
    "halkigheten": "halkighet",
    "halkighetens": "halkighet",
    "halkighets": "halkighet",
    "halkigs": "halkig",
    "halkigt": "halkig",
    "halkigts": "halkig",
    "halkkrockar": "halkkrock",
    "halkkrockarna": "halkkrock",
    "halkkrockarnas": "halkkrock",
    "halkkrockars": "halkkrock",
    "halkkrocken": "halkkrock",
    "halkkrockens": "halkkrock",
    "halkkrocks": "halkkrock",
    "halkkörningar": "halkkörning",
    "halkkörningarna": "halkkörning",
    "halkkörningarnas": "halkkörning",
    "halkkörningars": "halkkörning",
    "halkkörningen": "halkkörning",
    "halkkörningens": "halkkörning",
    "halkkörnings": "halkkörning",
    "halkrisken": "halkrisk",
    "halkriskens": "halkrisk",
    "halkrisker": "halkrisk",
    "halkriskerna": "halkrisk",
    "halkriskernas": "halkrisk",
    "halkriskers": "halkrisk",
    "halkrisks": "halkrisk",
    "halkskydden": "halkskydd",
    "halkskyddens": "halkskydd",
    "halkskyddet": "halkskydd",
    "halkskyddets": "halkskydd",
    "halkskydds": "halkskydd",
    "halkskyddstejpen": "halkskyddstejp",
    "halkskyddstejpens": "halkskyddstejp",
    "halkskyddstejps": "halkskyddstejp",
    "halkvarningar": "halkvarning",
    "halkvarningarna": "halkvarning",
    "halkvarningarnas": "halkvarning",
    "halkvarningars": "halkvarning",
    "halkvarningen": "halkvarning",
    "halkvarningens": "halkvarning",
    "halkvarnings": "halkvarning",
    "hallar": "hall",
    "hallarna": "hall",
    "hallarnas": "hall",
    "hallars": "hall",
    "hallelujamöten": "hallelujamöte",
    "hallelujamötena": "hallelujamöte",
    "hallelujamötenas": "hallelujamöte",
    "hallelujamötens": "hallelujamöte",
    "hallelujamötes": "hallelujamöte",
    "hallelujamötet": "hallelujamöte",
    "hallelujamötets": "hallelujamöte",
    "hallen": "hall",
    "hallens": "hall",
    "hallgolven": "hallgolv",
    "hallgolvens": "hallgolv",
    "hallgolvet": "hallgolv",
    "hallgolvets": "hallgolv",
    "hallgolvs": "hallgolv",
    "hallickar": "hallick",
    "hallickarna": "hallick",
    "hallickarnas": "hallick",
    "hallickars": "hallick",
    "hallicken": "hallick",
    "hallickens": "hallick",
    "hallicks": "hallick",
    "hallingar": "halling",
    "hallingarna": "halling",
    "hallingarnas": "halling",
    "hallingars": "halling",
    "hallingen": "halling",
    "hallingens": "halling",
    "hallings": "halling",
    "hallkyrk": "hallkyrka",
    "hallkyrkan": "hallkyrka",
    "hallkyrkans": "hallkyrka",
    "hallkyrkas": "hallkyrka",
    "hallkyrke": "hallkyrka",
    "hallkyrko": "hallkyrka",
    "hallkyrkor": "hallkyrka",
    "hallkyrkorna": "hallkyrka",
    "hallkyrkornas": "hallkyrka",
    "hallkyrkors": "hallkyrka",
    "hallkyrks": "hallkyrka",
    "hallmatt": "hallmatta",
    "hallmattan": "hallmatta",
    "hallmattans": "hallmatta",
    "hallmattas": "hallmatta",
    "hallmatte": "hallmatta",
    "hallmattor": "hallmatta",
    "hallmattorna": "hallmatta",
    "hallmattornas": "hallmatta",
    "hallmattors": "hallmatta",
    "hallmatts": "hallmatta",
    "hallonbusk": "hallonbuske",
    "hallonbuskar": "hallonbuske",
    "hallonbuskarna": "hallonbuske",
    "hallonbuskarnas": "hallonbuske",
    "hallonbuskars": "hallonbuske",
    "hallonbusken": "hallonbuske",
    "hallonbuskens": "hallonbuske",
    "hallonbuskes": "hallonbuske",
    "hallonen": "hallon",
    "hallonens": "hallon",
    "hallonet": "hallon",
    "hallonets": "hallon",
    "hallongrottan": "hallongrotta",
    "hallongrottans": "hallongrotta",
    "hallongrottas": "hallongrotta",
    "hallongrotte": "hallongrotta",
    "hallongrottor": "hallongrotta",
    "hallongrottorna": "hallongrotta",
    "hallongrottornas": "hallongrotta",
    "hallongrottors": "hallongrotta",
    "hallonmaskar": "hallonmask",
    "hallonmaskarna": "hallonmask",
    "hallonmaskarnas": "hallonmask",
    "hallonmaskars": "hallonmask",
    "hallonmasken": "hallonmask",
    "hallonmaskens": "hallonmask",
    "hallonmasks": "hallonmask",
    "hallons": "hallon",
    "hallonsaften": "hallonsaft",
    "hallonsaftens": "hallonsaft",
    "hallonsafter": "hallonsaft",
    "hallonsafterna": "hallonsaft",
    "hallonsafternas": "hallonsaft",
    "hallonsafters": "hallonsaft",
    "hallonsafts": "hallonsaft",
    "hallonsylten": "hallonsylt",
    "hallonsyltens": "hallonsylt",
    "hallonsylts": "hallonsylt",
    "hallrätten": "hallrätt",
    "hallrättens": "hallrätt",
    "hallrätts": "hallrätt",
    "halls": "hall",
    "hallspegeln": "hallspegel",
    "hallspegelns": "hallspegel",
    "hallspegels": "hallspegel",
    "hallspeglar": "hallspegel",
    "hallspeglarna": "hallspegel",
    "hallspeglarnas": "hallspegel",
    "hallspeglars": "hallspegel",
    "hallstämpeln": "hallstämpel",
    "hallstämpelns": "hallstämpel",
    "hallstämpels": "hallstämpel",
    "hallstämplad": "hallstämpla",
    "hallstämplade": "hallstämpla",
    "hallstämplades": "hallstämpla",
    "hallstämplads": "hallstämpla",
    "hallstämplande": "hallstämpla",
    "hallstämplanden": "hallstämplande",
    "hallstämplandena": "hallstämplande",
    "hallstämplandenas": "hallstämplande",
    "hallstämplandens": "hallstämplande",
    "hallstämplandes": "hallstämplande",
    "hallstämplandet": "hallstämplande",
    "hallstämplandets": "hallstämplande",
    "hallstämplar": "hallstämpla",
    "hallstämplarna": "hallstämpel",
    "hallstämplarnas": "hallstämpel",
    "hallstämplars": "hallstämpel",
    "hallstämplas": "hallstämpla",
    "hallstämplat": "hallstämpla",
    "hallstämplats": "hallstämpla",
    "halltelefonen": "halltelefon",
    "halltelefonens": "halltelefon",
    "halltelefoner": "halltelefon",
    "halltelefonerna": "halltelefon",
    "halltelefonernas": "halltelefon",
    "halltelefoners": "halltelefon",
    "halltelefons": "halltelefon",
    "hallucinationen": "hallucination",
    "hallucinationens": "hallucination",
    "hallucinationer": "hallucination",
    "hallucinationerna": "hallucination",
    "hallucinationernas": "hallucination",
    "hallucinationers": "hallucination",
    "hallucinations": "hallucination",
    "hallucinatoriska": "hallucinatorisk",
    "hallucinatoriskare": "hallucinatorisk",
    "hallucinatoriskares": "hallucinatorisk",
    "hallucinatoriskas": "hallucinatorisk",
    "hallucinatoriskast": "hallucinatorisk",
    "hallucinatoriskaste": "hallucinatorisk",
    "hallucinatoriskastes": "hallucinatorisk",
    "hallucinatoriskasts": "hallucinatorisk",
    "hallucinatoriske": "hallucinatorisk",
    "hallucinatoriskes": "hallucinatorisk",
    "hallucinatorisks": "hallucinatorisk",
    "hallucinatoriskt": "hallucinatorisk",
    "hallucinatoriskts": "hallucinatorisk",
    "hallucinerad": "hallucinera",
    "hallucinerade": "hallucinera",
    "hallucinerades": "hallucinera",
    "hallucinerads": "hallucinera",
    "hallucinerande": "hallucinera",
    "hallucineranden": "hallucinerande",
    "hallucinerandena": "hallucinerande",
    "hallucinerandenas": "hallucinerande",
    "hallucinerandens": "hallucinerande",
    "hallucinerandes": "hallucinerande",
    "hallucinerandet": "hallucinerande",
    "hallucinerandets": "hallucinerande",
    "hallucinerar": "hallucinera",
    "hallucineras": "hallucinera",
    "hallucinerat": "hallucinera",
    "hallucinerats": "hallucinera",
    "hallucinerbara": "hallucinerbar",
    "hallucinerbarare": "hallucinerbar",
    "hallucinerbarares": "hallucinerbar",
    "hallucinerbaras": "hallucinerbar",
    "hallucinerbarast": "hallucinerbar",
    "hallucinerbaraste": "hallucinerbar",
    "hallucinerbarastes": "hallucinerbar",
    "hallucinerbarasts": "hallucinerbar",
    "hallucinerbare": "hallucinerbar",
    "hallucinerbares": "hallucinerbar",
    "hallucinerbarheten": "hallucinerbarhet",
    "hallucinerbarhetens": "hallucinerbarhet",
    "hallucinerbarhets": "hallucinerbarhet",
    "hallucinerbars": "hallucinerbar",
    "hallucinerbart": "hallucinerbar",
    "hallucinerbarts": "hallucinerbar",
    "hallucineringar": "hallucinering",
    "hallucineringarna": "hallucinering",
    "hallucineringarnas": "hallucinering",
    "hallucineringars": "hallucinering",
    "hallucineringen": "hallucinering",
    "hallucineringens": "hallucinering",
    "hallucinerings": "hallucinering",
    "hallucinogena": "hallucinogen",
    "hallucinogenare": "hallucinogen",
    "hallucinogenares": "hallucinogen",
    "hallucinogenas": "hallucinogen",
    "hallucinogenast": "hallucinogen",
    "hallucinogenaste": "hallucinogen",
    "hallucinogenastes": "hallucinogen",
    "hallucinogenasts": "hallucinogen",
    "hallucinogene": "hallucinogen",
    "hallucinogenen": "hallucinogen",
    "hallucinogenens": "hallucinogen",
    "hallucinogener": "hallucinogen",
    "hallucinogenerna": "hallucinogen",
    "hallucinogenernas": "hallucinogen",
    "hallucinogeners": "hallucinogen",
    "hallucinogenes": "hallucinogen",
    "hallucinogens": "hallucinogen",
    "hallucinogent": "hallucinogen",
    "hallucinogents": "hallucinogen",
    "halländsk": "halländska",
    "halländska": "halländsk",
    "halländskan": "halländska",
    "halländskans": "halländska",
    "halländskare": "halländsk",
    "halländskares": "halländsk",
    "halländskas": "halländska",
    "halländskast": "halländsk",
    "halländskaste": "halländsk",
    "halländskastes": "halländsk",
    "halländskasts": "halländsk",
    "halländske": "halländska",
    "halländskes": "halländsk",
    "halländskor": "halländska",
    "halländskorna": "halländska",
    "halländskornas": "halländska",
    "halländskors": "halländska",
    "halländsks": "halländsk",
    "halländskt": "halländsk",
    "halländskts": "halländsk",
    "hallänningar": "hallänning",
    "hallänningarna": "hallänning",
    "hallänningarnas": "hallänning",
    "hallänningars": "hallänning",
    "hallänningen": "hallänning",
    "hallänningens": "hallänning",
    "hallännings": "hallänning",
    "hallå": "hallåa",
    "hallåade": "hallåa",
    "hallåades": "hallåa",
    "hallåan": "hallåa",
    "hallåande": "hallåa",
    "hallåanden": "hallåande",
    "hallåandena": "hallåande",
    "hallåandenas": "hallåande",
    "hallåandens": "hallåande",
    "hallåandes": "hallåande",
    "hallåandet": "hallåande",
    "hallåandets": "hallåande",
    "hallåans": "hallåa",
    "hallåar": "hallåa",
    "hallåas": "hallåa",
    "hallåat": "hallåa",
    "hallåats": "hallåa",
    "hallåe": "hallåa",
    "hallået": "hallå",
    "hallåets": "hallå",
    "hallåmannen": "hallåman",
    "hallåmannens": "hallåman",
    "hallåmans": "hallåman",
    "hallåmän": "hallåman",
    "hallåmännen": "hallåman",
    "hallåmännens": "hallåman",
    "hallåmäns": "hallåman",
    "hallåor": "hallåa",
    "hallåorna": "hallåa",
    "hallåornas": "hallåa",
    "hallåors": "hallåa",
    "hallås": "hallåa",
    "hallåt": "hallå",
    "hallåts": "hallå",
    "halmas": "halma",
    "halmen": "halm",
    "halmens": "halm",
    "halmhattar": "halmhatt",
    "halmhattarna": "halmhatt",
    "halmhattarnas": "halmhatt",
    "halmhattars": "halmhatt",
    "halmhatten": "halmhatt",
    "halmhattens": "halmhatt",
    "halmhatts": "halmhatt",
    "halmhjärt": "halmhjärta",
    "halmhjärtan": "halmhjärta",
    "halmhjärtana": "halmhjärta",
    "halmhjärtanas": "halmhjärta",
    "halmhjärtans": "halmhjärta",
    "halmhjärtas": "halmhjärta",
    "halmhjärtat": "halmhjärta",
    "halmhjärtats": "halmhjärta",
    "halmhjärts": "halmhjärta",
    "halmmadrassen": "halmmadrass",
    "halmmadrassens": "halmmadrass",
    "halmmadrasser": "halmmadrass",
    "halmmadrasserna": "halmmadrass",
    "halmmadrassernas": "halmmadrass",
    "halmmadrassers": "halmmadrass",
    "halmplatt": "halmplatta",
    "halmplattan": "halmplatta",
    "halmplattans": "halmplatta",
    "halmplattas": "halmplatta",
    "halmplatte": "halmplatta",
    "halmplattor": "halmplatta",
    "halmplattorna": "halmplatta",
    "halmplattornas": "halmplatta",
    "halmplattors": "halmplatta",
    "halmplatts": "halmplatta",
    "halms": "halm",
    "halmskakar": "halmskakare",
    "halmskakaren": "halmskakare",
    "halmskakarens": "halmskakare",
    "halmskakares": "halmskakare",
    "halmskakarna": "halmskakare",
    "halmskakarnas": "halmskakare",
    "halmstackar": "halmstack",
    "halmstackarna": "halmstack",
    "halmstackarnas": "halmstack",
    "halmstackars": "halmstack",
    "halmstacken": "halmstack",
    "halmstackens": "halmstack",
    "halmstacks": "halmstack",
    "halmstoppade": "halmstoppad",
    "halmstoppades": "halmstoppad",
    "halmstoppads": "halmstoppad",
    "halmstoppat": "halmstoppad",
    "halmstoppats": "halmstoppad",
    "halmstrået": "halmstrå",
    "halmstråets": "halmstrå",
    "halmstrån": "halmstrå",
    "halmstråna": "halmstrå",
    "halmstrånas": "halmstrå",
    "halmstråns": "halmstrå",
    "halmstrås": "halmstrå",
    "halmstråt": "halmstrå",
    "halmstråts": "halmstrå",
    "halmtaken": "halmtak",
    "halmtakens": "halmtak",
    "halmtaket": "halmtak",
    "halmtakets": "halmtak",
    "halmtaks": "halmtak",
    "haloeffekten": "haloeffekt",
    "haloeffektens": "haloeffekt",
    "haloeffekter": "haloeffekt",
    "haloeffekterna": "haloeffekt",
    "haloeffekternas": "haloeffekt",
    "haloeffekters": "haloeffekt",
    "haloeffekts": "haloeffekt",
    "haloer": "halo",
    "haloerna": "halo",
    "haloernas": "halo",
    "haloers": "halo",
    "halofenomenen": "halofenomen",
    "halofenomenens": "halofenomen",
    "halofenomenet": "halofenomen",
    "halofenomenets": "halofenomen",
    "halofenomens": "halofenomen",
    "halogenen": "halogen",
    "halogenens": "halogen",
    "halogener": "halogen",
    "halogenerna": "halogen",
    "halogenernas": "halogen",
    "halogeners": "halogen",
    "halogenlamp": "halogenlampa",
    "halogenlampan": "halogenlampa",
    "halogenlampans": "halogenlampa",
    "halogenlampas": "halogenlampa",
    "halogenlampe": "halogenlampa",
    "halogenlampor": "halogenlampa",
    "halogenlamporna": "halogenlampa",
    "halogenlampornas": "halogenlampa",
    "halogenlampors": "halogenlampa",
    "halogenlamps": "halogenlampa",
    "halogens": "halogen",
    "halogenstrålkastar": "halogenstrålkastare",
    "halogenstrålkastaren": "halogenstrålkastare",
    "halogenstrålkastarens": "halogenstrålkastare",
    "halogenstrålkastares": "halogenstrålkastare",
    "halogenstrålkastarna": "halogenstrålkastare",
    "halogenstrålkastarnas": "halogenstrålkastare",
    "halogenstrålkastarseten": "halogenstrålkastarset",
    "halogenstrålkastarsetens": "halogenstrålkastarset",
    "halogenstrålkastarsetet": "halogenstrålkastarset",
    "halogenstrålkastarsetets": "halogenstrålkastarset",
    "halogenstrålkastarsets": "halogenstrålkastarset",
    "halon": "halo",
    "halons": "halo",
    "halor": "halo",
    "halorna": "halo",
    "halornas": "halo",
    "halors": "halo",
    "halos": "halo",
    "hals": "halsa",
    "halsad": "halsa",
    "halsade": "halsa",
    "halsades": "halsa",
    "halsads": "halsa",
    "halsande": "halsa",
    "halsanden": "halsande",
    "halsandena": "halsande",
    "halsandenas": "halsande",
    "halsandens": "halsande",
    "halsandes": "halsande",
    "halsandet": "halsande",
    "halsandets": "halsande",
    "halsar": "halsa",
    "halsarna": "hals",
    "halsarnas": "hals",
    "halsars": "hals",
    "halsas": "halsa",
    "halsat": "halsa",
    "halsats": "halsa",
    "halsbanden": "halsband",
    "halsbandens": "halsband",
    "halsbandet": "halsband",
    "halsbandets": "halsband",
    "halsbands": "halsband",
    "halsblossen": "halsbloss",
    "halsblossens": "halsbloss",
    "halsblosset": "halsbloss",
    "halsblossets": "halsbloss",
    "halsbrännan": "halsbränna",
    "halsbrännans": "halsbränna",
    "halsbrännas": "halsbränna",
    "halsbölden": "halsböld",
    "halsböldens": "halsböld",
    "halsbölder": "halsböld",
    "halsbölderna": "halsböld",
    "halsböldernas": "halsböld",
    "halsbölders": "halsböld",
    "halsbölds": "halsböld",
    "halsdukar": "halsduk",
    "halsdukarna": "halsduk",
    "halsdukarnas": "halsduk",
    "halsdukars": "halsduk",
    "halsduken": "halsduk",
    "halsdukens": "halsduk",
    "halsduks": "halsduk",
    "halsen": "hals",
    "halsens": "hals",
    "halsflussen": "halsfluss",
    "halsflussens": "halsfluss",
    "halsflusser": "halsfluss",
    "halsflusserna": "halsfluss",
    "halsflussernas": "halsfluss",
    "halsflussers": "halsfluss",
    "halsgropar": "halsgrop",
    "halsgroparna": "halsgrop",
    "halsgroparnas": "halsgrop",
    "halsgropars": "halsgrop",
    "halsgropen": "halsgrop",
    "halsgropens": "halsgrop",
    "halsgrops": "halsgrop",
    "halshugg": "halshugga",
    "halshuggande": "halshugga",
    "halshugganden": "halshuggande",
    "halshuggandena": "halshuggande",
    "halshuggandenas": "halshuggande",
    "halshuggandens": "halshuggande",
    "halshuggandes": "halshuggande",
    "halshuggandet": "halshuggande",
    "halshuggandets": "halshuggande",
    "halshuggas": "halshugga",
    "halshugge": "halshugga",
    "halshuggen": "halshugga",
    "halshuggens": "halshugga",
    "halshugger": "halshugga",
    "halshugges": "halshugga",
    "halshugget": "halshugga",
    "halshuggets": "halshugga",
    "halshuggit": "halshugga",
    "halshuggits": "halshugga",
    "halshuggna": "halshugga",
    "halshuggnas": "halshugga",
    "halshuggne": "halshugga",
    "halshuggnes": "halshugga",
    "halshuggs": "halshugga",
    "halshögg": "halshugga",
    "halshögge": "halshugga",
    "halshögges": "halshugga",
    "halshöggs": "halshugga",
    "halskatarren": "halskatarr",
    "halskatarrens": "halskatarr",
    "halskatarrer": "halskatarr",
    "halskatarrerna": "halskatarr",
    "halskatarrernas": "halskatarr",
    "halskatarrers": "halskatarr",
    "halskatarrs": "halskatarr",
    "halskot": "halskota",
    "halskotan": "halskota",
    "halskotans": "halskota",
    "halskotas": "halskota",
    "halskote": "halskota",
    "halskotor": "halskota",
    "halskotorna": "halskota",
    "halskotornas": "halskota",
    "halskotors": "halskota",
    "halskots": "halskota",
    "halskråsen": "halskrås",
    "halskråsens": "halskrås",
    "halskråset": "halskrås",
    "halskråsets": "halskrås",
    "halsmandeln": "halsmandel",
    "halsmandelns": "halsmandel",
    "halsmandels": "halsmandel",
    "halsmandlar": "halsmandel",
    "halsmandlarna": "halsmandel",
    "halsmandlarnas": "halsmandel",
    "halsmandlars": "halsmandel",
    "halsremmar": "halsrem",
    "halsremmarna": "halsrem",
    "halsremmarnas": "halsrem",
    "halsremmars": "halsrem",
    "halsremmen": "halsrem",
    "halsremmens": "halsrem",
    "halsrems": "halsrem",
    "halsringar": "halsring",
    "halsringarna": "halsring",
    "halsringarnas": "halsring",
    "halsringars": "halsring",
    "halsringen": "halsring",
    "halsringens": "halsring",
    "halsrings": "halsring",
    "halssmycken": "halssmycke",
    "halssmyckena": "halssmycke",
    "halssmyckenas": "halssmycke",
    "halssmyckens": "halssmycke",
    "halssmyckes": "halssmycke",
    "halssmycket": "halssmycke",
    "halssmyckets": "halssmycke",
    "halsstarriga": "halsstarrig",
    "halsstarrigare": "halsstarrig",
    "halsstarrigares": "halsstarrig",
    "halsstarrigas": "halsstarrig",
    "halsstarrigast": "halsstarrig",
    "halsstarrigaste": "halsstarrig",
    "halsstarrigastes": "halsstarrig",
    "halsstarrigasts": "halsstarrig",
    "halsstarrige": "halsstarrig",
    "halsstarriges": "halsstarrig",
    "halsstarrigheten": "halsstarrighet",
    "halsstarrighetens": "halsstarrighet",
    "halsstarrighets": "halsstarrighet",
    "halsstarrigs": "halsstarrig",
    "halsstarrigt": "halsstarrig",
    "halsstarrigts": "halsstarrig",
    "halstabletten": "halstablett",
    "halstablettens": "halstablett",
    "halstabletter": "halstablett",
    "halstabletterna": "halstablett",
    "halstabletternas": "halstablett",
    "halstabletters": "halstablett",
    "halstabletts": "halstablett",
    "halster": "halstra",
    "halsterna": "halster",
    "halsternas": "halster",
    "halsters": "halster",
    "halstrad": "halstra",
    "halstrade": "halstra",
    "halstrades": "halstra",
    "halstrads": "halstra",
    "halstrande": "halstra",
    "halstranden": "halstrande",
    "halstrandena": "halstrande",
    "halstrandenas": "halstrande",
    "halstrandens": "halstrande",
    "halstrandes": "halstrande",
    "halstrandet": "halstrande",
    "halstrandets": "halstrande",
    "halstrar": "halstra",
    "halstras": "halstra",
    "halstrat": "halstra",
    "halstrats": "halstra",
    "halstren": "halster",
    "halstrens": "halster",
    "halstret": "halster",
    "halstrets": "halster",
    "halt": "hal",
    "halta": "halt",
    "haltade": "halta",
    "haltades": "halta",
    "haltande": "halta",
    "haltanden": "haltande",
    "haltandena": "haltande",
    "haltandenas": "haltande",
    "haltandens": "haltande",
    "haltandes": "haltande",
    "haltandet": "haltande",
    "haltandets": "haltande",
    "haltar": "halta",
    "haltare": "halt",
    "haltares": "halt",
    "haltas": "halta",
    "haltast": "halt",
    "haltaste": "halt",
    "haltastes": "halt",
    "haltasts": "halt",
    "haltat": "halta",
    "haltats": "halta",
    "halte": "halt",
    "halten": "halt",
    "haltens": "halt",
    "halter": "halt",
    "halterna": "halt",
    "halternas": "halt",
    "halters": "halt",
    "haltes": "halt",
    "haltheten": "halthet",
    "halthetens": "halthet",
    "halthets": "halthet",
    "haltiga": "haltig",
    "haltigare": "haltig",
    "haltigares": "haltig",
    "haltigas": "haltig",
    "haltigast": "haltig",
    "haltigaste": "haltig",
    "haltigastes": "haltig",
    "haltigasts": "haltig",
    "haltige": "haltig",
    "haltiges": "haltig",
    "haltigs": "haltig",
    "haltigt": "haltig",
    "haltigts": "haltig",
    "halts": "halt",
    "halv": "halva",
    "halva": "halv",
    "halvan": "halva",
    "halvankaren": "halvankare",
    "halvankarens": "halvankare",
    "halvankares": "halvankare",
    "halvankaret": "halvankare",
    "halvankarets": "halvankare",
    "halvankarna": "halvankare",
    "halvankarnas": "halvankare",
    "halvannans": "halvannan",
    "halvans": "halva",
    "halvap": "halvapa",
    "halvapan": "halvapa",
    "halvapans": "halvapa",
    "halvapas": "halvapa",
    "halvape": "halvapa",
    "halvapor": "halvapa",
    "halvaporna": "halvapa",
    "halvapornas": "halvapa",
    "halvapors": "halvapa",
    "halvaps": "halvapa",
    "halvare": "halv",
    "halvares": "halv",
    "halvas": "halva",
    "halvast": "halv",
    "halvaste": "halv",
    "halvastes": "halv",
    "halvasts": "halv",
    "halvautomatiska": "halvautomatisk",
    "halvautomatiskare": "halvautomatisk",
    "halvautomatiskares": "halvautomatisk",
    "halvautomatiskas": "halvautomatisk",
    "halvautomatiskast": "halvautomatisk",
    "halvautomatiskaste": "halvautomatisk",
    "halvautomatiskastes": "halvautomatisk",
    "halvautomatiskasts": "halvautomatisk",
    "halvautomatiske": "halvautomatisk",
    "halvautomatiskes": "halvautomatisk",
    "halvautomatisks": "halvautomatisk",
    "halvautomatiskt": "halvautomatisk",
    "halvautomatiskts": "halvautomatisk",
    "halvbackar": "halvback",
    "halvbackarna": "halvback",
    "halvbackarnas": "halvback",
    "halvbackars": "halvback",
    "halvbacken": "halvback",
    "halvbackens": "halvback",
    "halvbacks": "halvback",
    "halvberusade": "halvberusad",
    "halvberusades": "halvberusad",
    "halvberusads": "halvberusad",
    "halvberusat": "halvberusad",
    "halvberusats": "halvberusad",
    "halvbildade": "halvbildad",
    "halvbildades": "halvbildad",
    "halvbildads": "halvbildad",
    "halvbildat": "halvbildad",
    "halvbildats": "halvbildad",
    "halvbilden": "halvbild",
    "halvbildens": "halvbild",
    "halvbilder": "halvbild",
    "halvbilderna": "halvbild",
    "halvbildernas": "halvbild",
    "halvbilders": "halvbild",
    "halvbilds": "halvbild",
    "halvblanka": "halvblank",
    "halvblankas": "halvblank",
    "halvblanke": "halvblank",
    "halvblankes": "halvblank",
    "halvblanks": "halvblank",
    "halvblankt": "halvblank",
    "halvblankts": "halvblank",
    "halvblinda": "halvblind",
    "halvblindare": "halvblind",
    "halvblindares": "halvblind",
    "halvblindas": "halvblind",
    "halvblindast": "halvblind",
    "halvblindaste": "halvblind",
    "halvblindastes": "halvblind",
    "halvblindasts": "halvblind",
    "halvblinde": "halvblind",
    "halvblindes": "halvblind",
    "halvblindheten": "halvblindhet",
    "halvblindhetens": "halvblindhet",
    "halvblindhets": "halvblindhet",
    "halvblinds": "halvblind",
    "halvblint": "halvblind",
    "halvblints": "halvblind",
    "halvbloden": "halvblod",
    "halvblodens": "halvblod",
    "halvblodet": "halvblod",
    "halvblodets": "halvblod",
    "halvblods": "halvblod",
    "halvbrodern": "halvbror",
    "halvbroderns": "halvbror",
    "halvbrorn": "halvbror",
    "halvbrorns": "halvbror",
    "halvbrors": "halvbror",
    "halvbröder": "halvbror",
    "halvbröderna": "halvbror",
    "halvbrödernas": "halvbror",
    "halvbröders": "halvbror",
    "halvbusk": "halvbuske",
    "halvbuskar": "halvbuske",
    "halvbuskarna": "halvbuske",
    "halvbuskarnas": "halvbuske",
    "halvbuskars": "halvbuske",
    "halvbusken": "halvbuske",
    "halvbuskens": "halvbuske",
    "halvbuskes": "halvbuske",
    "halvbuteljen": "halvbutelj",
    "halvbuteljens": "halvbutelj",
    "halvbuteljer": "halvbutelj",
    "halvbuteljerna": "halvbutelj",
    "halvbuteljernas": "halvbutelj",
    "halvbuteljers": "halvbutelj",
    "halvbuteljs": "halvbutelj",
    "halvcirkelformade": "halvcirkelformad",
    "halvcirkelformades": "halvcirkelformad",
    "halvcirkelformads": "halvcirkelformad",
    "halvcirkelformat": "halvcirkelformad",
    "halvcirkelformats": "halvcirkelformad",
    "halvcirkeln": "halvcirkel",
    "halvcirkelns": "halvcirkel",
    "halvcirkels": "halvcirkel",
    "halvcirklar": "halvcirkel",
    "halvcirklarna": "halvcirkel",
    "halvcirklarnas": "halvcirkel",
    "halvcirklars": "halvcirkel",
    "halvdagern": "halvdager",
    "halvdagerns": "halvdager",
    "halvdagers": "halvdager",
    "halvdagliga": "halvdaglig",
    "halvdagligare": "halvdaglig",
    "halvdagligares": "halvdaglig",
    "halvdagligas": "halvdaglig",
    "halvdagligast": "halvdaglig",
    "halvdagligaste": "halvdaglig",
    "halvdagligastes": "halvdaglig",
    "halvdagligasts": "halvdaglig",
    "halvdaglige": "halvdaglig",
    "halvdagliges": "halvdaglig",
    "halvdagligs": "halvdaglig",
    "halvdagligt": "halvdaglig",
    "halvdagligts": "halvdaglig",
    "halvdana": "halvdan",
    "halvdanare": "halvdan",
    "halvdanares": "halvdan",
    "halvdanas": "halvdan",
    "halvdanast": "halvdan",
    "halvdanaste": "halvdan",
    "halvdanastes": "halvdan",
    "halvdanasts": "halvdan",
    "halvdane": "halvdan",
    "halvdanes": "halvdan",
    "halvdans": "halvdan",
    "halvdant": "halvdan",
    "halvdants": "halvdan",
    "halvdunkels": "halvdunkel",
    "halvdunkelt": "halvdunkel",
    "halvdunkelts": "halvdunkel",
    "halvdunkla": "halvdunkel",
    "halvdunklare": "halvdunkel",
    "halvdunklares": "halvdunkel",
    "halvdunklas": "halvdunkel",
    "halvdunklast": "halvdunkel",
    "halvdunklaste": "halvdunkel",
    "halvdunklastes": "halvdunkel",
    "halvdunklasts": "halvdunkel",
    "halvdunkle": "halvdunkel",
    "halvdunkles": "halvdunkel",
    "halvdunklet": "halvdunkel",
    "halvdunklets": "halvdunkel",
    "halvdussinen": "halvdussin",
    "halvdussinens": "halvdussin",
    "halvdussinet": "halvdussin",
    "halvdussinets": "halvdussin",
    "halvdussins": "halvdussin",
    "halvdvalan": "halvdvala",
    "halvdvalans": "halvdvala",
    "halvdvalas": "halvdvala",
    "halvdäckade": "halvdäckad",
    "halvdäckades": "halvdäckad",
    "halvdäckads": "halvdäckad",
    "halvdäckar": "halvdäckare",
    "halvdäckaren": "halvdäckare",
    "halvdäckarens": "halvdäckare",
    "halvdäckares": "halvdäckare",
    "halvdäckarna": "halvdäckare",
    "halvdäckarnas": "halvdäckare",
    "halvdäckat": "halvdäckad",
    "halvdäckats": "halvdäckad",
    "halvdäcken": "halvdäck",
    "halvdäckens": "halvdäck",
    "halvdäcket": "halvdäck",
    "halvdäckets": "halvdäck",
    "halvdäcks": "halvdäck",
    "halvdöda": "halvdöd",
    "halvdödare": "halvdöd",
    "halvdödares": "halvdöd",
    "halvdödas": "halvdöd",
    "halvdödast": "halvdöd",
    "halvdödaste": "halvdöd",
    "halvdödastes": "halvdöd",
    "halvdödasts": "halvdöd",
    "halvdöde": "halvdöd",
    "halvdödes": "halvdöd",
    "halvdödheten": "halvdödhet",
    "halvdödhetens": "halvdödhet",
    "halvdödhets": "halvdödhet",
    "halvdöds": "halvdöd",
    "halvdött": "halvdöd",
    "halvdötts": "halvdöd",
    "halve": "halva",
    "halvenskilda": "halvenskild",
    "halvenskildare": "halvenskild",
    "halvenskildares": "halvenskild",
    "halvenskildas": "halvenskild",
    "halvenskildast": "halvenskild",
    "halvenskildaste": "halvenskild",
    "halvenskildastes": "halvenskild",
    "halvenskildasts": "halvenskild",
    "halvenskilde": "halvenskild",
    "halvenskildes": "halvenskild",
    "halvenskilds": "halvenskild",
    "halvenskilt": "halvenskild",
    "halvenskilts": "halvenskild",
    "halverad": "halvera",
    "halverade": "halvera",
    "halverades": "halvera",
    "halverads": "halvera",
    "halverande": "halvera",
    "halveranden": "halverande",
    "halverandena": "halverande",
    "halverandenas": "halverande",
    "halverandens": "halverande",
    "halverandes": "halverande",
    "halverandet": "halverande",
    "halverandets": "halverande",
    "halverar": "halvera",
    "halveras": "halvera",
    "halverat": "halvera",
    "halverats": "halvera",
    "halverbara": "halverbar",
    "halverbarare": "halverbar",
    "halverbarares": "halverbar",
    "halverbaras": "halverbar",
    "halverbarast": "halverbar",
    "halverbaraste": "halverbar",
    "halverbarastes": "halverbar",
    "halverbarasts": "halverbar",
    "halverbare": "halverbar",
    "halverbares": "halverbar",
    "halverbarheten": "halverbarhet",
    "halverbarhetens": "halverbarhet",
    "halverbarhets": "halverbarhet",
    "halverbars": "halverbar",
    "halverbart": "halverbar",
    "halverbarts": "halverbar",
    "halverigerade": "halverigerad",
    "halverigerades": "halverigerad",
    "halverigerads": "halverigerad",
    "halverigerat": "halverigerad",
    "halverigerats": "halverigerad",
    "halveringar": "halvering",
    "halveringarna": "halvering",
    "halveringarnas": "halvering",
    "halveringars": "halvering",
    "halveringen": "halvering",
    "halveringens": "halvering",
    "halverings": "halvering",
    "halveringstiden": "halveringstid",
    "halveringstidens": "halveringstid",
    "halveringstids": "halveringstid",
    "halves": "halv",
    "halvfabrikaten": "halvfabrikat",
    "halvfabrikatens": "halvfabrikat",
    "halvfabrikatet": "halvfabrikat",
    "halvfabrikatets": "halvfabrikat",
    "halvfabrikats": "halvfabrikat",
    "halvfeta": "halvfet",
    "halvfetare": "halvfet",
    "halvfetares": "halvfet",
    "halvfetas": "halvfet",
    "halvfetast": "halvfet",
    "halvfetaste": "halvfet",
    "halvfetastes": "halvfet",
    "halvfetasts": "halvfet",
    "halvfete": "halvfet",
    "halvfetes": "halvfet",
    "halvfets": "halvfet",
    "halvfett": "halvfet",
    "halvfetts": "halvfet",
    "halvfiguren": "halvfigur",
    "halvfigurens": "halvfigur",
    "halvfigurer": "halvfigur",
    "halvfigurerna": "halvfigur",
    "halvfigurernas": "halvfigur",
    "halvfigurers": "halvfigur",
    "halvfigurs": "halvfigur",
    "halvflask": "halvflaska",
    "halvflaskan": "halvflaska",
    "halvflaskans": "halvflaska",
    "halvflaskas": "halvflaska",
    "halvflaske": "halvflaska",
    "halvflaskor": "halvflaska",
    "halvflaskorna": "halvflaska",
    "halvflaskornas": "halvflaska",
    "halvflaskors": "halvflaska",
    "halvfranska": "halvfransk",
    "halvfranskare": "halvfransk",
    "halvfranskares": "halvfransk",
    "halvfranskas": "halvfransk",
    "halvfranskast": "halvfransk",
    "halvfranskaste": "halvfransk",
    "halvfranskastes": "halvfransk",
    "halvfranskasts": "halvfransk",
    "halvfranske": "halvfransk",
    "halvfranskes": "halvfransk",
    "halvfransks": "halvfransk",
    "halvfranskt": "halvfransk",
    "halvfranskts": "halvfransk",
    "halvfyllda": "halvfylld",
    "halvfylldare": "halvfylld",
    "halvfylldares": "halvfylld",
    "halvfylldas": "halvfylld",
    "halvfylldast": "halvfylld",
    "halvfylldaste": "halvfylld",
    "halvfylldastes": "halvfylld",
    "halvfylldasts": "halvfylld",
    "halvfyllde": "halvfylld",
    "halvfylldes": "halvfylld",
    "halvfyllds": "halvfylld",
    "halvfyllt": "halvfylld",
    "halvfyllts": "halvfylld",
    "halvfärdiga": "halvfärdig",
    "halvfärdigare": "halvfärdig",
    "halvfärdigares": "halvfärdig",
    "halvfärdigas": "halvfärdig",
    "halvfärdigast": "halvfärdig",
    "halvfärdigaste": "halvfärdig",
    "halvfärdigastes": "halvfärdig",
    "halvfärdigasts": "halvfärdig",
    "halvfärdige": "halvfärdig",
    "halvfärdiges": "halvfärdig",
    "halvfärdigheten": "halvfärdighet",
    "halvfärdighetens": "halvfärdighet",
    "halvfärdigheter": "halvfärdighet",
    "halvfärdigheterna": "halvfärdighet",
    "halvfärdigheternas": "halvfärdighet",
    "halvfärdigheters": "halvfärdighet",
    "halvfärdighets": "halvfärdighet",
    "halvfärdigs": "halvfärdig",
    "halvfärdigt": "halvfärdig",
    "halvfärdigts": "halvfärdig",
    "halvgamla": "halvgammal",
    "halvgamlas": "halvgammal",
    "halvgamle": "halvgammal",
    "halvgamles": "halvgammal",
    "halvgammals": "halvgammal",
    "halvgammalt": "halvgammal",
    "halvgammalts": "halvgammal",
    "halvgenomskinliga": "halvgenomskinlig",
    "halvgenomskinligare": "halvgenomskinlig",
    "halvgenomskinligares": "halvgenomskinlig",
    "halvgenomskinligas": "halvgenomskinlig",
    "halvgenomskinligast": "halvgenomskinlig",
    "halvgenomskinligaste": "halvgenomskinlig",
    "halvgenomskinligastes": "halvgenomskinlig",
    "halvgenomskinligasts": "halvgenomskinlig",
    "halvgenomskinlige": "halvgenomskinlig",
    "halvgenomskinliges": "halvgenomskinlig",
    "halvgenomskinligheten": "halvgenomskinlighet",
    "halvgenomskinlighetens": "halvgenomskinlighet",
    "halvgenomskinlighets": "halvgenomskinlighet",
    "halvgenomskinligs": "halvgenomskinlig",
    "halvgenomskinligt": "halvgenomskinlig",
    "halvgenomskinligts": "halvgenomskinlig",
    "halvgräsen": "halvgräs",
    "halvgräsens": "halvgräs",
    "halvgräset": "halvgräs",
    "halvgräsets": "halvgräs",
    "halvgudar": "halvgud",
    "halvgudarna": "halvgud",
    "halvgudarnas": "halvgud",
    "halvgudars": "halvgud",
    "halvguden": "halvgud",
    "halvgudens": "halvgud",
    "halvguds": "halvgud",
    "halvgångenheten": "halvgångenhet",
    "halvgångenhetens": "halvgångenhet",
    "halvgångenhets": "halvgångenhet",
    "halvgångens": "halvgången",
    "halvgånget": "halvgången",
    "halvgångets": "halvgången",
    "halvgångna": "halvgången",
    "halvgångnare": "halvgången",
    "halvgångnares": "halvgången",
    "halvgångnas": "halvgången",
    "halvgångnast": "halvgången",
    "halvgångnaste": "halvgången",
    "halvgångnastes": "halvgången",
    "halvgångnasts": "halvgången",
    "halvgångne": "halvgången",
    "halvgångnes": "halvgången",
    "halvheten": "halvhet",
    "halvhetens": "halvhet",
    "halvheter": "halvhet",
    "halvheterna": "halvhet",
    "halvheternas": "halvhet",
    "halvheters": "halvhet",
    "halvhets": "halvhet",
    "halvhjärtade": "halvhjärtad",
    "halvhjärtades": "halvhjärtad",
    "halvhjärtads": "halvhjärtad",
    "halvhjärtat": "halvhjärtad",
    "halvhjärtats": "halvhjärtad",
    "halvhyvlade": "halvhyvlad",
    "halvhyvlades": "halvhyvlad",
    "halvhyvlads": "halvhyvlad",
    "halvhyvlat": "halvhyvlad",
    "halvhyvlats": "halvhyvlad",
    "halvhöga": "halvhög",
    "halvhögas": "halvhög",
    "halvhöge": "halvhög",
    "halvhöges": "halvhög",
    "halvhögs": "halvhög",
    "halvhögt": "halvhög",
    "halvhögts": "halvhög",
    "halvklara": "halvklar",
    "halvklarare": "halvklar",
    "halvklarares": "halvklar",
    "halvklaras": "halvklar",
    "halvklarast": "halvklar",
    "halvklaraste": "halvklar",
    "halvklarastes": "halvklar",
    "halvklarasts": "halvklar",
    "halvklare": "halvklar",
    "halvklares": "halvklar",
    "halvklars": "halvklar",
    "halvklart": "halvklar",
    "halvklarts": "halvklar",
    "halvklassen": "halvklass",
    "halvklassens": "halvklass",
    "halvklasser": "halvklass",
    "halvklasserna": "halvklass",
    "halvklassernas": "halvklass",
    "halvklassers": "halvklass",
    "halvkloten": "halvklot",
    "halvklotens": "halvklot",
    "halvklotet": "halvklot",
    "halvklotets": "halvklot",
    "halvklots": "halvklot",
    "halvknopar": "halvknop",
    "halvknoparna": "halvknop",
    "halvknoparnas": "halvknop",
    "halvknopars": "halvknop",
    "halvknopen": "halvknop",
    "halvknopens": "halvknop",
    "halvknops": "halvknop",
    "halvkolonnen": "halvkolonn",
    "halvkolonnens": "halvkolonn",
    "halvkolonner": "halvkolonn",
    "halvkolonnerna": "halvkolonn",
    "halvkolonnernas": "halvkolonn",
    "halvkolonners": "halvkolonn",
    "halvkolonns": "halvkolonn",
    "halvkonserven": "halvkonserv",
    "halvkonservens": "halvkonserv",
    "halvkonserver": "halvkonserv",
    "halvkonserverna": "halvkonserv",
    "halvkonservernas": "halvkonserv",
    "halvkonservers": "halvkonserv",
    "halvkonservs": "halvkonserv",
    "halvkvädenheten": "halvkvädenhet",
    "halvkvädenhetens": "halvkvädenhet",
    "halvkvädenhets": "halvkvädenhet",
    "halvkvädens": "halvkväden",
    "halvkvädet": "halvkväden",
    "halvkvädets": "halvkväden",
    "halvkvädna": "halvkväden",
    "halvkvädnare": "halvkväden",
    "halvkvädnares": "halvkväden",
    "halvkvädnas": "halvkväden",
    "halvkvädnast": "halvkväden",
    "halvkvädnaste": "halvkväden",
    "halvkvädnastes": "halvkväden",
    "halvkvädnasts": "halvkväden",
    "halvkvädne": "halvkväden",
    "halvkvädnes": "halvkväden",
    "halvkvävda": "halvkvävd",
    "halvkvävdare": "halvkvävd",
    "halvkvävdares": "halvkvävd",
    "halvkvävdas": "halvkvävd",
    "halvkvävdast": "halvkvävd",
    "halvkvävdaste": "halvkvävd",
    "halvkvävdastes": "halvkvävd",
    "halvkvävdasts": "halvkvävd",
    "halvkvävde": "halvkvävd",
    "halvkvävdes": "halvkvävd",
    "halvkvävds": "halvkvävd",
    "halvkvävt": "halvkvävd",
    "halvkvävts": "halvkvävd",
    "halvledar": "halvledare",
    "halvledardioden": "halvledardiod",
    "halvledardiodens": "halvledardiod",
    "halvledardioder": "halvledardiod",
    "halvledardioderna": "halvledardiod",
    "halvledardiodernas": "halvledardiod",
    "halvledardioders": "halvledardiod",
    "halvledardiods": "halvledardiod",
    "halvledaren": "halvledare",
    "halvledarens": "halvledare",
    "halvledares": "halvledare",
    "halvledarna": "halvledare",
    "halvledarnas": "halvledare",
    "halvlekar": "halvlek",
    "halvlekarna": "halvlek",
    "halvlekarnas": "halvlek",
    "halvlekars": "halvlek",
    "halvleken": "halvlek",
    "halvlekens": "halvlek",
    "halvleks": "halvlek",
    "halvlinnes": "halvlinne",
    "halvlinnet": "halvlinne",
    "halvlinnets": "halvlinne",
    "halvlitern": "halvliter",
    "halvliterna": "halvliter",
    "halvliternas": "halvliter",
    "halvliterns": "halvliter",
    "halvliters": "halvliter",
    "halvlitersbuteljen": "halvlitersbutelj",
    "halvlitersbuteljens": "halvlitersbutelj",
    "halvlitersbuteljer": "halvlitersbutelj",
    "halvlitersbuteljerna": "halvlitersbutelj",
    "halvlitersbuteljernas": "halvlitersbutelj",
    "halvlitersbuteljers": "halvlitersbutelj",
    "halvlitersbuteljs": "halvlitersbutelj",
    "halvljusen": "halvljus",
    "halvljusens": "halvljus",
    "halvljuset": "halvljus",
    "halvljusets": "halvljus",
    "halvmesyren": "halvmesyr",
    "halvmesyrens": "halvmesyr",
    "halvmesyrer": "halvmesyr",
    "halvmesyrerna": "halvmesyr",
    "halvmesyrernas": "halvmesyr",
    "halvmesyrers": "halvmesyr",
    "halvmesyrs": "halvmesyr",
    "halvmetallen": "halvmetall",
    "halvmetallens": "halvmetall",
    "halvmetaller": "halvmetall",
    "halvmetallerna": "halvmetall",
    "halvmetallernas": "halvmetall",
    "halvmetallers": "halvmetall",
    "halvmetalliska": "halvmetallisk",
    "halvmetalliskare": "halvmetallisk",
    "halvmetalliskares": "halvmetallisk",
    "halvmetalliskas": "halvmetallisk",
    "halvmetalliskast": "halvmetallisk",
    "halvmetalliskaste": "halvmetallisk",
    "halvmetalliskastes": "halvmetallisk",
    "halvmetalliskasts": "halvmetallisk",
    "halvmetalliske": "halvmetallisk",
    "halvmetalliskes": "halvmetallisk",
    "halvmetallisks": "halvmetallisk",
    "halvmetalliskt": "halvmetallisk",
    "halvmetalliskts": "halvmetallisk",
    "halvmetalls": "halvmetall",
    "halvmeterbreda": "halvmeterbred",
    "halvmeterbredare": "halvmeterbred",
    "halvmeterbredares": "halvmeterbred",
    "halvmeterbredas": "halvmeterbred",
    "halvmeterbredast": "halvmeterbred",
    "halvmeterbredaste": "halvmeterbred",
    "halvmeterbredastes": "halvmeterbred",
    "halvmeterbredasts": "halvmeterbred",
    "halvmeterbrede": "halvmeterbred",
    "halvmeterbredes": "halvmeterbred",
    "halvmeterbreds": "halvmeterbred",
    "halvmeterbrett": "halvmeterbred",
    "halvmeterbretts": "halvmeterbred",
    "halvmetern": "halvmeter",
    "halvmeterna": "halvmeter",
    "halvmeternas": "halvmeter",
    "halvmeterns": "halvmeter",
    "halvmeters": "halvmeter",
    "halvmetrar": "halvmeter",
    "halvmetrarna": "halvmeter",
    "halvmetrarnas": "halvmeter",
    "halvmetrars": "halvmeter",
    "halvmilen": "halvmil",
    "halvmilens": "halvmil",
    "halvmils": "halvmil",
    "halvmoderna": "halvmodern",
    "halvmodernare": "halvmodern",
    "halvmodernares": "halvmodern",
    "halvmodernas": "halvmodern",
    "halvmodernast": "halvmodern",
    "halvmodernaste": "halvmodern",
    "halvmodernastes": "halvmodern",
    "halvmodernasts": "halvmodern",
    "halvmoderne": "halvmodern",
    "halvmodernes": "halvmodern",
    "halvmoderns": "halvmodern",
    "halvmodernt": "halvmodern",
    "halvmodernts": "halvmodern",
    "halvmån": "halvmåne",
    "halvmånar": "halvmåne",
    "halvmånarna": "halvmåne",
    "halvmånarnas": "halvmåne",
    "halvmånars": "halvmåne",
    "halvmånen": "halvmåne",
    "halvmånens": "halvmåne",
    "halvmånes": "halvmåne",
    "halvmånformade": "halvmånformad",
    "halvmånformades": "halvmånformad",
    "halvmånformads": "halvmånformad",
    "halvmånformat": "halvmånformad",
    "halvmånformats": "halvmånformad",
    "halvmånformiga": "halvmånformig",
    "halvmånformigas": "halvmånformig",
    "halvmånformige": "halvmånformig",
    "halvmånformiges": "halvmånformig",
    "halvmånformigs": "halvmånformig",
    "halvmånformigt": "halvmånformig",
    "halvmånformigts": "halvmånformig",
    "halvmåns": "halvmåne",
    "halvmörka": "halvmörk",
    "halvmörkare": "halvmörk",
    "halvmörkares": "halvmörk",
    "halvmörkas": "halvmörk",
    "halvmörkast": "halvmörk",
    "halvmörkaste": "halvmörk",
    "halvmörkastes": "halvmörk",
    "halvmörkasts": "halvmörk",
    "halvmörke": "halvmörk",
    "halvmörkes": "halvmörk",
    "halvmörks": "halvmörk",
    "halvmörkt": "halvmörk",
    "halvmörkts": "halvmörk",
    "halvnakenheten": "halvnakenhet",
    "halvnakenhetens": "halvnakenhet",
    "halvnakenhets": "halvnakenhet",
    "halvnakens": "halvnaken",
    "halvnaket": "halvnaken",
    "halvnakets": "halvnaken",
    "halvnakna": "halvnaken",
    "halvnaknare": "halvnaken",
    "halvnaknares": "halvnaken",
    "halvnaknas": "halvnaken",
    "halvnaknast": "halvnaken",
    "halvnaknaste": "halvnaken",
    "halvnaknastes": "halvnaken",
    "halvnaknasts": "halvnaken",
    "halvnakne": "halvnaken",
    "halvnaknes": "halvnaken",
    "halvnelsons": "halvnelson",
    "halvnoten": "halvnot",
    "halvnotens": "halvnot",
    "halvnoter": "halvnot",
    "halvnoterna": "halvnot",
    "halvnoternas": "halvnot",
    "halvnoters": "halvnot",
    "halvnots": "halvnot",
    "halvnäck": "halvnäcka",
    "halvnäckade": "halvnäcka",
    "halvnäckades": "halvnäcka",
    "halvnäckande": "halvnäcka",
    "halvnäckandes": "halvnäcka",
    "halvnäckar": "halvnäcka",
    "halvnäckas": "halvnäcka",
    "halvnäckat": "halvnäcka",
    "halvnäckats": "halvnäcka",
    "halvofficiella": "halvofficiell",
    "halvofficiellare": "halvofficiell",
    "halvofficiellares": "halvofficiell",
    "halvofficiellas": "halvofficiell",
    "halvofficiellast": "halvofficiell",
    "halvofficiellaste": "halvofficiell",
    "halvofficiellastes": "halvofficiell",
    "halvofficiellasts": "halvofficiell",
    "halvofficielle": "halvofficiell",
    "halvofficielles": "halvofficiell",
    "halvofficiells": "halvofficiell",
    "halvofficiellt": "halvofficiell",
    "halvofficiellts": "halvofficiell",
    "halvor": "halva",
    "halvorna": "halva",
    "halvornas": "halva",
    "halvors": "halva",
    "halvpann": "halvpanna",
    "halvpannan": "halvpanna",
    "halvpannans": "halvpanna",
    "halvpannas": "halvpanna",
    "halvpanne": "halvpanna",
    "halvpannor": "halvpanna",
    "halvpannorna": "halvpanna",
    "halvpannornas": "halvpanna",
    "halvpannors": "halvpanna",
    "halvpanns": "halvpanna",
    "halvparten": "halvpart",
    "halvpartens": "halvpart",
    "halvparter": "halvpart",
    "halvparterna": "halvpart",
    "halvparternas": "halvpart",
    "halvparters": "halvpart",
    "halvparts": "halvpart",
    "halvpensionen": "halvpension",
    "halvpensionens": "halvpension",
    "halvpensioner": "halvpension",
    "halvpensionerna": "halvpension",
    "halvpensionernas": "halvpension",
    "halvpensioners": "halvpension",
    "halvpensions": "halvpension",
    "halvprofilen": "halvprofil",
    "halvprofilens": "halvprofil",
    "halvprofiler": "halvprofil",
    "halvprofilerna": "halvprofil",
    "halvprofilernas": "halvprofil",
    "halvprofilers": "halvprofil",
    "halvprofils": "halvprofil",
    "halvrimmen": "halvrim",
    "halvrimmens": "halvrim",
    "halvrimmet": "halvrim",
    "halvrimmets": "halvrim",
    "halvrims": "halvrim",
    "halvruttenheten": "halvruttenhet",
    "halvruttenhetens": "halvruttenhet",
    "halvruttenhets": "halvruttenhet",
    "halvruttens": "halvrutten",
    "halvruttet": "halvrutten",
    "halvruttets": "halvrutten",
    "halvruttna": "halvrutten",
    "halvruttnas": "halvrutten",
    "halvruttne": "halvrutten",
    "halvruttnes": "halvrutten",
    "halvs": "halva",
    "halvsanningar": "halvsanning",
    "halvsanningarna": "halvsanning",
    "halvsanningarnas": "halvsanning",
    "halvsanningars": "halvsanning",
    "halvsanningen": "halvsanning",
    "halvsanningens": "halvsanning",
    "halvsannings": "halvsanning",
    "halvsekels": "halvsekel",
    "halvseklen": "halvsekel",
    "halvseklens": "halvsekel",
    "halvsekler": "halvsekel",
    "halvseklerna": "halvsekel",
    "halvseklernas": "halvsekel",
    "halvseklers": "halvsekel",
    "halvseklet": "halvsekel",
    "halvseklets": "halvsekel",
    "halvsidenet": "halvsiden",
    "halvsidenets": "halvsiden",
    "halvsidens": "halvsiden",
    "halvskugg": "halvskugga",
    "halvskuggan": "halvskugga",
    "halvskuggans": "halvskugga",
    "halvskuggas": "halvskugga",
    "halvskugge": "halvskugga",
    "halvskuggor": "halvskugga",
    "halvskuggorna": "halvskugga",
    "halvskuggornas": "halvskugga",
    "halvskuggors": "halvskugga",
    "halvskuggs": "halvskugga",
    "halvskyddade": "halvskyddad",
    "halvskyddades": "halvskyddad",
    "halvskyddads": "halvskyddad",
    "halvskyddat": "halvskyddad",
    "halvskyddats": "halvskyddad",
    "halvslagen": "halvslag",
    "halvslagens": "halvslag",
    "halvslaget": "halvslag",
    "halvslagets": "halvslag",
    "halvslags": "halvslag",
    "halvslummern": "halvslummer",
    "halvslummerns": "halvslummer",
    "halvslummers": "halvslummer",
    "halvslutenheten": "halvslutenhet",
    "halvslutenhetens": "halvslutenhet",
    "halvslutenhets": "halvslutenhet",
    "halvslutens": "halvsluten",
    "halvslutet": "halvsluten",
    "halvslutets": "halvsluten",
    "halvslutna": "halvsluten",
    "halvslutnare": "halvsluten",
    "halvslutnares": "halvsluten",
    "halvslutnas": "halvsluten",
    "halvslutnast": "halvsluten",
    "halvslutnaste": "halvsluten",
    "halvslutnastes": "halvsluten",
    "halvslutnasts": "halvsluten",
    "halvslutne": "halvsluten",
    "halvslutnes": "halvsluten",
    "halvsmälta": "halvsmält",
    "halvsmältare": "halvsmält",
    "halvsmältares": "halvsmält",
    "halvsmältas": "halvsmält",
    "halvsmältast": "halvsmält",
    "halvsmältaste": "halvsmält",
    "halvsmältastes": "halvsmält",
    "halvsmältasts": "halvsmält",
    "halvsmälte": "halvsmält",
    "halvsmältes": "halvsmält",
    "halvsmälts": "halvsmält",
    "halvsov": "halvsova",
    "halvsovande": "halvsova",
    "halvsovanden": "halvsovande",
    "halvsovandena": "halvsovande",
    "halvsovandenas": "halvsovande",
    "halvsovandens": "halvsovande",
    "halvsovandes": "halvsovande",
    "halvsovandet": "halvsovande",
    "halvsovandets": "halvsovande",
    "halvsovas": "halvsova",
    "halvsove": "halvsova",
    "halvsover": "halvsova",
    "halvsoves": "halvsova",
    "halvsovit": "halvsova",
    "halvsovits": "halvsova",
    "halvsovs": "halvsova",
    "halvspråkiga": "halvspråkig",
    "halvspråkigare": "halvspråkig",
    "halvspråkigares": "halvspråkig",
    "halvspråkigas": "halvspråkig",
    "halvspråkigast": "halvspråkig",
    "halvspråkigaste": "halvspråkig",
    "halvspråkigastes": "halvspråkig",
    "halvspråkigasts": "halvspråkig",
    "halvspråkige": "halvspråkig",
    "halvspråkiges": "halvspråkig",
    "halvspråkigheten": "halvspråkighet",
    "halvspråkighetens": "halvspråkighet",
    "halvspråkighets": "halvspråkighet",
    "halvspråkigs": "halvspråkig",
    "halvspråkigt": "halvspråkig",
    "halvspråkigts": "halvspråkig",
    "halvstatliga": "halvstatlig",
    "halvstatligare": "halvstatlig",
    "halvstatligares": "halvstatlig",
    "halvstatligas": "halvstatlig",
    "halvstatligast": "halvstatlig",
    "halvstatligaste": "halvstatlig",
    "halvstatligastes": "halvstatlig",
    "halvstatligasts": "halvstatlig",
    "halvstatlige": "halvstatlig",
    "halvstatliges": "halvstatlig",
    "halvstatligheten": "halvstatlighet",
    "halvstatlighetens": "halvstatlighet",
    "halvstatlighets": "halvstatlighet",
    "halvstatligs": "halvstatlig",
    "halvstatligt": "halvstatlig",
    "halvstatligts": "halvstatlig",
    "halvstopen": "halvstop",
    "halvstopens": "halvstop",
    "halvstopet": "halvstop",
    "halvstopets": "halvstop",
    "halvstops": "halvstop",
    "halvsul": "halvsula",
    "halvsulad": "halvsula",
    "halvsulade": "halvsula",
    "halvsulades": "halvsula",
    "halvsulads": "halvsula",
    "halvsulande": "halvsula",
    "halvsulanden": "halvsulande",
    "halvsulandena": "halvsulande",
    "halvsulandenas": "halvsulande",
    "halvsulandens": "halvsulande",
    "halvsulandes": "halvsulande",
    "halvsulandet": "halvsulande",
    "halvsulandets": "halvsulande",
    "halvsular": "halvsula",
    "halvsulas": "halvsula",
    "halvsulat": "halvsula",
    "halvsulats": "halvsula",
    "halvsura": "halvsur",
    "halvsurare": "halvsur",
    "halvsurares": "halvsur",
    "halvsuras": "halvsur",
    "halvsurast": "halvsur",
    "halvsuraste": "halvsur",
    "halvsurastes": "halvsur",
    "halvsurasts": "halvsur",
    "halvsure": "halvsur",
    "halvsures": "halvsur",
    "halvsurs": "halvsur",
    "halvsurt": "halvsur",
    "halvsurts": "halvsur",
    "halvsvenska": "halvsvensk",
    "halvsvenskare": "halvsvensk",
    "halvsvenskares": "halvsvensk",
    "halvsvenskas": "halvsvensk",
    "halvsvenskast": "halvsvensk",
    "halvsvenskaste": "halvsvensk",
    "halvsvenskastes": "halvsvensk",
    "halvsvenskasts": "halvsvensk",
    "halvsvenske": "halvsvensk",
    "halvsvenskes": "halvsvensk",
    "halvsvensks": "halvsvensk",
    "halvsvenskt": "halvsvensk",
    "halvsvenskts": "halvsvensk",
    "halvsyskonen": "halvsyskon",
    "halvsyskonens": "halvsyskon",
    "halvsyskonet": "halvsyskon",
    "halvsyskonets": "halvsyskon",
    "halvsyskons": "halvsyskon",
    "halvsystern": "halvsyster",
    "halvsysterns": "halvsyster",
    "halvsysters": "halvsyster",
    "halvsystrar": "halvsyster",
    "halvsystrarna": "halvsyster",
    "halvsystrarnas": "halvsyster",
    "halvsystrars": "halvsyster",
    "halvsömnen": "halvsömn",
    "halvsömnens": "halvsömn",
    "halvsömns": "halvsömn",
    "halvt": "halv",
    "halvtannat": "halvannan",
    "halvtannats": "halvannan",
    "halvtiden": "halvtid",
    "halvtidens": "halvtid",
    "halvtider": "halvtid",
    "halvtiderna": "halvtid",
    "halvtidernas": "halvtid",
    "halvtiders": "halvtid",
    "halvtids": "halvtid",
    "halvtim": "halvtimme",
    "halvtimman": "halvtimma",
    "halvtimmans": "halvtimma",
    "halvtimmar": "halvtimme",
    "halvtimmarna": "halvtimme",
    "halvtimmarnas": "halvtimme",
    "halvtimmars": "halvtimme",
    "halvtimmas": "halvtimma",
    "halvtimmen": "halvtimme",
    "halvtimmens": "halvtimme",
    "halvtimmes": "halvtimme",
    "halvtims": "halvtimme",
    "halvtonen": "halvton",
    "halvtonens": "halvton",
    "halvtoner": "halvton",
    "halvtonerna": "halvton",
    "halvtonernas": "halvton",
    "halvtoners": "halvton",
    "halvtons": "halvton",
    "halvtorra": "halvtorr",
    "halvtorrare": "halvtorr",
    "halvtorrares": "halvtorr",
    "halvtorras": "halvtorr",
    "halvtorrast": "halvtorr",
    "halvtorraste": "halvtorr",
    "halvtorrastes": "halvtorr",
    "halvtorrasts": "halvtorr",
    "halvtorre": "halvtorr",
    "halvtorres": "halvtorr",
    "halvtorrs": "halvtorr",
    "halvtorrt": "halvtorr",
    "halvtorrts": "halvtorr",
    "halvtrapp": "halvtrappa",
    "halvtrappan": "halvtrappa",
    "halvtrappans": "halvtrappa",
    "halvtrappas": "halvtrappa",
    "halvtrappe": "halvtrappa",
    "halvtrappor": "halvtrappa",
    "halvtrapporna": "halvtrappa",
    "halvtrappornas": "halvtrappa",
    "halvtrappors": "halvtrappa",
    "halvtrapps": "halvtrappa",
    "halvts": "halv",
    "halvtummen": "halvtum",
    "halvtummens": "halvtum",
    "halvtums": "halvtum",
    "halvvokalen": "halvvokal",
    "halvvokalens": "halvvokal",
    "halvvokaler": "halvvokal",
    "halvvokalerna": "halvvokal",
    "halvvokalernas": "halvvokal",
    "halvvokalers": "halvvokal",
    "halvvokals": "halvvokal",
    "halvvolleyn": "halvvolley",
    "halvvolleyns": "halvvolley",
    "halvvolleys": "halvvolley",
    "halvvuxenheten": "halvvuxenhet",
    "halvvuxenhetens": "halvvuxenhet",
    "halvvuxenhets": "halvvuxenhet",
    "halvvuxens": "halvvuxen",
    "halvvuxet": "halvvuxen",
    "halvvuxets": "halvvuxen",
    "halvvuxna": "halvvuxen",
    "halvvuxnare": "halvvuxen",
    "halvvuxnares": "halvvuxen",
    "halvvuxnas": "halvvuxen",
    "halvvuxnast": "halvvuxen",
    "halvvuxnaste": "halvvuxen",
    "halvvuxnastes": "halvvuxen",
    "halvvuxnasts": "halvvuxen",
    "halvvuxne": "halvvuxen",
    "halvvuxnes": "halvvuxen",
    "halvvärldar": "halvvärld",
    "halvvärldarna": "halvvärld",
    "halvvärldarnas": "halvvärld",
    "halvvärldars": "halvvärld",
    "halvvärlden": "halvvärld",
    "halvvärldens": "halvvärld",
    "halvvärlds": "halvvärld",
    "halvylles": "halvylle",
    "halvyllet": "halvylle",
    "halvyllets": "halvylle",
    "halvädelstenar": "halvädelsten",
    "halvädelstenarna": "halvädelsten",
    "halvädelstenarnas": "halvädelsten",
    "halvädelstenars": "halvädelsten",
    "halvädelstenen": "halvädelsten",
    "halvädelstenens": "halvädelsten",
    "halvädelstens": "halvädelsten",
    "halvåren": "halvår",
    "halvårens": "halvår",
    "halvåret": "halvår",
    "halvårets": "halvår",
    "halvårs": "halvår",
    "halvårsskiften": "halvårsskifte",
    "halvårsskiftena": "halvårsskifte",
    "halvårsskiftenas": "halvårsskifte",
    "halvårsskiftens": "halvårsskifte",
    "halvårsskiftes": "halvårsskifte",
    "halvårsskiftet": "halvårsskifte",
    "halvårsskiftets": "halvårsskifte",
    "halvöar": "halvö",
    "halvöarna": "halvö",
    "halvöarnas": "halvö",
    "halvöars": "halvö",
    "halvön": "halvö",
    "halvöns": "halvö",
    "halvöppenheten": "halvöppenhet",
    "halvöppenhetens": "halvöppenhet",
    "halvöppenhets": "halvöppenhet",
    "halvöppens": "halvöppen",
    "halvöppet": "halvöppen",
    "halvöppets": "halvöppen",
    "halvöppna": "halvöppen",
    "halvöppnare": "halvöppen",
    "halvöppnares": "halvöppen",
    "halvöppnas": "halvöppen",
    "halvöppnast": "halvöppen",
    "halvöppnaste": "halvöppen",
    "halvöppnastes": "halvöppen",
    "halvöppnasts": "halvöppen",
    "halvöppne": "halvöppen",
    "halvöppnes": "halvöppen",
    "halvös": "halvö",
    "hamboer": "hambo",
    "hamboerna": "hambo",
    "hamboernas": "hambo",
    "hamboers": "hambo",
    "hambon": "hambo",
    "hambons": "hambo",
    "hambor": "hambo",
    "hamborna": "hambo",
    "hambornas": "hambo",
    "hambors": "hambo",
    "hambos": "hambo",
    "hamburgar": "hamburgare",
    "hamburgarbaren": "hamburgarbar",
    "hamburgarbarens": "hamburgarbar",
    "hamburgarbarer": "hamburgarbar",
    "hamburgarbarerna": "hamburgarbar",
    "hamburgarbarernas": "hamburgarbar",
    "hamburgarbarers": "hamburgarbar",
    "hamburgarbars": "hamburgarbar",
    "hamburgaren": "hamburgare",
    "hamburgarens": "hamburgare",
    "hamburgares": "hamburgare",
    "hamburgarna": "hamburgare",
    "hamburgarnas": "hamburgare",
    "hamburgarrestaurangen": "hamburgarrestaurang",
    "hamburgarrestaurangens": "hamburgarrestaurang",
    "hamburgarrestauranger": "hamburgarrestaurang",
    "hamburgarrestaurangerna": "hamburgarrestaurang",
    "hamburgarrestaurangernas": "hamburgarrestaurang",
    "hamburgarrestaurangers": "hamburgarrestaurang",
    "hamburgarrestaurangs": "hamburgarrestaurang",
    "hamburgarställen": "hamburgarställe",
    "hamburgarställena": "hamburgarställe",
    "hamburgarställenas": "hamburgarställe",
    "hamburgarställens": "hamburgarställe",
    "hamburgarställes": "hamburgarställe",
    "hamburgarstället": "hamburgarställe",
    "hamburgarställets": "hamburgarställe",
    "hamburgerbaren": "hamburgerbar",
    "hamburgerbarens": "hamburgerbar",
    "hamburgerbarer": "hamburgerbar",
    "hamburgerbarerna": "hamburgerbar",
    "hamburgerbarernas": "hamburgerbar",
    "hamburgerbarers": "hamburgerbar",
    "hamburgerbars": "hamburgerbar",
    "hamburgerköttet": "hamburgerkött",
    "hamburgerköttets": "hamburgerkött",
    "hamburgerkötts": "hamburgerkött",
    "hamburgerrestaurangen": "hamburgerrestaurang",
    "hamburgerrestaurangens": "hamburgerrestaurang",
    "hamburgerrestauranger": "hamburgerrestaurang",
    "hamburgerrestaurangerna": "hamburgerrestaurang",
    "hamburgerrestaurangernas": "hamburgerrestaurang",
    "hamburgerrestaurangers": "hamburgerrestaurang",
    "hamburgerrestaurangs": "hamburgerrestaurang",
    "hamburgerställen": "hamburgerställe",
    "hamburgerställena": "hamburgerställe",
    "hamburgerställenas": "hamburgerställe",
    "hamburgerställens": "hamburgerställe",
    "hamburgerställes": "hamburgerställe",
    "hamburgerstället": "hamburgerställe",
    "hamburgerställets": "hamburgerställe",
    "hamiten": "hamit",
    "hamitens": "hamit",
    "hamiter": "hamit",
    "hamiterna": "hamit",
    "hamiternas": "hamit",
    "hamiters": "hamit",
    "hamitiska": "hamitisk",
    "hamitiskare": "hamitisk",
    "hamitiskares": "hamitisk",
    "hamitiskas": "hamitisk",
    "hamitiskast": "hamitisk",
    "hamitiskaste": "hamitisk",
    "hamitiskastes": "hamitisk",
    "hamitiskasts": "hamitisk",
    "hamitiske": "hamitisk",
    "hamitiskes": "hamitisk",
    "hamitisks": "hamitisk",
    "hamitiskt": "hamitisk",
    "hamitiskts": "hamitisk",
    "hamits": "hamit",
    "hamlad": "hamla",
    "hamlade": "hamla",
    "hamlades": "hamla",
    "hamlads": "hamla",
    "hamlande": "hamla",
    "hamlanden": "hamlande",
    "hamlandena": "hamlande",
    "hamlandenas": "hamlande",
    "hamlandens": "hamlande",
    "hamlandes": "hamlande",
    "hamlandet": "hamlande",
    "hamlandets": "hamlande",
    "hamlar": "hammel",
    "hamlarna": "hammel",
    "hamlarnas": "hammel",
    "hamlars": "hammel",
    "hamlas": "hamla",
    "hamlat": "hamla",
    "hamlats": "hamla",
    "hammar": "hammare",
    "hammarattacken": "hammarattack",
    "hammarattackens": "hammarattack",
    "hammarattacker": "hammarattack",
    "hammarattackerna": "hammarattack",
    "hammarattackernas": "hammarattack",
    "hammarattackers": "hammarattack",
    "hammarattacks": "hammarattack",
    "hammarbanden": "hammarband",
    "hammarbandens": "hammarband",
    "hammarbandet": "hammarband",
    "hammarbandets": "hammarband",
    "hammarbands": "hammarband",
    "hammaren": "hammare",
    "hammarens": "hammare",
    "hammares": "hammare",
    "hammarhajar": "hammarhaj",
    "hammarhajarna": "hammarhaj",
    "hammarhajarnas": "hammarhaj",
    "hammarhajars": "hammarhaj",
    "hammarhajen": "hammarhaj",
    "hammarhajens": "hammarhaj",
    "hammarhajs": "hammarhaj",
    "hammarslagen": "hammarslag",
    "hammarslagens": "hammarslag",
    "hammarslaget": "hammarslag",
    "hammarslagets": "hammarslag",
    "hammarslags": "hammarslag",
    "hammel": "hamla",
    "hammeln": "hammel",
    "hammelns": "hammel",
    "hammels": "hammel",
    "hammelsadeln": "hammelsadel",
    "hammelsadelns": "hammelsadel",
    "hammelsadels": "hammelsadel",
    "hammelsadlar": "hammelsadel",
    "hammelsadlarna": "hammelsadel",
    "hammelsadlarnas": "hammelsadel",
    "hammelsadlars": "hammelsadel",
    "hammerlessen": "hammerless",
    "hammerlessens": "hammerless",
    "hammlar": "hammel",
    "hammlarna": "hammel",
    "hammlarnas": "hammel",
    "hammlars": "hammel",
    "hammockar": "hammock",
    "hammockarna": "hammock",
    "hammockarnas": "hammock",
    "hammockars": "hammock",
    "hammocken": "hammock",
    "hammockens": "hammock",
    "hammockgångjärnen": "hammockgångjärn",
    "hammockgångjärnens": "hammockgångjärn",
    "hammockgångjärnet": "hammockgångjärn",
    "hammockgångjärnets": "hammockgångjärn",
    "hammockgångjärns": "hammockgångjärn",
    "hammocks": "hammock",
    "hammondorgeln": "hammondorgel",
    "hammondorgelns": "hammondorgel",
    "hammondorgels": "hammondorgel",
    "hammondorglar": "hammondorgel",
    "hammondorglarna": "hammondorgel",
    "hammondorglarnas": "hammondorgel",
    "hammondorglars": "hammondorgel",
    "hamn": "hamna",
    "hamnad": "hamna",
    "hamnade": "hamna",
    "hamnades": "hamna",
    "hamnads": "hamna",
    "hamnande": "hamna",
    "hamnanden": "hamnande",
    "hamnandena": "hamnande",
    "hamnandenas": "hamnande",
    "hamnandens": "hamnande",
    "hamnandes": "hamnande",
    "hamnandet": "hamnande",
    "hamnandets": "hamnande",
    "hamnar": "hamna",
    "hamnarbetar": "hamnarbetare",
    "hamnarbetaren": "hamnarbetare",
    "hamnarbetarens": "hamnarbetare",
    "hamnarbetares": "hamnarbetare",
    "hamnarbetarna": "hamnarbetare",
    "hamnarbetarnas": "hamnarbetare",
    "hamnarbetarstrejken": "hamnarbetarstrejk",
    "hamnarbetarstrejkens": "hamnarbetarstrejk",
    "hamnarbetarstrejker": "hamnarbetarstrejk",
    "hamnarbetarstrejkerna": "hamnarbetarstrejk",
    "hamnarbetarstrejkernas": "hamnarbetarstrejk",
    "hamnarbetarstrejkers": "hamnarbetarstrejk",
    "hamnarbetarstrejks": "hamnarbetarstrejk",
    "hamnarna": "hamn",
    "hamnarnas": "hamn",
    "hamnars": "hamn",
    "hamnas": "hamna",
    "hamnat": "hamna",
    "hamnats": "hamna",
    "hamnbassängen": "hamnbassäng",
    "hamnbassängens": "hamnbassäng",
    "hamnbassänger": "hamnbassäng",
    "hamnbassängerna": "hamnbassäng",
    "hamnbassängernas": "hamnbassäng",
    "hamnbassängers": "hamnbassäng",
    "hamnbassängs": "hamnbassäng",
    "hamndirektionen": "hamndirektion",
    "hamndirektionens": "hamndirektion",
    "hamndirektioner": "hamndirektion",
    "hamndirektionerna": "hamndirektion",
    "hamndirektionernas": "hamndirektion",
    "hamndirektioners": "hamndirektion",
    "hamndirektions": "hamndirektion",
    "hamnen": "hamn",
    "hamnens": "hamn",
    "hamnförhållanden": "hamnförhållande",
    "hamnförhållandena": "hamnförhållande",
    "hamnförhållandenas": "hamnförhållande",
    "hamnförhållandens": "hamnförhållande",
    "hamnförhållandes": "hamnförhållande",
    "hamnförhållandet": "hamnförhållande",
    "hamnförhållandets": "hamnförhållande",
    "hamnkaptenen": "hamnkapten",
    "hamnkaptenens": "hamnkapten",
    "hamnkaptener": "hamnkapten",
    "hamnkaptenerna": "hamnkapten",
    "hamnkaptenernas": "hamnkapten",
    "hamnkapteners": "hamnkapten",
    "hamnkaptens": "hamnkapten",
    "hamnkontoren": "hamnkontor",
    "hamnkontorens": "hamnkontor",
    "hamnkontoret": "hamnkontor",
    "hamnkontorets": "hamnkontor",
    "hamnkontors": "hamnkontor",
    "hamnkvarteren": "hamnkvarter",
    "hamnkvarterens": "hamnkvarter",
    "hamnkvarteret": "hamnkvarter",
    "hamnkvarterets": "hamnkvarter",
    "hamnkvarters": "hamnkvarter",
    "hamns": "hamn",
    "hamnstaden": "hamnstad",
    "hamnstadens": "hamnstad",
    "hamnstads": "hamnstad",
    "hamnstan": "hamnstad",
    "hamnstans": "hamnstad",
    "hamnstyrelsen": "hamnstyrelse",
    "hamnstyrelsens": "hamnstyrelse",
    "hamnstyrelser": "hamnstyrelse",
    "hamnstyrelserna": "hamnstyrelse",
    "hamnstyrelsernas": "hamnstyrelse",
    "hamnstyrelsers": "hamnstyrelse",
    "hamnstyrelses": "hamnstyrelse",
    "hamnstäder": "hamnstad",
    "hamnstäderna": "hamnstad",
    "hamnstädernas": "hamnstad",
    "hamnstäders": "hamnstad",
    "hampan": "hampa",
    "hampans": "hampa",
    "hampas": "hampa",
    "hampdånen": "hampdån",
    "hampdånens": "hampdån",
    "hampdåns": "hampdån",
    "hampfröen": "hampfrö",
    "hampfröens": "hampfrö",
    "hampfröet": "hampfrö",
    "hampfröets": "hampfrö",
    "hampfrön": "hampfrö",
    "hampfröna": "hampfrö",
    "hampfrönas": "hampfrö",
    "hampfröns": "hampfrö",
    "hampfrös": "hampfrö",
    "hampfröt": "hampfrö",
    "hampfröts": "hampfrö",
    "hamrad": "hamra",
    "hamrade": "hamra",
    "hamrades": "hamra",
    "hamrads": "hamra",
    "hamrande": "hamra",
    "hamranden": "hamrande",
    "hamrandena": "hamrande",
    "hamrandenas": "hamrande",
    "hamrandens": "hamrande",
    "hamrandes": "hamrande",
    "hamrandet": "hamrande",
    "hamrandets": "hamrande",
    "hamrar": "hamra",
    "hamrarna": "hammare",
    "hamrarnas": "hammare",
    "hamrars": "hammare",
    "hamras": "hamra",
    "hamrat": "hamra",
    "hamrats": "hamra",
    "hamster": "hamstra",
    "hamstern": "hamster",
    "hamsterns": "hamster",
    "hamsters": "hamster",
    "hamstrad": "hamstra",
    "hamstrade": "hamstra",
    "hamstrades": "hamstra",
    "hamstrads": "hamstra",
    "hamstrande": "hamstra",
    "hamstranden": "hamstrande",
    "hamstrandena": "hamstrande",
    "hamstrandenas": "hamstrande",
    "hamstrandens": "hamstrande",
    "hamstrandes": "hamstrande",
    "hamstrandet": "hamstrande",
    "hamstrandets": "hamstrande",
    "hamstrar": "hamstra",
    "hamstrarna": "hamster",
    "hamstrarnas": "hamster",
    "hamstrars": "hamster",
    "hamstras": "hamstra",
    "hamstrat": "hamstra",
    "hamstrats": "hamstra",
    "han": "hane",
    "hanar": "hane",
    "hanarna": "hane",
    "hanarnas": "hane",
    "hanars": "hane",
    "hanbjälk": "hanbjälke",
    "hanbjälkar": "hanbjälke",
    "hanbjälkarna": "hanbjälke",
    "hanbjälkarnas": "hanbjälke",
    "hanbjälkars": "hanbjälke",
    "hanbjälken": "hanbjälke",
    "hanbjälkens": "hanbjälke",
    "hanbjälkes": "hanbjälke",
    "hanbjälks": "hanbjälke",
    "hanblom": "hanblomma",
    "hanblomman": "hanblomma",
    "hanblommans": "hanblomma",
    "hanblommas": "hanblomma",
    "hanblomme": "hanblomma",
    "hanblommor": "hanblomma",
    "hanblommorna": "hanblomma",
    "hanblommornas": "hanblomma",
    "hanblommors": "hanblomma",
    "hanbloms": "hanblomma",
    "handalfabeten": "handalfabet",
    "handalfabetens": "handalfabet",
    "handalfabetet": "handalfabet",
    "handalfabetets": "handalfabet",
    "handalfabets": "handalfabet",
    "handarbet": "handarbeta",
    "handarbetad": "handarbeta",
    "handarbetade": "handarbeta",
    "handarbetades": "handarbeta",
    "handarbetads": "handarbeta",
    "handarbetande": "handarbeta",
    "handarbetanden": "handarbetande",
    "handarbetandena": "handarbetande",
    "handarbetandenas": "handarbetande",
    "handarbetandens": "handarbetande",
    "handarbetandes": "handarbetande",
    "handarbetandet": "handarbetande",
    "handarbetandets": "handarbetande",
    "handarbetar": "handarbeta",
    "handarbetas": "handarbeta",
    "handarbetat": "handarbeta",
    "handarbetats": "handarbeta",
    "handarbeten": "handarbete",
    "handarbetena": "handarbete",
    "handarbetenas": "handarbete",
    "handarbetens": "handarbete",
    "handarbetes": "handarbete",
    "handarbetet": "handarbete",
    "handarbetets": "handarbete",
    "handarbets": "handarbete",
    "handavtrycken": "handavtryck",
    "handavtryckens": "handavtryck",
    "handavtrycket": "handavtryck",
    "handavtryckets": "handavtryck",
    "handavtrycks": "handavtryck",
    "handbagagen": "handbagage",
    "handbagagens": "handbagage",
    "handbagages": "handbagage",
    "handbagaget": "handbagage",
    "handbagagets": "handbagage",
    "handboj": "handboja",
    "handbojan": "handboja",
    "handbojans": "handboja",
    "handbojas": "handboja",
    "handboje": "handboja",
    "handbojor": "handboja",
    "handbojorna": "handboja",
    "handbojornas": "handboja",
    "handbojors": "handboja",
    "handbojs": "handboja",
    "handboken": "handbok",
    "handbokens": "handbok",
    "handboks": "handbok",
    "handboksmässiga": "handboksmässig",
    "handboksmässigare": "handboksmässig",
    "handboksmässigares": "handboksmässig",
    "handboksmässigas": "handboksmässig",
    "handboksmässigast": "handboksmässig",
    "handboksmässigaste": "handboksmässig",
    "handboksmässigastes": "handboksmässig",
    "handboksmässigasts": "handboksmässig",
    "handboksmässige": "handboksmässig",
    "handboksmässiges": "handboksmässig",
    "handboksmässigs": "handboksmässig",
    "handboksmässigt": "handboksmässig",
    "handboksmässigts": "handboksmässig",
    "handbollar": "handboll",
    "handbollarna": "handboll",
    "handbollarnas": "handboll",
    "handbollars": "handboll",
    "handbollen": "handboll",
    "handbollens": "handboll",
    "handbolls": "handboll",
    "handbollsmatchen": "handbollsmatch",
    "handbollsmatchens": "handbollsmatch",
    "handbollsmatcher": "handbollsmatch",
    "handbollsmatcherna": "handbollsmatch",
    "handbollsmatchernas": "handbollsmatch",
    "handbollsmatchers": "handbollsmatch",
    "handbollsmatchs": "handbollsmatch",
    "handbollsmässiga": "handbollsmässig",
    "handbollsmässigare": "handbollsmässig",
    "handbollsmässigares": "handbollsmässig",
    "handbollsmässigas": "handbollsmässig",
    "handbollsmässigast": "handbollsmässig",
    "handbollsmässigaste": "handbollsmässig",
    "handbollsmässigastes": "handbollsmässig",
    "handbollsmässigasts": "handbollsmässig",
    "handbollsmässige": "handbollsmässig",
    "handbollsmässiges": "handbollsmässig",
    "handbollsmässigs": "handbollsmässig",
    "handbollsmässigt": "handbollsmässig",
    "handbollsmässigts": "handbollsmässig",
    "handbreven": "handbrev",
    "handbrevens": "handbrev",
    "handbrevet": "handbrev",
    "handbrevets": "handbrev",
    "handbrevs": "handbrev",
    "handbromsar": "handbroms",
    "handbromsarna": "handbroms",
    "handbromsarnas": "handbroms",
    "handbromsars": "handbroms",
    "handbromsen": "handbroms",
    "handbromsens": "handbroms",
    "handböcker": "handbok",
    "handböckerna": "handbok",
    "handböckernas": "handbok",
    "handböckers": "handbok",
    "handdatorer": "handdator",
    "handdatorerna": "handdator",
    "handdatorernas": "handdator",
    "handdatorers": "handdator",
    "handdatorn": "handdator",
    "handdatorns": "handdator",
    "handdators": "handdator",
    "handdukar": "handduk",
    "handdukarna": "handduk",
    "handdukarnas": "handduk",
    "handdukars": "handduk",
    "handduken": "handduk",
    "handdukens": "handduk",
    "handduks": "handduk",
    "handdukstorkar": "handdukstork",
    "handdukstorkarna": "handdukstork",
    "handdukstorkarnas": "handdukstork",
    "handdukstorkars": "handdukstork",
    "handdukstorken": "handdukstork",
    "handdukstorkens": "handdukstork",
    "handdukstorks": "handdukstork",
    "hande": "ha",
    "handeksemen": "handeksem",
    "handeksemens": "handeksem",
    "handeksemet": "handeksem",
    "handeksemets": "handeksem",
    "handeksems": "handeksem",
    "handeldvapens": "handeldvapen",
    "handeldvapnen": "handeldvapen",
    "handeldvapnens": "handeldvapen",
    "handeldvapnet": "handeldvapen",
    "handeldvapnets": "handeldvapen",
    "handeln": "handel",
    "handelns": "handel",
    "handels": "handel",
    "handelsavtalen": "handelsavtal",
    "handelsavtalens": "handelsavtal",
    "handelsavtalet": "handelsavtal",
    "handelsavtalets": "handelsavtal",
    "handelsavtals": "handelsavtal",
    "handelsbalansen": "handelsbalans",
    "handelsbalansens": "handelsbalans",
    "handelsbanken": "handelsbank",
    "handelsbankens": "handelsbank",
    "handelsbanker": "handelsbank",
    "handelsbankerna": "handelsbank",
    "handelsbankernas": "handelsbank",
    "handelsbankers": "handelsbank",
    "handelsbanks": "handelsbank",
    "handelsbodar": "handelsbod",
    "handelsbodarna": "handelsbod",
    "handelsbodarnas": "handelsbod",
    "handelsbodars": "handelsbod",
    "handelsboden": "handelsbod",
    "handelsbodens": "handelsbod",
    "handelsbods": "handelsbod",
    "handelsbolagen": "handelsbolag",
    "handelsbolagens": "handelsbolag",
    "handelsbolaget": "handelsbolag",
    "handelsbolagets": "handelsbolag",
    "handelsbolags": "handelsbolag",
    "handelsdepartementen": "handelsdepartement",
    "handelsdepartementens": "handelsdepartement",
    "handelsdepartementet": "handelsdepartement",
    "handelsdepartementets": "handelsdepartement",
    "handelsdepartements": "handelsdepartement",
    "handelsfartygen": "handelsfartyg",
    "handelsfartygens": "handelsfartyg",
    "handelsfartyget": "handelsfartyg",
    "handelsfartygets": "handelsfartyg",
    "handelsfartygs": "handelsfartyg",
    "handelsflott": "handelsflotta",
    "handelsflottan": "handelsflotta",
    "handelsflottans": "handelsflotta",
    "handelsflottas": "handelsflotta",
    "handelsflotte": "handelsflotta",
    "handelsflottor": "handelsflotta",
    "handelsflottorna": "handelsflotta",
    "handelsflottornas": "handelsflotta",
    "handelsflottors": "handelsflotta",
    "handelsflotts": "handelsflotta",
    "handelsföretagen": "handelsföretag",
    "handelsföretagens": "handelsföretag",
    "handelsföretaget": "handelsföretag",
    "handelsföretagets": "handelsföretag",
    "handelsföretags": "handelsföretag",
    "handelsgymnasie": "handelsgymnasium",
    "handelsgymnasier": "handelsgymnasium",
    "handelsgymnasierna": "handelsgymnasium",
    "handelsgymnasiernas": "handelsgymnasium",
    "handelsgymnasiers": "handelsgymnasium",
    "handelsgymnasiet": "handelsgymnasium",
    "handelsgymnasiets": "handelsgymnasium",
    "handelsgymnasiums": "handelsgymnasium",
    "handelshusen": "handelshus",
    "handelshusens": "handelshus",
    "handelshuset": "handelshus",
    "handelshusets": "handelshus",
    "handelshögskolan": "handelshögskola",
    "handelshögskolans": "handelshögskola",
    "handelshögskolas": "handelshögskola",
    "handelshögskole": "handelshögskola",
    "handelshögskolor": "handelshögskola",
    "handelshögskolorna": "handelshögskola",
    "handelshögskolornas": "handelshögskola",
    "handelshögskolors": "handelshögskola",
    "handelskammar": "handelskammare",
    "handelskammaren": "handelskammare",
    "handelskammarens": "handelskammare",
    "handelskammares": "handelskammare",
    "handelskamrar": "handelskammare",
    "handelskamrarna": "handelskammare",
    "handelskamrarnas": "handelskammare",
    "handelskamrars": "handelskammare",
    "handelskompanier": "handelskompani",
    "handelskompanierna": "handelskompani",
    "handelskompaniernas": "handelskompani",
    "handelskompaniers": "handelskompani",
    "handelskompaniet": "handelskompani",
    "handelskompaniets": "handelskompani",
    "handelskompanis": "handelskompani",
    "handelskompanit": "handelskompani",
    "handelskompanits": "handelskompani",
    "handelsköpen": "handelsköp",
    "handelsköpens": "handelsköp",
    "handelsköpet": "handelsköp",
    "handelsköpets": "handelsköp",
    "handelsköps": "handelsköp",
    "handelsleden": "handelsled",
    "handelsledens": "handelsled",
    "handelsleder": "handelsled",
    "handelslederna": "handelsled",
    "handelsledernas": "handelsled",
    "handelsleders": "handelsled",
    "handelsleds": "handelsled",
    "handelsmannen": "handelsman",
    "handelsmannens": "handelsman",
    "handelsmans": "handelsman",
    "handelsministern": "handelsminister",
    "handelsministerns": "handelsminister",
    "handelsministers": "handelsminister",
    "handelsministrar": "handelsminister",
    "handelsministrarna": "handelsminister",
    "handelsministrarnas": "handelsminister",
    "handelsministrars": "handelsminister",
    "handelsmän": "handelsman",
    "handelsmännen": "handelsman",
    "handelsmännens": "handelsman",
    "handelsmäns": "handelsman",
    "handelsmässiga": "handelsmässig",
    "handelsmässigare": "handelsmässig",
    "handelsmässigares": "handelsmässig",
    "handelsmässigas": "handelsmässig",
    "handelsmässigast": "handelsmässig",
    "handelsmässigaste": "handelsmässig",
    "handelsmässigastes": "handelsmässig",
    "handelsmässigasts": "handelsmässig",
    "handelsmässige": "handelsmässig",
    "handelsmässiges": "handelsmässig",
    "handelsmässigs": "handelsmässig",
    "handelsmässigt": "handelsmässig",
    "handelsmässigts": "handelsmässig",
    "handelspolitiken": "handelspolitik",
    "handelspolitikens": "handelspolitik",
    "handelspolitiks": "handelspolitik",
    "handelspolitiska": "handelspolitisk",
    "handelspolitiskare": "handelspolitisk",
    "handelspolitiskares": "handelspolitisk",
    "handelspolitiskas": "handelspolitisk",
    "handelspolitiskast": "handelspolitisk",
    "handelspolitiskaste": "handelspolitisk",
    "handelspolitiskastes": "handelspolitisk",
    "handelspolitiskasts": "handelspolitisk",
    "handelspolitiske": "handelspolitisk",
    "handelspolitiskes": "handelspolitisk",
    "handelspolitisks": "handelspolitisk",
    "handelspolitiskt": "handelspolitisk",
    "handelspolitiskts": "handelspolitisk",
    "handelsregisterna": "handelsregister",
    "handelsregisternas": "handelsregister",
    "handelsregisters": "handelsregister",
    "handelsregistren": "handelsregister",
    "handelsregistrens": "handelsregister",
    "handelsregistret": "handelsregister",
    "handelsregistrets": "handelsregister",
    "handelsresan": "handelsresa",
    "handelsresanden": "handelsresande",
    "handelsresandena": "handelsresande",
    "handelsresandenas": "handelsresande",
    "handelsresandens": "handelsresande",
    "handelsresandes": "handelsresande",
    "handelsresans": "handelsresa",
    "handelsresas": "handelsresa",
    "handelsrese": "handelsresa",
    "handelsresor": "handelsresa",
    "handelsresorna": "handelsresa",
    "handelsresornas": "handelsresa",
    "handelsresors": "handelsresa",
    "handelssanktionen": "handelssanktion",
    "handelssanktionens": "handelssanktion",
    "handelssanktioner": "handelssanktion",
    "handelssanktionerna": "handelssanktion",
    "handelssanktionernas": "handelssanktion",
    "handelssanktioners": "handelssanktion",
    "handelssanktions": "handelssanktion",
    "handelsstaden": "handelsstad",
    "handelsstadens": "handelsstad",
    "handelsstads": "handelsstad",
    "handelsstan": "handelsstad",
    "handelsstans": "handelsstad",
    "handelsstäder": "handelsstad",
    "handelsstäderna": "handelsstad",
    "handelsstädernas": "handelsstad",
    "handelsstäders": "handelsstad",
    "handelsträdgårdar": "handelsträdgård",
    "handelsträdgårdarna": "handelsträdgård",
    "handelsträdgårdarnas": "handelsträdgård",
    "handelsträdgårdars": "handelsträdgård",
    "handelsträdgården": "handelsträdgård",
    "handelsträdgårdens": "handelsträdgård",
    "handelsträdgårds": "handelsträdgård",
    "handelsutbyten": "handelsutbyte",
    "handelsutbytena": "handelsutbyte",
    "handelsutbytenas": "handelsutbyte",
    "handelsutbytens": "handelsutbyte",
    "handelsutbytes": "handelsutbyte",
    "handelsutbytet": "handelsutbyte",
    "handelsutbytets": "handelsutbyte",
    "handelsvar": "handelsvara",
    "handelsvaran": "handelsvara",
    "handelsvarans": "handelsvara",
    "handelsvaras": "handelsvara",
    "handelsvare": "handelsvara",
    "handelsvaror": "handelsvara",
    "handelsvarorna": "handelsvara",
    "handelsvarornas": "handelsvara",
    "handelsvarors": "handelsvara",
    "handelsvars": "handelsvara",
    "handen": "hand",
    "handenheten": "handenhet",
    "handenhetens": "handenhet",
    "handenheter": "handenhet",
    "handenheterna": "handenhet",
    "handenheternas": "handenhet",
    "handenheters": "handenhet",
    "handenhets": "handenhet",
    "handens": "hand",
    "handes": "ha",
    "handfallenheten": "handfallenhet",
    "handfallenhetens": "handfallenhet",
    "handfallenheter": "handfallenhet",
    "handfallenheterna": "handfallenhet",
    "handfallenheternas": "handfallenhet",
    "handfallenheters": "handfallenhet",
    "handfallenhets": "handfallenhet",
    "handfallens": "handfallen",
    "handfallet": "handfallen",
    "handfallets": "handfallen",
    "handfallna": "handfallen",
    "handfallnare": "handfallen",
    "handfallnares": "handfallen",
    "handfallnas": "handfallen",
    "handfallnast": "handfallen",
    "handfallnaste": "handfallen",
    "handfallnastes": "handfallen",
    "handfallnasts": "handfallen",
    "handfallne": "handfallen",
    "handfallnes": "handfallen",
    "handfasta": "handfast",
    "handfastare": "handfast",
    "handfastares": "handfast",
    "handfastas": "handfast",
    "handfastast": "handfast",
    "handfastaste": "handfast",
    "handfastastes": "handfast",
    "handfastasts": "handfast",
    "handfaste": "handfast",
    "handfastes": "handfast",
    "handfastheten": "handfasthet",
    "handfasthetens": "handfasthet",
    "handfasthets": "handfasthet",
    "handfasts": "handfast",
    "handfaten": "handfat",
    "handfatens": "handfat",
    "handfatet": "handfat",
    "handfatets": "handfat",
    "handfats": "handfat",
    "handflat": "handflata",
    "handflatan": "handflata",
    "handflatans": "handflata",
    "handflatas": "handflata",
    "handflate": "handflata",
    "handflator": "handflata",
    "handflatorna": "handflata",
    "handflatornas": "handflata",
    "handflators": "handflata",
    "handflats": "handflata",
    "handflikiga": "handflikig",
    "handflikigare": "handflikig",
    "handflikigares": "handflikig",
    "handflikigas": "handflikig",
    "handflikigast": "handflikig",
    "handflikigaste": "handflikig",
    "handflikigastes": "handflikig",
    "handflikigasts": "handflikig",
    "handflikige": "handflikig",
    "handflikiges": "handflikig",
    "handflikigs": "handflikig",
    "handflikigt": "handflikig",
    "handflikigts": "handflikig",
    "handfullar": "handfull",
    "handfullarna": "handfull",
    "handfullarnas": "handfull",
    "handfullars": "handfull",
    "handfullen": "handfull",
    "handfullens": "handfull",
    "handfulls": "handfull",
    "handgemängen": "handgemäng",
    "handgemängens": "handgemäng",
    "handgemänget": "handgemäng",
    "handgemängets": "handgemäng",
    "handgemängs": "handgemäng",
    "handgjorda": "handgjord",
    "handgjordare": "handgjord",
    "handgjordares": "handgjord",
    "handgjordas": "handgjord",
    "handgjordast": "handgjord",
    "handgjordaste": "handgjord",
    "handgjordastes": "handgjord",
    "handgjordasts": "handgjord",
    "handgjorde": "handgjord",
    "handgjordes": "handgjord",
    "handgjords": "handgjord",
    "handgjort": "handgjord",
    "handgjorts": "handgjord",
    "handgranaten": "handgranat",
    "handgranatens": "handgranat",
    "handgranater": "handgranat",
    "handgranaterna": "handgranat",
    "handgranaternas": "handgranat",
    "handgranaters": "handgranat",
    "handgranats": "handgranat",
    "handgreppen": "handgrepp",
    "handgreppens": "handgrepp",
    "handgreppet": "handgrepp",
    "handgreppets": "handgrepp",
    "handgrepps": "handgrepp",
    "handgripliga": "handgriplig",
    "handgripligare": "handgriplig",
    "handgripligares": "handgriplig",
    "handgripligas": "handgriplig",
    "handgripligast": "handgriplig",
    "handgripligaste": "handgriplig",
    "handgripligastes": "handgriplig",
    "handgripligasts": "handgriplig",
    "handgriplige": "handgriplig",
    "handgripliges": "handgriplig",
    "handgripligheten": "handgriplighet",
    "handgriplighetens": "handgriplighet",
    "handgripligheter": "handgriplighet",
    "handgripligheterna": "handgriplighet",
    "handgripligheternas": "handgriplighet",
    "handgripligheters": "handgriplighet",
    "handgriplighets": "handgriplighet",
    "handgripligs": "handgriplig",
    "handgripligt": "handgriplig",
    "handgripligts": "handgriplig",
    "handgångens": "handgången",
    "handgånget": "handgången",
    "handgångets": "handgången",
    "handgångna": "handgången",
    "handgångnare": "handgången",
    "handgångnares": "handgången",
    "handgångnas": "handgången",
    "handgångnast": "handgången",
    "handgångnaste": "handgången",
    "handgångnastes": "handgången",
    "handgångnasts": "handgången",
    "handgångne": "handgången",
    "handgångnes": "handgången",
    "handhade": "handha",
    "handhades": "handha",
    "handhaft": "handha",
    "handhafts": "handha",
    "handhande": "handha",
    "handhandes": "handha",
    "handhar": "handha",
    "handhas": "handha",
    "handhava": "handha",
    "handhavande": "handha",
    "handhavanden": "handhavande",
    "handhavandena": "handhavande",
    "handhavandenas": "handhavande",
    "handhavandens": "handhavande",
    "handhavandes": "handhavande",
    "handhavandet": "handhavande",
    "handhavandets": "handhavande",
    "handhavas": "handha",
    "handhaver": "handha",
    "handhållens": "handhållen",
    "handhållet": "handhållen",
    "handhållets": "handhållen",
    "handhållna": "handhållen",
    "handhållnas": "handhållen",
    "handhållne": "handhållen",
    "handhållnes": "handhållen",
    "handikapp": "handikappa",
    "handikappad": "handikappa",
    "handikappade": "handikappad",
    "handikappades": "handikappad",
    "handikappads": "handikappad",
    "handikappande": "handikappa",
    "handikappanden": "handikappande",
    "handikappandena": "handikappande",
    "handikappandenas": "handikappande",
    "handikappandens": "handikappande",
    "handikappandes": "handikappande",
    "handikappandet": "handikappande",
    "handikappandets": "handikappande",
    "handikappar": "handikappa",
    "handikappas": "handikappa",
    "handikappat": "handikappad",
    "handikappats": "handikappad",
    "handikappen": "handikapp",
    "handikappens": "handikapp",
    "handikappet": "handikapp",
    "handikappets": "handikapp",
    "handikappfrågan": "handikappfråga",
    "handikappfrågans": "handikappfråga",
    "handikappfrågas": "handikappfråga",
    "handikappfråge": "handikappfråga",
    "handikappfrågor": "handikappfråga",
    "handikappfrågorna": "handikappfråga",
    "handikappfrågornas": "handikappfråga",
    "handikappfrågors": "handikappfråga",
    "handikappidrotten": "handikappidrott",
    "handikappidrottens": "handikappidrott",
    "handikappidrotter": "handikappidrott",
    "handikappidrotterna": "handikappidrott",
    "handikappidrotternas": "handikappidrott",
    "handikappidrotters": "handikappidrott",
    "handikappidrotts": "handikappidrott",
    "handikappolitiken": "handikappolitik",
    "handikappolitikens": "handikappolitik",
    "handikappolitiks": "handikappolitik",
    "handikappolitiska": "handikappolitisk",
    "handikappolitiskas": "handikappolitisk",
    "handikappolitiske": "handikappolitisk",
    "handikappolitiskes": "handikappolitisk",
    "handikappolitisks": "handikappolitisk",
    "handikappolitiskt": "handikappolitisk",
    "handikappolitiskts": "handikappolitisk",
    "handikapporganisationen": "handikapporganisation",
    "handikapporganisationens": "handikapporganisation",
    "handikapporganisationer": "handikapporganisation",
    "handikapporganisationerna": "handikapporganisation",
    "handikapporganisationernas": "handikapporganisation",
    "handikapporganisationers": "handikapporganisation",
    "handikapporganisations": "handikapporganisation",
    "handikapps": "handikapp",
    "handikappvårdar": "handikappvård",
    "handikappvårdarna": "handikappvård",
    "handikappvårdarnas": "handikappvård",
    "handikappvårdars": "handikappvård",
    "handikappvården": "handikappvård",
    "handikappvårdens": "handikappvård",
    "handikappvårds": "handikappvård",
    "handjagar": "handjagare",
    "handjagaren": "handjagare",
    "handjagarens": "handjagare",
    "handjagares": "handjagare",
    "handjagarna": "handjagare",
    "handjagarnas": "handjagare",
    "handjuren": "handjur",
    "handjurens": "handjur",
    "handjuret": "handjur",
    "handjurets": "handjur",
    "handjurs": "handjur",
    "handkassan": "handkassa",
    "handkassans": "handkassa",
    "handkassas": "handkassa",
    "handkasse": "handkassa",
    "handkassor": "handkassa",
    "handkassorna": "handkassa",
    "handkassornas": "handkassa",
    "handkassors": "handkassa",
    "handklappningar": "handklappning",
    "handklappningarna": "handklappning",
    "handklappningarnas": "handklappning",
    "handklappningars": "handklappning",
    "handklappningen": "handklappning",
    "handklappningens": "handklappning",
    "handklappnings": "handklappning",
    "handklaveren": "handklaver",
    "handklaverens": "handklaver",
    "handklaveret": "handklaver",
    "handklaverets": "handklaver",
    "handklavers": "handklaver",
    "handklov": "handklove",
    "handklovar": "handklove",
    "handklovarna": "handklove",
    "handklovarnas": "handklove",
    "handklovars": "handklove",
    "handkloven": "handklove",
    "handklovens": "handklove",
    "handkloves": "handklove",
    "handklovs": "handklove",
    "handknackade": "handknackad",
    "handknackades": "handknackad",
    "handknackads": "handknackad",
    "handknackat": "handknackad",
    "handknackats": "handknackad",
    "handkontrollen": "handkontroll",
    "handkontrollens": "handkontroll",
    "handkontroller": "handkontroll",
    "handkontrollerna": "handkontroll",
    "handkontrollernas": "handkontroll",
    "handkontrollers": "handkontroll",
    "handkontrolls": "handkontroll",
    "handkraften": "handkraft",
    "handkraftens": "handkraft",
    "handkrafts": "handkraft",
    "handkrämen": "handkräm",
    "handkrämens": "handkräm",
    "handkrämer": "handkräm",
    "handkrämerna": "handkräm",
    "handkrämernas": "handkräm",
    "handkrämers": "handkräm",
    "handkräms": "handkräm",
    "handkyssar": "handkyss",
    "handkyssarna": "handkyss",
    "handkyssarnas": "handkyss",
    "handkyssars": "handkyss",
    "handkyssen": "handkyss",
    "handkyssens": "handkyss",
    "handla": "handlägga",
    "handlad": "handla",
    "handlade": "handlägga",
    "handlades": "handlägga",
    "handlads": "handla",
    "handlagd": "handlägga",
    "handlagda": "handlägga",
    "handlagdas": "handlägga",
    "handlagde": "handlägga",
    "handlagdes": "handlägga",
    "handlagds": "handlägga",
    "handlaget": "handlag",
    "handlagets": "handlag",
    "handlags": "handlag",
    "handlagt": "handlägga",
    "handlagts": "handlägga",
    "handlamp": "handlampa",
    "handlampan": "handlampa",
    "handlampans": "handlampa",
    "handlampas": "handlampa",
    "handlampe": "handlampa",
    "handlampor": "handlampa",
    "handlamporna": "handlampa",
    "handlampornas": "handlampa",
    "handlampors": "handlampa",
    "handlamps": "handlampa",
    "handlande": "handla",
    "handlanden": "handlande",
    "handlandena": "handlande",
    "handlandenas": "handlande",
    "handlandens": "handlande",
    "handlandes": "handlande",
    "handlandet": "handlande",
    "handlandets": "handlande",
    "handlar": "handlare",
    "handlaren": "handlare",
    "handlarens": "handlare",
    "handlares": "handlare",
    "handlarna": "handlare",
    "handlarnas": "handlare",
    "handlars": "handel",
    "handlas": "handlägga",
    "handlat": "handla",
    "handlats": "handla",
    "handled": "handleda",
    "handledande": "handleda",
    "handledanden": "handledande",
    "handledandena": "handledande",
    "handledandenas": "handledande",
    "handledandens": "handledande",
    "handledandes": "handledande",
    "handledandet": "handledande",
    "handledandets": "handledande",
    "handledar": "handledare",
    "handledaren": "handledare",
    "handledarens": "handledare",
    "handledares": "handledare",
    "handledarna": "handledare",
    "handledarnas": "handledare",
    "handledas": "handleda",
    "handledd": "handleda",
    "handledda": "handleda",
    "handleddas": "handleda",
    "handledde": "handleda",
    "handleddes": "handleda",
    "handledds": "handleda",
    "handleden": "handled",
    "handledens": "handled",
    "handleder": "handleda",
    "handlederna": "handled",
    "handledernas": "handled",
    "handleders": "handled",
    "handledes": "handleda",
    "handledningar": "handledning",
    "handledningarna": "handledning",
    "handledningarnas": "handledning",
    "handledningars": "handledning",
    "handledningen": "handledning",
    "handledningens": "handledning",
    "handlednings": "handledning",
    "handleds": "handleda",
    "handlett": "handleda",
    "handletts": "handleda",
    "handlingar": "handling",
    "handlingarna": "handling",
    "handlingarnas": "handling",
    "handlingars": "handling",
    "handlingen": "handling",
    "handlingens": "handling",
    "handlings": "handling",
    "handlingsalternativen": "handlingsalternativ",
    "handlingsalternativens": "handlingsalternativ",
    "handlingsalternativet": "handlingsalternativ",
    "handlingsalternativets": "handlingsalternativ",
    "handlingsalternativs": "handlingsalternativ",
    "handlingsberedskapen": "handlingsberedskap",
    "handlingsberedskapens": "handlingsberedskap",
    "handlingsberedskaps": "handlingsberedskap",
    "handlingsfriheten": "handlingsfrihet",
    "handlingsfrihetens": "handlingsfrihet",
    "handlingsfriheter": "handlingsfrihet",
    "handlingsfriheterna": "handlingsfrihet",
    "handlingsfriheternas": "handlingsfrihet",
    "handlingsfriheters": "handlingsfrihet",
    "handlingsfrihets": "handlingsfrihet",
    "handlingsförlamade": "handlingsförlamad",
    "handlingsförlamades": "handlingsförlamad",
    "handlingsförlamads": "handlingsförlamad",
    "handlingsförlamat": "handlingsförlamad",
    "handlingsförlamats": "handlingsförlamad",
    "handlingsförlamningar": "handlingsförlamning",
    "handlingsförlamningarna": "handlingsförlamning",
    "handlingsförlamningarnas": "handlingsförlamning",
    "handlingsförlamningars": "handlingsförlamning",
    "handlingsförlamningen": "handlingsförlamning",
    "handlingsförlamningens": "handlingsförlamning",
    "handlingsförlamnings": "handlingsförlamning",
    "handlingskraften": "handlingskraft",
    "handlingskraftens": "handlingskraft",
    "handlingskraftiga": "handlingskraftig",
    "handlingskraftigare": "handlingskraftig",
    "handlingskraftigares": "handlingskraftig",
    "handlingskraftigas": "handlingskraftig",
    "handlingskraftigast": "handlingskraftig",
    "handlingskraftigaste": "handlingskraftig",
    "handlingskraftigastes": "handlingskraftig",
    "handlingskraftigasts": "handlingskraftig",
    "handlingskraftige": "handlingskraftig",
    "handlingskraftiges": "handlingskraftig",
    "handlingskraftigheten": "handlingskraftighet",
    "handlingskraftighetens": "handlingskraftighet",
    "handlingskraftighets": "handlingskraftighet",
    "handlingskraftigs": "handlingskraftig",
    "handlingskraftigt": "handlingskraftig",
    "handlingskraftigts": "handlingskraftig",
    "handlingskrafts": "handlingskraft",
    "handlingsmänniskan": "handlingsmänniska",
    "handlingsmänniskans": "handlingsmänniska",
    "handlingsmänniskas": "handlingsmänniska",
    "handlingsmännisko": "handlingsmänniska",
    "handlingsmänniskor": "handlingsmänniska",
    "handlingsmänniskorna": "handlingsmänniska",
    "handlingsmänniskornas": "handlingsmänniska",
    "handlingsmänniskors": "handlingsmänniska",
    "handlingsmässiga": "handlingsmässig",
    "handlingsmässigare": "handlingsmässig",
    "handlingsmässigares": "handlingsmässig",
    "handlingsmässigas": "handlingsmässig",
    "handlingsmässigast": "handlingsmässig",
    "handlingsmässigaste": "handlingsmässig",
    "handlingsmässigastes": "handlingsmässig",
    "handlingsmässigasts": "handlingsmässig",
    "handlingsmässige": "handlingsmässig",
    "handlingsmässiges": "handlingsmässig",
    "handlingsmässigs": "handlingsmässig",
    "handlingsmässigt": "handlingsmässig",
    "handlingsmässigts": "handlingsmässig",
    "handlingsorden": "handlingsord",
    "handlingsordens": "handlingsord",
    "handlingsordet": "handlingsord",
    "handlingsordets": "handlingsord",
    "handlingsords": "handlingsord",
    "handlingsprogrammen": "handlingsprogram",
    "handlingsprogrammens": "handlingsprogram",
    "handlingsprogrammet": "handlingsprogram",
    "handlingsprogrammets": "handlingsprogram",
    "handlingsprograms": "handlingsprogram",
    "handlingsregeln": "handlingsregel",
    "handlingsregelns": "handlingsregel",
    "handlingsregels": "handlingsregel",
    "handlingsregler": "handlingsregel",
    "handlingsreglerna": "handlingsregel",
    "handlingsreglernas": "handlingsregel",
    "handlingsreglers": "handlingsregel",
    "handlingssätten": "handlingssätt",
    "handlingssättens": "handlingssätt",
    "handlingssättet": "handlingssätt",
    "handlingssättets": "handlingssätt",
    "handlingssätts": "handlingssätt",
    "handljusstak": "handljusstake",
    "handljusstakar": "handljusstake",
    "handljusstakarna": "handljusstake",
    "handljusstakarnas": "handljusstake",
    "handljusstakars": "handljusstake",
    "handljusstaken": "handljusstake",
    "handljusstakens": "handljusstake",
    "handljusstakes": "handljusstake",
    "handljusstaks": "handljusstake",
    "handlov": "handlove",
    "handlovar": "handlove",
    "handlovarna": "handlove",
    "handlovarnas": "handlove",
    "handlovars": "handlove",
    "handloven": "handlove",
    "handlovens": "handlove",
    "handloves": "handlove",
    "handlovs": "handlove",
    "handlägg": "handlägga",
    "handläggande": "handlägga",
    "handlägganden": "handläggande",
    "handläggandena": "handläggande",
    "handläggandenas": "handläggande",
    "handläggandens": "handläggande",
    "handläggandes": "handläggande",
    "handläggandet": "handläggande",
    "handläggandets": "handläggande",
    "handläggar": "handläggare",
    "handläggaren": "handläggare",
    "handläggarens": "handläggare",
    "handläggares": "handläggare",
    "handläggarna": "handläggare",
    "handläggarnas": "handläggare",
    "handläggas": "handlägga",
    "handlägger": "handlägga",
    "handlägges": "handlägga",
    "handläggningar": "handläggning",
    "handläggningarna": "handläggning",
    "handläggningarnas": "handläggning",
    "handläggningars": "handläggning",
    "handläggningen": "handläggning",
    "handläggningens": "handläggning",
    "handläggnings": "handläggning",
    "handläggs": "handlägga",
    "handlånen": "handlån",
    "handlånens": "handlån",
    "handlånet": "handlån",
    "handlånets": "handlån",
    "handlåns": "handlån",
    "handouten": "handout",
    "handoutens": "handout",
    "handouts": "handout",
    "handoutsarna": "handout",
    "handoutsarnas": "handout",
    "handoutsen": "handout",
    "handoutsens": "handout",
    "handpenningar": "handpenning",
    "handpenningarna": "handpenning",
    "handpenningarnas": "handpenning",
    "handpenningars": "handpenning",
    "handpenningen": "handpenning",
    "handpenningens": "handpenning",
    "handpennings": "handpenning",
    "handplock": "handplocka",
    "handplockad": "handplocka",
    "handplockade": "handplocka",
    "handplockades": "handplocka",
    "handplockads": "handplocka",
    "handplockande": "handplocka",
    "handplockanden": "handplockande",
    "handplockandena": "handplockande",
    "handplockandenas": "handplockande",
    "handplockandens": "handplockande",
    "handplockandes": "handplockande",
    "handplockandet": "handplockande",
    "handplockandets": "handplockande",
    "handplockar": "handplocka",
    "handplockas": "handplocka",
    "handplockat": "handplocka",
    "handplockats": "handplocka",
    "handpåläggningar": "handpåläggning",
    "handpåläggningarna": "handpåläggning",
    "handpåläggningarnas": "handpåläggning",
    "handpåläggningars": "handpåläggning",
    "handpåläggningen": "handpåläggning",
    "handpåläggningens": "handpåläggning",
    "handpåläggnings": "handpåläggning",
    "handremmar": "handrem",
    "handremmarna": "handrem",
    "handremmarnas": "handrem",
    "handremmars": "handrem",
    "handremmen": "handrem",
    "handremmens": "handrem",
    "handrems": "handrem",
    "handräckningar": "handräckning",
    "handräckningarna": "handräckning",
    "handräckningarnas": "handräckning",
    "handräckningars": "handräckning",
    "handräckningen": "handräckning",
    "handräckningens": "handräckning",
    "handräcknings": "handräckning",
    "hands": "hand",
    "handsbredden": "handsbredd",
    "handsbreddens": "handsbredd",
    "handsbredder": "handsbredd",
    "handsbredderna": "handsbredd",
    "handsbreddernas": "handsbredd",
    "handsbredders": "handsbredd",
    "handsbredds": "handsbredd",
    "handsekreterar": "handsekreterare",
    "handsekreteraren": "handsekreterare",
    "handsekreterarens": "handsekreterare",
    "handsekreterares": "handsekreterare",
    "handsekreterarna": "handsekreterare",
    "handsekreterarnas": "handsekreterare",
    "handsen": "hands",
    "handsens": "hands",
    "handsk": "handske",
    "handskades": "handskas",
    "handskakningar": "handskakning",
    "handskakningarna": "handskakning",
    "handskakningarnas": "handskakning",
    "handskakningars": "handskakning",
    "handskakningen": "handskakning",
    "handskakningens": "handskakning",
    "handskaknings": "handskakning",
    "handskar": "handske",
    "handskarna": "handske",
    "handskarnas": "handske",
    "handskars": "handske",
    "handskats": "handskas",
    "handsken": "handske",
    "handskens": "handske",
    "handskes": "handske",
    "handskfacken": "handskfack",
    "handskfackens": "handskfack",
    "handskfacket": "handskfack",
    "handskfackets": "handskfack",
    "handskfacks": "handskfack",
    "handskriften": "handskrift",
    "handskriftens": "handskrift",
    "handskrifter": "handskrift",
    "handskrifterna": "handskrift",
    "handskrifternas": "handskrift",
    "handskrifters": "handskrift",
    "handskrifts": "handskrift",
    "handskriftsavdelningar": "handskriftsavdelning",
    "handskriftsavdelningarna": "handskriftsavdelning",
    "handskriftsavdelningarnas": "handskriftsavdelning",
    "handskriftsavdelningars": "handskriftsavdelning",
    "handskriftsavdelningen": "handskriftsavdelning",
    "handskriftsavdelningens": "handskriftsavdelning",
    "handskriftsavdelnings": "handskriftsavdelning",
    "handskriftsrull": "handskriftsrulle",
    "handskriftsrullar": "handskriftsrulle",
    "handskriftsrullarna": "handskriftsrulle",
    "handskriftsrullarnas": "handskriftsrulle",
    "handskriftsrullars": "handskriftsrulle",
    "handskriftsrullen": "handskriftsrulle",
    "handskriftsrullens": "handskriftsrulle",
    "handskriftsrulles": "handskriftsrulle",
    "handskriftsrulls": "handskriftsrulle",
    "handskriftssamlingar": "handskriftssamling",
    "handskriftssamlingarna": "handskriftssamling",
    "handskriftssamlingarnas": "handskriftssamling",
    "handskriftssamlingars": "handskriftssamling",
    "handskriftssamlingen": "handskriftssamling",
    "handskriftssamlingens": "handskriftssamling",
    "handskriftssamlings": "handskriftssamling",
    "handskrivens": "handskriven",
    "handskrivet": "handskriven",
    "handskrivets": "handskriven",
    "handskrivna": "handskriven",
    "handskrivnare": "handskriven",
    "handskrivnares": "handskriven",
    "handskrivnas": "handskriven",
    "handskrivnast": "handskriven",
    "handskrivnaste": "handskriven",
    "handskrivnastes": "handskriven",
    "handskrivnasts": "handskriven",
    "handskrivne": "handskriven",
    "handskrivnes": "handskriven",
    "handslagen": "handslag",
    "handslagens": "handslag",
    "handslaget": "handslag",
    "handslagets": "handslag",
    "handslags": "handslag",
    "handstilar": "handstil",
    "handstilarna": "handstil",
    "handstilarnas": "handstil",
    "handstilars": "handstil",
    "handstilen": "handstil",
    "handstilens": "handstil",
    "handstils": "handstil",
    "handstilsexperten": "handstilsexpert",
    "handstilsexpertens": "handstilsexpert",
    "handstilsexperter": "handstilsexpert",
    "handstilsexperterna": "handstilsexpert",
    "handstilsexperternas": "handstilsexpert",
    "handstilsexperters": "handstilsexpert",
    "handstilsexperts": "handstilsexpert",
    "handsvetten": "handsvett",
    "handsvettens": "handsvett",
    "handsvetts": "handsvett",
    "handsågar": "handsåg",
    "handsågarna": "handsåg",
    "handsågarnas": "handsåg",
    "handsågars": "handsåg",
    "handsågen": "handsåg",
    "handsågens": "handsåg",
    "handsågs": "handsåg",
    "handtagen": "handtag",
    "handtagens": "handtag",
    "handtaget": "handtag",
    "handtagets": "handtag",
    "handtags": "handtag",
    "handtrall": "handtralla",
    "handtrallan": "handtralla",
    "handtrallans": "handtralla",
    "handtrallas": "handtralla",
    "handtralle": "handtralla",
    "handtrallor": "handtralla",
    "handtrallorna": "handtralla",
    "handtrallornas": "handtralla",
    "handtrallors": "handtralla",
    "handtralls": "handtralla",
    "handtryckningar": "handtryckning",
    "handtryckningarna": "handtryckning",
    "handtryckningarnas": "handtryckning",
    "handtryckningars": "handtryckning",
    "handtryckningen": "handtryckning",
    "handtryckningens": "handtryckning",
    "handtrycknings": "handtryckning",
    "handuppräckningar": "handuppräckning",
    "handuppräckningarna": "handuppräckning",
    "handuppräckningarnas": "handuppräckning",
    "handuppräckningars": "handuppräckning",
    "handuppräckningen": "handuppräckning",
    "handuppräckningens": "handuppräckning",
    "handuppräcknings": "handuppräckning",
    "handvapens": "handvapen",
    "handvapnen": "handvapen",
    "handvapnens": "handvapen",
    "handvapnet": "handvapen",
    "handvapnets": "handvapen",
    "handvinschar": "handvinsch",
    "handvinscharna": "handvinsch",
    "handvinscharnas": "handvinsch",
    "handvinschars": "handvinsch",
    "handvinschen": "handvinsch",
    "handvinschens": "handvinsch",
    "handvinschs": "handvinsch",
    "handvolten": "handvolt",
    "handvoltens": "handvolt",
    "handvolter": "handvolt",
    "handvolterna": "handvolt",
    "handvolternas": "handvolt",
    "handvolters": "handvolt",
    "handvolts": "handvolt",
    "handväsk": "handväska",
    "handväskan": "handväska",
    "handväskans": "handväska",
    "handväskas": "handväska",
    "handväske": "handväska",
    "handväskor": "handväska",
    "handväskorna": "handväska",
    "handväskornas": "handväska",
    "handväskors": "handväska",
    "hanen": "hane",
    "hanens": "hane",
    "hanes": "hane",
    "hanfoten": "hanfot",
    "hanfotens": "hanfot",
    "hanfots": "hanfot",
    "hangaren": "hangar",
    "hangarens": "hangar",
    "hangarer": "hangar",
    "hangarerna": "hangar",
    "hangarernas": "hangar",
    "hangarers": "hangar",
    "hangarfartygen": "hangarfartyg",
    "hangarfartygens": "hangarfartyg",
    "hangarfartyget": "hangarfartyg",
    "hangarfartygets": "hangarfartyg",
    "hangarfartygs": "hangarfartyg",
    "hangars": "hangar",
    "hangen": "hang",
    "hangens": "hang",
    "hanget": "hang",
    "hangets": "hang",
    "hangs": "hang",
    "hank": "hanka",
    "hankade": "hanka",
    "hankades": "hanka",
    "hankande": "hanka",
    "hankanden": "hankande",
    "hankandena": "hankande",
    "hankandenas": "hankande",
    "hankandens": "hankande",
    "hankandes": "hankande",
    "hankandet": "hankande",
    "hankandets": "hankande",
    "hankar": "hanka",
    "hankarna": "hank",
    "hankarnas": "hank",
    "hankars": "hank",
    "hankas": "hanka",
    "hankat": "hanka",
    "hankats": "hanka",
    "hanken": "hank",
    "hankens": "hank",
    "hanks": "hank",
    "hankönade": "hankönad",
    "hankönades": "hankönad",
    "hankönads": "hankönad",
    "hankönat": "hankönad",
    "hankönats": "hankönad",
    "hankönet": "hankön",
    "hankönets": "hankön",
    "hanköns": "hankön",
    "hanliga": "hanlig",
    "hanligare": "hanlig",
    "hanligares": "hanlig",
    "hanligas": "hanlig",
    "hanligast": "hanlig",
    "hanligaste": "hanlig",
    "hanligastes": "hanlig",
    "hanligasts": "hanlig",
    "hanlige": "hanlig",
    "hanliges": "hanlig",
    "hanligs": "hanlig",
    "hanligt": "hanlig",
    "hanligts": "hanlig",
    "hann": "hinna",
    "hannar": "hanne",
    "hannarna": "hanne",
    "hannarnas": "hanne",
    "hannars": "hanne",
    "hannen": "hanne",
    "hannens": "hanne",
    "hannes": "hanne",
    "hanns": "hinna",
    "hanorganen": "hanorgan",
    "hanorganens": "hanorgan",
    "hanorganet": "hanorgan",
    "hanorganets": "hanorgan",
    "hanorgans": "hanorgan",
    "hanrejar": "hanrej",
    "hanrejarna": "hanrej",
    "hanrejarnas": "hanrej",
    "hanrejars": "hanrej",
    "hanrejen": "hanrej",
    "hanrejens": "hanrej",
    "hanrejer": "hanrej",
    "hanrejerna": "hanrej",
    "hanrejernas": "hanrej",
    "hanrejers": "hanrej",
    "hanrejs": "hanrej",
    "hans": "hane",
    "hanteln": "hantel",
    "hantelns": "hantel",
    "hantels": "hantel",
    "hanterad": "hantera",
    "hanterade": "hantera",
    "hanterades": "hantera",
    "hanterads": "hantera",
    "hanterande": "hantera",
    "hanteranden": "hanterande",
    "hanterandena": "hanterande",
    "hanterandenas": "hanterande",
    "hanterandens": "hanterande",
    "hanterandes": "hanterande",
    "hanterandet": "hanterande",
    "hanterandets": "hanterande",
    "hanterar": "hantera",
    "hanteras": "hantera",
    "hanterat": "hantera",
    "hanterats": "hantera",
    "hanterbara": "hanterbar",
    "hanterbarare": "hanterbar",
    "hanterbarares": "hanterbar",
    "hanterbaras": "hanterbar",
    "hanterbarast": "hanterbar",
    "hanterbaraste": "hanterbar",
    "hanterbarastes": "hanterbar",
    "hanterbarasts": "hanterbar",
    "hanterbare": "hanterbar",
    "hanterbares": "hanterbar",
    "hanterbarheten": "hanterbarhet",
    "hanterbarhetens": "hanterbarhet",
    "hanterbarhets": "hanterbarhet",
    "hanterbars": "hanterbar",
    "hanterbart": "hanterbar",
    "hanterbarts": "hanterbar",
    "hanteringar": "hantering",
    "hanteringarna": "hantering",
    "hanteringarnas": "hantering",
    "hanteringars": "hantering",
    "hanteringen": "hantering",
    "hanteringens": "hantering",
    "hanterings": "hantering",
    "hanteringskostnaden": "hanteringskostnad",
    "hanteringskostnadens": "hanteringskostnad",
    "hanteringskostnader": "hanteringskostnad",
    "hanteringskostnaderna": "hanteringskostnad",
    "hanteringskostnadernas": "hanteringskostnad",
    "hanteringskostnaders": "hanteringskostnad",
    "hanteringskostnads": "hanteringskostnad",
    "hanteringsrisken": "hanteringsrisk",
    "hanteringsriskens": "hanteringsrisk",
    "hanteringsrisker": "hanteringsrisk",
    "hanteringsriskerna": "hanteringsrisk",
    "hanteringsriskernas": "hanteringsrisk",
    "hanteringsriskers": "hanteringsrisk",
    "hanteringsrisks": "hanteringsrisk",
    "hanterliga": "hanterlig",
    "hanterligare": "hanterlig",
    "hanterligares": "hanterlig",
    "hanterligas": "hanterlig",
    "hanterligast": "hanterlig",
    "hanterligaste": "hanterlig",
    "hanterligastes": "hanterlig",
    "hanterligasts": "hanterlig",
    "hanterlige": "hanterlig",
    "hanterliges": "hanterlig",
    "hanterligheten": "hanterlighet",
    "hanterlighetens": "hanterlighet",
    "hanterlighets": "hanterlighet",
    "hanterligs": "hanterlig",
    "hanterligt": "hanterlig",
    "hanterligts": "hanterlig",
    "hantlangar": "hantlangare",
    "hantlangaren": "hantlangare",
    "hantlangarens": "hantlangare",
    "hantlangares": "hantlangare",
    "hantlangarna": "hantlangare",
    "hantlangarnas": "hantlangare",
    "hantlar": "hantel",
    "hantlarna": "hantel",
    "hantlarnas": "hantel",
    "hantlars": "hantel",
    "hantverkar": "hantverkare",
    "hantverkaren": "hantverkare",
    "hantverkarens": "hantverkare",
    "hantverkares": "hantverkare",
    "hantverkarna": "hantverkare",
    "hantverkarnas": "hantverkare",
    "hantverkarsatsen": "hantverkarsats",
    "hantverkarsatsens": "hantverkarsats",
    "hantverkarsatser": "hantverkarsats",
    "hantverkarsatserna": "hantverkarsats",
    "hantverkarsatsernas": "hantverkarsats",
    "hantverkarsatsers": "hantverkarsats",
    "hantverken": "hantverk",
    "hantverkens": "hantverk",
    "hantverket": "hantverk",
    "hantverkets": "hantverk",
    "hantverks": "hantverk",
    "hantverksarbetar": "hantverksarbetare",
    "hantverksarbetaren": "hantverksarbetare",
    "hantverksarbetarens": "hantverksarbetare",
    "hantverksarbetares": "hantverksarbetare",
    "hantverksarbetarna": "hantverksarbetare",
    "hantverksarbetarnas": "hantverksarbetare",
    "hantverksföreningar": "hantverksförening",
    "hantverksföreningarna": "hantverksförening",
    "hantverksföreningarnas": "hantverksförening",
    "hantverksföreningars": "hantverksförening",
    "hantverksföreningen": "hantverksförening",
    "hantverksföreningens": "hantverksförening",
    "hantverksförenings": "hantverksförening",
    "hantverksmässiga": "hantverksmässig",
    "hantverksmässigare": "hantverksmässig",
    "hantverksmässigares": "hantverksmässig",
    "hantverksmässigas": "hantverksmässig",
    "hantverksmässigast": "hantverksmässig",
    "hantverksmässigaste": "hantverksmässig",
    "hantverksmässigastes": "hantverksmässig",
    "hantverksmässigasts": "hantverksmässig",
    "hantverksmässige": "hantverksmässig",
    "hantverksmässiges": "hantverksmässig",
    "hantverksmässigheten": "hantverksmässighet",
    "hantverksmässighetens": "hantverksmässighet",
    "hantverksmässighets": "hantverksmässighet",
    "hantverksmässigs": "hantverksmässig",
    "hantverksmässigt": "hantverksmässig",
    "hantverksmässigts": "hantverksmässig",
    "hantverksskickligheten": "hantverksskicklighet",
    "hantverksskicklighetens": "hantverksskicklighet",
    "hantverksskickligheter": "hantverksskicklighet",
    "hantverksskickligheterna": "hantverksskicklighet",
    "hantverksskickligheternas": "hantverksskicklighet",
    "hantverksskickligheters": "hantverksskicklighet",
    "hantverksskicklighets": "hantverksskicklighet",
    "haploida": "haploid",
    "haploidare": "haploid",
    "haploidares": "haploid",
    "haploidas": "haploid",
    "haploidast": "haploid",
    "haploidaste": "haploid",
    "haploidastes": "haploid",
    "haploidasts": "haploid",
    "haploide": "haploid",
    "haploides": "haploid",
    "haploids": "haploid",
    "happeningar": "happening",
    "happeningarna": "happening",
    "happeningarnas": "happening",
    "happeningars": "happening",
    "happeningen": "happening",
    "happeningens": "happening",
    "happenings": "happening",
    "happeningsarna": "happening",
    "happeningsarnas": "happening",
    "happeningsen": "happening",
    "happeningsens": "happening",
    "haptoglobinen": "haptoglobin",
    "haptoglobinens": "haptoglobin",
    "haptoglobiner": "haptoglobin",
    "haptoglobinerna": "haptoglobin",
    "haptoglobinernas": "haptoglobin",
    "haptoglobiners": "haptoglobin",
    "haptoglobinet": "haptoglobin",
    "haptoglobinets": "haptoglobin",
    "haptoglobins": "haptoglobin",
    "har": "hare",
    "harakirin": "harakiri",
    "harakirins": "harakiri",
    "harakiris": "harakiri",
    "harakirit": "harakiri",
    "harakirits": "harakiri",
    "harangen": "harang",
    "harangens": "harang",
    "haranger": "harang",
    "harangerad": "harangera",
    "harangerade": "harangera",
    "harangerades": "harangera",
    "harangerads": "harangera",
    "harangerande": "harangera",
    "harangeranden": "harangerande",
    "harangerandena": "harangerande",
    "harangerandenas": "harangerande",
    "harangerandens": "harangerande",
    "harangerandes": "harangerande",
    "harangerandet": "harangerande",
    "harangerandets": "harangerande",
    "harangerar": "harangera",
    "harangeras": "harangera",
    "harangerat": "harangera",
    "harangerats": "harangera",
    "harangerbara": "harangerbar",
    "harangerbarare": "harangerbar",
    "harangerbarares": "harangerbar",
    "harangerbaras": "harangerbar",
    "harangerbarast": "harangerbar",
    "harangerbaraste": "harangerbar",
    "harangerbarastes": "harangerbar",
    "harangerbarasts": "harangerbar",
    "harangerbare": "harangerbar",
    "harangerbares": "harangerbar",
    "harangerbarheten": "harangerbarhet",
    "harangerbarhetens": "harangerbarhet",
    "harangerbarhets": "harangerbarhet",
    "harangerbars": "harangerbar",
    "harangerbart": "harangerbar",
    "harangerbarts": "harangerbar",
    "harangeringar": "harangering",
    "harangeringarna": "harangering",
    "harangeringarnas": "harangering",
    "harangeringars": "harangering",
    "harangeringen": "harangering",
    "harangeringens": "harangering",
    "harangerings": "harangering",
    "harangerna": "harang",
    "harangernas": "harang",
    "harangers": "harang",
    "harangs": "harang",
    "harar": "hare",
    "hararna": "hare",
    "hararnas": "hare",
    "harars": "hare",
    "hardangersömmar": "hardangersöm",
    "hardangersömmarna": "hardangersöm",
    "hardangersömmarnas": "hardangersöm",
    "hardangersömmars": "hardangersöm",
    "hardangersömmen": "hardangersöm",
    "hardangersömmens": "hardangersöm",
    "hardangersöms": "hardangersöm",
    "haremen": "harem",
    "haremens": "harem",
    "haremet": "harem",
    "haremets": "harem",
    "harems": "harem",
    "haren": "hare",
    "harens": "hare",
    "hares": "hare",
    "harhann": "harhanne",
    "harhannar": "harhanne",
    "harhannarna": "harhanne",
    "harhannarnas": "harhanne",
    "harhannars": "harhanne",
    "harhannen": "harhanne",
    "harhannens": "harhanne",
    "harhannes": "harhanne",
    "harhanns": "harhanne",
    "harhjärtade": "harhjärtad",
    "harhjärtades": "harhjärtad",
    "harhjärtads": "harhjärtad",
    "harhjärtat": "harhjärtad",
    "harhjärtats": "harhjärtad",
    "hariga": "harig",
    "harigare": "harig",
    "harigares": "harig",
    "harigas": "harig",
    "harigast": "harig",
    "harigaste": "harig",
    "harigastes": "harig",
    "harigasts": "harig",
    "harige": "harig",
    "hariges": "harig",
    "harigs": "harig",
    "harigt": "harig",
    "harigts": "harig",
    "harkel": "harkla",
    "harklade": "harkla",
    "harklades": "harkla",
    "harklande": "harkla",
    "harklanden": "harklande",
    "harklandena": "harklande",
    "harklandenas": "harklande",
    "harklandens": "harklande",
    "harklandes": "harklande",
    "harklandet": "harklande",
    "harklandets": "harklande",
    "harklar": "harkla",
    "harklas": "harkla",
    "harklat": "harkla",
    "harklats": "harkla",
    "harklingar": "harkling",
    "harklingarna": "harkling",
    "harklingarnas": "harkling",
    "harklingars": "harkling",
    "harklingen": "harkling",
    "harklingens": "harkling",
    "harklings": "harkling",
    "harklövern": "harklöver",
    "harklöverns": "harklöver",
    "harklövers": "harklöver",
    "harkrankar": "harkrank",
    "harkrankarna": "harkrank",
    "harkrankarnas": "harkrank",
    "harkrankars": "harkrank",
    "harkranken": "harkrank",
    "harkrankens": "harkrank",
    "harkranks": "harkrank",
    "harlekinen": "harlekin",
    "harlekinens": "harlekin",
    "harlekiner": "harlekin",
    "harlekinerna": "harlekin",
    "harlekinernas": "harlekin",
    "harlekiners": "harlekin",
    "harlekins": "harlekin",
    "harläppen": "harläpp",
    "harläppens": "harläpp",
    "harläpps": "harläpp",
    "harm": "harma",
    "harmad": "harma",
    "harmade": "harma",
    "harmades": "harmas",
    "harmads": "harma",
    "harmande": "harma",
    "harmanden": "harmande",
    "harmandena": "harmande",
    "harmandenas": "harmande",
    "harmandens": "harmande",
    "harmandes": "harmande",
    "harmandet": "harmande",
    "harmandets": "harmande",
    "harmar": "harma",
    "harmas": "harma",
    "harmat": "harma",
    "harmats": "harmas",
    "harmen": "harm",
    "harmens": "harm",
    "harmfulla": "harmfull",
    "harmfullare": "harmfull",
    "harmfullares": "harmfull",
    "harmfullas": "harmfull",
    "harmfullast": "harmfull",
    "harmfullaste": "harmfull",
    "harmfullastes": "harmfull",
    "harmfullasts": "harmfull",
    "harmfulle": "harmfull",
    "harmfulles": "harmfull",
    "harmfullheten": "harmfullhet",
    "harmfullhetens": "harmfullhet",
    "harmfullhets": "harmfullhet",
    "harmfulls": "harmfull",
    "harmfullt": "harmfull",
    "harmfullts": "harmfull",
    "harmfyllda": "harmfylld",
    "harmfylldare": "harmfylld",
    "harmfylldares": "harmfylld",
    "harmfylldas": "harmfylld",
    "harmfylldast": "harmfylld",
    "harmfylldaste": "harmfylld",
    "harmfylldastes": "harmfylld",
    "harmfylldasts": "harmfylld",
    "harmfyllde": "harmfylld",
    "harmfylldes": "harmfylld",
    "harmfylldheten": "harmfylldhet",
    "harmfylldhetens": "harmfylldhet",
    "harmfylldhets": "harmfylldhet",
    "harmfyllds": "harmfylld",
    "harmfyllt": "harmfylld",
    "harmfyllts": "harmfylld",
    "harmliga": "harmlig",
    "harmligare": "harmlig",
    "harmligares": "harmlig",
    "harmligas": "harmlig",
    "harmligast": "harmlig",
    "harmligaste": "harmlig",
    "harmligastes": "harmlig",
    "harmligasts": "harmlig",
    "harmlige": "harmlig",
    "harmliges": "harmlig",
    "harmligheten": "harmlighet",
    "harmlighetens": "harmlighet",
    "harmlighets": "harmlighet",
    "harmligs": "harmlig",
    "harmligt": "harmlig",
    "harmligts": "harmlig",
    "harmlösa": "harmlös",
    "harmlösare": "harmlös",
    "harmlösares": "harmlös",
    "harmlösas": "harmlös",
    "harmlösast": "harmlös",
    "harmlösaste": "harmlös",
    "harmlösastes": "harmlös",
    "harmlösasts": "harmlös",
    "harmlöse": "harmlös",
    "harmlöses": "harmlös",
    "harmlösheten": "harmlöshet",
    "harmlöshetens": "harmlöshet",
    "harmlösheter": "harmlöshet",
    "harmlösheterna": "harmlöshet",
    "harmlösheternas": "harmlöshet",
    "harmlösheters": "harmlöshet",
    "harmlöshets": "harmlöshet",
    "harmlöst": "harmlös",
    "harmlösts": "harmlös",
    "harmonie": "harmonium",
    "harmonien": "harmoni",
    "harmoniens": "harmoni",
    "harmonier": "harmonium",
    "harmonierade": "harmoniera",
    "harmonierades": "harmoniera",
    "harmonierande": "harmoniera",
    "harmonieranden": "harmonierande",
    "harmonierandena": "harmonierande",
    "harmonierandenas": "harmonierande",
    "harmonierandens": "harmonierande",
    "harmonierandes": "harmonierande",
    "harmonierandet": "harmonierande",
    "harmonierandets": "harmonierande",
    "harmonierar": "harmoniera",
    "harmonieras": "harmoniera",
    "harmonierat": "harmoniera",
    "harmonierats": "harmoniera",
    "harmonieringar": "harmoniering",
    "harmonieringarna": "harmoniering",
    "harmonieringarnas": "harmoniering",
    "harmonieringars": "harmoniering",
    "harmonieringen": "harmoniering",
    "harmonieringens": "harmoniering",
    "harmonierings": "harmoniering",
    "harmonierna": "harmonium",
    "harmoniernas": "harmonium",
    "harmoniers": "harmonium",
    "harmoniet": "harmonium",
    "harmoniets": "harmonium",
    "harmonik": "harmonika",
    "harmonikan": "harmonika",
    "harmonikans": "harmonika",
    "harmonikas": "harmonika",
    "harmonike": "harmonika",
    "harmoniken": "harmonik",
    "harmonikens": "harmonik",
    "harmonikor": "harmonika",
    "harmonikorna": "harmonika",
    "harmonikornas": "harmonika",
    "harmonikors": "harmonika",
    "harmoniks": "harmonika",
    "harmoniläran": "harmonilära",
    "harmonilärans": "harmonilära",
    "harmoniläras": "harmonilära",
    "harmonin": "harmoni",
    "harmonins": "harmoni",
    "harmonis": "harmoni",
    "harmoniserad": "harmonisera",
    "harmoniserade": "harmonisera",
    "harmoniserades": "harmonisera",
    "harmoniserads": "harmonisera",
    "harmoniserande": "harmonisera",
    "harmoniseranden": "harmoniserande",
    "harmoniserandena": "harmoniserande",
    "harmoniserandenas": "harmoniserande",
    "harmoniserandens": "harmoniserande",
    "harmoniserandes": "harmoniserande",
    "harmoniserandet": "harmoniserande",
    "harmoniserandets": "harmoniserande",
    "harmoniserar": "harmonisera",
    "harmoniseras": "harmonisera",
    "harmoniserat": "harmonisera",
    "harmoniserats": "harmonisera",
    "harmoniserbara": "harmoniserbar",
    "harmoniserbarare": "harmoniserbar",
    "harmoniserbarares": "harmoniserbar",
    "harmoniserbaras": "harmoniserbar",
    "harmoniserbarast": "harmoniserbar",
    "harmoniserbaraste": "harmoniserbar",
    "harmoniserbarastes": "harmoniserbar",
    "harmoniserbarasts": "harmoniserbar",
    "harmoniserbare": "harmoniserbar",
    "harmoniserbares": "harmoniserbar",
    "harmoniserbarheten": "harmoniserbarhet",
    "harmoniserbarhetens": "harmoniserbarhet",
    "harmoniserbarhets": "harmoniserbarhet",
    "harmoniserbars": "harmoniserbar",
    "harmoniserbart": "harmoniserbar",
    "harmoniserbarts": "harmoniserbar",
    "harmoniseringar": "harmonisering",
    "harmoniseringarna": "harmonisering",
    "harmoniseringarnas": "harmonisering",
    "harmoniseringars": "harmonisering",
    "harmoniseringen": "harmonisering",
    "harmoniseringens": "harmonisering",
    "harmoniserings": "harmonisering",
    "harmoniska": "harmonisk",
    "harmoniskare": "harmonisk",
    "harmoniskares": "harmonisk",
    "harmoniskas": "harmonisk",
    "harmoniskast": "harmonisk",
    "harmoniskaste": "harmonisk",
    "harmoniskastes": "harmonisk",
    "harmoniskasts": "harmonisk",
    "harmoniske": "harmonisk",
    "harmoniskes": "harmonisk",
    "harmonisks": "harmonisk",
    "harmoniskt": "harmonisk",
    "harmoniskts": "harmonisk",
    "harmoniums": "harmonium",
    "harms": "harm",
    "harmsenheten": "harmsenhet",
    "harmsenhetens": "harmsenhet",
    "harmsenhets": "harmsenhet",
    "harmsens": "harmsen",
    "harmset": "harmsen",
    "harmsets": "harmsen",
    "harmsna": "harmsen",
    "harmsnare": "harmsen",
    "harmsnares": "harmsen",
    "harmsnas": "harmsen",
    "harmsnast": "harmsen",
    "harmsnaste": "harmsen",
    "harmsnastes": "harmsen",
    "harmsnasts": "harmsen",
    "harmsne": "harmsen",
    "harmsnes": "harmsen",
    "harmynta": "harmynt",
    "harmyntare": "harmynt",
    "harmyntares": "harmynt",
    "harmyntas": "harmynt",
    "harmyntast": "harmynt",
    "harmyntaste": "harmynt",
    "harmyntastes": "harmynt",
    "harmyntasts": "harmynt",
    "harmynte": "harmynt",
    "harmyntes": "harmynt",
    "harmyntheten": "harmynthet",
    "harmynthetens": "harmynthet",
    "harmynthets": "harmynthet",
    "harmynts": "harmynt",
    "harnesken": "harnesk",
    "harneskens": "harnesk",
    "harnesket": "harnesk",
    "harneskets": "harnesk",
    "harnesks": "harnesk",
    "harp": "harpa",
    "harpaltar": "harpalt",
    "harpaltarna": "harpalt",
    "harpaltarnas": "harpalt",
    "harpaltars": "harpalt",
    "harpalten": "harpalt",
    "harpaltens": "harpalt",
    "harpalts": "harpalt",
    "harpan": "harpa",
    "harpans": "harpa",
    "harpas": "harpa",
    "harpe": "harpa",
    "harpesten": "harpest",
    "harpestens": "harpest",
    "harpests": "harpest",
    "harpisten": "harpist",
    "harpistens": "harpist",
    "harpister": "harpist",
    "harpisterna": "harpist",
    "harpisternas": "harpist",
    "harpisters": "harpist",
    "harpists": "harpist",
    "harpor": "harpa",
    "harporna": "harpa",
    "harpornas": "harpa",
    "harpors": "harpa",
    "harps": "harpa",
    "harpunen": "harpun",
    "harpunens": "harpun",
    "harpuner": "harpun",
    "harpunerad": "harpunera",
    "harpunerade": "harpunera",
    "harpunerades": "harpunera",
    "harpunerads": "harpunera",
    "harpunerande": "harpunera",
    "harpuneranden": "harpunerande",
    "harpunerandena": "harpunerande",
    "harpunerandenas": "harpunerande",
    "harpunerandens": "harpunerande",
    "harpunerandes": "harpunerande",
    "harpunerandet": "harpunerande",
    "harpunerandets": "harpunerande",
    "harpunerar": "harpunera",
    "harpuneras": "harpunera",
    "harpunerat": "harpunera",
    "harpunerats": "harpunera",
    "harpunerbara": "harpunerbar",
    "harpunerbarare": "harpunerbar",
    "harpunerbarares": "harpunerbar",
    "harpunerbaras": "harpunerbar",
    "harpunerbarast": "harpunerbar",
    "harpunerbaraste": "harpunerbar",
    "harpunerbarastes": "harpunerbar",
    "harpunerbarasts": "harpunerbar",
    "harpunerbare": "harpunerbar",
    "harpunerbares": "harpunerbar",
    "harpunerbarheten": "harpunerbarhet",
    "harpunerbarhetens": "harpunerbarhet",
    "harpunerbarhets": "harpunerbarhet",
    "harpunerbars": "harpunerbar",
    "harpunerbart": "harpunerbar",
    "harpunerbarts": "harpunerbar",
    "harpuneringar": "harpunering",
    "harpuneringarna": "harpunering",
    "harpuneringarnas": "harpunering",
    "harpuneringars": "harpunering",
    "harpuneringen": "harpunering",
    "harpuneringens": "harpunering",
    "harpunerings": "harpunering",
    "harpunerna": "harpun",
    "harpunernas": "harpun",
    "harpuners": "harpun",
    "harpuns": "harpun",
    "harpyan": "harpya",
    "harpyans": "harpya",
    "harpyas": "harpya",
    "harpye": "harpya",
    "harpyjan": "harpyja",
    "harpyjans": "harpyja",
    "harpyjas": "harpyja",
    "harpyje": "harpyja",
    "harpyjor": "harpyja",
    "harpyjorna": "harpyja",
    "harpyjornas": "harpyja",
    "harpyjors": "harpyja",
    "harpyor": "harpya",
    "harpyorna": "harpya",
    "harpyornas": "harpya",
    "harpyors": "harpya",
    "harrar": "harr",
    "harrarna": "harr",
    "harrarnas": "harr",
    "harrars": "harr",
    "harren": "harr",
    "harrens": "harr",
    "harrs": "harr",
    "hars": "hare",
    "harskel": "harskla",
    "harsklade": "harskla",
    "harsklades": "harskla",
    "harsklande": "harskla",
    "harsklanden": "harsklande",
    "harsklandena": "harsklande",
    "harsklandenas": "harsklande",
    "harsklandens": "harsklande",
    "harsklandes": "harsklande",
    "harsklandet": "harsklande",
    "harsklandets": "harsklande",
    "harsklar": "harskla",
    "harsklas": "harskla",
    "harsklat": "harskla",
    "harsklats": "harskla",
    "harskramel": "harskramla",
    "harskramlan": "harskramla",
    "harskramlans": "harskramla",
    "harskramlas": "harskramla",
    "harskramle": "harskramla",
    "harskramlor": "harskramla",
    "harskramlorna": "harskramla",
    "harskramlornas": "harskramla",
    "harskramlors": "harskramla",
    "harspåren": "harspår",
    "harspårens": "harspår",
    "harspåret": "harspår",
    "harspårets": "harspår",
    "harspårs": "harspår",
    "harstigar": "harstig",
    "harstigarna": "harstig",
    "harstigarnas": "harstig",
    "harstigars": "harstig",
    "harstigen": "harstig",
    "harstigens": "harstig",
    "harstigs": "harstig",
    "harsyran": "harsyra",
    "harsyrans": "harsyra",
    "harsyras": "harsyra",
    "harsyre": "harsyra",
    "harsyror": "harsyra",
    "harsyrorna": "harsyra",
    "harsyrornas": "harsyra",
    "harsyrors": "harsyra",
    "hartassar": "hartass",
    "hartassarna": "hartass",
    "hartassarnas": "hartass",
    "hartassars": "hartass",
    "hartassen": "hartass",
    "hartassens": "hartass",
    "harts": "hartsa",
    "hartsad": "hartsa",
    "hartsade": "hartsa",
    "hartsades": "hartsa",
    "hartsads": "hartsa",
    "hartsande": "hartsa",
    "hartsanden": "hartsande",
    "hartsandena": "hartsande",
    "hartsandenas": "hartsande",
    "hartsandens": "hartsande",
    "hartsandes": "hartsande",
    "hartsandet": "hartsande",
    "hartsandets": "hartsande",
    "hartsar": "hartsa",
    "hartsas": "hartsa",
    "hartsat": "hartsa",
    "hartsats": "hartsa",
    "hartser": "harts",
    "hartserna": "harts",
    "hartsernas": "harts",
    "hartsers": "harts",
    "hartset": "harts",
    "hartsets": "harts",
    "hartsfiolen": "hartsfiol",
    "hartsfiolens": "hartsfiol",
    "hartsfioler": "hartsfiol",
    "hartsfiolerna": "hartsfiol",
    "hartsfiolernas": "hartsfiol",
    "hartsfiolers": "hartsfiol",
    "hartsfiols": "hartsfiol",
    "harv": "harva",
    "harvad": "harva",
    "harvade": "harva",
    "harvades": "harva",
    "harvads": "harva",
    "harvande": "harva",
    "harvanden": "harvande",
    "harvandena": "harvande",
    "harvandenas": "harvande",
    "harvandens": "harvande",
    "harvandes": "harvande",
    "harvandet": "harvande",
    "harvandets": "harvande",
    "harvar": "harva",
    "harvarna": "harv",
    "harvarnas": "harv",
    "harvars": "harv",
    "harvas": "harva",
    "harvat": "harva",
    "harvats": "harva",
    "harven": "harv",
    "harvens": "harv",
    "harvs": "harv",
    "has": "hasa",
    "hasad": "hasa",
    "hasade": "hasa",
    "hasades": "hasa",
    "hasads": "hasa",
    "hasande": "hasa",
    "hasanden": "hasande",
    "hasandena": "hasande",
    "hasandenas": "hasande",
    "hasandens": "hasande",
    "hasandes": "hasande",
    "hasandet": "hasande",
    "hasandets": "hasande",
    "hasar": "hasa",
    "hasarden": "hasard",
    "hasardens": "hasard",
    "hasarderad": "hasardera",
    "hasarderade": "hasardera",
    "hasarderades": "hasardera",
    "hasarderads": "hasardera",
    "hasarderande": "hasardera",
    "hasarderanden": "hasarderande",
    "hasarderandena": "hasarderande",
    "hasarderandenas": "hasarderande",
    "hasarderandens": "hasarderande",
    "hasarderandes": "hasarderande",
    "hasarderandet": "hasarderande",
    "hasarderandets": "hasarderande",
    "hasarderar": "hasardera",
    "hasarderas": "hasardera",
    "hasarderat": "hasardera",
    "hasarderats": "hasardera",
    "hasarderbara": "hasarderbar",
    "hasarderbarare": "hasarderbar",
    "hasarderbarares": "hasarderbar",
    "hasarderbaras": "hasarderbar",
    "hasarderbarast": "hasarderbar",
    "hasarderbaraste": "hasarderbar",
    "hasarderbarastes": "hasarderbar",
    "hasarderbarasts": "hasarderbar",
    "hasarderbare": "hasarderbar",
    "hasarderbares": "hasarderbar",
    "hasarderbarheten": "hasarderbarhet",
    "hasarderbarhetens": "hasarderbarhet",
    "hasarderbarhets": "hasarderbarhet",
    "hasarderbars": "hasarderbar",
    "hasarderbart": "hasarderbar",
    "hasarderbarts": "hasarderbar",
    "hasarderingar": "hasardering",
    "hasarderingarna": "hasardering",
    "hasarderingarnas": "hasardering",
    "hasarderingars": "hasardering",
    "hasarderingen": "hasardering",
    "hasarderingens": "hasardering",
    "hasarderings": "hasardering",
    "hasards": "hasard",
    "hasardspelen": "hasardspel",
    "hasardspelens": "hasardspel",
    "hasardspelet": "hasardspel",
    "hasardspelets": "hasardspel",
    "hasardspels": "hasardspel",
    "hasarna": "has",
    "hasarnas": "has",
    "hasars": "has",
    "hasas": "hasa",
    "hasat": "hasa",
    "hasats": "hasa",
    "haschcigaretten": "haschcigarett",
    "haschcigarettens": "haschcigarett",
    "haschcigaretter": "haschcigarett",
    "haschcigaretterna": "haschcigarett",
    "haschcigaretternas": "haschcigarett",
    "haschcigaretters": "haschcigarett",
    "haschcigaretts": "haschcigarett",
    "haschen": "hasch",
    "haschens": "hasch",
    "haschet": "hasch",
    "haschets": "hasch",
    "haschhischen": "haschhisch",
    "haschhischens": "haschhisch",
    "haschhischet": "haschhisch",
    "haschhischets": "haschhisch",
    "haschhischs": "haschhisch",
    "haschischen": "haschisch",
    "haschischens": "haschisch",
    "haschischet": "haschisch",
    "haschischets": "haschisch",
    "haschischs": "haschisch",
    "haschrökningen": "haschrökning",
    "haschrökningens": "haschrökning",
    "haschröknings": "haschrökning",
    "haschs": "hasch",
    "hasen": "has",
    "hasens": "has",
    "hasor": "has",
    "hasorna": "has",
    "hasornas": "has",
    "hasors": "has",
    "hasp": "haspa",
    "haspad": "haspa",
    "haspade": "haspa",
    "haspades": "haspa",
    "haspads": "haspa",
    "haspande": "haspa",
    "haspanden": "haspande",
    "haspandena": "haspande",
    "haspandenas": "haspande",
    "haspandens": "haspande",
    "haspandes": "haspande",
    "haspandet": "haspande",
    "haspandets": "haspande",
    "haspar": "haspa",
    "hasparna": "hasp",
    "hasparnas": "hasp",
    "haspars": "hasp",
    "haspas": "haspa",
    "haspat": "haspa",
    "haspats": "haspa",
    "haspelfiskes": "haspelfiske",
    "haspelfisket": "haspelfiske",
    "haspelfiskets": "haspelfiske",
    "haspeln": "haspel",
    "haspelns": "haspel",
    "haspels": "haspel",
    "haspen": "hasp",
    "haspens": "hasp",
    "hasplad": "haspla",
    "hasplade": "haspla",
    "hasplades": "haspla",
    "hasplads": "haspla",
    "hasplande": "haspla",
    "hasplanden": "hasplande",
    "hasplandena": "hasplande",
    "hasplandenas": "hasplande",
    "hasplandens": "hasplande",
    "hasplandes": "hasplande",
    "hasplandet": "hasplande",
    "hasplandets": "hasplande",
    "hasplar": "haspla",
    "hasplarna": "haspel",
    "hasplarnas": "haspel",
    "hasplars": "haspel",
    "hasplas": "haspla",
    "hasplat": "haspla",
    "hasplats": "haspla",
    "hasps": "hasp",
    "hasselmusen": "hasselmus",
    "hasselmusens": "hasselmus",
    "hasselmöss": "hasselmus",
    "hasselmössen": "hasselmus",
    "hasselmössens": "hasselmus",
    "hasseln": "hassel",
    "hasselns": "hassel",
    "hasselnöten": "hasselnöt",
    "hasselnötens": "hasselnöt",
    "hasselnöts": "hasselnöt",
    "hasselnötter": "hasselnöt",
    "hasselnötterna": "hasselnöt",
    "hasselnötternas": "hasselnöt",
    "hasselnötters": "hasselnöt",
    "hassels": "hassel",
    "hasselsnokar": "hasselsnok",
    "hasselsnokarna": "hasselsnok",
    "hasselsnokarnas": "hasselsnok",
    "hasselsnokars": "hasselsnok",
    "hasselsnoken": "hasselsnok",
    "hasselsnokens": "hasselsnok",
    "hasselsnoks": "hasselsnok",
    "hasslar": "hassel",
    "hasslarna": "hassel",
    "hasslarnas": "hassel",
    "hasslars": "hassel",
    "hastade": "hasta",
    "hastades": "hasta",
    "hastande": "hasta",
    "hastanden": "hastande",
    "hastandena": "hastande",
    "hastandenas": "hastande",
    "hastandens": "hastande",
    "hastandes": "hastande",
    "hastandet": "hastande",
    "hastandets": "hastande",
    "hastar": "hasta",
    "hastas": "hasta",
    "hastat": "hasta",
    "hastats": "hasta",
    "hastiga": "hastig",
    "hastigare": "hastig",
    "hastigares": "hastig",
    "hastigas": "hastig",
    "hastigast": "hastig",
    "hastigaste": "hastig",
    "hastigastes": "hastig",
    "hastigasts": "hastig",
    "hastige": "hastig",
    "hastiges": "hastig",
    "hastigheten": "hastighet",
    "hastighetens": "hastighet",
    "hastigheter": "hastighet",
    "hastigheterna": "hastighet",
    "hastigheternas": "hastighet",
    "hastigheters": "hastighet",
    "hastighets": "hastighet",
    "hastighetsgränsen": "hastighetsgräns",
    "hastighetsgränsens": "hastighetsgräns",
    "hastighetsgränser": "hastighetsgräns",
    "hastighetsgränserna": "hastighetsgräns",
    "hastighetsgränsernas": "hastighetsgräns",
    "hastighetsgränsers": "hastighetsgräns",
    "hastighetskontrollen": "hastighetskontroll",
    "hastighetskontrollens": "hastighetskontroll",
    "hastighetskontroller": "hastighetskontroll",
    "hastighetskontrollerna": "hastighetskontroll",
    "hastighetskontrollernas": "hastighetskontroll",
    "hastighetskontrollers": "hastighetskontroll",
    "hastighetskontrolls": "hastighetskontroll",
    "hastighetsmätar": "hastighetsmätare",
    "hastighetsmätaren": "hastighetsmätare",
    "hastighetsmätarens": "hastighetsmätare",
    "hastighetsmätares": "hastighetsmätare",
    "hastighetsmätarna": "hastighetsmätare",
    "hastighetsmätarnas": "hastighetsmätare",
    "hastighetsreglagen": "hastighetsreglage",
    "hastighetsreglagens": "hastighetsreglage",
    "hastighetsreglages": "hastighetsreglage",
    "hastighetsreglaget": "hastighetsreglage",
    "hastighetsreglagets": "hastighetsreglage",
    "hastighetstävlingar": "hastighetstävling",
    "hastighetstävlingarna": "hastighetstävling",
    "hastighetstävlingarnas": "hastighetstävling",
    "hastighetstävlingars": "hastighetstävling",
    "hastighetstävlingen": "hastighetstävling",
    "hastighetstävlingens": "hastighetstävling",
    "hastighetstävlings": "hastighetstävling",
    "hastighetsåkningar": "hastighetsåkning",
    "hastighetsåkningarna": "hastighetsåkning",
    "hastighetsåkningarnas": "hastighetsåkning",
    "hastighetsåkningars": "hastighetsåkning",
    "hastighetsåkningen": "hastighetsåkning",
    "hastighetsåkningens": "hastighetsåkning",
    "hastighetsåknings": "hastighetsåkning",
    "hastigs": "hastig",
    "hastigt": "hastig",
    "hastigts": "hastig",
    "hastverken": "hastverk",
    "hastverkens": "hastverk",
    "hastverket": "hastverk",
    "hastverkets": "hastverk",
    "hastverks": "hastverk",
    "hat": "hata",
    "hatad": "hata",
    "hatade": "hata",
    "hatades": "hata",
    "hatads": "hata",
    "hatande": "hata",
    "hatanden": "hatande",
    "hatandena": "hatande",
    "hatandenas": "hatande",
    "hatandens": "hatande",
    "hatandes": "hatande",
    "hatandet": "hatande",
    "hatandets": "hatande",
    "hatar": "hata",
    "hatas": "hata",
    "hatat": "hata",
    "hatats": "hata",
    "hatbreven": "hatbrev",
    "hatbrevens": "hatbrev",
    "hatbrevet": "hatbrev",
    "hatbrevets": "hatbrev",
    "hatbrevs": "hatbrev",
    "hatbrotten": "hatbrott",
    "hatbrottens": "hatbrott",
    "hatbrottet": "hatbrott",
    "hatbrottets": "hatbrott",
    "hatbrotts": "hatbrott",
    "hatet": "hat",
    "hatets": "hat",
    "hatfulla": "hatfull",
    "hatfullare": "hatfull",
    "hatfullares": "hatfull",
    "hatfullas": "hatfull",
    "hatfullast": "hatfull",
    "hatfullaste": "hatfull",
    "hatfullastes": "hatfull",
    "hatfullasts": "hatfull",
    "hatfulle": "hatfull",
    "hatfulles": "hatfull",
    "hatfullheten": "hatfullhet",
    "hatfullhetens": "hatfullhet",
    "hatfullhets": "hatfullhet",
    "hatfulls": "hatfull",
    "hatfullt": "hatfull",
    "hatfullts": "hatfull",
    "hatfyllda": "hatfylld",
    "hatfylldare": "hatfylld",
    "hatfylldares": "hatfylld",
    "hatfylldas": "hatfylld",
    "hatfylldast": "hatfylld",
    "hatfylldaste": "hatfylld",
    "hatfylldastes": "hatfylld",
    "hatfylldasts": "hatfylld",
    "hatfyllde": "hatfylld",
    "hatfylldes": "hatfylld",
    "hatfylldheten": "hatfylldhet",
    "hatfylldhetens": "hatfylldhet",
    "hatfylldhets": "hatfylldhet",
    "hatfyllds": "hatfylld",
    "hatfyllt": "hatfylld",
    "hatfyllts": "hatfylld",
    "hatiska": "hatisk",
    "hatiskare": "hatisk",
    "hatiskares": "hatisk",
    "hatiskas": "hatisk",
    "hatiskast": "hatisk",
    "hatiskaste": "hatisk",
    "hatiskastes": "hatisk",
    "hatiskasts": "hatisk",
    "hatiske": "hatisk",
    "hatiskes": "hatisk",
    "hatisks": "hatisk",
    "hatiskt": "hatisk",
    "hatiskts": "hatisk",
    "hatkärlekar": "hatkärlek",
    "hatkärlekarna": "hatkärlek",
    "hatkärlekarnas": "hatkärlek",
    "hatkärlekars": "hatkärlek",
    "hatkärleken": "hatkärlek",
    "hatkärlekens": "hatkärlek",
    "hatkärleks": "hatkärlek",
    "hatporträtten": "hatporträtt",
    "hatporträttens": "hatporträtt",
    "hatporträttet": "hatporträtt",
    "hatporträttets": "hatporträtt",
    "hatporträtts": "hatporträtt",
    "hats": "hat",
    "hatstämningen": "hatstämning",
    "hatstämningens": "hatstämning",
    "hatstämnings": "hatstämning",
    "hatt": "hatta",
    "hattade": "hatta",
    "hattades": "hatta",
    "hattande": "hatta",
    "hattanden": "hattande",
    "hattandena": "hattande",
    "hattandenas": "hattande",
    "hattandens": "hattande",
    "hattandes": "hattande",
    "hattandet": "hattande",
    "hattandets": "hattande",
    "hattar": "hatta",
    "hattarna": "hatt",
    "hattarnas": "hatt",
    "hattars": "hatt",
    "hattas": "hatta",
    "hattat": "hatta",
    "hattats": "hatta",
    "hatten": "hatt",
    "hattens": "hatt",
    "hatthyll": "hatthylla",
    "hatthyllan": "hatthylla",
    "hatthyllans": "hatthylla",
    "hatthyllas": "hatthylla",
    "hatthylle": "hatthylla",
    "hatthyllor": "hatthylla",
    "hatthyllorna": "hatthylla",
    "hatthyllornas": "hatthylla",
    "hatthyllors": "hatthylla",
    "hatthylls": "hatthylla",
    "hattiga": "hattig",
    "hattigare": "hattig",
    "hattigares": "hattig",
    "hattigas": "hattig",
    "hattigast": "hattig",
    "hattigaste": "hattig",
    "hattigastes": "hattig",
    "hattigasts": "hattig",
    "hattige": "hattig",
    "hattiges": "hattig",
    "hattigheten": "hattighet",
    "hattighetens": "hattighet",
    "hattighets": "hattighet",
    "hattigs": "hattig",
    "hattigt": "hattig",
    "hattigts": "hattig",
    "hattkull": "hattkulle",
    "hattkullar": "hattkulle",
    "hattkullarna": "hattkulle",
    "hattkullarnas": "hattkulle",
    "hattkullars": "hattkulle",
    "hattkullen": "hattkulle",
    "hattkullens": "hattkulle",
    "hattkulles": "hattkulle",
    "hattkulls": "hattkulle",
    "hattpartiet": "hattparti",
    "hattpartiets": "hattparti",
    "hattpartis": "hattparti",
    "hatts": "hatt",
    "hattstockar": "hattstock",
    "hattstockarna": "hattstock",
    "hattstockarnas": "hattstock",
    "hattstockars": "hattstock",
    "hattstocken": "hattstock",
    "hattstockens": "hattstock",
    "hattstocks": "hattstock",
    "hattsvampar": "hattsvamp",
    "hattsvamparna": "hattsvamp",
    "hattsvamparnas": "hattsvamp",
    "hattsvampars": "hattsvamp",
    "hattsvampen": "hattsvamp",
    "hattsvampens": "hattsvamp",
    "hattsvamps": "hattsvamp",
    "haubitsar": "haubits",
    "haubitsarna": "haubits",
    "haubitsarnas": "haubits",
    "haubitsars": "haubits",
    "haubitsen": "haubits",
    "haubitsens": "haubits",
    "haubitser": "haubits",
    "haubitserna": "haubits",
    "haubitsernas": "haubits",
    "haubitsers": "haubits",
    "haubitzar": "haubitz",
    "haubitzarna": "haubitz",
    "haubitzarnas": "haubitz",
    "haubitzars": "haubitz",
    "haubitzen": "haubitz",
    "haubitzens": "haubitz",
    "hausas": "hausa",
    "hauss": "haussa",
    "haussad": "haussa",
    "haussade": "haussa",
    "haussades": "haussa",
    "haussads": "haussa",
    "haussande": "haussa",
    "haussanden": "haussande",
    "haussandena": "haussande",
    "haussandenas": "haussande",
    "haussandens": "haussande",
    "haussandes": "haussande",
    "haussandet": "haussande",
    "haussandets": "haussande",
    "haussar": "haussa",
    "haussas": "haussa",
    "haussat": "haussa",
    "haussats": "haussa",
    "haussen": "hausse",
    "haussens": "hausse",
    "hausser": "hausse",
    "hausserna": "hausse",
    "haussernas": "hausse",
    "haussers": "hausse",
    "hausses": "hausse",
    "hava": "ha",
    "havande": "ha",
    "havanden": "havande",
    "havandena": "havande",
    "havandenas": "havande",
    "havandens": "havande",
    "havandes": "havande",
    "havandeskapen": "havandeskap",
    "havandeskapens": "havandeskap",
    "havandeskapet": "havandeskap",
    "havandeskapets": "havandeskap",
    "havandeskaps": "havandeskap",
    "havandeskapsförgiftningar": "havandeskapsförgiftning",
    "havandeskapsförgiftningarna": "havandeskapsförgiftning",
    "havandeskapsförgiftningarnas": "havandeskapsförgiftning",
    "havandeskapsförgiftningars": "havandeskapsförgiftning",
    "havandeskapsförgiftningen": "havandeskapsförgiftning",
    "havandeskapsförgiftningens": "havandeskapsförgiftning",
    "havandeskapsförgiftnings": "havandeskapsförgiftning",
    "havandet": "havande",
    "havandets": "havande",
    "havas": "ha",
    "haven": "hav",
    "havens": "hav",
    "haver": "ha",
    "havererad": "haverera",
    "havererade": "haverera",
    "havererades": "haverera",
    "havererads": "haverera",
    "havererande": "haverera",
    "havereranden": "havererande",
    "havererandena": "havererande",
    "havererandenas": "havererande",
    "havererandens": "havererande",
    "havererandes": "havererande",
    "havererandet": "havererande",
    "havererandets": "havererande",
    "havererar": "haverera",
    "havereras": "haverera",
    "havererat": "haverera",
    "havererats": "haverera",
    "havererbara": "havererbar",
    "havererbarare": "havererbar",
    "havererbarares": "havererbar",
    "havererbaras": "havererbar",
    "havererbarast": "havererbar",
    "havererbaraste": "havererbar",
    "havererbarastes": "havererbar",
    "havererbarasts": "havererbar",
    "havererbare": "havererbar",
    "havererbares": "havererbar",
    "havererbarheten": "havererbarhet",
    "havererbarhetens": "havererbarhet",
    "havererbarhets": "havererbarhet",
    "havererbars": "havererbar",
    "havererbart": "havererbar",
    "havererbarts": "havererbar",
    "havereringar": "haverering",
    "havereringarna": "haverering",
    "havereringarnas": "haverering",
    "havereringars": "haverering",
    "havereringen": "haverering",
    "havereringens": "haverering",
    "havererings": "haverering",
    "haverier": "haveri",
    "haverierna": "haveri",
    "haveriernas": "haveri",
    "haveriers": "haveri",
    "haveriet": "haveri",
    "haveriets": "haveri",
    "haverikommissionen": "haverikommission",
    "haverikommissionens": "haverikommission",
    "haverikommissioner": "haverikommission",
    "haverikommissionerna": "haverikommission",
    "haverikommissionernas": "haverikommission",
    "haverikommissioners": "haverikommission",
    "haverikommissions": "haverikommission",
    "haveris": "haveri",
    "haveristen": "haverist",
    "haveristens": "haverist",
    "haverister": "haverist",
    "haveristerna": "haverist",
    "haveristernas": "haverist",
    "haveristers": "haverist",
    "haverists": "haverist",
    "haverit": "haveri",
    "haverits": "haveri",
    "haverroten": "haverrot",
    "haverrotens": "haverrot",
    "haverrots": "haverrot",
    "havet": "hav",
    "havets": "hav",
    "havreflarnen": "havreflarn",
    "havreflarnens": "havreflarn",
    "havreflarnet": "havreflarn",
    "havreflarnets": "havreflarn",
    "havreflarns": "havreflarn",
    "havregrynen": "havregryn",
    "havregrynens": "havregryn",
    "havregrynet": "havregryn",
    "havregrynets": "havregryn",
    "havregryns": "havregryn",
    "havregrynsgrötar": "havregrynsgröt",
    "havregrynsgrötarna": "havregrynsgröt",
    "havregrynsgrötarnas": "havregrynsgröt",
    "havregrynsgrötars": "havregrynsgröt",
    "havregrynsgröten": "havregrynsgröt",
    "havregrynsgrötens": "havregrynsgröt",
    "havregrynsgröts": "havregrynsgröt",
    "havrekak": "havrekaka",
    "havrekakan": "havrekaka",
    "havrekakans": "havrekaka",
    "havrekakas": "havrekaka",
    "havrekake": "havrekaka",
    "havrekakor": "havrekaka",
    "havrekakorna": "havrekaka",
    "havrekakornas": "havrekaka",
    "havrekakors": "havrekaka",
    "havrekaks": "havrekaka",
    "havrekornen": "havrekorn",
    "havrekornens": "havrekorn",
    "havrekornet": "havrekorn",
    "havrekornets": "havrekorn",
    "havrekorns": "havrekorn",
    "havremjölet": "havremjöl",
    "havremjölets": "havremjöl",
    "havremjöls": "havremjöl",
    "havremusten": "havremust",
    "havremustens": "havremust",
    "havremusts": "havremust",
    "havren": "havre",
    "havrens": "havre",
    "havres": "havre",
    "havretraktorer": "havretraktor",
    "havretraktorerna": "havretraktor",
    "havretraktorernas": "havretraktor",
    "havretraktorers": "havretraktor",
    "havretraktorn": "havretraktor",
    "havretraktorns": "havretraktor",
    "havretraktors": "havretraktor",
    "havs": "hav",
    "havsabborr": "havsabborre",
    "havsabborrar": "havsabborre",
    "havsabborrarna": "havsabborre",
    "havsabborrarnas": "havsabborre",
    "havsabborrars": "havsabborre",
    "havsabborren": "havsabborre",
    "havsabborrens": "havsabborre",
    "havsabborres": "havsabborre",
    "havsabborrs": "havsabborre",
    "havsanemonen": "havsanemon",
    "havsanemonens": "havsanemon",
    "havsanemoner": "havsanemon",
    "havsanemonerna": "havsanemon",
    "havsanemonernas": "havsanemon",
    "havsanemoners": "havsanemon",
    "havsanemons": "havsanemon",
    "havsbaden": "havsbad",
    "havsbadens": "havsbad",
    "havsbadet": "havsbad",
    "havsbadets": "havsbad",
    "havsbads": "havsbad",
    "havsbandet": "havsband",
    "havsbandets": "havsband",
    "havsbands": "havsband",
    "havsblåa": "havsblå",
    "havsblåare": "havsblå",
    "havsblåares": "havsblå",
    "havsblåas": "havsblå",
    "havsblåast": "havsblå",
    "havsblåaste": "havsblå",
    "havsblåastes": "havsblå",
    "havsblåasts": "havsblå",
    "havsblåe": "havsblå",
    "havsblåes": "havsblå",
    "havsblås": "havsblå",
    "havsblått": "havsblå",
    "havsblåtts": "havsblå",
    "havsborstmaskar": "havsborstmask",
    "havsborstmaskarna": "havsborstmask",
    "havsborstmaskarnas": "havsborstmask",
    "havsborstmaskars": "havsborstmask",
    "havsborstmasken": "havsborstmask",
    "havsborstmaskens": "havsborstmask",
    "havsborstmasks": "havsborstmask",
    "havsbottens": "havsbotten",
    "havsbottnar": "havsbotten",
    "havsbottnarna": "havsbotten",
    "havsbottnarnas": "havsbotten",
    "havsbottnars": "havsbotten",
    "havsbottnen": "havsbotten",
    "havsbottnens": "havsbotten",
    "havsbrisar": "havsbris",
    "havsbrisarna": "havsbris",
    "havsbrisarnas": "havsbris",
    "havsbrisars": "havsbris",
    "havsbrisen": "havsbris",
    "havsbrisens": "havsbris",
    "havsbriser": "havsbris",
    "havsbriserna": "havsbris",
    "havsbrisernas": "havsbris",
    "havsbrisers": "havsbris",
    "havsbrynet": "havsbryn",
    "havsbrynets": "havsbryn",
    "havsbryns": "havsbryn",
    "havsdjupen": "havsdjup",
    "havsdjupens": "havsdjup",
    "havsdjupet": "havsdjup",
    "havsdjupets": "havsdjup",
    "havsdjups": "havsdjup",
    "havsfiskes": "havsfiske",
    "havsfisket": "havsfiske",
    "havsfiskets": "havsfiske",
    "havsfruar": "havsfru",
    "havsfruarna": "havsfru",
    "havsfruarnas": "havsfru",
    "havsfruars": "havsfru",
    "havsfrun": "havsfru",
    "havsfruns": "havsfru",
    "havsfrus": "havsfru",
    "havsfågeln": "havsfågel",
    "havsfågelns": "havsfågel",
    "havsfågels": "havsfågel",
    "havsfåglar": "havsfågel",
    "havsfåglarna": "havsfågel",
    "havsfåglarnas": "havsfågel",
    "havsfåglars": "havsfågel",
    "havsgudar": "havsgud",
    "havsgudarna": "havsgud",
    "havsgudarnas": "havsgud",
    "havsgudars": "havsgud",
    "havsguden": "havsgud",
    "havsgudens": "havsgud",
    "havsguds": "havsgud",
    "havsisar": "havsis",
    "havsisarna": "havsis",
    "havsisarnas": "havsis",
    "havsisars": "havsis",
    "havsisen": "havsis",
    "havsisens": "havsis",
    "havskappseglingar": "havskappsegling",
    "havskappseglingarna": "havskappsegling",
    "havskappseglingarnas": "havskappsegling",
    "havskappseglingars": "havskappsegling",
    "havskappseglingen": "havskappsegling",
    "havskappseglingens": "havskappsegling",
    "havskappseglings": "havskappsegling",
    "havskatten": "havskatt",
    "havskattens": "havskatt",
    "havskatter": "havskatt",
    "havskatterna": "havskatt",
    "havskatternas": "havskatt",
    "havskatters": "havskatt",
    "havskatts": "havskatt",
    "havsklimatet": "havsklimat",
    "havsklimatets": "havsklimat",
    "havsklimats": "havsklimat",
    "havskryssar": "havskryssare",
    "havskryssaren": "havskryssare",
    "havskryssarens": "havskryssare",
    "havskryssares": "havskryssare",
    "havskryssarna": "havskryssare",
    "havskryssarnas": "havskryssare",
    "havskräft": "havskräfta",
    "havskräftan": "havskräfta",
    "havskräftans": "havskräfta",
    "havskräftas": "havskräfta",
    "havskräfte": "havskräfta",
    "havskräftor": "havskräfta",
    "havskräftorna": "havskräfta",
    "havskräftornas": "havskräfta",
    "havskräftors": "havskräfta",
    "havskräfts": "havskräfta",
    "havskräftstjärtar": "havskräftstjärt",
    "havskräftstjärtarna": "havskräftstjärt",
    "havskräftstjärtarnas": "havskräftstjärt",
    "havskräftstjärtars": "havskräftstjärt",
    "havskräftstjärten": "havskräftstjärt",
    "havskräftstjärtens": "havskräftstjärt",
    "havskräftstjärts": "havskräftstjärt",
    "havslaxar": "havslax",
    "havslaxarna": "havslax",
    "havslaxarnas": "havslax",
    "havslaxars": "havslax",
    "havslaxen": "havslax",
    "havslaxens": "havslax",
    "havsmusar": "havsmus",
    "havsmusarna": "havsmus",
    "havsmusarnas": "havsmus",
    "havsmusars": "havsmus",
    "havsmusen": "havsmus",
    "havsmusens": "havsmus",
    "havsnivåer": "havsnivå",
    "havsnivåerna": "havsnivå",
    "havsnivåernas": "havsnivå",
    "havsnivåers": "havsnivå",
    "havsnivån": "havsnivå",
    "havsnivåns": "havsnivå",
    "havsnivås": "havsnivå",
    "havsområden": "havsområde",
    "havsområdena": "havsområde",
    "havsområdenas": "havsområde",
    "havsområdens": "havsområde",
    "havsområdes": "havsområde",
    "havsområdet": "havsområde",
    "havsområdets": "havsområde",
    "havsorganismen": "havsorganism",
    "havsorganismens": "havsorganism",
    "havsorganismer": "havsorganism",
    "havsorganismerna": "havsorganism",
    "havsorganismernas": "havsorganism",
    "havsorganismers": "havsorganism",
    "havsorganisms": "havsorganism",
    "havsrätten": "havsrätt",
    "havsrättens": "havsrätt",
    "havsrätts": "havsrätt",
    "havssaltet": "havssalt",
    "havssaltets": "havssalt",
    "havssalts": "havssalt",
    "havsstranden": "havsstrand",
    "havsstrandens": "havsstrand",
    "havsstrands": "havsstrand",
    "havsstränder": "havsstrand",
    "havsstränderna": "havsstrand",
    "havssträndernas": "havsstrand",
    "havsstränders": "havsstrand",
    "havsströmmar": "havsström",
    "havsströmmarna": "havsström",
    "havsströmmarnas": "havsström",
    "havsströmmars": "havsström",
    "havsströmmen": "havsström",
    "havsströmmens": "havsström",
    "havsströms": "havsström",
    "havssul": "havssula",
    "havssulan": "havssula",
    "havssulans": "havssula",
    "havssulas": "havssula",
    "havssule": "havssula",
    "havssulor": "havssula",
    "havssulorna": "havssula",
    "havssulornas": "havssula",
    "havssulors": "havssula",
    "havssuls": "havssula",
    "havstrutar": "havstrut",
    "havstrutarna": "havstrut",
    "havstrutarnas": "havstrut",
    "havstrutars": "havstrut",
    "havstruten": "havstrut",
    "havstrutens": "havstrut",
    "havstruts": "havstrut",
    "havstulpanen": "havstulpan",
    "havstulpanens": "havstulpan",
    "havstulpaner": "havstulpan",
    "havstulpanerna": "havstulpan",
    "havstulpanernas": "havstulpan",
    "havstulpaners": "havstulpan",
    "havstulpans": "havstulpan",
    "havsuttern": "havsutter",
    "havsutterns": "havsutter",
    "havsutters": "havsutter",
    "havsuttrar": "havsutter",
    "havsuttrarna": "havsutter",
    "havsuttrarnas": "havsutter",
    "havsuttrars": "havsutter",
    "havsvattens": "havsvatten",
    "havsvattnen": "havsvatten",
    "havsvattnens": "havsvatten",
    "havsvattnet": "havsvatten",
    "havsvattnets": "havsvatten",
    "havsvikar": "havsvik",
    "havsvikarna": "havsvik",
    "havsvikarnas": "havsvik",
    "havsvikars": "havsvik",
    "havsviken": "havsvik",
    "havsvikens": "havsvik",
    "havsviks": "havsvik",
    "havsväxten": "havsväxt",
    "havsväxtens": "havsväxt",
    "havsväxter": "havsväxt",
    "havsväxterna": "havsväxt",
    "havsväxternas": "havsväxt",
    "havsväxters": "havsväxt",
    "havsväxts": "havsväxt",
    "havsvågen": "havsvåg",
    "havsvågens": "havsvåg",
    "havsvågor": "havsvåg",
    "havsvågorna": "havsvåg",
    "havsvågornas": "havsvåg",
    "havsvågors": "havsvåg",
    "havsvågs": "havsvåg",
    "havsytan": "havsyta",
    "havsytans": "havsyta",
    "havsytas": "havsyta",
    "havsörnar": "havsörn",
    "havsörnarna": "havsörn",
    "havsörnarnas": "havsörn",
    "havsörnars": "havsörn",
    "havsörnen": "havsörn",
    "havsörnens": "havsörn",
    "havsörns": "havsörn",
    "havsörnsparen": "havsörnspar",
    "havsörnsparens": "havsörnspar",
    "havsörnsparet": "havsörnspar",
    "havsörnsparets": "havsörnspar",
    "havsörnspars": "havsörnspar",
    "havtornar": "havtorn",
    "havtornarna": "havtorn",
    "havtornarnas": "havtorn",
    "havtornars": "havtorn",
    "havtornen": "havtorn",
    "havtornens": "havtorn",
    "havtorns": "havtorn",
    "hawaiianska": "hawaiiansk",
    "hawaiianskare": "hawaiiansk",
    "hawaiianskares": "hawaiiansk",
    "hawaiianskas": "hawaiiansk",
    "hawaiianskast": "hawaiiansk",
    "hawaiianskaste": "hawaiiansk",
    "hawaiianskastes": "hawaiiansk",
    "hawaiianskasts": "hawaiiansk",
    "hawaiianske": "hawaiiansk",
    "hawaiianskes": "hawaiiansk",
    "hawaiiansks": "hawaiiansk",
    "hawaiianskt": "hawaiiansk",
    "hawaiianskts": "hawaiiansk",
    "hawaiiska": "hawaiisk",
    "hawaiiskare": "hawaiisk",
    "hawaiiskares": "hawaiisk",
    "hawaiiskas": "hawaiisk",
    "hawaiiskast": "hawaiisk",
    "hawaiiskaste": "hawaiisk",
    "hawaiiskastes": "hawaiisk",
    "hawaiiskasts": "hawaiisk",
    "hawaiiske": "hawaiisk",
    "hawaiiskes": "hawaiisk",
    "hawaiisks": "hawaiisk",
    "hawaiiskt": "hawaiisk",
    "hawaiiskts": "hawaiisk",
    "hbt-personen": "hbt-person",
    "hbt-personens": "hbt-person",
    "hbt-personer": "hbt-person",
    "hbt-personerna": "hbt-person",
    "hbt-personernas": "hbt-person",
    "hbt-personers": "hbt-person",
    "hbt-persons": "hbt-person",
    "he-mannen": "he-man",
    "he-mannens": "he-man",
    "he-mans": "he-man",
    "he-män": "he-man",
    "he-männen": "he-man",
    "he-männens": "he-man",
    "he-mäns": "he-man",
    "hearingar": "hearing",
    "hearingarna": "hearing",
    "hearingarnas": "hearing",
    "hearingars": "hearing",
    "hearingen": "hearing",
    "hearingens": "hearing",
    "hearings": "hearing",
    "heaten": "heat",
    "heatens": "heat",
    "heatet": "heat",
    "heatets": "heat",
    "heats": "heat",
    "hebreisk": "hebreiska",
    "hebreiska": "hebreisk",
    "hebreiskan": "hebreiska",
    "hebreiskans": "hebreiska",
    "hebreiskare": "hebreisk",
    "hebreiskares": "hebreisk",
    "hebreiskas": "hebreiska",
    "hebreiskast": "hebreisk",
    "hebreiskaste": "hebreisk",
    "hebreiskastes": "hebreisk",
    "hebreiskasts": "hebreisk",
    "hebreiske": "hebreisk",
    "hebreiskes": "hebreisk",
    "hebreisks": "hebreisk",
    "hebreiskt": "hebreisk",
    "hebreiskts": "hebreisk",
    "hebréen": "hebré",
    "hebréens": "hebré",
    "hebréer": "hebré",
    "hebréerna": "hebré",
    "hebréernas": "hebré",
    "hebréers": "hebré",
    "hebrén": "hebré",
    "hebréns": "hebré",
    "hebrés": "hebré",
    "hedar": "hed",
    "hedarna": "hed",
    "hedarnas": "hed",
    "hedars": "hed",
    "heden": "hed",
    "hedendomar": "hedendom",
    "hedendomarna": "hedendom",
    "hedendomarnas": "hedendom",
    "hedendomars": "hedendom",
    "hedendomen": "hedendom",
    "hedendomens": "hedendom",
    "hedendoms": "hedendom",
    "hedenheten": "hedenhet",
    "hedenhetens": "hedenhet",
    "hedenhets": "hedenhet",
    "hedens": "heden",
    "hederliga": "hederlig",
    "hederligare": "hederlig",
    "hederligares": "hederlig",
    "hederligas": "hederlig",
    "hederligast": "hederlig",
    "hederligaste": "hederlig",
    "hederligastes": "hederlig",
    "hederligasts": "hederlig",
    "hederlige": "hederlig",
    "hederliges": "hederlig",
    "hederligheten": "hederlighet",
    "hederlighetens": "hederlighet",
    "hederlighets": "hederlighet",
    "hederligs": "hederlig",
    "hederligt": "hederlig",
    "hederligts": "hederlig",
    "hedern": "heder",
    "hederns": "heder",
    "heders": "heder",
    "hedersamheten": "hedersamhet",
    "hedersamhetens": "hedersamhet",
    "hedersamhets": "hedersamhet",
    "hedersamma": "hedersam",
    "hedersammare": "hedersam",
    "hedersammares": "hedersam",
    "hedersammas": "hedersam",
    "hedersammast": "hedersam",
    "hedersammaste": "hedersam",
    "hedersammastes": "hedersam",
    "hedersammasts": "hedersam",
    "hedersamme": "hedersam",
    "hedersammes": "hedersam",
    "hedersams": "hedersam",
    "hedersamt": "hedersam",
    "hedersamts": "hedersam",
    "hedersbetygelsen": "hedersbetygelse",
    "hedersbetygelsens": "hedersbetygelse",
    "hedersbetygelser": "hedersbetygelse",
    "hedersbetygelserna": "hedersbetygelse",
    "hedersbetygelsernas": "hedersbetygelse",
    "hedersbetygelsers": "hedersbetygelse",
    "hedersbetygelses": "hedersbetygelse",
    "hedersbevisningar": "hedersbevisning",
    "hedersbevisningarna": "hedersbevisning",
    "hedersbevisningarnas": "hedersbevisning",
    "hedersbevisningars": "hedersbevisning",
    "hedersbevisningen": "hedersbevisning",
    "hedersbevisningens": "hedersbevisning",
    "hedersbevisnings": "hedersbevisning",
    "hedersdoktorer": "hedersdoktor",
    "hedersdoktorerna": "hedersdoktor",
    "hedersdoktorernas": "hedersdoktor",
    "hedersdoktorers": "hedersdoktor",
    "hedersdoktorn": "hedersdoktor",
    "hedersdoktorns": "hedersdoktor",
    "hedersdoktors": "hedersdoktor",
    "hedersgästen": "hedersgäst",
    "hedersgästens": "hedersgäst",
    "hedersgäster": "hedersgäst",
    "hedersgästerna": "hedersgäst",
    "hedersgästernas": "hedersgäst",
    "hedersgästers": "hedersgäst",
    "hedersgästs": "hedersgäst",
    "hedersknyffeln": "hedersknyffel",
    "hedersknyffelns": "hedersknyffel",
    "hedersknyffels": "hedersknyffel",
    "hedersknyfflar": "hedersknyffel",
    "hedersknyfflarna": "hedersknyffel",
    "hedersknyfflarnas": "hedersknyffel",
    "hedersknyfflars": "hedersknyffel",
    "hederskodexar": "hederskodex",
    "hederskodexarna": "hederskodex",
    "hederskodexarnas": "hederskodex",
    "hederskodexars": "hederskodex",
    "hederskodexen": "hederskodex",
    "hederskodexens": "hederskodex",
    "hederskompanier": "hederskompani",
    "hederskompanierna": "hederskompani",
    "hederskompaniernas": "hederskompani",
    "hederskompaniers": "hederskompani",
    "hederskompaniet": "hederskompani",
    "hederskompaniets": "hederskompani",
    "hederskompanis": "hederskompani",
    "hederskompanit": "hederskompani",
    "hederskompanits": "hederskompani",
    "hederskonflikten": "hederskonflikt",
    "hederskonfliktens": "hederskonflikt",
    "hederskonflikter": "hederskonflikt",
    "hederskonflikterna": "hederskonflikt",
    "hederskonflikternas": "hederskonflikt",
    "hederskonflikters": "hederskonflikt",
    "hederskonflikts": "hederskonflikt",
    "hedersledamoten": "hedersledamot",
    "hedersledamotens": "hedersledamot",
    "hedersledamots": "hedersledamot",
    "hedersledamöter": "hedersledamot",
    "hedersledamöterna": "hedersledamot",
    "hedersledamöternas": "hedersledamot",
    "hedersledamöters": "hedersledamot",
    "hedersmannen": "hedersman",
    "hedersmannens": "hedersman",
    "hedersmans": "hedersman",
    "hedersmedaljen": "hedersmedalj",
    "hedersmedaljens": "hedersmedalj",
    "hedersmedaljer": "hedersmedalj",
    "hedersmedaljerna": "hedersmedalj",
    "hedersmedaljernas": "hedersmedalj",
    "hedersmedaljers": "hedersmedalj",
    "hedersmedaljs": "hedersmedalj",
    "hedersmedlemmar": "hedersmedlem",
    "hedersmedlemmarna": "hedersmedlem",
    "hedersmedlemmarnas": "hedersmedlem",
    "hedersmedlemmars": "hedersmedlem",
    "hedersmedlemmen": "hedersmedlem",
    "hedersmedlemmens": "hedersmedlem",
    "hedersmedlems": "hedersmedlem",
    "hedersmorden": "hedersmord",
    "hedersmordens": "hedersmord",
    "hedersmordet": "hedersmord",
    "hedersmordets": "hedersmord",
    "hedersmords": "hedersmord",
    "hedersmän": "hedersman",
    "hedersmännen": "hedersman",
    "hedersmännens": "hedersman",
    "hedersmäns": "hedersman",
    "hedersomnämnanden": "hedersomnämnande",
    "hedersomnämnandena": "hedersomnämnande",
    "hedersomnämnandenas": "hedersomnämnande",
    "hedersomnämnandens": "hedersomnämnande",
    "hedersomnämnandes": "hedersomnämnande",
    "hedersomnämnandet": "hedersomnämnande",
    "hedersomnämnandets": "hedersomnämnande",
    "hedersorden": "hedersord",
    "hedersordens": "hedersord",
    "hedersordet": "hedersord",
    "hedersordets": "hedersord",
    "hedersords": "hedersord",
    "hederspasch": "hederspascha",
    "hederspaschan": "hederspascha",
    "hederspaschans": "hederspascha",
    "hederspaschas": "hederspascha",
    "hederspasche": "hederspascha",
    "hederspaschor": "hederspascha",
    "hederspaschorna": "hederspascha",
    "hederspaschornas": "hederspascha",
    "hederspaschors": "hederspascha",
    "hedersprisen": "hederspris",
    "hedersprisens": "hederspris",
    "hederspriser": "hederspris",
    "hederspriserna": "hederspris",
    "hedersprisernas": "hederspris",
    "hedersprisers": "hederspris",
    "hederspriset": "hederspris",
    "hedersprisets": "hederspris",
    "hederssaken": "hederssak",
    "hederssakens": "hederssak",
    "hederssaker": "hederssak",
    "hederssakerna": "hederssak",
    "hederssakernas": "hederssak",
    "hederssakers": "hederssak",
    "hederssaks": "hederssak",
    "hedersskulden": "hedersskuld",
    "hedersskuldens": "hedersskuld",
    "hedersskulder": "hedersskuld",
    "hedersskulderna": "hedersskuld",
    "hedersskuldernas": "hedersskuld",
    "hedersskulders": "hedersskuld",
    "hedersskulds": "hedersskuld",
    "hedersvakten": "hedersvakt",
    "hedersvaktens": "hedersvakt",
    "hedersvakter": "hedersvakt",
    "hedersvakterna": "hedersvakt",
    "hedersvakternas": "hedersvakt",
    "hedersvakters": "hedersvakt",
    "hedersvakts": "hedersvakt",
    "hedervärda": "hedervärd",
    "hedervärdare": "hedervärd",
    "hedervärdares": "hedervärd",
    "hedervärdas": "hedervärd",
    "hedervärdast": "hedervärd",
    "hedervärdaste": "hedervärd",
    "hedervärdastes": "hedervärd",
    "hedervärdasts": "hedervärd",
    "hedervärde": "hedervärd",
    "hedervärdes": "hedervärd",
    "hedervärdheten": "hedervärdhet",
    "hedervärdhetens": "hedervärdhet",
    "hedervärdhets": "hedervärdhet",
    "hedervärds": "hedervärd",
    "hedervärt": "hedervärd",
    "hedervärts": "hedervärd",
    "hedet": "heden",
    "hedets": "heden",
    "hedna": "heden",
    "hednamissionen": "hednamission",
    "hednamissionens": "hednamission",
    "hednamissioner": "hednamission",
    "hednamissionerna": "hednamission",
    "hednamissionernas": "hednamission",
    "hednamissioners": "hednamission",
    "hednamissions": "hednamission",
    "hednare": "heden",
    "hednares": "heden",
    "hednas": "heden",
    "hednast": "heden",
    "hednaste": "heden",
    "hednastes": "heden",
    "hednasts": "heden",
    "hednatempels": "hednatempel",
    "hednatemplen": "hednatempel",
    "hednatemplens": "hednatempel",
    "hednatemplet": "hednatempel",
    "hednatemplets": "hednatempel",
    "hedne": "heden",
    "hednes": "heden",
    "hedningar": "hedning",
    "hedningarna": "hedning",
    "hedningarnas": "hedning",
    "hedningars": "hedning",
    "hedningen": "hedning",
    "hedningens": "hedning",
    "hednings": "hedning",
    "hedniska": "hednisk",
    "hedniskare": "hednisk",
    "hedniskares": "hednisk",
    "hedniskas": "hednisk",
    "hedniskast": "hednisk",
    "hedniskaste": "hednisk",
    "hedniskastes": "hednisk",
    "hedniskasts": "hednisk",
    "hedniske": "hednisk",
    "hedniskes": "hednisk",
    "hednisks": "hednisk",
    "hedniskt": "hednisk",
    "hedniskts": "hednisk",
    "hedonismen": "hedonism",
    "hedonismens": "hedonism",
    "hedonismer": "hedonism",
    "hedonismerna": "hedonism",
    "hedonismernas": "hedonism",
    "hedonismers": "hedonism",
    "hedonisms": "hedonism",
    "hedonisten": "hedonist",
    "hedonistens": "hedonist",
    "hedonister": "hedonist",
    "hedonisterna": "hedonist",
    "hedonisternas": "hedonist",
    "hedonisters": "hedonist",
    "hedonistiska": "hedonistisk",
    "hedonistiskare": "hedonistisk",
    "hedonistiskares": "hedonistisk",
    "hedonistiskas": "hedonistisk",
    "hedonistiskast": "hedonistisk",
    "hedonistiskaste": "hedonistisk",
    "hedonistiskastes": "hedonistisk",
    "hedonistiskasts": "hedonistisk",
    "hedonistiske": "hedonistisk",
    "hedonistiskes": "hedonistisk",
    "hedonistisks": "hedonistisk",
    "hedonistiskt": "hedonistisk",
    "hedonistiskts": "hedonistisk",
    "hedonists": "hedonist",
    "hedrad": "hedra",
    "hedrade": "hedra",
    "hedrades": "hedra",
    "hedrads": "hedra",
    "hedrande": "hedra",
    "hedranden": "hedrande",
    "hedrandena": "hedrande",
    "hedrandenas": "hedrande",
    "hedrandens": "hedrande",
    "hedrandes": "hedrande",
    "hedrandet": "hedrande",
    "hedrandets": "hedrande",
    "hedrar": "hedra",
    "hedras": "hedra",
    "hedrat": "hedra",
    "hedrats": "hedra",
    "heds": "hed",
    "hegemonien": "hegemoni",
    "hegemoniens": "hegemoni",
    "hegemonier": "hegemoni",
    "hegemonierna": "hegemoni",
    "hegemoniernas": "hegemoni",
    "hegemoniers": "hegemoni",
    "hegemonin": "hegemoni",
    "hegemonins": "hegemoni",
    "hegemonis": "hegemoni",
    "hej": "heja",
    "hejad": "heja",
    "hejade": "heja",
    "hejades": "heja",
    "hejads": "heja",
    "hejaklackar": "hejaklack",
    "hejaklackarna": "hejaklack",
    "hejaklackarnas": "hejaklack",
    "hejaklackars": "hejaklack",
    "hejaklacken": "hejaklack",
    "hejaklackens": "hejaklack",
    "hejaklacks": "hejaklack",
    "hejande": "heja",
    "hejanden": "hejande",
    "hejandena": "hejande",
    "hejandenas": "hejande",
    "hejandens": "hejande",
    "hejandes": "hejande",
    "hejandet": "hejande",
    "hejandets": "hejande",
    "hejar": "hejare",
    "hejarams": "hejaramsa",
    "hejaramsan": "hejaramsa",
    "hejaramsans": "hejaramsa",
    "hejaramsas": "hejaramsa",
    "hejaramse": "hejaramsa",
    "hejaramsor": "hejaramsa",
    "hejaramsorna": "hejaramsa",
    "hejaramsornas": "hejaramsa",
    "hejaramsors": "hejaramsa",
    "hejaren": "hejare",
    "hejarens": "hejare",
    "hejares": "hejare",
    "hejarklackar": "hejarklack",
    "hejarklackarna": "hejarklack",
    "hejarklackarnas": "hejarklack",
    "hejarklackars": "hejarklack",
    "hejarklacken": "hejarklack",
    "hejarklackens": "hejarklack",
    "hejarklacks": "hejarklack",
    "hejarna": "hejare",
    "hejarnas": "hejare",
    "hejas": "heja",
    "hejat": "heja",
    "hejats": "heja",
    "hejd": "hejda",
    "hejdad": "hejda",
    "hejdade": "hejda",
    "hejdades": "hejda",
    "hejdads": "hejda",
    "hejdande": "hejda",
    "hejdanden": "hejdande",
    "hejdandena": "hejdande",
    "hejdandenas": "hejdande",
    "hejdandens": "hejdande",
    "hejdandes": "hejdande",
    "hejdandet": "hejdande",
    "hejdandets": "hejdande",
    "hejdar": "hejda",
    "hejdas": "hejda",
    "hejdat": "hejda",
    "hejdats": "hejda",
    "hejdlösa": "hejdlös",
    "hejdlösare": "hejdlös",
    "hejdlösares": "hejdlös",
    "hejdlösas": "hejdlös",
    "hejdlösast": "hejdlös",
    "hejdlösaste": "hejdlös",
    "hejdlösastes": "hejdlös",
    "hejdlösasts": "hejdlös",
    "hejdlöse": "hejdlös",
    "hejdlöses": "hejdlös",
    "hejdlösheten": "hejdlöshet",
    "hejdlöshetens": "hejdlöshet",
    "hejdlösheter": "hejdlöshet",
    "hejdlösheterna": "hejdlöshet",
    "hejdlösheternas": "hejdlöshet",
    "hejdlösheters": "hejdlöshet",
    "hejdlöshets": "hejdlöshet",
    "hejdlöst": "hejdlös",
    "hejdlösts": "hejdlös",
    "hejds": "hejd",
    "hejdukar": "hejduk",
    "hejdukarna": "hejduk",
    "hejdukarnas": "hejduk",
    "hejdukars": "hejduk",
    "hejduken": "hejduk",
    "hejdukens": "hejduk",
    "hejduks": "hejduk",
    "hejiga": "hejig",
    "hejigare": "hejig",
    "hejigares": "hejig",
    "hejigas": "hejig",
    "hejigast": "hejig",
    "hejigaste": "hejig",
    "hejigastes": "hejig",
    "hejigasts": "hejig",
    "hejige": "hejig",
    "hejiges": "hejig",
    "hejigs": "hejig",
    "hejigt": "hejig",
    "hejigts": "hejig",
    "hekatomben": "hekatomb",
    "hekatombens": "hekatomb",
    "hekatomber": "hekatomb",
    "hekatomberna": "hekatomb",
    "hekatombernas": "hekatomb",
    "hekatombers": "hekatomb",
    "hekatombs": "hekatomb",
    "hektaren": "hektar",
    "hektarens": "hektar",
    "hektaret": "hektar",
    "hektarets": "hektar",
    "hektars": "hektar",
    "hektiska": "hektisk",
    "hektiskare": "hektisk",
    "hektiskares": "hektisk",
    "hektiskas": "hektisk",
    "hektiskast": "hektisk",
    "hektiskaste": "hektisk",
    "hektiskastes": "hektisk",
    "hektiskasts": "hektisk",
    "hektiske": "hektisk",
    "hektiskes": "hektisk",
    "hektisks": "hektisk",
    "hektiskt": "hektisk",
    "hektiskts": "hektisk",
    "hektografen": "hektograf",
    "hektografens": "hektograf",
    "hektografer": "hektograf",
    "hektograferad": "hektografera",
    "hektograferade": "hektografera",
    "hektograferades": "hektografera",
    "hektograferads": "hektografera",
    "hektograferande": "hektografera",
    "hektograferanden": "hektograferande",
    "hektograferandena": "hektograferande",
    "hektograferandenas": "hektograferande",
    "hektograferandens": "hektograferande",
    "hektograferandes": "hektograferande",
    "hektograferandet": "hektograferande",
    "hektograferandets": "hektograferande",
    "hektograferar": "hektografera",
    "hektograferas": "hektografera",
    "hektograferat": "hektografera",
    "hektograferats": "hektografera",
    "hektograferbara": "hektograferbar",
    "hektograferbarare": "hektograferbar",
    "hektograferbarares": "hektograferbar",
    "hektograferbaras": "hektograferbar",
    "hektograferbarast": "hektograferbar",
    "hektograferbaraste": "hektograferbar",
    "hektograferbarastes": "hektograferbar",
    "hektograferbarasts": "hektograferbar",
    "hektograferbare": "hektograferbar",
    "hektograferbares": "hektograferbar",
    "hektograferbarheten": "hektograferbarhet",
    "hektograferbarhetens": "hektograferbarhet",
    "hektograferbarhets": "hektograferbarhet",
    "hektograferbars": "hektograferbar",
    "hektograferbart": "hektograferbar",
    "hektograferbarts": "hektograferbar",
    "hektograferingar": "hektografering",
    "hektograferingarna": "hektografering",
    "hektograferingarnas": "hektografering",
    "hektograferingars": "hektografering",
    "hektograferingen": "hektografering",
    "hektograferingens": "hektografering",
    "hektograferings": "hektografering",
    "hektograferna": "hektograf",
    "hektografernas": "hektograf",
    "hektografers": "hektograf",
    "hektografs": "hektograf",
    "hektogrammen": "hektogram",
    "hektogrammens": "hektogram",
    "hektogrammet": "hektogram",
    "hektogrammets": "hektogram",
    "hektograms": "hektogram",
    "hektolitern": "hektoliter",
    "hektoliterna": "hektoliter",
    "hektoliternas": "hektoliter",
    "hektoliterns": "hektoliter",
    "hektoliters": "hektoliter",
    "hekton": "hekto",
    "hektona": "hekto",
    "hektonas": "hekto",
    "hektons": "hekto",
    "hektos": "hekto",
    "hektot": "hekto",
    "hektots": "hekto",
    "hel": "hela",
    "hela": "hel",
    "helad": "hela",
    "helade": "hela",
    "helades": "hela",
    "helads": "hela",
    "helaftnar": "helafton",
    "helaftnarna": "helafton",
    "helaftnarnas": "helafton",
    "helaftnars": "helafton",
    "helaftonen": "helafton",
    "helaftonens": "helafton",
    "helaftons": "helafton",
    "helan": "hela",
    "helande": "hela",
    "helanden": "helande",
    "helandena": "helande",
    "helandenas": "helande",
    "helandens": "helande",
    "helandes": "helande",
    "helandet": "helande",
    "helandets": "helande",
    "helans": "hela",
    "helar": "hela",
    "helare": "hel",
    "helares": "hel",
    "helas": "hela",
    "helast": "hel",
    "helaste": "hel",
    "helastes": "hel",
    "helasts": "hel",
    "helat": "hela",
    "helats": "hela",
    "helautomatiska": "helautomatisk",
    "helautomatiskare": "helautomatisk",
    "helautomatiskares": "helautomatisk",
    "helautomatiskas": "helautomatisk",
    "helautomatiskast": "helautomatisk",
    "helautomatiskaste": "helautomatisk",
    "helautomatiskastes": "helautomatisk",
    "helautomatiskasts": "helautomatisk",
    "helautomatiske": "helautomatisk",
    "helautomatiskes": "helautomatisk",
    "helautomatisks": "helautomatisk",
    "helautomatiskt": "helautomatisk",
    "helautomatiskts": "helautomatisk",
    "helbilden": "helbild",
    "helbildens": "helbild",
    "helbilder": "helbild",
    "helbilderna": "helbild",
    "helbildernas": "helbild",
    "helbilders": "helbild",
    "helbilds": "helbild",
    "helbrägdagörelsen": "helbrägdagörelse",
    "helbrägdagörelsens": "helbrägdagörelse",
    "helbrägdagörelser": "helbrägdagörelse",
    "helbrägdagörelserna": "helbrägdagörelse",
    "helbrägdagörelsernas": "helbrägdagörelse",
    "helbrägdagörelsers": "helbrägdagörelse",
    "helbrägdagörelses": "helbrägdagörelse",
    "heldagar": "heldag",
    "heldagarna": "heldag",
    "heldagarnas": "heldag",
    "heldagars": "heldag",
    "heldagen": "heldag",
    "heldagens": "heldag",
    "heldagliga": "heldaglig",
    "heldagligare": "heldaglig",
    "heldagligares": "heldaglig",
    "heldagligas": "heldaglig",
    "heldagligast": "heldaglig",
    "heldagligaste": "heldaglig",
    "heldagligastes": "heldaglig",
    "heldagligasts": "heldaglig",
    "heldaglige": "heldaglig",
    "heldagliges": "heldaglig",
    "heldagligs": "heldaglig",
    "heldagligt": "heldaglig",
    "heldagligts": "heldaglig",
    "heldags": "heldag",
    "heldragens": "heldragen",
    "heldraget": "heldragen",
    "heldragets": "heldragen",
    "heldragna": "heldragen",
    "heldragnare": "heldragen",
    "heldragnares": "heldragen",
    "heldragnas": "heldragen",
    "heldragnast": "heldragen",
    "heldragnaste": "heldragen",
    "heldragnastes": "heldragen",
    "heldragnasts": "heldragen",
    "heldragne": "heldragen",
    "heldragnes": "heldragen",
    "heldäckade": "heldäckad",
    "heldäckades": "heldäckad",
    "heldäckads": "heldäckad",
    "heldäckat": "heldäckad",
    "heldäckats": "heldäckad",
    "hele": "hela",
    "heles": "hel",
    "helfabrikaten": "helfabrikat",
    "helfabrikatens": "helfabrikat",
    "helfabrikatet": "helfabrikat",
    "helfabrikatets": "helfabrikat",
    "helfabrikats": "helfabrikat",
    "helfeta": "helfet",
    "helfetare": "helfet",
    "helfetares": "helfet",
    "helfetas": "helfet",
    "helfetast": "helfet",
    "helfetaste": "helfet",
    "helfetastes": "helfet",
    "helfetasts": "helfet",
    "helfete": "helfet",
    "helfetes": "helfet",
    "helfets": "helfet",
    "helfett": "helfet",
    "helfetts": "helfet",
    "helfiguren": "helfigur",
    "helfigurens": "helfigur",
    "helfigurer": "helfigur",
    "helfigurerna": "helfigur",
    "helfigurernas": "helfigur",
    "helfigurers": "helfigur",
    "helfigurs": "helfigur",
    "helfranska": "helfransk",
    "helfranskare": "helfransk",
    "helfranskares": "helfransk",
    "helfranskas": "helfransk",
    "helfranskast": "helfransk",
    "helfranskaste": "helfransk",
    "helfranskastes": "helfransk",
    "helfranskasts": "helfransk",
    "helfranske": "helfransk",
    "helfranskes": "helfransk",
    "helfransks": "helfransk",
    "helfranskt": "helfransk",
    "helfranskts": "helfransk",
    "helförlamade": "helförlamad",
    "helförlamades": "helförlamad",
    "helförlamads": "helförlamad",
    "helförlamat": "helförlamad",
    "helförlamats": "helförlamad",
    "helförsäkrad": "helförsäkra",
    "helförsäkrade": "helförsäkra",
    "helförsäkrades": "helförsäkra",
    "helförsäkrads": "helförsäkra",
    "helförsäkrande": "helförsäkra",
    "helförsäkranden": "helförsäkrande",
    "helförsäkrandena": "helförsäkrande",
    "helförsäkrandenas": "helförsäkrande",
    "helförsäkrandens": "helförsäkrande",
    "helförsäkrandes": "helförsäkrande",
    "helförsäkrandet": "helförsäkrande",
    "helförsäkrandets": "helförsäkrande",
    "helförsäkrar": "helförsäkra",
    "helförsäkras": "helförsäkra",
    "helförsäkrat": "helförsäkra",
    "helförsäkrats": "helförsäkra",
    "helförsäkringar": "helförsäkring",
    "helförsäkringarna": "helförsäkring",
    "helförsäkringarnas": "helförsäkring",
    "helförsäkringars": "helförsäkring",
    "helförsäkringen": "helförsäkring",
    "helförsäkringens": "helförsäkring",
    "helförsäkrings": "helförsäkring",
    "helg": "helga",
    "helgad": "helga",
    "helgade": "helga",
    "helgades": "helga",
    "helgads": "helga",
    "helgande": "helga",
    "helganden": "helgande",
    "helgandena": "helgande",
    "helgandenas": "helgande",
    "helgandens": "helgande",
    "helgandes": "helgande",
    "helgandet": "helgande",
    "helgandets": "helgande",
    "helgar": "helga",
    "helgarderad": "helgardera",
    "helgarderade": "helgardera",
    "helgarderades": "helgardera",
    "helgarderads": "helgardera",
    "helgarderande": "helgardera",
    "helgarderanden": "helgarderande",
    "helgarderandena": "helgarderande",
    "helgarderandenas": "helgarderande",
    "helgarderandens": "helgarderande",
    "helgarderandes": "helgarderande",
    "helgarderandet": "helgarderande",
    "helgarderandets": "helgarderande",
    "helgarderar": "helgardera",
    "helgarderas": "helgardera",
    "helgarderat": "helgardera",
    "helgarderats": "helgardera",
    "helgarderbara": "helgarderbar",
    "helgarderbarare": "helgarderbar",
    "helgarderbarares": "helgarderbar",
    "helgarderbaras": "helgarderbar",
    "helgarderbarast": "helgarderbar",
    "helgarderbaraste": "helgarderbar",
    "helgarderbarastes": "helgarderbar",
    "helgarderbarasts": "helgarderbar",
    "helgarderbare": "helgarderbar",
    "helgarderbares": "helgarderbar",
    "helgarderbarheten": "helgarderbarhet",
    "helgarderbarhetens": "helgarderbarhet",
    "helgarderbarhets": "helgarderbarhet",
    "helgarderbars": "helgarderbar",
    "helgarderbart": "helgarderbar",
    "helgarderbarts": "helgarderbar",
    "helgarderingar": "helgardering",
    "helgarderingarna": "helgardering",
    "helgarderingarnas": "helgardering",
    "helgarderingars": "helgardering",
    "helgarderingen": "helgardering",
    "helgarderingens": "helgardering",
    "helgarderings": "helgardering",
    "helgas": "helga",
    "helgat": "helga",
    "helgats": "helga",
    "helgdagar": "helgdag",
    "helgdagarna": "helgdag",
    "helgdagarnas": "helgdag",
    "helgdagars": "helgdag",
    "helgdagen": "helgdag",
    "helgdagens": "helgdag",
    "helgdags": "helgdag",
    "helgden": "helgd",
    "helgdens": "helgd",
    "helgds": "helgd",
    "helgedomar": "helgedom",
    "helgedomarna": "helgedom",
    "helgedomarnas": "helgedom",
    "helgedomars": "helgedom",
    "helgedomen": "helgedom",
    "helgedomens": "helgedom",
    "helgedoms": "helgedom",
    "helgeflundran": "helgeflundra",
    "helgeflundrans": "helgeflundra",
    "helgeflundras": "helgeflundra",
    "helgeflundre": "helgeflundra",
    "helgeflundror": "helgeflundra",
    "helgeflundrorna": "helgeflundra",
    "helgeflundrornas": "helgeflundra",
    "helgeflundrors": "helgeflundra",
    "helgelsen": "helgelse",
    "helgelsens": "helgelse",
    "helgelses": "helgelse",
    "helgen": "helg",
    "helgens": "helg",
    "helger": "helg",
    "helgerna": "helg",
    "helgernas": "helg",
    "helgers": "helg",
    "helgerånen": "helgerån",
    "helgerånens": "helgerån",
    "helgerånet": "helgerån",
    "helgerånets": "helgerån",
    "helgeråns": "helgerån",
    "helgfria": "helgfri",
    "helgfriare": "helgfri",
    "helgfriares": "helgfri",
    "helgfrias": "helgfri",
    "helgfriast": "helgfri",
    "helgfriaste": "helgfri",
    "helgfriastes": "helgfri",
    "helgfriasts": "helgfri",
    "helgfrie": "helgfri",
    "helgfries": "helgfri",
    "helgfris": "helgfri",
    "helgfritt": "helgfri",
    "helgfritts": "helgfri",
    "helgjutenheten": "helgjutenhet",
    "helgjutenhetens": "helgjutenhet",
    "helgjutenhets": "helgjutenhet",
    "helgjutens": "helgjuten",
    "helgjutet": "helgjuten",
    "helgjutets": "helgjuten",
    "helgjutna": "helgjuten",
    "helgjutnare": "helgjuten",
    "helgjutnares": "helgjuten",
    "helgjutnas": "helgjuten",
    "helgjutnast": "helgjuten",
    "helgjutnaste": "helgjuten",
    "helgjutnastes": "helgjuten",
    "helgjutnasts": "helgjuten",
    "helgjutne": "helgjuten",
    "helgjutnes": "helgjuten",
    "helgmålsringningar": "helgmålsringning",
    "helgmålsringningarna": "helgmålsringning",
    "helgmålsringningarnas": "helgmålsringning",
    "helgmålsringningars": "helgmålsringning",
    "helgmålsringningen": "helgmålsringning",
    "helgmålsringningens": "helgmålsringning",
    "helgmålsringnings": "helgmålsringning",
    "helgonen": "helgon",
    "helgonens": "helgon",
    "helgonet": "helgon",
    "helgonets": "helgon",
    "helgonförklarad": "helgonförklara",
    "helgonförklarade": "helgonförklara",
    "helgonförklarades": "helgonförklara",
    "helgonförklarads": "helgonförklara",
    "helgonförklarande": "helgonförklara",
    "helgonförklaranden": "helgonförklarande",
    "helgonförklarandena": "helgonförklarande",
    "helgonförklarandenas": "helgonförklarande",
    "helgonförklarandens": "helgonförklarande",
    "helgonförklarandes": "helgonförklarande",
    "helgonförklarandet": "helgonförklarande",
    "helgonförklarandets": "helgonförklarande",
    "helgonförklarar": "helgonförklara",
    "helgonförklaras": "helgonförklara",
    "helgonförklarat": "helgonförklara",
    "helgonförklarats": "helgonförklara",
    "helgonglori": "helgongloria",
    "helgonglorian": "helgongloria",
    "helgonglorians": "helgongloria",
    "helgonglorias": "helgongloria",
    "helgonglorie": "helgongloria",
    "helgonglorior": "helgongloria",
    "helgongloriorna": "helgongloria",
    "helgongloriornas": "helgongloria",
    "helgongloriors": "helgongloria",
    "helgongloris": "helgongloria",
    "helgonlegenden": "helgonlegend",
    "helgonlegendens": "helgonlegend",
    "helgonlegender": "helgonlegend",
    "helgonlegenderna": "helgonlegend",
    "helgonlegendernas": "helgonlegend",
    "helgonlegenders": "helgonlegend",
    "helgonlegends": "helgonlegend",
    "helgons": "helgon",
    "helgs": "helg",
    "helgsmåls": "helgsmål",
    "helheten": "helhet",
    "helhetens": "helhet",
    "helheter": "helhet",
    "helheterna": "helhet",
    "helheternas": "helhet",
    "helheters": "helhet",
    "helhets": "helhet",
    "helhetsbilden": "helhetsbild",
    "helhetsbildens": "helhetsbild",
    "helhetsbilder": "helhetsbild",
    "helhetsbilderna": "helhetsbild",
    "helhetsbildernas": "helhetsbild",
    "helhetsbilders": "helhetsbild",
    "helhetsbilds": "helhetsbild",
    "helhetsintrycken": "helhetsintryck",
    "helhetsintryckens": "helhetsintryck",
    "helhetsintrycket": "helhetsintryck",
    "helhetsintryckets": "helhetsintryck",
    "helhetsintrycks": "helhetsintryck",
    "helhetssynen": "helhetssyn",
    "helhetssynens": "helhetssyn",
    "helhetssyner": "helhetssyn",
    "helhetssynerna": "helhetssyn",
    "helhetssynernas": "helhetssyn",
    "helhetssyners": "helhetssyn",
    "helhetssyns": "helhetssyn",
    "helhjärtade": "helhjärtad",
    "helhjärtades": "helhjärtad",
    "helhjärtads": "helhjärtad",
    "helhjärtat": "helhjärtad",
    "helhjärtats": "helhjärtad",
    "helicobacters": "helicobacter",
    "helicobakters": "helicobakter",
    "heliet": "helium",
    "heliets": "helium",
    "heliga": "helig",
    "heligare": "helig",
    "heligares": "helig",
    "heligas": "helig",
    "heligast": "helig",
    "heligaste": "helig",
    "heligastes": "helig",
    "heligasts": "helig",
    "helige": "helig",
    "heliges": "helig",
    "heligheten": "helighet",
    "helighetens": "helighet",
    "heligheter": "helighet",
    "heligheterna": "helighet",
    "heligheternas": "helighet",
    "heligheters": "helighet",
    "helighets": "helighet",
    "heligs": "helig",
    "heligt": "helig",
    "heligts": "helig",
    "helikobacters": "helikobacter",
    "helikobakters": "helikobakter",
    "helikonen": "helikon",
    "helikonens": "helikon",
    "helikonet": "helikon",
    "helikonets": "helikon",
    "helikons": "helikon",
    "helikopterförar": "helikopterförare",
    "helikopterföraren": "helikopterförare",
    "helikopterförarens": "helikopterförare",
    "helikopterförares": "helikopterförare",
    "helikopterförarna": "helikopterförare",
    "helikopterförarnas": "helikopterförare",
    "helikopterkraschen": "helikopterkrasch",
    "helikopterkraschens": "helikopterkrasch",
    "helikopterkrascher": "helikopterkrasch",
    "helikopterkrascherna": "helikopterkrasch",
    "helikopterkraschernas": "helikopterkrasch",
    "helikopterkraschers": "helikopterkrasch",
    "helikopterkraschs": "helikopterkrasch",
    "helikoptern": "helikopter",
    "helikopterns": "helikopter",
    "helikopterpiloten": "helikopterpilot",
    "helikopterpilotens": "helikopterpilot",
    "helikopterpiloter": "helikopterpilot",
    "helikopterpiloterna": "helikopterpilot",
    "helikopterpiloternas": "helikopterpilot",
    "helikopterpiloters": "helikopterpilot",
    "helikopterpilots": "helikopterpilot",
    "helikopterplatt": "helikopterplatta",
    "helikopterplattan": "helikopterplatta",
    "helikopterplattans": "helikopterplatta",
    "helikopterplattas": "helikopterplatta",
    "helikopterplatte": "helikopterplatta",
    "helikopterplattor": "helikopterplatta",
    "helikopterplattorna": "helikopterplatta",
    "helikopterplattornas": "helikopterplatta",
    "helikopterplattors": "helikopterplatta",
    "helikopterplatts": "helikopterplatta",
    "helikopterrånen": "helikopterrån",
    "helikopterrånens": "helikopterrån",
    "helikopterrånet": "helikopterrån",
    "helikopterrånets": "helikopterrån",
    "helikopterråns": "helikopterrån",
    "helikopters": "helikopter",
    "helikoptrar": "helikopter",
    "helikoptrarna": "helikopter",
    "helikoptrarnas": "helikopter",
    "helikoptrars": "helikopter",
    "helinackorderad": "helinackordera",
    "helinackorderade": "helinackordera",
    "helinackorderades": "helinackordera",
    "helinackorderads": "helinackordera",
    "helinackorderande": "helinackordera",
    "helinackorderanden": "helinackorderande",
    "helinackorderandena": "helinackorderande",
    "helinackorderandenas": "helinackorderande",
    "helinackorderandens": "helinackorderande",
    "helinackorderandes": "helinackorderande",
    "helinackorderandet": "helinackorderande",
    "helinackorderandets": "helinackorderande",
    "helinackorderar": "helinackordera",
    "helinackorderas": "helinackordera",
    "helinackorderat": "helinackordera",
    "helinackorderats": "helinackordera",
    "helinackorderbara": "helinackorderbar",
    "helinackorderbarare": "helinackorderbar",
    "helinackorderbarares": "helinackorderbar",
    "helinackorderbaras": "helinackorderbar",
    "helinackorderbarast": "helinackorderbar",
    "helinackorderbaraste": "helinackorderbar",
    "helinackorderbarastes": "helinackorderbar",
    "helinackorderbarasts": "helinackorderbar",
    "helinackorderbare": "helinackorderbar",
    "helinackorderbares": "helinackorderbar",
    "helinackorderbarheten": "helinackorderbarhet",
    "helinackorderbarhetens": "helinackorderbarhet",
    "helinackorderbarhets": "helinackorderbarhet",
    "helinackorderbars": "helinackorderbar",
    "helinackorderbart": "helinackorderbar",
    "helinackorderbarts": "helinackorderbar",
    "helinackorderingar": "helinackordering",
    "helinackorderingarna": "helinackordering",
    "helinackorderingarnas": "helinackordering",
    "helinackorderingars": "helinackordering",
    "helinackorderingen": "helinackordering",
    "helinackorderingens": "helinackordering",
    "helinackorderings": "helinackordering",
    "heliocentriska": "heliocentrisk",
    "heliocentriskare": "heliocentrisk",
    "heliocentriskares": "heliocentrisk",
    "heliocentriskas": "heliocentrisk",
    "heliocentriskast": "heliocentrisk",
    "heliocentriskaste": "heliocentrisk",
    "heliocentriskastes": "heliocentrisk",
    "heliocentriskasts": "heliocentrisk",
    "heliocentriske": "heliocentrisk",
    "heliocentriskes": "heliocentrisk",
    "heliocentrisks": "heliocentrisk",
    "heliocentriskt": "heliocentrisk",
    "heliocentriskts": "heliocentrisk",
    "heliofoba": "heliofob",
    "heliofobare": "heliofob",
    "heliofobares": "heliofob",
    "heliofobas": "heliofob",
    "heliofobast": "heliofob",
    "heliofobaste": "heliofob",
    "heliofobastes": "heliofob",
    "heliofobasts": "heliofob",
    "heliofobe": "heliofob",
    "heliofobes": "heliofob",
    "heliofobs": "heliofob",
    "heliofobt": "heliofob",
    "heliofobts": "heliofob",
    "heliografen": "heliograf",
    "heliografens": "heliograf",
    "heliografer": "heliograf",
    "heliograferna": "heliograf",
    "heliografernas": "heliograf",
    "heliografers": "heliograf",
    "heliografs": "heliograf",
    "heliostaten": "heliostat",
    "heliostatens": "heliostat",
    "heliostater": "heliostat",
    "heliostaterna": "heliostat",
    "heliostaternas": "heliostat",
    "heliostaters": "heliostat",
    "heliostats": "heliostat",
    "heliotropen": "heliotrop",
    "heliotropens": "heliotrop",
    "heliotroper": "heliotrop",
    "heliotroperna": "heliotrop",
    "heliotropernas": "heliotrop",
    "heliotropers": "heliotrop",
    "heliotrops": "heliotrop",
    "heliumet": "helium",
    "heliumets": "helium",
    "heliumfyllde": "heliumfylld",
    "heliumfylldes": "heliumfylld",
    "heliumfyllds": "heliumfylld",
    "heliumfyllt": "heliumfylld",
    "heliumfyllts": "heliumfylld",
    "heliums": "helium",
    "helkaklade": "helkaklad",
    "helkaklades": "helkaklad",
    "helkaklads": "helkaklad",
    "helkaklat": "helkaklad",
    "helkaklats": "helkaklad",
    "helkonserven": "helkonserv",
    "helkonservens": "helkonserv",
    "helkonserver": "helkonserv",
    "helkonserverna": "helkonserv",
    "helkonservernas": "helkonserv",
    "helkonservers": "helkonserv",
    "helkonservs": "helkonserv",
    "helkroppsdosen": "helkroppsdos",
    "helkroppsdosens": "helkroppsdos",
    "helkroppsdoser": "helkroppsdos",
    "helkroppsdoserna": "helkroppsdos",
    "helkroppsdosernas": "helkroppsdos",
    "helkroppsdosers": "helkroppsdos",
    "helkvällar": "helkväll",
    "helkvällarna": "helkväll",
    "helkvällarnas": "helkväll",
    "helkvällars": "helkväll",
    "helkvällen": "helkväll",
    "helkvällens": "helkväll",
    "helkvälls": "helkväll",
    "hellenen": "hellen",
    "hellenens": "hellen",
    "hellener": "hellen",
    "hellenerna": "hellen",
    "hellenernas": "hellen",
    "helleners": "hellen",
    "hellenismen": "hellenism",
    "hellenismens": "hellenism",
    "hellenismer": "hellenism",
    "hellenismerna": "hellenism",
    "hellenismernas": "hellenism",
    "hellenismers": "hellenism",
    "hellenisms": "hellenism",
    "hellenistiska": "hellenistisk",
    "hellenistiskare": "hellenistisk",
    "hellenistiskares": "hellenistisk",
    "hellenistiskas": "hellenistisk",
    "hellenistiskast": "hellenistisk",
    "hellenistiskaste": "hellenistisk",
    "hellenistiskastes": "hellenistisk",
    "hellenistiskasts": "hellenistisk",
    "hellenistiske": "hellenistisk",
    "hellenistiskes": "hellenistisk",
    "hellenistisks": "hellenistisk",
    "hellenistiskt": "hellenistisk",
    "hellenistiskts": "hellenistisk",
    "hellens": "hellen",
    "hellenska": "hellensk",
    "hellenskare": "hellensk",
    "hellenskares": "hellensk",
    "hellenskas": "hellensk",
    "hellenskast": "hellensk",
    "hellenskaste": "hellensk",
    "hellenskastes": "hellensk",
    "hellenskasts": "hellensk",
    "hellenske": "hellensk",
    "hellenskes": "hellensk",
    "hellensks": "hellensk",
    "hellenskt": "hellensk",
    "hellenskts": "hellensk",
    "helljusen": "helljus",
    "helljusens": "helljus",
    "helljuset": "helljus",
    "helljusets": "helljus",
    "hellre": "gärna",
    "helnoten": "helnot",
    "helnotens": "helnot",
    "helnoter": "helnot",
    "helnoterna": "helnot",
    "helnoternas": "helnot",
    "helnoters": "helnot",
    "helnots": "helnot",
    "helnykterheten": "helnykterhet",
    "helnykterhetens": "helnykterhet",
    "helnykterhets": "helnykterhet",
    "helnykters": "helnykter",
    "helnyktert": "helnykter",
    "helnykterts": "helnykter",
    "helnyktra": "helnykter",
    "helnyktrare": "helnykter",
    "helnyktrares": "helnykter",
    "helnyktras": "helnykter",
    "helnyktrast": "helnykter",
    "helnyktraste": "helnykter",
    "helnyktrastes": "helnykter",
    "helnyktrasts": "helnykter",
    "helnyktre": "helnykter",
    "helnyktres": "helnykter",
    "helomvändningar": "helomvändning",
    "helomvändningarna": "helomvändning",
    "helomvändningarnas": "helomvändning",
    "helomvändningars": "helomvändning",
    "helomvändningen": "helomvändning",
    "helomvändningens": "helomvändning",
    "helomvändnings": "helomvändning",
    "helor": "hela",
    "helorna": "hela",
    "helornas": "hela",
    "helors": "hela",
    "helpensionen": "helpension",
    "helpensionens": "helpension",
    "helpensioner": "helpension",
    "helpensionerna": "helpension",
    "helpensionernas": "helpension",
    "helpensioners": "helpension",
    "helpensions": "helpension",
    "helröda": "helröd",
    "helrödare": "helröd",
    "helrödares": "helröd",
    "helrödas": "helröd",
    "helrödast": "helröd",
    "helrödaste": "helröd",
    "helrödastes": "helröd",
    "helrödasts": "helröd",
    "helröde": "helröd",
    "helrödes": "helröd",
    "helröds": "helröd",
    "helrött": "helröd",
    "helrötts": "helröd",
    "hels": "hela",
    "helsidan": "helsida",
    "helsidans": "helsida",
    "helsidas": "helsida",
    "helside": "helsida",
    "helsides": "helsida",
    "helsidesannonsen": "helsidesannons",
    "helsidesannonsens": "helsidesannons",
    "helsidesannonser": "helsidesannons",
    "helsidesannonserna": "helsidesannons",
    "helsidesannonsernas": "helsidesannons",
    "helsidesannonsers": "helsidesannons",
    "helsidor": "helsida",
    "helsidorna": "helsida",
    "helsidornas": "helsida",
    "helsidors": "helsida",
    "helsiken": "helsike",
    "helsikena": "helsike",
    "helsikenas": "helsike",
    "helsikens": "helsike",
    "helsikes": "helsike",
    "helsiket": "helsike",
    "helsikets": "helsike",
    "helsiks": "helsike",
    "helskinnade": "helskinnad",
    "helskinnades": "helskinnad",
    "helskinnads": "helskinnad",
    "helskinnat": "helskinnad",
    "helskinnats": "helskinnad",
    "helskottas": "helskotta",
    "helskäggen": "helskägg",
    "helskäggens": "helskägg",
    "helskägget": "helskägg",
    "helskäggets": "helskägg",
    "helskäggs": "helskägg",
    "helskäggsluffar": "helskäggsluffare",
    "helskäggsluffaren": "helskäggsluffare",
    "helskäggsluffarens": "helskäggsluffare",
    "helskäggsluffares": "helskäggsluffare",
    "helskäggsluffarna": "helskäggsluffare",
    "helskäggsluffarnas": "helskäggsluffare",
    "helst": "gärna",
    "helstatliga": "helstatlig",
    "helstatligas": "helstatlig",
    "helstatlige": "helstatlig",
    "helstatliges": "helstatlig",
    "helstatligheten": "helstatlighet",
    "helstatlighetens": "helstatlighet",
    "helstatlighets": "helstatlighet",
    "helstatligs": "helstatlig",
    "helstatligt": "helstatlig",
    "helstatligts": "helstatlig",
    "helstekta": "helstekt",
    "helstektare": "helstekt",
    "helstektares": "helstekt",
    "helstektas": "helstekt",
    "helstektast": "helstekt",
    "helstektaste": "helstekt",
    "helstektastes": "helstekt",
    "helstektasts": "helstekt",
    "helstekte": "helstekt",
    "helstektes": "helstekt",
    "helstekts": "helstekt",
    "helsvetsade": "helsvetsad",
    "helsvetsades": "helsvetsad",
    "helsvetsads": "helsvetsad",
    "helsvetsat": "helsvetsad",
    "helsvetsats": "helsvetsad",
    "helsyskonen": "helsyskon",
    "helsyskonens": "helsyskon",
    "helsyskonet": "helsyskon",
    "helsyskonets": "helsyskon",
    "helsyskons": "helsyskon",
    "helt": "hel",
    "heltalen": "heltal",
    "heltalens": "heltal",
    "heltalet": "heltal",
    "heltalets": "heltal",
    "heltals": "heltal",
    "heltiden": "heltid",
    "heltidens": "heltid",
    "heltider": "heltid",
    "heltiderna": "heltid",
    "heltidernas": "heltid",
    "heltiders": "heltid",
    "heltids": "heltid",
    "heltidsanställde": "heltidsanställd",
    "heltidsanställdes": "heltidsanställd",
    "heltidsanställds": "heltidsanställd",
    "heltidsanställt": "heltidsanställd",
    "heltidsanställts": "heltidsanställd",
    "heltidsjobben": "heltidsjobb",
    "heltidsjobbens": "heltidsjobb",
    "heltidsjobbet": "heltidsjobb",
    "heltidsjobbets": "heltidsjobb",
    "heltidsjobbs": "heltidsjobb",
    "heltidslönen": "heltidslön",
    "heltidslönens": "heltidslön",
    "heltidslöner": "heltidslön",
    "heltidslönerna": "heltidslön",
    "heltidslönernas": "heltidslön",
    "heltidslöners": "heltidslön",
    "heltidslöns": "heltidslön",
    "heltonen": "helton",
    "heltonens": "helton",
    "heltoner": "helton",
    "heltonerna": "helton",
    "heltonernas": "helton",
    "heltoners": "helton",
    "heltons": "helton",
    "helts": "hel",
    "heltäckningsmatt": "heltäckningsmatta",
    "heltäckningsmattan": "heltäckningsmatta",
    "heltäckningsmattans": "heltäckningsmatta",
    "heltäckningsmattas": "heltäckningsmatta",
    "heltäckningsmatte": "heltäckningsmatta",
    "heltäckningsmattor": "heltäckningsmatta",
    "heltäckningsmattorna": "heltäckningsmatta",
    "heltäckningsmattornas": "heltäckningsmatta",
    "heltäckningsmattors": "heltäckningsmatta",
    "heltäckningsmatts": "heltäckningsmatta",
    "helveten": "helvete",
    "helvetena": "helvete",
    "helvetenas": "helvete",
    "helvetens": "helvete",
    "helvetes": "helvete",
    "helvetesmaskinen": "helvetesmaskin",
    "helvetesmaskinens": "helvetesmaskin",
    "helvetesmaskiner": "helvetesmaskin",
    "helvetesmaskinerna": "helvetesmaskin",
    "helvetesmaskinernas": "helvetesmaskin",
    "helvetesmaskiners": "helvetesmaskin",
    "helvetesmaskins": "helvetesmaskin",
    "helvetet": "helvete",
    "helvetets": "helvete",
    "helvetiska": "helvetisk",
    "helvetiskare": "helvetisk",
    "helvetiskares": "helvetisk",
    "helvetiskas": "helvetisk",
    "helvetiskast": "helvetisk",
    "helvetiskaste": "helvetisk",
    "helvetiskastes": "helvetisk",
    "helvetiskasts": "helvetisk",
    "helvetiske": "helvetisk",
    "helvetiskes": "helvetisk",
    "helvetisks": "helvetisk",
    "helvetiskt": "helvetisk",
    "helvetiskts": "helvetisk",
    "helylles": "helylle",
    "helyllet": "helylle",
    "helyllets": "helylle",
    "helåkersbygden": "helåkersbygd",
    "helåkersbygdens": "helåkersbygd",
    "helåkersbygder": "helåkersbygd",
    "helåkersbygderna": "helåkersbygd",
    "helåkersbygdernas": "helåkersbygd",
    "helåkersbygders": "helåkersbygd",
    "helåkersbygds": "helåkersbygd",
    "helåret": "helår",
    "helårets": "helår",
    "helårs": "helår",
    "hemarbeten": "hemarbete",
    "hemarbetena": "hemarbete",
    "hemarbetenas": "hemarbete",
    "hemarbetens": "hemarbete",
    "hemarbetes": "hemarbete",
    "hemarbetet": "hemarbete",
    "hemarbetets": "hemarbete",
    "hemarbets": "hemarbete",
    "hematiten": "hematit",
    "hematitens": "hematit",
    "hematiter": "hematit",
    "hematiterna": "hematit",
    "hematiternas": "hematit",
    "hematiters": "hematit",
    "hematits": "hematit",
    "hematologien": "hematologi",
    "hematologiens": "hematologi",
    "hematologin": "hematologi",
    "hematologins": "hematologi",
    "hematologis": "hematologi",
    "hembagerier": "hembageri",
    "hembagerierna": "hembageri",
    "hembageriernas": "hembageri",
    "hembageriers": "hembageri",
    "hembageriet": "hembageri",
    "hembageriets": "hembageri",
    "hembageris": "hembageri",
    "hembagerit": "hembageri",
    "hembagerits": "hembageri",
    "hembakade": "hembakad",
    "hembakades": "hembakad",
    "hembakads": "hembakad",
    "hembakat": "hembakad",
    "hembakats": "hembakad",
    "hembakta": "hembakt",
    "hembaktare": "hembakt",
    "hembaktares": "hembakt",
    "hembaktas": "hembakt",
    "hembaktast": "hembakt",
    "hembaktaste": "hembakt",
    "hembaktastes": "hembakt",
    "hembaktasts": "hembakt",
    "hembakte": "hembakt",
    "hembaktes": "hembakt",
    "hembakts": "hembakt",
    "hembar": "hembära",
    "hembars": "hembära",
    "hembesöken": "hembesök",
    "hembesökens": "hembesök",
    "hembesöket": "hembesök",
    "hembesökets": "hembesök",
    "hembesöks": "hembesök",
    "hembiträden": "hembiträde",
    "hembiträdena": "hembiträde",
    "hembiträdenas": "hembiträde",
    "hembiträdens": "hembiträde",
    "hembiträdes": "hembiträde",
    "hembiträdet": "hembiträde",
    "hembiträdets": "hembiträde",
    "hembjud": "hembjuda",
    "hembjudande": "hembjuda",
    "hembjudanden": "hembjudande",
    "hembjudandena": "hembjudande",
    "hembjudandenas": "hembjudande",
    "hembjudandens": "hembjudande",
    "hembjudandes": "hembjudande",
    "hembjudandet": "hembjudande",
    "hembjudandets": "hembjudande",
    "hembjudas": "hembjuda",
    "hembjude": "hembjuda",
    "hembjuden": "hembjuda",
    "hembjudens": "hembjuda",
    "hembjuder": "hembjuda",
    "hembjudes": "hembjuda",
    "hembjudet": "hembjuda",
    "hembjudets": "hembjuda",
    "hembjudit": "hembjuda",
    "hembjudits": "hembjuda",
    "hembjudna": "hembjuda",
    "hembjudnas": "hembjuda",
    "hembjudne": "hembjuda",
    "hembjudnes": "hembjuda",
    "hembjuds": "hembjuda",
    "hembjöd": "hembjuda",
    "hembjöde": "hembjuda",
    "hembjödes": "hembjuda",
    "hembjöds": "hembjuda",
    "hembryggde": "hembryggd",
    "hembryggdes": "hembryggd",
    "hembryggds": "hembryggd",
    "hembryggningen": "hembryggning",
    "hembryggningens": "hembryggning",
    "hembryggnings": "hembryggning",
    "hembryggt": "hembryggd",
    "hembryggts": "hembryggd",
    "hembrände": "hembränd",
    "hembrändes": "hembränd",
    "hembränds": "hembränd",
    "hembrännar": "hembrännare",
    "hembrännaren": "hembrännare",
    "hembrännarens": "hembrännare",
    "hembrännares": "hembrännare",
    "hembrännarna": "hembrännare",
    "hembrännarnas": "hembrännare",
    "hembränningar": "hembränning",
    "hembränningarna": "hembränning",
    "hembränningarnas": "hembränning",
    "hembränningars": "hembränning",
    "hembränningen": "hembränning",
    "hembränningens": "hembränning",
    "hembrännings": "hembränning",
    "hembränt": "hembränd",
    "hembränts": "hembränd",
    "hembuden": "hembud",
    "hembudens": "hembud",
    "hembudet": "hembud",
    "hembudets": "hembud",
    "hembuds": "hembud",
    "hembure": "hembära",
    "hemburen": "hembära",
    "hemburens": "hembära",
    "hembures": "hembära",
    "hemburet": "hembära",
    "hemburets": "hembära",
    "hemburit": "hembära",
    "hemburits": "hembära",
    "hemburna": "hembära",
    "hemburnas": "hembära",
    "hemburne": "hembära",
    "hemburnes": "hembära",
    "hembygden": "hembygd",
    "hembygdens": "hembygd",
    "hembygder": "hembygd",
    "hembygderna": "hembygd",
    "hembygdernas": "hembygd",
    "hembygders": "hembygd",
    "hembygds": "hembygd",
    "hembygdsföreningar": "hembygdsförening",
    "hembygdsföreningarna": "hembygdsförening",
    "hembygdsföreningarnas": "hembygdsförening",
    "hembygdsföreningars": "hembygdsförening",
    "hembygdsföreningen": "hembygdsförening",
    "hembygdsföreningens": "hembygdsförening",
    "hembygdsförenings": "hembygdsförening",
    "hembygdsgårdar": "hembygdsgård",
    "hembygdsgårdarna": "hembygdsgård",
    "hembygdsgårdarnas": "hembygdsgård",
    "hembygdsgårdars": "hembygdsgård",
    "hembygdsgården": "hembygdsgård",
    "hembygdsgårdens": "hembygdsgård",
    "hembygdsgårds": "hembygdsgård",
    "hembygdsromantiken": "hembygdsromantik",
    "hembygdsromantikens": "hembygdsromantik",
    "hembygdsromantiks": "hembygdsromantik",
    "hembär": "hembära",
    "hembärande": "hembära",
    "hembäranden": "hembärande",
    "hembärandena": "hembärande",
    "hembärandenas": "hembärande",
    "hembärandens": "hembärande",
    "hembärandes": "hembärande",
    "hembärandet": "hembärande",
    "hembärandets": "hembärande",
    "hembäras": "hembära",
    "hembäre": "hembära",
    "hembäres": "hembära",
    "hembärs": "hembära",
    "hemdatorer": "hemdator",
    "hemdatorerna": "hemdator",
    "hemdatorernas": "hemdator",
    "hemdatorers": "hemdator",
    "hemdatorn": "hemdator",
    "hemdatorns": "hemdator",
    "hemdators": "hemdator",
    "hemfall": "hemfalla",
    "hemfallande": "hemfalla",
    "hemfallanden": "hemfallande",
    "hemfallandena": "hemfallande",
    "hemfallandenas": "hemfallande",
    "hemfallandens": "hemfallande",
    "hemfallandes": "hemfallande",
    "hemfallandet": "hemfallande",
    "hemfallandets": "hemfallande",
    "hemfallas": "hemfalla",
    "hemfalle": "hemfalla",
    "hemfallen": "hemfalla",
    "hemfallens": "hemfalla",
    "hemfaller": "hemfalla",
    "hemfalles": "hemfalla",
    "hemfallet": "hemfalla",
    "hemfallets": "hemfalla",
    "hemfallit": "hemfalla",
    "hemfallits": "hemfalla",
    "hemfallna": "hemfalla",
    "hemfallnas": "hemfalla",
    "hemfallne": "hemfalla",
    "hemfallnes": "hemfalla",
    "hemfalls": "hemfalla",
    "hemfraktade": "hemfraktad",
    "hemfraktades": "hemfraktad",
    "hemfraktads": "hemfraktad",
    "hemfraktat": "hemfraktad",
    "hemfraktats": "hemfraktad",
    "hemfriden": "hemfrid",
    "hemfridens": "hemfrid",
    "hemfrids": "hemfrid",
    "hemfridsbrotten": "hemfridsbrott",
    "hemfridsbrottens": "hemfridsbrott",
    "hemfridsbrottet": "hemfridsbrott",
    "hemfridsbrottets": "hemfridsbrott",
    "hemfridsbrotts": "hemfridsbrott",
    "hemföll": "hemfalla",
    "hemfölle": "hemfalla",
    "hemfölles": "hemfalla",
    "hemfölls": "hemfalla",
    "hemför": "hemföra",
    "hemförande": "hemföra",
    "hemföranden": "hemförande",
    "hemförandena": "hemförande",
    "hemförandenas": "hemförande",
    "hemförandens": "hemförande",
    "hemförandes": "hemförande",
    "hemförandet": "hemförande",
    "hemförandets": "hemförande",
    "hemföras": "hemföra",
    "hemförd": "hemföra",
    "hemförda": "hemföra",
    "hemfördas": "hemföra",
    "hemförde": "hemföra",
    "hemfördes": "hemföra",
    "hemförds": "hemföra",
    "hemföres": "hemföra",
    "hemförlov": "hemförlova",
    "hemförlovad": "hemförlova",
    "hemförlovade": "hemförlova",
    "hemförlovades": "hemförlova",
    "hemförlovads": "hemförlova",
    "hemförlovande": "hemförlova",
    "hemförlovanden": "hemförlovande",
    "hemförlovandena": "hemförlovande",
    "hemförlovandenas": "hemförlovande",
    "hemförlovandens": "hemförlovande",
    "hemförlovandes": "hemförlovande",
    "hemförlovandet": "hemförlovande",
    "hemförlovandets": "hemförlovande",
    "hemförlovar": "hemförlova",
    "hemförlovas": "hemförlova",
    "hemförlovat": "hemförlova",
    "hemförlovats": "hemförlova",
    "hemförs": "hemföra",
    "hemförsäkringar": "hemförsäkring",
    "hemförsäkringarna": "hemförsäkring",
    "hemförsäkringarnas": "hemförsäkring",
    "hemförsäkringars": "hemförsäkring",
    "hemförsäkringen": "hemförsäkring",
    "hemförsäkringens": "hemförsäkring",
    "hemförsäkrings": "hemförsäkring",
    "hemförsäljningar": "hemförsäljning",
    "hemförsäljningarna": "hemförsäljning",
    "hemförsäljningarnas": "hemförsäljning",
    "hemförsäljningars": "hemförsäljning",
    "hemförsäljningen": "hemförsäljning",
    "hemförsäljningens": "hemförsäljning",
    "hemförsäljnings": "hemförsäljning",
    "hemfört": "hemföra",
    "hemförts": "hemföra",
    "hemgalaxen": "hemgalax",
    "hemgalaxens": "hemgalax",
    "hemgalaxer": "hemgalax",
    "hemgalaxerna": "hemgalax",
    "hemgalaxernas": "hemgalax",
    "hemgalaxers": "hemgalax",
    "hemgiften": "hemgift",
    "hemgiftens": "hemgift",
    "hemgifter": "hemgift",
    "hemgifterna": "hemgift",
    "hemgifternas": "hemgift",
    "hemgifters": "hemgift",
    "hemgifts": "hemgift",
    "hemgjorda": "hemgjord",
    "hemgjordare": "hemgjord",
    "hemgjordares": "hemgjord",
    "hemgjordas": "hemgjord",
    "hemgjordast": "hemgjord",
    "hemgjordaste": "hemgjord",
    "hemgjordastes": "hemgjord",
    "hemgjordasts": "hemgjord",
    "hemgjorde": "hemgjord",
    "hemgjordes": "hemgjord",
    "hemgjords": "hemgjord",
    "hemgjort": "hemgjord",
    "hemgjorts": "hemgjord",
    "hemgångar": "hemgång",
    "hemgångarna": "hemgång",
    "hemgångarnas": "hemgång",
    "hemgångars": "hemgång",
    "hemgången": "hemgång",
    "hemgångens": "hemgång",
    "hemgångs": "hemgång",
    "hemhjälpar": "hemhjälp",
    "hemhjälparna": "hemhjälp",
    "hemhjälparnas": "hemhjälp",
    "hemhjälpars": "hemhjälp",
    "hemhjälpen": "hemhjälp",
    "hemhjälpens": "hemhjälp",
    "hemhjälps": "hemhjälp",
    "hemhöriga": "hemhörig",
    "hemhörigare": "hemhörig",
    "hemhörigares": "hemhörig",
    "hemhörigas": "hemhörig",
    "hemhörigast": "hemhörig",
    "hemhörigaste": "hemhörig",
    "hemhörigastes": "hemhörig",
    "hemhörigasts": "hemhörig",
    "hemhörige": "hemhörig",
    "hemhöriges": "hemhörig",
    "hemhörigheten": "hemhörighet",
    "hemhörighetens": "hemhörighet",
    "hemhörigheter": "hemhörighet",
    "hemhörigheterna": "hemhörighet",
    "hemhörigheternas": "hemhörighet",
    "hemhörigheters": "hemhörighet",
    "hemhörighets": "hemhörighet",
    "hemhörigs": "hemhörig",
    "hemhörigt": "hemhörig",
    "hemhörigts": "hemhörig",
    "heminredningar": "heminredning",
    "heminredningarna": "heminredning",
    "heminredningarnas": "heminredning",
    "heminredningars": "heminredning",
    "heminredningen": "heminredning",
    "heminredningens": "heminredning",
    "heminrednings": "heminredning",
    "hemisfären": "hemisfär",
    "hemisfärens": "hemisfär",
    "hemisfärer": "hemisfär",
    "hemisfärerna": "hemisfär",
    "hemisfärernas": "hemisfär",
    "hemisfärers": "hemisfär",
    "hemisfärs": "hemisfär",
    "hemkall": "hemkalla",
    "hemkallad": "hemkalla",
    "hemkallade": "hemkalla",
    "hemkallades": "hemkalla",
    "hemkallads": "hemkalla",
    "hemkallande": "hemkalla",
    "hemkallanden": "hemkallande",
    "hemkallandena": "hemkallande",
    "hemkallandenas": "hemkallande",
    "hemkallandens": "hemkallande",
    "hemkallandes": "hemkallande",
    "hemkallandet": "hemkallande",
    "hemkallandets": "hemkallande",
    "hemkallar": "hemkalla",
    "hemkallas": "hemkalla",
    "hemkallat": "hemkalla",
    "hemkallats": "hemkalla",
    "hemkomsten": "hemkomst",
    "hemkomstens": "hemkomst",
    "hemkomsts": "hemkomst",
    "hemkonsulenten": "hemkonsulent",
    "hemkonsulentens": "hemkonsulent",
    "hemkonsulenter": "hemkonsulent",
    "hemkonsulenterna": "hemkonsulent",
    "hemkonsulenternas": "hemkonsulent",
    "hemkonsulenters": "hemkonsulent",
    "hemkonsulents": "hemkonsulent",
    "hemkryddade": "hemkryddad",
    "hemkryddades": "hemkryddad",
    "hemkryddads": "hemkryddad",
    "hemkryddat": "hemkryddad",
    "hemkryddats": "hemkryddad",
    "hemkunskapen": "hemkunskap",
    "hemkunskapens": "hemkunskap",
    "hemkunskaps": "hemkunskap",
    "hemkära": "hemkär",
    "hemkärare": "hemkär",
    "hemkärares": "hemkär",
    "hemkäras": "hemkär",
    "hemkärast": "hemkär",
    "hemkäraste": "hemkär",
    "hemkärastes": "hemkär",
    "hemkärasts": "hemkär",
    "hemkäre": "hemkär",
    "hemkäres": "hemkär",
    "hemkärnade": "hemkärnad",
    "hemkärnades": "hemkärnad",
    "hemkärnads": "hemkärnad",
    "hemkärnat": "hemkärnad",
    "hemkärnats": "hemkärnad",
    "hemkärs": "hemkär",
    "hemkärt": "hemkär",
    "hemkärts": "hemkär",
    "hemkörde": "hemkörd",
    "hemkördes": "hemkörd",
    "hemkörds": "hemkörd",
    "hemkört": "hemkörd",
    "hemkörts": "hemkörd",
    "hemlagade": "hemlagad",
    "hemlagades": "hemlagad",
    "hemlagads": "hemlagad",
    "hemlagat": "hemlagad",
    "hemlagats": "hemlagad",
    "hemlandet": "hemland",
    "hemlandets": "hemland",
    "hemlands": "hemland",
    "hemlandstonerna": "hemlandstoner",
    "hemlandstonernas": "hemlandstoner",
    "hemlandstoners": "hemlandstoner",
    "hemlandstons": "hemlandstoner",
    "hemliga": "hemlig",
    "hemligare": "hemlig",
    "hemligares": "hemlig",
    "hemligas": "hemlig",
    "hemligast": "hemlig",
    "hemligaste": "hemlig",
    "hemligastes": "hemlig",
    "hemligasts": "hemlig",
    "hemlige": "hemlig",
    "hemliges": "hemlig",
    "hemligheten": "hemlighet",
    "hemlighetens": "hemlighet",
    "hemligheter": "hemlighet",
    "hemligheterna": "hemlighet",
    "hemligheternas": "hemlighet",
    "hemligheters": "hemlighet",
    "hemlighets": "hemlighet",
    "hemlighetsfulla": "hemlighetsfull",
    "hemlighetsfullare": "hemlighetsfull",
    "hemlighetsfullares": "hemlighetsfull",
    "hemlighetsfullas": "hemlighetsfull",
    "hemlighetsfullast": "hemlighetsfull",
    "hemlighetsfullaste": "hemlighetsfull",
    "hemlighetsfullastes": "hemlighetsfull",
    "hemlighetsfullasts": "hemlighetsfull",
    "hemlighetsfulle": "hemlighetsfull",
    "hemlighetsfulles": "hemlighetsfull",
    "hemlighetsfullheten": "hemlighetsfullhet",
    "hemlighetsfullhetens": "hemlighetsfullhet",
    "hemlighetsfullhets": "hemlighetsfullhet",
    "hemlighetsfulls": "hemlighetsfull",
    "hemlighetsfullt": "hemlighetsfull",
    "hemlighetsfullts": "hemlighetsfull",
    "hemlighetsmakerier": "hemlighetsmakeri",
    "hemlighetsmakerierna": "hemlighetsmakeri",
    "hemlighetsmakeriernas": "hemlighetsmakeri",
    "hemlighetsmakeriers": "hemlighetsmakeri",
    "hemlighetsmakeriet": "hemlighetsmakeri",
    "hemlighetsmakeriets": "hemlighetsmakeri",
    "hemlighetsmakeris": "hemlighetsmakeri",
    "hemlighetsmakerit": "hemlighetsmakeri",
    "hemlighetsmakerits": "hemlighetsmakeri",
    "hemlighusen": "hemlighus",
    "hemlighusens": "hemlighus",
    "hemlighuset": "hemlighus",
    "hemlighusets": "hemlighus",
    "hemlighåll": "hemlighålla",
    "hemlighållande": "hemlighålla",
    "hemlighållanden": "hemlighållande",
    "hemlighållandena": "hemlighållande",
    "hemlighållandenas": "hemlighållande",
    "hemlighållandens": "hemlighållande",
    "hemlighållandes": "hemlighållande",
    "hemlighållandet": "hemlighållande",
    "hemlighållandets": "hemlighållande",
    "hemlighållas": "hemlighålla",
    "hemlighålle": "hemlighålla",
    "hemlighållen": "hemlighålla",
    "hemlighållens": "hemlighålla",
    "hemlighåller": "hemlighålla",
    "hemlighålles": "hemlighålla",
    "hemlighållet": "hemlighålla",
    "hemlighållets": "hemlighålla",
    "hemlighållit": "hemlighålla",
    "hemlighållits": "hemlighålla",
    "hemlighållna": "hemlighålla",
    "hemlighållnas": "hemlighålla",
    "hemlighållne": "hemlighålla",
    "hemlighållnes": "hemlighålla",
    "hemlighålls": "hemlighålla",
    "hemlighöll": "hemlighålla",
    "hemlighölle": "hemlighålla",
    "hemlighölles": "hemlighålla",
    "hemlighölls": "hemlighålla",
    "hemligs": "hemlig",
    "hemligstämpeln": "hemligstämpel",
    "hemligstämpelns": "hemligstämpel",
    "hemligstämpels": "hemligstämpel",
    "hemligstämplad": "hemligstämpla",
    "hemligstämplade": "hemligstämpla",
    "hemligstämplades": "hemligstämpla",
    "hemligstämplads": "hemligstämpla",
    "hemligstämplande": "hemligstämpla",
    "hemligstämplanden": "hemligstämplande",
    "hemligstämplandena": "hemligstämplande",
    "hemligstämplandenas": "hemligstämplande",
    "hemligstämplandens": "hemligstämplande",
    "hemligstämplandes": "hemligstämplande",
    "hemligstämplandet": "hemligstämplande",
    "hemligstämplandets": "hemligstämplande",
    "hemligstämplar": "hemligstämpla",
    "hemligstämplarna": "hemligstämpel",
    "hemligstämplarnas": "hemligstämpel",
    "hemligstämplars": "hemligstämpel",
    "hemligstämplas": "hemligstämpla",
    "hemligstämplat": "hemligstämpla",
    "hemligstämplats": "hemligstämpla",
    "hemligt": "hemlig",
    "hemligts": "hemlig",
    "hemlockar": "hemlock",
    "hemlockarna": "hemlock",
    "hemlockarnas": "hemlock",
    "hemlockars": "hemlock",
    "hemlocken": "hemlock",
    "hemlockens": "hemlock",
    "hemlocks": "hemlock",
    "hemländer": "hemland",
    "hemländerna": "hemland",
    "hemländernas": "hemland",
    "hemländers": "hemland",
    "hemlängtans": "hemlängtan",
    "hemläx": "hemläxa",
    "hemläxan": "hemläxa",
    "hemläxans": "hemläxa",
    "hemläxas": "hemläxa",
    "hemläxe": "hemläxa",
    "hemläxor": "hemläxa",
    "hemläxorna": "hemläxa",
    "hemläxornas": "hemläxa",
    "hemläxors": "hemläxa",
    "hemlånen": "hemlån",
    "hemlånens": "hemlån",
    "hemlånet": "hemlån",
    "hemlånets": "hemlån",
    "hemlåns": "hemlån",
    "hemlösa": "hemlös",
    "hemlösare": "hemlös",
    "hemlösares": "hemlös",
    "hemlösas": "hemlös",
    "hemlösast": "hemlös",
    "hemlösaste": "hemlös",
    "hemlösastes": "hemlös",
    "hemlösasts": "hemlös",
    "hemlöse": "hemlös",
    "hemlöses": "hemlös",
    "hemlösheten": "hemlöshet",
    "hemlöshetens": "hemlöshet",
    "hemlöshets": "hemlöshet",
    "hemlöst": "hemlös",
    "hemlösts": "hemlös",
    "hemmablinda": "hemmablind",
    "hemmablindare": "hemmablind",
    "hemmablindares": "hemmablind",
    "hemmablindas": "hemmablind",
    "hemmablindast": "hemmablind",
    "hemmablindaste": "hemmablind",
    "hemmablindastes": "hemmablind",
    "hemmablindasts": "hemmablind",
    "hemmablinde": "hemmablind",
    "hemmablindes": "hemmablind",
    "hemmablindheten": "hemmablindhet",
    "hemmablindhetens": "hemmablindhet",
    "hemmablindhets": "hemmablindhet",
    "hemmablinds": "hemmablind",
    "hemmablint": "hemmablind",
    "hemmablints": "hemmablind",
    "hemmabruket": "hemmabruk",
    "hemmabrukets": "hemmabruk",
    "hemmabruks": "hemmabruk",
    "hemmabyggde": "hemmabyggd",
    "hemmabyggdes": "hemmabyggd",
    "hemmabyggds": "hemmabyggd",
    "hemmabyggt": "hemmabyggd",
    "hemmabyggts": "hemmabyggd",
    "hemmadottern": "hemmadotter",
    "hemmadotterns": "hemmadotter",
    "hemmadotters": "hemmadotter",
    "hemmadöttrar": "hemmadotter",
    "hemmadöttrarna": "hemmadotter",
    "hemmadöttrarnas": "hemmadotter",
    "hemmadöttrars": "hemmadotter",
    "hemmafixar": "hemmafixare",
    "hemmafixaren": "hemmafixare",
    "hemmafixarens": "hemmafixare",
    "hemmafixares": "hemmafixare",
    "hemmafixarna": "hemmafixare",
    "hemmafixarnas": "hemmafixare",
    "hemmafronten": "hemmafront",
    "hemmafrontens": "hemmafront",
    "hemmafronts": "hemmafront",
    "hemmafruar": "hemmafru",
    "hemmafruarna": "hemmafru",
    "hemmafruarnas": "hemmafru",
    "hemmafruars": "hemmafru",
    "hemmafrun": "hemmafru",
    "hemmafruns": "hemmafru",
    "hemmafrus": "hemmafru",
    "hemmagjorda": "hemmagjord",
    "hemmagjordare": "hemmagjord",
    "hemmagjordares": "hemmagjord",
    "hemmagjordas": "hemmagjord",
    "hemmagjordast": "hemmagjord",
    "hemmagjordaste": "hemmagjord",
    "hemmagjordastes": "hemmagjord",
    "hemmagjordasts": "hemmagjord",
    "hemmagjorde": "hemmagjord",
    "hemmagjordes": "hemmagjord",
    "hemmagjords": "hemmagjord",
    "hemmagjort": "hemmagjord",
    "hemmagjorts": "hemmagjord",
    "hemmahöriga": "hemmahörig",
    "hemmahörigare": "hemmahörig",
    "hemmahörigares": "hemmahörig",
    "hemmahörigas": "hemmahörig",
    "hemmahörigast": "hemmahörig",
    "hemmahörigaste": "hemmahörig",
    "hemmahörigastes": "hemmahörig",
    "hemmahörigasts": "hemmahörig",
    "hemmahörige": "hemmahörig",
    "hemmahöriges": "hemmahörig",
    "hemmahörigheten": "hemmahörighet",
    "hemmahörighetens": "hemmahörighet",
    "hemmahörigheter": "hemmahörighet",
    "hemmahörigheterna": "hemmahörighet",
    "hemmahörigheternas": "hemmahörighet",
    "hemmahörigheters": "hemmahörighet",
    "hemmahörighets": "hemmahörighet",
    "hemmahörigs": "hemmahörig",
    "hemmahörigt": "hemmahörig",
    "hemmahörigts": "hemmahörig",
    "hemmakvällar": "hemmakväll",
    "hemmakvällarna": "hemmakväll",
    "hemmakvällarnas": "hemmakväll",
    "hemmakvällars": "hemmakväll",
    "hemmakvällen": "hemmakväll",
    "hemmakvällens": "hemmakväll",
    "hemmakvälls": "hemmakväll",
    "hemmalagen": "hemmalag",
    "hemmalagens": "hemmalag",
    "hemmalaget": "hemmalag",
    "hemmalagets": "hemmalag",
    "hemmalags": "hemmalag",
    "hemmamannen": "hemmaman",
    "hemmamannens": "hemmaman",
    "hemmamans": "hemmaman",
    "hemmamatchen": "hemmamatch",
    "hemmamatchens": "hemmamatch",
    "hemmamatcher": "hemmamatch",
    "hemmamatcherna": "hemmamatch",
    "hemmamatchernas": "hemmamatch",
    "hemmamatchers": "hemmamatch",
    "hemmamatchs": "hemmamatch",
    "hemmamän": "hemmaman",
    "hemmamännen": "hemmaman",
    "hemmamännens": "hemmaman",
    "hemmamäns": "hemmaman",
    "hemmanen": "hemman",
    "hemmanens": "hemman",
    "hemmanet": "hemman",
    "hemmanets": "hemman",
    "hemmans": "hemman",
    "hemmansägar": "hemmansägare",
    "hemmansägaren": "hemmansägare",
    "hemmansägarens": "hemmansägare",
    "hemmansägares": "hemmansägare",
    "hemmansägarna": "hemmansägare",
    "hemmansägarnas": "hemmansägare",
    "hemmaopinionen": "hemmaopinion",
    "hemmaopinionens": "hemmaopinion",
    "hemmaopinioner": "hemmaopinion",
    "hemmaopinionerna": "hemmaopinion",
    "hemmaopinionernas": "hemmaopinion",
    "hemmaopinioners": "hemmaopinion",
    "hemmaopinions": "hemmaopinion",
    "hemmaplanen": "hemmaplan",
    "hemmaplanens": "hemmaplan",
    "hemmaplaner": "hemmaplan",
    "hemmaplanerna": "hemmaplan",
    "hemmaplanernas": "hemmaplan",
    "hemmaplaners": "hemmaplan",
    "hemmaplans": "hemmaplan",
    "hemmarockar": "hemmarock",
    "hemmarockarna": "hemmarock",
    "hemmarockarnas": "hemmarock",
    "hemmarockars": "hemmarock",
    "hemmarocken": "hemmarock",
    "hemmarockens": "hemmarock",
    "hemmarocks": "hemmarock",
    "hemmasegern": "hemmaseger",
    "hemmasegerns": "hemmaseger",
    "hemmasegers": "hemmaseger",
    "hemmasegrar": "hemmaseger",
    "hemmasegrarna": "hemmaseger",
    "hemmasegrarnas": "hemmaseger",
    "hemmasegrars": "hemmaseger",
    "hemmastadda": "hemmastadd",
    "hemmastaddare": "hemmastadd",
    "hemmastaddares": "hemmastadd",
    "hemmastaddas": "hemmastadd",
    "hemmastaddast": "hemmastadd",
    "hemmastaddaste": "hemmastadd",
    "hemmastaddastes": "hemmastadd",
    "hemmastaddasts": "hemmastadd",
    "hemmastadde": "hemmastadd",
    "hemmastaddes": "hemmastadd",
    "hemmastaddheten": "hemmastaddhet",
    "hemmastaddhetens": "hemmastaddhet",
    "hemmastaddhets": "hemmastaddhet",
    "hemmastadds": "hemmastadd",
    "hemmastatt": "hemmastadd",
    "hemmastatts": "hemmastadd",
    "hemmen": "hem",
    "hemmens": "hem",
    "hemmet": "hem",
    "hemmets": "hem",
    "hemmiljöer": "hemmiljö",
    "hemmiljöerna": "hemmiljö",
    "hemmiljöernas": "hemmiljö",
    "hemmiljöers": "hemmiljö",
    "hemmiljön": "hemmiljö",
    "hemmiljöns": "hemmiljö",
    "hemmiljös": "hemmiljö",
    "hemoglobinen": "hemoglobin",
    "hemoglobinens": "hemoglobin",
    "hemoglobiner": "hemoglobin",
    "hemoglobinerna": "hemoglobin",
    "hemoglobinernas": "hemoglobin",
    "hemoglobiners": "hemoglobin",
    "hemoglobinet": "hemoglobin",
    "hemoglobinets": "hemoglobin",
    "hemoglobins": "hemoglobin",
    "hemorrojd": "hemorrojder",
    "hemorrojderna": "hemorrojder",
    "hemorrojdernas": "hemorrojder",
    "hemorrojders": "hemorrojder",
    "hemorrojds": "hemorrojder",
    "hemorten": "hemort",
    "hemortens": "hemort",
    "hemorter": "hemort",
    "hemorterna": "hemort",
    "hemorternas": "hemort",
    "hemorters": "hemort",
    "hemorts": "hemort",
    "hemortsrätten": "hemortsrätt",
    "hemortsrättens": "hemortsrätt",
    "hemortsrätts": "hemortsrätt",
    "hemresan": "hemresa",
    "hemresans": "hemresa",
    "hemresas": "hemresa",
    "hemrese": "hemresa",
    "hemresor": "hemresa",
    "hemresorna": "hemresa",
    "hemresornas": "hemresa",
    "hemresors": "hemresa",
    "hems": "hem",
    "hemsamariten": "hemsamarit",
    "hemsamaritens": "hemsamarit",
    "hemsamariter": "hemsamarit",
    "hemsamariterna": "hemsamarit",
    "hemsamariternas": "hemsamarit",
    "hemsamariters": "hemsamarit",
    "hemsamarits": "hemsamarit",
    "hemsidan": "hemsida",
    "hemsidans": "hemsida",
    "hemsidas": "hemsida",
    "hemside": "hemsida",
    "hemsides": "hemsida",
    "hemsidor": "hemsida",
    "hemsidorna": "hemsida",
    "hemsidornas": "hemsida",
    "hemsidors": "hemsida",
    "hemsjukan": "hemsjuka",
    "hemsjukans": "hemsjuka",
    "hemsjukas": "hemsjuka",
    "hemsjuke": "hemsjuka",
    "hemsjuks": "hemsjuka",
    "hemsjukvården": "hemsjukvård",
    "hemsjukvårdens": "hemsjukvård",
    "hemsjukvårds": "hemsjukvård",
    "hemsjukvårdsbidragen": "hemsjukvårdsbidrag",
    "hemsjukvårdsbidragens": "hemsjukvårdsbidrag",
    "hemsjukvårdsbidraget": "hemsjukvårdsbidrag",
    "hemsjukvårdsbidragets": "hemsjukvårdsbidrag",
    "hemsjukvårdsbidrags": "hemsjukvårdsbidrag",
    "hemska": "hemsk",
    "hemskare": "hemsk",
    "hemskares": "hemsk",
    "hemskas": "hemsk",
    "hemskast": "hemsk",
    "hemskaste": "hemsk",
    "hemskastes": "hemsk",
    "hemskasts": "hemsk",
    "hemske": "hemsk",
    "hemskes": "hemsk",
    "hemskheten": "hemskhet",
    "hemskhetens": "hemskhet",
    "hemskheter": "hemskhet",
    "hemskheterna": "hemskhet",
    "hemskheternas": "hemskhet",
    "hemskheters": "hemskhet",
    "hemskhets": "hemskhet",
    "hemskickade": "hemskickad",
    "hemskickades": "hemskickad",
    "hemskickads": "hemskickad",
    "hemskickat": "hemskickad",
    "hemskickats": "hemskickad",
    "hemskillnaden": "hemskillnad",
    "hemskillnadens": "hemskillnad",
    "hemskillnader": "hemskillnad",
    "hemskillnaderna": "hemskillnad",
    "hemskillnadernas": "hemskillnad",
    "hemskillnaders": "hemskillnad",
    "hemskillnads": "hemskillnad",
    "hemsks": "hemsk",
    "hemskt": "hemsk",
    "hemskts": "hemsk",
    "hemslöjden": "hemslöjd",
    "hemslöjdens": "hemslöjd",
    "hemslöjds": "hemslöjd",
    "hemspråken": "hemspråk",
    "hemspråkens": "hemspråk",
    "hemspråket": "hemspråk",
    "hemspråkets": "hemspråk",
    "hemspråks": "hemspråk",
    "hemstaden": "hemstad",
    "hemstadens": "hemstad",
    "hemstads": "hemstad",
    "hemstan": "hemstad",
    "hemstans": "hemstad",
    "hemstickade": "hemstickad",
    "hemstickades": "hemstickad",
    "hemstickads": "hemstickad",
    "hemstickat": "hemstickad",
    "hemstickats": "hemstickad",
    "hemstäder": "hemstad",
    "hemstäderna": "hemstad",
    "hemstädernas": "hemstad",
    "hemstäders": "hemstad",
    "hemställ": "hemställa",
    "hemställande": "hemställa",
    "hemställanden": "hemställande",
    "hemställandena": "hemställande",
    "hemställandenas": "hemställande",
    "hemställandens": "hemställande",
    "hemställandes": "hemställande",
    "hemställandet": "hemställande",
    "hemställandets": "hemställande",
    "hemställans": "hemställan",
    "hemställde": "hemställa",
    "hemställer": "hemställa",
    "hemställningar": "hemställning",
    "hemställningarna": "hemställning",
    "hemställningarnas": "hemställning",
    "hemställningars": "hemställning",
    "hemställningen": "hemställning",
    "hemställningens": "hemställning",
    "hemställnings": "hemställning",
    "hemställt": "hemställa",
    "hemsök": "hemsöka",
    "hemsökande": "hemsöka",
    "hemsökanden": "hemsökande",
    "hemsökandena": "hemsökande",
    "hemsökandenas": "hemsökande",
    "hemsökandens": "hemsökande",
    "hemsökandes": "hemsökande",
    "hemsökandet": "hemsökande",
    "hemsökandets": "hemsökande",
    "hemsökas": "hemsöka",
    "hemsökelsen": "hemsökelse",
    "hemsökelsens": "hemsökelse",
    "hemsökelser": "hemsökelse",
    "hemsökelserna": "hemsökelse",
    "hemsökelsernas": "hemsökelse",
    "hemsökelsers": "hemsökelse",
    "hemsökelses": "hemsökelse",
    "hemsöker": "hemsöka",
    "hemsökes": "hemsöka",
    "hemsöks": "hemsöka",
    "hemsökt": "hemsöka",
    "hemsökta": "hemsöka",
    "hemsöktas": "hemsöka",
    "hemsökte": "hemsöka",
    "hemsöktes": "hemsöka",
    "hemsökts": "hemsöka",
    "hemtama": "hemtam",
    "hemtamare": "hemtam",
    "hemtamares": "hemtam",
    "hemtamas": "hemtam",
    "hemtamast": "hemtam",
    "hemtamaste": "hemtam",
    "hemtamastes": "hemtam",
    "hemtamasts": "hemtam",
    "hemtame": "hemtam",
    "hemtames": "hemtam",
    "hemtamheten": "hemtamhet",
    "hemtamhetens": "hemtamhet",
    "hemtamhets": "hemtamhet",
    "hemtams": "hemtam",
    "hemtamt": "hemtam",
    "hemtamts": "hemtam",
    "hemtjänsten": "hemtjänst",
    "hemtjänstens": "hemtjänst",
    "hemtjänster": "hemtjänst",
    "hemtjänsterna": "hemtjänst",
    "hemtjänsternas": "hemtjänst",
    "hemtjänsters": "hemtjänst",
    "hemtjänsts": "hemtjänst",
    "hemtrakten": "hemtrakt",
    "hemtraktens": "hemtrakt",
    "hemtrakter": "hemtrakt",
    "hemtrakterna": "hemtrakt",
    "hemtrakternas": "hemtrakt",
    "hemtrakters": "hemtrakt",
    "hemtrakts": "hemtrakt",
    "hemtrevliga": "hemtrevlig",
    "hemtrevligare": "hemtrevlig",
    "hemtrevligares": "hemtrevlig",
    "hemtrevligas": "hemtrevlig",
    "hemtrevligast": "hemtrevlig",
    "hemtrevligaste": "hemtrevlig",
    "hemtrevligastes": "hemtrevlig",
    "hemtrevligasts": "hemtrevlig",
    "hemtrevlige": "hemtrevlig",
    "hemtrevliges": "hemtrevlig",
    "hemtrevligheten": "hemtrevlighet",
    "hemtrevlighetens": "hemtrevlighet",
    "hemtrevligheter": "hemtrevlighet",
    "hemtrevligheterna": "hemtrevlighet",
    "hemtrevligheternas": "hemtrevlighet",
    "hemtrevligheters": "hemtrevlighet",
    "hemtrevlighets": "hemtrevlighet",
    "hemtrevligs": "hemtrevlig",
    "hemtrevligt": "hemtrevlig",
    "hemtrevligts": "hemtrevlig",
    "hemtrevnaden": "hemtrevnad",
    "hemtrevnadens": "hemtrevnad",
    "hemtrevnader": "hemtrevnad",
    "hemtrevnaderna": "hemtrevnad",
    "hemtrevnadernas": "hemtrevnad",
    "hemtrevnaders": "hemtrevnad",
    "hemtrevnads": "hemtrevnad",
    "hemuln": "hemul",
    "hemulns": "hemul",
    "hemuls": "hemul",
    "hemulsmannen": "hemulsman",
    "hemulsmannens": "hemulsman",
    "hemulsmans": "hemulsman",
    "hemulsmän": "hemulsman",
    "hemulsmännen": "hemulsman",
    "hemulsmännens": "hemulsman",
    "hemulsmäns": "hemulsman",
    "hemuppgiften": "hemuppgift",
    "hemuppgiftens": "hemuppgift",
    "hemuppgifter": "hemuppgift",
    "hemuppgifterna": "hemuppgift",
    "hemuppgifternas": "hemuppgift",
    "hemuppgifters": "hemuppgift",
    "hemuppgifts": "hemuppgift",
    "hemvisten": "hemvist",
    "hemvistens": "hemvist",
    "hemvister": "hemvist",
    "hemvisterna": "hemvist",
    "hemvisternas": "hemvist",
    "hemvisters": "hemvist",
    "hemvistet": "hemvist",
    "hemvistets": "hemvist",
    "hemvists": "hemvist",
    "hemvägen": "hemväg",
    "hemvägens": "hemväg",
    "hemvägs": "hemväg",
    "hemvärnen": "hemvärn",
    "hemvärnens": "hemvärn",
    "hemvärnet": "hemvärn",
    "hemvärnets": "hemvärn",
    "hemvärns": "hemvärn",
    "hemvärnschefen": "hemvärnschef",
    "hemvärnschefens": "hemvärnschef",
    "hemvärnschefer": "hemvärnschef",
    "hemvärnscheferna": "hemvärnschef",
    "hemvärnschefernas": "hemvärnschef",
    "hemvärnschefers": "hemvärnschef",
    "hemvärnschefs": "hemvärnschef",
    "hemvärnsstyrkan": "hemvärnsstyrka",
    "hemvärnsstyrkans": "hemvärnsstyrka",
    "hemvärnsstyrkas": "hemvärnsstyrka",
    "hemvärnsstyrke": "hemvärnsstyrka",
    "hemvärnsstyrkor": "hemvärnsstyrka",
    "hemvärnsstyrkorna": "hemvärnsstyrka",
    "hemvärnsstyrkornas": "hemvärnsstyrka",
    "hemvärnsstyrkors": "hemvärnsstyrka",
    "hemvävda": "hemvävd",
    "hemvävdare": "hemvävd",
    "hemvävdares": "hemvävd",
    "hemvävdas": "hemvävd",
    "hemvävdast": "hemvävd",
    "hemvävdaste": "hemvävd",
    "hemvävdastes": "hemvävd",
    "hemvävdasts": "hemvävd",
    "hemvävde": "hemvävd",
    "hemvävdes": "hemvävd",
    "hemvävdheten": "hemvävdhet",
    "hemvävdhetens": "hemvävdhet",
    "hemvävdhets": "hemvävdhet",
    "hemvävds": "hemvävd",
    "hemvävt": "hemvävd",
    "hemvävts": "hemvävd",
    "hemvården": "hemvård",
    "hemvårdens": "hemvård",
    "hemvårds": "hemvård",
    "henad": "hena",
    "henade": "hena",
    "henades": "hena",
    "henads": "hena",
    "henande": "hena",
    "henanden": "henande",
    "henandena": "henande",
    "henandenas": "henande",
    "henandens": "henande",
    "henandes": "henande",
    "henandet": "henande",
    "henandets": "henande",
    "henar": "hena",
    "henarna": "hen",
    "henarnas": "hen",
    "henars": "hen",
    "henas": "hena",
    "henat": "hena",
    "henats": "hena",
    "henen": "hen",
    "henens": "hen",
    "hennan": "henna",
    "hennans": "henna",
    "hennas": "henna",
    "henne": "hon",
    "hennes": "hon",
    "henryn": "henry",
    "henryna": "henry",
    "henrynas": "henry",
    "henryns": "henry",
    "henrys": "henry",
    "hens": "hen",
    "heparinen": "heparin",
    "heparinens": "heparin",
    "hepariner": "heparin",
    "heparinerna": "heparin",
    "heparinernas": "heparin",
    "hepariners": "heparin",
    "heparinet": "heparin",
    "heparinets": "heparin",
    "heparins": "heparin",
    "hepatiten": "hepatit",
    "hepatitens": "hepatit",
    "hepatiter": "hepatit",
    "hepatiterna": "hepatit",
    "hepatiternas": "hepatit",
    "hepatiters": "hepatit",
    "hepatits": "hepatit",
    "heraldiken": "heraldik",
    "heraldikens": "heraldik",
    "heraldikern": "heraldiker",
    "heraldikerna": "heraldiker",
    "heraldikernas": "heraldiker",
    "heraldikerns": "heraldiker",
    "heraldikers": "heraldiker",
    "heraldiks": "heraldik",
    "heraldiska": "heraldisk",
    "heraldiskare": "heraldisk",
    "heraldiskares": "heraldisk",
    "heraldiskas": "heraldisk",
    "heraldiskast": "heraldisk",
    "heraldiskaste": "heraldisk",
    "heraldiskastes": "heraldisk",
    "heraldiskasts": "heraldisk",
    "heraldiske": "heraldisk",
    "heraldiskes": "heraldisk",
    "heraldisks": "heraldisk",
    "heraldiskt": "heraldisk",
    "heraldiskts": "heraldisk",
    "herbarie": "herbarium",
    "herbarier": "herbarium",
    "herbarierna": "herbarium",
    "herbariernas": "herbarium",
    "herbariers": "herbarium",
    "herbariet": "herbarium",
    "herbariets": "herbarium",
    "herbariums": "herbarium",
    "herbiciden": "herbicid",
    "herbicidens": "herbicid",
    "herbicider": "herbicid",
    "herbiciderna": "herbicid",
    "herbicidernas": "herbicid",
    "herbiciders": "herbicid",
    "herbicids": "herbicid",
    "herda": "herde",
    "herdabreven": "herdabrev",
    "herdabrevens": "herdabrev",
    "herdabrevet": "herdabrev",
    "herdabrevets": "herdabrev",
    "herdabrevs": "herdabrev",
    "herdaminnen": "herdaminne",
    "herdaminnena": "herdaminne",
    "herdaminnenas": "herdaminne",
    "herdaminnens": "herdaminne",
    "herdaminnes": "herdaminne",
    "herdaminnet": "herdaminne",
    "herdaminnets": "herdaminne",
    "herdar": "herde",
    "herdarna": "herde",
    "herdarnas": "herde",
    "herdars": "herde",
    "herdedikten": "herdedikt",
    "herdediktens": "herdedikt",
    "herdedikter": "herdedikt",
    "herdedikterna": "herdedikt",
    "herdedikternas": "herdedikt",
    "herdedikters": "herdedikt",
    "herdedikts": "herdedikt",
    "herdeflöjten": "herdeflöjt",
    "herdeflöjtens": "herdeflöjt",
    "herdeflöjter": "herdeflöjt",
    "herdeflöjterna": "herdeflöjt",
    "herdeflöjternas": "herdeflöjt",
    "herdeflöjters": "herdeflöjt",
    "herdeflöjts": "herdeflöjt",
    "herdefolken": "herdefolk",
    "herdefolkens": "herdefolk",
    "herdefolket": "herdefolk",
    "herdefolkets": "herdefolk",
    "herdefolks": "herdefolk",
    "herden": "herde",
    "herdens": "herde",
    "herdes": "herde",
    "herdestunden": "herdestund",
    "herdestundens": "herdestund",
    "herdestunder": "herdestund",
    "herdestunderna": "herdestund",
    "herdestundernas": "herdestund",
    "herdestunders": "herdestund",
    "herdestunds": "herdestund",
    "hereditära": "hereditär",
    "hereditärare": "hereditär",
    "hereditärares": "hereditär",
    "hereditäras": "hereditär",
    "hereditärast": "hereditär",
    "hereditäraste": "hereditär",
    "hereditärastes": "hereditär",
    "hereditärasts": "hereditär",
    "hereditäre": "hereditär",
    "hereditäres": "hereditär",
    "hereditärs": "hereditär",
    "hereditärt": "hereditär",
    "hereditärts": "hereditär",
    "heresien": "heresi",
    "heresiens": "heresi",
    "heresier": "heresi",
    "heresierna": "heresi",
    "heresiernas": "heresi",
    "heresiers": "heresi",
    "heresin": "heresi",
    "heresins": "heresi",
    "heresis": "heresi",
    "heretikern": "heretiker",
    "heretikerna": "heretiker",
    "heretikernas": "heretiker",
    "heretikerns": "heretiker",
    "heretikers": "heretiker",
    "heretiska": "heretisk",
    "heretiskare": "heretisk",
    "heretiskares": "heretisk",
    "heretiskas": "heretisk",
    "heretiskast": "heretisk",
    "heretiskaste": "heretisk",
    "heretiskastes": "heretisk",
    "heretiskasts": "heretisk",
    "heretiske": "heretisk",
    "heretiskes": "heretisk",
    "heretisks": "heretisk",
    "heretiskt": "heretisk",
    "heretiskts": "heretisk",
    "herkulesarbeten": "herkulesarbete",
    "herkulesarbetena": "herkulesarbete",
    "herkulesarbetenas": "herkulesarbete",
    "herkulesarbetens": "herkulesarbete",
    "herkulesarbetes": "herkulesarbete",
    "herkulesarbetet": "herkulesarbete",
    "herkulesarbetets": "herkulesarbete",
    "herkulesarbets": "herkulesarbete",
    "herkuliska": "herkulisk",
    "herkuliskare": "herkulisk",
    "herkuliskares": "herkulisk",
    "herkuliskas": "herkulisk",
    "herkuliskast": "herkulisk",
    "herkuliskaste": "herkulisk",
    "herkuliskastes": "herkulisk",
    "herkuliskasts": "herkulisk",
    "herkuliske": "herkulisk",
    "herkuliskes": "herkulisk",
    "herkulisks": "herkulisk",
    "herkuliskt": "herkulisk",
    "herkuliskts": "herkulisk",
    "hermafroditen": "hermafrodit",
    "hermafroditens": "hermafrodit",
    "hermafroditer": "hermafrodit",
    "hermafroditerna": "hermafrodit",
    "hermafroditernas": "hermafrodit",
    "hermafroditers": "hermafrodit",
    "hermafrodits": "hermafrodit",
    "hermelinen": "hermelin",
    "hermelinens": "hermelin",
    "hermeliner": "hermelin",
    "hermelinerna": "hermelin",
    "hermelinernas": "hermelin",
    "hermeliners": "hermelin",
    "hermelins": "hermelin",
    "hermen": "herm",
    "hermeneutiken": "hermeneutik",
    "hermeneutikens": "hermeneutik",
    "hermeneutikern": "hermeneutiker",
    "hermeneutikerna": "hermeneutiker",
    "hermeneutikernas": "hermeneutiker",
    "hermeneutikerns": "hermeneutiker",
    "hermeneutikers": "hermeneutiker",
    "hermeneutiks": "hermeneutik",
    "hermeneutiska": "hermeneutisk",
    "hermeneutiskare": "hermeneutisk",
    "hermeneutiskares": "hermeneutisk",
    "hermeneutiskas": "hermeneutisk",
    "hermeneutiskast": "hermeneutisk",
    "hermeneutiskaste": "hermeneutisk",
    "hermeneutiskastes": "hermeneutisk",
    "hermeneutiskasts": "hermeneutisk",
    "hermeneutiske": "hermeneutisk",
    "hermeneutiskes": "hermeneutisk",
    "hermeneutisks": "hermeneutisk",
    "hermeneutiskt": "hermeneutisk",
    "hermeneutiskts": "hermeneutisk",
    "hermens": "herm",
    "hermer": "herm",
    "hermerna": "herm",
    "hermernas": "herm",
    "hermers": "herm",
    "hermetiska": "hermetisk",
    "hermetiskare": "hermetisk",
    "hermetiskares": "hermetisk",
    "hermetiskas": "hermetisk",
    "hermetiskast": "hermetisk",
    "hermetiskaste": "hermetisk",
    "hermetiskastes": "hermetisk",
    "hermetiskasts": "hermetisk",
    "hermetiske": "hermetisk",
    "hermetiskes": "hermetisk",
    "hermetisks": "hermetisk",
    "hermetiskt": "hermetisk",
    "hermetiskts": "hermetisk",
    "herms": "herm",
    "heroinbranchen": "heroinbranch",
    "heroinbranchens": "heroinbranch",
    "heroinbranchs": "heroinbranch",
    "heroinen": "heroin",
    "heroinens": "heroin",
    "heroiner": "heroin",
    "heroinerna": "heroin",
    "heroinernas": "heroin",
    "heroiners": "heroin",
    "heroinet": "heroin",
    "heroinets": "heroin",
    "heroinisten": "heroinist",
    "heroinistens": "heroinist",
    "heroinister": "heroinist",
    "heroinisterna": "heroinist",
    "heroinisternas": "heroinist",
    "heroinisters": "heroinist",
    "heroinists": "heroinist",
    "heroinproduktionen": "heroinproduktion",
    "heroinproduktionens": "heroinproduktion",
    "heroinproduktions": "heroinproduktion",
    "heroins": "heroin",
    "heroinsmugglingen": "heroinsmuggling",
    "heroinsmugglingens": "heroinsmuggling",
    "heroinsmugglings": "heroinsmuggling",
    "heroinvraken": "heroinvrak",
    "heroinvrakens": "heroinvrak",
    "heroinvraket": "heroinvrak",
    "heroinvrakets": "heroinvrak",
    "heroinvraks": "heroinvrak",
    "heroiserad": "heroisera",
    "heroiserade": "heroisera",
    "heroiserades": "heroisera",
    "heroiserads": "heroisera",
    "heroiserande": "heroisera",
    "heroiseranden": "heroiserande",
    "heroiserandena": "heroiserande",
    "heroiserandenas": "heroiserande",
    "heroiserandens": "heroiserande",
    "heroiserandes": "heroiserande",
    "heroiserandet": "heroiserande",
    "heroiserandets": "heroiserande",
    "heroiserar": "heroisera",
    "heroiseras": "heroisera",
    "heroiserat": "heroisera",
    "heroiserats": "heroisera",
    "heroiserbara": "heroiserbar",
    "heroiserbarare": "heroiserbar",
    "heroiserbarares": "heroiserbar",
    "heroiserbaras": "heroiserbar",
    "heroiserbarast": "heroiserbar",
    "heroiserbaraste": "heroiserbar",
    "heroiserbarastes": "heroiserbar",
    "heroiserbarasts": "heroiserbar",
    "heroiserbare": "heroiserbar",
    "heroiserbares": "heroiserbar",
    "heroiserbarheten": "heroiserbarhet",
    "heroiserbarhetens": "heroiserbarhet",
    "heroiserbarhets": "heroiserbarhet",
    "heroiserbars": "heroiserbar",
    "heroiserbart": "heroiserbar",
    "heroiserbarts": "heroiserbar",
    "heroiseringar": "heroisering",
    "heroiseringarna": "heroisering",
    "heroiseringarnas": "heroisering",
    "heroiseringars": "heroisering",
    "heroiseringen": "heroisering",
    "heroiseringens": "heroisering",
    "heroiserings": "heroisering",
    "heroiska": "heroisk",
    "heroiskare": "heroisk",
    "heroiskares": "heroisk",
    "heroiskas": "heroisk",
    "heroiskast": "heroisk",
    "heroiskaste": "heroisk",
    "heroiskastes": "heroisk",
    "heroiskasts": "heroisk",
    "heroiske": "heroisk",
    "heroiskes": "heroisk",
    "heroisks": "heroisk",
    "heroiskt": "heroisk",
    "heroiskts": "heroisk",
    "heroismen": "heroism",
    "heroismens": "heroism",
    "heroismer": "heroism",
    "heroismerna": "heroism",
    "heroismernas": "heroism",
    "heroismers": "heroism",
    "heroisms": "heroism",
    "herosen": "heros",
    "herosens": "heros",
    "heroser": "heros",
    "heroserna": "heros",
    "herosernas": "heros",
    "herosers": "heros",
    "herostratiska": "herostratisk",
    "herostratiskare": "herostratisk",
    "herostratiskares": "herostratisk",
    "herostratiskas": "herostratisk",
    "herostratiskast": "herostratisk",
    "herostratiskaste": "herostratisk",
    "herostratiskastes": "herostratisk",
    "herostratiskasts": "herostratisk",
    "herostratiske": "herostratisk",
    "herostratiskes": "herostratisk",
    "herostratisks": "herostratisk",
    "herostratiskt": "herostratisk",
    "herostratiskts": "herostratisk",
    "herpesen": "herpes",
    "herpesens": "herpes",
    "herpessalvan": "herpessalva",
    "herpessalvans": "herpessalva",
    "herpessalvas": "herpessalva",
    "herpessalve": "herpessalva",
    "herpessalvor": "herpessalva",
    "herpessalvorna": "herpessalva",
    "herpessalvornas": "herpessalva",
    "herpessalvors": "herpessalva",
    "herpetologien": "herpetologi",
    "herpetologiens": "herpetologi",
    "herpetologin": "herpetologi",
    "herpetologins": "herpetologi",
    "herpetologis": "herpetologi",
    "herr": "herre",
    "herradömen": "herradöme",
    "herradömena": "herradöme",
    "herradömenas": "herradöme",
    "herradömens": "herradöme",
    "herradömes": "herradöme",
    "herradömet": "herradöme",
    "herradömets": "herradöme",
    "herrans": "herran",
    "herrar": "herre",
    "herrarna": "herre",
    "herrarnas": "herre",
    "herrars": "herre",
    "herravälden": "herravälde",
    "herraväldena": "herravälde",
    "herraväldenas": "herravälde",
    "herraväldens": "herravälde",
    "herraväldes": "herravälde",
    "herraväldet": "herravälde",
    "herraväldets": "herravälde",
    "herrbekanta": "herrbekant",
    "herrbekantas": "herrbekant",
    "herrbekanten": "herrbekant",
    "herrbekantens": "herrbekant",
    "herrbekanter": "herrbekant",
    "herrbekanterna": "herrbekant",
    "herrbekanternas": "herrbekant",
    "herrbekanters": "herrbekant",
    "herrbekants": "herrbekant",
    "herrbyx": "herrbyxa",
    "herrbyxan": "herrbyxa",
    "herrbyxans": "herrbyxa",
    "herrbyxas": "herrbyxa",
    "herrbyxe": "herrbyxa",
    "herrbyxor": "herrbyxa",
    "herrbyxorna": "herrbyxa",
    "herrbyxornas": "herrbyxa",
    "herrbyxors": "herrbyxa",
    "herrcykeln": "herrcykel",
    "herrcykelns": "herrcykel",
    "herrcykels": "herrcykel",
    "herrcyklar": "herrcykel",
    "herrcyklarna": "herrcykel",
    "herrcyklarnas": "herrcykel",
    "herrcyklars": "herrcykel",
    "herrdubbeln": "herrdubbel",
    "herrdubbelns": "herrdubbel",
    "herrdubbels": "herrdubbel",
    "herrdubblar": "herrdubbel",
    "herrdubblarna": "herrdubbel",
    "herrdubblarnas": "herrdubbel",
    "herrdubblars": "herrdubbel",
    "herrefolken": "herrefolk",
    "herrefolkens": "herrefolk",
    "herrefolket": "herrefolk",
    "herrefolkets": "herrefolk",
    "herrefolks": "herrefolk",
    "herrekiperingar": "herrekipering",
    "herrekiperingarna": "herrekipering",
    "herrekiperingarnas": "herrekipering",
    "herrekiperingars": "herrekipering",
    "herrekiperingen": "herrekipering",
    "herrekiperingens": "herrekipering",
    "herrekiperings": "herrekipering",
    "herrelösa": "herrelös",
    "herrelösare": "herrelös",
    "herrelösares": "herrelös",
    "herrelösas": "herrelös",
    "herrelösast": "herrelös",
    "herrelösaste": "herrelös",
    "herrelösastes": "herrelös",
    "herrelösasts": "herrelös",
    "herrelöse": "herrelös",
    "herrelöses": "herrelös",
    "herrelösheten": "herrelöshet",
    "herrelöshetens": "herrelöshet",
    "herrelöshets": "herrelöshet",
    "herrelöst": "herrelös",
    "herrelösts": "herrelös",
    "herremannen": "herreman",
    "herremannens": "herreman",
    "herremans": "herreman",
    "herremän": "herreman",
    "herremännen": "herreman",
    "herremännens": "herreman",
    "herremäns": "herreman",
    "herren": "herre",
    "herrens": "herre",
    "herres": "herre",
    "herresäten": "herresäte",
    "herresätena": "herresäte",
    "herresätenas": "herresäte",
    "herresätens": "herresäte",
    "herresätes": "herresäte",
    "herresätet": "herresäte",
    "herresätets": "herresäte",
    "herrgårdar": "herrgård",
    "herrgårdarna": "herrgård",
    "herrgårdarnas": "herrgård",
    "herrgårdars": "herrgård",
    "herrgården": "herrgård",
    "herrgårdens": "herrgård",
    "herrgårds": "herrgård",
    "herrgårdsbyggnaden": "herrgårdsbyggnad",
    "herrgårdsbyggnadens": "herrgårdsbyggnad",
    "herrgårdsbyggnader": "herrgårdsbyggnad",
    "herrgårdsbyggnaderna": "herrgårdsbyggnad",
    "herrgårdsbyggnadernas": "herrgårdsbyggnad",
    "herrgårdsbyggnaders": "herrgårdsbyggnad",
    "herrgårdsbyggnads": "herrgårdsbyggnad",
    "herrgårdsostar": "herrgårdsost",
    "herrgårdsostarna": "herrgårdsost",
    "herrgårdsostarnas": "herrgårdsost",
    "herrgårdsostars": "herrgårdsost",
    "herrgårdsosten": "herrgårdsost",
    "herrgårdsostens": "herrgårdsost",
    "herrgårdsosts": "herrgårdsost",
    "herrgårdsvagnar": "herrgårdsvagn",
    "herrgårdsvagnarna": "herrgårdsvagn",
    "herrgårdsvagnarnas": "herrgårdsvagn",
    "herrgårdsvagnars": "herrgårdsvagn",
    "herrgårdsvagnen": "herrgårdsvagn",
    "herrgårdsvagnens": "herrgårdsvagn",
    "herrgårdsvagns": "herrgårdsvagn",
    "herrhattar": "herrhatt",
    "herrhattarna": "herrhatt",
    "herrhattarnas": "herrhatt",
    "herrhattars": "herrhatt",
    "herrhatten": "herrhatt",
    "herrhattens": "herrhatt",
    "herrhatts": "herrhatt",
    "herrkläderna": "herrkläder",
    "herrklädernas": "herrkläder",
    "herrkläders": "herrkläder",
    "herrklädes": "herrkläder",
    "herrkläds": "herrkläder",
    "herrlandslagen": "herrlandslag",
    "herrlandslagens": "herrlandslag",
    "herrlandslaget": "herrlandslag",
    "herrlandslagets": "herrlandslag",
    "herrlandslags": "herrlandslag",
    "herrn": "herr",
    "herrnhutar": "herrnhutare",
    "herrnhutaren": "herrnhutare",
    "herrnhutarens": "herrnhutare",
    "herrnhutares": "herrnhutare",
    "herrnhutarna": "herrnhutare",
    "herrnhutarnas": "herrnhutare",
    "herrnhutismen": "herrnhutism",
    "herrnhutismens": "herrnhutism",
    "herrnhutismer": "herrnhutism",
    "herrnhutismerna": "herrnhutism",
    "herrnhutismernas": "herrnhutism",
    "herrnhutismers": "herrnhutism",
    "herrnhutisms": "herrnhutism",
    "herrnhutistiska": "herrnhutistisk",
    "herrnhutistiskas": "herrnhutistisk",
    "herrnhutistiske": "herrnhutistisk",
    "herrnhutistiskes": "herrnhutistisk",
    "herrnhutistisks": "herrnhutistisk",
    "herrnhutistiskt": "herrnhutistisk",
    "herrnhutistiskts": "herrnhutistisk",
    "herrns": "herr",
    "herrs": "herre",
    "herrsidan": "herrsida",
    "herrsidans": "herrsida",
    "herrsidas": "herrsida",
    "herrside": "herrsida",
    "herrsides": "herrsida",
    "herrsidor": "herrsida",
    "herrsidorna": "herrsida",
    "herrsidornas": "herrsida",
    "herrsidors": "herrsida",
    "herrsingeln": "herrsingel",
    "herrsingelns": "herrsingel",
    "herrsingels": "herrsingel",
    "herrsinglar": "herrsingel",
    "herrsinglarna": "herrsingel",
    "herrsinglarnas": "herrsingel",
    "herrsinglars": "herrsingel",
    "herrskapen": "herrskap",
    "herrskapens": "herrskap",
    "herrskapet": "herrskap",
    "herrskapets": "herrskap",
    "herrskaps": "herrskap",
    "herrskon": "herrsko",
    "herrskons": "herrsko",
    "herrskor": "herrsko",
    "herrskorna": "herrsko",
    "herrskornas": "herrsko",
    "herrskors": "herrsko",
    "herrskos": "herrsko",
    "herrtidningar": "herrtidning",
    "herrtidningarna": "herrtidning",
    "herrtidningarnas": "herrtidning",
    "herrtidningars": "herrtidning",
    "herrtidningen": "herrtidning",
    "herrtidningens": "herrtidning",
    "herrtidnings": "herrtidning",
    "herrtoaletten": "herrtoalett",
    "herrtoalettens": "herrtoalett",
    "herrtoaletter": "herrtoalett",
    "herrtoaletterna": "herrtoalett",
    "herrtoaletternas": "herrtoalett",
    "herrtoaletters": "herrtoalett",
    "herrtoaletts": "herrtoalett",
    "hertigar": "hertig",
    "hertigarna": "hertig",
    "hertigarnas": "hertig",
    "hertigars": "hertig",
    "hertigdömen": "hertigdöme",
    "hertigdömena": "hertigdöme",
    "hertigdömenas": "hertigdöme",
    "hertigdömens": "hertigdöme",
    "hertigdömes": "hertigdöme",
    "hertigdömet": "hertigdöme",
    "hertigdömets": "hertigdöme",
    "hertigen": "hertig",
    "hertigens": "hertig",
    "hertiginnan": "hertiginna",
    "hertiginnans": "hertiginna",
    "hertiginnas": "hertiginna",
    "hertiginne": "hertiginna",
    "hertiginnor": "hertiginna",
    "hertiginnorna": "hertiginna",
    "hertiginnornas": "hertiginna",
    "hertiginnors": "hertiginna",
    "hertigs": "hertig",
    "hertzen": "hertz",
    "hertzens": "hertz",
    "hesa": "hes",
    "hesare": "hes",
    "hesares": "hes",
    "hesas": "hes",
    "hesast": "hes",
    "hesaste": "hes",
    "hesastes": "hes",
    "hesasts": "hes",
    "hese": "hes",
    "heses": "hes",
    "hesheten": "heshet",
    "heshetens": "heshet",
    "hesheter": "heshet",
    "hesheterna": "heshet",
    "hesheternas": "heshet",
    "hesheters": "heshet",
    "heshets": "heshet",
    "hesiterade": "hesitera",
    "hesiterades": "hesitera",
    "hesiterande": "hesitera",
    "hesiteranden": "hesiterande",
    "hesiterandena": "hesiterande",
    "hesiterandenas": "hesiterande",
    "hesiterandens": "hesiterande",
    "hesiterandes": "hesiterande",
    "hesiterandet": "hesiterande",
    "hesiterandets": "hesiterande",
    "hesiterar": "hesitera",
    "hesiteras": "hesitera",
    "hesiterat": "hesitera",
    "hesiterats": "hesitera",
    "hesiteringar": "hesitering",
    "hesiteringarna": "hesitering",
    "hesiteringarnas": "hesitering",
    "hesiteringars": "hesitering",
    "hesiteringen": "hesitering",
    "hesiteringens": "hesitering",
    "hesiterings": "hesitering",
    "hest": "hes",
    "hests": "hes",
    "het": "heta",
    "heta": "het",
    "hetande": "heta",
    "hetanden": "hetande",
    "hetandena": "hetande",
    "hetandenas": "hetande",
    "hetandens": "hetande",
    "hetandes": "hetande",
    "hetandet": "hetande",
    "hetandets": "hetande",
    "hetare": "het",
    "hetares": "het",
    "hetas": "het",
    "hetast": "het",
    "hetaste": "het",
    "hetastes": "het",
    "hetasts": "het",
    "hetat": "heta",
    "hete": "het",
    "heter": "heta",
    "heterodoxa": "heterodox",
    "heterodoxare": "heterodox",
    "heterodoxares": "heterodox",
    "heterodoxas": "heterodox",
    "heterodoxast": "heterodox",
    "heterodoxaste": "heterodox",
    "heterodoxastes": "heterodox",
    "heterodoxasts": "heterodox",
    "heterodoxe": "heterodox",
    "heterodoxes": "heterodox",
    "heterodoxt": "heterodox",
    "heterodoxts": "heterodox",
    "heterogena": "heterogen",
    "heterogenare": "heterogen",
    "heterogenares": "heterogen",
    "heterogenas": "heterogen",
    "heterogenast": "heterogen",
    "heterogenaste": "heterogen",
    "heterogenastes": "heterogen",
    "heterogenasts": "heterogen",
    "heterogene": "heterogen",
    "heterogenes": "heterogen",
    "heterogenheten": "heterogenhet",
    "heterogenhetens": "heterogenhet",
    "heterogenhets": "heterogenhet",
    "heterogens": "heterogen",
    "heterogent": "heterogen",
    "heterogents": "heterogen",
    "heteroklisen": "heteroklis",
    "heteroklisens": "heteroklis",
    "heterokliser": "heteroklis",
    "heterokliserna": "heteroklis",
    "heteroklisernas": "heteroklis",
    "heteroklisers": "heteroklis",
    "heteroklitiska": "heteroklitisk",
    "heteroklitiskare": "heteroklitisk",
    "heteroklitiskares": "heteroklitisk",
    "heteroklitiskas": "heteroklitisk",
    "heteroklitiskast": "heteroklitisk",
    "heteroklitiskaste": "heteroklitisk",
    "heteroklitiskastes": "heteroklitisk",
    "heteroklitiskasts": "heteroklitisk",
    "heteroklitiske": "heteroklitisk",
    "heteroklitiskes": "heteroklitisk",
    "heteroklitisks": "heteroklitisk",
    "heteroklitiskt": "heteroklitisk",
    "heteroklitiskts": "heteroklitisk",
    "heteronormativa": "heteronormativ",
    "heteronormativare": "heteronormativ",
    "heteronormativares": "heteronormativ",
    "heteronormativas": "heteronormativ",
    "heteronormativast": "heteronormativ",
    "heteronormativaste": "heteronormativ",
    "heteronormativastes": "heteronormativ",
    "heteronormativasts": "heteronormativ",
    "heteronormative": "heteronormativ",
    "heteronormatives": "heteronormativ",
    "heteronormativiteten": "heteronormativitet",
    "heteronormativitetens": "heteronormativitet",
    "heteronormativiteter": "heteronormativitet",
    "heteronormativiteterna": "heteronormativitet",
    "heteronormativiteternas": "heteronormativitet",
    "heteronormativiteters": "heteronormativitet",
    "heteronormativitets": "heteronormativitet",
    "heteronormativs": "heteronormativ",
    "heteronormativt": "heteronormativ",
    "heteronormativts": "heteronormativ",
    "heteronormen": "heteronorm",
    "heteronormens": "heteronorm",
    "heteronormer": "heteronorm",
    "heteronormerna": "heteronorm",
    "heteronormernas": "heteronorm",
    "heteronormers": "heteronorm",
    "heteronorms": "heteronorm",
    "heteroparen": "heteropar",
    "heteroparens": "heteropar",
    "heteroparet": "heteropar",
    "heteroparets": "heteropar",
    "heteropars": "heteropar",
    "heterosexet": "heterosex",
    "heterosexets": "heterosex",
    "heterosexualiteten": "heterosexualitet",
    "heterosexualitetens": "heterosexualitet",
    "heterosexualitets": "heterosexualitet",
    "heterosexuella": "heterosexuell",
    "heterosexuellare": "heterosexuell",
    "heterosexuellares": "heterosexuell",
    "heterosexuellas": "heterosexuell",
    "heterosexuellast": "heterosexuell",
    "heterosexuellaste": "heterosexuell",
    "heterosexuellastes": "heterosexuell",
    "heterosexuellasts": "heterosexuell",
    "heterosexuelle": "heterosexuell",
    "heterosexuelles": "heterosexuell",
    "heterosexuells": "heterosexuell",
    "heterosexuellt": "heterosexuell",
    "heterosexuellts": "heterosexuell",
    "heterotematiska": "heterotematisk",
    "heterotematiskare": "heterotematisk",
    "heterotematiskares": "heterotematisk",
    "heterotematiskas": "heterotematisk",
    "heterotematiskast": "heterotematisk",
    "heterotematiskaste": "heterotematisk",
    "heterotematiskastes": "heterotematisk",
    "heterotematiskasts": "heterotematisk",
    "heterotematiske": "heterotematisk",
    "heterotematiskes": "heterotematisk",
    "heterotematisks": "heterotematisk",
    "heterotematiskt": "heterotematisk",
    "heterotematiskts": "heterotematisk",
    "heterozygota": "heterozygot",
    "heterozygotare": "heterozygot",
    "heterozygotares": "heterozygot",
    "heterozygotas": "heterozygot",
    "heterozygotast": "heterozygot",
    "heterozygotaste": "heterozygot",
    "heterozygotastes": "heterozygot",
    "heterozygotasts": "heterozygot",
    "heterozygote": "heterozygot",
    "heterozygoten": "heterozygot",
    "heterozygotens": "heterozygot",
    "heterozygoter": "heterozygot",
    "heterozygoterna": "heterozygot",
    "heterozygoternas": "heterozygot",
    "heterozygoters": "heterozygot",
    "heterozygotes": "heterozygot",
    "heterozygots": "heterozygot",
    "hetes": "het",
    "hetlevrade": "hetlevrad",
    "hetlevrades": "hetlevrad",
    "hetlevrads": "hetlevrad",
    "hetlevrat": "hetlevrad",
    "hetlevrats": "hetlevrad",
    "hetluften": "hetluft",
    "hetluftens": "hetluft",
    "hetlufts": "hetluft",
    "hetmanen": "hetman",
    "hetmanens": "hetman",
    "hetmaner": "hetman",
    "hetmanerna": "hetman",
    "hetmanernas": "hetman",
    "hetmaners": "hetman",
    "hetmans": "hetman",
    "hets": "hetsa",
    "hetsad": "hetsa",
    "hetsade": "hetsa",
    "hetsades": "hetsa",
    "hetsads": "hetsa",
    "hetsande": "hetsa",
    "hetsanden": "hetsande",
    "hetsandena": "hetsande",
    "hetsandenas": "hetsande",
    "hetsandens": "hetsande",
    "hetsandes": "hetsande",
    "hetsandet": "hetsande",
    "hetsandets": "hetsande",
    "hetsar": "hetsa",
    "hetsas": "hetsa",
    "hetsat": "hetsa",
    "hetsats": "hetsa",
    "hetsbrotten": "hetsbrott",
    "hetsbrottens": "hetsbrott",
    "hetsbrottet": "hetsbrott",
    "hetsbrottets": "hetsbrott",
    "hetsbrotts": "hetsbrott",
    "hetsen": "hets",
    "hetsens": "hets",
    "hetsiga": "hetsig",
    "hetsigare": "hetsig",
    "hetsigares": "hetsig",
    "hetsigas": "hetsig",
    "hetsigast": "hetsig",
    "hetsigaste": "hetsig",
    "hetsigastes": "hetsig",
    "hetsigasts": "hetsig",
    "hetsige": "hetsig",
    "hetsiges": "hetsig",
    "hetsigheten": "hetsighet",
    "hetsighetens": "hetsighet",
    "hetsigheter": "hetsighet",
    "hetsigheterna": "hetsighet",
    "hetsigheternas": "hetsighet",
    "hetsigheters": "hetsighet",
    "hetsighets": "hetsighet",
    "hetsigs": "hetsig",
    "hetsigt": "hetsig",
    "hetsigts": "hetsig",
    "hetsjakten": "hetsjakt",
    "hetsjaktens": "hetsjakt",
    "hetsjakter": "hetsjakt",
    "hetsjakterna": "hetsjakt",
    "hetsjakternas": "hetsjakt",
    "hetsjakters": "hetsjakt",
    "hetsjakts": "hetsjakt",
    "hetspolitiken": "hetspolitik",
    "hetspolitikens": "hetspolitik",
    "hetspolitiks": "hetspolitik",
    "hetspolitiska": "hetspolitisk",
    "hetspolitiskas": "hetspolitisk",
    "hetspolitiske": "hetspolitisk",
    "hetspolitiskes": "hetspolitisk",
    "hetspolitisks": "hetspolitisk",
    "hetspolitiskt": "hetspolitisk",
    "hetspolitiskts": "hetspolitisk",
    "hetsporr": "hetsporre",
    "hetsporrar": "hetsporre",
    "hetsporrarna": "hetsporre",
    "hetsporrarnas": "hetsporre",
    "hetsporrars": "hetsporre",
    "hetsporren": "hetsporre",
    "hetsporrens": "hetsporre",
    "hetsporres": "hetsporre",
    "hetsporrs": "hetsporre",
    "hetsätningen": "hetsätning",
    "hetsätningens": "hetsätning",
    "hetsätnings": "hetsätning",
    "hett": "het",
    "hettade": "hetta",
    "hettades": "hetta",
    "hettan": "hetta",
    "hettande": "hetta",
    "hettanden": "hettande",
    "hettandena": "hettande",
    "hettandenas": "hettande",
    "hettandens": "hettande",
    "hettandes": "hettande",
    "hettandet": "hettande",
    "hettandets": "hettande",
    "hettans": "hetta",
    "hettar": "hetta",
    "hettas": "hetta",
    "hettat": "hetta",
    "hettats": "hetta",
    "hette": "heta",
    "hettiten": "hettit",
    "hettitens": "hettit",
    "hettiter": "hettit",
    "hettiterna": "hettit",
    "hettiternas": "hettit",
    "hettiters": "hettit",
    "hettitisk": "hettitiska",
    "hettitiska": "hettitisk",
    "hettitiskan": "hettitiska",
    "hettitiskans": "hettitiska",
    "hettitiskare": "hettitisk",
    "hettitiskares": "hettitisk",
    "hettitiskas": "hettitiska",
    "hettitiskast": "hettitisk",
    "hettitiskaste": "hettitisk",
    "hettitiskastes": "hettitisk",
    "hettitiskasts": "hettitisk",
    "hettitiske": "hettitisk",
    "hettitiskes": "hettitisk",
    "hettitisks": "hettitisk",
    "hettitiskt": "hettitisk",
    "hettitiskts": "hettitisk",
    "hettits": "hettit",
    "hetts": "het",
    "hetvattens": "hetvatten",
    "hetvattentvättar": "hetvattentvätt",
    "hetvattentvättarna": "hetvattentvätt",
    "hetvattentvättarnas": "hetvattentvätt",
    "hetvattentvättars": "hetvattentvätt",
    "hetvattentvätten": "hetvattentvätt",
    "hetvattentvättens": "hetvattentvätt",
    "hetvattentvätts": "hetvattentvätt",
    "hetvattnen": "hetvatten",
    "hetvattnens": "hetvatten",
    "hetvattnet": "hetvatten",
    "hetvattnets": "hetvatten",
    "hetviner": "hetvin",
    "hetvinerna": "hetvin",
    "hetvinernas": "hetvin",
    "hetviners": "hetvin",
    "hetvinet": "hetvin",
    "hetvinets": "hetvin",
    "hetvins": "hetvin",
    "hetären": "hetär",
    "hetärens": "hetär",
    "hetärer": "hetär",
    "hetärerna": "hetär",
    "hetärernas": "hetär",
    "hetärers": "hetär",
    "hetärs": "hetär",
    "heuristiken": "heuristik",
    "heuristikens": "heuristik",
    "heuristiks": "heuristik",
    "heuristiska": "heuristisk",
    "heuristiskare": "heuristisk",
    "heuristiskares": "heuristisk",
    "heuristiskas": "heuristisk",
    "heuristiskast": "heuristisk",
    "heuristiskaste": "heuristisk",
    "heuristiskastes": "heuristisk",
    "heuristiskasts": "heuristisk",
    "heuristiske": "heuristisk",
    "heuristiskes": "heuristisk",
    "heuristisks": "heuristisk",
    "heuristiskt": "heuristisk",
    "heuristiskts": "heuristisk",
    "hexametern": "hexameter",
    "hexameterns": "hexameter",
    "hexameters": "hexameter",
    "hexametrar": "hexameter",
    "hexametrarna": "hexameter",
    "hexametrarnas": "hexameter",
    "hexametrars": "hexameter",
    "hi-fin": "hi-fi",
    "hi-fins": "hi-fi",
    "hi-fis": "hi-fi",
    "hiatusen": "hiatus",
    "hiatusens": "hiatus",
    "hibernationen": "hibernation",
    "hibernationens": "hibernation",
    "hibernationer": "hibernation",
    "hibernationerna": "hibernation",
    "hibernationernas": "hibernation",
    "hibernationers": "hibernation",
    "hibernations": "hibernation",
    "hibernerade": "hibernera",
    "hibernerades": "hibernera",
    "hibernerande": "hibernera",
    "hiberneranden": "hibernerande",
    "hibernerandena": "hibernerande",
    "hibernerandenas": "hibernerande",
    "hibernerandens": "hibernerande",
    "hibernerandes": "hibernerande",
    "hibernerandet": "hibernerande",
    "hibernerandets": "hibernerande",
    "hibernerar": "hibernera",
    "hiberneras": "hibernera",
    "hibernerat": "hibernera",
    "hibernerats": "hibernera",
    "hiberneringar": "hibernering",
    "hiberneringarna": "hibernering",
    "hiberneringarnas": "hibernering",
    "hiberneringars": "hibernering",
    "hiberneringen": "hibernering",
    "hiberneringens": "hibernering",
    "hibernerings": "hibernering",
    "hibiskusar": "hibiskus",
    "hibiskusarna": "hibiskus",
    "hibiskusarnas": "hibiskus",
    "hibiskusars": "hibiskus",
    "hibiskusen": "hibiskus",
    "hibiskusens": "hibiskus",
    "hick": "hicka",
    "hickade": "hicka",
    "hickades": "hicka",
    "hickan": "hicka",
    "hickande": "hicka",
    "hickanden": "hickande",
    "hickandena": "hickande",
    "hickandenas": "hickande",
    "hickandens": "hickande",
    "hickandes": "hickande",
    "hickandet": "hickande",
    "hickandets": "hickande",
    "hickans": "hicka",
    "hickar": "hicka",
    "hickas": "hicka",
    "hickat": "hicka",
    "hickats": "hicka",
    "hickningar": "hickning",
    "hickningarna": "hickning",
    "hickningarnas": "hickning",
    "hickningars": "hickning",
    "hickningen": "hickning",
    "hickningens": "hickning",
    "hicknings": "hickning",
    "hickoryn": "hickory",
    "hickoryns": "hickory",
    "hickorys": "hickory",
    "hierarkien": "hierarki",
    "hierarkiens": "hierarki",
    "hierarkier": "hierarki",
    "hierarkierna": "hierarki",
    "hierarkiernas": "hierarki",
    "hierarkiers": "hierarki",
    "hierarkin": "hierarki",
    "hierarkins": "hierarki",
    "hierarkis": "hierarki",
    "hierarkiska": "hierarkisk",
    "hierarkiskare": "hierarkisk",
    "hierarkiskares": "hierarkisk",
    "hierarkiskas": "hierarkisk",
    "hierarkiskast": "hierarkisk",
    "hierarkiskaste": "hierarkisk",
    "hierarkiskastes": "hierarkisk",
    "hierarkiskasts": "hierarkisk",
    "hierarkiske": "hierarkisk",
    "hierarkiskes": "hierarkisk",
    "hierarkisks": "hierarkisk",
    "hierarkiskt": "hierarkisk",
    "hierarkiskts": "hierarkisk",
    "hieratiska": "hieratisk",
    "hieratiskare": "hieratisk",
    "hieratiskares": "hieratisk",
    "hieratiskas": "hieratisk",
    "hieratiskast": "hieratisk",
    "hieratiskaste": "hieratisk",
    "hieratiskastes": "hieratisk",
    "hieratiskasts": "hieratisk",
    "hieratiske": "hieratisk",
    "hieratiskes": "hieratisk",
    "hieratisks": "hieratisk",
    "hieratiskt": "hieratisk",
    "hieratiskts": "hieratisk",
    "hieroglyfen": "hieroglyf",
    "hieroglyfens": "hieroglyf",
    "hieroglyfer": "hieroglyf",
    "hieroglyferna": "hieroglyf",
    "hieroglyfernas": "hieroglyf",
    "hieroglyfers": "hieroglyf",
    "hieroglyfs": "hieroglyf",
    "higgspartikeln": "higgspartikel",
    "higgspartikelns": "higgspartikel",
    "higgspartikels": "higgspartikel",
    "higgspartiklar": "higgspartikel",
    "higgspartiklarna": "higgspartikel",
    "higgspartiklarnas": "higgspartikel",
    "higgspartiklars": "higgspartikel",
    "hillebarden": "hillebard",
    "hillebardens": "hillebard",
    "hillebarder": "hillebard",
    "hillebarderna": "hillebard",
    "hillebardernas": "hillebard",
    "hillebarders": "hillebard",
    "hillebards": "hillebard",
    "himlaborens": "himlaboren",
    "himlaboret": "himlaboren",
    "himlaborets": "himlaboren",
    "himlaborna": "himlaboren",
    "himlabornare": "himlaboren",
    "himlabornares": "himlaboren",
    "himlabornas": "himlaboren",
    "himlabornast": "himlaboren",
    "himlabornaste": "himlaboren",
    "himlabornastes": "himlaboren",
    "himlabornasts": "himlaboren",
    "himlaborne": "himlaboren",
    "himlabornes": "himlaboren",
    "himlade": "himla",
    "himlades": "himla",
    "himladrottningar": "himladrottning",
    "himladrottningarna": "himladrottning",
    "himladrottningarnas": "himladrottning",
    "himladrottningars": "himladrottning",
    "himladrottningen": "himladrottning",
    "himladrottningens": "himladrottning",
    "himladrottnings": "himladrottning",
    "himlafenomenen": "himlafenomen",
    "himlafenomenens": "himlafenomen",
    "himlafenomenet": "himlafenomen",
    "himlafenomenets": "himlafenomen",
    "himlafenomens": "himlafenomen",
    "himlakroppar": "himlakropp",
    "himlakropparna": "himlakropp",
    "himlakropparnas": "himlakropp",
    "himlakroppars": "himlakropp",
    "himlakroppen": "himlakropp",
    "himlakroppens": "himlakropp",
    "himlakropps": "himlakropp",
    "himlande": "himla",
    "himlanden": "himlande",
    "himlandena": "himlande",
    "himlandenas": "himlande",
    "himlandens": "himlande",
    "himlandes": "himlande",
    "himlandet": "himlande",
    "himlandets": "himlande",
    "himlapällen": "himlapäll",
    "himlapällens": "himlapäll",
    "himlapälls": "himlapäll",
    "himlar": "himmel",
    "himlaranden": "himlarand",
    "himlarandens": "himlarand",
    "himlarands": "himlarand",
    "himlarna": "himmel",
    "himlarnas": "himmel",
    "himlars": "himmel",
    "himlas": "himla",
    "himlasteg": "himlastege",
    "himlastegar": "himlastege",
    "himlastegarna": "himlastege",
    "himlastegarnas": "himlastege",
    "himlastegars": "himlastege",
    "himlastegen": "himlastege",
    "himlastegens": "himlastege",
    "himlasteges": "himlastege",
    "himlastegs": "himlastege",
    "himlastormar": "himlastormare",
    "himlastormaren": "himlastormare",
    "himlastormarens": "himlastormare",
    "himlastormares": "himlastormare",
    "himlastormarna": "himlastormare",
    "himlastormarnas": "himlastormare",
    "himlat": "himla",
    "himlats": "himla",
    "himlavalvet": "himlavalv",
    "himlavalvets": "himlavalv",
    "himlavalvs": "himlavalv",
    "himlen": "himmel",
    "himlens": "himmel",
    "himmel": "himla",
    "himmelen": "himmel",
    "himmelens": "himmel",
    "himmeln": "himmel",
    "himmelns": "himmel",
    "himmelrikes": "himmelrike",
    "himmelriket": "himmelrike",
    "himmelrikets": "himmelrike",
    "himmels": "himmel",
    "himmelsblåa": "himmelsblå",
    "himmelsblåare": "himmelsblå",
    "himmelsblåares": "himmelsblå",
    "himmelsblåas": "himmelsblå",
    "himmelsblåast": "himmelsblå",
    "himmelsblåaste": "himmelsblå",
    "himmelsblåastes": "himmelsblå",
    "himmelsblåasts": "himmelsblå",
    "himmelsblåe": "himmelsblå",
    "himmelsblåes": "himmelsblå",
    "himmelsblås": "himmelsblå",
    "himmelsblått": "himmelsblå",
    "himmelsblåtts": "himmelsblå",
    "himmelsekvatorn": "himmelsekvator",
    "himmelsekvatorns": "himmelsekvator",
    "himmelsekvators": "himmelsekvator",
    "himmelsfarar": "himmelsfarare",
    "himmelsfararen": "himmelsfarare",
    "himmelsfararens": "himmelsfarare",
    "himmelsfarares": "himmelsfarare",
    "himmelsfararna": "himmelsfarare",
    "himmelsfararnas": "himmelsfarare",
    "himmelsfärden": "himmelsfärd",
    "himmelsfärdens": "himmelsfärd",
    "himmelsfärder": "himmelsfärd",
    "himmelsfärderna": "himmelsfärd",
    "himmelsfärdernas": "himmelsfärd",
    "himmelsfärders": "himmelsfärd",
    "himmelsfärds": "himmelsfärd",
    "himmelska": "himmelsk",
    "himmelskare": "himmelsk",
    "himmelskares": "himmelsk",
    "himmelskas": "himmelsk",
    "himmelskast": "himmelsk",
    "himmelskaste": "himmelsk",
    "himmelskastes": "himmelsk",
    "himmelskasts": "himmelsk",
    "himmelske": "himmelsk",
    "himmelskes": "himmelsk",
    "himmelsks": "himmelsk",
    "himmelskt": "himmelsk",
    "himmelskts": "himmelsk",
    "himmelsmekaniken": "himmelsmekanik",
    "himmelsmekanikens": "himmelsmekanik",
    "himmelsmekaniks": "himmelsmekanik",
    "himmelsobjekten": "himmelsobjekt",
    "himmelsobjektens": "himmelsobjekt",
    "himmelsobjektet": "himmelsobjekt",
    "himmelsobjektets": "himmelsobjekt",
    "himmelsobjekts": "himmelsobjekt",
    "himmelspolen": "himmelspol",
    "himmelspolens": "himmelspol",
    "himmelspoler": "himmelspol",
    "himmelspolerna": "himmelspol",
    "himmelspolernas": "himmelspol",
    "himmelspolers": "himmelspol",
    "himmelspols": "himmelspol",
    "himmelssfären": "himmelssfär",
    "himmelssfärens": "himmelssfär",
    "himmelssfärer": "himmelssfär",
    "himmelssfärerna": "himmelssfär",
    "himmelssfärernas": "himmelssfär",
    "himmelssfärers": "himmelssfär",
    "himmelssfärs": "himmelssfär",
    "himmelssängar": "himmelssäng",
    "himmelssängarna": "himmelssäng",
    "himmelssängarnas": "himmelssäng",
    "himmelssängars": "himmelssäng",
    "himmelssängen": "himmelssäng",
    "himmelssängens": "himmelssäng",
    "himmelssängs": "himmelssäng",
    "himmelsvida": "himmelsvid",
    "himmelsvidare": "himmelsvid",
    "himmelsvidares": "himmelsvid",
    "himmelsvidas": "himmelsvid",
    "himmelsvidast": "himmelsvid",
    "himmelsvidaste": "himmelsvid",
    "himmelsvidastes": "himmelsvid",
    "himmelsvidasts": "himmelsvid",
    "himmelsvide": "himmelsvid",
    "himmelsvides": "himmelsvid",
    "himmelsvids": "himmelsvid",
    "himmelsvitt": "himmelsvid",
    "himmelsvitts": "himmelsvid",
    "hindar": "hind",
    "hindarna": "hind",
    "hindarnas": "hind",
    "hindars": "hind",
    "hinden": "hind",
    "hindens": "hind",
    "hinder": "hindra",
    "hinderbanan": "hinderbana",
    "hinderbanans": "hinderbana",
    "hinderbanas": "hinderbana",
    "hinderbane": "hinderbana",
    "hinderbanor": "hinderbana",
    "hinderbanorna": "hinderbana",
    "hinderbanornas": "hinderbana",
    "hinderbanors": "hinderbana",
    "hinderbockar": "hinderbock",
    "hinderbockarna": "hinderbock",
    "hinderbockarnas": "hinderbock",
    "hinderbockars": "hinderbock",
    "hinderbocken": "hinderbock",
    "hinderbockens": "hinderbock",
    "hinderbocks": "hinderbock",
    "hinderlöpningar": "hinderlöpning",
    "hinderlöpningarna": "hinderlöpning",
    "hinderlöpningarnas": "hinderlöpning",
    "hinderlöpningars": "hinderlöpning",
    "hinderlöpningen": "hinderlöpning",
    "hinderlöpningens": "hinderlöpning",
    "hinderlöpnings": "hinderlöpning",
    "hinderlösa": "hinderlös",
    "hinderlösare": "hinderlös",
    "hinderlösares": "hinderlös",
    "hinderlösas": "hinderlös",
    "hinderlösast": "hinderlös",
    "hinderlösaste": "hinderlös",
    "hinderlösastes": "hinderlös",
    "hinderlösasts": "hinderlös",
    "hinderlöse": "hinderlös",
    "hinderlöses": "hinderlös",
    "hinderlösheten": "hinderlöshet",
    "hinderlöshetens": "hinderlöshet",
    "hinderlöshets": "hinderlöshet",
    "hinderlöst": "hinderlös",
    "hinderlösts": "hinderlös",
    "hinderna": "hinder",
    "hindernas": "hinder",
    "hinders": "hinder",
    "hindersamheten": "hindersamhet",
    "hindersamhetens": "hindersamhet",
    "hindersamhets": "hindersamhet",
    "hindersamma": "hindersam",
    "hindersammare": "hindersam",
    "hindersammares": "hindersam",
    "hindersammas": "hindersam",
    "hindersammast": "hindersam",
    "hindersammaste": "hindersam",
    "hindersammastes": "hindersam",
    "hindersammasts": "hindersam",
    "hindersamme": "hindersam",
    "hindersammes": "hindersam",
    "hindersams": "hindersam",
    "hindersamt": "hindersam",
    "hindersamts": "hindersam",
    "hindersprövningar": "hindersprövning",
    "hindersprövningarna": "hindersprövning",
    "hindersprövningarnas": "hindersprövning",
    "hindersprövningars": "hindersprövning",
    "hindersprövningen": "hindersprövning",
    "hindersprövningens": "hindersprövning",
    "hindersprövnings": "hindersprövning",
    "hindertricken": "hindertrick",
    "hindertrickens": "hindertrick",
    "hindertricket": "hindertrick",
    "hindertrickets": "hindertrick",
    "hindertricks": "hindertrick",
    "hindis": "hindi",
    "hindrad": "hindra",
    "hindrade": "hindra",
    "hindrades": "hindra",
    "hindrads": "hindra",
    "hindrande": "hindra",
    "hindranden": "hindrande",
    "hindrandena": "hindrande",
    "hindrandenas": "hindrande",
    "hindrandens": "hindrande",
    "hindrandes": "hindrande",
    "hindrandet": "hindrande",
    "hindrandets": "hindrande",
    "hindrar": "hindra",
    "hindras": "hindra",
    "hindrat": "hindra",
    "hindrats": "hindra",
    "hindren": "hinder",
    "hindrens": "hinder",
    "hindret": "hinder",
    "hindrets": "hinder",
    "hinds": "hind",
    "hinduen": "hindu",
    "hinduens": "hindu",
    "hinduer": "hindu",
    "hinduerna": "hindu",
    "hinduernas": "hindu",
    "hinduers": "hindu",
    "hinduiska": "hinduisk",
    "hinduiskare": "hinduisk",
    "hinduiskares": "hinduisk",
    "hinduiskas": "hinduisk",
    "hinduiskast": "hinduisk",
    "hinduiskaste": "hinduisk",
    "hinduiskastes": "hinduisk",
    "hinduiskasts": "hinduisk",
    "hinduiske": "hinduisk",
    "hinduiskes": "hinduisk",
    "hinduisks": "hinduisk",
    "hinduiskt": "hinduisk",
    "hinduiskts": "hinduisk",
    "hinduismen": "hinduism",
    "hinduismens": "hinduism",
    "hinduismer": "hinduism",
    "hinduismerna": "hinduism",
    "hinduismernas": "hinduism",
    "hinduismers": "hinduism",
    "hinduisms": "hinduism",
    "hinduistiska": "hinduistisk",
    "hinduistiskas": "hinduistisk",
    "hinduistiske": "hinduistisk",
    "hinduistiskes": "hinduistisk",
    "hinduistisks": "hinduistisk",
    "hinduistiskt": "hinduistisk",
    "hinduistiskts": "hinduistisk",
    "hindun": "hindu",
    "hinduns": "hindu",
    "hindus": "hindu",
    "hindutempels": "hindutempel",
    "hindutemplen": "hindutempel",
    "hindutemplens": "hindutempel",
    "hindutemplet": "hindutempel",
    "hindutemplets": "hindutempel",
    "hingstar": "hingst",
    "hingstarna": "hingst",
    "hingstarnas": "hingst",
    "hingstars": "hingst",
    "hingsten": "hingst",
    "hingstens": "hingst",
    "hingsts": "hingst",
    "hinkad": "hinka",
    "hinkade": "hinka",
    "hinkades": "hinka",
    "hinkads": "hinka",
    "hinkande": "hinka",
    "hinkanden": "hinkande",
    "hinkandena": "hinkande",
    "hinkandenas": "hinkande",
    "hinkandens": "hinkande",
    "hinkandes": "hinkande",
    "hinkandet": "hinkande",
    "hinkandets": "hinkande",
    "hinkar": "hinka",
    "hinkarna": "hink",
    "hinkarnas": "hink",
    "hinkars": "hink",
    "hinkas": "hinka",
    "hinkat": "hinka",
    "hinkats": "hinka",
    "hinken": "hink",
    "hinkens": "hink",
    "hinks": "hink",
    "hinn": "hinna",
    "hinnan": "hinna",
    "hinnande": "hinna",
    "hinnanden": "hinnande",
    "hinnandena": "hinnande",
    "hinnandenas": "hinnande",
    "hinnandens": "hinnande",
    "hinnandes": "hinnande",
    "hinnandet": "hinnande",
    "hinnandets": "hinnande",
    "hinnans": "hinna",
    "hinnas": "hinna",
    "hinne": "hinna",
    "hinner": "hinna",
    "hinnes": "hinna",
    "hinnkräft": "hinnkräfta",
    "hinnkräftan": "hinnkräfta",
    "hinnkräftans": "hinnkräfta",
    "hinnkräftas": "hinnkräfta",
    "hinnkräfte": "hinnkräfta",
    "hinnkräftor": "hinnkräfta",
    "hinnkräftorna": "hinnkräfta",
    "hinnkräftornas": "hinnkräfta",
    "hinnkräftors": "hinnkräfta",
    "hinnkräfts": "hinnkräfta",
    "hinnor": "hinna",
    "hinnorna": "hinna",
    "hinnornas": "hinna",
    "hinnors": "hinna",
    "hinns": "hinna",
    "hins": "hin",
    "hinsidan": "hinsida",
    "hinsidans": "hinsida",
    "hinsidas": "hinsida",
    "hipp": "hippa",
    "hippa": "hipp",
    "hippan": "hippa",
    "hippans": "hippa",
    "hippare": "hipp",
    "hippares": "hipp",
    "hippas": "hippa",
    "hippast": "hipp",
    "hippaste": "hipp",
    "hippastes": "hipp",
    "hippasts": "hipp",
    "hippe": "hippa",
    "hippes": "hipp",
    "hippheten": "hipphet",
    "hipphetens": "hipphet",
    "hipphets": "hipphet",
    "hippieartade": "hippieartad",
    "hippieartades": "hippieartad",
    "hippieartads": "hippieartad",
    "hippieartat": "hippieartad",
    "hippieartats": "hippieartad",
    "hippien": "hippie",
    "hippiens": "hippie",
    "hippies": "hippie",
    "hippiesarna": "hippie",
    "hippiesarnas": "hippie",
    "hippiesen": "hippie",
    "hippiesens": "hippie",
    "hippodromen": "hippodrom",
    "hippodromens": "hippodrom",
    "hippodromer": "hippodrom",
    "hippodromerna": "hippodrom",
    "hippodromernas": "hippodrom",
    "hippodromers": "hippodrom",
    "hippodroms": "hippodrom",
    "hippologen": "hippolog",
    "hippologens": "hippolog",
    "hippologer": "hippolog",
    "hippologerna": "hippolog",
    "hippologernas": "hippolog",
    "hippologers": "hippolog",
    "hippologien": "hippologi",
    "hippologiens": "hippologi",
    "hippologin": "hippologi",
    "hippologins": "hippologi",
    "hippologis": "hippologi",
    "hippologiska": "hippologisk",
    "hippologiskare": "hippologisk",
    "hippologiskares": "hippologisk",
    "hippologiskas": "hippologisk",
    "hippologiskast": "hippologisk",
    "hippologiskaste": "hippologisk",
    "hippologiskastes": "hippologisk",
    "hippologiskasts": "hippologisk",
    "hippologiske": "hippologisk",
    "hippologiskes": "hippologisk",
    "hippologisks": "hippologisk",
    "hippologiskt": "hippologisk",
    "hippologiskts": "hippologisk",
    "hippologs": "hippolog",
    "hippor": "hippa",
    "hipporna": "hippa",
    "hippornas": "hippa",
    "hippors": "hippa",
    "hipps": "hippa",
    "hippt": "hipp",
    "hippts": "hipp",
    "hirden": "hird",
    "hirdens": "hird",
    "hirder": "hird",
    "hirderna": "hird",
    "hirdernas": "hird",
    "hirders": "hird",
    "hirds": "hird",
    "hirsen": "hirs",
    "hirsens": "hirs",
    "hiskeliga": "hiskelig",
    "hiskeligare": "hiskelig",
    "hiskeligares": "hiskelig",
    "hiskeligas": "hiskelig",
    "hiskeligast": "hiskelig",
    "hiskeligaste": "hiskelig",
    "hiskeligastes": "hiskelig",
    "hiskeligasts": "hiskelig",
    "hiskelige": "hiskelig",
    "hiskeliges": "hiskelig",
    "hiskeligheten": "hiskelighet",
    "hiskelighetens": "hiskelighet",
    "hiskeligheter": "hiskelighet",
    "hiskeligheterna": "hiskelighet",
    "hiskeligheternas": "hiskelighet",
    "hiskeligheters": "hiskelighet",
    "hiskelighets": "hiskelighet",
    "hiskeligs": "hiskelig",
    "hiskeligt": "hiskelig",
    "hiskeligts": "hiskelig",
    "hiskliga": "hisklig",
    "hiskligare": "hisklig",
    "hiskligares": "hisklig",
    "hiskligas": "hisklig",
    "hiskligast": "hisklig",
    "hiskligaste": "hisklig",
    "hiskligastes": "hisklig",
    "hiskligasts": "hisklig",
    "hisklige": "hisklig",
    "hiskliges": "hisklig",
    "hiskligheten": "hisklighet",
    "hisklighetens": "hisklighet",
    "hiskligheter": "hisklighet",
    "hiskligheterna": "hisklighet",
    "hiskligheternas": "hisklighet",
    "hiskligheters": "hisklighet",
    "hisklighets": "hisklighet",
    "hiskligs": "hisklig",
    "hiskligt": "hisklig",
    "hiskligts": "hisklig",
    "hisnade": "hisna",
    "hisnades": "hisna",
    "hisnande": "hisna",
    "hisnanden": "hisnande",
    "hisnandena": "hisnande",
    "hisnandenas": "hisnande",
    "hisnandens": "hisnande",
    "hisnandes": "hisnande",
    "hisnandet": "hisnande",
    "hisnandets": "hisnande",
    "hisnar": "hisna",
    "hisnas": "hisna",
    "hisnat": "hisna",
    "hisnats": "hisna",
    "hisp": "hispa",
    "hispan": "hispa",
    "hispans": "hispa",
    "hispas": "hispa",
    "hispe": "hispa",
    "hispiga": "hispig",
    "hispigare": "hispig",
    "hispigares": "hispig",
    "hispigas": "hispig",
    "hispigast": "hispig",
    "hispigaste": "hispig",
    "hispigastes": "hispig",
    "hispigasts": "hispig",
    "hispige": "hispig",
    "hispiges": "hispig",
    "hispigheten": "hispighet",
    "hispighetens": "hispighet",
    "hispighets": "hispighet",
    "hispigs": "hispig",
    "hispigt": "hispig",
    "hispigts": "hispig",
    "hispor": "hispa",
    "hisporna": "hispa",
    "hispornas": "hispa",
    "hispors": "hispa",
    "hiss": "hissa",
    "hissad": "hissa",
    "hissade": "hissa",
    "hissades": "hissa",
    "hissads": "hissa",
    "hissande": "hissa",
    "hissanden": "hissande",
    "hissandena": "hissande",
    "hissandenas": "hissande",
    "hissandens": "hissande",
    "hissandes": "hissande",
    "hissandet": "hissande",
    "hissandets": "hissande",
    "hissar": "hissa",
    "hissarna": "hiss",
    "hissarnas": "hiss",
    "hissars": "hiss",
    "hissas": "hissa",
    "hissat": "hissa",
    "hissats": "hissa",
    "hissdörrar": "hissdörr",
    "hissdörrarna": "hissdörr",
    "hissdörrarnas": "hissdörr",
    "hissdörrars": "hissdörr",
    "hissdörren": "hissdörr",
    "hissdörrens": "hissdörr",
    "hissdörrs": "hissdörr",
    "hissen": "hiss",
    "hissens": "hiss",
    "hissinstallationen": "hissinstallation",
    "hissinstallationens": "hissinstallation",
    "hissinstallationer": "hissinstallation",
    "hissinstallationerna": "hissinstallation",
    "hissinstallationernas": "hissinstallation",
    "hissinstallationers": "hissinstallation",
    "hissinstallations": "hissinstallation",
    "hisskorgar": "hisskorg",
    "hisskorgarna": "hisskorg",
    "hisskorgarnas": "hisskorg",
    "hisskorgars": "hisskorg",
    "hisskorgen": "hisskorg",
    "hisskorgens": "hisskorg",
    "hisskorgs": "hisskorg",
    "hissnade": "hissna",
    "hissnades": "hissna",
    "hissnande": "hissna",
    "hissnanden": "hissnande",
    "hissnandena": "hissnande",
    "hissnandenas": "hissnande",
    "hissnandens": "hissnande",
    "hissnandes": "hissnande",
    "hissnandet": "hissnande",
    "hissnandets": "hissnande",
    "hissnar": "hissna",
    "hissnas": "hissna",
    "hissnat": "hissna",
    "hissnats": "hissna",
    "histaminer": "histamin",
    "histaminerna": "histamin",
    "histaminernas": "histamin",
    "histaminers": "histamin",
    "histaminet": "histamin",
    "histaminets": "histamin",
    "histamins": "histamin",
    "histologen": "histolog",
    "histologens": "histolog",
    "histologer": "histolog",
    "histologerna": "histolog",
    "histologernas": "histolog",
    "histologers": "histolog",
    "histologien": "histologi",
    "histologiens": "histologi",
    "histologin": "histologi",
    "histologins": "histologi",
    "histologis": "histologi",
    "histologs": "histolog",
    "historian": "historia",
    "historians": "historia",
    "historias": "historia",
    "historicismen": "historicism",
    "historicismens": "historicism",
    "historicismer": "historicism",
    "historicismerna": "historicism",
    "historicismernas": "historicism",
    "historicismers": "historicism",
    "historicisms": "historicism",
    "historicistiska": "historicistisk",
    "historicistiskas": "historicistisk",
    "historicistiske": "historicistisk",
    "historicistiskes": "historicistisk",
    "historicistisks": "historicistisk",
    "historicistiskt": "historicistisk",
    "historicistiskts": "historicistisk",
    "historieboken": "historiebok",
    "historiebokens": "historiebok",
    "historieboks": "historiebok",
    "historieböcker": "historiebok",
    "historieböckerna": "historiebok",
    "historieböckernas": "historiebok",
    "historieböckers": "historiebok",
    "historieintresses": "historieintresse",
    "historieintresset": "historieintresse",
    "historieintressets": "historieintresse",
    "historielösa": "historielös",
    "historielösare": "historielös",
    "historielösares": "historielös",
    "historielösas": "historielös",
    "historielösast": "historielös",
    "historielösaste": "historielös",
    "historielösastes": "historielös",
    "historielösasts": "historielös",
    "historielöse": "historielös",
    "historielöses": "historielös",
    "historielösheten": "historielöshet",
    "historielöshetens": "historielöshet",
    "historielöshets": "historielöshet",
    "historielöst": "historielös",
    "historielösts": "historielös",
    "historien": "historia",
    "historiens": "historia",
    "historier": "historia",
    "historierad": "historiera",
    "historierade": "historiera",
    "historierades": "historiera",
    "historierads": "historiera",
    "historierande": "historiera",
    "historieranden": "historierande",
    "historierandena": "historierande",
    "historierandenas": "historierande",
    "historierandens": "historierande",
    "historierandes": "historierande",
    "historierandet": "historierande",
    "historierandets": "historierande",
    "historierar": "historiera",
    "historieras": "historiera",
    "historierat": "historiera",
    "historierats": "historiera",
    "historierbara": "historierbar",
    "historierbarare": "historierbar",
    "historierbarares": "historierbar",
    "historierbaras": "historierbar",
    "historierbarast": "historierbar",
    "historierbaraste": "historierbar",
    "historierbarastes": "historierbar",
    "historierbarasts": "historierbar",
    "historierbare": "historierbar",
    "historierbares": "historierbar",
    "historierbarheten": "historierbarhet",
    "historierbarhetens": "historierbarhet",
    "historierbarhets": "historierbarhet",
    "historierbars": "historierbar",
    "historierbart": "historierbar",
    "historierbarts": "historierbar",
    "historieringar": "historiering",
    "historieringarna": "historiering",
    "historieringarnas": "historiering",
    "historieringars": "historiering",
    "historieringen": "historiering",
    "historieringens": "historiering",
    "historierings": "historiering",
    "historierna": "historia",
    "historiernas": "historia",
    "historiers": "historia",
    "historieskrivar": "historieskrivare",
    "historieskrivaren": "historieskrivare",
    "historieskrivarens": "historieskrivare",
    "historieskrivares": "historieskrivare",
    "historieskrivarna": "historieskrivare",
    "historieskrivarnas": "historieskrivare",
    "historieskrivningar": "historieskrivning",
    "historieskrivningarna": "historieskrivning",
    "historieskrivningarnas": "historieskrivning",
    "historieskrivningars": "historieskrivning",
    "historieskrivningen": "historieskrivning",
    "historieskrivningens": "historieskrivning",
    "historieskrivnings": "historieskrivning",
    "historietten": "historiett",
    "historiettens": "historiett",
    "historietter": "historiett",
    "historietterna": "historiett",
    "historietternas": "historiett",
    "historietters": "historiett",
    "historietts": "historiett",
    "historieverken": "historieverk",
    "historieverkens": "historieverk",
    "historieverket": "historieverk",
    "historieverkets": "historieverk",
    "historieverks": "historieverk",
    "historiken": "historik",
    "historikens": "historik",
    "historiker": "historik",
    "historikern": "historiker",
    "historikerna": "historiker",
    "historikernas": "historiker",
    "historikerns": "historiker",
    "historikers": "historiker",
    "historiks": "historik",
    "historiografen": "historiograf",
    "historiografens": "historiograf",
    "historiografer": "historiograf",
    "historiograferna": "historiograf",
    "historiografernas": "historiograf",
    "historiografers": "historiograf",
    "historiografs": "historiograf",
    "historiserad": "historisera",
    "historiserade": "historisera",
    "historiserades": "historisera",
    "historiserads": "historisera",
    "historiserande": "historisera",
    "historiseranden": "historiserande",
    "historiserandena": "historiserande",
    "historiserandenas": "historiserande",
    "historiserandens": "historiserande",
    "historiserandes": "historiserande",
    "historiserandet": "historiserande",
    "historiserandets": "historiserande",
    "historiserar": "historisera",
    "historiseras": "historisera",
    "historiserat": "historisera",
    "historiserats": "historisera",
    "historiserbara": "historiserbar",
    "historiserbarare": "historiserbar",
    "historiserbarares": "historiserbar",
    "historiserbaras": "historiserbar",
    "historiserbarast": "historiserbar",
    "historiserbaraste": "historiserbar",
    "historiserbarastes": "historiserbar",
    "historiserbarasts": "historiserbar",
    "historiserbare": "historiserbar",
    "historiserbares": "historiserbar",
    "historiserbarheten": "historiserbarhet",
    "historiserbarhetens": "historiserbarhet",
    "historiserbarhets": "historiserbarhet",
    "historiserbars": "historiserbar",
    "historiserbart": "historiserbar",
    "historiserbarts": "historiserbar",
    "historiseringar": "historisering",
    "historiseringarna": "historisering",
    "historiseringarnas": "historisering",
    "historiseringars": "historisering",
    "historiseringen": "historisering",
    "historiseringens": "historisering",
    "historiserings": "historisering",
    "historiska": "historisk",
    "historiskare": "historisk",
    "historiskares": "historisk",
    "historiskas": "historisk",
    "historiskast": "historisk",
    "historiskaste": "historisk",
    "historiskastes": "historisk",
    "historiskasts": "historisk",
    "historiske": "historisk",
    "historiskes": "historisk",
    "historisks": "historisk",
    "historiskt": "historisk",
    "historiskts": "historisk",
    "historismen": "historism",
    "historismens": "historism",
    "historismer": "historism",
    "historismerna": "historism",
    "historismernas": "historism",
    "historismers": "historism",
    "historisms": "historism",
    "histrionen": "histrion",
    "histrionens": "histrion",
    "histrioner": "histrion",
    "histrionerna": "histrion",
    "histrionernas": "histrion",
    "histrioners": "histrion",
    "histrions": "histrion",
    "hiten": "hit",
    "hitens": "hit",
    "hitersta": "hitre",
    "hiterstas": "hitre",
    "hiterste": "hitre",
    "hiterstes": "hitre",
    "hitlist": "hitlista",
    "hitlistan": "hitlista",
    "hitlistans": "hitlista",
    "hitlistas": "hitlista",
    "hitliste": "hitlista",
    "hitlistor": "hitlista",
    "hitlistorna": "hitlista",
    "hitlistornas": "hitlista",
    "hitlistors": "hitlista",
    "hitmässiga": "hitmässig",
    "hitmässigare": "hitmässig",
    "hitmässigares": "hitmässig",
    "hitmässigas": "hitmässig",
    "hitmässigast": "hitmässig",
    "hitmässigaste": "hitmässig",
    "hitmässigastes": "hitmässig",
    "hitmässigasts": "hitmässig",
    "hitmässige": "hitmässig",
    "hitmässiges": "hitmässig",
    "hitmässigs": "hitmässig",
    "hitmässigt": "hitmässig",
    "hitmässigts": "hitmässig",
    "hitres": "hitre",
    "hitresan": "hitresa",
    "hitresans": "hitresa",
    "hitresas": "hitresa",
    "hitrese": "hitresa",
    "hitresor": "hitresa",
    "hitresorna": "hitresa",
    "hitresornas": "hitresa",
    "hitresors": "hitresa",
    "hits": "hit",
    "hitsarna": "hit",
    "hitsarnas": "hit",
    "hitsen": "hit",
    "hitsens": "hit",
    "hittad": "hitta",
    "hittade": "hitta",
    "hittades": "hitta",
    "hittads": "hitta",
    "hittande": "hitta",
    "hittanden": "hittande",
    "hittandena": "hittande",
    "hittandenas": "hittande",
    "hittandens": "hittande",
    "hittandes": "hittande",
    "hittandet": "hittande",
    "hittandets": "hittande",
    "hittar": "hitta",
    "hittas": "hitta",
    "hittat": "hitta",
    "hittats": "hitta",
    "hitte": "hitta",
    "hittebarnen": "hittebarn",
    "hittebarnens": "hittebarn",
    "hittebarnet": "hittebarn",
    "hittebarnets": "hittebarn",
    "hittebarns": "hittebarn",
    "hittegodset": "hittegods",
    "hittegodsets": "hittegods",
    "hittelönen": "hittelön",
    "hittelönens": "hittelön",
    "hittelöner": "hittelön",
    "hittelönerna": "hittelön",
    "hittelönernas": "hittelön",
    "hittelöners": "hittelön",
    "hittelöns": "hittelön",
    "hitvägens": "hitvägen",
    "hiv": "hiva",
    "hiv-s": "hiv",
    "hivad": "hiva",
    "hivade": "hiva",
    "hivades": "hiva",
    "hivads": "hiva",
    "hivande": "hiva",
    "hivanden": "hivande",
    "hivandena": "hivande",
    "hivandenas": "hivande",
    "hivandens": "hivande",
    "hivandes": "hivande",
    "hivandet": "hivande",
    "hivandets": "hivande",
    "hivar": "hiva",
    "hivas": "hiva",
    "hivat": "hiva",
    "hivats": "hiva",
    "hivlagstiftningar": "hivlagstiftning",
    "hivlagstiftningarna": "hivlagstiftning",
    "hivlagstiftningarnas": "hivlagstiftning",
    "hivlagstiftningars": "hivlagstiftning",
    "hivlagstiftningen": "hivlagstiftning",
    "hivlagstiftningens": "hivlagstiftning",
    "hivlagstiftnings": "hivlagstiftning",
    "hivutbrotten": "hivutbrott",
    "hivutbrottens": "hivutbrott",
    "hivutbrottet": "hivutbrott",
    "hivutbrottets": "hivutbrott",
    "hivutbrotts": "hivutbrott",
    "hjonelagen": "hjonelag",
    "hjonelagens": "hjonelag",
    "hjonelaget": "hjonelag",
    "hjonelagets": "hjonelag",
    "hjonelags": "hjonelag",
    "hjonen": "hjon",
    "hjonens": "hjon",
    "hjonet": "hjon",
    "hjonets": "hjon",
    "hjons": "hjon",
    "hjordar": "hjord",
    "hjordarna": "hjord",
    "hjordarnas": "hjord",
    "hjordars": "hjord",
    "hjorden": "hjord",
    "hjordens": "hjord",
    "hjordinstinkten": "hjordinstinkt",
    "hjordinstinktens": "hjordinstinkt",
    "hjordinstinkts": "hjordinstinkt",
    "hjords": "hjord",
    "hjortar": "hjort",
    "hjortarna": "hjort",
    "hjortarnas": "hjort",
    "hjortars": "hjort",
    "hjortdjuren": "hjortdjur",
    "hjortdjurens": "hjortdjur",
    "hjortdjuret": "hjortdjur",
    "hjortdjurets": "hjortdjur",
    "hjortdjurs": "hjortdjur",
    "hjorten": "hjort",
    "hjortens": "hjort",
    "hjorthornssaltet": "hjorthornssalt",
    "hjorthornssaltets": "hjorthornssalt",
    "hjorthornssalts": "hjorthornssalt",
    "hjortkalvar": "hjortkalv",
    "hjortkalvarna": "hjortkalv",
    "hjortkalvarnas": "hjortkalv",
    "hjortkalvars": "hjortkalv",
    "hjortkalven": "hjortkalv",
    "hjortkalvens": "hjortkalv",
    "hjortkalvs": "hjortkalv",
    "hjortronen": "hjortron",
    "hjortronens": "hjortron",
    "hjortronet": "hjortron",
    "hjortronets": "hjortron",
    "hjortrons": "hjortron",
    "hjortronsylten": "hjortronsylt",
    "hjortronsyltens": "hjortronsylt",
    "hjortronsylts": "hjortronsylt",
    "hjortsadeln": "hjortsadel",
    "hjortsadelns": "hjortsadel",
    "hjortsadels": "hjortsadel",
    "hjortsadlar": "hjortsadel",
    "hjortsadlarna": "hjortsadel",
    "hjortsadlarnas": "hjortsadel",
    "hjortsadlars": "hjortsadel",
    "hjulade": "hjula",
    "hjulades": "hjula",
    "hjulande": "hjula",
    "hjulanden": "hjulande",
    "hjulandena": "hjulande",
    "hjulandenas": "hjulande",
    "hjulandens": "hjulande",
    "hjulandes": "hjulande",
    "hjulandet": "hjulande",
    "hjulandets": "hjulande",
    "hjular": "hjula",
    "hjulas": "hjula",
    "hjulat": "hjula",
    "hjulats": "hjula",
    "hjulbasen": "hjulbas",
    "hjulbasens": "hjulbas",
    "hjulbaser": "hjulbas",
    "hjulbaserna": "hjulbas",
    "hjulbasernas": "hjulbas",
    "hjulbasers": "hjulbas",
    "hjulbenta": "hjulbent",
    "hjulbentare": "hjulbent",
    "hjulbentares": "hjulbent",
    "hjulbentas": "hjulbent",
    "hjulbentast": "hjulbent",
    "hjulbentaste": "hjulbent",
    "hjulbentastes": "hjulbent",
    "hjulbentasts": "hjulbent",
    "hjulbente": "hjulbent",
    "hjulbentes": "hjulbent",
    "hjulbentheten": "hjulbenthet",
    "hjulbenthetens": "hjulbenthet",
    "hjulbenthets": "hjulbenthet",
    "hjulbents": "hjulbent",
    "hjuldjuren": "hjuldjur",
    "hjuldjurens": "hjuldjur",
    "hjuldjuret": "hjuldjur",
    "hjuldjurets": "hjuldjur",
    "hjuldjurs": "hjuldjur",
    "hjuldollyn": "hjuldolly",
    "hjuldollyns": "hjuldolly",
    "hjuldollys": "hjuldolly",
    "hjuldollysarna": "hjuldolly",
    "hjuldollysarnas": "hjuldolly",
    "hjuldollysen": "hjuldolly",
    "hjuldollysens": "hjuldolly",
    "hjulen": "hjul",
    "hjulens": "hjul",
    "hjulet": "hjul",
    "hjulets": "hjul",
    "hjulfjädringar": "hjulfjädring",
    "hjulfjädringarna": "hjulfjädring",
    "hjulfjädringarnas": "hjulfjädring",
    "hjulfjädringars": "hjulfjädring",
    "hjulfjädringen": "hjulfjädring",
    "hjulfjädringens": "hjulfjädring",
    "hjulfjädrings": "hjulfjädring",
    "hjulfönsterna": "hjulfönster",
    "hjulfönsternas": "hjulfönster",
    "hjulfönsters": "hjulfönster",
    "hjulfönstren": "hjulfönster",
    "hjulfönstrens": "hjulfönster",
    "hjulfönstret": "hjulfönster",
    "hjulfönstrets": "hjulfönster",
    "hjulkorsen": "hjulkors",
    "hjulkorsens": "hjulkors",
    "hjulkorset": "hjulkors",
    "hjulkorsets": "hjulkors",
    "hjullagerna": "hjullager",
    "hjullagernas": "hjullager",
    "hjullagers": "hjullager",
    "hjullagren": "hjullager",
    "hjullagrens": "hjullager",
    "hjullagret": "hjullager",
    "hjullagrets": "hjullager",
    "hjulmutterdragar": "hjulmutterdragare",
    "hjulmutterdragaren": "hjulmutterdragare",
    "hjulmutterdragarens": "hjulmutterdragare",
    "hjulmutterdragares": "hjulmutterdragare",
    "hjulmutterdragarna": "hjulmutterdragare",
    "hjulmutterdragarnas": "hjulmutterdragare",
    "hjulmutterhyls": "hjulmutterhylsa",
    "hjulmutterhylsan": "hjulmutterhylsa",
    "hjulmutterhylsans": "hjulmutterhylsa",
    "hjulmutterhylsas": "hjulmutterhylsa",
    "hjulmutterhylse": "hjulmutterhylsa",
    "hjulmutterhylsor": "hjulmutterhylsa",
    "hjulmutterhylsorna": "hjulmutterhylsa",
    "hjulmutterhylsornas": "hjulmutterhylsa",
    "hjulmutterhylsors": "hjulmutterhylsa",
    "hjulmuttern": "hjulmutter",
    "hjulmutterns": "hjulmutter",
    "hjulmutters": "hjulmutter",
    "hjulmuttrar": "hjulmutter",
    "hjulmuttrarna": "hjulmutter",
    "hjulmuttrarnas": "hjulmutter",
    "hjulmuttrars": "hjulmutter",
    "hjulnaven": "hjulnav",
    "hjulnavens": "hjulnav",
    "hjulnavet": "hjulnav",
    "hjulnavets": "hjulnav",
    "hjulnavs": "hjulnav",
    "hjuls": "hjul",
    "hjulsatsen": "hjulsats",
    "hjulsatsens": "hjulsats",
    "hjulsatser": "hjulsats",
    "hjulsatserna": "hjulsats",
    "hjulsatsernas": "hjulsats",
    "hjulsatsers": "hjulsats",
    "hjulsidan": "hjulsida",
    "hjulsidans": "hjulsida",
    "hjulsidas": "hjulsida",
    "hjulside": "hjulsida",
    "hjulsides": "hjulsida",
    "hjulsidor": "hjulsida",
    "hjulsidorna": "hjulsida",
    "hjulsidornas": "hjulsida",
    "hjulsidors": "hjulsida",
    "hjulspåren": "hjulspår",
    "hjulspårens": "hjulspår",
    "hjulspåret": "hjulspår",
    "hjulspårets": "hjulspår",
    "hjulspårs": "hjulspår",
    "hjulupphängningar": "hjulupphängning",
    "hjulupphängningarna": "hjulupphängning",
    "hjulupphängningarnas": "hjulupphängning",
    "hjulupphängningars": "hjulupphängning",
    "hjulupphängningen": "hjulupphängning",
    "hjulupphängningens": "hjulupphängning",
    "hjulupphängnings": "hjulupphängning",
    "hjulångar": "hjulångare",
    "hjulångaren": "hjulångare",
    "hjulångarens": "hjulångare",
    "hjulångares": "hjulångare",
    "hjulångarna": "hjulångare",
    "hjulångarnas": "hjulångare",
    "hjälmar": "hjälm",
    "hjälmarna": "hjälm",
    "hjälmarnas": "hjälm",
    "hjälmars": "hjälm",
    "hjälmen": "hjälm",
    "hjälmens": "hjälm",
    "hjälmprydnaden": "hjälmprydnad",
    "hjälmprydnadens": "hjälmprydnad",
    "hjälmprydnader": "hjälmprydnad",
    "hjälmprydnaderna": "hjälmprydnad",
    "hjälmprydnadernas": "hjälmprydnad",
    "hjälmprydnaders": "hjälmprydnad",
    "hjälmprydnads": "hjälmprydnad",
    "hjälmpås": "hjälmpåse",
    "hjälmpåsar": "hjälmpåse",
    "hjälmpåsarna": "hjälmpåse",
    "hjälmpåsarnas": "hjälmpåse",
    "hjälmpåsars": "hjälmpåse",
    "hjälmpåsen": "hjälmpåse",
    "hjälmpåsens": "hjälmpåse",
    "hjälmpåses": "hjälmpåse",
    "hjälms": "hjälm",
    "hjälp": "hjälpa",
    "hjälpande": "hjälpa",
    "hjälpanden": "hjälpande",
    "hjälpandena": "hjälpande",
    "hjälpandenas": "hjälpande",
    "hjälpandens": "hjälpande",
    "hjälpandes": "hjälpande",
    "hjälpandet": "hjälpande",
    "hjälpandets": "hjälpande",
    "hjälpar": "hjälpare",
    "hjälparen": "hjälpare",
    "hjälparens": "hjälpare",
    "hjälpares": "hjälpare",
    "hjälparna": "hjälpare",
    "hjälparnas": "hjälpare",
    "hjälpars": "hjälp",
    "hjälpas": "hjälpa",
    "hjälpbåtar": "hjälpbåt",
    "hjälpbåtarna": "hjälpbåt",
    "hjälpbåtarnas": "hjälpbåt",
    "hjälpbåtars": "hjälpbåt",
    "hjälpbåten": "hjälpbåt",
    "hjälpbåtens": "hjälpbåt",
    "hjälpbåts": "hjälpbåt",
    "hjälpen": "hjälp",
    "hjälpens": "hjälp",
    "hjälper": "hjälpa",
    "hjälpes": "hjälpa",
    "hjälpfartygen": "hjälpfartyg",
    "hjälpfartygens": "hjälpfartyg",
    "hjälpfartyget": "hjälpfartyg",
    "hjälpfartygets": "hjälpfartyg",
    "hjälpfartygs": "hjälpfartyg",
    "hjälpgum": "hjälpgumma",
    "hjälpgumman": "hjälpgumma",
    "hjälpgummans": "hjälpgumma",
    "hjälpgummas": "hjälpgumma",
    "hjälpgumme": "hjälpgumma",
    "hjälpgummor": "hjälpgumma",
    "hjälpgummorna": "hjälpgumma",
    "hjälpgummornas": "hjälpgumma",
    "hjälpgummors": "hjälpgumma",
    "hjälpgums": "hjälpgumma",
    "hjälpklassen": "hjälpklass",
    "hjälpklassens": "hjälpklass",
    "hjälpklasser": "hjälpklass",
    "hjälpklasserna": "hjälpklass",
    "hjälpklassernas": "hjälpklass",
    "hjälpklassers": "hjälpklass",
    "hjälpkryssar": "hjälpkryssare",
    "hjälpkryssaren": "hjälpkryssare",
    "hjälpkryssarens": "hjälpkryssare",
    "hjälpkryssares": "hjälpkryssare",
    "hjälpkryssarna": "hjälpkryssare",
    "hjälpkryssarnas": "hjälpkryssare",
    "hjälpliga": "hjälplig",
    "hjälpligare": "hjälplig",
    "hjälpligares": "hjälplig",
    "hjälpligas": "hjälplig",
    "hjälpligast": "hjälplig",
    "hjälpligaste": "hjälplig",
    "hjälpligastes": "hjälplig",
    "hjälpligasts": "hjälplig",
    "hjälplige": "hjälplig",
    "hjälpliges": "hjälplig",
    "hjälpligs": "hjälplig",
    "hjälpligt": "hjälplig",
    "hjälpligts": "hjälplig",
    "hjälplinjen": "hjälplinje",
    "hjälplinjens": "hjälplinje",
    "hjälplinjer": "hjälplinje",
    "hjälplinjerna": "hjälplinje",
    "hjälplinjernas": "hjälplinje",
    "hjälplinjers": "hjälplinje",
    "hjälplinjes": "hjälplinje",
    "hjälplärar": "hjälplärare",
    "hjälpläraren": "hjälplärare",
    "hjälplärarens": "hjälplärare",
    "hjälplärares": "hjälplärare",
    "hjälplärarna": "hjälplärare",
    "hjälplärarnas": "hjälplärare",
    "hjälplösa": "hjälplös",
    "hjälplösare": "hjälplös",
    "hjälplösares": "hjälplös",
    "hjälplösas": "hjälplös",
    "hjälplösast": "hjälplös",
    "hjälplösaste": "hjälplös",
    "hjälplösastes": "hjälplös",
    "hjälplösasts": "hjälplös",
    "hjälplöse": "hjälplös",
    "hjälplöses": "hjälplös",
    "hjälplösheten": "hjälplöshet",
    "hjälplöshetens": "hjälplöshet",
    "hjälplöshets": "hjälplöshet",
    "hjälplöst": "hjälplös",
    "hjälplösts": "hjälplös",
    "hjälpmedels": "hjälpmedel",
    "hjälpmedlen": "hjälpmedel",
    "hjälpmedlens": "hjälpmedel",
    "hjälpmedlet": "hjälpmedel",
    "hjälpmedlets": "hjälpmedel",
    "hjälpmotorer": "hjälpmotor",
    "hjälpmotorerna": "hjälpmotor",
    "hjälpmotorernas": "hjälpmotor",
    "hjälpmotorers": "hjälpmotor",
    "hjälpmotorn": "hjälpmotor",
    "hjälpmotorns": "hjälpmotor",
    "hjälpmotors": "hjälpmotor",
    "hjälporganisationen": "hjälporganisation",
    "hjälporganisationens": "hjälporganisation",
    "hjälporganisationer": "hjälporganisation",
    "hjälporganisationerna": "hjälporganisation",
    "hjälporganisationernas": "hjälporganisation",
    "hjälporganisationers": "hjälporganisation",
    "hjälporganisations": "hjälporganisation",
    "hjälpred": "hjälpreda",
    "hjälpredan": "hjälpreda",
    "hjälpredans": "hjälpreda",
    "hjälpredas": "hjälpreda",
    "hjälprede": "hjälpreda",
    "hjälpredor": "hjälpreda",
    "hjälpredorna": "hjälpreda",
    "hjälpredornas": "hjälpreda",
    "hjälpredors": "hjälpreda",
    "hjälpreds": "hjälpreda",
    "hjälps": "hjälpa",
    "hjälpsamheten": "hjälpsamhet",
    "hjälpsamhetens": "hjälpsamhet",
    "hjälpsamheter": "hjälpsamhet",
    "hjälpsamheterna": "hjälpsamhet",
    "hjälpsamheternas": "hjälpsamhet",
    "hjälpsamheters": "hjälpsamhet",
    "hjälpsamhets": "hjälpsamhet",
    "hjälpsamma": "hjälpsam",
    "hjälpsammare": "hjälpsam",
    "hjälpsammares": "hjälpsam",
    "hjälpsammas": "hjälpsam",
    "hjälpsammast": "hjälpsam",
    "hjälpsammaste": "hjälpsam",
    "hjälpsammastes": "hjälpsam",
    "hjälpsammasts": "hjälpsam",
    "hjälpsamme": "hjälpsam",
    "hjälpsammes": "hjälpsam",
    "hjälpsams": "hjälpsam",
    "hjälpsamt": "hjälpsam",
    "hjälpsamts": "hjälpsam",
    "hjälpspråken": "hjälpspråk",
    "hjälpspråkens": "hjälpspråk",
    "hjälpspråket": "hjälpspråk",
    "hjälpspråkets": "hjälpspråk",
    "hjälpspråks": "hjälpspråk",
    "hjälpsändningar": "hjälpsändning",
    "hjälpsändningarna": "hjälpsändning",
    "hjälpsändningarnas": "hjälpsändning",
    "hjälpsändningars": "hjälpsändning",
    "hjälpsändningen": "hjälpsändning",
    "hjälpsändningens": "hjälpsändning",
    "hjälpsändnings": "hjälpsändning",
    "hjälpt": "hjälpa",
    "hjälpta": "hjälpa",
    "hjälptas": "hjälpa",
    "hjälpte": "hjälpa",
    "hjälptes": "hjälpa",
    "hjälptruppen": "hjälptrupp",
    "hjälptruppens": "hjälptrupp",
    "hjälptrupper": "hjälptrupp",
    "hjälptrupperna": "hjälptrupp",
    "hjälptruppernas": "hjälptrupp",
    "hjälptruppers": "hjälptrupp",
    "hjälptrupps": "hjälptrupp",
    "hjälpts": "hjälpa",
    "hjälpverben": "hjälpverb",
    "hjälpverbens": "hjälpverb",
    "hjälpverbet": "hjälpverb",
    "hjälpverbets": "hjälpverb",
    "hjälpverbs": "hjälpverb",
    "hjälpvetenskapen": "hjälpvetenskap",
    "hjälpvetenskapens": "hjälpvetenskap",
    "hjälpvetenskaper": "hjälpvetenskap",
    "hjälpvetenskaperna": "hjälpvetenskap",
    "hjälpvetenskapernas": "hjälpvetenskap",
    "hjälpvetenskapers": "hjälpvetenskap",
    "hjälpvetenskaps": "hjälpvetenskap",
    "hjältar": "hjälte",
    "hjältarna": "hjälte",
    "hjältarnas": "hjälte",
    "hjältars": "hjälte",
    "hjältbragden": "hjältbragd",
    "hjältbragdens": "hjältbragd",
    "hjältbragder": "hjältbragd",
    "hjältbragderna": "hjältbragd",
    "hjältbragdernas": "hjältbragd",
    "hjältbragders": "hjältbragd",
    "hjältbragds": "hjältbragd",
    "hjältebragden": "hjältebragd",
    "hjältebragdens": "hjältebragd",
    "hjältebragder": "hjältebragd",
    "hjältebragderna": "hjältebragd",
    "hjältebragdernas": "hjältebragd",
    "hjältebragders": "hjältebragd",
    "hjältebragds": "hjältebragd",
    "hjältedaterna": "hjältedater",
    "hjältedaternas": "hjältedater",
    "hjältedaters": "hjältedater",
    "hjältedats": "hjältedater",
    "hjältedyrkans": "hjältedyrkan",
    "hjältedåden": "hjältedåd",
    "hjältedådens": "hjältedåd",
    "hjältedådet": "hjältedåd",
    "hjältedådets": "hjältedåd",
    "hjältedåds": "hjältedåd",
    "hjältehundar": "hjältehund",
    "hjältehundarna": "hjältehund",
    "hjältehundarnas": "hjältehund",
    "hjältehundars": "hjältehund",
    "hjältehunden": "hjältehund",
    "hjältehundens": "hjältehund",
    "hjältehunds": "hjältehund",
    "hjältemodet": "hjältemod",
    "hjältemodets": "hjältemod",
    "hjältemodiga": "hjältemodig",
    "hjältemodigare": "hjältemodig",
    "hjältemodigares": "hjältemodig",
    "hjältemodigas": "hjältemodig",
    "hjältemodigast": "hjältemodig",
    "hjältemodigaste": "hjältemodig",
    "hjältemodigastes": "hjältemodig",
    "hjältemodigasts": "hjältemodig",
    "hjältemodige": "hjältemodig",
    "hjältemodiges": "hjältemodig",
    "hjältemodigheten": "hjältemodighet",
    "hjältemodighetens": "hjältemodighet",
    "hjältemodighets": "hjältemodighet",
    "hjältemodigs": "hjältemodig",
    "hjältemodigt": "hjältemodig",
    "hjältemodigts": "hjältemodig",
    "hjältemods": "hjältemod",
    "hjälten": "hjälte",
    "hjältens": "hjälte",
    "hjälteporträtten": "hjälteporträtt",
    "hjälteporträttens": "hjälteporträtt",
    "hjälteporträttet": "hjälteporträtt",
    "hjälteporträttets": "hjälteporträtt",
    "hjälteporträtts": "hjälteporträtt",
    "hjältes": "hjälte",
    "hjältesagan": "hjältesaga",
    "hjältesagans": "hjältesaga",
    "hjältesagas": "hjältesaga",
    "hjältesage": "hjältesaga",
    "hjältesago": "hjältesaga",
    "hjältesagor": "hjältesaga",
    "hjältesagorna": "hjältesaga",
    "hjältesagornas": "hjältesaga",
    "hjältesagors": "hjältesaga",
    "hjältestatusen": "hjältestatus",
    "hjältestatusens": "hjältestatus",
    "hjältinnan": "hjältinna",
    "hjältinnans": "hjältinna",
    "hjältinnas": "hjältinna",
    "hjältinne": "hjältinna",
    "hjältinnor": "hjältinna",
    "hjältinnorna": "hjältinna",
    "hjältinnornas": "hjältinna",
    "hjältinnors": "hjältinna",
    "hjärn": "hjärna",
    "hjärnaktiviteten": "hjärnaktivitet",
    "hjärnaktivitetens": "hjärnaktivitet",
    "hjärnaktiviteter": "hjärnaktivitet",
    "hjärnaktiviteterna": "hjärnaktivitet",
    "hjärnaktiviteternas": "hjärnaktivitet",
    "hjärnaktiviteters": "hjärnaktivitet",
    "hjärnaktivitets": "hjärnaktivitet",
    "hjärnan": "hjärna",
    "hjärnans": "hjärna",
    "hjärnas": "hjärna",
    "hjärnatrofien": "hjärnatrofi",
    "hjärnatrofiens": "hjärnatrofi",
    "hjärnatrofier": "hjärnatrofi",
    "hjärnatrofierna": "hjärnatrofi",
    "hjärnatrofiernas": "hjärnatrofi",
    "hjärnatrofiers": "hjärnatrofi",
    "hjärnatrofin": "hjärnatrofi",
    "hjärnatrofins": "hjärnatrofi",
    "hjärnatrofis": "hjärnatrofi",
    "hjärnbalkar": "hjärnbalk",
    "hjärnbalkarna": "hjärnbalk",
    "hjärnbalkarnas": "hjärnbalk",
    "hjärnbalkars": "hjärnbalk",
    "hjärnbalken": "hjärnbalk",
    "hjärnbalkens": "hjärnbalk",
    "hjärnbalks": "hjärnbalk",
    "hjärnbarken": "hjärnbark",
    "hjärnbarkens": "hjärnbark",
    "hjärnbarks": "hjärnbark",
    "hjärnblödningar": "hjärnblödning",
    "hjärnblödningarna": "hjärnblödning",
    "hjärnblödningarnas": "hjärnblödning",
    "hjärnblödningars": "hjärnblödning",
    "hjärnblödningen": "hjärnblödning",
    "hjärnblödningens": "hjärnblödning",
    "hjärnblödnings": "hjärnblödning",
    "hjärnbyten": "hjärnbyte",
    "hjärnbytena": "hjärnbyte",
    "hjärnbytenas": "hjärnbyte",
    "hjärnbytens": "hjärnbyte",
    "hjärnbytes": "hjärnbyte",
    "hjärnbytet": "hjärnbyte",
    "hjärnbytets": "hjärnbyte",
    "hjärncellen": "hjärncell",
    "hjärncellens": "hjärncell",
    "hjärnceller": "hjärncell",
    "hjärncellerna": "hjärncell",
    "hjärncellernas": "hjärncell",
    "hjärncellers": "hjärncell",
    "hjärncells": "hjärncell",
    "hjärndelar": "hjärndel",
    "hjärndelarna": "hjärndel",
    "hjärndelarnas": "hjärndel",
    "hjärndelars": "hjärndel",
    "hjärndelen": "hjärndel",
    "hjärndelens": "hjärndel",
    "hjärndels": "hjärndel",
    "hjärndöda": "hjärndöd",
    "hjärndödare": "hjärndöd",
    "hjärndödares": "hjärndöd",
    "hjärndödas": "hjärndöd",
    "hjärndödast": "hjärndöd",
    "hjärndödaste": "hjärndöd",
    "hjärndödastes": "hjärndöd",
    "hjärndödasts": "hjärndöd",
    "hjärndöde": "hjärndöd",
    "hjärndöden": "hjärndöd",
    "hjärndödens": "hjärndöd",
    "hjärndödes": "hjärndöd",
    "hjärndöds": "hjärndöd",
    "hjärndött": "hjärndöd",
    "hjärndötts": "hjärndöd",
    "hjärne": "hjärna",
    "hjärnforskningen": "hjärnforskning",
    "hjärnforskningens": "hjärnforskning",
    "hjärnforsknings": "hjärnforskning",
    "hjärngymnastiken": "hjärngymnastik",
    "hjärngymnastikens": "hjärngymnastik",
    "hjärngymnastiks": "hjärngymnastik",
    "hjärngympan": "hjärngympa",
    "hjärngympans": "hjärngympa",
    "hjärngympas": "hjärngympa",
    "hjärngympor": "hjärngympa",
    "hjärngymporna": "hjärngympa",
    "hjärngympornas": "hjärngympa",
    "hjärngympors": "hjärngympa",
    "hjärnhalv": "hjärnhalva",
    "hjärnhalvan": "hjärnhalva",
    "hjärnhalvans": "hjärnhalva",
    "hjärnhalvas": "hjärnhalva",
    "hjärnhalve": "hjärnhalva",
    "hjärnhalvor": "hjärnhalva",
    "hjärnhalvorna": "hjärnhalva",
    "hjärnhalvornas": "hjärnhalva",
    "hjärnhalvors": "hjärnhalva",
    "hjärnhalvs": "hjärnhalva",
    "hjärnhinnan": "hjärnhinna",
    "hjärnhinnans": "hjärnhinna",
    "hjärnhinnas": "hjärnhinna",
    "hjärnhinne": "hjärnhinna",
    "hjärnhinneinflammationen": "hjärnhinneinflammation",
    "hjärnhinneinflammationens": "hjärnhinneinflammation",
    "hjärnhinneinflammationer": "hjärnhinneinflammation",
    "hjärnhinneinflammationerna": "hjärnhinneinflammation",
    "hjärnhinneinflammationernas": "hjärnhinneinflammation",
    "hjärnhinneinflammationers": "hjärnhinneinflammation",
    "hjärnhinneinflammations": "hjärnhinneinflammation",
    "hjärnhinnor": "hjärnhinna",
    "hjärnhinnorna": "hjärnhinna",
    "hjärnhinnornas": "hjärnhinna",
    "hjärnhinnors": "hjärnhinna",
    "hjärninflammationen": "hjärninflammation",
    "hjärninflammationens": "hjärninflammation",
    "hjärninflammationer": "hjärninflammation",
    "hjärninflammationerna": "hjärninflammation",
    "hjärninflammationernas": "hjärninflammation",
    "hjärninflammationers": "hjärninflammation",
    "hjärninflammations": "hjärninflammation",
    "hjärnintresserade": "hjärnintresserad",
    "hjärnintresserades": "hjärnintresserad",
    "hjärnintresserads": "hjärnintresserad",
    "hjärnintresserat": "hjärnintresserad",
    "hjärnintresserats": "hjärnintresserad",
    "hjärnoperationen": "hjärnoperation",
    "hjärnoperationens": "hjärnoperation",
    "hjärnoperationer": "hjärnoperation",
    "hjärnoperationerna": "hjärnoperation",
    "hjärnoperationernas": "hjärnoperation",
    "hjärnoperationers": "hjärnoperation",
    "hjärnoperations": "hjärnoperation",
    "hjärnor": "hjärna",
    "hjärnorna": "hjärna",
    "hjärnornas": "hjärna",
    "hjärnors": "hjärna",
    "hjärns": "hjärna",
    "hjärnsjukdomar": "hjärnsjukdom",
    "hjärnsjukdomarna": "hjärnsjukdom",
    "hjärnsjukdomarnas": "hjärnsjukdom",
    "hjärnsjukdomars": "hjärnsjukdom",
    "hjärnsjukdomen": "hjärnsjukdom",
    "hjärnsjukdomens": "hjärnsjukdom",
    "hjärnsjukdoms": "hjärnsjukdom",
    "hjärnskadade": "hjärnskadad",
    "hjärnskadades": "hjärnskadad",
    "hjärnskadads": "hjärnskadad",
    "hjärnskadan": "hjärnskada",
    "hjärnskadans": "hjärnskada",
    "hjärnskadas": "hjärnskada",
    "hjärnskadat": "hjärnskadad",
    "hjärnskadats": "hjärnskadad",
    "hjärnskade": "hjärnskada",
    "hjärnskador": "hjärnskada",
    "hjärnskadorna": "hjärnskada",
    "hjärnskadornas": "hjärnskada",
    "hjärnskadors": "hjärnskada",
    "hjärnskakningar": "hjärnskakning",
    "hjärnskakningarna": "hjärnskakning",
    "hjärnskakningarnas": "hjärnskakning",
    "hjärnskakningars": "hjärnskakning",
    "hjärnskakningen": "hjärnskakning",
    "hjärnskakningens": "hjärnskakning",
    "hjärnskaknings": "hjärnskakning",
    "hjärnskålar": "hjärnskål",
    "hjärnskålarna": "hjärnskål",
    "hjärnskålarnas": "hjärnskål",
    "hjärnskålars": "hjärnskål",
    "hjärnskålen": "hjärnskål",
    "hjärnskålens": "hjärnskål",
    "hjärnskåls": "hjärnskål",
    "hjärnsläppen": "hjärnsläpp",
    "hjärnsläppens": "hjärnsläpp",
    "hjärnsläppet": "hjärnsläpp",
    "hjärnsläppets": "hjärnsläpp",
    "hjärnsläpps": "hjärnsläpp",
    "hjärnspöken": "hjärnspöke",
    "hjärnspökena": "hjärnspöke",
    "hjärnspökenas": "hjärnspöke",
    "hjärnspökens": "hjärnspöke",
    "hjärnspökes": "hjärnspöke",
    "hjärnspöket": "hjärnspöke",
    "hjärnspökets": "hjärnspöke",
    "hjärnspöks": "hjärnspöke",
    "hjärnstammar": "hjärnstam",
    "hjärnstammarna": "hjärnstam",
    "hjärnstammarnas": "hjärnstam",
    "hjärnstammars": "hjärnstam",
    "hjärnstammen": "hjärnstam",
    "hjärnstammens": "hjärnstam",
    "hjärnstams": "hjärnstam",
    "hjärnstormar": "hjärnstorm",
    "hjärnstormarna": "hjärnstorm",
    "hjärnstormarnas": "hjärnstorm",
    "hjärnstormars": "hjärnstorm",
    "hjärnstormen": "hjärnstorm",
    "hjärnstormens": "hjärnstorm",
    "hjärnstorms": "hjärnstorm",
    "hjärntrusten": "hjärntrust",
    "hjärntrustens": "hjärntrust",
    "hjärntruster": "hjärntrust",
    "hjärntrusterna": "hjärntrust",
    "hjärntrusternas": "hjärntrust",
    "hjärntrusters": "hjärntrust",
    "hjärntrusts": "hjärntrust",
    "hjärntumören": "hjärntumör",
    "hjärntumörens": "hjärntumör",
    "hjärntumörer": "hjärntumör",
    "hjärntumörerna": "hjärntumör",
    "hjärntumörernas": "hjärntumör",
    "hjärntumörers": "hjärntumör",
    "hjärntumörs": "hjärntumör",
    "hjärntvätt": "hjärntvätta",
    "hjärntvättad": "hjärntvätta",
    "hjärntvättade": "hjärntvätta",
    "hjärntvättades": "hjärntvätta",
    "hjärntvättads": "hjärntvätta",
    "hjärntvättande": "hjärntvätta",
    "hjärntvättanden": "hjärntvättande",
    "hjärntvättandena": "hjärntvättande",
    "hjärntvättandenas": "hjärntvättande",
    "hjärntvättandens": "hjärntvättande",
    "hjärntvättandes": "hjärntvättande",
    "hjärntvättandet": "hjärntvättande",
    "hjärntvättandets": "hjärntvättande",
    "hjärntvättar": "hjärntvätta",
    "hjärntvättas": "hjärntvätta",
    "hjärntvättat": "hjärntvätta",
    "hjärntvättats": "hjärntvätta",
    "hjärntvätten": "hjärntvätt",
    "hjärntvättens": "hjärntvätt",
    "hjärntvätts": "hjärntvätt",
    "hjärnvindlingar": "hjärnvindling",
    "hjärnvindlingarna": "hjärnvindling",
    "hjärnvindlingarnas": "hjärnvindling",
    "hjärnvindlingars": "hjärnvindling",
    "hjärnvindlingen": "hjärnvindling",
    "hjärnvindlingens": "hjärnvindling",
    "hjärnvindlings": "hjärnvindling",
    "hjärnvolymen": "hjärnvolym",
    "hjärnvolymens": "hjärnvolym",
    "hjärnvolymer": "hjärnvolym",
    "hjärnvolymerna": "hjärnvolym",
    "hjärnvolymernas": "hjärnvolym",
    "hjärnvolymers": "hjärnvolym",
    "hjärnvolyms": "hjärnvolym",
    "hjärt": "hjärta",
    "hjärt-lungräddningen": "hjärt-lungräddning",
    "hjärt-lungräddningens": "hjärt-lungräddning",
    "hjärt-lungräddnings": "hjärt-lungräddning",
    "hjärtaktiviteten": "hjärtaktivitet",
    "hjärtaktivitetens": "hjärtaktivitet",
    "hjärtaktiviteter": "hjärtaktivitet",
    "hjärtaktiviteterna": "hjärtaktivitet",
    "hjärtaktiviteternas": "hjärtaktivitet",
    "hjärtaktiviteters": "hjärtaktivitet",
    "hjärtaktivitets": "hjärtaktivitet",
    "hjärtan": "hjärta",
    "hjärtana": "hjärta",
    "hjärtanas": "hjärta",
    "hjärtans": "hjärta",
    "hjärtansfröjden": "hjärtansfröjd",
    "hjärtansfröjdens": "hjärtansfröjd",
    "hjärtansfröjds": "hjärtansfröjd",
    "hjärtanskärs": "hjärtanskär",
    "hjärtas": "hjärta",
    "hjärtat": "hjärta",
    "hjärtats": "hjärta",
    "hjärtattacken": "hjärtattack",
    "hjärtattackens": "hjärtattack",
    "hjärtattacker": "hjärtattack",
    "hjärtattackerna": "hjärtattack",
    "hjärtattackernas": "hjärtattack",
    "hjärtattackers": "hjärtattack",
    "hjärtattacks": "hjärtattack",
    "hjärtbladen": "hjärtblad",
    "hjärtbladens": "hjärtblad",
    "hjärtbladet": "hjärtblad",
    "hjärtbladets": "hjärtblad",
    "hjärtblads": "hjärtblad",
    "hjärteangelägenheten": "hjärteangelägenhet",
    "hjärteangelägenhetens": "hjärteangelägenhet",
    "hjärteangelägenheter": "hjärteangelägenhet",
    "hjärteangelägenheterna": "hjärteangelägenhet",
    "hjärteangelägenheternas": "hjärteangelägenhet",
    "hjärteangelägenheters": "hjärteangelägenhet",
    "hjärteangelägenhets": "hjärteangelägenhet",
    "hjärtefrågan": "hjärtefråga",
    "hjärtefrågans": "hjärtefråga",
    "hjärtefrågas": "hjärtefråga",
    "hjärtefråge": "hjärtefråga",
    "hjärtefrågor": "hjärtefråga",
    "hjärtefrågorna": "hjärtefråga",
    "hjärtefrågornas": "hjärtefråga",
    "hjärtefrågors": "hjärtefråga",
    "hjärtegoda": "hjärtegod",
    "hjärtegodare": "hjärtegod",
    "hjärtegodares": "hjärtegod",
    "hjärtegodas": "hjärtegod",
    "hjärtegodast": "hjärtegod",
    "hjärtegodaste": "hjärtegod",
    "hjärtegodastes": "hjärtegod",
    "hjärtegodasts": "hjärtegod",
    "hjärtegode": "hjärtegod",
    "hjärtegodes": "hjärtegod",
    "hjärtegodheten": "hjärtegodhet",
    "hjärtegodhetens": "hjärtegodhet",
    "hjärtegodhets": "hjärtegodhet",
    "hjärtegods": "hjärtegod",
    "hjärtegott": "hjärtegod",
    "hjärtegotts": "hjärtegod",
    "hjärtegrynen": "hjärtegryn",
    "hjärtegrynens": "hjärtegryn",
    "hjärtegrynet": "hjärtegryn",
    "hjärtegrynets": "hjärtegryn",
    "hjärtegryns": "hjärtegryn",
    "hjärtegullen": "hjärtegull",
    "hjärtegullens": "hjärtegull",
    "hjärtegullet": "hjärtegull",
    "hjärtegullets": "hjärtegull",
    "hjärtegulls": "hjärtegull",
    "hjärtekrossar": "hjärtekrossare",
    "hjärtekrossaren": "hjärtekrossare",
    "hjärtekrossarens": "hjärtekrossare",
    "hjärtekrossares": "hjärtekrossare",
    "hjärtekrossarna": "hjärtekrossare",
    "hjärtekrossarnas": "hjärtekrossare",
    "hjärtekvalen": "hjärtekval",
    "hjärtekvalens": "hjärtekval",
    "hjärtekvalet": "hjärtekval",
    "hjärtekvalets": "hjärtekval",
    "hjärtekvals": "hjärtekval",
    "hjärtern": "hjärter",
    "hjärterna": "hjärter",
    "hjärternas": "hjärter",
    "hjärterns": "hjärter",
    "hjärteroten": "hjärterot",
    "hjärterotens": "hjärterot",
    "hjärterots": "hjärterot",
    "hjärters": "hjärter",
    "hjärterummet": "hjärterum",
    "hjärterummets": "hjärterum",
    "hjärterums": "hjärterum",
    "hjärterötter": "hjärterot",
    "hjärterötterna": "hjärterot",
    "hjärterötternas": "hjärterot",
    "hjärterötters": "hjärterot",
    "hjärtesaken": "hjärtesak",
    "hjärtesakens": "hjärtesak",
    "hjärtesaker": "hjärtesak",
    "hjärtesakerna": "hjärtesak",
    "hjärtesakernas": "hjärtesak",
    "hjärtesakers": "hjärtesak",
    "hjärtesaks": "hjärtesak",
    "hjärtesuckar": "hjärtesuck",
    "hjärtesuckarna": "hjärtesuck",
    "hjärtesuckarnas": "hjärtesuck",
    "hjärtesuckars": "hjärtesuck",
    "hjärtesucken": "hjärtesuck",
    "hjärtesuckens": "hjärtesuck",
    "hjärtesucks": "hjärtesuck",
    "hjärtetrakten": "hjärtetrakt",
    "hjärtetraktens": "hjärtetrakt",
    "hjärtetrakter": "hjärtetrakt",
    "hjärtetrakterna": "hjärtetrakt",
    "hjärtetrakternas": "hjärtetrakt",
    "hjärtetrakters": "hjärtetrakt",
    "hjärtetrakts": "hjärtetrakt",
    "hjärtevännen": "hjärtevän",
    "hjärtevännens": "hjärtevän",
    "hjärtevänner": "hjärtevän",
    "hjärtevännerna": "hjärtevän",
    "hjärtevännernas": "hjärtevän",
    "hjärtevänners": "hjärtevän",
    "hjärteväns": "hjärtevän",
    "hjärtfelen": "hjärtfel",
    "hjärtfelens": "hjärtfel",
    "hjärtfelet": "hjärtfel",
    "hjärtfelets": "hjärtfel",
    "hjärtfels": "hjärtfel",
    "hjärtflimmers": "hjärtflimmer",
    "hjärtflimret": "hjärtflimmer",
    "hjärtflimrets": "hjärtflimmer",
    "hjärtformade": "hjärtformad",
    "hjärtformades": "hjärtformad",
    "hjärtformads": "hjärtformad",
    "hjärtformat": "hjärtformad",
    "hjärtformats": "hjärtformad",
    "hjärtformiga": "hjärtformig",
    "hjärtformigare": "hjärtformig",
    "hjärtformigares": "hjärtformig",
    "hjärtformigas": "hjärtformig",
    "hjärtformigast": "hjärtformig",
    "hjärtformigaste": "hjärtformig",
    "hjärtformigastes": "hjärtformig",
    "hjärtformigasts": "hjärtformig",
    "hjärtformige": "hjärtformig",
    "hjärtformiges": "hjärtformig",
    "hjärtformigs": "hjärtformig",
    "hjärtformigt": "hjärtformig",
    "hjärtformigts": "hjärtformig",
    "hjärtinfarkten": "hjärtinfarkt",
    "hjärtinfarktens": "hjärtinfarkt",
    "hjärtinfarkter": "hjärtinfarkt",
    "hjärtinfarkterna": "hjärtinfarkt",
    "hjärtinfarkternas": "hjärtinfarkt",
    "hjärtinfarkters": "hjärtinfarkt",
    "hjärtinfarkts": "hjärtinfarkt",
    "hjärtinnerliga": "hjärtinnerlig",
    "hjärtinnerligare": "hjärtinnerlig",
    "hjärtinnerligares": "hjärtinnerlig",
    "hjärtinnerligas": "hjärtinnerlig",
    "hjärtinnerligast": "hjärtinnerlig",
    "hjärtinnerligaste": "hjärtinnerlig",
    "hjärtinnerligastes": "hjärtinnerlig",
    "hjärtinnerligasts": "hjärtinnerlig",
    "hjärtinnerlige": "hjärtinnerlig",
    "hjärtinnerliges": "hjärtinnerlig",
    "hjärtinnerligheten": "hjärtinnerlighet",
    "hjärtinnerlighetens": "hjärtinnerlighet",
    "hjärtinnerligheter": "hjärtinnerlighet",
    "hjärtinnerligheterna": "hjärtinnerlighet",
    "hjärtinnerligheternas": "hjärtinnerlighet",
    "hjärtinnerligheters": "hjärtinnerlighet",
    "hjärtinnerlighets": "hjärtinnerlighet",
    "hjärtinnerligs": "hjärtinnerlig",
    "hjärtinnerligt": "hjärtinnerlig",
    "hjärtinnerligts": "hjärtinnerlig",
    "hjärtinsufficiensen": "hjärtinsufficiens",
    "hjärtinsufficiensens": "hjärtinsufficiens",
    "hjärtklaffar": "hjärtklaff",
    "hjärtklaffarna": "hjärtklaff",
    "hjärtklaffarnas": "hjärtklaff",
    "hjärtklaffars": "hjärtklaff",
    "hjärtklaffen": "hjärtklaff",
    "hjärtklaffens": "hjärtklaff",
    "hjärtklaffs": "hjärtklaff",
    "hjärtklappningar": "hjärtklappning",
    "hjärtklappningarna": "hjärtklappning",
    "hjärtklappningarnas": "hjärtklappning",
    "hjärtklappningars": "hjärtklappning",
    "hjärtklappningen": "hjärtklappning",
    "hjärtklappningens": "hjärtklappning",
    "hjärtklappnings": "hjärtklappning",
    "hjärtkrampen": "hjärtkramp",
    "hjärtkrampens": "hjärtkramp",
    "hjärtkramper": "hjärtkramp",
    "hjärtkramperna": "hjärtkramp",
    "hjärtkrampernas": "hjärtkramp",
    "hjärtkrampers": "hjärtkramp",
    "hjärtkramps": "hjärtkramp",
    "hjärtliga": "hjärtlig",
    "hjärtligare": "hjärtlig",
    "hjärtligares": "hjärtlig",
    "hjärtligas": "hjärtlig",
    "hjärtligast": "hjärtlig",
    "hjärtligaste": "hjärtlig",
    "hjärtligastes": "hjärtlig",
    "hjärtligasts": "hjärtlig",
    "hjärtlige": "hjärtlig",
    "hjärtliges": "hjärtlig",
    "hjärtligheten": "hjärtlighet",
    "hjärtlighetens": "hjärtlighet",
    "hjärtligheter": "hjärtlighet",
    "hjärtligheterna": "hjärtlighet",
    "hjärtligheternas": "hjärtlighet",
    "hjärtligheters": "hjärtlighet",
    "hjärtlighets": "hjärtlighet",
    "hjärtligs": "hjärtlig",
    "hjärtligt": "hjärtlig",
    "hjärtligts": "hjärtlig",
    "hjärtljuden": "hjärtljud",
    "hjärtljudens": "hjärtljud",
    "hjärtljudet": "hjärtljud",
    "hjärtljudets": "hjärtljud",
    "hjärtljuds": "hjärtljud",
    "hjärtlungmaskinen": "hjärtlungmaskin",
    "hjärtlungmaskinens": "hjärtlungmaskin",
    "hjärtlungmaskiner": "hjärtlungmaskin",
    "hjärtlungmaskinerna": "hjärtlungmaskin",
    "hjärtlungmaskinernas": "hjärtlungmaskin",
    "hjärtlungmaskiners": "hjärtlungmaskin",
    "hjärtlungmaskins": "hjärtlungmaskin",
    "hjärtlösa": "hjärtlös",
    "hjärtlösare": "hjärtlös",
    "hjärtlösares": "hjärtlös",
    "hjärtlösas": "hjärtlös",
    "hjärtlösast": "hjärtlös",
    "hjärtlösaste": "hjärtlös",
    "hjärtlösastes": "hjärtlös",
    "hjärtlösasts": "hjärtlös",
    "hjärtlöse": "hjärtlös",
    "hjärtlöses": "hjärtlös",
    "hjärtlösheten": "hjärtlöshet",
    "hjärtlöshetens": "hjärtlöshet",
    "hjärtlösheter": "hjärtlöshet",
    "hjärtlösheterna": "hjärtlöshet",
    "hjärtlösheternas": "hjärtlöshet",
    "hjärtlösheters": "hjärtlöshet",
    "hjärtlöshets": "hjärtlöshet",
    "hjärtlöst": "hjärtlös",
    "hjärtlösts": "hjärtlös",
    "hjärtmassagen": "hjärtmassage",
    "hjärtmassagens": "hjärtmassage",
    "hjärtmassages": "hjärtmassage",
    "hjärtmuskeln": "hjärtmuskel",
    "hjärtmuskelns": "hjärtmuskel",
    "hjärtmuskels": "hjärtmuskel",
    "hjärtmuskler": "hjärtmuskel",
    "hjärtmusklerna": "hjärtmuskel",
    "hjärtmusklernas": "hjärtmuskel",
    "hjärtmusklers": "hjärtmuskel",
    "hjärtmussel": "hjärtmussla",
    "hjärtmusslan": "hjärtmussla",
    "hjärtmusslans": "hjärtmussla",
    "hjärtmusslas": "hjärtmussla",
    "hjärtmussle": "hjärtmussla",
    "hjärtmusslor": "hjärtmussla",
    "hjärtmusslorna": "hjärtmussla",
    "hjärtmusslornas": "hjärtmussla",
    "hjärtmusslors": "hjärtmussla",
    "hjärtnupenheten": "hjärtnupenhet",
    "hjärtnupenhetens": "hjärtnupenhet",
    "hjärtnupenhets": "hjärtnupenhet",
    "hjärtnupens": "hjärtnupen",
    "hjärtnupet": "hjärtnupen",
    "hjärtnupets": "hjärtnupen",
    "hjärtnupna": "hjärtnupen",
    "hjärtnupnare": "hjärtnupen",
    "hjärtnupnares": "hjärtnupen",
    "hjärtnupnas": "hjärtnupen",
    "hjärtnupnast": "hjärtnupen",
    "hjärtnupnaste": "hjärtnupen",
    "hjärtnupnastes": "hjärtnupen",
    "hjärtnupnasts": "hjärtnupen",
    "hjärtnupne": "hjärtnupen",
    "hjärtnupnes": "hjärtnupen",
    "hjärtoperationen": "hjärtoperation",
    "hjärtoperationens": "hjärtoperation",
    "hjärtoperationer": "hjärtoperation",
    "hjärtoperationerna": "hjärtoperation",
    "hjärtoperationernas": "hjärtoperation",
    "hjärtoperationers": "hjärtoperation",
    "hjärtoperations": "hjärtoperation",
    "hjärtpunkten": "hjärtpunkt",
    "hjärtpunktens": "hjärtpunkt",
    "hjärtpunkter": "hjärtpunkt",
    "hjärtpunkterna": "hjärtpunkt",
    "hjärtpunkternas": "hjärtpunkt",
    "hjärtpunkters": "hjärtpunkt",
    "hjärtpunkts": "hjärtpunkt",
    "hjärtrytmen": "hjärtrytm",
    "hjärtrytmens": "hjärtrytm",
    "hjärtrytmer": "hjärtrytm",
    "hjärtrytmerna": "hjärtrytm",
    "hjärtrytmernas": "hjärtrytm",
    "hjärtrytmers": "hjärtrytm",
    "hjärtrytms": "hjärtrytm",
    "hjärts": "hjärta",
    "hjärtsjuka": "hjärtsjuk",
    "hjärtsjukare": "hjärtsjuk",
    "hjärtsjukares": "hjärtsjuk",
    "hjärtsjukas": "hjärtsjuk",
    "hjärtsjukast": "hjärtsjuk",
    "hjärtsjukaste": "hjärtsjuk",
    "hjärtsjukastes": "hjärtsjuk",
    "hjärtsjukasts": "hjärtsjuk",
    "hjärtsjukdomar": "hjärtsjukdom",
    "hjärtsjukdomarna": "hjärtsjukdom",
    "hjärtsjukdomarnas": "hjärtsjukdom",
    "hjärtsjukdomars": "hjärtsjukdom",
    "hjärtsjukdomen": "hjärtsjukdom",
    "hjärtsjukdomens": "hjärtsjukdom",
    "hjärtsjukdoms": "hjärtsjukdom",
    "hjärtsjuke": "hjärtsjuk",
    "hjärtsjukes": "hjärtsjuk",
    "hjärtsjuks": "hjärtsjuk",
    "hjärtsjukt": "hjärtsjuk",
    "hjärtsjukts": "hjärtsjuk",
    "hjärtslagen": "hjärtslag",
    "hjärtslagens": "hjärtslag",
    "hjärtslaget": "hjärtslag",
    "hjärtslagets": "hjärtslag",
    "hjärtslags": "hjärtslag",
    "hjärtstill": "hjärtstilla",
    "hjärtstillan": "hjärtstilla",
    "hjärtstillans": "hjärtstilla",
    "hjärtstillas": "hjärtstilla",
    "hjärtstille": "hjärtstilla",
    "hjärtstillor": "hjärtstilla",
    "hjärtstillorna": "hjärtstilla",
    "hjärtstillornas": "hjärtstilla",
    "hjärtstillors": "hjärtstilla",
    "hjärtstills": "hjärtstilla",
    "hjärtstoppen": "hjärtstopp",
    "hjärtstoppens": "hjärtstopp",
    "hjärtstoppet": "hjärtstopp",
    "hjärtstoppets": "hjärtstopp",
    "hjärtstopps": "hjärtstopp",
    "hjärtsvikten": "hjärtsvikt",
    "hjärtsviktens": "hjärtsvikt",
    "hjärtsvikts": "hjärtsvikt",
    "hjärtsäckar": "hjärtsäck",
    "hjärtsäckarna": "hjärtsäck",
    "hjärtsäckarnas": "hjärtsäck",
    "hjärtsäckars": "hjärtsäck",
    "hjärtsäcken": "hjärtsäck",
    "hjärtsäckens": "hjärtsäck",
    "hjärtsäcks": "hjärtsäck",
    "hjärttrakten": "hjärttrakt",
    "hjärttraktens": "hjärttrakt",
    "hjärttrakter": "hjärttrakt",
    "hjärttrakterna": "hjärttrakt",
    "hjärttrakternas": "hjärttrakt",
    "hjärttrakters": "hjärttrakt",
    "hjärttrakts": "hjärttrakt",
    "hjärttransplantationen": "hjärttransplantation",
    "hjärttransplantationens": "hjärttransplantation",
    "hjärttransplantationer": "hjärttransplantation",
    "hjärttransplantationerna": "hjärttransplantation",
    "hjärttransplantationernas": "hjärttransplantation",
    "hjärttransplantationers": "hjärttransplantation",
    "hjärttransplantations": "hjärttransplantation",
    "hjärtverksamheten": "hjärtverksamhet",
    "hjärtverksamhetens": "hjärtverksamhet",
    "hjärtverksamheter": "hjärtverksamhet",
    "hjärtverksamheterna": "hjärtverksamhet",
    "hjärtverksamheternas": "hjärtverksamhet",
    "hjärtverksamheters": "hjärtverksamhet",
    "hjärtverksamhets": "hjärtverksamhet",
    "hjärtängslans": "hjärtängslan",
    "hjärtängsliga": "hjärtängslig",
    "hjärtängsligare": "hjärtängslig",
    "hjärtängsligares": "hjärtängslig",
    "hjärtängsligas": "hjärtängslig",
    "hjärtängsligast": "hjärtängslig",
    "hjärtängsligaste": "hjärtängslig",
    "hjärtängsligastes": "hjärtängslig",
    "hjärtängsligasts": "hjärtängslig",
    "hjärtängslige": "hjärtängslig",
    "hjärtängsliges": "hjärtängslig",
    "hjärtängsligheten": "hjärtängslighet",
    "hjärtängslighetens": "hjärtängslighet",
    "hjärtängslighets": "hjärtängslighet",
    "hjärtängsligs": "hjärtängslig",
    "hjärtängsligt": "hjärtängslig",
    "hjärtängsligts": "hjärtängslig",
    "hjäss": "hjässa",
    "hjässan": "hjässa",
    "hjässans": "hjässa",
    "hjässas": "hjässa",
    "hjässbenen": "hjässben",
    "hjässbenens": "hjässben",
    "hjässbenet": "hjässben",
    "hjässbenets": "hjässben",
    "hjässbens": "hjässben",
    "hjässbjudningar": "hjässbjudning",
    "hjässbjudningarna": "hjässbjudning",
    "hjässbjudningarnas": "hjässbjudning",
    "hjässbjudningars": "hjässbjudning",
    "hjässbjudningen": "hjässbjudning",
    "hjässbjudningens": "hjässbjudning",
    "hjässbjudnings": "hjässbjudning",
    "hjässe": "hjässa",
    "hjässor": "hjässa",
    "hjässorna": "hjässa",
    "hjässornas": "hjässa",
    "hjässors": "hjässa",
    "hmongen": "hmong",
    "hmongens": "hmong",
    "hmonger": "hmong",
    "hmongerna": "hmong",
    "hmongernas": "hmong",
    "hmongers": "hmong",
    "hmongs": "hmong",
    "hoade": "hoa",
    "hoades": "hoa",
    "hoande": "hoa",
    "hoanden": "hoande",
    "hoandena": "hoande",
    "hoandenas": "hoande",
    "hoandens": "hoande",
    "hoandes": "hoande",
    "hoandet": "hoande",
    "hoandets": "hoande",
    "hoar": "hoa",
    "hoarna": "ho",
    "hoarnas": "ho",
    "hoars": "ho",
    "hoas": "hoa",
    "hoat": "hoa",
    "hoats": "hoa",
    "hobbier": "hobby",
    "hobbierna": "hobby",
    "hobbiernas": "hobby",
    "hobbiers": "hobby",
    "hobbies": "hobby",
    "hobbiesarna": "hobby",
    "hobbiesarnas": "hobby",
    "hobbyer": "hobby",
    "hobbyerna": "hobby",
    "hobbyernas": "hobby",
    "hobbyers": "hobby",
    "hobbymässiga": "hobbymässig",
    "hobbymässigare": "hobbymässig",
    "hobbymässigares": "hobbymässig",
    "hobbymässigas": "hobbymässig",
    "hobbymässigast": "hobbymässig",
    "hobbymässigaste": "hobbymässig",
    "hobbymässigastes": "hobbymässig",
    "hobbymässigasts": "hobbymässig",
    "hobbymässige": "hobbymässig",
    "hobbymässiges": "hobbymässig",
    "hobbymässigs": "hobbymässig",
    "hobbymässigt": "hobbymässig",
    "hobbymässigts": "hobbymässig",
    "hobbyn": "hobby",
    "hobbyns": "hobby",
    "hobbys": "hobby",
    "hobbysar": "hobby",
    "hobbysarna": "hobby",
    "hobbysarnas": "hobby",
    "hobbysars": "hobby",
    "hobbyutbildningar": "hobbyutbildning",
    "hobbyutbildningarna": "hobbyutbildning",
    "hobbyutbildningarnas": "hobbyutbildning",
    "hobbyutbildningars": "hobbyutbildning",
    "hobbyutbildningen": "hobbyutbildning",
    "hobbyutbildningens": "hobbyutbildning",
    "hobbyutbildnings": "hobbyutbildning",
    "hockey-bockeyn": "hockey-bockey",
    "hockey-bockeyns": "hockey-bockey",
    "hockey-bockeys": "hockey-bockey",
    "hockeyklubb": "hockeyklubba",
    "hockeyklubban": "hockeyklubba",
    "hockeyklubbans": "hockeyklubba",
    "hockeyklubbas": "hockeyklubba",
    "hockeyklubbe": "hockeyklubba",
    "hockeyklubbor": "hockeyklubba",
    "hockeyklubborna": "hockeyklubba",
    "hockeyklubbornas": "hockeyklubba",
    "hockeyklubbors": "hockeyklubba",
    "hockeyklubbs": "hockeyklubba",
    "hockeymässiga": "hockeymässig",
    "hockeymässigare": "hockeymässig",
    "hockeymässigares": "hockeymässig",
    "hockeymässigas": "hockeymässig",
    "hockeymässigast": "hockeymässig",
    "hockeymässigaste": "hockeymässig",
    "hockeymässigastes": "hockeymässig",
    "hockeymässigasts": "hockeymässig",
    "hockeymässige": "hockeymässig",
    "hockeymässiges": "hockeymässig",
    "hockeymässigs": "hockeymässig",
    "hockeymässigt": "hockeymässig",
    "hockeymässigts": "hockeymässig",
    "hockeyn": "hockey",
    "hockeyns": "hockey",
    "hockeyrören": "hockeyrör",
    "hockeyrörens": "hockeyrör",
    "hockeyröret": "hockeyrör",
    "hockeyrörets": "hockeyrör",
    "hockeyrörs": "hockeyrör",
    "hockeys": "hockey",
    "hockeyspelar": "hockeyspelare",
    "hockeyspelaren": "hockeyspelare",
    "hockeyspelarens": "hockeyspelare",
    "hockeyspelares": "hockeyspelare",
    "hockeyspelarna": "hockeyspelare",
    "hockeyspelarnas": "hockeyspelare",
    "hojade": "hoja",
    "hojades": "hoja",
    "hojande": "hoja",
    "hojanden": "hojande",
    "hojandena": "hojande",
    "hojandenas": "hojande",
    "hojandens": "hojande",
    "hojandes": "hojande",
    "hojandet": "hojande",
    "hojandets": "hojande",
    "hojar": "hoja",
    "hojarna": "hoj",
    "hojarnas": "hoj",
    "hojars": "hoj",
    "hojas": "hoja",
    "hojat": "hoja",
    "hojats": "hoja",
    "hojen": "hoj",
    "hojens": "hoj",
    "hojs": "hoj",
    "hojt": "hojta",
    "hojtade": "hojta",
    "hojtades": "hojta",
    "hojtande": "hojta",
    "hojtanden": "hojtande",
    "hojtandena": "hojtande",
    "hojtandenas": "hojtande",
    "hojtandens": "hojtande",
    "hojtandes": "hojtande",
    "hojtandet": "hojtande",
    "hojtandets": "hojtande",
    "hojtar": "hojta",
    "hojtas": "hojta",
    "hojtat": "hojta",
    "hojtats": "hojta",
    "hokus-pokusterapien": "hokus-pokusterapi",
    "hokus-pokusterapiens": "hokus-pokusterapi",
    "hokus-pokusterapier": "hokus-pokusterapi",
    "hokus-pokusterapierna": "hokus-pokusterapi",
    "hokus-pokusterapiernas": "hokus-pokusterapi",
    "hokus-pokusterapiers": "hokus-pokusterapi",
    "hokus-pokusterapin": "hokus-pokusterapi",
    "hokus-pokusterapins": "hokus-pokusterapi",
    "hokus-pokusterapis": "hokus-pokusterapi",
    "hokuspokuset": "hokuspokus",
    "hokuspokusets": "hokuspokus",
    "holdingbolagen": "holdingbolag",
    "holdingbolagens": "holdingbolag",
    "holdingbolaget": "holdingbolag",
    "holdingbolagets": "holdingbolag",
    "holdingbolags": "holdingbolag",
    "holismen": "holism",
    "holismens": "holism",
    "holismer": "holism",
    "holismerna": "holism",
    "holismernas": "holism",
    "holismers": "holism",
    "holisms": "holism",
    "holistiska": "holistisk",
    "holistiskare": "holistisk",
    "holistiskares": "holistisk",
    "holistiskas": "holistisk",
    "holistiskast": "holistisk",
    "holistiskaste": "holistisk",
    "holistiskastes": "holistisk",
    "holistiskasts": "holistisk",
    "holistiske": "holistisk",
    "holistiskes": "holistisk",
    "holistisks": "holistisk",
    "holistiskt": "holistisk",
    "holistiskts": "holistisk",
    "holkar": "holk",
    "holkarna": "holk",
    "holkarnas": "holk",
    "holkars": "holk",
    "holken": "holk",
    "holkens": "holk",
    "holks": "holk",
    "hollandaisen": "hollandaise",
    "hollandaisens": "hollandaise",
    "hollandaises": "hollandaise",
    "holländar": "holländare",
    "holländaren": "holländare",
    "holländarens": "holländare",
    "holländares": "holländare",
    "holländarna": "holländare",
    "holländarnas": "holländare",
    "holländsk": "holländska",
    "holländska": "holländsk",
    "holländskan": "holländska",
    "holländskans": "holländska",
    "holländskare": "holländsk",
    "holländskares": "holländsk",
    "holländskas": "holländska",
    "holländskast": "holländsk",
    "holländskaste": "holländsk",
    "holländskastes": "holländsk",
    "holländskasts": "holländsk",
    "holländske": "holländska",
    "holländskes": "holländsk",
    "holländskor": "holländska",
    "holländskorna": "holländska",
    "holländskornas": "holländska",
    "holländskors": "holländska",
    "holländsks": "holländsk",
    "holländskt": "holländsk",
    "holländskts": "holländsk",
    "holm": "holme",
    "holmar": "holme",
    "holmarna": "holme",
    "holmarnas": "holme",
    "holmars": "holme",
    "holmen": "holme",
    "holmens": "holme",
    "holmes": "holme",
    "holmgångar": "holmgång",
    "holmgångarna": "holmgång",
    "holmgångarnas": "holmgång",
    "holmgångars": "holmgång",
    "holmgången": "holmgång",
    "holmgångens": "holmgång",
    "holmgångs": "holmgång",
    "holmiet": "holmium",
    "holmiets": "holmium",
    "holmiumet": "holmium",
    "holmiumets": "holmium",
    "holmiums": "holmium",
    "holms": "holme",
    "holocens": "holocen",
    "holograferad": "holografera",
    "holograferade": "holografera",
    "holograferades": "holografera",
    "holograferads": "holografera",
    "holograferande": "holografera",
    "holograferanden": "holograferande",
    "holograferandena": "holograferande",
    "holograferandenas": "holograferande",
    "holograferandens": "holograferande",
    "holograferandes": "holograferande",
    "holograferandet": "holograferande",
    "holograferandets": "holograferande",
    "holograferar": "holografera",
    "holograferas": "holografera",
    "holograferat": "holografera",
    "holograferats": "holografera",
    "holograferbara": "holograferbar",
    "holograferbarare": "holograferbar",
    "holograferbarares": "holograferbar",
    "holograferbaras": "holograferbar",
    "holograferbarast": "holograferbar",
    "holograferbaraste": "holograferbar",
    "holograferbarastes": "holograferbar",
    "holograferbarasts": "holograferbar",
    "holograferbare": "holograferbar",
    "holograferbares": "holograferbar",
    "holograferbarheten": "holograferbarhet",
    "holograferbarhetens": "holograferbarhet",
    "holograferbarhets": "holograferbarhet",
    "holograferbars": "holograferbar",
    "holograferbart": "holograferbar",
    "holograferbarts": "holograferbar",
    "holograferingar": "holografering",
    "holograferingarna": "holografering",
    "holograferingarnas": "holografering",
    "holograferingars": "holografering",
    "holograferingen": "holografering",
    "holograferingens": "holografering",
    "holograferings": "holografering",
    "holografien": "holografi",
    "holografiens": "holografi",
    "holografin": "holografi",
    "holografins": "holografi",
    "holografis": "holografi",
    "hologrammen": "hologram",
    "hologrammens": "hologram",
    "hologrammet": "hologram",
    "hologrammets": "hologram",
    "holograms": "hologram",
    "holonymen": "holonym",
    "holonymens": "holonym",
    "holonymer": "holonym",
    "holonymerna": "holonym",
    "holonymernas": "holonym",
    "holonymers": "holonym",
    "holonymien": "holonymi",
    "holonymiens": "holonymi",
    "holonymier": "holonymi",
    "holonymierna": "holonymi",
    "holonymiernas": "holonymi",
    "holonymiers": "holonymi",
    "holonymin": "holonymi",
    "holonymins": "holonymi",
    "holonymis": "holonymi",
    "holonyms": "holonym",
    "holten": "holt",
    "holtens": "holt",
    "holtet": "holt",
    "holtets": "holt",
    "holts": "holt",
    "hom": "homma",
    "homeopaten": "homeopat",
    "homeopatens": "homeopat",
    "homeopater": "homeopat",
    "homeopaterna": "homeopat",
    "homeopaternas": "homeopat",
    "homeopaters": "homeopat",
    "homeopatien": "homeopati",
    "homeopatiens": "homeopati",
    "homeopatin": "homeopati",
    "homeopatins": "homeopati",
    "homeopatis": "homeopati",
    "homeopatiska": "homeopatisk",
    "homeopatiskare": "homeopatisk",
    "homeopatiskares": "homeopatisk",
    "homeopatiskas": "homeopatisk",
    "homeopatiskast": "homeopatisk",
    "homeopatiskaste": "homeopatisk",
    "homeopatiskastes": "homeopatisk",
    "homeopatiskasts": "homeopatisk",
    "homeopatiske": "homeopatisk",
    "homeopatiskes": "homeopatisk",
    "homeopatisks": "homeopatisk",
    "homeopatiskt": "homeopatisk",
    "homeopatiskts": "homeopatisk",
    "homeopats": "homeopat",
    "homeriska": "homerisk",
    "homeriskare": "homerisk",
    "homeriskares": "homerisk",
    "homeriskas": "homerisk",
    "homeriskast": "homerisk",
    "homeriskaste": "homerisk",
    "homeriskastes": "homerisk",
    "homeriskasts": "homerisk",
    "homeriske": "homerisk",
    "homeriskes": "homerisk",
    "homerisks": "homerisk",
    "homeriskt": "homerisk",
    "homeriskts": "homerisk",
    "homileten": "homilet",
    "homiletens": "homilet",
    "homileter": "homilet",
    "homileterna": "homilet",
    "homileternas": "homilet",
    "homileters": "homilet",
    "homiletiken": "homiletik",
    "homiletikens": "homiletik",
    "homiletiks": "homiletik",
    "homiletiska": "homiletisk",
    "homiletiskare": "homiletisk",
    "homiletiskares": "homiletisk",
    "homiletiskas": "homiletisk",
    "homiletiskast": "homiletisk",
    "homiletiskaste": "homiletisk",
    "homiletiskastes": "homiletisk",
    "homiletiskasts": "homiletisk",
    "homiletiske": "homiletisk",
    "homiletiskes": "homiletisk",
    "homiletisks": "homiletisk",
    "homiletiskt": "homiletisk",
    "homiletiskts": "homiletisk",
    "homilets": "homilet",
    "hommagen": "hommage",
    "hommagens": "hommage",
    "hommages": "hommage",
    "hommaget": "hommage",
    "hommagets": "hommage",
    "homman": "homma",
    "hommans": "homma",
    "hommas": "homma",
    "homme": "homma",
    "hommor": "homma",
    "hommorna": "homma",
    "hommornas": "homma",
    "hommors": "homma",
    "homofilen": "homofil",
    "homofilens": "homofil",
    "homofiler": "homofil",
    "homofilerna": "homofil",
    "homofilernas": "homofil",
    "homofilers": "homofil",
    "homofils": "homofil",
    "homofona": "homofon",
    "homofonare": "homofon",
    "homofonares": "homofon",
    "homofonas": "homofon",
    "homofonast": "homofon",
    "homofonaste": "homofon",
    "homofonastes": "homofon",
    "homofonasts": "homofon",
    "homofone": "homofon",
    "homofonen": "homofon",
    "homofonens": "homofon",
    "homofoner": "homofon",
    "homofonerna": "homofon",
    "homofonernas": "homofon",
    "homofoners": "homofon",
    "homofones": "homofon",
    "homofons": "homofon",
    "homofont": "homofon",
    "homofonts": "homofon",
    "homogena": "homogen",
    "homogenare": "homogen",
    "homogenares": "homogen",
    "homogenas": "homogen",
    "homogenast": "homogen",
    "homogenaste": "homogen",
    "homogenastes": "homogen",
    "homogenasts": "homogen",
    "homogene": "homogen",
    "homogenes": "homogen",
    "homogenheten": "homogenhet",
    "homogenhetens": "homogenhet",
    "homogenhets": "homogenhet",
    "homogeniserad": "homogenisera",
    "homogeniserade": "homogenisera",
    "homogeniserades": "homogenisera",
    "homogeniserads": "homogenisera",
    "homogeniserande": "homogenisera",
    "homogeniseranden": "homogeniserande",
    "homogeniserandena": "homogeniserande",
    "homogeniserandenas": "homogeniserande",
    "homogeniserandens": "homogeniserande",
    "homogeniserandes": "homogeniserande",
    "homogeniserandet": "homogeniserande",
    "homogeniserandets": "homogeniserande",
    "homogeniserar": "homogenisera",
    "homogeniseras": "homogenisera",
    "homogeniserat": "homogenisera",
    "homogeniserats": "homogenisera",
    "homogeniserbara": "homogeniserbar",
    "homogeniserbarare": "homogeniserbar",
    "homogeniserbarares": "homogeniserbar",
    "homogeniserbaras": "homogeniserbar",
    "homogeniserbarast": "homogeniserbar",
    "homogeniserbaraste": "homogeniserbar",
    "homogeniserbarastes": "homogeniserbar",
    "homogeniserbarasts": "homogeniserbar",
    "homogeniserbare": "homogeniserbar",
    "homogeniserbares": "homogeniserbar",
    "homogeniserbarheten": "homogeniserbarhet",
    "homogeniserbarhetens": "homogeniserbarhet",
    "homogeniserbarhets": "homogeniserbarhet",
    "homogeniserbars": "homogeniserbar",
    "homogeniserbart": "homogeniserbar",
    "homogeniserbarts": "homogeniserbar",
    "homogeniseringar": "homogenisering",
    "homogeniseringarna": "homogenisering",
    "homogeniseringarnas": "homogenisering",
    "homogeniseringars": "homogenisering",
    "homogeniseringen": "homogenisering",
    "homogeniseringens": "homogenisering",
    "homogeniserings": "homogenisering",
    "homogeniteten": "homogenitet",
    "homogenitetens": "homogenitet",
    "homogeniteter": "homogenitet",
    "homogeniteterna": "homogenitet",
    "homogeniteternas": "homogenitet",
    "homogeniteters": "homogenitet",
    "homogenitets": "homogenitet",
    "homogens": "homogen",
    "homogent": "homogen",
    "homogents": "homogen",
    "homografa": "homograf",
    "homografare": "homograf",
    "homografares": "homograf",
    "homografas": "homograf",
    "homografast": "homograf",
    "homografaste": "homograf",
    "homografastes": "homograf",
    "homografasts": "homograf",
    "homografe": "homograf",
    "homografen": "homograf",
    "homografens": "homograf",
    "homografer": "homograf",
    "homograferna": "homograf",
    "homografernas": "homograf",
    "homografers": "homograf",
    "homografes": "homograf",
    "homografs": "homograf",
    "homograft": "homograf",
    "homografts": "homograf",
    "homologa": "homolog",
    "homologare": "homolog",
    "homologares": "homolog",
    "homologas": "homolog",
    "homologast": "homolog",
    "homologaste": "homolog",
    "homologastes": "homolog",
    "homologasts": "homolog",
    "homologe": "homolog",
    "homologes": "homolog",
    "homologs": "homolog",
    "homologt": "homolog",
    "homologts": "homolog",
    "homonyma": "homonym",
    "homonymare": "homonym",
    "homonymares": "homonym",
    "homonymas": "homonym",
    "homonymast": "homonym",
    "homonymaste": "homonym",
    "homonymastes": "homonym",
    "homonymasts": "homonym",
    "homonyme": "homonym",
    "homonymen": "homonym",
    "homonymens": "homonym",
    "homonymer": "homonym",
    "homonymerna": "homonym",
    "homonymernas": "homonym",
    "homonymers": "homonym",
    "homonymes": "homonym",
    "homonymien": "homonymi",
    "homonymiens": "homonymi",
    "homonymier": "homonymi",
    "homonymierna": "homonymi",
    "homonymiernas": "homonymi",
    "homonymiers": "homonymi",
    "homonymin": "homonymi",
    "homonymins": "homonymi",
    "homonymis": "homonymi",
    "homonyms": "homonym",
    "homonymt": "homonym",
    "homonymts": "homonym",
    "homoparen": "homopar",
    "homoparens": "homopar",
    "homoparet": "homopar",
    "homoparets": "homopar",
    "homopars": "homopar",
    "homos": "homo",
    "homosexet": "homosex",
    "homosexets": "homosex",
    "homosexualiteten": "homosexualitet",
    "homosexualitetens": "homosexualitet",
    "homosexualiteter": "homosexualitet",
    "homosexualiteterna": "homosexualitet",
    "homosexualiteternas": "homosexualitet",
    "homosexualiteters": "homosexualitet",
    "homosexualitets": "homosexualitet",
    "homosexuella": "homosexuell",
    "homosexuellare": "homosexuell",
    "homosexuellares": "homosexuell",
    "homosexuellas": "homosexuell",
    "homosexuellast": "homosexuell",
    "homosexuellaste": "homosexuell",
    "homosexuellastes": "homosexuell",
    "homosexuellasts": "homosexuell",
    "homosexuelle": "homosexuell",
    "homosexuelles": "homosexuell",
    "homosexuells": "homosexuell",
    "homosexuellt": "homosexuell",
    "homosexuellts": "homosexuell",
    "homozygota": "homozygot",
    "homozygotare": "homozygot",
    "homozygotares": "homozygot",
    "homozygotas": "homozygot",
    "homozygotast": "homozygot",
    "homozygotaste": "homozygot",
    "homozygotastes": "homozygot",
    "homozygotasts": "homozygot",
    "homozygote": "homozygot",
    "homozygoten": "homozygot",
    "homozygotens": "homozygot",
    "homozygoter": "homozygot",
    "homozygoterna": "homozygot",
    "homozygoternas": "homozygot",
    "homozygoters": "homozygot",
    "homozygotes": "homozygot",
    "homozygots": "homozygot",
    "homoäktenskapen": "homoäktenskap",
    "homoäktenskapens": "homoäktenskap",
    "homoäktenskapet": "homoäktenskap",
    "homoäktenskapets": "homoäktenskap",
    "homoäktenskaps": "homoäktenskap",
    "homs": "homma",
    "hon": "hona",
    "honan": "hona",
    "honans": "hona",
    "honas": "hona",
    "honblom": "honblomma",
    "honblomman": "honblomma",
    "honblommans": "honblomma",
    "honblommas": "honblomma",
    "honblomme": "honblomma",
    "honblommor": "honblomma",
    "honblommorna": "honblomma",
    "honblommornas": "honblomma",
    "honblommors": "honblomma",
    "honbloms": "honblomma",
    "honduranen": "honduran",
    "honduranens": "honduran",
    "honduraner": "honduran",
    "honduranerna": "honduran",
    "honduranernas": "honduran",
    "honduraners": "honduran",
    "hondurans": "honduran",
    "honduranska": "honduransk",
    "honduranskan": "honduranska",
    "honduranskans": "honduranska",
    "honduranskare": "honduransk",
    "honduranskares": "honduransk",
    "honduranskas": "honduranska",
    "honduranskast": "honduransk",
    "honduranskaste": "honduransk",
    "honduranskastes": "honduransk",
    "honduranskasts": "honduransk",
    "honduranske": "honduranska",
    "honduranskes": "honduransk",
    "honduranskor": "honduranska",
    "honduranskorna": "honduranska",
    "honduranskornas": "honduranska",
    "honduranskors": "honduranska",
    "honduransks": "honduransk",
    "honduranskt": "honduransk",
    "honduranskts": "honduransk",
    "hone": "hona",
    "honkönet": "honkön",
    "honkönets": "honkön",
    "honköns": "honkön",
    "honliga": "honlig",
    "honligare": "honlig",
    "honligares": "honlig",
    "honligas": "honlig",
    "honligast": "honlig",
    "honligaste": "honlig",
    "honligastes": "honlig",
    "honligasts": "honlig",
    "honlige": "honlig",
    "honliges": "honlig",
    "honligs": "honlig",
    "honligt": "honlig",
    "honligts": "honlig",
    "honnetta": "honnett",
    "honnettare": "honnett",
    "honnettares": "honnett",
    "honnettas": "honnett",
    "honnettast": "honnett",
    "honnettaste": "honnett",
    "honnettastes": "honnett",
    "honnettasts": "honnett",
    "honnette": "honnett",
    "honnettes": "honnett",
    "honnetts": "honnett",
    "honnören": "honnör",
    "honnörens": "honnör",
    "honnörer": "honnör",
    "honnörerna": "honnör",
    "honnörernas": "honnör",
    "honnörers": "honnör",
    "honnörs": "honnör",
    "honnörsbetygen": "honnörsbetyg",
    "honnörsbetygens": "honnörsbetyg",
    "honnörsbetyget": "honnörsbetyg",
    "honnörsbetygets": "honnörsbetyg",
    "honnörsbetygs": "honnörsbetyg",
    "honnörsborden": "honnörsbord",
    "honnörsbordens": "honnörsbord",
    "honnörsbordet": "honnörsbord",
    "honnörsbordets": "honnörsbord",
    "honnörsbords": "honnörsbord",
    "honnörsorden": "honnörsord",
    "honnörsordens": "honnörsord",
    "honnörsordet": "honnörsord",
    "honnörsordets": "honnörsord",
    "honnörsords": "honnörsord",
    "honnörsposten": "honnörspost",
    "honnörspostens": "honnörspost",
    "honnörsposter": "honnörspost",
    "honnörsposterna": "honnörspost",
    "honnörsposternas": "honnörspost",
    "honnörsposters": "honnörspost",
    "honnörsposts": "honnörspost",
    "honom": "han",
    "honor": "hona",
    "honoraren": "honorar",
    "honorarens": "honorar",
    "honoraret": "honorar",
    "honorarets": "honorar",
    "honorars": "honorar",
    "honorerad": "honorera",
    "honorerade": "honorera",
    "honorerades": "honorera",
    "honorerads": "honorera",
    "honorerande": "honorera",
    "honoreranden": "honorerande",
    "honorerandena": "honorerande",
    "honorerandenas": "honorerande",
    "honorerandens": "honorerande",
    "honorerandes": "honorerande",
    "honorerandet": "honorerande",
    "honorerandets": "honorerande",
    "honorerar": "honorera",
    "honoreras": "honorera",
    "honorerat": "honorera",
    "honorerats": "honorera",
    "honorerbara": "honorerbar",
    "honorerbarare": "honorerbar",
    "honorerbarares": "honorerbar",
    "honorerbaras": "honorerbar",
    "honorerbarast": "honorerbar",
    "honorerbaraste": "honorerbar",
    "honorerbarastes": "honorerbar",
    "honorerbarasts": "honorerbar",
    "honorerbare": "honorerbar",
    "honorerbares": "honorerbar",
    "honorerbarheten": "honorerbarhet",
    "honorerbarhetens": "honorerbarhet",
    "honorerbarhets": "honorerbarhet",
    "honorerbars": "honorerbar",
    "honorerbart": "honorerbar",
    "honorerbarts": "honorerbar",
    "honoreringar": "honorering",
    "honoreringarna": "honorering",
    "honoreringarnas": "honorering",
    "honoreringars": "honorering",
    "honoreringen": "honorering",
    "honoreringens": "honorering",
    "honorerings": "honorering",
    "honorna": "hona",
    "honornas": "hona",
    "honors": "hona",
    "honorära": "honorär",
    "honorärare": "honorär",
    "honorärares": "honorär",
    "honoräras": "honorär",
    "honorärast": "honorär",
    "honoräraste": "honorär",
    "honorärastes": "honorär",
    "honorärasts": "honorär",
    "honoräre": "honorär",
    "honoräres": "honorär",
    "honorärs": "honorär",
    "honorärt": "honorär",
    "honorärts": "honorär",
    "hons": "hona",
    "honungar": "honung",
    "honungarna": "honung",
    "honungarnas": "honung",
    "honungars": "honung",
    "honungen": "honung",
    "honungens": "honung",
    "honungs": "honung",
    "honungsbakade": "honungsbakad",
    "honungsbakades": "honungsbakad",
    "honungsbakads": "honungsbakad",
    "honungsbakat": "honungsbakad",
    "honungsbakats": "honungsbakad",
    "honungsfärgade": "honungsfärgad",
    "honungsfärgades": "honungsfärgad",
    "honungsfärgads": "honungsfärgad",
    "honungsfärgat": "honungsfärgad",
    "honungsfärgats": "honungsfärgad",
    "honungsgula": "honungsgul",
    "honungsgulare": "honungsgul",
    "honungsgulares": "honungsgul",
    "honungsgulas": "honungsgul",
    "honungsgulast": "honungsgul",
    "honungsgulaste": "honungsgul",
    "honungsgulastes": "honungsgul",
    "honungsgulasts": "honungsgul",
    "honungsgule": "honungsgul",
    "honungsgules": "honungsgul",
    "honungsguls": "honungsgul",
    "honungsgult": "honungsgul",
    "honungsgults": "honungsgul",
    "honungskak": "honungskaka",
    "honungskakan": "honungskaka",
    "honungskakans": "honungskaka",
    "honungskakas": "honungskaka",
    "honungskake": "honungskaka",
    "honungskakor": "honungskaka",
    "honungskakorna": "honungskaka",
    "honungskakornas": "honungskaka",
    "honungskakors": "honungskaka",
    "honungskaks": "honungskaka",
    "honungslena": "honungslen",
    "honungslenare": "honungslen",
    "honungslenares": "honungslen",
    "honungslenas": "honungslen",
    "honungslenast": "honungslen",
    "honungslenaste": "honungslen",
    "honungslenastes": "honungslen",
    "honungslenasts": "honungslen",
    "honungslene": "honungslen",
    "honungslenes": "honungslen",
    "honungslenheten": "honungslenhet",
    "honungslenhetens": "honungslenhet",
    "honungslenhets": "honungslenhet",
    "honungslens": "honungslen",
    "honungslent": "honungslen",
    "honungslents": "honungslen",
    "honungsmelonen": "honungsmelon",
    "honungsmelonens": "honungsmelon",
    "honungsmeloner": "honungsmelon",
    "honungsmelonerna": "honungsmelon",
    "honungsmelonernas": "honungsmelon",
    "honungsmeloners": "honungsmelon",
    "honungsmelons": "honungsmelon",
    "honungsproducenten": "honungsproducent",
    "honungsproducentens": "honungsproducent",
    "honungsproducenter": "honungsproducent",
    "honungsproducenterna": "honungsproducent",
    "honungsproducenternas": "honungsproducent",
    "honungsproducenters": "honungsproducent",
    "honungsproducents": "honungsproducent",
    "honungsskivlingar": "honungsskivling",
    "honungsskivlingarna": "honungsskivling",
    "honungsskivlingarnas": "honungsskivling",
    "honungsskivlingars": "honungsskivling",
    "honungsskivlingen": "honungsskivling",
    "honungsskivlingens": "honungsskivling",
    "honungsskivlings": "honungsskivling",
    "hop": "hopa",
    "hopad": "hopa",
    "hopade": "hopa",
    "hopades": "hopa",
    "hopads": "hopa",
    "hopande": "hopa",
    "hopanden": "hopande",
    "hopandena": "hopande",
    "hopandenas": "hopande",
    "hopandens": "hopande",
    "hopandes": "hopande",
    "hopandet": "hopande",
    "hopandets": "hopande",
    "hopar": "hopa",
    "hoparna": "hop",
    "hoparnas": "hop",
    "hopars": "hop",
    "hopas": "hopa",
    "hopat": "hopa",
    "hopats": "hopa",
    "hopbitenheten": "hopbitenhet",
    "hopbitenhetens": "hopbitenhet",
    "hopbitenhets": "hopbitenhet",
    "hopbitens": "hopbiten",
    "hopbitet": "hopbiten",
    "hopbitets": "hopbiten",
    "hopbitna": "hopbiten",
    "hopbitnare": "hopbiten",
    "hopbitnares": "hopbiten",
    "hopbitnas": "hopbiten",
    "hopbitnast": "hopbiten",
    "hopbitnaste": "hopbiten",
    "hopbitnastes": "hopbiten",
    "hopbitnasts": "hopbiten",
    "hopbitne": "hopbiten",
    "hopbitnes": "hopbiten",
    "hopblandningar": "hopblandning",
    "hopblandningarna": "hopblandning",
    "hopblandningarnas": "hopblandning",
    "hopblandningars": "hopblandning",
    "hopblandningen": "hopblandning",
    "hopblandningens": "hopblandning",
    "hopblandnings": "hopblandning",
    "hopbragt": "hopbringa",
    "hopbragte": "hopbringa",
    "hopbragtes": "hopbringa",
    "hopbragts": "hopbringa",
    "hopbring": "hopbringa",
    "hopbringad": "hopbringa",
    "hopbringade": "hopbringa",
    "hopbringades": "hopbringa",
    "hopbringads": "hopbringa",
    "hopbringande": "hopbringa",
    "hopbringanden": "hopbringande",
    "hopbringandena": "hopbringande",
    "hopbringandenas": "hopbringande",
    "hopbringandens": "hopbringande",
    "hopbringandes": "hopbringande",
    "hopbringandet": "hopbringande",
    "hopbringandets": "hopbringande",
    "hopbringar": "hopbringa",
    "hopbringas": "hopbringa",
    "hopbringat": "hopbringa",
    "hopbringats": "hopbringa",
    "hopbunt": "hopbunta",
    "hopbuntad": "hopbunta",
    "hopbuntade": "hopbunta",
    "hopbuntades": "hopbunta",
    "hopbuntads": "hopbunta",
    "hopbuntande": "hopbunta",
    "hopbuntanden": "hopbuntande",
    "hopbuntandena": "hopbuntande",
    "hopbuntandenas": "hopbuntande",
    "hopbuntandens": "hopbuntande",
    "hopbuntandes": "hopbuntande",
    "hopbuntandet": "hopbuntande",
    "hopbuntandets": "hopbuntande",
    "hopbuntar": "hopbunta",
    "hopbuntas": "hopbunta",
    "hopbuntat": "hopbunta",
    "hopbuntats": "hopbunta",
    "hopbyggda": "hopbyggd",
    "hopbyggdare": "hopbyggd",
    "hopbyggdares": "hopbyggd",
    "hopbyggdas": "hopbyggd",
    "hopbyggdast": "hopbyggd",
    "hopbyggdaste": "hopbyggd",
    "hopbyggdastes": "hopbyggd",
    "hopbyggdasts": "hopbyggd",
    "hopbyggde": "hopbyggd",
    "hopbyggdes": "hopbyggd",
    "hopbyggds": "hopbyggd",
    "hopbyggt": "hopbyggd",
    "hopbyggts": "hopbyggd",
    "hopdikt": "hopdikta",
    "hopdiktad": "hopdikta",
    "hopdiktade": "hopdikta",
    "hopdiktades": "hopdikta",
    "hopdiktads": "hopdikta",
    "hopdiktande": "hopdikta",
    "hopdiktanden": "hopdiktande",
    "hopdiktandena": "hopdiktande",
    "hopdiktandenas": "hopdiktande",
    "hopdiktandens": "hopdiktande",
    "hopdiktandes": "hopdiktande",
    "hopdiktandet": "hopdiktande",
    "hopdiktandets": "hopdiktande",
    "hopdiktar": "hopdikta",
    "hopdiktas": "hopdikta",
    "hopdiktat": "hopdikta",
    "hopdiktats": "hopdikta",
    "hopdragningar": "hopdragning",
    "hopdragningarna": "hopdragning",
    "hopdragningarnas": "hopdragning",
    "hopdragningars": "hopdragning",
    "hopdragningen": "hopdragning",
    "hopdragningens": "hopdragning",
    "hopdragnings": "hopdragning",
    "hopen": "hop",
    "hopens": "hop",
    "hopers": "hoper",
    "hopfog": "hopfoga",
    "hopfogad": "hopfoga",
    "hopfogade": "hopfoga",
    "hopfogades": "hopfoga",
    "hopfogads": "hopfoga",
    "hopfogande": "hopfoga",
    "hopfoganden": "hopfogande",
    "hopfogandena": "hopfogande",
    "hopfogandenas": "hopfogande",
    "hopfogandens": "hopfogande",
    "hopfogandes": "hopfogande",
    "hopfogandet": "hopfogande",
    "hopfogandets": "hopfogande",
    "hopfogar": "hopfoga",
    "hopfogas": "hopfoga",
    "hopfogat": "hopfoga",
    "hopfogats": "hopfoga",
    "hopfällbara": "hopfällbar",
    "hopfällbarare": "hopfällbar",
    "hopfällbarares": "hopfällbar",
    "hopfällbaras": "hopfällbar",
    "hopfällbarast": "hopfällbar",
    "hopfällbaraste": "hopfällbar",
    "hopfällbarastes": "hopfällbar",
    "hopfällbarasts": "hopfällbar",
    "hopfällbare": "hopfällbar",
    "hopfällbares": "hopfällbar",
    "hopfällbarheten": "hopfällbarhet",
    "hopfällbarhetens": "hopfällbarhet",
    "hopfällbarhets": "hopfällbarhet",
    "hopfällbars": "hopfällbar",
    "hopfällbart": "hopfällbar",
    "hopfällbarts": "hopfällbar",
    "hopfällda": "hopfälld",
    "hopfälldare": "hopfälld",
    "hopfälldares": "hopfälld",
    "hopfälldas": "hopfälld",
    "hopfälldast": "hopfälld",
    "hopfälldaste": "hopfälld",
    "hopfälldastes": "hopfälld",
    "hopfälldasts": "hopfälld",
    "hopfällde": "hopfälld",
    "hopfälldes": "hopfälld",
    "hopfällds": "hopfälld",
    "hopfällt": "hopfälld",
    "hopfällts": "hopfälld",
    "hopgyttrade": "hopgyttrad",
    "hopgyttrades": "hopgyttrad",
    "hopgyttrads": "hopgyttrad",
    "hopgyttrat": "hopgyttrad",
    "hopgyttrats": "hopgyttrad",
    "hophållens": "hophållen",
    "hophållet": "hophållen",
    "hophållets": "hophållen",
    "hophållna": "hophållen",
    "hophållnare": "hophållen",
    "hophållnares": "hophållen",
    "hophållnas": "hophållen",
    "hophållnast": "hophållen",
    "hophållnaste": "hophållen",
    "hophållnastes": "hophållen",
    "hophållnasts": "hophållen",
    "hophållne": "hophållen",
    "hophållnes": "hophållen",
    "hopklumpningar": "hopklumpning",
    "hopklumpningarna": "hopklumpning",
    "hopklumpningarnas": "hopklumpning",
    "hopklumpningars": "hopklumpning",
    "hopklumpningen": "hopklumpning",
    "hopklumpningens": "hopklumpning",
    "hopklumpnings": "hopklumpning",
    "hopklumpningstillstånden": "hopklumpningstillstånd",
    "hopklumpningstillståndens": "hopklumpningstillstånd",
    "hopklumpningstillståndet": "hopklumpningstillstånd",
    "hopklumpningstillståndets": "hopklumpningstillstånd",
    "hopklumpningstillstånds": "hopklumpningstillstånd",
    "hopknuten": "hopknyta",
    "hopknutens": "hopknyta",
    "hopknutet": "hopknyta",
    "hopknutets": "hopknyta",
    "hopknutit": "hopknyta",
    "hopknutits": "hopknyta",
    "hopknutna": "hopknyta",
    "hopknutnas": "hopknyta",
    "hopknutne": "hopknyta",
    "hopknutnes": "hopknyta",
    "hopknyckel": "hopknyckla",
    "hopknycklad": "hopknyckla",
    "hopknycklade": "hopknyckla",
    "hopknycklades": "hopknyckla",
    "hopknycklads": "hopknyckla",
    "hopknycklande": "hopknyckla",
    "hopknycklanden": "hopknycklande",
    "hopknycklandena": "hopknycklande",
    "hopknycklandenas": "hopknycklande",
    "hopknycklandens": "hopknycklande",
    "hopknycklandes": "hopknycklande",
    "hopknycklandet": "hopknycklande",
    "hopknycklandets": "hopknycklande",
    "hopknycklar": "hopknyckla",
    "hopknycklas": "hopknyckla",
    "hopknycklat": "hopknyckla",
    "hopknycklats": "hopknyckla",
    "hopknyt": "hopknyta",
    "hopknytande": "hopknyta",
    "hopknytanden": "hopknytande",
    "hopknytandena": "hopknytande",
    "hopknytandenas": "hopknytande",
    "hopknytandens": "hopknytande",
    "hopknytandes": "hopknytande",
    "hopknytandet": "hopknytande",
    "hopknytandets": "hopknytande",
    "hopknytas": "hopknyta",
    "hopknyte": "hopknyta",
    "hopknyter": "hopknyta",
    "hopknytes": "hopknyta",
    "hopknyts": "hopknyta",
    "hopknäppta": "hopknäppt",
    "hopknäpptare": "hopknäppt",
    "hopknäpptares": "hopknäppt",
    "hopknäpptas": "hopknäppt",
    "hopknäpptast": "hopknäppt",
    "hopknäpptaste": "hopknäppt",
    "hopknäpptastes": "hopknäppt",
    "hopknäpptasts": "hopknäppt",
    "hopknäppte": "hopknäppt",
    "hopknäpptes": "hopknäppt",
    "hopknäppts": "hopknäppt",
    "hopknåpade": "hopknåpad",
    "hopknåpades": "hopknåpad",
    "hopknåpads": "hopknåpad",
    "hopknåpat": "hopknåpad",
    "hopknåpats": "hopknåpad",
    "hopknölade": "hopknölad",
    "hopknölades": "hopknölad",
    "hopknölads": "hopknölad",
    "hopknölat": "hopknölad",
    "hopknölats": "hopknölad",
    "hopknöt": "hopknyta",
    "hopknöte": "hopknyta",
    "hopknötes": "hopknyta",
    "hopknöts": "hopknyta",
    "hopkoken": "hopkok",
    "hopkokens": "hopkok",
    "hopkoket": "hopkok",
    "hopkokets": "hopkok",
    "hopkoks": "hopkok",
    "hopkommens": "hopkommen",
    "hopkommet": "hopkommen",
    "hopkommets": "hopkommen",
    "hopkomna": "hopkommen",
    "hopkomnare": "hopkommen",
    "hopkomnares": "hopkommen",
    "hopkomnas": "hopkommen",
    "hopkomnast": "hopkommen",
    "hopkomnaste": "hopkommen",
    "hopkomnastes": "hopkommen",
    "hopkomnasts": "hopkommen",
    "hopkomne": "hopkommen",
    "hopkomnes": "hopkommen",
    "hopkoppel": "hopkoppla",
    "hopkopplad": "hopkoppla",
    "hopkopplade": "hopkoppla",
    "hopkopplades": "hopkoppla",
    "hopkopplads": "hopkoppla",
    "hopkopplande": "hopkoppla",
    "hopkopplanden": "hopkopplande",
    "hopkopplandena": "hopkopplande",
    "hopkopplandenas": "hopkopplande",
    "hopkopplandens": "hopkopplande",
    "hopkopplandes": "hopkopplande",
    "hopkopplandet": "hopkopplande",
    "hopkopplandets": "hopkopplande",
    "hopkopplar": "hopkoppla",
    "hopkopplas": "hopkoppla",
    "hopkopplat": "hopkoppla",
    "hopkopplats": "hopkoppla",
    "hopkopplingar": "hopkoppling",
    "hopkopplingarna": "hopkoppling",
    "hopkopplingarnas": "hopkoppling",
    "hopkopplingars": "hopkoppling",
    "hopkopplingen": "hopkoppling",
    "hopkopplingens": "hopkoppling",
    "hopkopplings": "hopkoppling",
    "hopkrupens": "hopkrupen",
    "hopkrupet": "hopkrupen",
    "hopkrupets": "hopkrupen",
    "hopkrupna": "hopkrupen",
    "hopkrupnare": "hopkrupen",
    "hopkrupnares": "hopkrupen",
    "hopkrupnas": "hopkrupen",
    "hopkrupnast": "hopkrupen",
    "hopkrupnaste": "hopkrupen",
    "hopkrupnastes": "hopkrupen",
    "hopkrupnasts": "hopkrupen",
    "hopkrupne": "hopkrupen",
    "hopkrupnes": "hopkrupen",
    "hopkurade": "hopkurad",
    "hopkurades": "hopkurad",
    "hopkurads": "hopkurad",
    "hopkurat": "hopkurad",
    "hopkurats": "hopkurad",
    "hoplapp": "hoplappa",
    "hoplappad": "hoplappa",
    "hoplappade": "hoplappa",
    "hoplappades": "hoplappa",
    "hoplappads": "hoplappa",
    "hoplappande": "hoplappa",
    "hoplappanden": "hoplappande",
    "hoplappandena": "hoplappande",
    "hoplappandenas": "hoplappande",
    "hoplappandens": "hoplappande",
    "hoplappandes": "hoplappande",
    "hoplappandet": "hoplappande",
    "hoplappandets": "hoplappande",
    "hoplappar": "hoplappa",
    "hoplappas": "hoplappa",
    "hoplappat": "hoplappa",
    "hoplappats": "hoplappa",
    "hopliten": "hoplit",
    "hoplitens": "hoplit",
    "hopliter": "hoplit",
    "hopliterna": "hoplit",
    "hopliternas": "hoplit",
    "hopliters": "hoplit",
    "hoplits": "hoplit",
    "hopp": "hoppa",
    "hopp-i-landkall": "hopp-i-landkalle",
    "hopp-i-landkallar": "hopp-i-landkalle",
    "hopp-i-landkallarna": "hopp-i-landkalle",
    "hopp-i-landkallarnas": "hopp-i-landkalle",
    "hopp-i-landkallars": "hopp-i-landkalle",
    "hopp-i-landkallen": "hopp-i-landkalle",
    "hopp-i-landkallens": "hopp-i-landkalle",
    "hopp-i-landkalles": "hopp-i-landkalle",
    "hopp-i-landkalls": "hopp-i-landkalle",
    "hoppack": "hoppacka",
    "hoppackad": "hoppacka",
    "hoppackade": "hoppacka",
    "hoppackades": "hoppacka",
    "hoppackads": "hoppacka",
    "hoppackande": "hoppacka",
    "hoppackanden": "hoppackande",
    "hoppackandena": "hoppackande",
    "hoppackandenas": "hoppackande",
    "hoppackandens": "hoppackande",
    "hoppackandes": "hoppackande",
    "hoppackandet": "hoppackande",
    "hoppackandets": "hoppackande",
    "hoppackar": "hoppacka",
    "hoppackas": "hoppacka",
    "hoppackat": "hoppacka",
    "hoppackats": "hoppacka",
    "hoppad": "hoppa",
    "hoppade": "hoppa",
    "hoppades": "hoppas",
    "hoppads": "hoppa",
    "hoppande": "hoppa",
    "hoppanden": "hoppande",
    "hoppandena": "hoppande",
    "hoppandenas": "hoppande",
    "hoppandens": "hoppande",
    "hoppandes": "hoppande",
    "hoppandet": "hoppande",
    "hoppandets": "hoppande",
    "hoppar": "hoppare",
    "hopparen": "hoppare",
    "hopparens": "hoppare",
    "hoppares": "hoppare",
    "hopparna": "hoppare",
    "hopparnas": "hoppare",
    "hoppas": "hoppa",
    "hoppat": "hoppa",
    "hoppats": "hoppas",
    "hoppback": "hoppbacke",
    "hoppbackar": "hoppbacke",
    "hoppbackarna": "hoppbacke",
    "hoppbackarnas": "hoppbacke",
    "hoppbackars": "hoppbacke",
    "hoppbacken": "hoppbacke",
    "hoppbackens": "hoppbacke",
    "hoppbackes": "hoppbacke",
    "hoppbacks": "hoppbacke",
    "hoppen": "hopp",
    "hoppens": "hopp",
    "hoppet": "hopp",
    "hoppets": "hopp",
    "hoppfulla": "hoppfull",
    "hoppfullare": "hoppfull",
    "hoppfullares": "hoppfull",
    "hoppfullas": "hoppfull",
    "hoppfullast": "hoppfull",
    "hoppfullaste": "hoppfull",
    "hoppfullastes": "hoppfull",
    "hoppfullasts": "hoppfull",
    "hoppfulle": "hoppfull",
    "hoppfulles": "hoppfull",
    "hoppfullheten": "hoppfullhet",
    "hoppfullhetens": "hoppfullhet",
    "hoppfullheter": "hoppfullhet",
    "hoppfullheterna": "hoppfullhet",
    "hoppfullheternas": "hoppfullhet",
    "hoppfullheters": "hoppfullhet",
    "hoppfullhets": "hoppfullhet",
    "hoppfulls": "hoppfull",
    "hoppfullt": "hoppfull",
    "hoppfullts": "hoppfull",
    "hoppförsöken": "hoppförsök",
    "hoppförsökens": "hoppförsök",
    "hoppförsöket": "hoppförsök",
    "hoppförsökets": "hoppförsök",
    "hoppförsöks": "hoppförsök",
    "hoppiga": "hoppig",
    "hoppigare": "hoppig",
    "hoppigares": "hoppig",
    "hoppigas": "hoppig",
    "hoppigast": "hoppig",
    "hoppigaste": "hoppig",
    "hoppigastes": "hoppig",
    "hoppigasts": "hoppig",
    "hoppige": "hoppig",
    "hoppiges": "hoppig",
    "hoppigheten": "hoppighet",
    "hoppighetens": "hoppighet",
    "hoppighets": "hoppighet",
    "hoppigs": "hoppig",
    "hoppigt": "hoppig",
    "hoppigts": "hoppig",
    "hoppjerk": "hoppjerka",
    "hoppjerkan": "hoppjerka",
    "hoppjerkans": "hoppjerka",
    "hoppjerkas": "hoppjerka",
    "hoppjerke": "hoppjerka",
    "hoppjerkor": "hoppjerka",
    "hoppjerkorna": "hoppjerka",
    "hoppjerkornas": "hoppjerka",
    "hoppjerkors": "hoppjerka",
    "hoppjerks": "hoppjerka",
    "hoppledar": "hoppledare",
    "hoppledaren": "hoppledare",
    "hoppledarens": "hoppledare",
    "hoppledares": "hoppledare",
    "hoppledarna": "hoppledare",
    "hoppledarnas": "hoppledare",
    "hopplocket": "hopplock",
    "hopplockets": "hopplock",
    "hopplocks": "hopplock",
    "hopplösa": "hopplös",
    "hopplösare": "hopplös",
    "hopplösares": "hopplös",
    "hopplösas": "hopplös",
    "hopplösast": "hopplös",
    "hopplösaste": "hopplös",
    "hopplösastes": "hopplös",
    "hopplösasts": "hopplös",
    "hopplöse": "hopplös",
    "hopplöses": "hopplös",
    "hopplösheten": "hopplöshet",
    "hopplöshetens": "hopplöshet",
    "hopplösheter": "hopplöshet",
    "hopplösheterna": "hopplöshet",
    "hopplösheternas": "hopplöshet",
    "hopplösheters": "hopplöshet",
    "hopplöshets": "hopplöshet",
    "hopplöst": "hopplös",
    "hopplösts": "hopplös",
    "hopprepen": "hopprep",
    "hopprepens": "hopprep",
    "hopprepet": "hopprep",
    "hopprepets": "hopprep",
    "hoppreps": "hopprep",
    "hopps": "hopp",
    "hoppstjärtar": "hoppstjärt",
    "hoppstjärtarna": "hoppstjärt",
    "hoppstjärtarnas": "hoppstjärt",
    "hoppstjärtars": "hoppstjärt",
    "hoppstjärten": "hoppstjärt",
    "hoppstjärtens": "hoppstjärt",
    "hoppstjärts": "hoppstjärt",
    "hoppställningar": "hoppställning",
    "hoppställningarna": "hoppställning",
    "hoppställningarnas": "hoppställning",
    "hoppställningars": "hoppställning",
    "hoppställningen": "hoppställning",
    "hoppställningens": "hoppställning",
    "hoppställnings": "hoppställning",
    "hopptornen": "hopptorn",
    "hopptornens": "hopptorn",
    "hopptornet": "hopptorn",
    "hopptornets": "hopptorn",
    "hopptorns": "hopptorn",
    "hoppträningar": "hoppträning",
    "hoppträningarna": "hoppträning",
    "hoppträningarnas": "hoppträning",
    "hoppträningars": "hoppträning",
    "hoppträningen": "hoppträning",
    "hoppträningens": "hoppträning",
    "hopptränings": "hoppträning",
    "hoprafsad": "hoprafsa",
    "hoprafsade": "hoprafsa",
    "hoprafsades": "hoprafsa",
    "hoprafsads": "hoprafsa",
    "hoprafsande": "hoprafsa",
    "hoprafsanden": "hoprafsande",
    "hoprafsandena": "hoprafsande",
    "hoprafsandenas": "hoprafsande",
    "hoprafsandens": "hoprafsande",
    "hoprafsandes": "hoprafsande",
    "hoprafsandet": "hoprafsande",
    "hoprafsandets": "hoprafsande",
    "hoprafsar": "hoprafsa",
    "hoprafsas": "hoprafsa",
    "hoprafsat": "hoprafsa",
    "hoprafsats": "hoprafsa",
    "hoprasade": "hoprasad",
    "hoprasades": "hoprasad",
    "hoprasads": "hoprasad",
    "hoprasat": "hoprasad",
    "hoprasats": "hoprasad",
    "hoprullade": "hoprullad",
    "hoprullades": "hoprullad",
    "hoprullads": "hoprullad",
    "hoprullat": "hoprullad",
    "hoprullats": "hoprullad",
    "hops": "hop",
    "hopsjunkens": "hopsjunken",
    "hopsjunket": "hopsjunken",
    "hopsjunkets": "hopsjunken",
    "hopsjunkna": "hopsjunken",
    "hopsjunknare": "hopsjunken",
    "hopsjunknares": "hopsjunken",
    "hopsjunknas": "hopsjunken",
    "hopsjunknast": "hopsjunken",
    "hopsjunknaste": "hopsjunken",
    "hopsjunknastes": "hopsjunken",
    "hopsjunknasts": "hopsjunken",
    "hopsjunkne": "hopsjunken",
    "hopsjunknes": "hopsjunken",
    "hopskjut": "hopskjuta",
    "hopskjutande": "hopskjuta",
    "hopskjutanden": "hopskjutande",
    "hopskjutandena": "hopskjutande",
    "hopskjutandenas": "hopskjutande",
    "hopskjutandens": "hopskjutande",
    "hopskjutandes": "hopskjutande",
    "hopskjutandet": "hopskjutande",
    "hopskjutandets": "hopskjutande",
    "hopskjutas": "hopskjuta",
    "hopskjutbara": "hopskjutbar",
    "hopskjutbaras": "hopskjutbar",
    "hopskjutbare": "hopskjutbar",
    "hopskjutbares": "hopskjutbar",
    "hopskjutbars": "hopskjutbar",
    "hopskjutbart": "hopskjutbar",
    "hopskjutbarts": "hopskjutbar",
    "hopskjute": "hopskjuta",
    "hopskjuten": "hopskjuta",
    "hopskjutens": "hopskjuta",
    "hopskjuter": "hopskjuta",
    "hopskjutes": "hopskjuta",
    "hopskjutet": "hopskjuta",
    "hopskjutets": "hopskjuta",
    "hopskjutit": "hopskjuta",
    "hopskjutits": "hopskjuta",
    "hopskjutna": "hopskjuta",
    "hopskjutnas": "hopskjuta",
    "hopskjutne": "hopskjuta",
    "hopskjutnes": "hopskjuta",
    "hopskjuts": "hopskjuta",
    "hopskrynklade": "hopskrynklad",
    "hopskrynklades": "hopskrynklad",
    "hopskrynklads": "hopskrynklad",
    "hopskrynklat": "hopskrynklad",
    "hopskrynklats": "hopskrynklad",
    "hopsköt": "hopskjuta",
    "hopsköte": "hopskjuta",
    "hopskötes": "hopskjuta",
    "hopsköts": "hopskjuta",
    "hopslagens": "hopslagen",
    "hopslaget": "hopslagen",
    "hopslagets": "hopslagen",
    "hopslagna": "hopslagen",
    "hopslagnare": "hopslagen",
    "hopslagnares": "hopslagen",
    "hopslagnas": "hopslagen",
    "hopslagnast": "hopslagen",
    "hopslagnaste": "hopslagen",
    "hopslagnastes": "hopslagen",
    "hopslagnasts": "hopslagen",
    "hopslagne": "hopslagen",
    "hopslagnes": "hopslagen",
    "hopsnodda": "hopsnodd",
    "hopsnoddare": "hopsnodd",
    "hopsnoddares": "hopsnodd",
    "hopsnoddas": "hopsnodd",
    "hopsnoddast": "hopsnodd",
    "hopsnoddaste": "hopsnodd",
    "hopsnoddastes": "hopsnodd",
    "hopsnoddasts": "hopsnodd",
    "hopsnodde": "hopsnodd",
    "hopsnoddes": "hopsnodd",
    "hopsnodds": "hopsnodd",
    "hopsnott": "hopsnodd",
    "hopsnotts": "hopsnodd",
    "hopsnörda": "hopsnörd",
    "hopsnördare": "hopsnörd",
    "hopsnördares": "hopsnörd",
    "hopsnördas": "hopsnörd",
    "hopsnördast": "hopsnörd",
    "hopsnördaste": "hopsnörd",
    "hopsnördastes": "hopsnörd",
    "hopsnördasts": "hopsnörd",
    "hopsnörde": "hopsnörd",
    "hopsnördes": "hopsnörd",
    "hopsnörds": "hopsnörd",
    "hopsnörpta": "hopsnörpt",
    "hopsnörptare": "hopsnörpt",
    "hopsnörptares": "hopsnörpt",
    "hopsnörptas": "hopsnörpt",
    "hopsnörptast": "hopsnörpt",
    "hopsnörptaste": "hopsnörpt",
    "hopsnörptastes": "hopsnörpt",
    "hopsnörptasts": "hopsnörpt",
    "hopsnörpte": "hopsnörpt",
    "hopsnörptes": "hopsnörpt",
    "hopsnörpts": "hopsnörpt",
    "hopsnört": "hopsnörd",
    "hopsnörts": "hopsnörd",
    "hopsvetsade": "hopsvetsad",
    "hopsvetsades": "hopsvetsad",
    "hopsvetsads": "hopsvetsad",
    "hopsvetsat": "hopsvetsad",
    "hopsvetsats": "hopsvetsad",
    "hoptrasslade": "hoptrasslad",
    "hoptrasslades": "hoptrasslad",
    "hoptrasslads": "hoptrasslad",
    "hoptrasslat": "hoptrasslad",
    "hoptrasslats": "hoptrasslad",
    "hoptryckbara": "hoptryckbar",
    "hoptryckbarare": "hoptryckbar",
    "hoptryckbarares": "hoptryckbar",
    "hoptryckbaras": "hoptryckbar",
    "hoptryckbarast": "hoptryckbar",
    "hoptryckbaraste": "hoptryckbar",
    "hoptryckbarastes": "hoptryckbar",
    "hoptryckbarasts": "hoptryckbar",
    "hoptryckbare": "hoptryckbar",
    "hoptryckbares": "hoptryckbar",
    "hoptryckbarheten": "hoptryckbarhet",
    "hoptryckbarhetens": "hoptryckbarhet",
    "hoptryckbarhets": "hoptryckbarhet",
    "hoptryckbars": "hoptryckbar",
    "hoptryckbart": "hoptryckbar",
    "hoptryckbarts": "hoptryckbar",
    "hoptvinnade": "hoptvinnad",
    "hoptvinnades": "hoptvinnad",
    "hoptvinnads": "hoptvinnad",
    "hoptvinnat": "hoptvinnad",
    "hoptvinnats": "hoptvinnad",
    "hopvek": "hopvika",
    "hopveke": "hopvika",
    "hopvekes": "hopvika",
    "hopveks": "hopvika",
    "hopvik": "hopvika",
    "hopvikande": "hopvika",
    "hopvikanden": "hopvikande",
    "hopvikandena": "hopvikande",
    "hopvikandenas": "hopvikande",
    "hopvikandens": "hopvikande",
    "hopvikandes": "hopvikande",
    "hopvikandet": "hopvikande",
    "hopvikandets": "hopvikande",
    "hopvikas": "hopvika",
    "hopvike": "hopvika",
    "hopviken": "hopvika",
    "hopvikens": "hopvika",
    "hopviker": "hopvika",
    "hopvikes": "hopvika",
    "hopviket": "hopvika",
    "hopvikets": "hopvika",
    "hopvikit": "hopvika",
    "hopvikits": "hopvika",
    "hopvikna": "hopvika",
    "hopviknas": "hopvika",
    "hopvikne": "hopvika",
    "hopviknes": "hopvika",
    "hopviks": "hopvika",
    "hopvikt": "hopvika",
    "hopvikts": "hopvika",
    "hopvuxens": "hopvuxen",
    "hopvuxet": "hopvuxen",
    "hopvuxets": "hopvuxen",
    "hopvuxna": "hopvuxen",
    "hopvuxnare": "hopvuxen",
    "hopvuxnares": "hopvuxen",
    "hopvuxnas": "hopvuxen",
    "hopvuxnast": "hopvuxen",
    "hopvuxnaste": "hopvuxen",
    "hopvuxnastes": "hopvuxen",
    "hopvuxnasts": "hopvuxen",
    "hopvuxne": "hopvuxen",
    "hopvuxnes": "hopvuxen",
    "hopväxta": "hopväxt",
    "hopväxtare": "hopväxt",
    "hopväxtares": "hopväxt",
    "hopväxtas": "hopväxt",
    "hopväxtast": "hopväxt",
    "hopväxtaste": "hopväxt",
    "hopväxtastes": "hopväxt",
    "hopväxtasts": "hopväxt",
    "hopväxte": "hopväxt",
    "hopväxtes": "hopväxt",
    "hopväxts": "hopväxt",
    "hor": "hora",
    "horade": "hora",
    "horades": "hora",
    "horan": "hora",
    "horande": "hora",
    "horanden": "horande",
    "horandena": "horande",
    "horandenas": "horande",
    "horandens": "horande",
    "horandes": "horande",
    "horandet": "horande",
    "horandets": "horande",
    "horans": "hora",
    "horar": "hora",
    "horas": "hora",
    "horat": "hora",
    "horats": "hora",
    "horbockar": "horbock",
    "horbockarna": "horbock",
    "horbockarnas": "horbock",
    "horbockars": "horbock",
    "horbocken": "horbock",
    "horbockens": "horbock",
    "horbocks": "horbock",
    "horden": "hord",
    "hordens": "hord",
    "horder": "hord",
    "horderna": "hord",
    "hordernas": "hord",
    "horders": "hord",
    "hords": "hord",
    "hore": "hora",
    "horet": "hor",
    "horets": "hor",
    "horhusen": "horhus",
    "horhusens": "horhus",
    "horhuset": "horhus",
    "horhusets": "horhus",
    "horisontala": "horisontal",
    "horisontalare": "horisontal",
    "horisontalares": "horisontal",
    "horisontalas": "horisontal",
    "horisontalast": "horisontal",
    "horisontalaste": "horisontal",
    "horisontalastes": "horisontal",
    "horisontalasts": "horisontal",
    "horisontalaxlade": "horisontalaxlad",
    "horisontalaxlades": "horisontalaxlad",
    "horisontalaxlads": "horisontalaxlad",
    "horisontalaxlat": "horisontalaxlad",
    "horisontalaxlats": "horisontalaxlad",
    "horisontale": "horisontal",
    "horisontales": "horisontal",
    "horisontallägen": "horisontalläge",
    "horisontallägena": "horisontalläge",
    "horisontallägenas": "horisontalläge",
    "horisontallägens": "horisontalläge",
    "horisontalläges": "horisontalläge",
    "horisontalläget": "horisontalläge",
    "horisontallägets": "horisontalläge",
    "horisontalplanen": "horisontalplan",
    "horisontalplanens": "horisontalplan",
    "horisontalplanet": "horisontalplan",
    "horisontalplanets": "horisontalplan",
    "horisontalplans": "horisontalplan",
    "horisontals": "horisontal",
    "horisontalt": "horisontal",
    "horisontalts": "horisontal",
    "horisontella": "horisontell",
    "horisontellare": "horisontell",
    "horisontellares": "horisontell",
    "horisontellas": "horisontell",
    "horisontellast": "horisontell",
    "horisontellaste": "horisontell",
    "horisontellastes": "horisontell",
    "horisontellasts": "horisontell",
    "horisontelle": "horisontell",
    "horisontelles": "horisontell",
    "horisontells": "horisontell",
    "horisontellt": "horisontell",
    "horisontellts": "horisontell",
    "horisonten": "horisont",
    "horisontens": "horisont",
    "horisonter": "horisont",
    "horisonterna": "horisont",
    "horisonternas": "horisont",
    "horisonters": "horisont",
    "horisontlinjen": "horisontlinje",
    "horisontlinjens": "horisontlinje",
    "horisontlinjer": "horisontlinje",
    "horisontlinjerna": "horisontlinje",
    "horisontlinjernas": "horisontlinje",
    "horisontlinjers": "horisontlinje",
    "horisontlinjes": "horisontlinje",
    "horisontproblemen": "horisontproblem",
    "horisontproblemens": "horisontproblem",
    "horisontproblemet": "horisontproblem",
    "horisontproblemets": "horisontproblem",
    "horisontproblems": "horisontproblem",
    "horisonts": "horisont",
    "hormonbalansen": "hormonbalans",
    "hormonbalansens": "hormonbalans",
    "hormonbalanser": "hormonbalans",
    "hormonbalanserna": "hormonbalans",
    "hormonbalansernas": "hormonbalans",
    "hormonbalansers": "hormonbalans",
    "hormonella": "hormonell",
    "hormonellare": "hormonell",
    "hormonellares": "hormonell",
    "hormonellas": "hormonell",
    "hormonellast": "hormonell",
    "hormonellaste": "hormonell",
    "hormonellastes": "hormonell",
    "hormonellasts": "hormonell",
    "hormonelle": "hormonell",
    "hormonelles": "hormonell",
    "hormonells": "hormonell",
    "hormonellt": "hormonell",
    "hormonellts": "hormonell",
    "hormonen": "hormon",
    "hormonens": "hormon",
    "hormoner": "hormon",
    "hormonerna": "hormon",
    "hormonernas": "hormon",
    "hormoners": "hormon",
    "hormonet": "hormon",
    "hormonets": "hormon",
    "hormonfunktionen": "hormonfunktion",
    "hormonfunktionens": "hormonfunktion",
    "hormonfunktioner": "hormonfunktion",
    "hormonfunktionerna": "hormonfunktion",
    "hormonfunktionernas": "hormonfunktion",
    "hormonfunktioners": "hormonfunktion",
    "hormonfunktions": "hormonfunktion",
    "hormonhalten": "hormonhalt",
    "hormonhaltens": "hormonhalt",
    "hormonhalter": "hormonhalt",
    "hormonhalterna": "hormonhalt",
    "hormonhalternas": "hormonhalt",
    "hormonhalters": "hormonhalt",
    "hormonhalts": "hormonhalt",
    "hormonproduktionen": "hormonproduktion",
    "hormonproduktionens": "hormonproduktion",
    "hormonproduktioner": "hormonproduktion",
    "hormonproduktionerna": "hormonproduktion",
    "hormonproduktionernas": "hormonproduktion",
    "hormonproduktioners": "hormonproduktion",
    "hormonproduktions": "hormonproduktion",
    "hormons": "hormon",
    "hormonsystemen": "hormonsystem",
    "hormonsystemens": "hormonsystem",
    "hormonsystemet": "hormonsystem",
    "hormonsystemets": "hormonsystem",
    "hormonsystems": "hormonsystem",
    "hormoslyret": "hormoslyr",
    "hormoslyrets": "hormoslyr",
    "hormoslyrs": "hormoslyr",
    "hornbländes": "hornblände",
    "hornbländet": "hornblände",
    "hornbländets": "hornblände",
    "hornboskapen": "hornboskap",
    "hornboskapens": "hornboskap",
    "hornboskaps": "hornboskap",
    "hornbåg": "hornbåge",
    "hornbågade": "hornbågad",
    "hornbågades": "hornbågad",
    "hornbågads": "hornbågad",
    "hornbågar": "hornbåge",
    "hornbågarna": "hornbåge",
    "hornbågarnas": "hornbåge",
    "hornbågars": "hornbåge",
    "hornbågat": "hornbågad",
    "hornbågats": "hornbågad",
    "hornbågen": "hornbåge",
    "hornbågens": "hornbåge",
    "hornbåges": "hornbåge",
    "hornbågs": "hornbåge",
    "hornen": "horn",
    "hornens": "horn",
    "hornet": "horn",
    "hornets": "horn",
    "horngädd": "horngädda",
    "horngäddan": "horngädda",
    "horngäddans": "horngädda",
    "horngäddas": "horngädda",
    "horngädde": "horngädda",
    "horngäddor": "horngädda",
    "horngäddorna": "horngädda",
    "horngäddornas": "horngädda",
    "horngäddors": "horngädda",
    "horngädds": "horngädda",
    "hornhinnan": "hornhinna",
    "hornhinnans": "hornhinna",
    "hornhinnas": "hornhinna",
    "hornhinne": "hornhinna",
    "hornhinnor": "hornhinna",
    "hornhinnorna": "hornhinna",
    "hornhinnornas": "hornhinna",
    "hornhinnors": "hornhinna",
    "hornhuden": "hornhud",
    "hornhudens": "hornhud",
    "hornhuds": "hornhud",
    "hornisten": "hornist",
    "hornistens": "hornist",
    "hornister": "hornist",
    "hornisterna": "hornist",
    "hornisternas": "hornist",
    "hornisters": "hornist",
    "hornists": "hornist",
    "hornkron": "hornkrona",
    "hornkronan": "hornkrona",
    "hornkronans": "hornkrona",
    "hornkronas": "hornkrona",
    "hornkrone": "hornkrona",
    "hornkronor": "hornkrona",
    "hornkronorna": "hornkrona",
    "hornkronornas": "hornkrona",
    "hornkronors": "hornkrona",
    "hornkrons": "hornkrona",
    "hornlagers": "hornlager",
    "hornlagret": "hornlager",
    "hornlagrets": "hornlager",
    "hornlösa": "hornlös",
    "hornlösare": "hornlös",
    "hornlösares": "hornlös",
    "hornlösas": "hornlös",
    "hornlösast": "hornlös",
    "hornlösaste": "hornlös",
    "hornlösastes": "hornlös",
    "hornlösasts": "hornlös",
    "hornlöse": "hornlös",
    "hornlöses": "hornlös",
    "hornlösheten": "hornlöshet",
    "hornlöshetens": "hornlöshet",
    "hornlöshets": "hornlöshet",
    "hornlöst": "hornlös",
    "hornlösts": "hornlös",
    "horns": "horn",
    "hornugglan": "hornuggla",
    "hornugglans": "hornuggla",
    "hornugglas": "hornuggla",
    "hornuggle": "hornuggla",
    "hornugglor": "hornuggla",
    "hornugglorna": "hornuggla",
    "hornugglornas": "hornuggla",
    "hornugglors": "hornuggla",
    "hornämnes": "hornämne",
    "hornämnet": "hornämne",
    "hornämnets": "hornämne",
    "horologie": "horologium",
    "horologier": "horologium",
    "horologierna": "horologium",
    "horologiernas": "horologium",
    "horologiers": "horologium",
    "horologiet": "horologium",
    "horologiets": "horologium",
    "horologiums": "horologium",
    "horor": "hora",
    "hororna": "hora",
    "horornas": "hora",
    "horors": "hora",
    "horoskopen": "horoskop",
    "horoskopens": "horoskop",
    "horoskopet": "horoskop",
    "horoskopets": "horoskop",
    "horoskops": "horoskop",
    "horribels": "horribel",
    "horribelt": "horribel",
    "horribelts": "horribel",
    "horribla": "horribel",
    "horriblare": "horribel",
    "horriblares": "horribel",
    "horriblas": "horribel",
    "horriblast": "horribel",
    "horriblaste": "horribel",
    "horriblastes": "horribel",
    "horriblasts": "horribel",
    "horrible": "horribel",
    "horribles": "horribel",
    "horrören": "horrör",
    "horrörens": "horrör",
    "horrörer": "horrör",
    "horrörerna": "horrör",
    "horrörernas": "horrör",
    "horrörers": "horrör",
    "horrörs": "horrör",
    "hors": "hora",
    "horsgökar": "horsgök",
    "horsgökarna": "horsgök",
    "horsgökarnas": "horsgök",
    "horsgökars": "horsgök",
    "horsgöken": "horsgök",
    "horsgökens": "horsgök",
    "horsgöks": "horsgök",
    "horstar": "horst",
    "horstarna": "horst",
    "horstarnas": "horst",
    "horstars": "horst",
    "horsten": "horst",
    "horstens": "horst",
    "horsts": "horst",
    "hortensi": "hortensia",
    "hortensian": "hortensia",
    "hortensians": "hortensia",
    "hortensias": "hortensia",
    "hortensie": "hortensia",
    "hortensior": "hortensia",
    "hortensiorna": "hortensia",
    "hortensiornas": "hortensia",
    "hortensiors": "hortensia",
    "hortensis": "hortensia",
    "hortikulturen": "hortikultur",
    "hortikulturens": "hortikultur",
    "hortikulturs": "hortikultur",
    "hortonomen": "hortonom",
    "hortonomens": "hortonom",
    "hortonomer": "hortonom",
    "hortonomerna": "hortonom",
    "hortonomernas": "hortonom",
    "hortonomers": "hortonom",
    "hortonoms": "hortonom",
    "horungar": "horunge",
    "horungarna": "horunge",
    "horungarnas": "horunge",
    "horungars": "horunge",
    "horungen": "horunge",
    "horungens": "horunge",
    "horunges": "horunge",
    "hos": "ho",
    "hospicen": "hospice",
    "hospicens": "hospice",
    "hospices": "hospice",
    "hospicet": "hospice",
    "hospicets": "hospice",
    "hospisen": "hospis",
    "hospisens": "hospis",
    "hospiset": "hospis",
    "hospisets": "hospis",
    "hospitalen": "hospital",
    "hospitalens": "hospital",
    "hospitalet": "hospital",
    "hospitalets": "hospital",
    "hospitaliserad": "hospitalisera",
    "hospitaliserade": "hospitalisera",
    "hospitaliserades": "hospitalisera",
    "hospitaliserads": "hospitalisera",
    "hospitaliserande": "hospitalisera",
    "hospitaliseranden": "hospitaliserande",
    "hospitaliserandena": "hospitaliserande",
    "hospitaliserandenas": "hospitaliserande",
    "hospitaliserandens": "hospitaliserande",
    "hospitaliserandes": "hospitaliserande",
    "hospitaliserandet": "hospitaliserande",
    "hospitaliserandets": "hospitaliserande",
    "hospitaliserar": "hospitalisera",
    "hospitaliseras": "hospitalisera",
    "hospitaliserat": "hospitalisera",
    "hospitaliserats": "hospitalisera",
    "hospitaliserbara": "hospitaliserbar",
    "hospitaliserbarare": "hospitaliserbar",
    "hospitaliserbarares": "hospitaliserbar",
    "hospitaliserbaras": "hospitaliserbar",
    "hospitaliserbarast": "hospitaliserbar",
    "hospitaliserbaraste": "hospitaliserbar",
    "hospitaliserbarastes": "hospitaliserbar",
    "hospitaliserbarasts": "hospitaliserbar",
    "hospitaliserbare": "hospitaliserbar",
    "hospitaliserbares": "hospitaliserbar",
    "hospitaliserbarheten": "hospitaliserbarhet",
    "hospitaliserbarhetens": "hospitaliserbarhet",
    "hospitaliserbarhets": "hospitaliserbarhet",
    "hospitaliserbars": "hospitaliserbar",
    "hospitaliserbart": "hospitaliserbar",
    "hospitaliserbarts": "hospitaliserbar",
    "hospitaliseringar": "hospitalisering",
    "hospitaliseringarna": "hospitalisering",
    "hospitaliseringarnas": "hospitalisering",
    "hospitaliseringars": "hospitalisering",
    "hospitaliseringen": "hospitalisering",
    "hospitaliseringens": "hospitalisering",
    "hospitaliserings": "hospitalisering",
    "hospitaliseringseffekten": "hospitaliseringseffekt",
    "hospitaliseringseffektens": "hospitaliseringseffekt",
    "hospitaliseringseffekts": "hospitaliseringseffekt",
    "hospitals": "hospital",
    "hospitsen": "hospits",
    "hospitsens": "hospits",
    "hospitset": "hospits",
    "hospitsets": "hospits",
    "host": "hosta",
    "hostad": "hosta",
    "hostade": "hosta",
    "hostades": "hosta",
    "hostads": "hosta",
    "hostan": "hosta",
    "hostande": "hosta",
    "hostanden": "hostande",
    "hostandena": "hostande",
    "hostandenas": "hostande",
    "hostandens": "hostande",
    "hostandes": "hostande",
    "hostandet": "hostande",
    "hostandets": "hostande",
    "hostanfallen": "hostanfall",
    "hostanfallens": "hostanfall",
    "hostanfallet": "hostanfall",
    "hostanfallets": "hostanfall",
    "hostanfalls": "hostanfall",
    "hostans": "hosta",
    "hostar": "hosta",
    "hostarna": "host",
    "hostarnas": "host",
    "hostars": "host",
    "hostas": "hosta",
    "hostat": "hosta",
    "hostats": "hosta",
    "hostattacken": "hostattack",
    "hostattackens": "hostattack",
    "hostattacker": "hostattack",
    "hostattackerna": "hostattack",
    "hostattackernas": "hostattack",
    "hostattackers": "hostattack",
    "hostattacks": "hostattack",
    "hosten": "host",
    "hostens": "host",
    "hostet": "host",
    "hostets": "host",
    "hostian": "hostia",
    "hostians": "hostia",
    "hostias": "hostia",
    "hostiga": "hostig",
    "hostigare": "hostig",
    "hostigares": "hostig",
    "hostigas": "hostig",
    "hostigast": "hostig",
    "hostigaste": "hostig",
    "hostigastes": "hostig",
    "hostigasts": "hostig",
    "hostige": "hostig",
    "hostiges": "hostig",
    "hostigheten": "hostighet",
    "hostighetens": "hostighet",
    "hostighets": "hostighet",
    "hostigs": "hostig",
    "hostigt": "hostig",
    "hostigts": "hostig",
    "hostior": "hostia",
    "hostiorna": "hostia",
    "hostiornas": "hostia",
    "hostiors": "hostia",
    "hostningar": "hostning",
    "hostningarna": "hostning",
    "hostningarnas": "hostning",
    "hostningars": "hostning",
    "hostningen": "hostning",
    "hostningens": "hostning",
    "hostnings": "hostning",
    "hosts": "host",
    "hot": "hota",
    "hotad": "hota",
    "hotade": "hota",
    "hotades": "hota",
    "hotads": "hota",
    "hotande": "hota",
    "hotanden": "hotande",
    "hotandena": "hotande",
    "hotandenas": "hotande",
    "hotandens": "hotande",
    "hotandes": "hotande",
    "hotandet": "hotande",
    "hotandets": "hotande",
    "hotar": "hota",
    "hotas": "hota",
    "hotat": "hota",
    "hotats": "hota",
    "hotbilden": "hotbild",
    "hotbildens": "hotbild",
    "hotbilder": "hotbild",
    "hotbilderna": "hotbild",
    "hotbildernas": "hotbild",
    "hotbilders": "hotbild",
    "hotbilds": "hotbild",
    "hotchpotchsoppan": "hotchpotchsoppa",
    "hotchpotchsoppans": "hotchpotchsoppa",
    "hotchpotchsoppas": "hotchpotchsoppa",
    "hotellbranden": "hotellbrand",
    "hotellbrandens": "hotellbrand",
    "hotellbrands": "hotellbrand",
    "hotellbränder": "hotellbrand",
    "hotellbränderna": "hotellbrand",
    "hotellbrändernas": "hotellbrand",
    "hotellbränders": "hotellbrand",
    "hotellen": "hotell",
    "hotellens": "hotell",
    "hotellet": "hotell",
    "hotellets": "hotell",
    "hotellgästen": "hotellgäst",
    "hotellgästens": "hotellgäst",
    "hotellgäster": "hotellgäst",
    "hotellgästerna": "hotellgäst",
    "hotellgästernas": "hotellgäst",
    "hotellgästers": "hotellgäst",
    "hotellgästs": "hotellgäst",
    "hotellkomplexen": "hotellkomplex",
    "hotellkomplexens": "hotellkomplex",
    "hotellkomplexet": "hotellkomplex",
    "hotellkomplexets": "hotellkomplex",
    "hotellmatsalar": "hotellmatsal",
    "hotellmatsalarna": "hotellmatsal",
    "hotellmatsalarnas": "hotellmatsal",
    "hotellmatsalars": "hotellmatsal",
    "hotellmatsalen": "hotellmatsal",
    "hotellmatsalens": "hotellmatsal",
    "hotellmatsals": "hotellmatsal",
    "hotellmatt": "hotellmatta",
    "hotellmattan": "hotellmatta",
    "hotellmattans": "hotellmatta",
    "hotellmattas": "hotellmatta",
    "hotellmatte": "hotellmatta",
    "hotellmattor": "hotellmatta",
    "hotellmattorna": "hotellmatta",
    "hotellmattornas": "hotellmatta",
    "hotellmattors": "hotellmatta",
    "hotellmatts": "hotellmatta",
    "hotellpojk": "hotellpojke",
    "hotellpojkar": "hotellpojke",
    "hotellpojkarna": "hotellpojke",
    "hotellpojkarnas": "hotellpojke",
    "hotellpojkars": "hotellpojke",
    "hotellpojken": "hotellpojke",
    "hotellpojkens": "hotellpojke",
    "hotellpojkes": "hotellpojke",
    "hotellpojks": "hotellpojke",
    "hotellrummen": "hotellrum",
    "hotellrummens": "hotellrum",
    "hotellrummet": "hotellrum",
    "hotellrummets": "hotellrum",
    "hotellrums": "hotellrum",
    "hotells": "hotell",
    "hotelsen": "hotelse",
    "hotelsens": "hotelse",
    "hotelser": "hotelse",
    "hotelserna": "hotelse",
    "hotelsernas": "hotelse",
    "hotelsers": "hotelse",
    "hotelses": "hotelse",
    "hoten": "hot",
    "hotens": "hot",
    "hotet": "hot",
    "hotets": "hot",
    "hotfulla": "hotfull",
    "hotfullare": "hotfull",
    "hotfullares": "hotfull",
    "hotfullas": "hotfull",
    "hotfullast": "hotfull",
    "hotfullaste": "hotfull",
    "hotfullastes": "hotfull",
    "hotfullasts": "hotfull",
    "hotfulle": "hotfull",
    "hotfulles": "hotfull",
    "hotfullheten": "hotfullhet",
    "hotfullhetens": "hotfullhet",
    "hotfullheter": "hotfullhet",
    "hotfullheterna": "hotfullhet",
    "hotfullheternas": "hotfullhet",
    "hotfullheters": "hotfullhet",
    "hotfullhets": "hotfullhet",
    "hotfulls": "hotfull",
    "hotfullt": "hotfull",
    "hotfullts": "hotfull",
    "hotnivåer": "hotnivå",
    "hotnivåerna": "hotnivå",
    "hotnivåernas": "hotnivå",
    "hotnivåers": "hotnivå",
    "hotnivån": "hotnivå",
    "hotnivåns": "hotnivå",
    "hotnivås": "hotnivå",
    "hots": "hot",
    "hott": "hotta",
    "hottad": "hotta",
    "hottade": "hotta",
    "hottades": "hotta",
    "hottads": "hotta",
    "hottande": "hotta",
    "hottanden": "hottande",
    "hottandena": "hottande",
    "hottandenas": "hottande",
    "hottandens": "hottande",
    "hottandes": "hottande",
    "hottandet": "hottande",
    "hottandets": "hottande",
    "hottar": "hotta",
    "hottas": "hotta",
    "hottat": "hotta",
    "hottats": "hotta",
    "hottentotsk": "hottentotska",
    "hottentotska": "hottentotsk",
    "hottentotskan": "hottentotska",
    "hottentotskans": "hottentotska",
    "hottentotskare": "hottentotsk",
    "hottentotskares": "hottentotsk",
    "hottentotskas": "hottentotska",
    "hottentotskast": "hottentotsk",
    "hottentotskaste": "hottentotsk",
    "hottentotskastes": "hottentotsk",
    "hottentotskasts": "hottentotsk",
    "hottentotske": "hottentotska",
    "hottentotskes": "hottentotsk",
    "hottentotskor": "hottentotska",
    "hottentotskorna": "hottentotska",
    "hottentotskornas": "hottentotska",
    "hottentotskors": "hottentotska",
    "hottentotsks": "hottentotsk",
    "hottentotskt": "hottentotsk",
    "hottentotskts": "hottentotsk",
    "hottentotten": "hottentott",
    "hottentottens": "hottentott",
    "hottentotter": "hottentott",
    "hottentotterna": "hottentott",
    "hottentotternas": "hottentott",
    "hottentotters": "hottentott",
    "hottentotts": "hottentott",
    "hottningar": "hottning",
    "hottningarna": "hottning",
    "hottningarnas": "hottning",
    "hottningars": "hottning",
    "hottningen": "hottning",
    "hottningens": "hottning",
    "hottnings": "hottning",
    "housen": "house",
    "housens": "house",
    "houses": "house",
    "hovar": "hov",
    "hovarna": "hov",
    "hovarnas": "hov",
    "hovars": "hov",
    "hovbeslagen": "hovbeslag",
    "hovbeslagens": "hovbeslag",
    "hovbeslaget": "hovbeslag",
    "hovbeslagets": "hovbeslag",
    "hovbeslags": "hovbeslag",
    "hovbetjänten": "hovbetjänt",
    "hovbetjäntens": "hovbetjänt",
    "hovbetjänter": "hovbetjänt",
    "hovbetjänterna": "hovbetjänt",
    "hovbetjänternas": "hovbetjänt",
    "hovbetjänters": "hovbetjänt",
    "hovbetjänts": "hovbetjänt",
    "hovdamen": "hovdam",
    "hovdamens": "hovdam",
    "hovdamer": "hovdam",
    "hovdamerna": "hovdam",
    "hovdamernas": "hovdam",
    "hovdamers": "hovdam",
    "hovdams": "hovdam",
    "hovdjuren": "hovdjur",
    "hovdjurens": "hovdjur",
    "hovdjuret": "hovdjur",
    "hovdjurets": "hovdjur",
    "hovdjurs": "hovdjur",
    "hoven": "hov",
    "hovens": "hov",
    "hovet": "hov",
    "hovets": "hov",
    "hovkapellen": "hovkapell",
    "hovkapellens": "hovkapell",
    "hovkapellet": "hovkapell",
    "hovkapellets": "hovkapell",
    "hovkapells": "hovkapell",
    "hovleverantören": "hovleverantör",
    "hovleverantörens": "hovleverantör",
    "hovleverantörer": "hovleverantör",
    "hovleverantörerna": "hovleverantör",
    "hovleverantörernas": "hovleverantör",
    "hovleverantörers": "hovleverantör",
    "hovleverantörs": "hovleverantör",
    "hovmannamässiga": "hovmannamässig",
    "hovmannamässigare": "hovmannamässig",
    "hovmannamässigares": "hovmannamässig",
    "hovmannamässigas": "hovmannamässig",
    "hovmannamässigast": "hovmannamässig",
    "hovmannamässigaste": "hovmannamässig",
    "hovmannamässigastes": "hovmannamässig",
    "hovmannamässigasts": "hovmannamässig",
    "hovmannamässige": "hovmannamässig",
    "hovmannamässiges": "hovmannamässig",
    "hovmannamässigs": "hovmannamässig",
    "hovmannamässigt": "hovmannamässig",
    "hovmannamässigts": "hovmannamässig",
    "hovmannen": "hovman",
    "hovmannens": "hovman",
    "hovmans": "hovman",
    "hovmarskalkar": "hovmarskalk",
    "hovmarskalkarna": "hovmarskalk",
    "hovmarskalkarnas": "hovmarskalk",
    "hovmarskalkars": "hovmarskalk",
    "hovmarskalken": "hovmarskalk",
    "hovmarskalkens": "hovmarskalk",
    "hovmarskalks": "hovmarskalk",
    "hovmän": "hovman",
    "hovmännen": "hovman",
    "hovmännens": "hovman",
    "hovmäns": "hovman",
    "hovmästar": "hovmästare",
    "hovmästaren": "hovmästare",
    "hovmästarens": "hovmästare",
    "hovmästares": "hovmästare",
    "hovmästarna": "hovmästare",
    "hovmästarnas": "hovmästare",
    "hovnarrar": "hovnarr",
    "hovnarrarna": "hovnarr",
    "hovnarrarnas": "hovnarr",
    "hovnarrars": "hovnarr",
    "hovnarren": "hovnarr",
    "hovnarrens": "hovnarr",
    "hovnarrs": "hovnarr",
    "hovnigningar": "hovnigning",
    "hovnigningarna": "hovnigning",
    "hovnigningarnas": "hovnigning",
    "hovnigningars": "hovnigning",
    "hovnigningen": "hovnigning",
    "hovnigningens": "hovnigning",
    "hovnignings": "hovnigning",
    "hovrade": "hovra",
    "hovrades": "hovra",
    "hovrande": "hovra",
    "hovranden": "hovrande",
    "hovrandena": "hovrande",
    "hovrandenas": "hovrande",
    "hovrandens": "hovrande",
    "hovrandes": "hovrande",
    "hovrandet": "hovrande",
    "hovrandets": "hovrande",
    "hovrar": "hovra",
    "hovras": "hovra",
    "hovrat": "hovra",
    "hovrats": "hovra",
    "hovreportern": "hovreporter",
    "hovreporterns": "hovreporter",
    "hovreporters": "hovreporter",
    "hovreportrar": "hovreporter",
    "hovreportrarna": "hovreporter",
    "hovreportrarnas": "hovreporter",
    "hovreportrars": "hovreporter",
    "hovrätten": "hovrätt",
    "hovrättens": "hovrätt",
    "hovrätter": "hovrätt",
    "hovrätterna": "hovrätt",
    "hovrätternas": "hovrätt",
    "hovrätters": "hovrätt",
    "hovrätts": "hovrätt",
    "hovrättspresidenten": "hovrättspresident",
    "hovrättspresidentens": "hovrättspresident",
    "hovrättspresidenter": "hovrättspresident",
    "hovrättspresidenterna": "hovrättspresident",
    "hovrättspresidenternas": "hovrättspresident",
    "hovrättspresidenters": "hovrättspresident",
    "hovrättspresidents": "hovrättspresident",
    "hovrättsråden": "hovrättsråd",
    "hovrättsrådens": "hovrättsråd",
    "hovrättsrådet": "hovrättsråd",
    "hovrättsrådets": "hovrättsråd",
    "hovrättsråds": "hovrättsråd",
    "hovs": "hov",
    "hovsamheten": "hovsamhet",
    "hovsamhetens": "hovsamhet",
    "hovsamhets": "hovsamhet",
    "hovsamma": "hovsam",
    "hovsammare": "hovsam",
    "hovsammares": "hovsam",
    "hovsammas": "hovsam",
    "hovsammast": "hovsam",
    "hovsammaste": "hovsam",
    "hovsammastes": "hovsam",
    "hovsammasts": "hovsam",
    "hovsamme": "hovsam",
    "hovsammes": "hovsam",
    "hovsams": "hovsam",
    "hovsamt": "hovsam",
    "hovsamts": "hovsam",
    "hovslagar": "hovslagare",
    "hovslagaren": "hovslagare",
    "hovslagarens": "hovslagare",
    "hovslagares": "hovslagare",
    "hovslagarna": "hovslagare",
    "hovslagarnas": "hovslagare",
    "hovslagen": "hovslag",
    "hovslagens": "hovslag",
    "hovslaget": "hovslag",
    "hovslagets": "hovslag",
    "hovslags": "hovslag",
    "hovstaten": "hovstat",
    "hovstatens": "hovstat",
    "hovstater": "hovstat",
    "hovstaterna": "hovstat",
    "hovstaternas": "hovstat",
    "hovstaters": "hovstat",
    "hovstats": "hovstat",
    "hovtänger": "hovtång",
    "hovtängerna": "hovtång",
    "hovtängernas": "hovtång",
    "hovtängers": "hovtång",
    "hovtången": "hovtång",
    "hovtångens": "hovtång",
    "hovtångs": "hovtång",
    "hryvnjan": "hryvnja",
    "hryvnjana": "hryvnja",
    "hryvnjanas": "hryvnja",
    "hryvnjans": "hryvnja",
    "hryvnjas": "hryvnja",
    "hucklen": "huckle",
    "hucklena": "huckle",
    "hucklenas": "huckle",
    "hucklens": "huckle",
    "huckles": "huckle",
    "hucklet": "huckle",
    "hucklets": "huckle",
    "huckls": "huckle",
    "hudar": "hud",
    "hudarna": "hud",
    "hudarnas": "hud",
    "hudars": "hud",
    "hudcancerformen": "hudcancerform",
    "hudcancerformens": "hudcancerform",
    "hudcancerformer": "hudcancerform",
    "hudcancerformerna": "hudcancerform",
    "hudcancerformernas": "hudcancerform",
    "hudcancerformers": "hudcancerform",
    "hudcancerforms": "hudcancerform",
    "hudcancern": "hudcancer",
    "hudcancerns": "hudcancer",
    "hudcancers": "hudcancer",
    "hudcellen": "hudcell",
    "hudcellens": "hudcell",
    "hudceller": "hudcell",
    "hudcellerna": "hudcell",
    "hudcellernas": "hudcell",
    "hudcellers": "hudcell",
    "hudcells": "hudcell",
    "huden": "hud",
    "hudens": "hud",
    "hudfick": "hudficka",
    "hudfickan": "hudficka",
    "hudfickans": "hudficka",
    "hudfickas": "hudficka",
    "hudficke": "hudficka",
    "hudfickor": "hudficka",
    "hudfickorna": "hudficka",
    "hudfickornas": "hudficka",
    "hudfickors": "hudficka",
    "hudficks": "hudficka",
    "hudflikar": "hudflik",
    "hudflikarna": "hudflik",
    "hudflikarnas": "hudflik",
    "hudflikars": "hudflik",
    "hudfliken": "hudflik",
    "hudflikens": "hudflik",
    "hudfliks": "hudflik",
    "hudfläckar": "hudfläck",
    "hudfläckarna": "hudfläck",
    "hudfläckarnas": "hudfläck",
    "hudfläckars": "hudfläck",
    "hudfläcken": "hudfläck",
    "hudfläckens": "hudfläck",
    "hudfläcks": "hudfläck",
    "hudfläng": "hudflänga",
    "hudflängande": "hudflänga",
    "hudflänganden": "hudflängande",
    "hudflängandena": "hudflängande",
    "hudflängandenas": "hudflängande",
    "hudflängandens": "hudflängande",
    "hudflängandes": "hudflängande",
    "hudflängandet": "hudflängande",
    "hudflängandets": "hudflängande",
    "hudflängas": "hudflänga",
    "hudflängd": "hudflänga",
    "hudflängda": "hudflänga",
    "hudflängdas": "hudflänga",
    "hudflängde": "hudflänga",
    "hudflängdes": "hudflänga",
    "hudflängds": "hudflänga",
    "hudflänger": "hudflänga",
    "hudflänges": "hudflänga",
    "hudflängs": "hudflänga",
    "hudflängt": "hudflänga",
    "hudflängts": "hudflänga",
    "hudfärgade": "hudfärgad",
    "hudfärgades": "hudfärgad",
    "hudfärgads": "hudfärgad",
    "hudfärgat": "hudfärgad",
    "hudfärgats": "hudfärgad",
    "hudfärgen": "hudfärg",
    "hudfärgens": "hudfärg",
    "hudfärger": "hudfärg",
    "hudfärgerna": "hudfärg",
    "hudfärgernas": "hudfärg",
    "hudfärgers": "hudfärg",
    "hudfärgs": "hudfärg",
    "hudinflammationen": "hudinflammation",
    "hudinflammationens": "hudinflammation",
    "hudinflammationer": "hudinflammation",
    "hudinflammationerna": "hudinflammation",
    "hudinflammationernas": "hudinflammation",
    "hudinflammationers": "hudinflammation",
    "hudinflammations": "hudinflammation",
    "hudkrämen": "hudkräm",
    "hudkrämens": "hudkräm",
    "hudkrämer": "hudkräm",
    "hudkrämerna": "hudkräm",
    "hudkrämernas": "hudkräm",
    "hudkrämers": "hudkräm",
    "hudkräms": "hudkräm",
    "hudlagerna": "hudlager",
    "hudlagernas": "hudlager",
    "hudlagers": "hudlager",
    "hudlagren": "hudlager",
    "hudlagrens": "hudlager",
    "hudlagret": "hudlager",
    "hudlagrets": "hudlager",
    "hudlösa": "hudlös",
    "hudlösare": "hudlös",
    "hudlösares": "hudlös",
    "hudlösas": "hudlös",
    "hudlösast": "hudlös",
    "hudlösaste": "hudlös",
    "hudlösastes": "hudlös",
    "hudlösasts": "hudlös",
    "hudlöse": "hudlös",
    "hudlöses": "hudlös",
    "hudlösheten": "hudlöshet",
    "hudlöshetens": "hudlöshet",
    "hudlöshets": "hudlöshet",
    "hudlöst": "hudlös",
    "hudlösts": "hudlös",
    "hudmedels": "hudmedel",
    "hudmedlen": "hudmedel",
    "hudmedlens": "hudmedel",
    "hudmedlet": "hudmedel",
    "hudmedlets": "hudmedel",
    "hudoljan": "hudolja",
    "hudoljans": "hudolja",
    "hudoljas": "hudolja",
    "hudolje": "hudolja",
    "hudoljor": "hudolja",
    "hudoljorna": "hudolja",
    "hudoljornas": "hudolja",
    "hudoljors": "hudolja",
    "huds": "hud",
    "hudsalv": "hudsalva",
    "hudsalvan": "hudsalva",
    "hudsalvans": "hudsalva",
    "hudsalvas": "hudsalva",
    "hudsalve": "hudsalva",
    "hudsalvor": "hudsalva",
    "hudsalvorna": "hudsalva",
    "hudsalvornas": "hudsalva",
    "hudsalvors": "hudsalva",
    "hudsalvs": "hudsalva",
    "hudsjukdomar": "hudsjukdom",
    "hudsjukdomarna": "hudsjukdom",
    "hudsjukdomarnas": "hudsjukdom",
    "hudsjukdomars": "hudsjukdom",
    "hudsjukdomen": "hudsjukdom",
    "hudsjukdomens": "hudsjukdom",
    "hudsjukdoms": "hudsjukdom",
    "hudsprick": "hudspricka",
    "hudsprickan": "hudspricka",
    "hudsprickans": "hudspricka",
    "hudsprickas": "hudspricka",
    "hudspricke": "hudspricka",
    "hudsprickor": "hudspricka",
    "hudsprickorna": "hudspricka",
    "hudsprickornas": "hudspricka",
    "hudsprickors": "hudspricka",
    "hudspricks": "hudspricka",
    "hudtransplantationen": "hudtransplantation",
    "hudtransplantationens": "hudtransplantation",
    "hudtransplantationer": "hudtransplantation",
    "hudtransplantationerna": "hudtransplantation",
    "hudtransplantationernas": "hudtransplantation",
    "hudtransplantationers": "hudtransplantation",
    "hudtransplantations": "hudtransplantation",
    "hudutslagen": "hudutslag",
    "hudutslagens": "hudutslag",
    "hudutslaget": "hudutslag",
    "hudutslagets": "hudutslag",
    "hudutslags": "hudutslag",
    "hudvecken": "hudveck",
    "hudveckens": "hudveck",
    "hudvecket": "hudveck",
    "hudveckets": "hudveck",
    "hudvecks": "hudveck",
    "hudvänliga": "hudvänlig",
    "hudvänligare": "hudvänlig",
    "hudvänligares": "hudvänlig",
    "hudvänligas": "hudvänlig",
    "hudvänligast": "hudvänlig",
    "hudvänligaste": "hudvänlig",
    "hudvänligastes": "hudvänlig",
    "hudvänligasts": "hudvänlig",
    "hudvänlige": "hudvänlig",
    "hudvänliges": "hudvänlig",
    "hudvänligheten": "hudvänlighet",
    "hudvänlighetens": "hudvänlighet",
    "hudvänlighets": "hudvänlighet",
    "hudvänligs": "hudvänlig",
    "hudvänligt": "hudvänlig",
    "hudvänligts": "hudvänlig",
    "hudömsningar": "hudömsning",
    "hudömsningarna": "hudömsning",
    "hudömsningarnas": "hudömsning",
    "hudömsningars": "hudömsning",
    "hudömsningen": "hudömsning",
    "hudömsningens": "hudömsning",
    "hudömsnings": "hudömsning",
    "hugade": "hugad",
    "hugades": "hugad",
    "hugads": "hugad",
    "hugat": "hugad",
    "hugats": "hugad",
    "hugen": "hug",
    "hugenotten": "hugenott",
    "hugenottens": "hugenott",
    "hugenotter": "hugenott",
    "hugenotterna": "hugenott",
    "hugenotternas": "hugenott",
    "hugenotters": "hugenott",
    "hugenotts": "hugenott",
    "hugens": "hug",
    "hugfäst": "hugfästa",
    "hugfästande": "hugfästa",
    "hugfästanden": "hugfästande",
    "hugfästandena": "hugfästande",
    "hugfästandenas": "hugfästande",
    "hugfästandens": "hugfästande",
    "hugfästandes": "hugfästande",
    "hugfästandet": "hugfästande",
    "hugfästandets": "hugfästande",
    "hugfästas": "hugfästa",
    "hugfäste": "hugfästa",
    "hugfäster": "hugfästa",
    "hugfästes": "hugfästa",
    "hugfästs": "hugfästa",
    "hugg": "hugga",
    "huggande": "hugga",
    "hugganden": "huggande",
    "huggandena": "huggande",
    "huggandenas": "huggande",
    "huggandens": "huggande",
    "huggandes": "huggande",
    "huggandet": "huggande",
    "huggandets": "huggande",
    "huggar": "huggare",
    "huggaren": "huggare",
    "huggarens": "huggare",
    "huggares": "huggare",
    "huggarna": "huggare",
    "huggarnas": "huggare",
    "huggas": "hugga",
    "hugge": "hugga",
    "huggen": "hugga",
    "huggens": "hugga",
    "hugger": "hugga",
    "hugges": "hugga",
    "hugget": "hugga",
    "huggets": "hugga",
    "huggit": "hugga",
    "huggits": "hugga",
    "huggkrokar": "huggkrok",
    "huggkrokarna": "huggkrok",
    "huggkrokarnas": "huggkrok",
    "huggkrokars": "huggkrok",
    "huggkroken": "huggkrok",
    "huggkrokens": "huggkrok",
    "huggkroks": "huggkrok",
    "huggkubb": "huggkubbe",
    "huggkubbar": "huggkubbe",
    "huggkubbarna": "huggkubbe",
    "huggkubbarnas": "huggkubbe",
    "huggkubbars": "huggkubbe",
    "huggkubben": "huggkubbe",
    "huggkubbens": "huggkubbe",
    "huggkubbes": "huggkubbe",
    "huggkubbs": "huggkubbe",
    "huggmejseln": "huggmejsel",
    "huggmejselns": "huggmejsel",
    "huggmejsels": "huggmejsel",
    "huggmejslar": "huggmejsel",
    "huggmejslarna": "huggmejsel",
    "huggmejslarnas": "huggmejsel",
    "huggmejslars": "huggmejsel",
    "huggna": "hugga",
    "huggnas": "hugga",
    "huggne": "hugga",
    "huggnes": "hugga",
    "huggormar": "huggorm",
    "huggormarna": "huggorm",
    "huggormarnas": "huggorm",
    "huggormars": "huggorm",
    "huggormen": "huggorm",
    "huggormens": "huggorm",
    "huggorms": "huggorm",
    "huggs": "hugga",
    "huggsexan": "huggsexa",
    "huggsexans": "huggsexa",
    "huggsexas": "huggsexa",
    "huggsexe": "huggsexa",
    "huggsexor": "huggsexa",
    "huggsexorna": "huggsexa",
    "huggsexornas": "huggsexa",
    "huggsexors": "huggsexa",
    "huggtanden": "huggtand",
    "huggtandens": "huggtand",
    "huggtands": "huggtand",
    "huggtänder": "huggtand",
    "huggtänderna": "huggtand",
    "huggtändernas": "huggtand",
    "huggtänders": "huggtand",
    "hugn": "hugna",
    "hugnad": "hugna",
    "hugnade": "hugna",
    "hugnaden": "hugnad",
    "hugnadens": "hugnad",
    "hugnader": "hugnad",
    "hugnaderna": "hugnad",
    "hugnadernas": "hugnad",
    "hugnaders": "hugnad",
    "hugnades": "hugna",
    "hugnads": "hugnad",
    "hugnande": "hugna",
    "hugnanden": "hugnande",
    "hugnandena": "hugnande",
    "hugnandenas": "hugnande",
    "hugnandens": "hugnande",
    "hugnandes": "hugnande",
    "hugnandet": "hugnande",
    "hugnandets": "hugnande",
    "hugnar": "hugna",
    "hugnas": "hugna",
    "hugnat": "hugna",
    "hugnats": "hugna",
    "hugnesamheten": "hugnesamhet",
    "hugnesamhetens": "hugnesamhet",
    "hugnesamhets": "hugnesamhet",
    "hugnesamma": "hugnesam",
    "hugnesammare": "hugnesam",
    "hugnesammares": "hugnesam",
    "hugnesammas": "hugnesam",
    "hugnesammast": "hugnesam",
    "hugnesammaste": "hugnesam",
    "hugnesammastes": "hugnesam",
    "hugnesammasts": "hugnesam",
    "hugnesamme": "hugnesam",
    "hugnesammes": "hugnesam",
    "hugnesams": "hugnesam",
    "hugnesamt": "hugnesam",
    "hugnesamts": "hugnesam",
    "hugs": "hug",
    "hugskotten": "hugskott",
    "hugskottens": "hugskott",
    "hugskottet": "hugskott",
    "hugskottets": "hugskott",
    "hugskotts": "hugskott",
    "hugsval": "hugsvala",
    "hugsvalad": "hugsvala",
    "hugsvalade": "hugsvala",
    "hugsvalades": "hugsvala",
    "hugsvalads": "hugsvala",
    "hugsvalande": "hugsvala",
    "hugsvalanden": "hugsvalande",
    "hugsvalandena": "hugsvalande",
    "hugsvalandenas": "hugsvalande",
    "hugsvalandens": "hugsvalande",
    "hugsvalandes": "hugsvalande",
    "hugsvalandet": "hugsvalande",
    "hugsvalandets": "hugsvalande",
    "hugsvalar": "hugsvala",
    "hugsvalas": "hugsvala",
    "hugsvalat": "hugsvala",
    "hugsvalats": "hugsvala",
    "hula-hulan": "hula-hula",
    "hula-hulans": "hula-hula",
    "hula-hulas": "hula-hula",
    "hulda": "huld",
    "huldare": "huld",
    "huldares": "huld",
    "huldas": "huld",
    "huldast": "huld",
    "huldaste": "huld",
    "huldastes": "huld",
    "huldasts": "huld",
    "hulde": "huld",
    "huldes": "huld",
    "huldheten": "huldhet",
    "huldhetens": "huldhet",
    "huldhets": "huldhet",
    "huldran": "huldra",
    "huldrans": "huldra",
    "huldras": "huldra",
    "huldre": "huldra",
    "huldror": "huldra",
    "huldrorna": "huldra",
    "huldrornas": "huldra",
    "huldrors": "huldra",
    "hulds": "huld",
    "huliganen": "huligan",
    "huliganens": "huligan",
    "huliganer": "huligan",
    "huliganerna": "huligan",
    "huliganernas": "huligan",
    "huliganers": "huligan",
    "huligans": "huligan",
    "hulk": "hulka",
    "hulkade": "hulka",
    "hulkades": "hulka",
    "hulkande": "hulka",
    "hulkanden": "hulkande",
    "hulkandena": "hulkande",
    "hulkandenas": "hulkande",
    "hulkandens": "hulkande",
    "hulkandes": "hulkande",
    "hulkandet": "hulkande",
    "hulkandets": "hulkande",
    "hulkar": "hulka",
    "hulkarna": "hulk",
    "hulkarnas": "hulk",
    "hulkars": "hulk",
    "hulkas": "hulka",
    "hulkat": "hulka",
    "hulkats": "hulka",
    "hulken": "hulk",
    "hulkens": "hulk",
    "hulks": "hulk",
    "hullet": "hull",
    "hullets": "hull",
    "hullingar": "hulling",
    "hullingarna": "hulling",
    "hullingarnas": "hulling",
    "hullingars": "hulling",
    "hullingen": "hulling",
    "hullingens": "hulling",
    "hullings": "hulling",
    "hulls": "hull",
    "hult": "huld",
    "hultar": "hult",
    "hultarna": "hult",
    "hultarnas": "hult",
    "hultars": "hult",
    "hulten": "hult",
    "hultens": "hult",
    "hulter": "hult",
    "hulterna": "hult",
    "hulternas": "hult",
    "hulters": "hult",
    "hultet": "hult",
    "hultets": "hult",
    "hults": "hult",
    "hum": "humma",
    "humana": "human",
    "humanare": "human",
    "humanares": "human",
    "humanas": "human",
    "humanast": "human",
    "humanaste": "human",
    "humanastes": "human",
    "humanasts": "human",
    "humane": "human",
    "humanekologien": "humanekologi",
    "humanekologiens": "humanekologi",
    "humanekologin": "humanekologi",
    "humanekologins": "humanekologi",
    "humanekologis": "humanekologi",
    "humanekologiska": "humanekologisk",
    "humanekologiskare": "humanekologisk",
    "humanekologiskares": "humanekologisk",
    "humanekologiskas": "humanekologisk",
    "humanekologiskast": "humanekologisk",
    "humanekologiskaste": "humanekologisk",
    "humanekologiskastes": "humanekologisk",
    "humanekologiskasts": "humanekologisk",
    "humanekologiske": "humanekologisk",
    "humanekologiskes": "humanekologisk",
    "humanekologisks": "humanekologisk",
    "humanekologiskt": "humanekologisk",
    "humanekologiskts": "humanekologisk",
    "humanes": "human",
    "humanioran": "humaniora",
    "humaniorana": "humaniora",
    "humanioranas": "humaniora",
    "humaniorans": "humaniora",
    "humanioras": "humaniora",
    "humaniserad": "humanisera",
    "humaniserade": "humanisera",
    "humaniserades": "humanisera",
    "humaniserads": "humanisera",
    "humaniserande": "humanisera",
    "humaniseranden": "humaniserande",
    "humaniserandena": "humaniserande",
    "humaniserandenas": "humaniserande",
    "humaniserandens": "humaniserande",
    "humaniserandes": "humaniserande",
    "humaniserandet": "humaniserande",
    "humaniserandets": "humaniserande",
    "humaniserar": "humanisera",
    "humaniseras": "humanisera",
    "humaniserat": "humanisera",
    "humaniserats": "humanisera",
    "humaniserbara": "humaniserbar",
    "humaniserbarare": "humaniserbar",
    "humaniserbarares": "humaniserbar",
    "humaniserbaras": "humaniserbar",
    "humaniserbarast": "humaniserbar",
    "humaniserbaraste": "humaniserbar",
    "humaniserbarastes": "humaniserbar",
    "humaniserbarasts": "humaniserbar",
    "humaniserbare": "humaniserbar",
    "humaniserbares": "humaniserbar",
    "humaniserbarheten": "humaniserbarhet",
    "humaniserbarhetens": "humaniserbarhet",
    "humaniserbarhets": "humaniserbarhet",
    "humaniserbars": "humaniserbar",
    "humaniserbart": "humaniserbar",
    "humaniserbarts": "humaniserbar",
    "humaniseringar": "humanisering",
    "humaniseringarna": "humanisering",
    "humaniseringarnas": "humanisering",
    "humaniseringars": "humanisering",
    "humaniseringen": "humanisering",
    "humaniseringens": "humanisering",
    "humaniserings": "humanisering",
    "humanismen": "humanism",
    "humanismens": "humanism",
    "humanismer": "humanism",
    "humanismerna": "humanism",
    "humanismernas": "humanism",
    "humanismers": "humanism",
    "humanisms": "humanism",
    "humanisten": "humanist",
    "humanistens": "humanist",
    "humanister": "humanist",
    "humanisterna": "humanist",
    "humanisternas": "humanist",
    "humanisters": "humanist",
    "humanistiska": "humanistisk",
    "humanistiskare": "humanistisk",
    "humanistiskares": "humanistisk",
    "humanistiskas": "humanistisk",
    "humanistiskast": "humanistisk",
    "humanistiskaste": "humanistisk",
    "humanistiskastes": "humanistisk",
    "humanistiskasts": "humanistisk",
    "humanistiske": "humanistisk",
    "humanistiskes": "humanistisk",
    "humanistisks": "humanistisk",
    "humanistiskt": "humanistisk",
    "humanistiskts": "humanistisk",
    "humanists": "humanist",
    "humaniteten": "humanitet",
    "humanitetens": "humanitet",
    "humaniteter": "humanitet",
    "humaniteterna": "humanitet",
    "humaniteternas": "humanitet",
    "humaniteters": "humanitet",
    "humanitets": "humanitet",
    "humanitära": "humanitär",
    "humanitärare": "humanitär",
    "humanitärares": "humanitär",
    "humanitäras": "humanitär",
    "humanitärast": "humanitär",
    "humanitäraste": "humanitär",
    "humanitärastes": "humanitär",
    "humanitärasts": "humanitär",
    "humanitäre": "humanitär",
    "humanitäres": "humanitär",
    "humanitärs": "humanitär",
    "humanitärt": "humanitär",
    "humanitärts": "humanitär",
    "humans": "human",
    "humant": "human",
    "humants": "human",
    "humanvetenskapen": "humanvetenskap",
    "humanvetenskapens": "humanvetenskap",
    "humanvetenskaper": "humanvetenskap",
    "humanvetenskaperna": "humanvetenskap",
    "humanvetenskapernas": "humanvetenskap",
    "humanvetenskapers": "humanvetenskap",
    "humanvetenskaps": "humanvetenskap",
    "humbugar": "humbug",
    "humbugarna": "humbug",
    "humbugarnas": "humbug",
    "humbugars": "humbug",
    "humbugen": "humbug",
    "humbugens": "humbug",
    "humbugs": "humbug",
    "humida": "humid",
    "humidare": "humid",
    "humidares": "humid",
    "humidas": "humid",
    "humidast": "humid",
    "humidaste": "humid",
    "humidastes": "humid",
    "humidasts": "humid",
    "humide": "humid",
    "humides": "humid",
    "humids": "humid",
    "humifieringar": "humifiering",
    "humifieringarna": "humifiering",
    "humifieringarnas": "humifiering",
    "humifieringars": "humifiering",
    "humifieringen": "humifiering",
    "humifieringens": "humifiering",
    "humifierings": "humifiering",
    "humlan": "humla",
    "humlans": "humla",
    "humlas": "humla",
    "humle": "humla",
    "humleblom": "humleblomma",
    "humleblomman": "humleblomma",
    "humleblommans": "humleblomma",
    "humleblommas": "humleblomma",
    "humleblomme": "humleblomma",
    "humleblommor": "humleblomma",
    "humleblommorna": "humleblomma",
    "humleblommornas": "humleblomma",
    "humleblommors": "humleblomma",
    "humlebloms": "humleblomma",
    "humleblomsterna": "humleblomster",
    "humleblomsternas": "humleblomster",
    "humleblomsters": "humleblomster",
    "humleblomstren": "humleblomster",
    "humleblomstrens": "humleblomster",
    "humleblomstret": "humleblomster",
    "humleblomstrets": "humleblomster",
    "humlen": "humle",
    "humlens": "humle",
    "humles": "humle",
    "humlesurren": "humlesurr",
    "humlesurrens": "humlesurr",
    "humlesurret": "humlesurr",
    "humlesurrets": "humlesurr",
    "humlesurrs": "humlesurr",
    "humlet": "humle",
    "humlets": "humle",
    "humlor": "humla",
    "humlorna": "humla",
    "humlornas": "humla",
    "humlors": "humla",
    "hummade": "humma",
    "hummades": "humma",
    "hummande": "humma",
    "hummanden": "hummande",
    "hummandena": "hummande",
    "hummandenas": "hummande",
    "hummandens": "hummande",
    "hummandes": "hummande",
    "hummandet": "hummande",
    "hummandets": "hummande",
    "hummar": "humma",
    "hummas": "humma",
    "hummat": "humma",
    "hummats": "humma",
    "hummern": "hummer",
    "hummerns": "hummer",
    "hummers": "hummer",
    "hummertin": "hummertina",
    "hummertinan": "hummertina",
    "hummertinans": "hummertina",
    "hummertinas": "hummertina",
    "hummertine": "hummertina",
    "hummertinor": "hummertina",
    "hummertinorna": "hummertina",
    "hummertinornas": "hummertina",
    "hummertinors": "hummertina",
    "hummertins": "hummertina",
    "hummusen": "hummus",
    "hummusens": "hummus",
    "humorduon": "humorduo",
    "humorduons": "humorduo",
    "humorduor": "humorduo",
    "humorduorna": "humorduo",
    "humorduornas": "humorduo",
    "humorduors": "humorduo",
    "humorduos": "humorduo",
    "humorduosen": "humorduo",
    "humorduosens": "humorduo",
    "humoresken": "humoresk",
    "humoreskens": "humoresk",
    "humoresker": "humoresk",
    "humoreskerna": "humoresk",
    "humoreskernas": "humoresk",
    "humoreskers": "humoresk",
    "humoresks": "humoresk",
    "humoristen": "humorist",
    "humoristens": "humorist",
    "humorister": "humorist",
    "humoristerna": "humorist",
    "humoristernas": "humorist",
    "humoristers": "humorist",
    "humoristiska": "humoristisk",
    "humoristiskare": "humoristisk",
    "humoristiskares": "humoristisk",
    "humoristiskas": "humoristisk",
    "humoristiskast": "humoristisk",
    "humoristiskaste": "humoristisk",
    "humoristiskastes": "humoristisk",
    "humoristiskasts": "humoristisk",
    "humoristiske": "humoristisk",
    "humoristiskes": "humoristisk",
    "humoristisks": "humoristisk",
    "humoristiskt": "humoristisk",
    "humoristiskts": "humoristisk",
    "humorists": "humorist",
    "humorn": "humor",
    "humorns": "humor",
    "humors": "humor",
    "humrar": "hummer",
    "humrarna": "hummer",
    "humrarnas": "hummer",
    "humrars": "hummer",
    "humusbundenheten": "humusbundenhet",
    "humusbundenhetens": "humusbundenhet",
    "humusbundenhets": "humusbundenhet",
    "humusbundens": "humusbunden",
    "humusbundet": "humusbunden",
    "humusbundets": "humusbunden",
    "humusbundna": "humusbunden",
    "humusbundnare": "humusbunden",
    "humusbundnares": "humusbunden",
    "humusbundnas": "humusbunden",
    "humusbundnast": "humusbunden",
    "humusbundnaste": "humusbunden",
    "humusbundnastes": "humusbunden",
    "humusbundnasts": "humusbunden",
    "humusbundne": "humusbunden",
    "humusbundnes": "humusbunden",
    "humusen": "humus",
    "humusens": "humus",
    "humusföreningar": "humusförening",
    "humusföreningarna": "humusförening",
    "humusföreningarnas": "humusförening",
    "humusföreningars": "humusförening",
    "humusföreningen": "humusförening",
    "humusföreningens": "humusförening",
    "humusförenings": "humusförening",
    "humushalten": "humushalt",
    "humushaltens": "humushalt",
    "humushalter": "humushalt",
    "humushalterna": "humushalt",
    "humushalternas": "humushalt",
    "humushalters": "humushalt",
    "humushaltiga": "humushaltig",
    "humushaltigare": "humushaltig",
    "humushaltigares": "humushaltig",
    "humushaltigas": "humushaltig",
    "humushaltigast": "humushaltig",
    "humushaltigaste": "humushaltig",
    "humushaltigastes": "humushaltig",
    "humushaltigasts": "humushaltig",
    "humushaltige": "humushaltig",
    "humushaltiges": "humushaltig",
    "humushaltigs": "humushaltig",
    "humushaltigt": "humushaltig",
    "humushaltigts": "humushaltig",
    "humushalts": "humushalt",
    "humuskomponenten": "humuskomponent",
    "humuskomponentens": "humuskomponent",
    "humuskomponenter": "humuskomponent",
    "humuskomponenterna": "humuskomponent",
    "humuskomponenternas": "humuskomponent",
    "humuskomponenters": "humuskomponent",
    "humuskomponents": "humuskomponent",
    "humuskoncentrationen": "humuskoncentration",
    "humuskoncentrationens": "humuskoncentration",
    "humuskoncentrationer": "humuskoncentration",
    "humuskoncentrationerna": "humuskoncentration",
    "humuskoncentrationernas": "humuskoncentration",
    "humuskoncentrationers": "humuskoncentration",
    "humuskoncentrations": "humuskoncentration",
    "humussubstansen": "humussubstans",
    "humussubstansens": "humussubstans",
    "humussubstanser": "humussubstans",
    "humussubstanserna": "humussubstans",
    "humussubstansernas": "humussubstans",
    "humussubstansers": "humussubstans",
    "humussyran": "humussyra",
    "humussyrans": "humussyra",
    "humussyras": "humussyra",
    "humussyre": "humussyra",
    "humussyror": "humussyra",
    "humussyrorna": "humussyra",
    "humussyrornas": "humussyra",
    "humussyrors": "humussyra",
    "humusvattens": "humusvatten",
    "humusvattnen": "humusvatten",
    "humusvattnens": "humusvatten",
    "humusvattnet": "humusvatten",
    "humusvattnets": "humusvatten",
    "humusämnen": "humusämne",
    "humusämnena": "humusämne",
    "humusämnenas": "humusämne",
    "humusämnens": "humusämne",
    "humusämnes": "humusämne",
    "humusämnet": "humusämne",
    "humusämnets": "humusämne",
    "humören": "humör",
    "humörens": "humör",
    "humöret": "humör",
    "humörets": "humör",
    "humörmänniskan": "humörmänniska",
    "humörmänniskans": "humörmänniska",
    "humörmänniskas": "humörmänniska",
    "humörmännisko": "humörmänniska",
    "humörmänniskor": "humörmänniska",
    "humörmänniskorna": "humörmänniska",
    "humörmänniskornas": "humörmänniska",
    "humörmänniskors": "humörmänniska",
    "humörmässiga": "humörmässig",
    "humörmässigare": "humörmässig",
    "humörmässigares": "humörmässig",
    "humörmässigas": "humörmässig",
    "humörmässigast": "humörmässig",
    "humörmässigaste": "humörmässig",
    "humörmässigastes": "humörmässig",
    "humörmässigasts": "humörmässig",
    "humörmässige": "humörmässig",
    "humörmässiges": "humörmässig",
    "humörmässigs": "humörmässig",
    "humörmässigt": "humörmässig",
    "humörmässigts": "humörmässig",
    "humörs": "humör",
    "humörspelar": "humörspelare",
    "humörspelaren": "humörspelare",
    "humörspelarens": "humörspelare",
    "humörspelares": "humörspelare",
    "humörspelarna": "humörspelare",
    "humörspelarnas": "humörspelare",
    "hundallergien": "hundallergi",
    "hundallergiens": "hundallergi",
    "hundallergier": "hundallergi",
    "hundallergierna": "hundallergi",
    "hundallergiernas": "hundallergi",
    "hundallergiers": "hundallergi",
    "hundallergin": "hundallergi",
    "hundallergins": "hundallergi",
    "hundallergis": "hundallergi",
    "hundans": "hundan",
    "hundap": "hundapa",
    "hundapan": "hundapa",
    "hundapans": "hundapa",
    "hundapas": "hundapa",
    "hundape": "hundapa",
    "hundapor": "hundapa",
    "hundaporna": "hundapa",
    "hundapornas": "hundapa",
    "hundapors": "hundapa",
    "hundaps": "hundapa",
    "hundar": "hund",
    "hundaren": "hundare",
    "hundarena": "hundare",
    "hundarenas": "hundare",
    "hundarens": "hundare",
    "hundares": "hundare",
    "hundaret": "hundare",
    "hundarets": "hundare",
    "hundarna": "hund",
    "hundarnas": "hund",
    "hundars": "hundare",
    "hundbenen": "hundben",
    "hundbenens": "hundben",
    "hundbenet": "hundben",
    "hundbenets": "hundben",
    "hundbens": "hundben",
    "hundblickar": "hundblick",
    "hundblickarna": "hundblick",
    "hundblickarnas": "hundblick",
    "hundblickars": "hundblick",
    "hundblicken": "hundblick",
    "hundblickens": "hundblick",
    "hundblicks": "hundblick",
    "hunddjuren": "hunddjur",
    "hunddjurens": "hunddjur",
    "hunddjuret": "hunddjur",
    "hunddjurets": "hunddjur",
    "hunddjurs": "hunddjur",
    "hunden": "hund",
    "hundens": "hund",
    "hundförar": "hundförare",
    "hundföraren": "hundförare",
    "hundförarens": "hundförare",
    "hundförares": "hundförare",
    "hundförarna": "hundförare",
    "hundförarnas": "hundförare",
    "hundgöras": "hundgöra",
    "hundgörat": "hundgöra",
    "hundgörats": "hundgöra",
    "hundhalsbanden": "hundhalsband",
    "hundhalsbandens": "hundhalsband",
    "hundhalsbandet": "hundhalsband",
    "hundhalsbandets": "hundhalsband",
    "hundhalsbands": "hundhalsband",
    "hundhuvuden": "hundhuvud",
    "hundhuvudena": "hundhuvud",
    "hundhuvudenas": "hundhuvud",
    "hundhuvudens": "hundhuvud",
    "hundhuvudet": "hundhuvud",
    "hundhuvudets": "hundhuvud",
    "hundhuvuds": "hundhuvud",
    "hundhåren": "hundhår",
    "hundhårens": "hundhår",
    "hundhåret": "hundhår",
    "hundhårets": "hundhår",
    "hundhårs": "hundhår",
    "hundhövdade": "hundhövdad",
    "hundhövdades": "hundhövdad",
    "hundhövdads": "hundhövdad",
    "hundhövdat": "hundhövdad",
    "hundhövdats": "hundhövdad",
    "hundkapplöpningar": "hundkapplöpning",
    "hundkapplöpningarna": "hundkapplöpning",
    "hundkapplöpningarnas": "hundkapplöpning",
    "hundkapplöpningars": "hundkapplöpning",
    "hundkapplöpningen": "hundkapplöpning",
    "hundkapplöpningens": "hundkapplöpning",
    "hundkapplöpnings": "hundkapplöpning",
    "hundkexen": "hundkex",
    "hundkexens": "hundkex",
    "hundkexet": "hundkex",
    "hundkexets": "hundkex",
    "hundkoj": "hundkoja",
    "hundkojan": "hundkoja",
    "hundkojans": "hundkoja",
    "hundkojas": "hundkoja",
    "hundkoje": "hundkoja",
    "hundkojor": "hundkoja",
    "hundkojorna": "hundkoja",
    "hundkojornas": "hundkoja",
    "hundkojors": "hundkoja",
    "hundkojs": "hundkoja",
    "hundkäxen": "hundkäx",
    "hundkäxens": "hundkäx",
    "hundkäxet": "hundkäx",
    "hundkäxets": "hundkäx",
    "hundlivet": "hundliv",
    "hundlivets": "hundliv",
    "hundlivs": "hundliv",
    "hundlok": "hundloka",
    "hundlokan": "hundloka",
    "hundlokans": "hundloka",
    "hundlokas": "hundloka",
    "hundloke": "hundloka",
    "hundlokor": "hundloka",
    "hundlokorna": "hundloka",
    "hundlokornas": "hundloka",
    "hundlokors": "hundloka",
    "hundloks": "hundloka",
    "hundlortar": "hundlort",
    "hundlortarna": "hundlort",
    "hundlortarnas": "hundlort",
    "hundlortars": "hundlort",
    "hundlorten": "hundlort",
    "hundlortens": "hundlort",
    "hundlorts": "hundlort",
    "hundmaten": "hundmat",
    "hundmatens": "hundmat",
    "hundmats": "hundmat",
    "hundpatrullen": "hundpatrull",
    "hundpatrullens": "hundpatrull",
    "hundpatruller": "hundpatrull",
    "hundpatrullerna": "hundpatrull",
    "hundpatrullernas": "hundpatrull",
    "hundpatrullers": "hundpatrull",
    "hundpatrulls": "hundpatrull",
    "hundrack": "hundracka",
    "hundrackan": "hundracka",
    "hundrackans": "hundracka",
    "hundrackas": "hundracka",
    "hundracke": "hundracka",
    "hundrackor": "hundracka",
    "hundrackorna": "hundracka",
    "hundrackornas": "hundracka",
    "hundrackors": "hundracka",
    "hundracks": "hundracka",
    "hundrade": "hundra",
    "hundradedelar": "hundradedel",
    "hundradedelarna": "hundradedel",
    "hundradedelarnas": "hundradedel",
    "hundradedelars": "hundradedel",
    "hundradedelen": "hundradedel",
    "hundradedelens": "hundradedel",
    "hundradedels": "hundradedel",
    "hundradelar": "hundradel",
    "hundradelarna": "hundradel",
    "hundradelarnas": "hundradel",
    "hundradelars": "hundradel",
    "hundradelen": "hundradel",
    "hundradelens": "hundradel",
    "hundradels": "hundradel",
    "hundraden": "hundrade",
    "hundradena": "hundrade",
    "hundradenas": "hundrade",
    "hundradens": "hundrade",
    "hundrades": "hundrade",
    "hundradet": "hundrade",
    "hundradets": "hundrade",
    "hundrakronorssedeln": "hundrakronorssedel",
    "hundrakronorssedelns": "hundrakronorssedel",
    "hundrakronorssedels": "hundrakronorssedel",
    "hundrakronorssedlar": "hundrakronorssedel",
    "hundrakronorssedlarna": "hundrakronorssedel",
    "hundrakronorssedlarnas": "hundrakronorssedel",
    "hundrakronorssedlars": "hundrakronorssedel",
    "hundralappar": "hundralapp",
    "hundralapparna": "hundralapp",
    "hundralapparnas": "hundralapp",
    "hundralappars": "hundralapp",
    "hundralappen": "hundralapp",
    "hundralappens": "hundralapp",
    "hundralapps": "hundralapp",
    "hundraprocentiga": "hundraprocentig",
    "hundraprocentigare": "hundraprocentig",
    "hundraprocentigares": "hundraprocentig",
    "hundraprocentigas": "hundraprocentig",
    "hundraprocentigast": "hundraprocentig",
    "hundraprocentigaste": "hundraprocentig",
    "hundraprocentigastes": "hundraprocentig",
    "hundraprocentigasts": "hundraprocentig",
    "hundraprocentige": "hundraprocentig",
    "hundraprocentiges": "hundraprocentig",
    "hundraprocentigs": "hundraprocentig",
    "hundraprocentigt": "hundraprocentig",
    "hundraprocentigts": "hundraprocentig",
    "hundras": "hundra",
    "hundrasen": "hundras",
    "hundrasens": "hundras",
    "hundraser": "hundras",
    "hundraserna": "hundras",
    "hundrasernas": "hundras",
    "hundrasers": "hundras",
    "hundratalen": "hundratal",
    "hundratalens": "hundratal",
    "hundratalet": "hundratal",
    "hundratalets": "hundratal",
    "hundratals": "hundratal",
    "hundratusentalen": "hundratusental",
    "hundratusentalens": "hundratusental",
    "hundratusentalet": "hundratusental",
    "hundratusentalets": "hundratusental",
    "hundratusentals": "hundratusental",
    "hundratusentonnar": "hundratusentonnare",
    "hundratusentonnaren": "hundratusentonnare",
    "hundratusentonnarens": "hundratusentonnare",
    "hundratusentonnares": "hundratusentonnare",
    "hundratusentonnarna": "hundratusentonnare",
    "hundratusentonnarnas": "hundratusentonnare",
    "hundraåriga": "hundraårig",
    "hundraårigas": "hundraårig",
    "hundraårige": "hundraårig",
    "hundraåriges": "hundraårig",
    "hundraårigs": "hundraårig",
    "hundraårigt": "hundraårig",
    "hundraårigts": "hundraårig",
    "hundraåringar": "hundraåring",
    "hundraåringarna": "hundraåring",
    "hundraåringarnas": "hundraåring",
    "hundraåringars": "hundraåring",
    "hundraåringen": "hundraåring",
    "hundraåringens": "hundraåring",
    "hundraårings": "hundraåring",
    "hundringar": "hundring",
    "hundringarna": "hundring",
    "hundringarnas": "hundring",
    "hundringars": "hundring",
    "hundringen": "hundring",
    "hundringens": "hundring",
    "hundrings": "hundring",
    "hundrov": "hundrova",
    "hundrovan": "hundrova",
    "hundrovans": "hundrova",
    "hundrovas": "hundrova",
    "hundrove": "hundrova",
    "hundrovor": "hundrova",
    "hundrovorna": "hundrova",
    "hundrovornas": "hundrova",
    "hundrovors": "hundrova",
    "hundrovs": "hundrova",
    "hundrädda": "hundrädd",
    "hundräddare": "hundrädd",
    "hundräddares": "hundrädd",
    "hundräddas": "hundrädd",
    "hundräddast": "hundrädd",
    "hundräddaste": "hundrädd",
    "hundräddastes": "hundrädd",
    "hundräddasts": "hundrädd",
    "hundrädde": "hundrädd",
    "hundräddes": "hundrädd",
    "hundrädds": "hundrädd",
    "hunds": "hund",
    "hundsad": "hundsa",
    "hundsade": "hundsa",
    "hundsades": "hundsa",
    "hundsads": "hundsa",
    "hundsande": "hundsa",
    "hundsanden": "hundsande",
    "hundsandena": "hundsande",
    "hundsandenas": "hundsande",
    "hundsandens": "hundsande",
    "hundsandes": "hundsande",
    "hundsandet": "hundsande",
    "hundsandets": "hundsande",
    "hundsar": "hundsa",
    "hundsas": "hundsa",
    "hundsat": "hundsa",
    "hundsats": "hundsa",
    "hundsfotterad": "hundsfottera",
    "hundsfotterade": "hundsfottera",
    "hundsfotterades": "hundsfottera",
    "hundsfotterads": "hundsfottera",
    "hundsfotterande": "hundsfottera",
    "hundsfotteranden": "hundsfotterande",
    "hundsfotterandena": "hundsfotterande",
    "hundsfotterandenas": "hundsfotterande",
    "hundsfotterandens": "hundsfotterande",
    "hundsfotterandes": "hundsfotterande",
    "hundsfotterandet": "hundsfotterande",
    "hundsfotterandets": "hundsfotterande",
    "hundsfotterar": "hundsfottera",
    "hundsfotteras": "hundsfottera",
    "hundsfotterat": "hundsfottera",
    "hundsfotterats": "hundsfottera",
    "hundsfotterbara": "hundsfotterbar",
    "hundsfotterbarare": "hundsfotterbar",
    "hundsfotterbarares": "hundsfotterbar",
    "hundsfotterbaras": "hundsfotterbar",
    "hundsfotterbarast": "hundsfotterbar",
    "hundsfotterbaraste": "hundsfotterbar",
    "hundsfotterbarastes": "hundsfotterbar",
    "hundsfotterbarasts": "hundsfotterbar",
    "hundsfotterbare": "hundsfotterbar",
    "hundsfotterbares": "hundsfotterbar",
    "hundsfotterbarheten": "hundsfotterbarhet",
    "hundsfotterbarhetens": "hundsfotterbarhet",
    "hundsfotterbarhets": "hundsfotterbarhet",
    "hundsfotterbars": "hundsfotterbar",
    "hundsfotterbart": "hundsfotterbar",
    "hundsfotterbarts": "hundsfotterbar",
    "hundsfotteringar": "hundsfottering",
    "hundsfotteringarna": "hundsfottering",
    "hundsfotteringarnas": "hundsfottering",
    "hundsfotteringars": "hundsfottering",
    "hundsfotteringen": "hundsfottering",
    "hundsfotteringens": "hundsfottering",
    "hundsfotterings": "hundsfottering",
    "hundsimmet": "hundsim",
    "hundsimmets": "hundsim",
    "hundsims": "hundsim",
    "hundskatten": "hundskatt",
    "hundskattens": "hundskatt",
    "hundskatter": "hundskatt",
    "hundskatterna": "hundskatt",
    "hundskatternas": "hundskatt",
    "hundskatters": "hundskatt",
    "hundskatts": "hundskatt",
    "hundskitar": "hundskit",
    "hundskitarna": "hundskit",
    "hundskitarnas": "hundskit",
    "hundskitars": "hundskit",
    "hundskiten": "hundskit",
    "hundskitens": "hundskit",
    "hundskits": "hundskit",
    "hundskulpturen": "hundskulptur",
    "hundskulpturens": "hundskulptur",
    "hundskulpturer": "hundskulptur",
    "hundskulpturerna": "hundskulptur",
    "hundskulpturernas": "hundskulptur",
    "hundskulpturers": "hundskulptur",
    "hundskulpturs": "hundskulptur",
    "hundsläd": "hundsläde",
    "hundslädar": "hundsläde",
    "hundslädarna": "hundsläde",
    "hundslädarnas": "hundsläde",
    "hundslädars": "hundsläde",
    "hundsläden": "hundsläde",
    "hundslädens": "hundsläde",
    "hundslädes": "hundsläde",
    "hundsläds": "hundsläde",
    "hundvakten": "hundvakt",
    "hundvaktens": "hundvakt",
    "hundvakter": "hundvakt",
    "hundvakterna": "hundvakt",
    "hundvakternas": "hundvakt",
    "hundvakters": "hundvakt",
    "hundvakts": "hundvakt",
    "hundvalpar": "hundvalp",
    "hundvalparna": "hundvalp",
    "hundvalparnas": "hundvalp",
    "hundvalpars": "hundvalp",
    "hundvalpen": "hundvalp",
    "hundvalpens": "hundvalp",
    "hundvalps": "hundvalp",
    "hundväderna": "hundväder",
    "hundvädernas": "hundväder",
    "hundväders": "hundväder",
    "hundvädren": "hundväder",
    "hundvädrens": "hundväder",
    "hundvädret": "hundväder",
    "hundvädrets": "hundväder",
    "hundägar": "hundägare",
    "hundägaren": "hundägare",
    "hundägarens": "hundägare",
    "hundägares": "hundägare",
    "hundägarna": "hundägare",
    "hundägarnas": "hundägare",
    "hundäxingar": "hundäxing",
    "hundäxingarna": "hundäxing",
    "hundäxingarnas": "hundäxing",
    "hundäxingars": "hundäxing",
    "hundäxingen": "hundäxing",
    "hundäxingens": "hundäxing",
    "hundäxings": "hundäxing",
    "hundåren": "hundår",
    "hundårens": "hundår",
    "hundåret": "hundår",
    "hundårets": "hundår",
    "hundårs": "hundår",
    "hundöras": "hundöra",
    "hundörat": "hundöra",
    "hundörats": "hundöra",
    "hundöron": "hundöra",
    "hundöronen": "hundöra",
    "hundöronens": "hundöra",
    "hundörons": "hundöra",
    "hungern": "hunger",
    "hungerns": "hunger",
    "hungers": "hunger",
    "hungersnöden": "hungersnöd",
    "hungersnödens": "hungersnöd",
    "hungersnöds": "hungersnöd",
    "hungerstrejkade": "hungerstrejka",
    "hungerstrejkades": "hungerstrejka",
    "hungerstrejkande": "hungerstrejka",
    "hungerstrejkanden": "hungerstrejkande",
    "hungerstrejkandena": "hungerstrejkande",
    "hungerstrejkandenas": "hungerstrejkande",
    "hungerstrejkandens": "hungerstrejkande",
    "hungerstrejkandes": "hungerstrejkande",
    "hungerstrejkandet": "hungerstrejkande",
    "hungerstrejkandets": "hungerstrejkande",
    "hungerstrejkar": "hungerstrejka",
    "hungerstrejkas": "hungerstrejka",
    "hungerstrejkat": "hungerstrejka",
    "hungerstrejkats": "hungerstrejka",
    "hungerstrejken": "hungerstrejk",
    "hungerstrejkens": "hungerstrejk",
    "hungerstrejker": "hungerstrejk",
    "hungerstrejkerna": "hungerstrejk",
    "hungerstrejkernas": "hungerstrejk",
    "hungerstrejkers": "hungerstrejk",
    "hungerstrejks": "hungerstrejk",
    "hungrade": "hungra",
    "hungrades": "hungra",
    "hungrande": "hungra",
    "hungranden": "hungrande",
    "hungrandena": "hungrande",
    "hungrandenas": "hungrande",
    "hungrandens": "hungrande",
    "hungrandes": "hungrande",
    "hungrandet": "hungrande",
    "hungrandets": "hungrande",
    "hungrar": "hungra",
    "hungras": "hungra",
    "hungrat": "hungra",
    "hungrats": "hungra",
    "hungriga": "hungrig",
    "hungrigare": "hungrig",
    "hungrigares": "hungrig",
    "hungrigas": "hungrig",
    "hungrigast": "hungrig",
    "hungrigaste": "hungrig",
    "hungrigastes": "hungrig",
    "hungrigasts": "hungrig",
    "hungrige": "hungrig",
    "hungriges": "hungrig",
    "hungrigheten": "hungrighet",
    "hungrighetens": "hungrighet",
    "hungrighets": "hungrighet",
    "hungrigs": "hungrig",
    "hungrigt": "hungrig",
    "hungrigts": "hungrig",
    "hunkar": "hunk",
    "hunkarna": "hunk",
    "hunkarnas": "hunk",
    "hunkars": "hunk",
    "hunken": "hunk",
    "hunkens": "hunk",
    "hunks": "hunk",
    "hunna": "hinna",
    "hunnas": "hinna",
    "hunne": "hinna",
    "hunnen": "hunn",
    "hunnens": "hunn",
    "hunner": "hunn",
    "hunnern": "hunner",
    "hunnerna": "hunner",
    "hunnernas": "hunner",
    "hunnerns": "hunner",
    "hunners": "hunner",
    "hunnes": "hinna",
    "hunnet": "hinna",
    "hunnets": "hinna",
    "hunnit": "hinna",
    "hunnits": "hinna",
    "hunsad": "hunsa",
    "hunsade": "hunsa",
    "hunsades": "hunsa",
    "hunsads": "hunsa",
    "hunsande": "hunsa",
    "hunsanden": "hunsande",
    "hunsandena": "hunsande",
    "hunsandenas": "hunsande",
    "hunsandens": "hunsande",
    "hunsandes": "hunsande",
    "hunsandet": "hunsande",
    "hunsandets": "hunsande",
    "hunsar": "hunsa",
    "hunsas": "hunsa",
    "hunsat": "hunsa",
    "hunsats": "hunsa",
    "hurdadan": "hurdan",
    "hurdadana": "hurdan",
    "hurdadanas": "hurdan",
    "hurdadans": "hurdan",
    "hurdadant": "hurdan",
    "hurdadants": "hurdan",
    "hurdana": "hurdan",
    "hurdanas": "hurdan",
    "hurdans": "hurdan",
    "hurdant": "hurdan",
    "hurdants": "hurdan",
    "hurrade": "hurra",
    "hurrades": "hurra",
    "hurran": "hurra",
    "hurrana": "hurra",
    "hurranas": "hurra",
    "hurrande": "hurra",
    "hurranden": "hurrande",
    "hurrandena": "hurrande",
    "hurrandenas": "hurrande",
    "hurrandens": "hurrande",
    "hurrandes": "hurrande",
    "hurrandet": "hurrande",
    "hurrandets": "hurrande",
    "hurrans": "hurra",
    "hurrar": "hurra",
    "hurraropen": "hurrarop",
    "hurraropens": "hurrarop",
    "hurraropet": "hurrarop",
    "hurraropets": "hurrarop",
    "hurrarops": "hurrarop",
    "hurras": "hurra",
    "hurrat": "hurra",
    "hurrats": "hurra",
    "hurrilar": "hurril",
    "hurrilarna": "hurril",
    "hurrilarnas": "hurril",
    "hurrilars": "hurril",
    "hurrilen": "hurril",
    "hurrilens": "hurril",
    "hurriln": "hurril",
    "hurrilns": "hurril",
    "hurrils": "hurril",
    "hursarregementen": "hursarregemente",
    "hursarregementena": "hursarregemente",
    "hursarregementenas": "hursarregemente",
    "hursarregementens": "hursarregemente",
    "hursarregementes": "hursarregemente",
    "hursarregementet": "hursarregemente",
    "hursarregementets": "hursarregemente",
    "hurtbull": "hurtbulle",
    "hurtbullar": "hurtbulle",
    "hurtbullarna": "hurtbulle",
    "hurtbullarnas": "hurtbulle",
    "hurtbullars": "hurtbulle",
    "hurtbullen": "hurtbulle",
    "hurtbullens": "hurtbulle",
    "hurtbulles": "hurtbulle",
    "hurtbulls": "hurtbulle",
    "hurtfriska": "hurtfrisk",
    "hurtfriskare": "hurtfrisk",
    "hurtfriskares": "hurtfrisk",
    "hurtfriskas": "hurtfrisk",
    "hurtfriskast": "hurtfrisk",
    "hurtfriskaste": "hurtfrisk",
    "hurtfriskastes": "hurtfrisk",
    "hurtfriskasts": "hurtfrisk",
    "hurtfriske": "hurtfrisk",
    "hurtfriskes": "hurtfrisk",
    "hurtfrisks": "hurtfrisk",
    "hurtfriskt": "hurtfrisk",
    "hurtfriskts": "hurtfrisk",
    "hurtiga": "hurtig",
    "hurtigare": "hurtig",
    "hurtigares": "hurtig",
    "hurtigas": "hurtig",
    "hurtigast": "hurtig",
    "hurtigaste": "hurtig",
    "hurtigastes": "hurtig",
    "hurtigasts": "hurtig",
    "hurtige": "hurtig",
    "hurtiges": "hurtig",
    "hurtigheten": "hurtighet",
    "hurtighetens": "hurtighet",
    "hurtighets": "hurtighet",
    "hurtigs": "hurtig",
    "hurtigt": "hurtig",
    "hurtigts": "hurtig",
    "hurtsar": "hurts",
    "hurtsarna": "hurts",
    "hurtsarnas": "hurts",
    "hurtsars": "hurts",
    "hurtsen": "hurts",
    "hurtsens": "hurts",
    "hurudadan": "hurudan",
    "hurudadana": "hurudan",
    "hurudadanas": "hurudan",
    "hurudadans": "hurudan",
    "hurudadant": "hurudan",
    "hurudadants": "hurudan",
    "hurudana": "hurudan",
    "hurudanas": "hurudan",
    "hurudans": "hurudan",
    "hurudant": "hurudan",
    "hurudants": "hurudan",
    "husan": "husa",
    "husandakten": "husandakt",
    "husandaktens": "husandakt",
    "husandakter": "husandakt",
    "husandakterna": "husandakt",
    "husandakternas": "husandakt",
    "husandakters": "husandakt",
    "husandakts": "husandakt",
    "husans": "husa",
    "husapoteken": "husapotek",
    "husapotekens": "husapotek",
    "husapoteket": "husapotek",
    "husapotekets": "husapotek",
    "husapoteks": "husapotek",
    "husaren": "husar",
    "husarens": "husar",
    "husarer": "husar",
    "husarerna": "husar",
    "husarernas": "husar",
    "husarers": "husar",
    "husarresten": "husarrest",
    "husarrestens": "husarrest",
    "husarrests": "husarrest",
    "husars": "husar",
    "husas": "husa",
    "husbehoven": "husbehov",
    "husbehovens": "husbehov",
    "husbehovet": "husbehov",
    "husbehovets": "husbehov",
    "husbehovs": "husbehov",
    "husbilar": "husbil",
    "husbilarna": "husbil",
    "husbilarnas": "husbil",
    "husbilars": "husbil",
    "husbilen": "husbil",
    "husbilens": "husbil",
    "husbils": "husbil",
    "husbockar": "husbock",
    "husbockarna": "husbock",
    "husbockarnas": "husbock",
    "husbockars": "husbock",
    "husbocken": "husbock",
    "husbockens": "husbock",
    "husbocks": "husbock",
    "husbond": "husbonde",
    "husbonden": "husbonde",
    "husbondens": "husbonde",
    "husbondes": "husbonde",
    "husbonds": "husbonde",
    "husbyggen": "husbygge",
    "husbyggena": "husbygge",
    "husbyggenas": "husbygge",
    "husbyggens": "husbygge",
    "husbygges": "husbygge",
    "husbygget": "husbygge",
    "husbyggets": "husbygge",
    "husbåtar": "husbåt",
    "husbåtarna": "husbåt",
    "husbåtarnas": "husbåt",
    "husbåtars": "husbåt",
    "husbåten": "husbåt",
    "husbåtens": "husbåt",
    "husbåts": "husbåt",
    "husbönder": "husbonde",
    "husbönderna": "husbonde",
    "husböndernas": "husbonde",
    "husbönders": "husbonde",
    "husdjuren": "husdjur",
    "husdjurens": "husdjur",
    "husdjuret": "husdjur",
    "husdjurets": "husdjur",
    "husdjurs": "husdjur",
    "husdjursartikeln": "husdjursartikel",
    "husdjursartikelns": "husdjursartikel",
    "husdjursartikels": "husdjursartikel",
    "husdjursartiklar": "husdjursartikel",
    "husdjursartiklarna": "husdjursartikel",
    "husdjursartiklarnas": "husdjursartikel",
    "husdjursartiklars": "husdjursartikel",
    "husdjursaveln": "husdjursavel",
    "husdjursavelns": "husdjursavel",
    "husdjursavels": "husdjursavel",
    "husdjursskötseln": "husdjursskötsel",
    "husdjursskötselns": "husdjursskötsel",
    "husdjursskötsels": "husdjursskötsel",
    "husen": "hus",
    "husens": "hus",
    "huserad": "husera",
    "huserade": "husera",
    "huserades": "husera",
    "huserads": "husera",
    "huserande": "husera",
    "huseranden": "huserande",
    "huserandena": "huserande",
    "huserandenas": "huserande",
    "huserandens": "huserande",
    "huserandes": "huserande",
    "huserandet": "huserande",
    "huserandets": "huserande",
    "huserar": "husera",
    "huseras": "husera",
    "huserat": "husera",
    "huserats": "husera",
    "huserbara": "huserbar",
    "huserbarare": "huserbar",
    "huserbarares": "huserbar",
    "huserbaras": "huserbar",
    "huserbarast": "huserbar",
    "huserbaraste": "huserbar",
    "huserbarastes": "huserbar",
    "huserbarasts": "huserbar",
    "huserbare": "huserbar",
    "huserbares": "huserbar",
    "huserbarheten": "huserbarhet",
    "huserbarhetens": "huserbarhet",
    "huserbarhets": "huserbarhet",
    "huserbars": "huserbar",
    "huserbart": "huserbar",
    "huserbarts": "huserbar",
    "huseringar": "husering",
    "huseringarna": "husering",
    "huseringarnas": "husering",
    "huseringars": "husering",
    "huseringen": "husering",
    "huseringens": "husering",
    "huserings": "husering",
    "husesynen": "husesyn",
    "husesynens": "husesyn",
    "husesyner": "husesyn",
    "husesynerna": "husesyn",
    "husesynernas": "husesyn",
    "husesyners": "husesyn",
    "husesyns": "husesyn",
    "huset": "hus",
    "husets": "hus",
    "husfader": "husfar",
    "husfadern": "husfar",
    "husfaderns": "husfar",
    "husfaders": "husfar",
    "husfars": "husfar",
    "husfasaden": "husfasad",
    "husfasadens": "husfasad",
    "husfasader": "husfasad",
    "husfasaderna": "husfasad",
    "husfasadernas": "husfasad",
    "husfasaders": "husfasad",
    "husfasads": "husfasad",
    "husfasder": "husfar",
    "husflug": "husfluga",
    "husflugan": "husfluga",
    "husflugans": "husfluga",
    "husflugas": "husfluga",
    "husfluge": "husfluga",
    "husflugor": "husfluga",
    "husflugorna": "husfluga",
    "husflugornas": "husfluga",
    "husflugors": "husfluga",
    "husflugs": "husfluga",
    "husfriden": "husfrid",
    "husfridens": "husfrid",
    "husfrids": "husfrid",
    "husfridsknullen": "husfridsknull",
    "husfridsknullens": "husfridsknull",
    "husfridsknullet": "husfridsknull",
    "husfridsknullets": "husfridsknull",
    "husfridsknulls": "husfridsknull",
    "husfruar": "husfru",
    "husfruarna": "husfru",
    "husfruarnas": "husfru",
    "husfruars": "husfru",
    "husfrun": "husfru",
    "husfruns": "husfru",
    "husfrus": "husfru",
    "husfäder": "husfar",
    "husfäderna": "husfar",
    "husfädernas": "husfar",
    "husfäders": "husfar",
    "husföreståndarinnan": "husföreståndarinna",
    "husföreståndarinnans": "husföreståndarinna",
    "husföreståndarinnas": "husföreståndarinna",
    "husföreståndarinne": "husföreståndarinna",
    "husföreståndarinnor": "husföreståndarinna",
    "husföreståndarinnorna": "husföreståndarinna",
    "husföreståndarinnornas": "husföreståndarinna",
    "husföreståndarinnors": "husföreståndarinna",
    "husförhören": "husförhör",
    "husförhörens": "husförhör",
    "husförhöret": "husförhör",
    "husförhörets": "husförhör",
    "husförhörs": "husförhör",
    "husgaveln": "husgavel",
    "husgavelns": "husgavel",
    "husgavels": "husgavel",
    "husgavlar": "husgavel",
    "husgavlarna": "husgavel",
    "husgavlarnas": "husgavel",
    "husgavlars": "husgavel",
    "husgeråden": "husgeråd",
    "husgerådens": "husgeråd",
    "husgerådet": "husgeråd",
    "husgerådets": "husgeråd",
    "husgeråds": "husgeråd",
    "husgrunden": "husgrund",
    "husgrundens": "husgrund",
    "husgrunder": "husgrund",
    "husgrunderna": "husgrund",
    "husgrundernas": "husgrund",
    "husgrunders": "husgrund",
    "husgrunds": "husgrund",
    "husgudar": "husgud",
    "husgudarna": "husgud",
    "husgudarnas": "husgud",
    "husgudars": "husgud",
    "husguden": "husgud",
    "husgudens": "husgud",
    "husguds": "husgud",
    "hushållade": "hushålla",
    "hushållades": "hushålla",
    "hushållande": "hushålla",
    "hushållanden": "hushållande",
    "hushållandena": "hushållande",
    "hushållandenas": "hushållande",
    "hushållandens": "hushållande",
    "hushållandes": "hushållande",
    "hushållandet": "hushållande",
    "hushållandets": "hushållande",
    "hushållar": "hushålla",
    "hushållas": "hushålla",
    "hushållat": "hushålla",
    "hushållats": "hushålla",
    "hushållen": "hushåll",
    "hushållens": "hushåll",
    "hushållerskan": "hushållerska",
    "hushållerskans": "hushållerska",
    "hushållerskas": "hushållerska",
    "hushållerske": "hushållerska",
    "hushållerskor": "hushållerska",
    "hushållerskorna": "hushållerska",
    "hushållerskornas": "hushållerska",
    "hushållerskors": "hushållerska",
    "hushållet": "hushåll",
    "hushållets": "hushåll",
    "hushållningar": "hushållning",
    "hushållningarna": "hushållning",
    "hushållningarnas": "hushållning",
    "hushållningars": "hushållning",
    "hushållningen": "hushållning",
    "hushållningens": "hushållning",
    "hushållnings": "hushållning",
    "hushållningssällskapen": "hushållningssällskap",
    "hushållningssällskapens": "hushållningssällskap",
    "hushållningssällskapet": "hushållningssällskap",
    "hushållningssällskapets": "hushållningssällskap",
    "hushållningssällskaps": "hushållningssällskap",
    "hushålls": "hushåll",
    "hushållsarbeten": "hushållsarbete",
    "hushållsarbetena": "hushållsarbete",
    "hushållsarbetenas": "hushållsarbete",
    "hushållsarbetens": "hushållsarbete",
    "hushållsarbetes": "hushållsarbete",
    "hushållsarbetet": "hushållsarbete",
    "hushållsarbetets": "hushållsarbete",
    "hushållsarbets": "hushållsarbete",
    "hushållsassistenten": "hushållsassistent",
    "hushållsassistentens": "hushållsassistent",
    "hushållsassistenter": "hushållsassistent",
    "hushållsassistenterna": "hushållsassistent",
    "hushållsassistenternas": "hushållsassistent",
    "hushållsassistenters": "hushållsassistent",
    "hushållsassistents": "hushållsassistent",
    "hushållsgrisar": "hushållsgris",
    "hushållsgrisarna": "hushållsgris",
    "hushållsgrisarnas": "hushållsgris",
    "hushållsgrisars": "hushållsgris",
    "hushållsgrisen": "hushållsgris",
    "hushållsgrisens": "hushållsgris",
    "hushållsinventarie": "hushållsinventarier",
    "hushållsinventarierna": "hushållsinventarier",
    "hushållsinventariernas": "hushållsinventarier",
    "hushållsinventariers": "hushållsinventarier",
    "hushållsostar": "hushållsost",
    "hushållsostarna": "hushållsost",
    "hushållsostarnas": "hushållsost",
    "hushållsostars": "hushållsost",
    "hushållsosten": "hushållsost",
    "hushållsostens": "hushållsost",
    "hushållsosts": "hushållsost",
    "hushållspapperet": "hushållspapper",
    "hushållspapperets": "hushållspapper",
    "hushållspappers": "hushållspapper",
    "hushållspappret": "hushållspapper",
    "hushållspapprets": "hushållspapper",
    "hushållsrull": "hushållsrulle",
    "hushållsrullar": "hushållsrulle",
    "hushållsrullarna": "hushållsrulle",
    "hushållsrullarnas": "hushållsrulle",
    "hushållsrullars": "hushållsrulle",
    "hushållsrullen": "hushållsrulle",
    "hushållsrullens": "hushållsrulle",
    "hushållsrulles": "hushållsrulle",
    "hushållsrulls": "hushållsrulle",
    "hushållssyssl": "hushållssyssla",
    "hushållssysslan": "hushållssyssla",
    "hushållssysslans": "hushållssyssla",
    "hushållssysslas": "hushållssyssla",
    "hushållssyssle": "hushållssyssla",
    "hushållssysslo": "hushållssyssla",
    "hushållssysslor": "hushållssyssla",
    "hushållssysslorna": "hushållssyssla",
    "hushållssysslornas": "hushållssyssla",
    "hushållssysslors": "hushållssyssla",
    "hushållsvågar": "hushållsvåg",
    "hushållsvågarna": "hushållsvåg",
    "hushållsvågarnas": "hushållsvåg",
    "hushållsvågars": "hushållsvåg",
    "hushållsvågen": "hushållsvåg",
    "hushållsvågens": "hushållsvåg",
    "hushållsvågs": "hushållsvåg",
    "husknutar": "husknut",
    "husknutarna": "husknut",
    "husknutarnas": "husknut",
    "husknutars": "husknut",
    "husknuten": "husknut",
    "husknutens": "husknut",
    "husknuts": "husknut",
    "huskorsen": "huskors",
    "huskorsens": "huskors",
    "huskorset": "huskors",
    "huskorsets": "huskors",
    "huskroppar": "huskropp",
    "huskropparna": "huskropp",
    "huskropparnas": "huskropp",
    "huskroppars": "huskropp",
    "huskroppen": "huskropp",
    "huskroppens": "huskropp",
    "huskropps": "huskropp",
    "huskuren": "huskur",
    "huskurens": "huskur",
    "huskurer": "huskur",
    "huskurerna": "huskur",
    "huskurernas": "huskur",
    "huskurers": "huskur",
    "huskurs": "huskur",
    "husköpen": "husköp",
    "husköpens": "husköp",
    "husköpet": "husköp",
    "husköpets": "husköp",
    "husköps": "husköp",
    "husliga": "huslig",
    "husligare": "huslig",
    "husligares": "huslig",
    "husligas": "huslig",
    "husligast": "huslig",
    "husligaste": "huslig",
    "husligastes": "huslig",
    "husligasts": "huslig",
    "huslige": "huslig",
    "husliges": "huslig",
    "husligheten": "huslighet",
    "huslighetens": "huslighet",
    "huslighets": "huslighet",
    "husligs": "huslig",
    "husligt": "huslig",
    "husligts": "huslig",
    "husläkar": "husläkare",
    "husläkaren": "husläkare",
    "husläkarens": "husläkare",
    "husläkares": "husläkare",
    "husläkarna": "husläkare",
    "husläkarnas": "husläkare",
    "husmansfolket": "husmansfolk",
    "husmansfolkets": "husmansfolk",
    "husmansfolks": "husmansfolk",
    "husmanskosten": "husmanskost",
    "husmanskostens": "husmanskost",
    "husmanskosts": "husmanskost",
    "husmoder": "husmor",
    "husmodern": "husmor",
    "husmoderns": "husmor",
    "husmoders": "husmor",
    "husmors": "husmor",
    "husmorsföreningar": "husmorsförening",
    "husmorsföreningarna": "husmorsförening",
    "husmorsföreningarnas": "husmorsförening",
    "husmorsföreningars": "husmorsförening",
    "husmorsföreningen": "husmorsförening",
    "husmorsföreningens": "husmorsförening",
    "husmorsförenings": "husmorsförening",
    "husmödrar": "husmor",
    "husmödrarna": "husmor",
    "husmödrarnas": "husmor",
    "husmödrars": "husmor",
    "husor": "husa",
    "husorganen": "husorgan",
    "husorganens": "husorgan",
    "husorganet": "husorgan",
    "husorganets": "husorgan",
    "husorgans": "husorgan",
    "husorna": "husa",
    "husornas": "husa",
    "husors": "husa",
    "husrannsakans": "husrannsakan",
    "husrannsakningar": "husrannsakning",
    "husrannsakningarna": "husrannsakning",
    "husrannsakningarnas": "husrannsakning",
    "husrannsakningars": "husrannsakning",
    "husrannsakningen": "husrannsakning",
    "husrannsakningens": "husrannsakning",
    "husrannsaknings": "husrannsakning",
    "husrummet": "husrum",
    "husrummets": "husrum",
    "husrums": "husrum",
    "huss": "husse",
    "hussar": "husse",
    "hussarna": "husse",
    "hussarnas": "husse",
    "hussars": "husse",
    "hussen": "husse",
    "hussens": "husse",
    "husses": "husse",
    "hussval": "hussvala",
    "hussvalan": "hussvala",
    "hussvalans": "hussvala",
    "hussvalas": "hussvala",
    "hussvale": "hussvala",
    "hussvalor": "hussvala",
    "hussvalorna": "hussvala",
    "hussvalornas": "hussvala",
    "hussvalors": "hussvala",
    "hussvals": "hussvala",
    "hustimmerna": "hustimmer",
    "hustimmernas": "hustimmer",
    "hustimmers": "hustimmer",
    "hustimren": "hustimmer",
    "hustimrens": "hustimmer",
    "hustimret": "hustimmer",
    "hustimrets": "hustimmer",
    "hustomtar": "hustomte",
    "hustomtarna": "hustomte",
    "hustomtarnas": "hustomte",
    "hustomtars": "hustomte",
    "hustomten": "hustomte",
    "hustomtens": "hustomte",
    "hustomtes": "hustomte",
    "hustrun": "hustru",
    "hustruns": "hustru",
    "hustrur": "hustru",
    "hustrurna": "hustru",
    "hustrurnas": "hustru",
    "hustrurs": "hustru",
    "hustrus": "hustru",
    "hustrutilläggen": "hustrutillägg",
    "hustrutilläggens": "hustrutillägg",
    "hustrutillägget": "hustrutillägg",
    "hustrutilläggets": "hustrutillägg",
    "hustrutilläggs": "hustrutillägg",
    "hustyrannen": "hustyrann",
    "hustyrannens": "hustyrann",
    "hustyranner": "hustyrann",
    "hustyrannerna": "hustyrann",
    "hustyrannernas": "hustyrann",
    "hustyranners": "hustyrann",
    "hustyranns": "hustyrann",
    "husundersökningar": "husundersökning",
    "husundersökningarna": "husundersökning",
    "husundersökningarnas": "husundersökning",
    "husundersökningars": "husundersökning",
    "husundersökningen": "husundersökning",
    "husundersökningens": "husundersökning",
    "husundersöknings": "husundersökning",
    "husvagnar": "husvagn",
    "husvagnarna": "husvagn",
    "husvagnarnas": "husvagn",
    "husvagnars": "husvagn",
    "husvagnen": "husvagn",
    "husvagnens": "husvagn",
    "husvagns": "husvagn",
    "husvilla": "husvill",
    "husvillare": "husvill",
    "husvillares": "husvill",
    "husvillas": "husvill",
    "husvillast": "husvill",
    "husvillaste": "husvill",
    "husvillastes": "husvill",
    "husvillasts": "husvill",
    "husville": "husvill",
    "husvilles": "husvill",
    "husvillheten": "husvillhet",
    "husvillhetens": "husvillhet",
    "husvillhets": "husvillhet",
    "husvills": "husvill",
    "husvillt": "husvill",
    "husvillts": "husvill",
    "husägar": "husägare",
    "husägaren": "husägare",
    "husägarens": "husägare",
    "husägares": "husägare",
    "husägarna": "husägare",
    "husägarnas": "husägare",
    "hut": "huta",
    "hutade": "huta",
    "hutades": "huta",
    "hutande": "huta",
    "hutanden": "hutande",
    "hutandena": "hutande",
    "hutandenas": "hutande",
    "hutandens": "hutande",
    "hutandes": "hutande",
    "hutandet": "hutande",
    "hutandets": "hutande",
    "hutar": "huta",
    "hutas": "huta",
    "hutat": "huta",
    "hutats": "huta",
    "hutchar": "hutch",
    "hutcharna": "hutch",
    "hutcharnas": "hutch",
    "hutchars": "hutch",
    "hutchen": "hutch",
    "hutchens": "hutch",
    "hutchs": "hutch",
    "hutlösa": "hutlös",
    "hutlösare": "hutlös",
    "hutlösares": "hutlös",
    "hutlösas": "hutlös",
    "hutlösast": "hutlös",
    "hutlösaste": "hutlös",
    "hutlösastes": "hutlös",
    "hutlösasts": "hutlös",
    "hutlöse": "hutlös",
    "hutlöses": "hutlös",
    "hutlösheten": "hutlöshet",
    "hutlöshetens": "hutlöshet",
    "hutlösheter": "hutlöshet",
    "hutlösheterna": "hutlöshet",
    "hutlösheternas": "hutlöshet",
    "hutlösheters": "hutlöshet",
    "hutlöshets": "hutlöshet",
    "hutlöst": "hutlös",
    "hutlösts": "hutlös",
    "huts": "hut",
    "huttar": "hutt",
    "huttarna": "hutt",
    "huttarnas": "hutt",
    "huttars": "hutt",
    "huttel": "huttla",
    "hutten": "hutt",
    "huttens": "hutt",
    "hutter": "huttra",
    "huttlade": "huttla",
    "huttlades": "huttla",
    "huttlande": "huttla",
    "huttlanden": "huttlande",
    "huttlandena": "huttlande",
    "huttlandenas": "huttlande",
    "huttlandens": "huttlande",
    "huttlandes": "huttlande",
    "huttlandet": "huttlande",
    "huttlandets": "huttlande",
    "huttlar": "huttla",
    "huttlas": "huttla",
    "huttlat": "huttla",
    "huttlats": "huttla",
    "huttrade": "huttra",
    "huttrades": "huttra",
    "huttrande": "huttra",
    "huttranden": "huttrande",
    "huttrandena": "huttrande",
    "huttrandenas": "huttrande",
    "huttrandens": "huttrande",
    "huttrandes": "huttrande",
    "huttrandet": "huttrande",
    "huttrandets": "huttrande",
    "huttrar": "huttra",
    "huttras": "huttra",
    "huttrat": "huttra",
    "huttrats": "huttra",
    "hutts": "hutt",
    "huv": "huva",
    "huvan": "huva",
    "huvans": "huva",
    "huvar": "huv",
    "huvarna": "huv",
    "huvarnas": "huv",
    "huvars": "huv",
    "huvas": "huva",
    "huve": "huva",
    "huven": "huve",
    "huvena": "huve",
    "huvenas": "huve",
    "huvens": "huve",
    "huves": "huve",
    "huvet": "huve",
    "huvets": "huve",
    "huvor": "huva",
    "huvorna": "huva",
    "huvornas": "huva",
    "huvors": "huva",
    "huvs": "huve",
    "huvudanföranden": "huvudanförande",
    "huvudanförandena": "huvudanförande",
    "huvudanförandenas": "huvudanförande",
    "huvudanförandens": "huvudanförande",
    "huvudanförandes": "huvudanförande",
    "huvudanförandet": "huvudanförande",
    "huvudanförandets": "huvudanförande",
    "huvudanstalten": "huvudanstalt",
    "huvudanstaltens": "huvudanstalt",
    "huvudanstalter": "huvudanstalt",
    "huvudanstalterna": "huvudanstalt",
    "huvudanstalternas": "huvudanstalt",
    "huvudanstalters": "huvudanstalt",
    "huvudanstalts": "huvudanstalt",
    "huvudansvaret": "huvudansvar",
    "huvudansvarets": "huvudansvar",
    "huvudansvariga": "huvudansvarig",
    "huvudansvarigas": "huvudansvarig",
    "huvudansvarige": "huvudansvarig",
    "huvudansvariges": "huvudansvarig",
    "huvudansvarigs": "huvudansvarig",
    "huvudansvarigt": "huvudansvarig",
    "huvudansvarigts": "huvudansvarig",
    "huvudansvars": "huvudansvar",
    "huvudavtalen": "huvudavtal",
    "huvudavtalens": "huvudavtal",
    "huvudavtalet": "huvudavtal",
    "huvudavtalets": "huvudavtal",
    "huvudavtals": "huvudavtal",
    "huvudaxeln": "huvudaxel",
    "huvudaxelns": "huvudaxel",
    "huvudaxels": "huvudaxel",
    "huvudaxlar": "huvudaxel",
    "huvudaxlarna": "huvudaxel",
    "huvudaxlarnas": "huvudaxel",
    "huvudaxlars": "huvudaxel",
    "huvudbjudningar": "huvudbjudning",
    "huvudbjudningarna": "huvudbjudning",
    "huvudbjudningarnas": "huvudbjudning",
    "huvudbjudningars": "huvudbjudning",
    "huvudbjudningen": "huvudbjudning",
    "huvudbjudningens": "huvudbjudning",
    "huvudbjudnings": "huvudbjudning",
    "huvudboken": "huvudbok",
    "huvudbokens": "huvudbok",
    "huvudboks": "huvudbok",
    "huvudbonaden": "huvudbonad",
    "huvudbonadens": "huvudbonad",
    "huvudbonader": "huvudbonad",
    "huvudbonaderna": "huvudbonad",
    "huvudbonadernas": "huvudbonad",
    "huvudbonaders": "huvudbonad",
    "huvudbonads": "huvudbonad",
    "huvudbryet": "huvudbry",
    "huvudbryets": "huvudbry",
    "huvudbrys": "huvudbry",
    "huvudbryt": "huvudbry",
    "huvudbryts": "huvudbry",
    "huvudbyggnaden": "huvudbyggnad",
    "huvudbyggnadens": "huvudbyggnad",
    "huvudbyggnader": "huvudbyggnad",
    "huvudbyggnaderna": "huvudbyggnad",
    "huvudbyggnadernas": "huvudbyggnad",
    "huvudbyggnaders": "huvudbyggnad",
    "huvudbyggnads": "huvudbyggnad",
    "huvudböcker": "huvudbok",
    "huvudböckerna": "huvudbok",
    "huvudböckernas": "huvudbok",
    "huvudböckers": "huvudbok",
    "huvuddelar": "huvuddel",
    "huvuddelarna": "huvuddel",
    "huvuddelarnas": "huvuddel",
    "huvuddelars": "huvuddel",
    "huvuddelen": "huvuddel",
    "huvuddelens": "huvuddel",
    "huvuddels": "huvuddel",
    "huvuddragen": "huvuddrag",
    "huvuddragens": "huvuddrag",
    "huvuddraget": "huvuddrag",
    "huvuddragets": "huvuddrag",
    "huvuddrags": "huvuddrag",
    "huvuden": "huvud",
    "huvudena": "huvud",
    "huvudenas": "huvud",
    "huvudens": "huvud",
    "huvudentréer": "huvudentré",
    "huvudentréerna": "huvudentré",
    "huvudentréernas": "huvudentré",
    "huvudentréers": "huvudentré",
    "huvudentrén": "huvudentré",
    "huvudentréns": "huvudentré",
    "huvudentrés": "huvudentré",
    "huvudet": "huvud",
    "huvudets": "huvud",
    "huvudfasaden": "huvudfasad",
    "huvudfasadens": "huvudfasad",
    "huvudfasader": "huvudfasad",
    "huvudfasaderna": "huvudfasad",
    "huvudfasadernas": "huvudfasad",
    "huvudfasaders": "huvudfasad",
    "huvudfasads": "huvudfasad",
    "huvudfiguren": "huvudfigur",
    "huvudfigurens": "huvudfigur",
    "huvudfigurer": "huvudfigur",
    "huvudfigurerna": "huvudfigur",
    "huvudfigurernas": "huvudfigur",
    "huvudfigurers": "huvudfigur",
    "huvudfigurs": "huvudfigur",
    "huvudformen": "huvudform",
    "huvudformens": "huvudform",
    "huvudformer": "huvudform",
    "huvudformerna": "huvudform",
    "huvudformernas": "huvudform",
    "huvudformers": "huvudform",
    "huvudforms": "huvudform",
    "huvudfrågan": "huvudfråga",
    "huvudfrågans": "huvudfråga",
    "huvudfrågas": "huvudfråga",
    "huvudfråge": "huvudfråga",
    "huvudfrågor": "huvudfråga",
    "huvudfrågorna": "huvudfråga",
    "huvudfrågornas": "huvudfråga",
    "huvudfrågors": "huvudfråga",
    "huvudfunktionen": "huvudfunktion",
    "huvudfunktionens": "huvudfunktion",
    "huvudfunktioner": "huvudfunktion",
    "huvudfunktionerna": "huvudfunktion",
    "huvudfunktionernas": "huvudfunktion",
    "huvudfunktioners": "huvudfunktion",
    "huvudfunktions": "huvudfunktion",
    "huvudfödan": "huvudföda",
    "huvudfödans": "huvudföda",
    "huvudfödas": "huvudföda",
    "huvudförhandlingar": "huvudförhandling",
    "huvudförhandlingarna": "huvudförhandling",
    "huvudförhandlingarnas": "huvudförhandling",
    "huvudförhandlingars": "huvudförhandling",
    "huvudförhandlingen": "huvudförhandling",
    "huvudförhandlingens": "huvudförhandling",
    "huvudförhandlings": "huvudförhandling",
    "huvudgärden": "huvudgärd",
    "huvudgärdens": "huvudgärd",
    "huvudgärder": "huvudgärd",
    "huvudgärderna": "huvudgärd",
    "huvudgärdernas": "huvudgärd",
    "huvudgärders": "huvudgärd",
    "huvudgärds": "huvudgärd",
    "huvudhåren": "huvudhår",
    "huvudhårens": "huvudhår",
    "huvudhåret": "huvudhår",
    "huvudhårets": "huvudhår",
    "huvudhårs": "huvudhår",
    "huvudideologien": "huvudideologi",
    "huvudideologiens": "huvudideologi",
    "huvudideologier": "huvudideologi",
    "huvudideologierna": "huvudideologi",
    "huvudideologiernas": "huvudideologi",
    "huvudideologiers": "huvudideologi",
    "huvudideologin": "huvudideologi",
    "huvudideologins": "huvudideologi",
    "huvudideologis": "huvudideologi",
    "huvudingångar": "huvudingång",
    "huvudingångarna": "huvudingång",
    "huvudingångarnas": "huvudingång",
    "huvudingångars": "huvudingång",
    "huvudingången": "huvudingång",
    "huvudingångens": "huvudingång",
    "huvudingångs": "huvudingång",
    "huvudinkomsten": "huvudinkomst",
    "huvudinkomstens": "huvudinkomst",
    "huvudinkomster": "huvudinkomst",
    "huvudinkomsterna": "huvudinkomst",
    "huvudinkomsternas": "huvudinkomst",
    "huvudinkomsters": "huvudinkomst",
    "huvudinkomsts": "huvudinkomst",
    "huvudinnehållen": "huvudinnehåll",
    "huvudinnehållens": "huvudinnehåll",
    "huvudinnehållet": "huvudinnehåll",
    "huvudinnehållets": "huvudinnehåll",
    "huvudinnehålls": "huvudinnehåll",
    "huvudjakten": "huvudjakt",
    "huvudjaktens": "huvudjakt",
    "huvudjakts": "huvudjakt",
    "huvudjägar": "huvudjägare",
    "huvudjägaren": "huvudjägare",
    "huvudjägarens": "huvudjägare",
    "huvudjägares": "huvudjägare",
    "huvudjägarna": "huvudjägare",
    "huvudjägarnas": "huvudjägare",
    "huvudkontoren": "huvudkontor",
    "huvudkontorens": "huvudkontor",
    "huvudkontoret": "huvudkontor",
    "huvudkontorets": "huvudkontor",
    "huvudkontors": "huvudkontor",
    "huvudkvarteren": "huvudkvarter",
    "huvudkvarterens": "huvudkvarter",
    "huvudkvarteret": "huvudkvarter",
    "huvudkvarterets": "huvudkvarter",
    "huvudkvarters": "huvudkvarter",
    "huvudlagen": "huvudlag",
    "huvudlagens": "huvudlag",
    "huvudlaget": "huvudlag",
    "huvudlagets": "huvudlag",
    "huvudlags": "huvudlag",
    "huvudleden": "huvudled",
    "huvudledens": "huvudled",
    "huvudleder": "huvudled",
    "huvudlederna": "huvudled",
    "huvudledernas": "huvudled",
    "huvudleders": "huvudled",
    "huvudledningar": "huvudledning",
    "huvudledningarna": "huvudledning",
    "huvudledningarnas": "huvudledning",
    "huvudledningars": "huvudledning",
    "huvudledningen": "huvudledning",
    "huvudledningens": "huvudledning",
    "huvudlednings": "huvudledning",
    "huvudleds": "huvudled",
    "huvudlinjen": "huvudlinje",
    "huvudlinjens": "huvudlinje",
    "huvudlinjer": "huvudlinje",
    "huvudlinjerna": "huvudlinje",
    "huvudlinjernas": "huvudlinje",
    "huvudlinjers": "huvudlinje",
    "huvudlinjes": "huvudlinje",
    "huvudlärar": "huvudlärare",
    "huvudläraren": "huvudlärare",
    "huvudlärarens": "huvudlärare",
    "huvudlärares": "huvudlärare",
    "huvudlärarna": "huvudlärare",
    "huvudlärarnas": "huvudlärare",
    "huvudlösa": "huvudlös",
    "huvudlösare": "huvudlös",
    "huvudlösares": "huvudlös",
    "huvudlösas": "huvudlös",
    "huvudlösast": "huvudlös",
    "huvudlösaste": "huvudlös",
    "huvudlösastes": "huvudlös",
    "huvudlösasts": "huvudlös",
    "huvudlöse": "huvudlös",
    "huvudlöses": "huvudlös",
    "huvudlösheten": "huvudlöshet",
    "huvudlöshetens": "huvudlöshet",
    "huvudlösheter": "huvudlöshet",
    "huvudlösheterna": "huvudlöshet",
    "huvudlösheternas": "huvudlöshet",
    "huvudlösheters": "huvudlöshet",
    "huvudlöshets": "huvudlöshet",
    "huvudlöst": "huvudlös",
    "huvudlösts": "huvudlös",
    "huvudmannaskapet": "huvudmannaskap",
    "huvudmannaskapets": "huvudmannaskap",
    "huvudmannaskaps": "huvudmannaskap",
    "huvudmannen": "huvudman",
    "huvudmannens": "huvudman",
    "huvudmans": "huvudman",
    "huvudmomenten": "huvudmoment",
    "huvudmomentens": "huvudmoment",
    "huvudmomentet": "huvudmoment",
    "huvudmomentets": "huvudmoment",
    "huvudmoments": "huvudmoment",
    "huvudmotorer": "huvudmotor",
    "huvudmotorerna": "huvudmotor",
    "huvudmotorernas": "huvudmotor",
    "huvudmotorers": "huvudmotor",
    "huvudmotorn": "huvudmotor",
    "huvudmotorns": "huvudmotor",
    "huvudmotors": "huvudmotor",
    "huvudmotståndar": "huvudmotståndare",
    "huvudmotståndaren": "huvudmotståndare",
    "huvudmotståndarens": "huvudmotståndare",
    "huvudmotståndares": "huvudmotståndare",
    "huvudmotståndarna": "huvudmotståndare",
    "huvudmotståndarnas": "huvudmotståndare",
    "huvudmän": "huvudman",
    "huvudmännen": "huvudman",
    "huvudmännens": "huvudman",
    "huvudmäns": "huvudman",
    "huvudnyckeln": "huvudnyckel",
    "huvudnyckelns": "huvudnyckel",
    "huvudnyckels": "huvudnyckel",
    "huvudnycklar": "huvudnyckel",
    "huvudnycklarna": "huvudnyckel",
    "huvudnycklarnas": "huvudnyckel",
    "huvudnycklars": "huvudnyckel",
    "huvudnäringar": "huvudnäring",
    "huvudnäringarna": "huvudnäring",
    "huvudnäringarnas": "huvudnäring",
    "huvudnäringars": "huvudnäring",
    "huvudnäringen": "huvudnäring",
    "huvudnäringens": "huvudnäring",
    "huvudnärings": "huvudnäring",
    "huvudorden": "huvudord",
    "huvudordens": "huvudord",
    "huvudordet": "huvudord",
    "huvudordets": "huvudord",
    "huvudords": "huvudord",
    "huvudorsaken": "huvudorsak",
    "huvudorsakens": "huvudorsak",
    "huvudorsaker": "huvudorsak",
    "huvudorsakerna": "huvudorsak",
    "huvudorsakernas": "huvudorsak",
    "huvudorsakers": "huvudorsak",
    "huvudorsaks": "huvudorsak",
    "huvudparten": "huvudpart",
    "huvudpartens": "huvudpart",
    "huvudparts": "huvudpart",
    "huvudpersonen": "huvudperson",
    "huvudpersonens": "huvudperson",
    "huvudpersoner": "huvudperson",
    "huvudpersonerna": "huvudperson",
    "huvudpersonernas": "huvudperson",
    "huvudpersoners": "huvudperson",
    "huvudpersons": "huvudperson",
    "huvudpunkten": "huvudpunkt",
    "huvudpunktens": "huvudpunkt",
    "huvudpunkter": "huvudpunkt",
    "huvudpunkterna": "huvudpunkt",
    "huvudpunkternas": "huvudpunkt",
    "huvudpunkters": "huvudpunkt",
    "huvudpunkts": "huvudpunkt",
    "huvudregeln": "huvudregel",
    "huvudregelns": "huvudregel",
    "huvudregels": "huvudregel",
    "huvudregler": "huvudregel",
    "huvudreglerna": "huvudregel",
    "huvudreglernas": "huvudregel",
    "huvudreglers": "huvudregel",
    "huvudrollen": "huvudroll",
    "huvudrollens": "huvudroll",
    "huvudroller": "huvudroll",
    "huvudrollerna": "huvudroll",
    "huvudrollernas": "huvudroll",
    "huvudrollers": "huvudroll",
    "huvudrolls": "huvudroll",
    "huvudrollsinnehavar": "huvudrollsinnehavare",
    "huvudrollsinnehavaren": "huvudrollsinnehavare",
    "huvudrollsinnehavarens": "huvudrollsinnehavare",
    "huvudrollsinnehavares": "huvudrollsinnehavare",
    "huvudrollsinnehavarna": "huvudrollsinnehavare",
    "huvudrollsinnehavarnas": "huvudrollsinnehavare",
    "huvudräkningar": "huvudräkning",
    "huvudräkningarna": "huvudräkning",
    "huvudräkningarnas": "huvudräkning",
    "huvudräkningars": "huvudräkning",
    "huvudräkningen": "huvudräkning",
    "huvudräkningens": "huvudräkning",
    "huvudräknings": "huvudräkning",
    "huvudrätten": "huvudrätt",
    "huvudrättens": "huvudrätt",
    "huvudrätter": "huvudrätt",
    "huvudrätterna": "huvudrätt",
    "huvudrätternas": "huvudrätt",
    "huvudrätters": "huvudrätt",
    "huvudrätts": "huvudrätt",
    "huvuds": "huvud",
    "huvudsaken": "huvudsak",
    "huvudsakens": "huvudsak",
    "huvudsaker": "huvudsak",
    "huvudsakerna": "huvudsak",
    "huvudsakernas": "huvudsak",
    "huvudsakers": "huvudsak",
    "huvudsakliga": "huvudsaklig",
    "huvudsakligare": "huvudsaklig",
    "huvudsakligares": "huvudsaklig",
    "huvudsakligas": "huvudsaklig",
    "huvudsakligast": "huvudsaklig",
    "huvudsakligaste": "huvudsaklig",
    "huvudsakligastes": "huvudsaklig",
    "huvudsakligasts": "huvudsaklig",
    "huvudsaklige": "huvudsaklig",
    "huvudsakliges": "huvudsaklig",
    "huvudsakligs": "huvudsaklig",
    "huvudsakligt": "huvudsaklig",
    "huvudsakligts": "huvudsaklig",
    "huvudsaks": "huvudsak",
    "huvudsatsen": "huvudsats",
    "huvudsatsens": "huvudsats",
    "huvudsatser": "huvudsats",
    "huvudsatserna": "huvudsats",
    "huvudsatsernas": "huvudsats",
    "huvudsatsers": "huvudsats",
    "huvudskakningar": "huvudskakning",
    "huvudskakningarna": "huvudskakning",
    "huvudskakningarnas": "huvudskakning",
    "huvudskakningars": "huvudskakning",
    "huvudskakningen": "huvudskakning",
    "huvudskakningens": "huvudskakning",
    "huvudskaknings": "huvudskakning",
    "huvudskydden": "huvudskydd",
    "huvudskyddens": "huvudskydd",
    "huvudskyddet": "huvudskydd",
    "huvudskyddets": "huvudskydd",
    "huvudskydds": "huvudskydd",
    "huvudskyddsombuden": "huvudskyddsombud",
    "huvudskyddsombudens": "huvudskyddsombud",
    "huvudskyddsombudet": "huvudskyddsombud",
    "huvudskyddsombudets": "huvudskyddsombud",
    "huvudskyddsombuds": "huvudskyddsombud",
    "huvudskälen": "huvudskäl",
    "huvudskälens": "huvudskäl",
    "huvudskälet": "huvudskäl",
    "huvudskälets": "huvudskäl",
    "huvudskäls": "huvudskäl",
    "huvudskålar": "huvudskål",
    "huvudskålarna": "huvudskål",
    "huvudskålarnas": "huvudskål",
    "huvudskålars": "huvudskål",
    "huvudskålen": "huvudskål",
    "huvudskålens": "huvudskål",
    "huvudskåls": "huvudskål",
    "huvudstaden": "huvudstad",
    "huvudstadens": "huvudstad",
    "huvudstads": "huvudstad",
    "huvudstan": "huvudstad",
    "huvudstans": "huvudstad",
    "huvudstolar": "huvudstol",
    "huvudstolarna": "huvudstol",
    "huvudstolarnas": "huvudstol",
    "huvudstolars": "huvudstol",
    "huvudstolen": "huvudstol",
    "huvudstolens": "huvudstol",
    "huvudstols": "huvudstol",
    "huvudstråken": "huvudstråk",
    "huvudstråkens": "huvudstråk",
    "huvudstråket": "huvudstråk",
    "huvudstråkets": "huvudstråk",
    "huvudstråks": "huvudstråk",
    "huvudströmbrytar": "huvudströmbrytare",
    "huvudströmbrytaren": "huvudströmbrytare",
    "huvudströmbrytarens": "huvudströmbrytare",
    "huvudströmbrytares": "huvudströmbrytare",
    "huvudströmbrytarna": "huvudströmbrytare",
    "huvudströmbrytarnas": "huvudströmbrytare",
    "huvudstycken": "huvudstycke",
    "huvudstyckena": "huvudstycke",
    "huvudstyckenas": "huvudstycke",
    "huvudstyckens": "huvudstycke",
    "huvudstyckes": "huvudstycke",
    "huvudstycket": "huvudstycke",
    "huvudstyckets": "huvudstycke",
    "huvudstycks": "huvudstycke",
    "huvudstäder": "huvudstad",
    "huvudstäderna": "huvudstad",
    "huvudstädernas": "huvudstad",
    "huvudstäders": "huvudstad",
    "huvudsvålar": "huvudsvål",
    "huvudsvålarna": "huvudsvål",
    "huvudsvålarnas": "huvudsvål",
    "huvudsvålars": "huvudsvål",
    "huvudsvålen": "huvudsvål",
    "huvudsvålens": "huvudsvål",
    "huvudsvåls": "huvudsvål",
    "huvudteman": "huvudtema",
    "huvudtemana": "huvudtema",
    "huvudtemanas": "huvudtema",
    "huvudtemans": "huvudtema",
    "huvudtemas": "huvudtema",
    "huvudtemat": "huvudtema",
    "huvudtemata": "huvudtema",
    "huvudtematana": "huvudtema",
    "huvudtematanas": "huvudtema",
    "huvudtematas": "huvudtema",
    "huvudtemats": "huvudtema",
    "huvudtiteln": "huvudtitel",
    "huvudtitelns": "huvudtitel",
    "huvudtitels": "huvudtitel",
    "huvudtitlar": "huvudtitel",
    "huvudtitlarna": "huvudtitel",
    "huvudtitlarnas": "huvudtitel",
    "huvudtitlars": "huvudtitel",
    "huvudtonen": "huvudton",
    "huvudtonens": "huvudton",
    "huvudtoner": "huvudton",
    "huvudtonerna": "huvudton",
    "huvudtonernas": "huvudton",
    "huvudtoners": "huvudton",
    "huvudtons": "huvudton",
    "huvudtrakten": "huvudtrakt",
    "huvudtraktens": "huvudtrakt",
    "huvudtrakter": "huvudtrakt",
    "huvudtrakterna": "huvudtrakt",
    "huvudtrakternas": "huvudtrakt",
    "huvudtrakters": "huvudtrakt",
    "huvudtrakts": "huvudtrakt",
    "huvudtrycket": "huvudtryck",
    "huvudtryckets": "huvudtryck",
    "huvudtrycks": "huvudtryck",
    "huvuduppgiften": "huvuduppgift",
    "huvuduppgiftens": "huvuduppgift",
    "huvuduppgifter": "huvuduppgift",
    "huvuduppgifterna": "huvuduppgift",
    "huvuduppgifternas": "huvuduppgift",
    "huvuduppgifters": "huvuduppgift",
    "huvuduppgifts": "huvuduppgift",
    "huvudvattenledningar": "huvudvattenledning",
    "huvudvattenledningarna": "huvudvattenledning",
    "huvudvattenledningarnas": "huvudvattenledning",
    "huvudvattenledningars": "huvudvattenledning",
    "huvudvattenledningen": "huvudvattenledning",
    "huvudvattenledningens": "huvudvattenledning",
    "huvudvattenlednings": "huvudvattenledning",
    "huvudverben": "huvudverb",
    "huvudverbens": "huvudverb",
    "huvudverbet": "huvudverb",
    "huvudverbets": "huvudverb",
    "huvudverbs": "huvudverb",
    "huvudvittnen": "huvudvittne",
    "huvudvittnena": "huvudvittne",
    "huvudvittnenas": "huvudvittne",
    "huvudvittnens": "huvudvittne",
    "huvudvittnes": "huvudvittne",
    "huvudvittnet": "huvudvittne",
    "huvudvittnets": "huvudvittne",
    "huvudvägar": "huvudväg",
    "huvudvägarna": "huvudväg",
    "huvudvägarnas": "huvudväg",
    "huvudvägars": "huvudväg",
    "huvudvägen": "huvudväg",
    "huvudvägens": "huvudväg",
    "huvudvägs": "huvudväg",
    "huvudvärken": "huvudvärk",
    "huvudvärkens": "huvudvärk",
    "huvudvärks": "huvudvärk",
    "huvudvärkstabletten": "huvudvärkstablett",
    "huvudvärkstablettens": "huvudvärkstablett",
    "huvudvärkstabletter": "huvudvärkstablett",
    "huvudvärkstabletterna": "huvudvärkstablett",
    "huvudvärkstabletternas": "huvudvärkstablett",
    "huvudvärkstabletters": "huvudvärkstablett",
    "huvudvärkstabletts": "huvudvärkstablett",
    "huvudämnen": "huvudämne",
    "huvudämnena": "huvudämne",
    "huvudämnenas": "huvudämne",
    "huvudämnens": "huvudämne",
    "huvudämnes": "huvudämne",
    "huvudämnet": "huvudämne",
    "huvudämnets": "huvudämne",
    "hyacinten": "hyacint",
    "hyacintens": "hyacint",
    "hyacinter": "hyacint",
    "hyacinterna": "hyacint",
    "hyacinternas": "hyacint",
    "hyacinters": "hyacint",
    "hyacints": "hyacint",
    "hybblen": "hybble",
    "hybblena": "hybble",
    "hybblenas": "hybble",
    "hybblens": "hybble",
    "hybbles": "hybble",
    "hybblet": "hybble",
    "hybblets": "hybble",
    "hybbls": "hybble",
    "hybrida": "hybrid",
    "hybridare": "hybrid",
    "hybridares": "hybrid",
    "hybridas": "hybrid",
    "hybridast": "hybrid",
    "hybridaste": "hybrid",
    "hybridastes": "hybrid",
    "hybridasts": "hybrid",
    "hybride": "hybrid",
    "hybriden": "hybrid",
    "hybridens": "hybrid",
    "hybrider": "hybrid",
    "hybriderna": "hybrid",
    "hybridernas": "hybrid",
    "hybriders": "hybrid",
    "hybrides": "hybrid",
    "hybridiserad": "hybridisera",
    "hybridiserade": "hybridisera",
    "hybridiserades": "hybridisera",
    "hybridiserads": "hybridisera",
    "hybridiserande": "hybridisera",
    "hybridiseranden": "hybridiserande",
    "hybridiserandena": "hybridiserande",
    "hybridiserandenas": "hybridiserande",
    "hybridiserandens": "hybridiserande",
    "hybridiserandes": "hybridiserande",
    "hybridiserandet": "hybridiserande",
    "hybridiserandets": "hybridiserande",
    "hybridiserar": "hybridisera",
    "hybridiseras": "hybridisera",
    "hybridiserat": "hybridisera",
    "hybridiserats": "hybridisera",
    "hybridiserbara": "hybridiserbar",
    "hybridiserbarare": "hybridiserbar",
    "hybridiserbarares": "hybridiserbar",
    "hybridiserbaras": "hybridiserbar",
    "hybridiserbarast": "hybridiserbar",
    "hybridiserbaraste": "hybridiserbar",
    "hybridiserbarastes": "hybridiserbar",
    "hybridiserbarasts": "hybridiserbar",
    "hybridiserbare": "hybridiserbar",
    "hybridiserbares": "hybridiserbar",
    "hybridiserbarheten": "hybridiserbarhet",
    "hybridiserbarhetens": "hybridiserbarhet",
    "hybridiserbarhets": "hybridiserbarhet",
    "hybridiserbars": "hybridiserbar",
    "hybridiserbart": "hybridiserbar",
    "hybridiserbarts": "hybridiserbar",
    "hybridiseringar": "hybridisering",
    "hybridiseringarna": "hybridisering",
    "hybridiseringarnas": "hybridisering",
    "hybridiseringars": "hybridisering",
    "hybridiseringen": "hybridisering",
    "hybridiseringens": "hybridisering",
    "hybridiserings": "hybridisering",
    "hybrids": "hybrid",
    "hybrisen": "hybris",
    "hybrisens": "hybris",
    "hyckel": "hyckla",
    "hyckels": "hyckel",
    "hycklad": "hyckla",
    "hycklade": "hyckla",
    "hycklades": "hyckla",
    "hycklads": "hyckla",
    "hycklande": "hyckla",
    "hycklanden": "hycklande",
    "hycklandena": "hycklande",
    "hycklandenas": "hycklande",
    "hycklandens": "hycklande",
    "hycklandes": "hycklande",
    "hycklandet": "hycklande",
    "hycklandets": "hycklande",
    "hycklar": "hycklare",
    "hycklaren": "hycklare",
    "hycklarens": "hycklare",
    "hycklares": "hycklare",
    "hycklarna": "hycklare",
    "hycklarnas": "hycklare",
    "hycklas": "hyckla",
    "hycklat": "hyckla",
    "hycklats": "hyckla",
    "hycklerier": "hyckleri",
    "hycklerierna": "hyckleri",
    "hyckleriernas": "hyckleri",
    "hyckleriers": "hyckleri",
    "hyckleriet": "hyckleri",
    "hyckleriets": "hyckleri",
    "hyckleris": "hyckleri",
    "hycklerit": "hyckleri",
    "hycklerits": "hyckleri",
    "hycklet": "hyckel",
    "hycklets": "hyckel",
    "hydd": "hydda",
    "hyddan": "hydda",
    "hyddans": "hydda",
    "hyddas": "hydda",
    "hydde": "hydda",
    "hyddor": "hydda",
    "hyddorna": "hydda",
    "hyddornas": "hydda",
    "hyddors": "hydda",
    "hydds": "hydda",
    "hydran": "hydra",
    "hydrans": "hydra",
    "hydras": "hydra",
    "hydraten": "hydrat",
    "hydratens": "hydrat",
    "hydrater": "hydrat",
    "hydraterna": "hydrat",
    "hydraternas": "hydrat",
    "hydraters": "hydrat",
    "hydratet": "hydrat",
    "hydratets": "hydrat",
    "hydratiserade": "hydratiserad",
    "hydratiserades": "hydratiserad",
    "hydratiserads": "hydratiserad",
    "hydratiserat": "hydratiserad",
    "hydratiserats": "hydratiserad",
    "hydratiseringar": "hydratisering",
    "hydratiseringarna": "hydratisering",
    "hydratiseringarnas": "hydratisering",
    "hydratiseringars": "hydratisering",
    "hydratiseringen": "hydratisering",
    "hydratiseringens": "hydratisering",
    "hydratiserings": "hydratisering",
    "hydrats": "hydrat",
    "hydrauliken": "hydraulik",
    "hydraulikens": "hydraulik",
    "hydrauliks": "hydraulik",
    "hydrauliska": "hydraulisk",
    "hydrauliskare": "hydraulisk",
    "hydrauliskares": "hydraulisk",
    "hydrauliskas": "hydraulisk",
    "hydrauliskast": "hydraulisk",
    "hydrauliskaste": "hydraulisk",
    "hydrauliskastes": "hydraulisk",
    "hydrauliskasts": "hydraulisk",
    "hydrauliske": "hydraulisk",
    "hydrauliskes": "hydraulisk",
    "hydraulisks": "hydraulisk",
    "hydrauliskt": "hydraulisk",
    "hydrauliskts": "hydraulisk",
    "hydraullyftar": "hydraullyft",
    "hydraullyftarna": "hydraullyft",
    "hydraullyftarnas": "hydraullyft",
    "hydraullyftars": "hydraullyft",
    "hydraullyften": "hydraullyft",
    "hydraullyftens": "hydraullyft",
    "hydraullyfts": "hydraullyft",
    "hydrauloljan": "hydraulolja",
    "hydrauloljans": "hydraulolja",
    "hydrauloljas": "hydraulolja",
    "hydraulolje": "hydraulolja",
    "hydrauloljor": "hydraulolja",
    "hydrauloljorna": "hydraulolja",
    "hydrauloljornas": "hydraulolja",
    "hydrauloljors": "hydraulolja",
    "hydre": "hydra",
    "hydrerad": "hydrera",
    "hydrerade": "hydrera",
    "hydrerades": "hydrera",
    "hydrerads": "hydrera",
    "hydrerande": "hydrera",
    "hydreranden": "hydrerande",
    "hydrerandena": "hydrerande",
    "hydrerandenas": "hydrerande",
    "hydrerandens": "hydrerande",
    "hydrerandes": "hydrerande",
    "hydrerandet": "hydrerande",
    "hydrerandets": "hydrerande",
    "hydrerar": "hydrera",
    "hydreras": "hydrera",
    "hydrerat": "hydrera",
    "hydrerats": "hydrera",
    "hydrerbara": "hydrerbar",
    "hydrerbarare": "hydrerbar",
    "hydrerbarares": "hydrerbar",
    "hydrerbaras": "hydrerbar",
    "hydrerbarast": "hydrerbar",
    "hydrerbaraste": "hydrerbar",
    "hydrerbarastes": "hydrerbar",
    "hydrerbarasts": "hydrerbar",
    "hydrerbare": "hydrerbar",
    "hydrerbares": "hydrerbar",
    "hydrerbarheten": "hydrerbarhet",
    "hydrerbarhetens": "hydrerbarhet",
    "hydrerbarhets": "hydrerbarhet",
    "hydrerbars": "hydrerbar",
    "hydrerbart": "hydrerbar",
    "hydrerbarts": "hydrerbar",
    "hydreringar": "hydrering",
    "hydreringarna": "hydrering",
    "hydreringarnas": "hydrering",
    "hydreringars": "hydrering",
    "hydreringen": "hydrering",
    "hydreringens": "hydrering",
    "hydrerings": "hydrering",
    "hydrodynamiken": "hydrodynamik",
    "hydrodynamikens": "hydrodynamik",
    "hydrodynamiks": "hydrodynamik",
    "hydrodynamiska": "hydrodynamisk",
    "hydrodynamiskare": "hydrodynamisk",
    "hydrodynamiskares": "hydrodynamisk",
    "hydrodynamiskas": "hydrodynamisk",
    "hydrodynamiskast": "hydrodynamisk",
    "hydrodynamiskaste": "hydrodynamisk",
    "hydrodynamiskastes": "hydrodynamisk",
    "hydrodynamiskasts": "hydrodynamisk",
    "hydrodynamiske": "hydrodynamisk",
    "hydrodynamiskes": "hydrodynamisk",
    "hydrodynamisks": "hydrodynamisk",
    "hydrodynamiskt": "hydrodynamisk",
    "hydrodynamiskts": "hydrodynamisk",
    "hydrofoba": "hydrofob",
    "hydrofobare": "hydrofob",
    "hydrofobares": "hydrofob",
    "hydrofobas": "hydrofob",
    "hydrofobast": "hydrofob",
    "hydrofobaste": "hydrofob",
    "hydrofobastes": "hydrofob",
    "hydrofobasts": "hydrofob",
    "hydrofobe": "hydrofob",
    "hydrofobes": "hydrofob",
    "hydrofobs": "hydrofob",
    "hydrofobt": "hydrofob",
    "hydrofobts": "hydrofob",
    "hydrofonen": "hydrofon",
    "hydrofonens": "hydrofon",
    "hydrofoner": "hydrofon",
    "hydrofonerna": "hydrofon",
    "hydrofonernas": "hydrofon",
    "hydrofoners": "hydrofon",
    "hydrofons": "hydrofon",
    "hydroforen": "hydrofor",
    "hydroforens": "hydrofor",
    "hydroforer": "hydrofor",
    "hydroforerna": "hydrofor",
    "hydroforernas": "hydrofor",
    "hydroforers": "hydrofor",
    "hydroforpumpar": "hydroforpump",
    "hydroforpumparna": "hydroforpump",
    "hydroforpumparnas": "hydroforpump",
    "hydroforpumpars": "hydroforpump",
    "hydroforpumpen": "hydroforpump",
    "hydroforpumpens": "hydroforpump",
    "hydroforpumps": "hydroforpump",
    "hydrofors": "hydrofor",
    "hydrofyten": "hydrofyt",
    "hydrofytens": "hydrofyt",
    "hydrofyter": "hydrofyt",
    "hydrofyterna": "hydrofyt",
    "hydrofyternas": "hydrofyt",
    "hydrofyters": "hydrofyt",
    "hydrofyts": "hydrofyt",
    "hydrografien": "hydrografi",
    "hydrografiens": "hydrografi",
    "hydrografin": "hydrografi",
    "hydrografins": "hydrografi",
    "hydrografis": "hydrografi",
    "hydrokinonen": "hydrokinon",
    "hydrokinonens": "hydrokinon",
    "hydrokinons": "hydrokinon",
    "hydrokoptern": "hydrokopter",
    "hydrokopterns": "hydrokopter",
    "hydrokopters": "hydrokopter",
    "hydrokoptrar": "hydrokopter",
    "hydrokoptrarna": "hydrokopter",
    "hydrokoptrarnas": "hydrokopter",
    "hydrokoptrars": "hydrokopter",
    "hydrokulturen": "hydrokultur",
    "hydrokulturens": "hydrokultur",
    "hydrokulturer": "hydrokultur",
    "hydrokulturerna": "hydrokultur",
    "hydrokulturernas": "hydrokultur",
    "hydrokulturers": "hydrokultur",
    "hydrokulturs": "hydrokultur",
    "hydrologen": "hydrolog",
    "hydrologens": "hydrolog",
    "hydrologer": "hydrolog",
    "hydrologerna": "hydrolog",
    "hydrologernas": "hydrolog",
    "hydrologers": "hydrolog",
    "hydrologien": "hydrologi",
    "hydrologiens": "hydrologi",
    "hydrologin": "hydrologi",
    "hydrologins": "hydrologi",
    "hydrologis": "hydrologi",
    "hydrologiska": "hydrologisk",
    "hydrologiskare": "hydrologisk",
    "hydrologiskares": "hydrologisk",
    "hydrologiskas": "hydrologisk",
    "hydrologiskast": "hydrologisk",
    "hydrologiskaste": "hydrologisk",
    "hydrologiskastes": "hydrologisk",
    "hydrologiskasts": "hydrologisk",
    "hydrologiske": "hydrologisk",
    "hydrologiskes": "hydrologisk",
    "hydrologisks": "hydrologisk",
    "hydrologiskt": "hydrologisk",
    "hydrologiskts": "hydrologisk",
    "hydrologs": "hydrolog",
    "hydrolysen": "hydrolys",
    "hydrolysens": "hydrolys",
    "hydrolyser": "hydrolys",
    "hydrolyserna": "hydrolys",
    "hydrolysernas": "hydrolys",
    "hydrolysers": "hydrolys",
    "hydroplanen": "hydroplan",
    "hydroplanens": "hydroplan",
    "hydroplanet": "hydroplan",
    "hydroplanets": "hydroplan",
    "hydroplans": "hydroplan",
    "hydror": "hydra",
    "hydrorna": "hydra",
    "hydrornas": "hydra",
    "hydrors": "hydra",
    "hydrosfären": "hydrosfär",
    "hydrosfärens": "hydrosfär",
    "hydrosfärs": "hydrosfär",
    "hydrostatiken": "hydrostatik",
    "hydrostatikens": "hydrostatik",
    "hydrostatiks": "hydrostatik",
    "hydrostatiska": "hydrostatisk",
    "hydrostatiskare": "hydrostatisk",
    "hydrostatiskares": "hydrostatisk",
    "hydrostatiskas": "hydrostatisk",
    "hydrostatiskast": "hydrostatisk",
    "hydrostatiskaste": "hydrostatisk",
    "hydrostatiskastes": "hydrostatisk",
    "hydrostatiskasts": "hydrostatisk",
    "hydrostatiske": "hydrostatisk",
    "hydrostatiskes": "hydrostatisk",
    "hydrostatisks": "hydrostatisk",
    "hydrostatiskt": "hydrostatisk",
    "hydrostatiskts": "hydrostatisk",
    "hydroxiden": "hydroxid",
    "hydroxidens": "hydroxid",
    "hydroxider": "hydroxid",
    "hydroxiderna": "hydroxid",
    "hydroxidernas": "hydroxid",
    "hydroxiders": "hydroxid",
    "hydroxidjonen": "hydroxidjon",
    "hydroxidjonens": "hydroxidjon",
    "hydroxidjoner": "hydroxidjon",
    "hydroxidjonerna": "hydroxidjon",
    "hydroxidjonernas": "hydroxidjon",
    "hydroxidjoners": "hydroxidjon",
    "hydroxidjons": "hydroxidjon",
    "hydroxids": "hydroxid",
    "hyen": "hyena",
    "hyenan": "hyena",
    "hyenans": "hyena",
    "hyenas": "hyena",
    "hyenden": "hyende",
    "hyendena": "hyende",
    "hyendenas": "hyende",
    "hyendens": "hyende",
    "hyendes": "hyende",
    "hyendet": "hyende",
    "hyendets": "hyende",
    "hyene": "hyena",
    "hyenor": "hyena",
    "hyenorna": "hyena",
    "hyenornas": "hyena",
    "hyenors": "hyena",
    "hyens": "hyena",
    "hyfen": "hyf",
    "hyfens": "hyf",
    "hyfer": "hyf",
    "hyferna": "hyf",
    "hyfernas": "hyf",
    "hyfers": "hyf",
    "hyfs": "hyfsa",
    "hyfsad": "hyfsa",
    "hyfsade": "hyfsad",
    "hyfsades": "hyfsad",
    "hyfsads": "hyfsad",
    "hyfsande": "hyfsa",
    "hyfsanden": "hyfsande",
    "hyfsandena": "hyfsande",
    "hyfsandenas": "hyfsande",
    "hyfsandens": "hyfsande",
    "hyfsandes": "hyfsande",
    "hyfsandet": "hyfsande",
    "hyfsandets": "hyfsande",
    "hyfsar": "hyfsa",
    "hyfsas": "hyfsa",
    "hyfsat": "hyfsad",
    "hyfsats": "hyfsad",
    "hyfsen": "hyfs",
    "hyfsens": "hyfs",
    "hyggen": "hygge",
    "hyggena": "hygge",
    "hyggenas": "hygge",
    "hyggens": "hygge",
    "hygges": "hygge",
    "hyggesbränningar": "hyggesbränning",
    "hyggesbränningarna": "hyggesbränning",
    "hyggesbränningarnas": "hyggesbränning",
    "hyggesbränningars": "hyggesbränning",
    "hyggesbränningen": "hyggesbränning",
    "hyggesbränningens": "hyggesbränning",
    "hyggesbrännings": "hyggesbränning",
    "hygget": "hygge",
    "hyggets": "hygge",
    "hyggliga": "hygglig",
    "hyggligare": "hygglig",
    "hyggligares": "hygglig",
    "hyggligas": "hygglig",
    "hyggligast": "hygglig",
    "hyggligaste": "hygglig",
    "hyggligastes": "hygglig",
    "hyggligasts": "hygglig",
    "hygglige": "hygglig",
    "hyggliges": "hygglig",
    "hyggligheten": "hygglighet",
    "hygglighetens": "hygglighet",
    "hyggligheter": "hygglighet",
    "hyggligheterna": "hygglighet",
    "hyggligheternas": "hygglighet",
    "hyggligheters": "hygglighet",
    "hygglighets": "hygglighet",
    "hyggligs": "hygglig",
    "hyggligt": "hygglig",
    "hyggligts": "hygglig",
    "hygglon": "hygglo",
    "hygglona": "hygglo",
    "hygglonas": "hygglo",
    "hygglons": "hygglo",
    "hygglos": "hygglo",
    "hygglot": "hygglo",
    "hygglots": "hygglo",
    "hygienen": "hygien",
    "hygienens": "hygien",
    "hygienfrågan": "hygienfråga",
    "hygienfrågans": "hygienfråga",
    "hygienfrågas": "hygienfråga",
    "hygienfråge": "hygienfråga",
    "hygienfrågor": "hygienfråga",
    "hygienfrågorna": "hygienfråga",
    "hygienfrågornas": "hygienfråga",
    "hygienfrågors": "hygienfråga",
    "hygieniska": "hygienisk",
    "hygieniskare": "hygienisk",
    "hygieniskares": "hygienisk",
    "hygieniskas": "hygienisk",
    "hygieniskast": "hygienisk",
    "hygieniskaste": "hygienisk",
    "hygieniskastes": "hygienisk",
    "hygieniskasts": "hygienisk",
    "hygieniske": "hygienisk",
    "hygieniskes": "hygienisk",
    "hygienisks": "hygienisk",
    "hygieniskt": "hygienisk",
    "hygieniskts": "hygienisk",
    "hygienisten": "hygienist",
    "hygienistens": "hygienist",
    "hygienister": "hygienist",
    "hygienisterna": "hygienist",
    "hygienisternas": "hygienist",
    "hygienisters": "hygienist",
    "hygienists": "hygienist",
    "hygienkampanjen": "hygienkampanj",
    "hygienkampanjens": "hygienkampanj",
    "hygienkampanjer": "hygienkampanj",
    "hygienkampanjerna": "hygienkampanj",
    "hygienkampanjernas": "hygienkampanj",
    "hygienkampanjers": "hygienkampanj",
    "hygienkampanjs": "hygienkampanj",
    "hygiens": "hygien",
    "hygrografen": "hygrograf",
    "hygrografens": "hygrograf",
    "hygrografer": "hygrograf",
    "hygrograferna": "hygrograf",
    "hygrografernas": "hygrograf",
    "hygrografers": "hygrograf",
    "hygrografs": "hygrograf",
    "hygrometern": "hygrometer",
    "hygrometerns": "hygrometer",
    "hygrometers": "hygrometer",
    "hygrometrar": "hygrometer",
    "hygrometrarna": "hygrometer",
    "hygrometrarnas": "hygrometer",
    "hygrometrars": "hygrometer",
    "hygroskopiska": "hygroskopisk",
    "hygroskopiskare": "hygroskopisk",
    "hygroskopiskares": "hygroskopisk",
    "hygroskopiskas": "hygroskopisk",
    "hygroskopiskast": "hygroskopisk",
    "hygroskopiskaste": "hygroskopisk",
    "hygroskopiskastes": "hygroskopisk",
    "hygroskopiskasts": "hygroskopisk",
    "hygroskopiske": "hygroskopisk",
    "hygroskopiskes": "hygroskopisk",
    "hygroskopisks": "hygroskopisk",
    "hygroskopiskt": "hygroskopisk",
    "hygroskopiskts": "hygroskopisk",
    "hyl": "hyla",
    "hylade": "hyla",
    "hylades": "hyla",
    "hylande": "hyla",
    "hylanden": "hylande",
    "hylandena": "hylande",
    "hylandenas": "hylande",
    "hylandens": "hylande",
    "hylandes": "hylande",
    "hylandet": "hylande",
    "hylandets": "hylande",
    "hylar": "hyla",
    "hylas": "hyla",
    "hylat": "hyla",
    "hylats": "hyla",
    "hyll": "hylla",
    "hyllad": "hylla",
    "hyllade": "hylla",
    "hyllades": "hylla",
    "hyllads": "hylla",
    "hyllan": "hylla",
    "hyllande": "hylla",
    "hyllanden": "hyllande",
    "hyllandena": "hyllande",
    "hyllandenas": "hyllande",
    "hyllandens": "hyllande",
    "hyllandes": "hyllande",
    "hyllandet": "hyllande",
    "hyllandets": "hyllande",
    "hyllans": "hylla",
    "hyllar": "hylla",
    "hyllas": "hylla",
    "hyllat": "hylla",
    "hyllats": "hylla",
    "hylle": "hylla",
    "hyllen": "hylle",
    "hyllena": "hylle",
    "hyllenas": "hylle",
    "hyllens": "hylle",
    "hylles": "hylle",
    "hyllet": "hylle",
    "hyllets": "hylle",
    "hyllformade": "hyllformad",
    "hyllformades": "hyllformad",
    "hyllformads": "hyllformad",
    "hyllformat": "hyllformad",
    "hyllformats": "hyllformad",
    "hyllmetern": "hyllmeter",
    "hyllmeterna": "hyllmeter",
    "hyllmeternas": "hyllmeter",
    "hyllmeterns": "hyllmeter",
    "hyllmeters": "hyllmeter",
    "hyllmetrar": "hyllmeter",
    "hyllmetrarna": "hyllmeter",
    "hyllmetrarnas": "hyllmeter",
    "hyllmetrars": "hyllmeter",
    "hyllningar": "hyllning",
    "hyllningarna": "hyllning",
    "hyllningarnas": "hyllning",
    "hyllningars": "hyllning",
    "hyllningen": "hyllning",
    "hyllningens": "hyllning",
    "hyllnings": "hyllning",
    "hyllningsdikten": "hyllningsdikt",
    "hyllningsdiktens": "hyllningsdikt",
    "hyllningsdikter": "hyllningsdikt",
    "hyllningsdikterna": "hyllningsdikt",
    "hyllningsdikternas": "hyllningsdikt",
    "hyllningsdikters": "hyllningsdikt",
    "hyllningsdikts": "hyllningsdikt",
    "hyllningssången": "hyllningssång",
    "hyllningssångens": "hyllningssång",
    "hyllningssånger": "hyllningssång",
    "hyllningssångerna": "hyllningssång",
    "hyllningssångernas": "hyllningssång",
    "hyllningssångers": "hyllningssång",
    "hyllningssångs": "hyllningssång",
    "hyllor": "hylla",
    "hyllorna": "hylla",
    "hyllornas": "hylla",
    "hyllors": "hylla",
    "hylls": "hylle",
    "hyls": "hylsa",
    "hylsan": "hylsa",
    "hylsans": "hylsa",
    "hylsas": "hylsa",
    "hylse": "hylsa",
    "hylsformade": "hylsformad",
    "hylsformades": "hylsformad",
    "hylsformads": "hylsformad",
    "hylsformat": "hylsformad",
    "hylsformats": "hylsformad",
    "hylsnyckeln": "hylsnyckel",
    "hylsnyckelns": "hylsnyckel",
    "hylsnyckels": "hylsnyckel",
    "hylsnyckelsatsen": "hylsnyckelsats",
    "hylsnyckelsatsens": "hylsnyckelsats",
    "hylsnyckelsatser": "hylsnyckelsats",
    "hylsnyckelsatserna": "hylsnyckelsats",
    "hylsnyckelsatsernas": "hylsnyckelsats",
    "hylsnyckelsatsers": "hylsnyckelsats",
    "hylsnycklar": "hylsnyckel",
    "hylsnycklarna": "hylsnyckel",
    "hylsnycklarnas": "hylsnyckel",
    "hylsnycklars": "hylsnyckel",
    "hylsor": "hylsa",
    "hylsorna": "hylsa",
    "hylsornas": "hylsa",
    "hylsors": "hylsa",
    "hylssatsen": "hylssats",
    "hylssatsens": "hylssats",
    "hylssatser": "hylssats",
    "hylssatserna": "hylssats",
    "hylssatsernas": "hylssats",
    "hylssatsers": "hylssats",
    "hymens": "hymen",
    "hymlade": "hymla",
    "hymlades": "hymla",
    "hymlande": "hymla",
    "hymlanden": "hymlande",
    "hymlandena": "hymlande",
    "hymlandenas": "hymlande",
    "hymlandens": "hymlande",
    "hymlandes": "hymlande",
    "hymlandet": "hymlande",
    "hymlandets": "hymlande",
    "hymlar": "hymla",
    "hymlas": "hymla",
    "hymlat": "hymla",
    "hymlats": "hymla",
    "hymnen": "hymn",
    "hymnens": "hymn",
    "hymner": "hymn",
    "hymnerna": "hymn",
    "hymnernas": "hymn",
    "hymners": "hymn",
    "hymnologien": "hymnologi",
    "hymnologiens": "hymnologi",
    "hymnologin": "hymnologi",
    "hymnologins": "hymnologi",
    "hymnologis": "hymnologi",
    "hymns": "hymn",
    "hyn": "hy",
    "hynd": "hynda",
    "hyndan": "hynda",
    "hyndans": "hynda",
    "hyndas": "hynda",
    "hynde": "hynda",
    "hyndor": "hynda",
    "hyndorna": "hynda",
    "hyndornas": "hynda",
    "hyndors": "hynda",
    "hynds": "hynda",
    "hyns": "hy",
    "hyperaktiva": "hyperaktiv",
    "hyperaktivare": "hyperaktiv",
    "hyperaktivares": "hyperaktiv",
    "hyperaktivas": "hyperaktiv",
    "hyperaktivast": "hyperaktiv",
    "hyperaktivaste": "hyperaktiv",
    "hyperaktivastes": "hyperaktiv",
    "hyperaktivasts": "hyperaktiv",
    "hyperaktive": "hyperaktiv",
    "hyperaktives": "hyperaktiv",
    "hyperaktivs": "hyperaktiv",
    "hyperaktivt": "hyperaktiv",
    "hyperaktivts": "hyperaktiv",
    "hyperbeln": "hyperbel",
    "hyperbelns": "hyperbel",
    "hyperbels": "hyperbel",
    "hyperbler": "hyperbel",
    "hyperblerna": "hyperbel",
    "hyperblernas": "hyperbel",
    "hyperblers": "hyperbel",
    "hyperbolen": "hyperbol",
    "hyperbolens": "hyperbol",
    "hyperboler": "hyperbol",
    "hyperbolerna": "hyperbol",
    "hyperbolernas": "hyperbol",
    "hyperbolers": "hyperbol",
    "hyperboliska": "hyperbolisk",
    "hyperboliskare": "hyperbolisk",
    "hyperboliskares": "hyperbolisk",
    "hyperboliskas": "hyperbolisk",
    "hyperboliskast": "hyperbolisk",
    "hyperboliskaste": "hyperbolisk",
    "hyperboliskastes": "hyperbolisk",
    "hyperboliskasts": "hyperbolisk",
    "hyperboliske": "hyperbolisk",
    "hyperboliskes": "hyperbolisk",
    "hyperbolisks": "hyperbolisk",
    "hyperboliskt": "hyperbolisk",
    "hyperboliskts": "hyperbolisk",
    "hyperbols": "hyperbol",
    "hyperboréen": "hyperboré",
    "hyperboréens": "hyperboré",
    "hyperboréer": "hyperboré",
    "hyperboréerna": "hyperboré",
    "hyperboréernas": "hyperboré",
    "hyperboréers": "hyperboré",
    "hyperborén": "hyperboré",
    "hyperboréns": "hyperboré",
    "hyperborés": "hyperboré",
    "hypereleganta": "hyperelegant",
    "hyperelegantare": "hyperelegant",
    "hyperelegantares": "hyperelegant",
    "hyperelegantas": "hyperelegant",
    "hyperelegantast": "hyperelegant",
    "hyperelegantaste": "hyperelegant",
    "hyperelegantastes": "hyperelegant",
    "hyperelegantasts": "hyperelegant",
    "hyperelegante": "hyperelegant",
    "hyperelegantes": "hyperelegant",
    "hyperelegants": "hyperelegant",
    "hyperiten": "hyperit",
    "hyperitens": "hyperit",
    "hyperiter": "hyperit",
    "hyperiterna": "hyperit",
    "hyperiternas": "hyperit",
    "hyperiters": "hyperit",
    "hyperits": "hyperit",
    "hyperkatalektiska": "hyperkatalektisk",
    "hyperkatalektiskare": "hyperkatalektisk",
    "hyperkatalektiskares": "hyperkatalektisk",
    "hyperkatalektiskas": "hyperkatalektisk",
    "hyperkatalektiskast": "hyperkatalektisk",
    "hyperkatalektiskaste": "hyperkatalektisk",
    "hyperkatalektiskastes": "hyperkatalektisk",
    "hyperkatalektiskasts": "hyperkatalektisk",
    "hyperkatalektiske": "hyperkatalektisk",
    "hyperkatalektiskes": "hyperkatalektisk",
    "hyperkatalektisks": "hyperkatalektisk",
    "hyperkatalektiskt": "hyperkatalektisk",
    "hyperkatalektiskts": "hyperkatalektisk",
    "hyperkorrekta": "hyperkorrekt",
    "hyperkorrektare": "hyperkorrekt",
    "hyperkorrektares": "hyperkorrekt",
    "hyperkorrektas": "hyperkorrekt",
    "hyperkorrektast": "hyperkorrekt",
    "hyperkorrektaste": "hyperkorrekt",
    "hyperkorrektastes": "hyperkorrekt",
    "hyperkorrektasts": "hyperkorrekt",
    "hyperkorrekte": "hyperkorrekt",
    "hyperkorrektes": "hyperkorrekt",
    "hyperkorrektheten": "hyperkorrekthet",
    "hyperkorrekthetens": "hyperkorrekthet",
    "hyperkorrekthets": "hyperkorrekthet",
    "hyperkorrekts": "hyperkorrekt",
    "hyperkänsliga": "hyperkänslig",
    "hyperkänsligare": "hyperkänslig",
    "hyperkänsligares": "hyperkänslig",
    "hyperkänsligas": "hyperkänslig",
    "hyperkänsligast": "hyperkänslig",
    "hyperkänsligaste": "hyperkänslig",
    "hyperkänsligastes": "hyperkänslig",
    "hyperkänsligasts": "hyperkänslig",
    "hyperkänslige": "hyperkänslig",
    "hyperkänsliges": "hyperkänslig",
    "hyperkänsligheten": "hyperkänslighet",
    "hyperkänslighetens": "hyperkänslighet",
    "hyperkänslighets": "hyperkänslighet",
    "hyperkänsligs": "hyperkänslig",
    "hyperkänsligt": "hyperkänslig",
    "hyperkänsligts": "hyperkänslig",
    "hyperlänkar": "hyperlänk",
    "hyperlänkarna": "hyperlänk",
    "hyperlänkarnas": "hyperlänk",
    "hyperlänkars": "hyperlänk",
    "hyperlänken": "hyperlänk",
    "hyperlänkens": "hyperlänk",
    "hyperlänks": "hyperlänk",
    "hypermoderna": "hypermodern",
    "hypermodernare": "hypermodern",
    "hypermodernares": "hypermodern",
    "hypermodernas": "hypermodern",
    "hypermodernast": "hypermodern",
    "hypermodernaste": "hypermodern",
    "hypermodernastes": "hypermodern",
    "hypermodernasts": "hypermodern",
    "hypermoderne": "hypermodern",
    "hypermodernes": "hypermodern",
    "hypermodernheten": "hypermodernhet",
    "hypermodernhetens": "hypermodernhet",
    "hypermodernhets": "hypermodernhet",
    "hypermoderns": "hypermodern",
    "hypermodernt": "hypermodern",
    "hypermodernts": "hypermodern",
    "hypernymen": "hypernym",
    "hypernymens": "hypernym",
    "hypernymer": "hypernym",
    "hypernymerna": "hypernym",
    "hypernymernas": "hypernym",
    "hypernymers": "hypernym",
    "hypernymien": "hypernymi",
    "hypernymiens": "hypernymi",
    "hypernymier": "hypernymi",
    "hypernymierna": "hypernymi",
    "hypernymiernas": "hypernymi",
    "hypernymiers": "hypernymi",
    "hypernymin": "hypernymi",
    "hypernymins": "hypernymi",
    "hypernymis": "hypernymi",
    "hypernyms": "hypernym",
    "hyperonymen": "hyperonym",
    "hyperonymens": "hyperonym",
    "hyperonymer": "hyperonym",
    "hyperonymerna": "hyperonym",
    "hyperonymernas": "hyperonym",
    "hyperonymers": "hyperonym",
    "hyperonymien": "hyperonymi",
    "hyperonymiens": "hyperonymi",
    "hyperonymier": "hyperonymi",
    "hyperonymierna": "hyperonymi",
    "hyperonymiernas": "hyperonymi",
    "hyperonymiers": "hyperonymi",
    "hyperonymin": "hyperonymi",
    "hyperonymins": "hyperonymi",
    "hyperonymis": "hyperonymi",
    "hyperonyms": "hyperonym",
    "hyperstenen": "hypersten",
    "hyperstenens": "hypersten",
    "hyperstens": "hypersten",
    "hypersvecismen": "hypersvecism",
    "hypersvecismens": "hypersvecism",
    "hypersvecismer": "hypersvecism",
    "hypersvecismerna": "hypersvecism",
    "hypersvecismernas": "hypersvecism",
    "hypersvecismers": "hypersvecism",
    "hypersvecisms": "hypersvecism",
    "hypertexten": "hypertext",
    "hypertextens": "hypertext",
    "hypertexter": "hypertext",
    "hypertexterna": "hypertext",
    "hypertexternas": "hypertext",
    "hypertexters": "hypertext",
    "hypertexts": "hypertext",
    "hypertonien": "hypertoni",
    "hypertoniens": "hypertoni",
    "hypertonin": "hypertoni",
    "hypertonins": "hypertoni",
    "hypertonis": "hypertoni",
    "hypertrofien": "hypertrofi",
    "hypertrofiens": "hypertrofi",
    "hypertrofier": "hypertrofi",
    "hypertrofierna": "hypertrofi",
    "hypertrofiernas": "hypertrofi",
    "hypertrofiers": "hypertrofi",
    "hypertrofin": "hypertrofi",
    "hypertrofins": "hypertrofi",
    "hypertrofis": "hypertrofi",
    "hypnosen": "hypnos",
    "hypnosens": "hypnos",
    "hypnoser": "hypnos",
    "hypnoserna": "hypnos",
    "hypnosernas": "hypnos",
    "hypnosers": "hypnos",
    "hypnoskursen": "hypnoskurs",
    "hypnoskursens": "hypnoskurs",
    "hypnoskurser": "hypnoskurs",
    "hypnoskurserna": "hypnoskurs",
    "hypnoskursernas": "hypnoskurs",
    "hypnoskursers": "hypnoskurs",
    "hypnotiserad": "hypnotisera",
    "hypnotiserade": "hypnotisera",
    "hypnotiserades": "hypnotisera",
    "hypnotiserads": "hypnotisera",
    "hypnotiserande": "hypnotisera",
    "hypnotiseranden": "hypnotiserande",
    "hypnotiserandena": "hypnotiserande",
    "hypnotiserandenas": "hypnotiserande",
    "hypnotiserandens": "hypnotiserande",
    "hypnotiserandes": "hypnotiserande",
    "hypnotiserandet": "hypnotiserande",
    "hypnotiserandets": "hypnotiserande",
    "hypnotiserar": "hypnotisera",
    "hypnotiseras": "hypnotisera",
    "hypnotiserat": "hypnotisera",
    "hypnotiserats": "hypnotisera",
    "hypnotiserbara": "hypnotiserbar",
    "hypnotiserbarare": "hypnotiserbar",
    "hypnotiserbarares": "hypnotiserbar",
    "hypnotiserbaras": "hypnotiserbar",
    "hypnotiserbarast": "hypnotiserbar",
    "hypnotiserbaraste": "hypnotiserbar",
    "hypnotiserbarastes": "hypnotiserbar",
    "hypnotiserbarasts": "hypnotiserbar",
    "hypnotiserbare": "hypnotiserbar",
    "hypnotiserbares": "hypnotiserbar",
    "hypnotiserbarheten": "hypnotiserbarhet",
    "hypnotiserbarhetens": "hypnotiserbarhet",
    "hypnotiserbarhets": "hypnotiserbarhet",
    "hypnotiserbars": "hypnotiserbar",
    "hypnotiserbart": "hypnotiserbar",
    "hypnotiserbarts": "hypnotiserbar",
    "hypnotiseringar": "hypnotisering",
    "hypnotiseringarna": "hypnotisering",
    "hypnotiseringarnas": "hypnotisering",
    "hypnotiseringars": "hypnotisering",
    "hypnotiseringen": "hypnotisering",
    "hypnotiseringens": "hypnotisering",
    "hypnotiserings": "hypnotisering",
    "hypnotiska": "hypnotisk",
    "hypnotiskare": "hypnotisk",
    "hypnotiskares": "hypnotisk",
    "hypnotiskas": "hypnotisk",
    "hypnotiskast": "hypnotisk",
    "hypnotiskaste": "hypnotisk",
    "hypnotiskastes": "hypnotisk",
    "hypnotiskasts": "hypnotisk",
    "hypnotiske": "hypnotisk",
    "hypnotiskes": "hypnotisk",
    "hypnotisks": "hypnotisk",
    "hypnotiskt": "hypnotisk",
    "hypnotiskts": "hypnotisk",
    "hypnotismen": "hypnotism",
    "hypnotismens": "hypnotism",
    "hypnotismer": "hypnotism",
    "hypnotismerna": "hypnotism",
    "hypnotismernas": "hypnotism",
    "hypnotismers": "hypnotism",
    "hypnotisms": "hypnotism",
    "hypnotisören": "hypnotisör",
    "hypnotisörens": "hypnotisör",
    "hypnotisörer": "hypnotisör",
    "hypnotisörerna": "hypnotisör",
    "hypnotisörernas": "hypnotisör",
    "hypnotisörers": "hypnotisör",
    "hypnotisörs": "hypnotisör",
    "hypofysen": "hypofys",
    "hypofysens": "hypofys",
    "hypofyser": "hypofys",
    "hypofyserna": "hypofys",
    "hypofysernas": "hypofys",
    "hypofysers": "hypofys",
    "hypofyshormonen": "hypofyshormon",
    "hypofyshormonens": "hypofyshormon",
    "hypofyshormoner": "hypofyshormon",
    "hypofyshormonerna": "hypofyshormon",
    "hypofyshormonernas": "hypofyshormon",
    "hypofyshormoners": "hypofyshormon",
    "hypofyshormonet": "hypofyshormon",
    "hypofyshormonets": "hypofyshormon",
    "hypofyshormons": "hypofyshormon",
    "hypokondern": "hypokonder",
    "hypokonderns": "hypokonder",
    "hypokonders": "hypokonder",
    "hypokondrer": "hypokonder",
    "hypokondrerna": "hypokonder",
    "hypokondrernas": "hypokonder",
    "hypokondrers": "hypokonder",
    "hypokondrien": "hypokondri",
    "hypokondriens": "hypokondri",
    "hypokondrier": "hypokondri",
    "hypokondrierna": "hypokondri",
    "hypokondriernas": "hypokondri",
    "hypokondriers": "hypokondri",
    "hypokondrikern": "hypokondriker",
    "hypokondrikerna": "hypokondriker",
    "hypokondrikernas": "hypokondriker",
    "hypokondrikerns": "hypokondriker",
    "hypokondrikers": "hypokondriker",
    "hypokondrin": "hypokondri",
    "hypokondrins": "hypokondri",
    "hypokondris": "hypokondri",
    "hypokondriska": "hypokondrisk",
    "hypokondriskare": "hypokondrisk",
    "hypokondriskares": "hypokondrisk",
    "hypokondriskas": "hypokondrisk",
    "hypokondriskast": "hypokondrisk",
    "hypokondriskaste": "hypokondrisk",
    "hypokondriskastes": "hypokondrisk",
    "hypokondriskasts": "hypokondrisk",
    "hypokondriske": "hypokondrisk",
    "hypokondriskes": "hypokondrisk",
    "hypokondrisks": "hypokondrisk",
    "hypokondriskt": "hypokondrisk",
    "hypokondriskts": "hypokondrisk",
    "hypokriten": "hypokrit",
    "hypokritens": "hypokrit",
    "hypokriter": "hypokrit",
    "hypokriterna": "hypokrit",
    "hypokriternas": "hypokrit",
    "hypokriters": "hypokrit",
    "hypokritiska": "hypokritisk",
    "hypokritiskare": "hypokritisk",
    "hypokritiskares": "hypokritisk",
    "hypokritiskas": "hypokritisk",
    "hypokritiskast": "hypokritisk",
    "hypokritiskaste": "hypokritisk",
    "hypokritiskastes": "hypokritisk",
    "hypokritiskasts": "hypokritisk",
    "hypokritiske": "hypokritisk",
    "hypokritiskes": "hypokritisk",
    "hypokritisks": "hypokritisk",
    "hypokritiskt": "hypokritisk",
    "hypokritiskts": "hypokritisk",
    "hypokrits": "hypokrit",
    "hypomanien": "hypomani",
    "hypomaniens": "hypomani",
    "hypomanier": "hypomani",
    "hypomanierna": "hypomani",
    "hypomaniernas": "hypomani",
    "hypomaniers": "hypomani",
    "hypomanin": "hypomani",
    "hypomanins": "hypomani",
    "hypomanis": "hypomani",
    "hypomaniska": "hypomanisk",
    "hypomaniskare": "hypomanisk",
    "hypomaniskares": "hypomanisk",
    "hypomaniskas": "hypomanisk",
    "hypomaniskast": "hypomanisk",
    "hypomaniskaste": "hypomanisk",
    "hypomaniskastes": "hypomanisk",
    "hypomaniskasts": "hypomanisk",
    "hypomaniske": "hypomanisk",
    "hypomaniskes": "hypomanisk",
    "hypomanisks": "hypomanisk",
    "hypomaniskt": "hypomanisk",
    "hypomaniskts": "hypomanisk",
    "hyponymen": "hyponym",
    "hyponymens": "hyponym",
    "hyponymer": "hyponym",
    "hyponymerna": "hyponym",
    "hyponymernas": "hyponym",
    "hyponymers": "hyponym",
    "hyponymien": "hyponymi",
    "hyponymiens": "hyponymi",
    "hyponymier": "hyponymi",
    "hyponymierna": "hyponymi",
    "hyponymiernas": "hyponymi",
    "hyponymiers": "hyponymi",
    "hyponymin": "hyponymi",
    "hyponymins": "hyponymi",
    "hyponymis": "hyponymi",
    "hyponyms": "hyponym",
    "hypotaktiska": "hypotaktisk",
    "hypotaktiskare": "hypotaktisk",
    "hypotaktiskares": "hypotaktisk",
    "hypotaktiskas": "hypotaktisk",
    "hypotaktiskast": "hypotaktisk",
    "hypotaktiskaste": "hypotaktisk",
    "hypotaktiskastes": "hypotaktisk",
    "hypotaktiskasts": "hypotaktisk",
    "hypotaktiske": "hypotaktisk",
    "hypotaktiskes": "hypotaktisk",
    "hypotaktisks": "hypotaktisk",
    "hypotaktiskt": "hypotaktisk",
    "hypotaktiskts": "hypotaktisk",
    "hypotalamusen": "hypotalamus",
    "hypotalamusens": "hypotalamus",
    "hypotaxen": "hypotax",
    "hypotaxens": "hypotax",
    "hypoteken": "hypotek",
    "hypotekens": "hypotek",
    "hypoteket": "hypotek",
    "hypotekets": "hypotek",
    "hypoteks": "hypotek",
    "hypotekslånen": "hypotekslån",
    "hypotekslånens": "hypotekslån",
    "hypotekslånet": "hypotekslån",
    "hypotekslånets": "hypotekslån",
    "hypotekslåns": "hypotekslån",
    "hypotenus": "hypotenusa",
    "hypotenusan": "hypotenusa",
    "hypotenusans": "hypotenusa",
    "hypotenusas": "hypotenusa",
    "hypotenuse": "hypotenusa",
    "hypotenusor": "hypotenusa",
    "hypotenusorna": "hypotenusa",
    "hypotenusornas": "hypotenusa",
    "hypotenusors": "hypotenusa",
    "hypotesen": "hypotes",
    "hypotesens": "hypotes",
    "hypoteser": "hypotes",
    "hypoteserna": "hypotes",
    "hypotesernas": "hypotes",
    "hypotesers": "hypotes",
    "hypotetiska": "hypotetisk",
    "hypotetiskare": "hypotetisk",
    "hypotetiskares": "hypotetisk",
    "hypotetiskas": "hypotetisk",
    "hypotetiskast": "hypotetisk",
    "hypotetiskaste": "hypotetisk",
    "hypotetiskastes": "hypotetisk",
    "hypotetiskasts": "hypotetisk",
    "hypotetiske": "hypotetisk",
    "hypotetiskes": "hypotetisk",
    "hypotetisks": "hypotetisk",
    "hypotetiskt": "hypotetisk",
    "hypotetiskts": "hypotetisk",
    "hypotiserad": "hypotisera",
    "hypotiserade": "hypotisera",
    "hypotiserades": "hypotisera",
    "hypotiserads": "hypotisera",
    "hypotiserande": "hypotisera",
    "hypotiseranden": "hypotiserande",
    "hypotiserandena": "hypotiserande",
    "hypotiserandenas": "hypotiserande",
    "hypotiserandens": "hypotiserande",
    "hypotiserandes": "hypotiserande",
    "hypotiserandet": "hypotiserande",
    "hypotiserandets": "hypotiserande",
    "hypotiserar": "hypotisera",
    "hypotiseras": "hypotisera",
    "hypotiserat": "hypotisera",
    "hypotiserats": "hypotisera",
    "hypotiserbara": "hypotiserbar",
    "hypotiserbarare": "hypotiserbar",
    "hypotiserbarares": "hypotiserbar",
    "hypotiserbaras": "hypotiserbar",
    "hypotiserbarast": "hypotiserbar",
    "hypotiserbaraste": "hypotiserbar",
    "hypotiserbarastes": "hypotiserbar",
    "hypotiserbarasts": "hypotiserbar",
    "hypotiserbare": "hypotiserbar",
    "hypotiserbares": "hypotiserbar",
    "hypotiserbarheten": "hypotiserbarhet",
    "hypotiserbarhetens": "hypotiserbarhet",
    "hypotiserbarhets": "hypotiserbarhet",
    "hypotiserbars": "hypotiserbar",
    "hypotiserbart": "hypotiserbar",
    "hypotiserbarts": "hypotiserbar",
    "hypotiseringar": "hypotisering",
    "hypotiseringarna": "hypotisering",
    "hypotiseringarnas": "hypotisering",
    "hypotiseringars": "hypotisering",
    "hypotiseringen": "hypotisering",
    "hypotiseringens": "hypotisering",
    "hypotiserings": "hypotisering",
    "hypsometern": "hypsometer",
    "hypsometerns": "hypsometer",
    "hypsometers": "hypsometer",
    "hypsometrar": "hypsometer",
    "hypsometrarna": "hypsometer",
    "hypsometrarnas": "hypsometer",
    "hypsometrars": "hypsometer",
    "hyr": "hyra",
    "hyran": "hyra",
    "hyrande": "hyra",
    "hyranden": "hyrande",
    "hyrandena": "hyrande",
    "hyrandenas": "hyrande",
    "hyrandens": "hyrande",
    "hyrandes": "hyrande",
    "hyrandet": "hyrande",
    "hyrandets": "hyrande",
    "hyrans": "hyra",
    "hyras": "hyra",
    "hyrd": "hyra",
    "hyrda": "hyra",
    "hyrdas": "hyra",
    "hyrde": "hyra",
    "hyrdes": "hyra",
    "hyrds": "hyra",
    "hyre": "hyra",
    "hyres": "hyra",
    "hyresbostaden": "hyresbostad",
    "hyresbostadens": "hyresbostad",
    "hyresbostads": "hyresbostad",
    "hyresbostan": "hyresbostad",
    "hyresbostans": "hyresbostad",
    "hyresbostäder": "hyresbostad",
    "hyresbostäderna": "hyresbostad",
    "hyresbostädernas": "hyresbostad",
    "hyresbostäders": "hyresbostad",
    "hyresgästen": "hyresgäst",
    "hyresgästens": "hyresgäst",
    "hyresgäster": "hyresgäst",
    "hyresgästerna": "hyresgäst",
    "hyresgästernas": "hyresgäst",
    "hyresgästers": "hyresgäst",
    "hyresgästs": "hyresgäst",
    "hyreshajar": "hyreshaj",
    "hyreshajarna": "hyreshaj",
    "hyreshajarnas": "hyreshaj",
    "hyreshajars": "hyreshaj",
    "hyreshajen": "hyreshaj",
    "hyreshajens": "hyreshaj",
    "hyreshajs": "hyreshaj",
    "hyreshusen": "hyreshus",
    "hyreshusens": "hyreshus",
    "hyreshuset": "hyreshus",
    "hyreshusets": "hyreshus",
    "hyreskasernen": "hyreskasern",
    "hyreskasernens": "hyreskasern",
    "hyreskaserner": "hyreskasern",
    "hyreskasernerna": "hyreskasern",
    "hyreskasernernas": "hyreskasern",
    "hyreskaserners": "hyreskasern",
    "hyreskaserns": "hyreskasern",
    "hyreskontrakten": "hyreskontrakt",
    "hyreskontraktens": "hyreskontrakt",
    "hyreskontraktet": "hyreskontrakt",
    "hyreskontraktets": "hyreskontrakt",
    "hyreskontrakts": "hyreskontrakt",
    "hyreslägenheten": "hyreslägenhet",
    "hyreslägenhetens": "hyreslägenhet",
    "hyreslägenheter": "hyreslägenhet",
    "hyreslägenheterna": "hyreslägenhet",
    "hyreslägenheternas": "hyreslägenhet",
    "hyreslägenheters": "hyreslägenhet",
    "hyreslägenhets": "hyreslägenhet",
    "hyresnämnden": "hyresnämnd",
    "hyresnämndens": "hyresnämnd",
    "hyresnämnder": "hyresnämnd",
    "hyresnämnderna": "hyresnämnd",
    "hyresnämndernas": "hyresnämnd",
    "hyresnämnders": "hyresnämnd",
    "hyresnämnds": "hyresnämnd",
    "hyresreglerad": "hyresreglera",
    "hyresreglerade": "hyresreglera",
    "hyresreglerades": "hyresreglera",
    "hyresreglerads": "hyresreglera",
    "hyresreglerande": "hyresreglera",
    "hyresregleranden": "hyresreglerande",
    "hyresreglerandena": "hyresreglerande",
    "hyresreglerandenas": "hyresreglerande",
    "hyresreglerandens": "hyresreglerande",
    "hyresreglerandes": "hyresreglerande",
    "hyresreglerandet": "hyresreglerande",
    "hyresreglerandets": "hyresreglerande",
    "hyresreglerar": "hyresreglera",
    "hyresregleras": "hyresreglera",
    "hyresreglerat": "hyresreglera",
    "hyresreglerats": "hyresreglera",
    "hyresregleringar": "hyresreglering",
    "hyresregleringarna": "hyresreglering",
    "hyresregleringarnas": "hyresreglering",
    "hyresregleringars": "hyresreglering",
    "hyresregleringen": "hyresreglering",
    "hyresregleringens": "hyresreglering",
    "hyresreglerings": "hyresreglering",
    "hyresstrejken": "hyresstrejk",
    "hyresstrejkens": "hyresstrejk",
    "hyresstrejker": "hyresstrejk",
    "hyresstrejkerna": "hyresstrejk",
    "hyresstrejkernas": "hyresstrejk",
    "hyresstrejkers": "hyresstrejk",
    "hyresstrejks": "hyresstrejk",
    "hyrestilläggen": "hyrestillägg",
    "hyrestilläggens": "hyrestillägg",
    "hyrestillägget": "hyrestillägg",
    "hyrestilläggets": "hyrestillägg",
    "hyrestilläggs": "hyrestillägg",
    "hyrestvisten": "hyrestvist",
    "hyrestvistens": "hyrestvist",
    "hyrestvister": "hyrestvist",
    "hyrestvisterna": "hyrestvist",
    "hyrestvisternas": "hyrestvist",
    "hyrestvisters": "hyrestvist",
    "hyrestvists": "hyrestvist",
    "hyresvärdar": "hyresvärd",
    "hyresvärdarna": "hyresvärd",
    "hyresvärdarnas": "hyresvärd",
    "hyresvärdars": "hyresvärd",
    "hyresvärden": "hyresvärd",
    "hyresvärdens": "hyresvärd",
    "hyresvärds": "hyresvärd",
    "hyrläkar": "hyrläkare",
    "hyrläkaren": "hyrläkare",
    "hyrläkarens": "hyrläkare",
    "hyrläkares": "hyrläkare",
    "hyrläkarna": "hyrläkare",
    "hyrläkarnas": "hyrläkare",
    "hyror": "hyra",
    "hyrorna": "hyra",
    "hyrornas": "hyra",
    "hyrors": "hyra",
    "hyrs": "hyra",
    "hyrt": "hyra",
    "hyrts": "hyra",
    "hys": "hysa",
    "hysande": "hysa",
    "hysanden": "hysande",
    "hysandena": "hysande",
    "hysandenas": "hysande",
    "hysandens": "hysande",
    "hysandes": "hysande",
    "hysandet": "hysande",
    "hysandets": "hysande",
    "hysas": "hysa",
    "hysbara": "hysbar",
    "hysbarare": "hysbar",
    "hysbarares": "hysbar",
    "hysbaras": "hysbar",
    "hysbarast": "hysbar",
    "hysbaraste": "hysbar",
    "hysbarastes": "hysbar",
    "hysbarasts": "hysbar",
    "hysbare": "hysbar",
    "hysbares": "hysbar",
    "hysbarheten": "hysbarhet",
    "hysbarhetens": "hysbarhet",
    "hysbarhets": "hysbarhet",
    "hysbars": "hysbar",
    "hysbart": "hysbar",
    "hysbarts": "hysbar",
    "hysch-hyschet": "hysch-hysch",
    "hysch-hyschets": "hysch-hysch",
    "hysch-hyschs": "hysch-hysch",
    "hyser": "hysa",
    "hyses": "hysa",
    "hysk": "hyska",
    "hyskan": "hyska",
    "hyskans": "hyska",
    "hyskas": "hyska",
    "hyske": "hyska",
    "hyskor": "hyska",
    "hyskorna": "hyska",
    "hyskornas": "hyska",
    "hyskors": "hyska",
    "hyssen": "hyss",
    "hyssens": "hyss",
    "hysset": "hyss",
    "hyssets": "hyss",
    "hyssj": "hyssja",
    "hyssjad": "hyssja",
    "hyssjade": "hyssja",
    "hyssjades": "hyssja",
    "hyssjads": "hyssja",
    "hyssjande": "hyssja",
    "hyssjanden": "hyssjande",
    "hyssjandena": "hyssjande",
    "hyssjandenas": "hyssjande",
    "hyssjandens": "hyssjande",
    "hyssjandes": "hyssjande",
    "hyssjandet": "hyssjande",
    "hyssjandets": "hyssjande",
    "hyssjar": "hyssja",
    "hyssjas": "hyssja",
    "hyssjat": "hyssja",
    "hyssjats": "hyssja",
    "hyst": "hysta",
    "hysta": "hysa",
    "hystad": "hysta",
    "hystade": "hysta",
    "hystades": "hysta",
    "hystads": "hysta",
    "hystande": "hysta",
    "hystanden": "hystande",
    "hystandena": "hystande",
    "hystandenas": "hystande",
    "hystandens": "hystande",
    "hystandes": "hystande",
    "hystandet": "hystande",
    "hystandets": "hystande",
    "hystar": "hysta",
    "hystas": "hysta",
    "hystat": "hysta",
    "hystats": "hysta",
    "hyste": "hysa",
    "hysterien": "hysteri",
    "hysteriens": "hysteri",
    "hysteriet": "hysteri",
    "hysteriets": "hysteri",
    "hysterik": "hysterika",
    "hysterikan": "hysterika",
    "hysterikans": "hysterika",
    "hysterikas": "hysterika",
    "hysterike": "hysterika",
    "hysterikern": "hysteriker",
    "hysterikerna": "hysteriker",
    "hysterikernas": "hysteriker",
    "hysterikerns": "hysteriker",
    "hysterikers": "hysteriker",
    "hysterikor": "hysterika",
    "hysterikorna": "hysterika",
    "hysterikornas": "hysterika",
    "hysterikors": "hysterika",
    "hysteriks": "hysterika",
    "hysterin": "hysteri",
    "hysterins": "hysteri",
    "hysteris": "hysteri",
    "hysteriska": "hysterisk",
    "hysteriskare": "hysterisk",
    "hysteriskares": "hysterisk",
    "hysteriskas": "hysterisk",
    "hysteriskast": "hysterisk",
    "hysteriskaste": "hysterisk",
    "hysteriskastes": "hysterisk",
    "hysteriskasts": "hysterisk",
    "hysteriske": "hysterisk",
    "hysteriskes": "hysterisk",
    "hysterisks": "hysterisk",
    "hysteriskt": "hysterisk",
    "hysteriskts": "hysterisk",
    "hysterit": "hysteri",
    "hysterits": "hysteri",
    "hystes": "hysa",
    "hysts": "hysa",
    "hytt": "hytta",
    "hyttad": "hytta",
    "hyttade": "hytta",
    "hyttades": "hytta",
    "hyttads": "hytta",
    "hyttan": "hytta",
    "hyttande": "hytta",
    "hyttanden": "hyttande",
    "hyttandena": "hyttande",
    "hyttandenas": "hyttande",
    "hyttandens": "hyttande",
    "hyttandes": "hyttande",
    "hyttandet": "hyttande",
    "hyttandets": "hyttande",
    "hyttans": "hytta",
    "hyttas": "hytta",
    "hyttat": "hytta",
    "hyttats": "hytta",
    "hytte": "hytta",
    "hytten": "hytt",
    "hyttens": "hytt",
    "hytter": "hytta",
    "hytterna": "hytt",
    "hytternas": "hytt",
    "hytters": "hytt",
    "hyttes": "hytta",
    "hyttor": "hytta",
    "hyttorna": "hytta",
    "hyttornas": "hytta",
    "hyttors": "hytta",
    "hytts": "hytta",
    "hyv": "hyva",
    "hyvad": "hyva",
    "hyvade": "hyva",
    "hyvades": "hyva",
    "hyvads": "hyva",
    "hyvande": "hyva",
    "hyvanden": "hyvande",
    "hyvandena": "hyvande",
    "hyvandenas": "hyvande",
    "hyvandens": "hyvande",
    "hyvandes": "hyvande",
    "hyvandet": "hyvande",
    "hyvandets": "hyvande",
    "hyvar": "hyva",
    "hyvas": "hyva",
    "hyvat": "hyva",
    "hyvats": "hyva",
    "hyvel": "hyvla",
    "hyvelbredden": "hyvelbredd",
    "hyvelbreddens": "hyvelbredd",
    "hyvelbredder": "hyvelbredd",
    "hyvelbredderna": "hyvelbredd",
    "hyvelbreddernas": "hyvelbredd",
    "hyvelbredders": "hyvelbredd",
    "hyvelbredds": "hyvelbredd",
    "hyvelbänkar": "hyvelbänk",
    "hyvelbänkarna": "hyvelbänk",
    "hyvelbänkarnas": "hyvelbänk",
    "hyvelbänkars": "hyvelbänk",
    "hyvelbänken": "hyvelbänk",
    "hyvelbänkens": "hyvelbänk",
    "hyvelbänks": "hyvelbänk",
    "hyveljärnen": "hyveljärn",
    "hyveljärnens": "hyveljärn",
    "hyveljärnet": "hyveljärn",
    "hyveljärnets": "hyveljärn",
    "hyveljärns": "hyveljärn",
    "hyveln": "hyvel",
    "hyvelns": "hyvel",
    "hyvels": "hyvel",
    "hyvelspånen": "hyvelspån",
    "hyvelspånens": "hyvelspån",
    "hyvelspånet": "hyvelspån",
    "hyvelspånets": "hyvelspån",
    "hyvelspåns": "hyvelspån",
    "hyvelstålen": "hyvelstål",
    "hyvelstålens": "hyvelstål",
    "hyvelstålet": "hyvelstål",
    "hyvelstålets": "hyvelstål",
    "hyvelståls": "hyvelstål",
    "hyveltandade": "hyveltandad",
    "hyveltandades": "hyveltandad",
    "hyveltandads": "hyveltandad",
    "hyveltandat": "hyveltandad",
    "hyveltandats": "hyveltandad",
    "hyvlad": "hyvla",
    "hyvlade": "hyvla",
    "hyvlades": "hyvla",
    "hyvlads": "hyvla",
    "hyvlande": "hyvla",
    "hyvlanden": "hyvlande",
    "hyvlandena": "hyvlande",
    "hyvlandenas": "hyvlande",
    "hyvlandens": "hyvlande",
    "hyvlandes": "hyvlande",
    "hyvlandet": "hyvlande",
    "hyvlandets": "hyvlande",
    "hyvlar": "hyvla",
    "hyvlarna": "hyvel",
    "hyvlarnas": "hyvel",
    "hyvlars": "hyvel",
    "hyvlas": "hyvla",
    "hyvlat": "hyvla",
    "hyvlats": "hyvla",
    "häckade": "häcka",
    "häckades": "häcka",
    "häckande": "häcka",
    "häckanden": "häckande",
    "häckandena": "häckande",
    "häckandenas": "häckande",
    "häckandens": "häckande",
    "häckandes": "häckande",
    "häckandet": "häckande",
    "häckandets": "häckande",
    "häckar": "häcka",
    "häckarna": "häck",
    "häckarnas": "häck",
    "häckars": "häck",
    "häckas": "häcka",
    "häckat": "häcka",
    "häckats": "häcka",
    "häckel": "häckla",
    "häcken": "häck",
    "häckens": "häck",
    "häckfågeln": "häckfågel",
    "häckfågelns": "häckfågel",
    "häckfågels": "häckfågel",
    "häckfåglar": "häckfågel",
    "häckfåglarna": "häckfågel",
    "häckfåglarnas": "häckfågel",
    "häckfåglars": "häckfågel",
    "häckl": "häckla",
    "häcklad": "häckla",
    "häcklade": "häckla",
    "häcklades": "häckla",
    "häcklads": "häckla",
    "häcklan": "häckla",
    "häcklande": "häckla",
    "häcklanden": "häcklande",
    "häcklandena": "häcklande",
    "häcklandenas": "häcklande",
    "häcklandens": "häcklande",
    "häcklandes": "häcklande",
    "häcklandet": "häcklande",
    "häcklandets": "häcklande",
    "häcklans": "häckla",
    "häcklar": "häcklare",
    "häcklaren": "häcklare",
    "häcklarens": "häcklare",
    "häcklares": "häcklare",
    "häcklarna": "häcklare",
    "häcklarnas": "häcklare",
    "häcklas": "häckla",
    "häcklat": "häckla",
    "häcklats": "häckla",
    "häckle": "häckla",
    "häckloppen": "häcklopp",
    "häckloppens": "häcklopp",
    "häckloppet": "häcklopp",
    "häckloppets": "häcklopp",
    "häcklopps": "häcklopp",
    "häcklor": "häckla",
    "häcklorna": "häckla",
    "häcklornas": "häckla",
    "häcklors": "häckla",
    "häckls": "häckla",
    "häcklöpningar": "häcklöpning",
    "häcklöpningarna": "häcklöpning",
    "häcklöpningarnas": "häcklöpning",
    "häcklöpningars": "häcklöpning",
    "häcklöpningen": "häcklöpning",
    "häcklöpningens": "häcklöpning",
    "häcklöpnings": "häcklöpning",
    "häckningar": "häckning",
    "häckningarna": "häckning",
    "häckningarnas": "häckning",
    "häckningars": "häckning",
    "häckningen": "häckning",
    "häckningens": "häckning",
    "häcknings": "häckning",
    "häckningsplatsen": "häckningsplats",
    "häckningsplatsens": "häckningsplats",
    "häckningsplatser": "häckningsplats",
    "häckningsplatserna": "häckningsplats",
    "häckningsplatsernas": "häckningsplats",
    "häckningsplatsers": "häckningsplats",
    "häcks": "häck",
    "häcksaxar": "häcksax",
    "häcksaxarna": "häcksax",
    "häcksaxarnas": "häcksax",
    "häcksaxars": "häcksax",
    "häcksaxen": "häcksax",
    "häcksaxens": "häcksax",
    "häd": "häda",
    "hädad": "häda",
    "hädade": "häda",
    "hädades": "häda",
    "hädads": "häda",
    "hädande": "häda",
    "hädanden": "hädande",
    "hädandena": "hädande",
    "hädandenas": "hädande",
    "hädandens": "hädande",
    "hädandes": "hädande",
    "hädandet": "hädande",
    "hädandets": "hädande",
    "hädanfärden": "hädanfärd",
    "hädanfärdens": "hädanfärd",
    "hädanfärder": "hädanfärd",
    "hädanfärderna": "hädanfärd",
    "hädanfärdernas": "hädanfärd",
    "hädanfärders": "hädanfärd",
    "hädanfärds": "hädanfärd",
    "hädankall": "hädankalla",
    "hädankallad": "hädankalla",
    "hädankallade": "hädankalla",
    "hädankallades": "hädankalla",
    "hädankallads": "hädankalla",
    "hädankallande": "hädankalla",
    "hädankallanden": "hädankallande",
    "hädankallandena": "hädankallande",
    "hädankallandenas": "hädankallande",
    "hädankallandens": "hädankallande",
    "hädankallandes": "hädankallande",
    "hädankallandet": "hädankallande",
    "hädankallandets": "hädankallande",
    "hädankallar": "hädankalla",
    "hädankallas": "hädankalla",
    "hädankallat": "hädankalla",
    "hädankallats": "hädankalla",
    "hädar": "häda",
    "hädas": "häda",
    "hädat": "häda",
    "hädats": "häda",
    "hädd": "häda",
    "hädda": "häda",
    "häddas": "häda",
    "hädde": "häda",
    "häddes": "häda",
    "hädds": "häda",
    "hädelsen": "hädelse",
    "hädelsens": "hädelse",
    "hädelser": "hädelse",
    "hädelserna": "hädelse",
    "hädelsernas": "hädelse",
    "hädelsers": "hädelse",
    "hädelses": "hädelse",
    "hädiska": "hädisk",
    "hädiskare": "hädisk",
    "hädiskares": "hädisk",
    "hädiskas": "hädisk",
    "hädiskast": "hädisk",
    "hädiskaste": "hädisk",
    "hädiskastes": "hädisk",
    "hädiskasts": "hädisk",
    "hädiske": "hädisk",
    "hädiskes": "hädisk",
    "hädisks": "hädisk",
    "hädiskt": "hädisk",
    "hädiskts": "hädisk",
    "häft": "häfta",
    "häftad": "häfta",
    "häftade": "häftad",
    "häftades": "häftad",
    "häftads": "häftad",
    "häftande": "häfta",
    "häftanden": "häftande",
    "häftandena": "häftande",
    "häftandenas": "häftande",
    "häftandens": "häftande",
    "häftandes": "häftande",
    "häftandet": "häftande",
    "häftandets": "häftande",
    "häftapparaten": "häftapparat",
    "häftapparatens": "häftapparat",
    "häftapparater": "häftapparat",
    "häftapparaterna": "häftapparat",
    "häftapparaternas": "häftapparat",
    "häftapparaters": "häftapparat",
    "häftapparats": "häftapparat",
    "häftar": "häfta",
    "häftas": "häfta",
    "häftat": "häftad",
    "häftats": "häftad",
    "häften": "häfte",
    "häftena": "häfte",
    "häftenas": "häfte",
    "häftens": "häfte",
    "häftes": "häfte",
    "häftet": "häfte",
    "häftets": "häfte",
    "häftiga": "häftig",
    "häftigare": "häftig",
    "häftigares": "häftig",
    "häftigas": "häftig",
    "häftigast": "häftig",
    "häftigaste": "häftig",
    "häftigastes": "häftig",
    "häftigasts": "häftig",
    "häftige": "häftig",
    "häftiges": "häftig",
    "häftigheten": "häftighet",
    "häftighetens": "häftighet",
    "häftighets": "häftighet",
    "häftigs": "häftig",
    "häftigt": "häftig",
    "häftigts": "häftig",
    "häftklammern": "häftklammer",
    "häftklammerna": "häftklammer",
    "häftklammernas": "häftklammer",
    "häftklammerns": "häftklammer",
    "häftklammers": "häftklammer",
    "häftklamrar": "häftklammer",
    "häftklamrarna": "häftklammer",
    "häftklamrarnas": "häftklammer",
    "häftklamrars": "häftklammer",
    "häftpistolen": "häftpistol",
    "häftpistolens": "häftpistol",
    "häftpistoler": "häftpistol",
    "häftpistolerna": "häftpistol",
    "häftpistolernas": "häftpistol",
    "häftpistolers": "häftpistol",
    "häftpistols": "häftpistol",
    "häftplåsters": "häftplåster",
    "häftplåstren": "häftplåster",
    "häftplåstrens": "häftplåster",
    "häftplåstret": "häftplåster",
    "häftplåstrets": "häftplåster",
    "häftstiften": "häftstift",
    "häftstiftens": "häftstift",
    "häftstiftet": "häftstift",
    "häftstiftets": "häftstift",
    "häftstifts": "häftstift",
    "hägern": "häger",
    "hägerns": "häger",
    "hägers": "häger",
    "häggar": "hägg",
    "häggarna": "hägg",
    "häggarnas": "hägg",
    "häggars": "hägg",
    "häggen": "hägg",
    "häggens": "hägg",
    "häggs": "hägg",
    "hägn": "hägna",
    "hägnad": "hägna",
    "hägnade": "hägna",
    "hägnaden": "hägnad",
    "hägnadens": "hägnad",
    "hägnader": "hägnad",
    "hägnaderna": "hägnad",
    "hägnadernas": "hägnad",
    "hägnaders": "hägnad",
    "hägnades": "hägna",
    "hägnads": "hägnad",
    "hägnande": "hägna",
    "hägnanden": "hägnande",
    "hägnandena": "hägnande",
    "hägnandenas": "hägnande",
    "hägnandens": "hägnande",
    "hägnandes": "hägnande",
    "hägnandet": "hägnande",
    "hägnandets": "hägnande",
    "hägnar": "hägna",
    "hägnas": "hägna",
    "hägnat": "hägna",
    "hägnats": "hägna",
    "hägnet": "hägn",
    "hägnets": "hägn",
    "hägns": "hägn",
    "hägrade": "hägra",
    "hägrades": "hägra",
    "hägrande": "hägra",
    "hägranden": "hägrande",
    "hägrandena": "hägrande",
    "hägrandenas": "hägrande",
    "hägrandens": "hägrande",
    "hägrandes": "hägrande",
    "hägrandet": "hägrande",
    "hägrandets": "hägrande",
    "hägrar": "hägra",
    "hägrarna": "häger",
    "hägrarnas": "häger",
    "hägrars": "häger",
    "hägras": "hägra",
    "hägrat": "hägra",
    "hägrats": "hägra",
    "hägringar": "hägring",
    "hägringarna": "hägring",
    "hägringarnas": "hägring",
    "hägringars": "hägring",
    "hägringen": "hägring",
    "hägringens": "hägring",
    "hägrings": "hägring",
    "häkt": "häkta",
    "häktad": "häkta",
    "häktade": "häkta",
    "häktades": "häkta",
    "häktads": "häkta",
    "häktan": "häkta",
    "häktande": "häkta",
    "häktanden": "häktande",
    "häktandena": "häktande",
    "häktandenas": "häktande",
    "häktandens": "häktande",
    "häktandes": "häktande",
    "häktandet": "häktande",
    "häktandets": "häktande",
    "häktans": "häkta",
    "häktar": "häkta",
    "häktas": "häkta",
    "häktat": "häkta",
    "häktats": "häkta",
    "häkte": "häkta",
    "häkten": "häkte",
    "häktena": "häkte",
    "häktenas": "häkte",
    "häktens": "häkte",
    "häktes": "häkte",
    "häktesvakten": "häktesvakt",
    "häktesvaktens": "häktesvakt",
    "häktesvakter": "häktesvakt",
    "häktesvakterna": "häktesvakt",
    "häktesvakternas": "häktesvakt",
    "häktesvakters": "häktesvakt",
    "häktesvakts": "häktesvakt",
    "häktet": "häkte",
    "häktets": "häkte",
    "häktningar": "häktning",
    "häktningarna": "häktning",
    "häktningarnas": "häktning",
    "häktningars": "häktning",
    "häktningen": "häktning",
    "häktningens": "häktning",
    "häktnings": "häktning",
    "häktningsbesluten": "häktningsbeslut",
    "häktningsbeslutens": "häktningsbeslut",
    "häktningsbeslutet": "häktningsbeslut",
    "häktningsbeslutets": "häktningsbeslut",
    "häktningsbesluts": "häktningsbeslut",
    "häktningsförhandlingar": "häktningsförhandling",
    "häktningsförhandlingarna": "häktningsförhandling",
    "häktningsförhandlingarnas": "häktningsförhandling",
    "häktningsförhandlingars": "häktningsförhandling",
    "häktningsförhandlingen": "häktningsförhandling",
    "häktningsförhandlingens": "häktningsförhandling",
    "häktningsförhandlings": "häktningsförhandling",
    "häktningstiden": "häktningstid",
    "häktningstidens": "häktningstid",
    "häktningstider": "häktningstid",
    "häktningstiderna": "häktningstid",
    "häktningstidernas": "häktningstid",
    "häktningstiders": "häktningstid",
    "häktningstids": "häktningstid",
    "häktor": "häkta",
    "häktorna": "häkta",
    "häktornas": "häkta",
    "häktors": "häkta",
    "häkts": "häkta",
    "hälar": "hälare",
    "hälaren": "hälare",
    "hälarens": "hälare",
    "hälares": "hälare",
    "hälarna": "hälare",
    "hälarnas": "hälare",
    "hälars": "häl",
    "hälbenen": "hälben",
    "hälbenens": "hälben",
    "hälbenet": "hälben",
    "hälbenets": "hälben",
    "hälbens": "hälben",
    "hälen": "häl",
    "hälens": "häl",
    "hälerier": "häleri",
    "hälerierna": "häleri",
    "häleriernas": "häleri",
    "häleriers": "häleri",
    "häleriet": "häleri",
    "häleriets": "häleri",
    "häleris": "häleri",
    "hälerit": "häleri",
    "hälerits": "häleri",
    "hälften": "hälft",
    "hälftenbruken": "hälftenbruk",
    "hälftenbrukens": "hälftenbruk",
    "hälftenbruket": "hälftenbruk",
    "hälftenbrukets": "hälftenbruk",
    "hälftenbruks": "hälftenbruk",
    "hälftens": "hälft",
    "hälfter": "hälft",
    "hälfterna": "hälft",
    "hälfternas": "hälft",
    "hälfters": "hälft",
    "hälfts": "hälft",
    "hälgångar": "hälgångare",
    "hälgångaren": "hälgångare",
    "hälgångarens": "hälgångare",
    "hälgångares": "hälgångare",
    "hälgångarna": "hälgångare",
    "hälgångarnas": "hälgångare",
    "häll": "hälla",
    "hällan": "hälla",
    "hällande": "hälla",
    "hällanden": "hällande",
    "hällandena": "hällande",
    "hällandenas": "hällande",
    "hällandens": "hällande",
    "hällandes": "hällande",
    "hällandet": "hällande",
    "hällandets": "hällande",
    "hällans": "hälla",
    "hällar": "häll",
    "hällarna": "häll",
    "hällarnas": "häll",
    "hällars": "häll",
    "hällas": "hälla",
    "hälld": "hälla",
    "hällda": "hälla",
    "hälldas": "hälla",
    "hällde": "hälla",
    "hälldes": "hälla",
    "hällds": "hälla",
    "hälle": "hälla",
    "hälleberget": "hälleberg",
    "hällebergets": "hälleberg",
    "hällebergs": "hälleberg",
    "hälleflintan": "hälleflinta",
    "hälleflintans": "hälleflinta",
    "hälleflintas": "hälleflinta",
    "hälleflundran": "hälleflundra",
    "hälleflundrans": "hälleflundra",
    "hälleflundras": "hälleflundra",
    "hälleflundre": "hälleflundra",
    "hälleflundror": "hälleflundra",
    "hälleflundrorna": "hälleflundra",
    "hälleflundrornas": "hälleflundra",
    "hälleflundrors": "hälleflundra",
    "hällen": "häll",
    "hällens": "häll",
    "häller": "hälla",
    "hälles": "hälla",
    "hällkist": "hällkista",
    "hällkistan": "hällkista",
    "hällkistans": "hällkista",
    "hällkistas": "hällkista",
    "hällkiste": "hällkista",
    "hällkistor": "hällkista",
    "hällkistorna": "hällkista",
    "hällkistornas": "hällkista",
    "hällkistors": "hällkista",
    "hällkonsten": "hällkonst",
    "hällkonstens": "hällkonst",
    "hällkonster": "hällkonst",
    "hällkonsterna": "hällkonst",
    "hällkonsternas": "hällkonst",
    "hällkonsters": "hällkonst",
    "hällkonsts": "hällkonst",
    "hällmarken": "hällmark",
    "hällmarkens": "hällmark",
    "hällmarker": "hällmark",
    "hällmarkerna": "hällmark",
    "hällmarkernas": "hällmark",
    "hällmarkers": "hällmark",
    "hällmarks": "hällmark",
    "hällor": "hälla",
    "hällorna": "hälla",
    "hällornas": "hälla",
    "hällors": "hälla",
    "hällregnade": "hällregna",
    "hällregnades": "hällregna",
    "hällregnande": "hällregna",
    "hällregnanden": "hällregnande",
    "hällregnandena": "hällregnande",
    "hällregnandenas": "hällregnande",
    "hällregnandens": "hällregnande",
    "hällregnandes": "hällregnande",
    "hällregnandet": "hällregnande",
    "hällregnandets": "hällregnande",
    "hällregnar": "hällregna",
    "hällregnas": "hällregna",
    "hällregnat": "hällregna",
    "hällregnats": "hällregna",
    "hällregnen": "hällregn",
    "hällregnens": "hällregn",
    "hällregnet": "hällregn",
    "hällregnets": "hällregn",
    "hällregns": "hällregn",
    "hällristningar": "hällristning",
    "hällristningarna": "hällristning",
    "hällristningarnas": "hällristning",
    "hällristningars": "hällristning",
    "hällristningen": "hällristning",
    "hällristningens": "hällristning",
    "hällristnings": "hällristning",
    "hälls": "hälla",
    "hällt": "hälla",
    "hällts": "hälla",
    "häls": "häl",
    "hälsad": "hälsa",
    "hälsade": "hälsa",
    "hälsades": "hälsa",
    "hälsads": "hälsa",
    "hälsan": "hälsa",
    "hälsande": "hälsa",
    "hälsanden": "hälsande",
    "hälsandena": "hälsande",
    "hälsandenas": "hälsande",
    "hälsandens": "hälsande",
    "hälsandes": "hälsande",
    "hälsandet": "hälsande",
    "hälsandets": "hälsande",
    "hälsans": "hälsa",
    "hälsar": "hälsa",
    "hälsas": "hälsa",
    "hälsat": "hälsa",
    "hälsats": "hälsa",
    "hälse": "hälsa",
    "hälsen": "hälsena",
    "hälsenan": "hälsena",
    "hälsenans": "hälsena",
    "hälsenas": "hälsena",
    "hälsene": "hälsena",
    "hälsenor": "hälsena",
    "hälsenorna": "hälsena",
    "hälsenornas": "hälsena",
    "hälsenors": "hälsena",
    "hälsens": "hälsena",
    "hälsingar": "hälsing",
    "hälsingarna": "hälsing",
    "hälsingarnas": "hälsing",
    "hälsingars": "hälsing",
    "hälsingen": "hälsing",
    "hälsingens": "hälsing",
    "hälsings": "hälsing",
    "hälsingsk": "hälsingska",
    "hälsingska": "hälsingsk",
    "hälsingskan": "hälsingska",
    "hälsingskans": "hälsingska",
    "hälsingskare": "hälsingsk",
    "hälsingskares": "hälsingsk",
    "hälsingskas": "hälsingska",
    "hälsingskast": "hälsingsk",
    "hälsingskaste": "hälsingsk",
    "hälsingskastes": "hälsingsk",
    "hälsingskasts": "hälsingsk",
    "hälsingske": "hälsingska",
    "hälsingskes": "hälsingsk",
    "hälsingskor": "hälsingska",
    "hälsingskorna": "hälsingska",
    "hälsingskornas": "hälsingska",
    "hälsingskors": "hälsingska",
    "hälsingsks": "hälsingsk",
    "hälsingskt": "hälsingsk",
    "hälsingskts": "hälsingsk",
    "hälsningar": "hälsning",
    "hälsningarna": "hälsning",
    "hälsningarnas": "hälsning",
    "hälsningars": "hälsning",
    "hälsningen": "hälsning",
    "hälsningens": "hälsning",
    "hälsnings": "hälsning",
    "hälsningsanföranden": "hälsningsanförande",
    "hälsningsanförandena": "hälsningsanförande",
    "hälsningsanförandenas": "hälsningsanförande",
    "hälsningsanförandens": "hälsningsanförande",
    "hälsningsanförandes": "hälsningsanförande",
    "hälsningsanförandet": "hälsningsanförande",
    "hälsningsanförandets": "hälsningsanförande",
    "hälsningsritualen": "hälsningsritual",
    "hälsningsritualens": "hälsningsritual",
    "hälsningsritualer": "hälsningsritual",
    "hälsningsritualerna": "hälsningsritual",
    "hälsningsritualernas": "hälsningsritual",
    "hälsningsritualers": "hälsningsritual",
    "hälsningsritualet": "hälsningsritual",
    "hälsningsritualets": "hälsningsritual",
    "hälsningsrituals": "hälsningsritual",
    "hälso": "hälsa",
    "hälsobrunnar": "hälsobrunn",
    "hälsobrunnarna": "hälsobrunn",
    "hälsobrunnarnas": "hälsobrunn",
    "hälsobrunnars": "hälsobrunn",
    "hälsobrunnen": "hälsobrunn",
    "hälsobrunnens": "hälsobrunn",
    "hälsobrunns": "hälsobrunn",
    "hälsocenters": "hälsocenter",
    "hälsocentrer": "hälsocenter",
    "hälsocentrerna": "hälsocenter",
    "hälsocentrernas": "hälsocenter",
    "hälsocentrers": "hälsocenter",
    "hälsocentret": "hälsocenter",
    "hälsocentrets": "hälsocenter",
    "hälsoeffekten": "hälsoeffekt",
    "hälsoeffektens": "hälsoeffekt",
    "hälsoeffekter": "hälsoeffekt",
    "hälsoeffekterna": "hälsoeffekt",
    "hälsoeffekternas": "hälsoeffekt",
    "hälsoeffekters": "hälsoeffekt",
    "hälsoeffekts": "hälsoeffekt",
    "hälsofarliga": "hälsofarlig",
    "hälsofarligare": "hälsofarlig",
    "hälsofarligares": "hälsofarlig",
    "hälsofarligas": "hälsofarlig",
    "hälsofarligast": "hälsofarlig",
    "hälsofarligaste": "hälsofarlig",
    "hälsofarligastes": "hälsofarlig",
    "hälsofarligasts": "hälsofarlig",
    "hälsofarlige": "hälsofarlig",
    "hälsofarliges": "hälsofarlig",
    "hälsofarligheten": "hälsofarlighet",
    "hälsofarlighetens": "hälsofarlighet",
    "hälsofarligheter": "hälsofarlighet",
    "hälsofarligheterna": "hälsofarlighet",
    "hälsofarligheternas": "hälsofarlighet",
    "hälsofarligheters": "hälsofarlighet",
    "hälsofarlighets": "hälsofarlighet",
    "hälsofarligs": "hälsofarlig",
    "hälsofarligt": "hälsofarlig",
    "hälsofarligts": "hälsofarlig",
    "hälsokontrollen": "hälsokontroll",
    "hälsokontrollens": "hälsokontroll",
    "hälsokontroller": "hälsokontroll",
    "hälsokontrollerna": "hälsokontroll",
    "hälsokontrollernas": "hälsokontroll",
    "hälsokontrollers": "hälsokontroll",
    "hälsokontrolls": "hälsokontroll",
    "hälsokorten": "hälsokort",
    "hälsokortens": "hälsokort",
    "hälsokortet": "hälsokort",
    "hälsokortets": "hälsokort",
    "hälsokorts": "hälsokort",
    "hälsokosten": "hälsokost",
    "hälsokostens": "hälsokost",
    "hälsokosts": "hälsokost",
    "hälsokäll": "hälsokälla",
    "hälsokällan": "hälsokälla",
    "hälsokällans": "hälsokälla",
    "hälsokällas": "hälsokälla",
    "hälsokälle": "hälsokälla",
    "hälsokällor": "hälsokälla",
    "hälsokällorna": "hälsokälla",
    "hälsokällornas": "hälsokälla",
    "hälsokällors": "hälsokälla",
    "hälsokälls": "hälsokälla",
    "hälsolägen": "hälsoläge",
    "hälsolägena": "hälsoläge",
    "hälsolägenas": "hälsoläge",
    "hälsolägens": "hälsoläge",
    "hälsoläges": "hälsoläge",
    "hälsoläget": "hälsoläge",
    "hälsolägets": "hälsoläge",
    "hälsomedvetenheten": "hälsomedvetenhet",
    "hälsomedvetenhetens": "hälsomedvetenhet",
    "hälsomedvetenhets": "hälsomedvetenhet",
    "hälsomedvetens": "hälsomedveten",
    "hälsomedvetet": "hälsomedveten",
    "hälsomedvetets": "hälsomedveten",
    "hälsomedvetna": "hälsomedveten",
    "hälsomedvetnare": "hälsomedveten",
    "hälsomedvetnares": "hälsomedveten",
    "hälsomedvetnas": "hälsomedveten",
    "hälsomedvetnast": "hälsomedveten",
    "hälsomedvetnaste": "hälsomedveten",
    "hälsomedvetnastes": "hälsomedveten",
    "hälsomedvetnasts": "hälsomedveten",
    "hälsomedvetne": "hälsomedveten",
    "hälsomedvetnes": "hälsomedveten",
    "hälsomässiga": "hälsomässig",
    "hälsomässigare": "hälsomässig",
    "hälsomässigares": "hälsomässig",
    "hälsomässigas": "hälsomässig",
    "hälsomässigast": "hälsomässig",
    "hälsomässigaste": "hälsomässig",
    "hälsomässigastes": "hälsomässig",
    "hälsomässigasts": "hälsomässig",
    "hälsomässige": "hälsomässig",
    "hälsomässiges": "hälsomässig",
    "hälsomässigs": "hälsomässig",
    "hälsomässigt": "hälsomässig",
    "hälsomässigts": "hälsomässig",
    "hälsopolitiken": "hälsopolitik",
    "hälsopolitikens": "hälsopolitik",
    "hälsopolitiks": "hälsopolitik",
    "hälsopolitiska": "hälsopolitisk",
    "hälsopolitiskas": "hälsopolitisk",
    "hälsopolitiske": "hälsopolitisk",
    "hälsopolitiskes": "hälsopolitisk",
    "hälsopolitisks": "hälsopolitisk",
    "hälsopolitiskt": "hälsopolitisk",
    "hälsopolitiskts": "hälsopolitisk",
    "hälsorisken": "hälsorisk",
    "hälsoriskens": "hälsorisk",
    "hälsorisker": "hälsorisk",
    "hälsoriskerna": "hälsorisk",
    "hälsoriskernas": "hälsorisk",
    "hälsoriskers": "hälsorisk",
    "hälsorisks": "hälsorisk",
    "hälsosamheten": "hälsosamhet",
    "hälsosamhetens": "hälsosamhet",
    "hälsosamhets": "hälsosamhet",
    "hälsosamma": "hälsosam",
    "hälsosammare": "hälsosam",
    "hälsosammares": "hälsosam",
    "hälsosammas": "hälsosam",
    "hälsosammast": "hälsosam",
    "hälsosammaste": "hälsosam",
    "hälsosammastes": "hälsosam",
    "hälsosammasts": "hälsosam",
    "hälsosamme": "hälsosam",
    "hälsosammes": "hälsosam",
    "hälsosams": "hälsosam",
    "hälsosamt": "hälsosam",
    "hälsosamts": "hälsosam",
    "hälsoskyddet": "hälsoskydd",
    "hälsoskyddets": "hälsoskydd",
    "hälsoskydds": "hälsoskydd",
    "hälsoteckens": "hälsotecken",
    "hälsotecknen": "hälsotecken",
    "hälsotecknens": "hälsotecken",
    "hälsotecknet": "hälsotecken",
    "hälsotecknets": "hälsotecken",
    "hälsoteken": "hälsotek",
    "hälsotekens": "hälsotek",
    "hälsoteket": "hälsotek",
    "hälsotekets": "hälsotek",
    "hälsoteks": "hälsotek",
    "hälsovådliga": "hälsovådlig",
    "hälsovådligare": "hälsovådlig",
    "hälsovådligares": "hälsovådlig",
    "hälsovådligas": "hälsovådlig",
    "hälsovådligast": "hälsovådlig",
    "hälsovådligaste": "hälsovådlig",
    "hälsovådligastes": "hälsovådlig",
    "hälsovådligasts": "hälsovådlig",
    "hälsovådlige": "hälsovådlig",
    "hälsovådliges": "hälsovådlig",
    "hälsovådligheten": "hälsovådlighet",
    "hälsovådlighetens": "hälsovådlighet",
    "hälsovådligheter": "hälsovådlighet",
    "hälsovådligheterna": "hälsovådlighet",
    "hälsovådligheternas": "hälsovådlighet",
    "hälsovådligheters": "hälsovådlighet",
    "hälsovådlighets": "hälsovådlighet",
    "hälsovådligs": "hälsovådlig",
    "hälsovådligt": "hälsovådlig",
    "hälsovådligts": "hälsovådlig",
    "hälsovården": "hälsovård",
    "hälsovårdens": "hälsovård",
    "hälsovårds": "hälsovård",
    "hälsovårdskostnaden": "hälsovårdskostnad",
    "hälsovårdskostnadens": "hälsovårdskostnad",
    "hälsovårdskostnader": "hälsovårdskostnad",
    "hälsovårdskostnaderna": "hälsovårdskostnad",
    "hälsovårdskostnadernas": "hälsovårdskostnad",
    "hälsovårdskostnaders": "hälsovårdskostnad",
    "hälsovårdskostnads": "hälsovårdskostnad",
    "hälsovårdsnämnden": "hälsovårdsnämnd",
    "hälsovårdsnämndens": "hälsovårdsnämnd",
    "hälsovårdsnämnder": "hälsovårdsnämnd",
    "hälsovårdsnämnderna": "hälsovårdsnämnd",
    "hälsovårdsnämndernas": "hälsovårdsnämnd",
    "hälsovårdsnämnders": "hälsovårdsnämnd",
    "hälsovårdsnämnds": "hälsovårdsnämnd",
    "hält": "hälta",
    "hältan": "hälta",
    "hältans": "hälta",
    "hältas": "hälta",
    "häm": "hämma",
    "hämmade": "hämmad",
    "hämmades": "hämmad",
    "hämmads": "hämmad",
    "hämmande": "hämma",
    "hämmanden": "hämmande",
    "hämmandena": "hämmande",
    "hämmandenas": "hämmande",
    "hämmandens": "hämmande",
    "hämmandes": "hämmande",
    "hämmandet": "hämmande",
    "hämmandets": "hämmande",
    "hämmar": "hämma",
    "hämmas": "hämma",
    "hämmat": "hämmad",
    "hämmats": "hämmad",
    "hämn": "hämna",
    "hämnad": "hämna",
    "hämnade": "hämna",
    "hämnades": "hämnas",
    "hämnads": "hämna",
    "hämnande": "hämna",
    "hämnanden": "hämnande",
    "hämnandena": "hämnande",
    "hämnandenas": "hämnande",
    "hämnandens": "hämnande",
    "hämnandes": "hämnande",
    "hämnandet": "hämnande",
    "hämnandets": "hämnande",
    "hämnar": "hämnare",
    "hämnaren": "hämnare",
    "hämnarens": "hämnare",
    "hämnares": "hämnare",
    "hämnarna": "hämnare",
    "hämnarnas": "hämnare",
    "hämnas": "hämna",
    "hämnat": "hämna",
    "hämnats": "hämnas",
    "hämndaktionen": "hämndaktion",
    "hämndaktionens": "hämndaktion",
    "hämndaktioner": "hämndaktion",
    "hämndaktionerna": "hämndaktion",
    "hämndaktionernas": "hämndaktion",
    "hämndaktioners": "hämndaktion",
    "hämndaktions": "hämndaktion",
    "hämndattacken": "hämndattack",
    "hämndattackens": "hämndattack",
    "hämndattacker": "hämndattack",
    "hämndattackerna": "hämndattack",
    "hämndattackernas": "hämndattack",
    "hämndattackers": "hämndattack",
    "hämndattacks": "hämndattack",
    "hämndeaktionen": "hämndeaktion",
    "hämndeaktionens": "hämndeaktion",
    "hämndeaktioner": "hämndeaktion",
    "hämndeaktionerna": "hämndeaktion",
    "hämndeaktionernas": "hämndeaktion",
    "hämndeaktioners": "hämndeaktion",
    "hämndeaktions": "hämndeaktion",
    "hämndeandar": "hämndeande",
    "hämndeandarna": "hämndeande",
    "hämndeandarnas": "hämndeande",
    "hämndeandars": "hämndeande",
    "hämndeanden": "hämndeande",
    "hämndeandens": "hämndeande",
    "hämndeandes": "hämndeande",
    "hämnden": "hämnd",
    "hämndens": "hämnd",
    "hämndgiriga": "hämndgirig",
    "hämndgirigare": "hämndgirig",
    "hämndgirigares": "hämndgirig",
    "hämndgirigas": "hämndgirig",
    "hämndgirigast": "hämndgirig",
    "hämndgirigaste": "hämndgirig",
    "hämndgirigastes": "hämndgirig",
    "hämndgirigasts": "hämndgirig",
    "hämndgirige": "hämndgirig",
    "hämndgiriges": "hämndgirig",
    "hämndgirigheten": "hämndgirighet",
    "hämndgirighetens": "hämndgirighet",
    "hämndgirighets": "hämndgirighet",
    "hämndgirigs": "hämndgirig",
    "hämndgirigt": "hämndgirig",
    "hämndgirigts": "hämndgirig",
    "hämndgudinnan": "hämndgudinna",
    "hämndgudinnans": "hämndgudinna",
    "hämndgudinnas": "hämndgudinna",
    "hämndgudinne": "hämndgudinna",
    "hämndgudinnor": "hämndgudinna",
    "hämndgudinnorna": "hämndgudinna",
    "hämndgudinnornas": "hämndgudinna",
    "hämndgudinnors": "hämndgudinna",
    "hämndlystenheten": "hämndlystenhet",
    "hämndlystenhetens": "hämndlystenhet",
    "hämndlystenhets": "hämndlystenhet",
    "hämndlystens": "hämndlysten",
    "hämndlystet": "hämndlysten",
    "hämndlystets": "hämndlysten",
    "hämndlystna": "hämndlysten",
    "hämndlystnaden": "hämndlystnad",
    "hämndlystnadens": "hämndlystnad",
    "hämndlystnader": "hämndlystnad",
    "hämndlystnaderna": "hämndlystnad",
    "hämndlystnadernas": "hämndlystnad",
    "hämndlystnaders": "hämndlystnad",
    "hämndlystnads": "hämndlystnad",
    "hämndlystnare": "hämndlysten",
    "hämndlystnares": "hämndlysten",
    "hämndlystnas": "hämndlysten",
    "hämndlystnast": "hämndlysten",
    "hämndlystnaste": "hämndlysten",
    "hämndlystnastes": "hämndlysten",
    "hämndlystnasts": "hämndlysten",
    "hämndlystne": "hämndlysten",
    "hämndlystnes": "hämndlysten",
    "hämnds": "hämnd",
    "hämningar": "hämning",
    "hämningarna": "hämning",
    "hämningarnas": "hämning",
    "hämningars": "hämning",
    "hämningen": "hämning",
    "hämningens": "hämning",
    "hämnings": "hämning",
    "hämningslösa": "hämningslös",
    "hämningslösare": "hämningslös",
    "hämningslösares": "hämningslös",
    "hämningslösas": "hämningslös",
    "hämningslösast": "hämningslös",
    "hämningslösaste": "hämningslös",
    "hämningslösastes": "hämningslös",
    "hämningslösasts": "hämningslös",
    "hämningslöse": "hämningslös",
    "hämningslöses": "hämningslös",
    "hämningslösheten": "hämningslöshet",
    "hämningslöshetens": "hämningslöshet",
    "hämningslösheter": "hämningslöshet",
    "hämningslösheterna": "hämningslöshet",
    "hämningslösheternas": "hämningslöshet",
    "hämningslösheters": "hämningslöshet",
    "hämningslöshets": "hämningslöshet",
    "hämningslöst": "hämningslös",
    "hämningslösts": "hämningslös",
    "hämplingar": "hämpling",
    "hämplingarna": "hämpling",
    "hämplingarnas": "hämpling",
    "hämplingars": "hämpling",
    "hämplingen": "hämpling",
    "hämplingens": "hämpling",
    "hämplings": "hämpling",
    "hämskon": "hämsko",
    "hämskons": "hämsko",
    "hämskor": "hämsko",
    "hämskorna": "hämsko",
    "hämskornas": "hämsko",
    "hämskors": "hämsko",
    "hämskos": "hämsko",
    "hämt": "hämta",
    "hämtad": "hämta",
    "hämtade": "hämta",
    "hämtades": "hämta",
    "hämtads": "hämta",
    "hämtande": "hämta",
    "hämtanden": "hämtande",
    "hämtandena": "hämtande",
    "hämtandenas": "hämtande",
    "hämtandens": "hämtande",
    "hämtandes": "hämtande",
    "hämtandet": "hämtande",
    "hämtandets": "hämtande",
    "hämtar": "hämta",
    "hämtas": "hämta",
    "hämtat": "hämta",
    "hämtats": "hämta",
    "hämtmaten": "hämtmat",
    "hämtmatens": "hämtmat",
    "hämtmats": "hämtmat",
    "hämtningar": "hämtning",
    "hämtningarna": "hämtning",
    "hämtningarnas": "hämtning",
    "hämtningars": "hämtning",
    "hämtningen": "hämtning",
    "hämtningens": "hämtning",
    "hämtnings": "hämtning",
    "hämtpizzan": "hämtpizza",
    "hämtpizzans": "hämtpizza",
    "hämtpizzas": "hämtpizza",
    "hämtpizzor": "hämtpizza",
    "hämtpizzorna": "hämtpizza",
    "hämtpizzornas": "hämtpizza",
    "hämtpizzors": "hämtpizza",
    "hämtprisen": "hämtpris",
    "hämtprisens": "hämtpris",
    "hämtpriser": "hämtpris",
    "hämtpriserna": "hämtpris",
    "hämtprisernas": "hämtpris",
    "hämtprisers": "hämtpris",
    "hämtpriset": "hämtpris",
    "hämtprisets": "hämtpris",
    "händ": "hända",
    "händande": "hända",
    "händanden": "händande",
    "händandena": "händande",
    "händandenas": "händande",
    "händandens": "händande",
    "händandes": "händande",
    "händandet": "händande",
    "händandets": "händande",
    "händas": "hända",
    "hände": "hända",
    "händelsefattiga": "händelsefattig",
    "händelsefattigare": "händelsefattig",
    "händelsefattigares": "händelsefattig",
    "händelsefattigas": "händelsefattig",
    "händelsefattigast": "händelsefattig",
    "händelsefattigaste": "händelsefattig",
    "händelsefattigastes": "händelsefattig",
    "händelsefattigasts": "händelsefattig",
    "händelsefattige": "händelsefattig",
    "händelsefattiges": "händelsefattig",
    "händelsefattigheten": "händelsefattighet",
    "händelsefattighetens": "händelsefattighet",
    "händelsefattighets": "händelsefattighet",
    "händelsefattigs": "händelsefattig",
    "händelsefattigt": "händelsefattig",
    "händelsefattigts": "händelsefattig",
    "händelseförloppen": "händelseförlopp",
    "händelseförloppens": "händelseförlopp",
    "händelseförloppet": "händelseförlopp",
    "händelseförloppets": "händelseförlopp",
    "händelseförlopps": "händelseförlopp",
    "händelselösa": "händelselös",
    "händelselösare": "händelselös",
    "händelselösares": "händelselös",
    "händelselösas": "händelselös",
    "händelselösast": "händelselös",
    "händelselösaste": "händelselös",
    "händelselösastes": "händelselös",
    "händelselösasts": "händelselös",
    "händelselöse": "händelselös",
    "händelselöses": "händelselös",
    "händelselösheten": "händelselöshet",
    "händelselöshetens": "händelselöshet",
    "händelselöshets": "händelselöshet",
    "händelselöst": "händelselös",
    "händelselösts": "händelselös",
    "händelsen": "händelse",
    "händelsens": "händelse",
    "händelser": "händelse",
    "händelserika": "händelserik",
    "händelserikare": "händelserik",
    "händelserikares": "händelserik",
    "händelserikas": "händelserik",
    "händelserikast": "händelserik",
    "händelserikaste": "händelserik",
    "händelserikastes": "händelserik",
    "händelserikasts": "händelserik",
    "händelserike": "händelserik",
    "händelserikes": "händelserik",
    "händelserikheten": "händelserikhet",
    "händelserikhetens": "händelserikhet",
    "händelserikhets": "händelserikhet",
    "händelseriks": "händelserik",
    "händelserikt": "händelserik",
    "händelserikts": "händelserik",
    "händelserna": "händelse",
    "händelsernas": "händelse",
    "händelsers": "händelse",
    "händelses": "händelse",
    "händelseutvecklingar": "händelseutveckling",
    "händelseutvecklingarna": "händelseutveckling",
    "händelseutvecklingarnas": "händelseutveckling",
    "händelseutvecklingars": "händelseutveckling",
    "händelseutvecklingen": "händelseutveckling",
    "händelseutvecklingens": "händelseutveckling",
    "händelseutvecklings": "händelseutveckling",
    "händer": "hända",
    "händerna": "hand",
    "händernas": "hand",
    "händers": "hand",
    "händes": "hända",
    "händiga": "händig",
    "händigare": "händig",
    "händigares": "händig",
    "händigas": "händig",
    "händigast": "händig",
    "händigaste": "händig",
    "händigastes": "händig",
    "händigasts": "händig",
    "händige": "händig",
    "händiges": "händig",
    "händigheten": "händighet",
    "händighetens": "händighet",
    "händighets": "händighet",
    "händigs": "händig",
    "händigt": "händig",
    "händigts": "händig",
    "händs": "hända",
    "hänför": "hänföra",
    "hänförande": "hänföra",
    "hänföranden": "hänförande",
    "hänförandena": "hänförande",
    "hänförandenas": "hänförande",
    "hänförandens": "hänförande",
    "hänförandes": "hänförande",
    "hänförandet": "hänförande",
    "hänförandets": "hänförande",
    "hänföras": "hänföra",
    "hänförd": "hänföra",
    "hänförda": "hänförd",
    "hänfördare": "hänförd",
    "hänfördares": "hänförd",
    "hänfördas": "hänförd",
    "hänfördast": "hänförd",
    "hänfördaste": "hänförd",
    "hänfördastes": "hänförd",
    "hänfördasts": "hänförd",
    "hänförde": "hänförd",
    "hänfördes": "hänförd",
    "hänfördheten": "hänfördhet",
    "hänfördhetens": "hänfördhet",
    "hänfördhets": "hänfördhet",
    "hänförds": "hänförd",
    "hänförelsen": "hänförelse",
    "hänförelsens": "hänförelse",
    "hänförelses": "hänförelse",
    "hänföres": "hänföra",
    "hänförs": "hänföra",
    "hänfört": "hänförd",
    "hänförts": "hänförd",
    "häng": "hänga",
    "hängande": "hänga",
    "hänganden": "hängande",
    "hängandena": "hängande",
    "hängandenas": "hängande",
    "hängandens": "hängande",
    "hängandes": "hängande",
    "hängandet": "hängande",
    "hängandets": "hängande",
    "hängar": "hängare",
    "hängaren": "hängare",
    "hängarens": "hängare",
    "hängares": "hängare",
    "hängarna": "hängare",
    "hängarnas": "hängare",
    "hängas": "hänga",
    "hängavtalen": "hängavtal",
    "hängavtalens": "hängavtal",
    "hängavtalet": "hängavtal",
    "hängavtalets": "hängavtal",
    "hängavtals": "hängavtal",
    "hängbanan": "hängbana",
    "hängbanans": "hängbana",
    "hängbanas": "hängbana",
    "hängbane": "hängbana",
    "hängbanor": "hängbana",
    "hängbanorna": "hängbana",
    "hängbanornas": "hängbana",
    "hängbanors": "hängbana",
    "hängbjörkar": "hängbjörk",
    "hängbjörkarna": "hängbjörk",
    "hängbjörkarnas": "hängbjörk",
    "hängbjörkars": "hängbjörk",
    "hängbjörken": "hängbjörk",
    "hängbjörkens": "hängbjörk",
    "hängbjörks": "hängbjörk",
    "hängbroar": "hängbro",
    "hängbroarna": "hängbro",
    "hängbroarnas": "hängbro",
    "hängbroars": "hängbro",
    "hängbron": "hängbro",
    "hängbrons": "hängbro",
    "hängbros": "hängbro",
    "hängbrösten": "hängbröst",
    "hängbröstens": "hängbröst",
    "hängbröstet": "hängbröst",
    "hängbröstets": "hängbröst",
    "hängbrösts": "hängbröst",
    "hängbukar": "hängbuk",
    "hängbukarna": "hängbuk",
    "hängbukarnas": "hängbuk",
    "hängbukars": "hängbuk",
    "hängbuken": "hängbuk",
    "hängbukens": "hängbuk",
    "hängbuks": "hängbuk",
    "hängd": "hänga",
    "hängda": "hänga",
    "hängdalar": "hängdal",
    "hängdalarna": "hängdal",
    "hängdalarnas": "hängdal",
    "hängdalars": "hängdal",
    "hängdalen": "hängdal",
    "hängdalens": "hängdal",
    "hängdals": "hängdal",
    "hängdas": "hänga",
    "hängde": "hänga",
    "hängdes": "hänga",
    "hängds": "hänga",
    "hängen": "hänge",
    "hängena": "hänge",
    "hängenas": "hänge",
    "hängens": "hänge",
    "hänger": "hänga",
    "hänges": "hänge",
    "hänget": "hänge",
    "hängets": "hänge",
    "hängfärdiga": "hängfärdig",
    "hängfärdigare": "hängfärdig",
    "hängfärdigares": "hängfärdig",
    "hängfärdigas": "hängfärdig",
    "hängfärdigast": "hängfärdig",
    "hängfärdigaste": "hängfärdig",
    "hängfärdigastes": "hängfärdig",
    "hängfärdigasts": "hängfärdig",
    "hängfärdige": "hängfärdig",
    "hängfärdiges": "hängfärdig",
    "hängfärdigs": "hängfärdig",
    "hängfärdigt": "hängfärdig",
    "hängfärdigts": "hängfärdig",
    "hängiga": "hängig",
    "hängigare": "hängig",
    "hängigares": "hängig",
    "hängigas": "hängig",
    "hängigast": "hängig",
    "hängigaste": "hängig",
    "hängigastes": "hängig",
    "hängigasts": "hängig",
    "hängige": "hängig",
    "hängiges": "hängig",
    "hängigheten": "hängighet",
    "hängighetens": "hängighet",
    "hängighets": "hängighet",
    "hängigs": "hängig",
    "hängigt": "hängig",
    "hängigts": "hängig",
    "hängivelsen": "hängivelse",
    "hängivelsens": "hängivelse",
    "hängivelses": "hängivelse",
    "hängivenheten": "hängivenhet",
    "hängivenhetens": "hängivenhet",
    "hängivenhets": "hängivenhet",
    "hängivens": "hängiven",
    "hängivet": "hängiven",
    "hängivets": "hängiven",
    "hängivna": "hängiven",
    "hängivnare": "hängiven",
    "hängivnares": "hängiven",
    "hängivnas": "hängiven",
    "hängivnast": "hängiven",
    "hängivnaste": "hängiven",
    "hängivnastes": "hängiven",
    "hängivnasts": "hängiven",
    "hängivne": "hängiven",
    "hängivnes": "hängiven",
    "hänglåsen": "hänglås",
    "hänglåsens": "hänglås",
    "hänglåset": "hänglås",
    "hänglåsets": "hänglås",
    "hängmatt": "hängmatta",
    "hängmattan": "hängmatta",
    "hängmattans": "hängmatta",
    "hängmattas": "hängmatta",
    "hängmatte": "hängmatta",
    "hängmattor": "hängmatta",
    "hängmattorna": "hängmatta",
    "hängmattornas": "hängmatta",
    "hängmattors": "hängmatta",
    "hängmatts": "hängmatta",
    "hängningar": "hängning",
    "hängningarna": "hängning",
    "hängningarnas": "hängning",
    "hängningars": "hängning",
    "hängningen": "hängning",
    "hängningens": "hängning",
    "hängnings": "hängning",
    "hängpartier": "hängparti",
    "hängpartierna": "hängparti",
    "hängpartiernas": "hängparti",
    "hängpartiers": "hängparti",
    "hängpartiet": "hängparti",
    "hängpartiets": "hängparti",
    "hängpartis": "hängparti",
    "hängpartit": "hängparti",
    "hängpartits": "hängparti",
    "hängränn": "hängränna",
    "hängrännan": "hängränna",
    "hängrännans": "hängränna",
    "hängrännas": "hängränna",
    "hängränne": "hängränna",
    "hängrännor": "hängränna",
    "hängrännorna": "hängränna",
    "hängrännornas": "hängränna",
    "hängrännors": "hängränna",
    "hängränns": "hängränna",
    "hängs": "hänge",
    "hängselkjolar": "hängselkjol",
    "hängselkjolarna": "hängselkjol",
    "hängselkjolarnas": "hängselkjol",
    "hängselkjolars": "hängselkjol",
    "hängselkjolen": "hängselkjol",
    "hängselkjolens": "hängselkjol",
    "hängselkjols": "hängselkjol",
    "hängsjuka": "hängsjuk",
    "hängsjukare": "hängsjuk",
    "hängsjukares": "hängsjuk",
    "hängsjukas": "hängsjuk",
    "hängsjukast": "hängsjuk",
    "hängsjukaste": "hängsjuk",
    "hängsjukastes": "hängsjuk",
    "hängsjukasts": "hängsjuk",
    "hängsjuke": "hängsjuk",
    "hängsjukes": "hängsjuk",
    "hängsjuks": "hängsjuk",
    "hängsjukt": "hängsjuk",
    "hängsjukts": "hängsjuk",
    "hängsl": "hängsle",
    "hängslen": "hängsle",
    "hängslena": "hängsle",
    "hängslenas": "hängsle",
    "hängslens": "hängsle",
    "hängsles": "hängsle",
    "hängslet": "hängsle",
    "hängslets": "hängsle",
    "hängsmycken": "hängsmycke",
    "hängsmyckena": "hängsmycke",
    "hängsmyckenas": "hängsmycke",
    "hängsmyckens": "hängsmycke",
    "hängsmyckes": "hängsmycke",
    "hängsmycket": "hängsmycke",
    "hängsmyckets": "hängsmycke",
    "hängt": "hänga",
    "hängts": "hänga",
    "hänryck": "hänrycka",
    "hänryckande": "hänrycka",
    "hänryckanden": "hänryckande",
    "hänryckandena": "hänryckande",
    "hänryckandenas": "hänryckande",
    "hänryckandens": "hänryckande",
    "hänryckandes": "hänryckande",
    "hänryckandet": "hänryckande",
    "hänryckandets": "hänryckande",
    "hänryckas": "hänrycka",
    "hänrycker": "hänrycka",
    "hänryckes": "hänrycka",
    "hänryckningar": "hänryckning",
    "hänryckningarna": "hänryckning",
    "hänryckningarnas": "hänryckning",
    "hänryckningars": "hänryckning",
    "hänryckningen": "hänryckning",
    "hänryckningens": "hänryckning",
    "hänrycknings": "hänryckning",
    "hänrycks": "hänrycka",
    "hänryckt": "hänrycka",
    "hänryckta": "hänryckt",
    "hänrycktare": "hänryckt",
    "hänrycktares": "hänryckt",
    "hänrycktas": "hänryckt",
    "hänrycktast": "hänryckt",
    "hänrycktaste": "hänryckt",
    "hänrycktastes": "hänryckt",
    "hänrycktasts": "hänryckt",
    "hänryckte": "hänryckt",
    "hänrycktes": "hänryckt",
    "hänrycktheten": "hänryckthet",
    "hänryckthetens": "hänryckthet",
    "hänryckthets": "hänryckthet",
    "hänryckts": "hänryckt",
    "hänseenden": "hänseende",
    "hänseendena": "hänseende",
    "hänseendenas": "hänseende",
    "hänseendens": "hänseende",
    "hänseendes": "hänseende",
    "hänseendet": "hänseende",
    "hänseendets": "hänseende",
    "hänsjunkenheten": "hänsjunkenhet",
    "hänsjunkenhetens": "hänsjunkenhet",
    "hänsjunkenhets": "hänsjunkenhet",
    "hänsjunkens": "hänsjunken",
    "hänsjunket": "hänsjunken",
    "hänsjunkets": "hänsjunken",
    "hänsjunkna": "hänsjunken",
    "hänsjunknare": "hänsjunken",
    "hänsjunknares": "hänsjunken",
    "hänsjunknas": "hänsjunken",
    "hänsjunknast": "hänsjunken",
    "hänsjunknaste": "hänsjunken",
    "hänsjunknastes": "hänsjunken",
    "hänsjunknasts": "hänsjunken",
    "hänsjunkne": "hänsjunken",
    "hänsjunknes": "hänsjunken",
    "hänskjut": "hänskjuta",
    "hänskjutande": "hänskjuta",
    "hänskjutanden": "hänskjutande",
    "hänskjutandena": "hänskjutande",
    "hänskjutandenas": "hänskjutande",
    "hänskjutandens": "hänskjutande",
    "hänskjutandes": "hänskjutande",
    "hänskjutandet": "hänskjutande",
    "hänskjutandets": "hänskjutande",
    "hänskjutas": "hänskjuta",
    "hänskjute": "hänskjuta",
    "hänskjuten": "hänskjuta",
    "hänskjutens": "hänskjuta",
    "hänskjuter": "hänskjuta",
    "hänskjutes": "hänskjuta",
    "hänskjutet": "hänskjuta",
    "hänskjutets": "hänskjuta",
    "hänskjutit": "hänskjuta",
    "hänskjutits": "hänskjuta",
    "hänskjutna": "hänskjuta",
    "hänskjutnas": "hänskjuta",
    "hänskjutne": "hänskjuta",
    "hänskjutnes": "hänskjuta",
    "hänskjuts": "hänskjuta",
    "hänsköt": "hänskjuta",
    "hänsköte": "hänskjuta",
    "hänskötes": "hänskjuta",
    "hänsköts": "hänskjuta",
    "hänsovens": "hänsoven",
    "hänsovet": "hänsoven",
    "hänsovets": "hänsoven",
    "hänsovna": "hänsoven",
    "hänsovnare": "hänsoven",
    "hänsovnares": "hänsoven",
    "hänsovnas": "hänsoven",
    "hänsovnast": "hänsoven",
    "hänsovnaste": "hänsoven",
    "hänsovnastes": "hänsoven",
    "hänsovnasts": "hänsoven",
    "hänsovne": "hänsoven",
    "hänsovnes": "hänsoven",
    "hänsyftade": "hänsyfta",
    "hänsyftades": "hänsyfta",
    "hänsyftande": "hänsyfta",
    "hänsyftanden": "hänsyftande",
    "hänsyftandena": "hänsyftande",
    "hänsyftandenas": "hänsyftande",
    "hänsyftandens": "hänsyftande",
    "hänsyftandes": "hänsyftande",
    "hänsyftandet": "hänsyftande",
    "hänsyftandets": "hänsyftande",
    "hänsyftar": "hänsyfta",
    "hänsyftas": "hänsyfta",
    "hänsyftat": "hänsyfta",
    "hänsyftats": "hänsyfta",
    "hänsyftningar": "hänsyftning",
    "hänsyftningarna": "hänsyftning",
    "hänsyftningarnas": "hänsyftning",
    "hänsyftningars": "hänsyftning",
    "hänsyftningen": "hänsyftning",
    "hänsyftningens": "hänsyftning",
    "hänsyftnings": "hänsyftning",
    "hänsynen": "hänsyn",
    "hänsynens": "hänsyn",
    "hänsyns": "hänsyn",
    "hänsynsfulla": "hänsynsfull",
    "hänsynsfullare": "hänsynsfull",
    "hänsynsfullares": "hänsynsfull",
    "hänsynsfullas": "hänsynsfull",
    "hänsynsfullast": "hänsynsfull",
    "hänsynsfullaste": "hänsynsfull",
    "hänsynsfullastes": "hänsynsfull",
    "hänsynsfullasts": "hänsynsfull",
    "hänsynsfulle": "hänsynsfull",
    "hänsynsfulles": "hänsynsfull",
    "hänsynsfullheten": "hänsynsfullhet",
    "hänsynsfullhetens": "hänsynsfullhet",
    "hänsynsfullheter": "hänsynsfullhet",
    "hänsynsfullheterna": "hänsynsfullhet",
    "hänsynsfullheternas": "hänsynsfullhet",
    "hänsynsfullheters": "hänsynsfullhet",
    "hänsynsfullhets": "hänsynsfullhet",
    "hänsynsfulls": "hänsynsfull",
    "hänsynsfullt": "hänsynsfull",
    "hänsynsfullts": "hänsynsfull",
    "hänsynslösa": "hänsynslös",
    "hänsynslösare": "hänsynslös",
    "hänsynslösares": "hänsynslös",
    "hänsynslösas": "hänsynslös",
    "hänsynslösast": "hänsynslös",
    "hänsynslösaste": "hänsynslös",
    "hänsynslösastes": "hänsynslös",
    "hänsynslösasts": "hänsynslös",
    "hänsynslöse": "hänsynslös",
    "hänsynslöses": "hänsynslös",
    "hänsynslösheten": "hänsynslöshet",
    "hänsynslöshetens": "hänsynslöshet",
    "hänsynslösheter": "hänsynslöshet",
    "hänsynslösheterna": "hänsynslöshet",
    "hänsynslösheternas": "hänsynslöshet",
    "hänsynslösheters": "hänsynslöshet",
    "hänsynslöshets": "hänsynslöshet",
    "hänsynslöst": "hänsynslös",
    "hänsynslösts": "hänsynslös",
    "hänsynstaganden": "hänsynstagande",
    "hänsynstagandena": "hänsynstagande",
    "hänsynstagandenas": "hänsynstagande",
    "hänsynstagandens": "hänsynstagande",
    "hänsynstagandes": "hänsynstagande",
    "hänsynstagandet": "hänsynstagande",
    "hänsynstagandets": "hänsynstagande",
    "hänt": "hända",
    "häntheten": "hänthet",
    "hänthetens": "hänthet",
    "häntheter": "hänthet",
    "häntheterna": "hänthet",
    "häntheternas": "hänthet",
    "häntheters": "hänthet",
    "hänthets": "hänthet",
    "hänts": "hända",
    "häntyd": "häntyda",
    "häntydande": "häntyda",
    "häntydanden": "häntydande",
    "häntydandena": "häntydande",
    "häntydandenas": "häntydande",
    "häntydandens": "häntydande",
    "häntydandes": "häntydande",
    "häntydandet": "häntydande",
    "häntydandets": "häntydande",
    "häntydas": "häntyda",
    "häntydd": "häntyda",
    "häntydda": "häntyda",
    "häntyddas": "häntyda",
    "häntydde": "häntyda",
    "häntyddes": "häntyda",
    "häntydds": "häntyda",
    "häntyder": "häntyda",
    "häntydes": "häntyda",
    "häntydningar": "häntydning",
    "häntydningarna": "häntydning",
    "häntydningarnas": "häntydning",
    "häntydningars": "häntydning",
    "häntydningen": "häntydning",
    "häntydningens": "häntydning",
    "häntydnings": "häntydning",
    "häntyds": "häntyda",
    "häntytt": "häntyda",
    "häntytts": "häntyda",
    "hänvisad": "hänvisa",
    "hänvisade": "hänvisa",
    "hänvisades": "hänvisa",
    "hänvisads": "hänvisa",
    "hänvisande": "hänvisa",
    "hänvisanden": "hänvisande",
    "hänvisandena": "hänvisande",
    "hänvisandenas": "hänvisande",
    "hänvisandens": "hänvisande",
    "hänvisandes": "hänvisande",
    "hänvisandet": "hänvisande",
    "hänvisandets": "hänvisande",
    "hänvisar": "hänvisa",
    "hänvisas": "hänvisa",
    "hänvisat": "hänvisa",
    "hänvisats": "hänvisa",
    "hänvisningar": "hänvisning",
    "hänvisningarna": "hänvisning",
    "hänvisningarnas": "hänvisning",
    "hänvisningars": "hänvisning",
    "hänvisningen": "hänvisning",
    "hänvisningens": "hänvisning",
    "hänvisnings": "hänvisning",
    "hänvändelsen": "hänvändelse",
    "hänvändelsens": "hänvändelse",
    "hänvändelser": "hänvändelse",
    "hänvändelserna": "hänvändelse",
    "hänvändelsernas": "hänvändelse",
    "hänvändelsers": "hänvändelse",
    "hänvändelses": "hänvändelse",
    "häpenheten": "häpenhet",
    "häpenhetens": "häpenhet",
    "häpenhets": "häpenhet",
    "häpens": "häpen",
    "häpet": "häpen",
    "häpets": "häpen",
    "häpna": "häpen",
    "häpnade": "häpna",
    "häpnaden": "häpnad",
    "häpnadens": "häpnad",
    "häpnader": "häpnad",
    "häpnaderna": "häpnad",
    "häpnadernas": "häpnad",
    "häpnaders": "häpnad",
    "häpnades": "häpna",
    "häpnads": "häpnad",
    "häpnande": "häpna",
    "häpnanden": "häpnande",
    "häpnandena": "häpnande",
    "häpnandenas": "häpnande",
    "häpnandens": "häpnande",
    "häpnandes": "häpnande",
    "häpnandet": "häpnande",
    "häpnandets": "häpnande",
    "häpnar": "häpna",
    "häpnare": "häpen",
    "häpnares": "häpen",
    "häpnas": "häpna",
    "häpnast": "häpen",
    "häpnaste": "häpen",
    "häpnastes": "häpen",
    "häpnasts": "häpen",
    "häpnat": "häpna",
    "häpnats": "häpna",
    "häpne": "häpen",
    "häpnes": "häpen",
    "häraden": "härad",
    "häradena": "härad",
    "häradenas": "härad",
    "häradens": "härad",
    "härader": "härad",
    "häraderna": "härad",
    "häradernas": "härad",
    "häraders": "härad",
    "häradet": "härad",
    "häradets": "härad",
    "härads": "härad",
    "häradshövdingar": "häradshövding",
    "häradshövdingarna": "häradshövding",
    "häradshövdingarnas": "häradshövding",
    "häradshövdingars": "häradshövding",
    "häradshövdingen": "häradshövding",
    "häradshövdingens": "häradshövding",
    "häradshövdings": "häradshövding",
    "häradsrätten": "häradsrätt",
    "häradsrättens": "häradsrätt",
    "häradsrätter": "häradsrätt",
    "häradsrätterna": "häradsrätt",
    "häradsrätternas": "häradsrätt",
    "häradsrätters": "häradsrätt",
    "häradsrätts": "häradsrätt",
    "häradsskrivar": "häradsskrivare",
    "häradsskrivaren": "häradsskrivare",
    "häradsskrivarens": "häradsskrivare",
    "häradsskrivares": "häradsskrivare",
    "häradsskrivarna": "häradsskrivare",
    "häradsskrivarnas": "häradsskrivare",
    "härar": "här",
    "härarna": "här",
    "härarnas": "här",
    "härars": "här",
    "härbren": "härbre",
    "härbrena": "härbre",
    "härbrenas": "härbre",
    "härbrens": "härbre",
    "härbres": "härbre",
    "härbret": "härbre",
    "härbrets": "härbre",
    "härbrs": "härbre",
    "härbärgen": "härbärge",
    "härbärgena": "härbärge",
    "härbärgenas": "härbärge",
    "härbärgens": "härbärge",
    "härbärgerad": "härbärgera",
    "härbärgerade": "härbärgera",
    "härbärgerades": "härbärgera",
    "härbärgerads": "härbärgera",
    "härbärgerande": "härbärgera",
    "härbärgeranden": "härbärgerande",
    "härbärgerandena": "härbärgerande",
    "härbärgerandenas": "härbärgerande",
    "härbärgerandens": "härbärgerande",
    "härbärgerandes": "härbärgerande",
    "härbärgerandet": "härbärgerande",
    "härbärgerandets": "härbärgerande",
    "härbärgerar": "härbärgera",
    "härbärgeras": "härbärgera",
    "härbärgerat": "härbärgera",
    "härbärgerats": "härbärgera",
    "härbärgerbara": "härbärgerbar",
    "härbärgerbarare": "härbärgerbar",
    "härbärgerbarares": "härbärgerbar",
    "härbärgerbaras": "härbärgerbar",
    "härbärgerbarast": "härbärgerbar",
    "härbärgerbaraste": "härbärgerbar",
    "härbärgerbarastes": "härbärgerbar",
    "härbärgerbarasts": "härbärgerbar",
    "härbärgerbare": "härbärgerbar",
    "härbärgerbares": "härbärgerbar",
    "härbärgerbarheten": "härbärgerbarhet",
    "härbärgerbarhetens": "härbärgerbarhet",
    "härbärgerbarhets": "härbärgerbarhet",
    "härbärgerbars": "härbärgerbar",
    "härbärgerbart": "härbärgerbar",
    "härbärgerbarts": "härbärgerbar",
    "härbärgeringar": "härbärgering",
    "härbärgeringarna": "härbärgering",
    "härbärgeringarnas": "härbärgering",
    "härbärgeringars": "härbärgering",
    "härbärgeringen": "härbärgering",
    "härbärgeringens": "härbärgering",
    "härbärgerings": "härbärgering",
    "härbärges": "härbärge",
    "härbärget": "härbärge",
    "härbärgets": "härbärge",
    "härbärgs": "härbärge",
    "härd": "härda",
    "härdad": "härda",
    "härdade": "härda",
    "härdades": "härda",
    "härdads": "härda",
    "härdande": "härda",
    "härdanden": "härdande",
    "härdandena": "härdande",
    "härdandenas": "härdande",
    "härdandens": "härdande",
    "härdandes": "härdande",
    "härdandet": "härdande",
    "härdandets": "härdande",
    "härdar": "härda",
    "härdarna": "härd",
    "härdarnas": "härd",
    "härdars": "härd",
    "härdas": "härda",
    "härdat": "härda",
    "härdats": "härda",
    "härden": "härd",
    "härdens": "härd",
    "härdiga": "härdig",
    "härdigare": "härdig",
    "härdigares": "härdig",
    "härdigas": "härdig",
    "härdigast": "härdig",
    "härdigaste": "härdig",
    "härdigastes": "härdig",
    "härdigasts": "härdig",
    "härdige": "härdig",
    "härdiges": "härdig",
    "härdigheten": "härdighet",
    "härdighetens": "härdighet",
    "härdigheter": "härdighet",
    "härdigheterna": "härdighet",
    "härdigheternas": "härdighet",
    "härdigheters": "härdighet",
    "härdighets": "härdighet",
    "härdighetskraven": "härdighetskrav",
    "härdighetskravens": "härdighetskrav",
    "härdighetskravet": "härdighetskrav",
    "härdighetskravets": "härdighetskrav",
    "härdighetskravs": "härdighetskrav",
    "härdigs": "härdig",
    "härdigt": "härdig",
    "härdigts": "härdig",
    "härdlacken": "härdlack",
    "härdlackens": "härdlack",
    "härdlacker": "härdlack",
    "härdlackerna": "härdlack",
    "härdlackernas": "härdlack",
    "härdlackers": "härdlack",
    "härdlacks": "härdlack",
    "härdningar": "härdning",
    "härdningarna": "härdning",
    "härdningarnas": "härdning",
    "härdningars": "härdning",
    "härdningen": "härdning",
    "härdningens": "härdning",
    "härdnings": "härdning",
    "härdningstiden": "härdningstid",
    "härdningstidens": "härdningstid",
    "härdningstider": "härdningstid",
    "härdningstiderna": "härdningstid",
    "härdningstidernas": "härdningstid",
    "härdningstiders": "härdningstid",
    "härdningstids": "härdningstid",
    "härdplasten": "härdplast",
    "härdplastens": "härdplast",
    "härdplaster": "härdplast",
    "härdplasterna": "härdplast",
    "härdplasternas": "härdplast",
    "härdplasters": "härdplast",
    "härdplasts": "härdplast",
    "härds": "härd",
    "härdsmält": "härdsmälta",
    "härdsmältan": "härdsmälta",
    "härdsmältans": "härdsmälta",
    "härdsmältas": "härdsmälta",
    "härdsmälte": "härdsmälta",
    "härdsmältor": "härdsmälta",
    "härdsmältorna": "härdsmälta",
    "härdsmältornas": "härdsmälta",
    "härdsmältors": "härdsmälta",
    "härdsmälts": "härdsmälta",
    "härdtiden": "härdtid",
    "härdtidens": "härdtid",
    "härdtider": "härdtid",
    "härdtiderna": "härdtid",
    "härdtidernas": "härdtid",
    "härdtiders": "härdtid",
    "härdtids": "härdtid",
    "hären": "här",
    "härens": "här",
    "härfluten": "härflyta",
    "härflutens": "härflyta",
    "härflutet": "härflyta",
    "härflutets": "härflyta",
    "härflutit": "härflyta",
    "härflutits": "härflyta",
    "härflutna": "härflyta",
    "härflutnas": "härflyta",
    "härflutne": "härflyta",
    "härflutnes": "härflyta",
    "härflyt": "härflyta",
    "härflytande": "härflyta",
    "härflytanden": "härflytande",
    "härflytandena": "härflytande",
    "härflytandenas": "härflytande",
    "härflytandens": "härflytande",
    "härflytandes": "härflytande",
    "härflytandet": "härflytande",
    "härflytandets": "härflytande",
    "härflytas": "härflyta",
    "härflyte": "härflyta",
    "härflyter": "härflyta",
    "härflytes": "härflyta",
    "härflyts": "härflyta",
    "härflöt": "härflyta",
    "härflöte": "härflyta",
    "härflötes": "härflyta",
    "härflöts": "härflyta",
    "härfågeln": "härfågel",
    "härfågelns": "härfågel",
    "härfågels": "härfågel",
    "härfåglar": "härfågel",
    "härfåglarna": "härfågel",
    "härfåglarnas": "härfågel",
    "härfåglars": "härfågel",
    "härförar": "härförare",
    "härföraren": "härförare",
    "härförarens": "härförare",
    "härförares": "härförare",
    "härförarna": "härförare",
    "härförarnas": "härförare",
    "härj": "härja",
    "härjad": "härja",
    "härjade": "härjad",
    "härjades": "härjad",
    "härjads": "härjad",
    "härjande": "härja",
    "härjanden": "härjande",
    "härjandena": "härjande",
    "härjandenas": "härjande",
    "härjandens": "härjande",
    "härjandes": "härjande",
    "härjandet": "härjande",
    "härjandets": "härjande",
    "härjar": "härja",
    "härjas": "härja",
    "härjat": "härjad",
    "härjats": "härjad",
    "härjedalingar": "härjedaling",
    "härjedalingarna": "härjedaling",
    "härjedalingarnas": "härjedaling",
    "härjedalingars": "härjedaling",
    "härjedalingen": "härjedaling",
    "härjedalingens": "härjedaling",
    "härjedalings": "härjedaling",
    "härjedalsk": "härjedalska",
    "härjedalska": "härjedalsk",
    "härjedalskan": "härjedalska",
    "härjedalskans": "härjedalska",
    "härjedalskare": "härjedalsk",
    "härjedalskares": "härjedalsk",
    "härjedalskas": "härjedalska",
    "härjedalskast": "härjedalsk",
    "härjedalskaste": "härjedalsk",
    "härjedalskastes": "härjedalsk",
    "härjedalskasts": "härjedalsk",
    "härjedalske": "härjedalska",
    "härjedalskes": "härjedalsk",
    "härjedalskor": "härjedalska",
    "härjedalskorna": "härjedalska",
    "härjedalskornas": "härjedalska",
    "härjedalskors": "härjedalska",
    "härjedalsks": "härjedalsk",
    "härjedalskt": "härjedalsk",
    "härjedalskts": "härjedalsk",
    "härjningar": "härjning",
    "härjningarna": "härjning",
    "härjningarnas": "härjning",
    "härjningars": "härjning",
    "härjningen": "härjning",
    "härjningens": "härjning",
    "härjnings": "härjning",
    "härkar": "härk",
    "härkarna": "härk",
    "härkarnas": "härk",
    "härkars": "härk",
    "härken": "härk",
    "härkens": "härk",
    "härkomsten": "härkomst",
    "härkomstens": "härkomst",
    "härkomsts": "härkomst",
    "härks": "härk",
    "härled": "härleda",
    "härledande": "härleda",
    "härledanden": "härledande",
    "härledandena": "härledande",
    "härledandenas": "härledande",
    "härledandens": "härledande",
    "härledandes": "härledande",
    "härledandet": "härledande",
    "härledandets": "härledande",
    "härledas": "härleda",
    "härledd": "härleda",
    "härledda": "härleda",
    "härleddas": "härleda",
    "härledde": "härleda",
    "härleddes": "härleda",
    "härledds": "härleda",
    "härleder": "härleda",
    "härledes": "härleda",
    "härledningar": "härledning",
    "härledningarna": "härledning",
    "härledningarnas": "härledning",
    "härledningars": "härledning",
    "härledningen": "härledning",
    "härledningens": "härledning",
    "härlednings": "härledning",
    "härleds": "härleda",
    "härlett": "härleda",
    "härletts": "härleda",
    "härliga": "härlig",
    "härligare": "härlig",
    "härligares": "härlig",
    "härligas": "härlig",
    "härligast": "härlig",
    "härligaste": "härlig",
    "härligastes": "härlig",
    "härligasts": "härlig",
    "härlige": "härlig",
    "härliges": "härlig",
    "härligheten": "härlighet",
    "härlighetens": "härlighet",
    "härligheter": "härlighet",
    "härligheterna": "härlighet",
    "härligheternas": "härlighet",
    "härligheters": "härlighet",
    "härlighets": "härlighet",
    "härligs": "härlig",
    "härligt": "härlig",
    "härligts": "härlig",
    "härm": "härma",
    "härmad": "härma",
    "härmade": "härma",
    "härmades": "härma",
    "härmads": "härma",
    "härmande": "härma",
    "härmanden": "härmande",
    "härmandena": "härmande",
    "härmandenas": "härmande",
    "härmandens": "härmande",
    "härmandes": "härmande",
    "härmandet": "härmande",
    "härmandets": "härmande",
    "härmapan": "härmapa",
    "härmapans": "härmapa",
    "härmapas": "härmapa",
    "härmape": "härmapa",
    "härmapor": "härmapa",
    "härmaporna": "härmapa",
    "härmapornas": "härmapa",
    "härmapors": "härmapa",
    "härmar": "härma",
    "härmas": "härma",
    "härmaskar": "härmask",
    "härmaskarna": "härmask",
    "härmaskarnas": "härmask",
    "härmaskars": "härmask",
    "härmasken": "härmask",
    "härmaskens": "härmask",
    "härmasks": "härmask",
    "härmat": "härma",
    "härmats": "härma",
    "härmfågeln": "härmfågel",
    "härmfågelns": "härmfågel",
    "härmfågels": "härmfågel",
    "härmfåglar": "härmfågel",
    "härmfåglarna": "härmfågel",
    "härmfåglarnas": "härmfågel",
    "härmfåglars": "härmfågel",
    "härnaden": "härnad",
    "härnadens": "härnad",
    "härnader": "härnad",
    "härnaderna": "härnad",
    "härnadernas": "härnad",
    "härnaders": "härnad",
    "härnads": "härnad",
    "härolden": "härold",
    "häroldens": "härold",
    "härolder": "härold",
    "härolderna": "härold",
    "häroldernas": "härold",
    "härolders": "härold",
    "härolds": "härold",
    "härordningar": "härordning",
    "härordningarna": "härordning",
    "härordningarnas": "härordning",
    "härordningars": "härordning",
    "härordningen": "härordning",
    "härordningens": "härordning",
    "härordnings": "härordning",
    "härrör": "härröra",
    "härrörande": "härröra",
    "härröranden": "härrörande",
    "härrörandena": "härrörande",
    "härrörandenas": "härrörande",
    "härrörandens": "härrörande",
    "härrörandes": "härrörande",
    "härrörandet": "härrörande",
    "härrörandets": "härrörande",
    "härrörde": "härröra",
    "härrörer": "härröra",
    "härrört": "härröra",
    "härs": "här",
    "härsk": "härska",
    "härskade": "härska",
    "härskades": "härska",
    "härskande": "härska",
    "härskanden": "härskande",
    "härskandena": "härskande",
    "härskandenas": "härskande",
    "härskandens": "härskande",
    "härskandes": "härskande",
    "härskandet": "härskande",
    "härskandets": "härskande",
    "härskar": "härskare",
    "härskaran": "härskara",
    "härskarans": "härskara",
    "härskaras": "härskara",
    "härskare": "härskara",
    "härskaren": "härskare",
    "härskarens": "härskare",
    "härskares": "härskare",
    "härskarinnan": "härskarinna",
    "härskarinnans": "härskarinna",
    "härskarinnas": "härskarinna",
    "härskarinne": "härskarinna",
    "härskarinnor": "härskarinna",
    "härskarinnorna": "härskarinna",
    "härskarinnornas": "härskarinna",
    "härskarinnors": "härskarinna",
    "härskarklassen": "härskarklass",
    "härskarklassens": "härskarklass",
    "härskarklasser": "härskarklass",
    "härskarklasserna": "härskarklass",
    "härskarklassernas": "härskarklass",
    "härskarklassers": "härskarklass",
    "härskarna": "härskare",
    "härskarnas": "härskare",
    "härskaror": "härskara",
    "härskarorna": "härskara",
    "härskarornas": "härskara",
    "härskarors": "härskara",
    "härskarparen": "härskarpar",
    "härskarparens": "härskarpar",
    "härskarparet": "härskarpar",
    "härskarparets": "härskarpar",
    "härskarpars": "härskarpar",
    "härskars": "härskara",
    "härskas": "härska",
    "härskat": "härska",
    "härskats": "härska",
    "härskenheten": "härskenhet",
    "härskenhetens": "härskenhet",
    "härskenhets": "härskenhet",
    "härskens": "härsken",
    "härsket": "härsken",
    "härskets": "härsken",
    "härsklystenheten": "härsklystenhet",
    "härsklystenhetens": "härsklystenhet",
    "härsklystenhets": "härsklystenhet",
    "härsklystens": "härsklysten",
    "härsklystet": "härsklysten",
    "härsklystets": "härsklysten",
    "härsklystna": "härsklysten",
    "härsklystnare": "härsklysten",
    "härsklystnares": "härsklysten",
    "härsklystnas": "härsklysten",
    "härsklystnast": "härsklysten",
    "härsklystnaste": "härsklysten",
    "härsklystnastes": "härsklysten",
    "härsklystnasts": "härsklysten",
    "härsklystne": "härsklysten",
    "härsklystnes": "härsklysten",
    "härskn": "härskna",
    "härskna": "härsken",
    "härsknad": "härskna",
    "härsknade": "härskna",
    "härsknades": "härskna",
    "härsknads": "härskna",
    "härsknande": "härskna",
    "härsknanden": "härsknande",
    "härsknandena": "härsknande",
    "härsknandenas": "härsknande",
    "härsknandens": "härsknande",
    "härsknandes": "härsknande",
    "härsknandet": "härsknande",
    "härsknandets": "härsknande",
    "härsknar": "härskna",
    "härsknare": "härsken",
    "härsknares": "härsken",
    "härsknas": "härskna",
    "härsknast": "härsken",
    "härsknaste": "härsken",
    "härsknastes": "härsken",
    "härsknasts": "härsken",
    "härsknat": "härskna",
    "härsknats": "härskna",
    "härskne": "härsken",
    "härsknes": "härsken",
    "härskrien": "härskri",
    "härskriens": "härskri",
    "härskriet": "härskri",
    "härskriets": "härskri",
    "härskrin": "härskri",
    "härskrina": "härskri",
    "härskrinas": "härskri",
    "härskrins": "härskri",
    "härskris": "härskri",
    "härskrit": "härskri",
    "härskrits": "härskri",
    "härstammade": "härstamma",
    "härstammades": "härstamma",
    "härstammande": "härstamma",
    "härstammanden": "härstammande",
    "härstammandena": "härstammande",
    "härstammandenas": "härstammande",
    "härstammandens": "härstammande",
    "härstammandes": "härstammande",
    "härstammandet": "härstammande",
    "härstammandets": "härstammande",
    "härstammar": "härstamma",
    "härstammas": "härstamma",
    "härstammat": "härstamma",
    "härstammats": "härstamma",
    "härstamningar": "härstamning",
    "härstamningarna": "härstamning",
    "härstamningarnas": "härstamning",
    "härstamningars": "härstamning",
    "härstamningen": "härstamning",
    "härstamningens": "härstamning",
    "härstamnings": "härstamning",
    "härtagens": "härtagen",
    "härtaget": "härtagen",
    "härtagets": "härtagen",
    "härtagna": "härtagen",
    "härtagnare": "härtagen",
    "härtagnares": "härtagen",
    "härtagnas": "härtagen",
    "härtagnast": "härtagen",
    "härtagnaste": "härtagen",
    "härtagnastes": "härtagen",
    "härtagnasts": "härtagen",
    "härtagne": "härtagen",
    "härtagnes": "härtagen",
    "härtappade": "härtappad",
    "härtappades": "härtappad",
    "härtappads": "härtappad",
    "härtappat": "härtappad",
    "härtappats": "härtappad",
    "härv": "härva",
    "härvan": "härva",
    "härvans": "härva",
    "härvas": "härva",
    "härve": "härva",
    "härveln": "härvel",
    "härvelns": "härvel",
    "härvels": "härvel",
    "härvlar": "härvel",
    "härvlarna": "härvel",
    "härvlarnas": "härvel",
    "härvlars": "härvel",
    "härvor": "härva",
    "härvorna": "härva",
    "härvornas": "härva",
    "härvors": "härva",
    "härvs": "härva",
    "hässj": "hässja",
    "hässjad": "hässja",
    "hässjade": "hässja",
    "hässjades": "hässja",
    "hässjads": "hässja",
    "hässjan": "hässja",
    "hässjande": "hässja",
    "hässjanden": "hässjande",
    "hässjandena": "hässjande",
    "hässjandenas": "hässjande",
    "hässjandens": "hässjande",
    "hässjandes": "hässjande",
    "hässjandet": "hässjande",
    "hässjandets": "hässjande",
    "hässjans": "hässja",
    "hässjar": "hässja",
    "hässjas": "hässja",
    "hässjat": "hässja",
    "hässjats": "hässja",
    "hässje": "hässja",
    "hässjor": "hässja",
    "hässjorna": "hässja",
    "hässjornas": "hässja",
    "hässjors": "hässja",
    "hästansikten": "hästansikte",
    "hästansiktena": "hästansikte",
    "hästansiktenas": "hästansikte",
    "hästansiktens": "hästansikte",
    "hästansiktes": "hästansikte",
    "hästansiktet": "hästansikte",
    "hästansiktets": "hästansikte",
    "hästansikts": "hästansikte",
    "hästar": "häst",
    "hästarna": "häst",
    "hästarnas": "häst",
    "hästars": "häst",
    "hästbenen": "hästben",
    "hästbenens": "hästben",
    "hästbenet": "hästben",
    "hästbenets": "hästben",
    "hästbens": "hästben",
    "hästbond": "hästbonde",
    "hästbonden": "hästbonde",
    "hästbondens": "hästbonde",
    "hästbondes": "hästbonde",
    "hästbonds": "hästbonde",
    "hästbönder": "hästbonde",
    "hästbönderna": "hästbonde",
    "hästböndernas": "hästbonde",
    "hästbönders": "hästbonde",
    "hästdjuren": "hästdjur",
    "hästdjurens": "hästdjur",
    "hästdjuret": "hästdjur",
    "hästdjurets": "hästdjur",
    "hästdjurs": "hästdjur",
    "hästdragens": "hästdragen",
    "hästdraget": "hästdragen",
    "hästdragets": "hästdragen",
    "hästdragna": "hästdragen",
    "hästdragnare": "hästdragen",
    "hästdragnares": "hästdragen",
    "hästdragnas": "hästdragen",
    "hästdragnast": "hästdragen",
    "hästdragnaste": "hästdragen",
    "hästdragnastes": "hästdragen",
    "hästdragnasts": "hästdragen",
    "hästdragne": "hästdragen",
    "hästdragnes": "hästdragen",
    "hästdressyren": "hästdressyr",
    "hästdressyrens": "hästdressyr",
    "hästdressyrer": "hästdressyr",
    "hästdressyrerna": "hästdressyr",
    "hästdressyrernas": "hästdressyr",
    "hästdressyrers": "hästdressyr",
    "hästdressyrs": "hästdressyr",
    "hästen": "häst",
    "hästens": "häst",
    "hästgrim": "hästgrimma",
    "hästgrimman": "hästgrimma",
    "hästgrimmans": "hästgrimma",
    "hästgrimmas": "hästgrimma",
    "hästgrimme": "hästgrimma",
    "hästgrimmor": "hästgrimma",
    "hästgrimmorna": "hästgrimma",
    "hästgrimmornas": "hästgrimma",
    "hästgrimmors": "hästgrimma",
    "hästgrims": "hästgrimma",
    "hästhovar": "hästhov",
    "hästhovarna": "hästhov",
    "hästhovarnas": "hästhov",
    "hästhovars": "hästhov",
    "hästhoven": "hästhov",
    "hästhovens": "hästhov",
    "hästhovs": "hästhov",
    "hästhovsörten": "hästhovsört",
    "hästhovsörtens": "hästhovsört",
    "hästhovsörter": "hästhovsört",
    "hästhovsörterna": "hästhovsört",
    "hästhovsörternas": "hästhovsört",
    "hästhovsörters": "hästhovsört",
    "hästhovsörts": "hästhovsört",
    "hästhuvuden": "hästhuvud",
    "hästhuvudena": "hästhuvud",
    "hästhuvudenas": "hästhuvud",
    "hästhuvudens": "hästhuvud",
    "hästhuvudet": "hästhuvud",
    "hästhuvudets": "hästhuvud",
    "hästhuvudnebulosans": "hästhuvudnebulosan",
    "hästhuvuds": "hästhuvud",
    "hästkapplöpningar": "hästkapplöpning",
    "hästkapplöpningarna": "hästkapplöpning",
    "hästkapplöpningarnas": "hästkapplöpning",
    "hästkapplöpningars": "hästkapplöpning",
    "hästkapplöpningen": "hästkapplöpning",
    "hästkapplöpningens": "hästkapplöpning",
    "hästkapplöpnings": "hästkapplöpning",
    "hästkapplöpningsbanan": "hästkapplöpningsbana",
    "hästkapplöpningsbanans": "hästkapplöpningsbana",
    "hästkapplöpningsbanas": "hästkapplöpningsbana",
    "hästkapplöpningsbane": "hästkapplöpningsbana",
    "hästkapplöpningsbanor": "hästkapplöpningsbana",
    "hästkapplöpningsbanorna": "hästkapplöpningsbana",
    "hästkapplöpningsbanornas": "hästkapplöpningsbana",
    "hästkapplöpningsbanors": "hästkapplöpningsbana",
    "hästkastanjen": "hästkastanj",
    "hästkastanjens": "hästkastanj",
    "hästkastanjer": "hästkastanj",
    "hästkastanjerna": "hästkastanj",
    "hästkastanjernas": "hästkastanj",
    "hästkastanjers": "hästkastanj",
    "hästkastanjs": "hästkastanj",
    "hästkraften": "hästkraft",
    "hästkraftens": "hästkraft",
    "hästkrafter": "hästkraft",
    "hästkrafterna": "hästkraft",
    "hästkrafternas": "hästkraft",
    "hästkrafters": "hästkraft",
    "hästkrafts": "hästkraft",
    "hästkrak": "hästkrake",
    "hästkrakar": "hästkrake",
    "hästkrakarna": "hästkrake",
    "hästkrakarnas": "hästkrake",
    "hästkrakars": "hästkrake",
    "hästkraken": "hästkrake",
    "hästkrakens": "hästkrake",
    "hästkrakes": "hästkrake",
    "hästkraks": "hästkrake",
    "hästkuren": "hästkur",
    "hästkurens": "hästkur",
    "hästkurer": "hästkur",
    "hästkurerna": "hästkur",
    "hästkurernas": "hästkur",
    "hästkurers": "hästkur",
    "hästkurs": "hästkur",
    "hästkärr": "hästkärra",
    "hästkärran": "hästkärra",
    "hästkärrans": "hästkärra",
    "hästkärras": "hästkärra",
    "hästkärre": "hästkärra",
    "hästkärror": "hästkärra",
    "hästkärrorna": "hästkärra",
    "hästkärrornas": "hästkärra",
    "hästkärrors": "hästkärra",
    "hästkärrs": "hästkärra",
    "hästlassen": "hästlass",
    "hästlassens": "hästlass",
    "hästlasset": "hästlass",
    "hästlassets": "hästlass",
    "hästlängden": "hästlängd",
    "hästlängdens": "hästlängd",
    "hästlängder": "hästlängd",
    "hästlängderna": "hästlängd",
    "hästlängdernas": "hästlängd",
    "hästlängders": "hästlängd",
    "hästlängds": "hästlängd",
    "hästminnes": "hästminne",
    "hästminnet": "hästminne",
    "hästminnets": "hästminne",
    "hästpolon": "hästpolo",
    "hästpolons": "hästpolo",
    "hästpolos": "hästpolo",
    "hästrasen": "hästras",
    "hästrasens": "hästras",
    "hästraser": "hästras",
    "hästraserna": "hästras",
    "hästrasernas": "hästras",
    "hästrasers": "hästras",
    "hästryggar": "hästrygg",
    "hästryggarna": "hästrygg",
    "hästryggarnas": "hästrygg",
    "hästryggars": "hästrygg",
    "hästryggen": "hästrygg",
    "hästryggens": "hästrygg",
    "hästryggs": "hästrygg",
    "hästräfs": "hästräfsa",
    "hästräfsan": "hästräfsa",
    "hästräfsans": "hästräfsa",
    "hästräfsas": "hästräfsa",
    "hästräfse": "hästräfsa",
    "hästräfsor": "hästräfsa",
    "hästräfsorna": "hästräfsa",
    "hästräfsornas": "hästräfsa",
    "hästräfsors": "hästräfsa",
    "hästs": "häst",
    "hästskjutsar": "hästskjuts",
    "hästskjutsarna": "hästskjuts",
    "hästskjutsarnas": "hästskjuts",
    "hästskjutsars": "hästskjuts",
    "hästskjutsen": "hästskjuts",
    "hästskjutsens": "hästskjuts",
    "hästskobåg": "hästskobåge",
    "hästskobågar": "hästskobåge",
    "hästskobågarna": "hästskobåge",
    "hästskobågarnas": "hästskobåge",
    "hästskobågars": "hästskobåge",
    "hästskobågen": "hästskobåge",
    "hästskobågens": "hästskobåge",
    "hästskobåges": "hästskobåge",
    "hästskobågs": "hästskobåge",
    "hästskojar": "hästskojare",
    "hästskojaren": "hästskojare",
    "hästskojarens": "hästskojare",
    "hästskojares": "hästskojare",
    "hästskojarna": "hästskojare",
    "hästskojarnas": "hästskojare",
    "hästskomagneten": "hästskomagnet",
    "hästskomagnetens": "hästskomagnet",
    "hästskomagneter": "hästskomagnet",
    "hästskomagneterna": "hästskomagnet",
    "hästskomagneternas": "hästskomagnet",
    "hästskomagneters": "hästskomagnet",
    "hästskomagnets": "hästskomagnet",
    "hästskon": "hästsko",
    "hästskons": "hästsko",
    "hästskor": "hästsko",
    "hästskorna": "hästsko",
    "hästskornas": "hästsko",
    "hästskors": "hästsko",
    "hästskos": "hästsko",
    "hästskosömmen": "hästskosöm",
    "hästskosömmens": "hästskosöm",
    "hästskosömmet": "hästskosöm",
    "hästskosömmets": "hästskosöm",
    "hästskosöms": "hästskosöm",
    "hästspannen": "hästspann",
    "hästspannens": "hästspann",
    "hästspannet": "hästspann",
    "hästspannets": "hästspann",
    "hästspanns": "hästspann",
    "häststyngen": "häststyng",
    "häststyngens": "häststyng",
    "häststynget": "häststyng",
    "häststyngets": "häststyng",
    "häststyngs": "häststyng",
    "hästsvansar": "hästsvans",
    "hästsvansarna": "hästsvans",
    "hästsvansarnas": "hästsvans",
    "hästsvansars": "hästsvans",
    "hästsvansen": "hästsvans",
    "hästsvansens": "hästsvans",
    "hästtämjandes": "hästtämjande",
    "hästtämjandet": "hästtämjande",
    "hästtämjandets": "hästtämjande",
    "hästvagnar": "hästvagn",
    "hästvagnarna": "hästvagn",
    "hästvagnarnas": "hästvagn",
    "hästvagnars": "hästvagn",
    "hästvagnen": "hästvagn",
    "hästvagnens": "hästvagn",
    "hästvagns": "hästvagn",
    "hätska": "hätsk",
    "hätskare": "hätsk",
    "hätskares": "hätsk",
    "hätskas": "hätsk",
    "hätskast": "hätsk",
    "hätskaste": "hätsk",
    "hätskastes": "hätsk",
    "hätskasts": "hätsk",
    "hätske": "hätsk",
    "hätskes": "hätsk",
    "hätskheten": "hätskhet",
    "hätskhetens": "hätskhet",
    "hätskheter": "hätskhet",
    "hätskheterna": "hätskhet",
    "hätskheternas": "hätskhet",
    "hätskheters": "hätskhet",
    "hätskhets": "hätskhet",
    "hätsks": "hätsk",
    "hätskt": "hätsk",
    "hätskts": "hätsk",
    "hätt": "hätta",
    "hättan": "hätta",
    "hättans": "hätta",
    "hättas": "hätta",
    "hätte": "hätta",
    "hättor": "hätta",
    "hättorna": "hätta",
    "hättornas": "hätta",
    "hättors": "hätta",
    "hätts": "hätta",
    "häv": "häva",
    "hävande": "häva",
    "hävanden": "hävande",
    "hävandena": "hävande",
    "hävandenas": "hävande",
    "hävandens": "hävande",
    "hävandes": "hävande",
    "hävandet": "hävande",
    "hävandets": "hävande",
    "hävarmar": "hävarm",
    "hävarmarna": "hävarm",
    "hävarmarnas": "hävarm",
    "hävarmars": "hävarm",
    "hävarmen": "hävarm",
    "hävarmens": "hävarm",
    "hävarms": "hävarm",
    "hävarmslyftar": "hävarmslyft",
    "hävarmslyftarna": "hävarmslyft",
    "hävarmslyftarnas": "hävarmslyft",
    "hävarmslyftars": "hävarmslyft",
    "hävarmslyften": "hävarmslyft",
    "hävarmslyftens": "hävarmslyft",
    "hävarmslyfts": "hävarmslyft",
    "hävas": "häva",
    "hävd": "hävder",
    "hävda": "häva",
    "hävdad": "hävda",
    "hävdade": "hävda",
    "hävdades": "hävda",
    "hävdads": "hävda",
    "hävdande": "hävda",
    "hävdanden": "hävdande",
    "hävdandena": "hävdande",
    "hävdandenas": "hävdande",
    "hävdandens": "hävdande",
    "hävdandes": "hävdande",
    "hävdandet": "hävdande",
    "hävdandets": "hävdande",
    "hävdar": "hävda",
    "hävdas": "hävda",
    "hävdat": "hävda",
    "hävdatecknar": "hävdatecknare",
    "hävdatecknaren": "hävdatecknare",
    "hävdatecknarens": "hävdatecknare",
    "hävdatecknares": "hävdatecknare",
    "hävdatecknarna": "hävdatecknare",
    "hävdatecknarnas": "hävdatecknare",
    "hävdats": "hävda",
    "hävde": "häva",
    "hävdelsen": "hävdelse",
    "hävdelsens": "hävdelse",
    "hävdelses": "hävdelse",
    "hävden": "hävd",
    "hävdens": "hävd",
    "hävder": "hävd",
    "hävderna": "hävder",
    "hävdernas": "hävder",
    "hävders": "hävder",
    "hävdes": "häva",
    "hävds": "hävder",
    "hävdvunna": "hävdvunnen",
    "hävdvunnare": "hävdvunnen",
    "hävdvunnares": "hävdvunnen",
    "hävdvunnas": "hävdvunnen",
    "hävdvunnast": "hävdvunnen",
    "hävdvunnaste": "hävdvunnen",
    "hävdvunnastes": "hävdvunnen",
    "hävdvunnasts": "hävdvunnen",
    "hävdvunne": "hävdvunnen",
    "hävdvunnenheten": "hävdvunnenhet",
    "hävdvunnenhetens": "hävdvunnenhet",
    "hävdvunnenhets": "hävdvunnenhet",
    "hävdvunnens": "hävdvunnen",
    "hävdvunnes": "hävdvunnen",
    "hävdvunnet": "hävdvunnen",
    "hävdvunnets": "hävdvunnen",
    "häveln": "hävel",
    "hävelns": "hävel",
    "hävels": "hävel",
    "häver": "häva",
    "hävertar": "hävert",
    "hävertarna": "hävert",
    "hävertarnas": "hävert",
    "hävertars": "hävert",
    "häverten": "hävert",
    "hävertens": "hävert",
    "häverts": "hävert",
    "häves": "häva",
    "hävlar": "hävel",
    "hävlarna": "hävel",
    "hävlarnas": "hävel",
    "hävlars": "hävel",
    "hävs": "häva",
    "hävstänger": "hävstång",
    "hävstängerna": "hävstång",
    "hävstängernas": "hävstång",
    "hävstängers": "hävstång",
    "hävstången": "hävstång",
    "hävstångens": "hävstång",
    "hävstångs": "hävstång",
    "hävstångsarmar": "hävstångsarm",
    "hävstångsarmarna": "hävstångsarm",
    "hävstångsarmarnas": "hävstångsarm",
    "hävstångsarmars": "hävstångsarm",
    "hävstångsarmen": "hävstångsarm",
    "hävstångsarmens": "hävstångsarm",
    "hävstångsarms": "hävstångsarm",
    "hävt": "häva",
    "hävts": "häva",
    "häx": "häxa",
    "häxan": "häxa",
    "häxans": "häxa",
    "häxas": "häxa",
    "häxdansen": "häxdans",
    "häxdansens": "häxdans",
    "häxdanser": "häxdans",
    "häxdanserna": "häxdans",
    "häxdansernas": "häxdans",
    "häxdansers": "häxdans",
    "häxe": "häxa",
    "häxerier": "häxeri",
    "häxerierna": "häxeri",
    "häxeriernas": "häxeri",
    "häxeriers": "häxeri",
    "häxeriet": "häxeri",
    "häxeriets": "häxeri",
    "häxeris": "häxeri",
    "häxerit": "häxeri",
    "häxerits": "häxeri",
    "häxjakten": "häxjakt",
    "häxjaktens": "häxjakt",
    "häxjakter": "häxjakt",
    "häxjakterna": "häxjakt",
    "häxjakternas": "häxjakt",
    "häxjakters": "häxjakt",
    "häxjakts": "häxjakt",
    "häxkitteln": "häxkittel",
    "häxkittelns": "häxkittel",
    "häxkittels": "häxkittel",
    "häxkittlar": "häxkittel",
    "häxkittlarna": "häxkittel",
    "häxkittlarnas": "häxkittel",
    "häxkittlars": "häxkittel",
    "häxkonspirationen": "häxkonspiration",
    "häxkonspirationens": "häxkonspiration",
    "häxkonspirationer": "häxkonspiration",
    "häxkonspirationerna": "häxkonspiration",
    "häxkonspirationernas": "häxkonspiration",
    "häxkonspirationers": "häxkonspiration",
    "häxkonspirations": "häxkonspiration",
    "häxmästar": "häxmästare",
    "häxmästaren": "häxmästare",
    "häxmästarens": "häxmästare",
    "häxmästares": "häxmästare",
    "häxmästarna": "häxmästare",
    "häxmästarnas": "häxmästare",
    "häxor": "häxa",
    "häxorna": "häxa",
    "häxornas": "häxa",
    "häxors": "häxa",
    "häxprocessen": "häxprocess",
    "häxprocessens": "häxprocess",
    "häxprocesser": "häxprocess",
    "häxprocesserna": "häxprocess",
    "häxprocessernas": "häxprocess",
    "häxprocessers": "häxprocess",
    "häxringar": "häxring",
    "häxringarna": "häxring",
    "häxringarnas": "häxring",
    "häxringars": "häxring",
    "häxringen": "häxring",
    "häxringens": "häxring",
    "häxrings": "häxring",
    "häxsabbaten": "häxsabbat",
    "häxsabbatens": "häxsabbat",
    "häxsabbater": "häxsabbat",
    "häxsabbaterna": "häxsabbat",
    "häxsabbaternas": "häxsabbat",
    "häxsabbaters": "häxsabbat",
    "häxsabbats": "häxsabbat",
    "håbrandar": "håbrand",
    "håbrandarna": "håbrand",
    "håbrandarnas": "håbrand",
    "håbrandars": "håbrand",
    "håbranden": "håbrand",
    "håbrandens": "håbrand",
    "håbrands": "håbrand",
    "hågade": "hågad",
    "hågades": "hågad",
    "hågads": "hågad",
    "hågat": "hågad",
    "hågats": "hågad",
    "hågen": "håg",
    "hågens": "håg",
    "hågkomsten": "hågkomst",
    "hågkomstens": "hågkomst",
    "hågkomster": "hågkomst",
    "hågkomsterna": "hågkomst",
    "hågkomsternas": "hågkomst",
    "hågkomsters": "hågkomst",
    "hågkomsts": "hågkomst",
    "håglösa": "håglös",
    "håglösare": "håglös",
    "håglösares": "håglös",
    "håglösas": "håglös",
    "håglösast": "håglös",
    "håglösaste": "håglös",
    "håglösastes": "håglös",
    "håglösasts": "håglös",
    "håglöse": "håglös",
    "håglöses": "håglös",
    "håglösheten": "håglöshet",
    "håglöshetens": "håglöshet",
    "håglöshets": "håglöshet",
    "håglöst": "håglös",
    "håglösts": "håglös",
    "hågs": "håg",
    "håkens": "håken",
    "håkäringar": "håkäring",
    "håkäringarna": "håkäring",
    "håkäringarnas": "håkäring",
    "håkäringars": "håkäring",
    "håkäringen": "håkäring",
    "håkäringens": "håkäring",
    "håkärings": "håkäring",
    "hål": "håla",
    "hålad": "håla",
    "hålade": "håla",
    "hålades": "håla",
    "hålads": "håla",
    "hålan": "håla",
    "hålande": "håla",
    "hålanden": "hålande",
    "hålandena": "hålande",
    "hålandenas": "hålande",
    "hålandens": "hålande",
    "hålandes": "hålande",
    "hålandet": "hålande",
    "hålandets": "hålande",
    "hålans": "håla",
    "hålar": "håla",
    "hålas": "håla",
    "hålat": "håla",
    "hålats": "håla",
    "håle": "håla",
    "hålen": "hål",
    "hålens": "hål",
    "hålet": "hål",
    "hålets": "hål",
    "hålfoten": "hålfot",
    "hålfotens": "hålfot",
    "hålfots": "hålfot",
    "hålfotsinläggen": "hålfotsinlägg",
    "hålfotsinläggens": "hålfotsinlägg",
    "hålfotsinlägget": "hålfotsinlägg",
    "hålfotsinläggets": "hålfotsinlägg",
    "hålfotsinläggs": "hålfotsinlägg",
    "hålfötter": "hålfot",
    "hålfötterna": "hålfot",
    "hålfötternas": "hålfot",
    "hålfötters": "hålfot",
    "håliga": "hålig",
    "håligare": "hålig",
    "håligares": "hålig",
    "håligas": "hålig",
    "håligast": "hålig",
    "håligaste": "hålig",
    "håligastes": "hålig",
    "håligasts": "hålig",
    "hålige": "hålig",
    "håliges": "hålig",
    "håligheten": "hålighet",
    "hålighetens": "hålighet",
    "håligheter": "hålighet",
    "håligheterna": "hålighet",
    "håligheternas": "hålighet",
    "håligheters": "hålighet",
    "hålighets": "hålighet",
    "håligs": "hålig",
    "håligt": "hålig",
    "håligts": "hålig",
    "hålkindade": "hålkindad",
    "hålkindades": "hålkindad",
    "hålkindads": "hålkindad",
    "hålkindat": "hålkindad",
    "hålkindats": "hålkindad",
    "hålkorten": "hålkort",
    "hålkortens": "hålkort",
    "hålkortet": "hålkort",
    "hålkortets": "hålkort",
    "hålkorts": "hålkort",
    "hålkälar": "hålkäl",
    "hålkälarna": "hålkäl",
    "hålkälarnas": "hålkäl",
    "hålkälars": "hålkäl",
    "hålkälen": "hålkäl",
    "hålkälens": "hålkäl",
    "hålkäls": "hålkäl",
    "håll": "hålla",
    "hållande": "hålla",
    "hållanden": "hållande",
    "hållandena": "hållande",
    "hållandenas": "hållande",
    "hållandens": "hållande",
    "hållandes": "hållande",
    "hållandet": "hållande",
    "hållandets": "hållande",
    "hållar": "hållare",
    "hållaren": "hållare",
    "hållarens": "hållare",
    "hållares": "hållare",
    "hållarna": "hållare",
    "hållarnas": "hållare",
    "hållas": "hålla",
    "hållbara": "hållbar",
    "hållbarare": "hållbar",
    "hållbarares": "hållbar",
    "hållbaras": "hållbar",
    "hållbarast": "hållbar",
    "hållbaraste": "hållbar",
    "hållbarastes": "hållbar",
    "hållbarasts": "hållbar",
    "hållbare": "hållbar",
    "hållbares": "hållbar",
    "hållbarheten": "hållbarhet",
    "hållbarhetens": "hållbarhet",
    "hållbarheter": "hållbarhet",
    "hållbarheterna": "hållbarhet",
    "hållbarheternas": "hållbarhet",
    "hållbarheters": "hållbarhet",
    "hållbarhets": "hållbarhet",
    "hållbarhetsdagar": "hållbarhetsdag",
    "hållbarhetsdagarna": "hållbarhetsdag",
    "hållbarhetsdagarnas": "hållbarhetsdag",
    "hållbarhetsdagars": "hållbarhetsdag",
    "hållbarhetsdagen": "hållbarhetsdag",
    "hållbarhetsdagens": "hållbarhetsdag",
    "hållbarhetsdags": "hållbarhetsdag",
    "hållbarhetsdan": "hållbarhetsdag",
    "hållbarhetsdans": "hållbarhetsdag",
    "hållbarhetsdar": "hållbarhetsdag",
    "hållbarhetsdarna": "hållbarhetsdag",
    "hållbarhetsdarnas": "hållbarhetsdag",
    "hållbarhetsdars": "hållbarhetsdag",
    "hållbars": "hållbar",
    "hållbart": "hållbar",
    "hållbarts": "hållbar",
    "hålldamen": "hålldam",
    "hålldamens": "hålldam",
    "hålldamer": "hålldam",
    "hålldamerna": "hålldam",
    "hålldamernas": "hålldam",
    "hålldamers": "hålldam",
    "hålldams": "hålldam",
    "hålle": "hålla",
    "hållen": "hålla",
    "hållens": "hållen",
    "håller": "hålla",
    "hålles": "hålla",
    "hållet": "hållen",
    "hållets": "hållen",
    "hållfasta": "hållfast",
    "hållfastare": "hållfast",
    "hållfastares": "hållfast",
    "hållfastas": "hållfast",
    "hållfastast": "hållfast",
    "hållfastaste": "hållfast",
    "hållfastastes": "hållfast",
    "hållfastasts": "hållfast",
    "hållfaste": "hållfast",
    "hållfastes": "hållfast",
    "hållfastheten": "hållfasthet",
    "hållfasthetens": "hållfasthet",
    "hållfastheter": "hållfasthet",
    "hållfastheterna": "hållfasthet",
    "hållfastheternas": "hållfasthet",
    "hållfastheters": "hållfasthet",
    "hållfasthets": "hållfasthet",
    "hållfasthetsberäkningar": "hållfasthetsberäkning",
    "hållfasthetsberäkningarna": "hållfasthetsberäkning",
    "hållfasthetsberäkningarnas": "hållfasthetsberäkning",
    "hållfasthetsberäkningars": "hållfasthetsberäkning",
    "hållfasthetsberäkningen": "hållfasthetsberäkning",
    "hållfasthetsberäkningens": "hållfasthetsberäkning",
    "hållfasthetsberäknings": "hållfasthetsberäkning",
    "hållfasthetsläran": "hållfasthetslära",
    "hållfasthetslärans": "hållfasthetslära",
    "hållfasthetsläras": "hållfasthetslära",
    "hållfasthetsläre": "hållfasthetslära",
    "hållfasthetsläro": "hållfasthetslära",
    "hållfasthetsläror": "hållfasthetslära",
    "hållfasthetslärorna": "hållfasthetslära",
    "hållfasthetslärornas": "hållfasthetslära",
    "hållfasthetslärors": "hållfasthetslära",
    "hållfasts": "hållfast",
    "hållhakar": "hållhake",
    "hållhakarna": "hållhake",
    "hållhakarnas": "hållhake",
    "hållhakars": "hållhake",
    "hållhaken": "hållhake",
    "hållhakens": "hållhake",
    "hållhakes": "hållhake",
    "hålligången": "hålligång",
    "hålligångens": "hålligång",
    "hålligånget": "hålligång",
    "hålligångets": "hålligång",
    "hålligångs": "hålligång",
    "hållit": "hålla",
    "hållits": "hållas",
    "hållna": "hållen",
    "hållnare": "hållen",
    "hållnares": "hållen",
    "hållnas": "hållen",
    "hållnast": "hållen",
    "hållnaste": "hållen",
    "hållnastes": "hållen",
    "hållnasts": "hållen",
    "hållne": "hållen",
    "hållnes": "hållen",
    "hållningar": "hållning",
    "hållningarna": "hållning",
    "hållningarnas": "hållning",
    "hållningars": "hållning",
    "hållningen": "hållning",
    "hållningens": "hållning",
    "hållnings": "hållning",
    "hållningslösa": "hållningslös",
    "hållningslösare": "hållningslös",
    "hållningslösares": "hållningslös",
    "hållningslösas": "hållningslös",
    "hållningslösast": "hållningslös",
    "hållningslösaste": "hållningslös",
    "hållningslösastes": "hållningslös",
    "hållningslösasts": "hållningslös",
    "hållningslöse": "hållningslös",
    "hållningslöses": "hållningslös",
    "hållningslösheten": "hållningslöshet",
    "hållningslöshetens": "hållningslöshet",
    "hållningslöshets": "hållningslöshet",
    "hållningslöst": "hållningslös",
    "hållningslösts": "hållningslös",
    "hållplatsen": "hållplats",
    "hållplatsens": "hållplats",
    "hållplatser": "hållplats",
    "hållplatserna": "hållplats",
    "hållplatsernas": "hållplats",
    "hållplatsers": "hållplats",
    "hållpunkten": "hållpunkt",
    "hållpunktens": "hållpunkt",
    "hållpunkter": "hållpunkt",
    "hållpunkterna": "hållpunkt",
    "hållpunkternas": "hållpunkt",
    "hållpunkters": "hållpunkt",
    "hållpunkts": "hållpunkt",
    "hålls": "hållas",
    "hålmönsterna": "hålmönster",
    "hålmönsternas": "hålmönster",
    "hålmönsters": "hålmönster",
    "hålmönstren": "hålmönster",
    "hålmönstrens": "hålmönster",
    "hålmönstret": "hålmönster",
    "hålmönstrets": "hålmönster",
    "hålor": "håla",
    "hålorna": "håla",
    "hålornas": "håla",
    "hålors": "håla",
    "hålrems": "hålremsa",
    "hålremsan": "hålremsa",
    "hålremsans": "hålremsa",
    "hålremsas": "hålremsa",
    "hålremse": "hålremsa",
    "hålremsor": "hålremsa",
    "hålremsorna": "hålremsa",
    "hålremsornas": "hålremsa",
    "hålremsors": "hålremsa",
    "hålrummen": "hålrum",
    "hålrummens": "hålrum",
    "hålrummet": "hålrum",
    "hålrummets": "hålrum",
    "hålrums": "hålrum",
    "håls": "håla",
    "hålslagen": "hålslag",
    "hålslagens": "hålslag",
    "hålslaget": "hålslag",
    "hålslagets": "hålslag",
    "hålslagit": "hålslå",
    "hålslagits": "hålslå",
    "hålslagna": "hålslå",
    "hålslagnas": "hålslå",
    "hålslagne": "hålslå",
    "hålslagnes": "hålslå",
    "hålslagningar": "hålslagning",
    "hålslagningarna": "hålslagning",
    "hålslagningarnas": "hålslagning",
    "hålslagningars": "hålslagning",
    "hålslagningen": "hålslagning",
    "hålslagningens": "hålslagning",
    "hålslagnings": "hålslagning",
    "hålslags": "hålslag",
    "hålslevar": "hålslev",
    "hålslevarna": "hålslev",
    "hålslevarnas": "hålslev",
    "hålslevars": "hålslev",
    "hålsleven": "hålslev",
    "hålslevens": "hålslev",
    "hålslevs": "hålslev",
    "hålslog": "hålslå",
    "hålsloge": "hålslå",
    "hålsloges": "hålslå",
    "hålslogs": "hålslå",
    "hålslående": "hålslå",
    "hålslåenden": "hålslående",
    "hålslåendena": "hålslående",
    "hålslåendenas": "hålslående",
    "hålslåendens": "hålslående",
    "hålslåendes": "hålslående",
    "hålslåendet": "hålslående",
    "hålslåendets": "hålslående",
    "hålslår": "hålslå",
    "hålslås": "hålslå",
    "hålspetsammunitionen": "hålspetsammunition",
    "hålspetsammunitionens": "hålspetsammunition",
    "hålspetsammunitions": "hålspetsammunition",
    "hålspetskulan": "hålspetskula",
    "hålspetskulans": "hålspetskula",
    "hålspetskulas": "hålspetskula",
    "hålspetskule": "hålspetskula",
    "hålspetskulor": "hålspetskula",
    "hålspetskulorna": "hålspetskula",
    "hålspetskulornas": "hålspetskula",
    "hålspetskulors": "hålspetskula",
    "hålspikbanden": "hålspikband",
    "hålspikbandens": "hålspikband",
    "hålspikbandet": "hålspikband",
    "hålspikbandets": "hålspikband",
    "hålspikbands": "hålspikband",
    "håltegels": "håltegel",
    "hålteglet": "håltegel",
    "hålteglets": "håltegel",
    "håltim": "håltimme",
    "håltimman": "håltimma",
    "håltimmans": "håltimma",
    "håltimmar": "håltimme",
    "håltimmarna": "håltimme",
    "håltimmarnas": "håltimme",
    "håltimmars": "håltimme",
    "håltimmas": "håltimma",
    "håltimmen": "håltimme",
    "håltimmens": "håltimme",
    "håltimmes": "håltimme",
    "håltims": "håltimme",
    "hålvenen": "hålven",
    "hålvenens": "hålven",
    "hålvener": "hålven",
    "hålvenerna": "hålven",
    "hålvenernas": "hålven",
    "hålveners": "hålven",
    "hålvens": "hålven",
    "hålvägar": "hålväg",
    "hålvägarna": "hålväg",
    "hålvägarnas": "hålväg",
    "hålvägars": "hålväg",
    "hålvägen": "hålväg",
    "hålvägens": "hålväg",
    "hålvägs": "hålväg",
    "hålögda": "hålögd",
    "hålögdare": "hålögd",
    "hålögdares": "hålögd",
    "hålögdas": "hålögd",
    "hålögdast": "hålögd",
    "hålögdaste": "hålögd",
    "hålögdastes": "hålögd",
    "hålögdasts": "hålögd",
    "hålögde": "hålögd",
    "hålögdes": "hålögd",
    "hålögdheten": "hålögdhet",
    "hålögdhetens": "hålögdhet",
    "hålögdhets": "hålögdhet",
    "hålögds": "hålögd",
    "hålögt": "hålögd",
    "hålögts": "hålögd",
    "hån": "håna",
    "hånad": "håna",
    "hånade": "håna",
    "hånades": "håna",
    "hånads": "håna",
    "hånande": "håna",
    "hånanden": "hånande",
    "hånandena": "hånande",
    "hånandenas": "hånande",
    "hånandens": "hånande",
    "hånandes": "hånande",
    "hånandet": "hånande",
    "hånandets": "hånande",
    "hånar": "håna",
    "hånas": "håna",
    "hånat": "håna",
    "hånats": "håna",
    "hånet": "hån",
    "hånets": "hån",
    "hånfulla": "hånfull",
    "hånfullare": "hånfull",
    "hånfullares": "hånfull",
    "hånfullas": "hånfull",
    "hånfullast": "hånfull",
    "hånfullaste": "hånfull",
    "hånfullastes": "hånfull",
    "hånfullasts": "hånfull",
    "hånfulle": "hånfull",
    "hånfulles": "hånfull",
    "hånfullheten": "hånfullhet",
    "hånfullhetens": "hånfullhet",
    "hånfullheter": "hånfullhet",
    "hånfullheterna": "hånfullhet",
    "hånfullheternas": "hånfullhet",
    "hånfullheters": "hånfullhet",
    "hånfullhets": "hånfullhet",
    "hånfulls": "hånfull",
    "hånfullt": "hånfull",
    "hånfullts": "hånfull",
    "hångel": "hångla",
    "hångels": "hångel",
    "hånglade": "hångla",
    "hånglades": "hångla",
    "hånglande": "hångla",
    "hånglanden": "hånglande",
    "hånglandena": "hånglande",
    "hånglandenas": "hånglande",
    "hånglandens": "hånglande",
    "hånglandes": "hånglande",
    "hånglandet": "hånglande",
    "hånglandets": "hånglande",
    "hånglar": "hångla",
    "hånglas": "hångla",
    "hånglat": "hångla",
    "hånglats": "hångla",
    "hånglet": "hångel",
    "hånglets": "hångel",
    "hånleende": "hånle",
    "hånleenden": "hånleende",
    "hånleendena": "hånleende",
    "hånleendenas": "hånleende",
    "hånleendens": "hånleende",
    "hånleendes": "hånleende",
    "hånleendet": "hånleende",
    "hånleendets": "hånleende",
    "hånler": "hånle",
    "hånles": "hånle",
    "hånlett": "hånle",
    "hånletts": "hånle",
    "hånlog": "hånle",
    "hånloge": "hånle",
    "hånloges": "hånle",
    "hånlogs": "hånle",
    "håns": "hån",
    "hånskrattade": "hånskratta",
    "hånskrattades": "hånskratta",
    "hånskrattande": "hånskratta",
    "hånskrattanden": "hånskrattande",
    "hånskrattandena": "hånskrattande",
    "hånskrattandenas": "hånskrattande",
    "hånskrattandens": "hånskrattande",
    "hånskrattandes": "hånskrattande",
    "hånskrattandet": "hånskrattande",
    "hånskrattandets": "hånskrattande",
    "hånskrattar": "hånskratta",
    "hånskrattas": "hånskratta",
    "hånskrattat": "hånskratta",
    "hånskrattats": "hånskratta",
    "hånskratten": "hånskratt",
    "hånskrattens": "hånskratt",
    "hånskrattet": "hånskratt",
    "hånskrattets": "hånskratt",
    "hånskratts": "hånskratt",
    "håravfallet": "håravfall",
    "håravfallets": "håravfall",
    "håravfalls": "håravfall",
    "hårbanden": "hårband",
    "hårbandens": "hårband",
    "hårbandet": "hårband",
    "hårbandets": "hårband",
    "hårbands": "hårband",
    "hårbeklädnaden": "hårbeklädnad",
    "hårbeklädnadens": "hårbeklädnad",
    "hårbeklädnader": "hårbeklädnad",
    "hårbeklädnaderna": "hårbeklädnad",
    "hårbeklädnadernas": "hårbeklädnad",
    "hårbeklädnaders": "hårbeklädnad",
    "hårbeklädnads": "hårbeklädnad",
    "hårbevuxenheten": "hårbevuxenhet",
    "hårbevuxenhetens": "hårbevuxenhet",
    "hårbevuxenhets": "hårbevuxenhet",
    "hårbevuxens": "hårbevuxen",
    "hårbevuxet": "hårbevuxen",
    "hårbevuxets": "hårbevuxen",
    "hårbevuxna": "hårbevuxen",
    "hårbevuxnare": "hårbevuxen",
    "hårbevuxnares": "hårbevuxen",
    "hårbevuxnas": "hårbevuxen",
    "hårbevuxnast": "hårbevuxen",
    "hårbevuxnaste": "hårbevuxen",
    "hårbevuxnastes": "hårbevuxen",
    "hårbevuxnasts": "hårbevuxen",
    "hårbevuxne": "hårbevuxen",
    "hårbevuxnes": "hårbevuxen",
    "hårborst": "hårborste",
    "hårborstar": "hårborste",
    "hårborstarna": "hårborste",
    "hårborstarnas": "hårborste",
    "hårborstars": "hårborste",
    "hårborsten": "hårborste",
    "hårborstens": "hårborste",
    "hårborstes": "hårborste",
    "hårbottens": "hårbotten",
    "hårbottnar": "hårbotten",
    "hårbottnarna": "hårbotten",
    "hårbottnarnas": "hårbotten",
    "hårbottnars": "hårbotten",
    "hårbottnen": "hårbotten",
    "hårbottnens": "hårbotten",
    "hårburret": "hårburr",
    "hårburrets": "hårburr",
    "hårburrs": "hårburr",
    "hårda": "hård",
    "hårdagar": "hårdag",
    "hårdagarna": "hårdag",
    "hårdagarnas": "hårdag",
    "hårdagars": "hårdag",
    "hårdagen": "hårdag",
    "hårdagens": "hårdag",
    "hårdags": "hårdag",
    "hårdare": "hård",
    "hårdares": "hård",
    "hårdas": "hård",
    "hårdast": "hård",
    "hårdaste": "hård",
    "hårdastes": "hård",
    "hårdasts": "hård",
    "hårdbevakade": "hårdbevakad",
    "hårdbevakades": "hårdbevakad",
    "hårdbevakads": "hårdbevakad",
    "hårdbevakat": "hårdbevakad",
    "hårdbevakats": "hårdbevakad",
    "hårdblyet": "hårdbly",
    "hårdblyets": "hårdbly",
    "hårdblykul": "hårdblykula",
    "hårdblykulan": "hårdblykula",
    "hårdblykulans": "hårdblykula",
    "hårdblykulas": "hårdblykula",
    "hårdblykule": "hårdblykula",
    "hårdblykulor": "hårdblykula",
    "hårdblykulorna": "hårdblykula",
    "hårdblykulornas": "hårdblykula",
    "hårdblykulors": "hårdblykula",
    "hårdblykuls": "hårdblykula",
    "hårdblys": "hårdbly",
    "hårdblyt": "hårdbly",
    "hårdblyts": "hårdbly",
    "hårddatan": "hårddata",
    "hårddatana": "hårddata",
    "hårddatanas": "hårddata",
    "hårddatans": "hårddata",
    "hårddatas": "hårddata",
    "hårddatat": "hårddata",
    "hårddatats": "hårddata",
    "hårddiskar": "hårddisk",
    "hårddiskarna": "hårddisk",
    "hårddiskarnas": "hårddisk",
    "hårddiskars": "hårddisk",
    "hårddisken": "hårddisk",
    "hårddiskens": "hårddisk",
    "hårddisks": "hårddisk",
    "hårde": "hård",
    "hårdes": "hård",
    "hårdfjällade": "hårdfjällad",
    "hårdfjällades": "hårdfjällad",
    "hårdfjällads": "hårdfjällad",
    "hårdfjällat": "hårdfjällad",
    "hårdfjällats": "hårdfjällad",
    "hårdflirtade": "hårdflirtad",
    "hårdflirtades": "hårdflirtad",
    "hårdflirtads": "hårdflirtad",
    "hårdflirtat": "hårdflirtad",
    "hårdflirtats": "hårdflirtad",
    "hårdflörtade": "hårdflörtad",
    "hårdflörtades": "hårdflörtad",
    "hårdflörtads": "hårdflörtad",
    "hårdflörtat": "hårdflörtad",
    "hårdflörtats": "hårdflörtad",
    "hårdfrusens": "hårdfrusen",
    "hårdfruset": "hårdfrusen",
    "hårdfrusets": "hårdfrusen",
    "hårdfrusna": "hårdfrusen",
    "hårdfrusnare": "hårdfrusen",
    "hårdfrusnares": "hårdfrusen",
    "hårdfrusnas": "hårdfrusen",
    "hårdfrusnast": "hårdfrusen",
    "hårdfrusnaste": "hårdfrusen",
    "hårdfrusnastes": "hårdfrusen",
    "hårdfrusnasts": "hårdfrusen",
    "hårdfrusne": "hårdfrusen",
    "hårdfrusnes": "hårdfrusen",
    "hårdföra": "hårdför",
    "hårdförare": "hårdför",
    "hårdförares": "hårdför",
    "hårdföras": "hårdför",
    "hårdförast": "hårdför",
    "hårdföraste": "hårdför",
    "hårdförastes": "hårdför",
    "hårdförasts": "hårdför",
    "hårdföre": "hårdför",
    "hårdföres": "hårdför",
    "hårdförheten": "hårdförhet",
    "hårdförhetens": "hårdförhet",
    "hårdförhets": "hårdförhet",
    "hårdförs": "hårdför",
    "hårdfört": "hårdför",
    "hårdförts": "hårdför",
    "hårdgranskad": "hårdgranska",
    "hårdgranskade": "hårdgranska",
    "hårdgranskades": "hårdgranska",
    "hårdgranskads": "hårdgranska",
    "hårdgranskande": "hårdgranska",
    "hårdgranskandes": "hårdgranska",
    "hårdgranskar": "hårdgranska",
    "hårdgranskas": "hårdgranska",
    "hårdgranskat": "hårdgranska",
    "hårdgranskats": "hårdgranska",
    "hårdgummis": "hårdgummi",
    "hårdgummit": "hårdgummi",
    "hårdgummits": "hårdgummi",
    "hårdheten": "hårdhet",
    "hårdhetens": "hårdhet",
    "hårdheter": "hårdhet",
    "hårdheterna": "hårdhet",
    "hårdheternas": "hårdhet",
    "hårdheters": "hårdhet",
    "hårdhets": "hårdhet",
    "hårdhjärtade": "hårdhjärtad",
    "hårdhjärtades": "hårdhjärtad",
    "hårdhjärtads": "hårdhjärtad",
    "hårdhjärtat": "hårdhjärtad",
    "hårdhjärtats": "hårdhjärtad",
    "hårdhudade": "hårdhudad",
    "hårdhudades": "hårdhudad",
    "hårdhudads": "hårdhudad",
    "hårdhudat": "hårdhudad",
    "hårdhudats": "hårdhudad",
    "hårdhänta": "hårdhänt",
    "hårdhäntare": "hårdhänt",
    "hårdhäntares": "hårdhänt",
    "hårdhäntas": "hårdhänt",
    "hårdhäntast": "hårdhänt",
    "hårdhäntaste": "hårdhänt",
    "hårdhäntastes": "hårdhänt",
    "hårdhäntasts": "hårdhänt",
    "hårdhänte": "hårdhänt",
    "hårdhäntes": "hårdhänt",
    "hårdhäntheten": "hårdhänthet",
    "hårdhänthetens": "hårdhänthet",
    "hårdhänthets": "hårdhänthet",
    "hårdhänts": "hårdhänt",
    "hårdingar": "hårding",
    "hårdingarna": "hårding",
    "hårdingarnas": "hårding",
    "hårdingars": "hårding",
    "hårdingen": "hårding",
    "hårdingens": "hårding",
    "hårdings": "hårding",
    "hårdkokta": "hårdkokt",
    "hårdkoktare": "hårdkokt",
    "hårdkoktares": "hårdkokt",
    "hårdkoktas": "hårdkokt",
    "hårdkoktast": "hårdkokt",
    "hårdkoktaste": "hårdkokt",
    "hårdkoktastes": "hårdkokt",
    "hårdkoktasts": "hårdkokt",
    "hårdkokte": "hårdkokt",
    "hårdkoktes": "hårdkokt",
    "hårdkoktheten": "hårdkokthet",
    "hårdkokthetens": "hårdkokthet",
    "hårdkokthets": "hårdkokthet",
    "hårdkokts": "hårdkokt",
    "hårdlodet": "hårdlod",
    "hårdlodets": "hårdlod",
    "hårdlods": "hårdlod",
    "hårdlöd": "hårdlöda",
    "hårdlödande": "hårdlöda",
    "hårdlödandes": "hårdlödande",
    "hårdlödandet": "hårdlödande",
    "hårdlödandets": "hårdlödande",
    "hårdlödas": "hårdlöda",
    "hårdlödd": "hårdlöda",
    "hårdlödda": "hårdlöda",
    "hårdlöddas": "hårdlöda",
    "hårdlödde": "hårdlöda",
    "hårdlöddes": "hårdlöda",
    "hårdlödds": "hårdlöda",
    "hårdlöder": "hårdlöda",
    "hårdlödes": "hårdlöda",
    "hårdlödningar": "hårdlödning",
    "hårdlödningarna": "hårdlödning",
    "hårdlödningarnas": "hårdlödning",
    "hårdlödningars": "hårdlödning",
    "hårdlödningen": "hårdlödning",
    "hårdlödningens": "hårdlödning",
    "hårdlödnings": "hårdlödning",
    "hårdlöds": "hårdlöda",
    "hårdlött": "hårdlöda",
    "hårdlötts": "hårdlöda",
    "hårdmetallen": "hårdmetall",
    "hårdmetallens": "hårdmetall",
    "hårdmetaller": "hårdmetall",
    "hårdmetallerna": "hårdmetall",
    "hårdmetallernas": "hårdmetall",
    "hårdmetallers": "hårdmetall",
    "hårdmetalls": "hårdmetall",
    "hårdnackade": "hårdnackad",
    "hårdnackades": "hårdnackad",
    "hårdnackads": "hårdnackad",
    "hårdnackat": "hårdnackad",
    "hårdnackats": "hårdnackad",
    "hårdnad": "hårdna",
    "hårdnade": "hårdna",
    "hårdnades": "hårdna",
    "hårdnads": "hårdna",
    "hårdnande": "hårdna",
    "hårdnanden": "hårdnande",
    "hårdnandena": "hårdnande",
    "hårdnandenas": "hårdnande",
    "hårdnandens": "hårdnande",
    "hårdnandes": "hårdnande",
    "hårdnandet": "hårdnande",
    "hårdnandets": "hårdnande",
    "hårdnar": "hårdna",
    "hårdnas": "hårdna",
    "hårdnat": "hårdna",
    "hårdnats": "hårdna",
    "hårdporren": "hårdporr",
    "hårdporrens": "hårdporr",
    "hårdporrs": "hårdporr",
    "hårdrag": "hårdra",
    "hårdraga": "hårdra",
    "hårdragande": "hårdra",
    "hårdraganden": "hårdragande",
    "hårdragandena": "hårdragande",
    "hårdragandenas": "hårdragande",
    "hårdragandens": "hårdragande",
    "hårdragandes": "hårdragande",
    "hårdragandet": "hårdragande",
    "hårdragandets": "hårdragande",
    "hårdragas": "hårdra",
    "hårdrage": "hårdra",
    "hårdragen": "hårdra",
    "hårdragens": "hårdra",
    "hårdrager": "hårdra",
    "hårdrages": "hårdra",
    "hårdraget": "hårdra",
    "hårdragets": "hårdra",
    "hårdragit": "hårdra",
    "hårdragits": "hårdra",
    "hårdragna": "hårdra",
    "hårdragnas": "hårdra",
    "hårdragne": "hårdra",
    "hårdragnes": "hårdra",
    "hårdrags": "hårdra",
    "hårdrar": "hårdra",
    "hårdras": "hårdra",
    "hårdrocken": "hårdrock",
    "hårdrockens": "hårdrock",
    "hårdrocks": "hårdrock",
    "hårdrog": "hårdra",
    "hårdroge": "hårdra",
    "hårdroges": "hårdra",
    "hårdrogs": "hårdra",
    "hårds": "hård",
    "hårdsmälta": "hårdsmält",
    "hårdsmältare": "hårdsmält",
    "hårdsmältares": "hårdsmält",
    "hårdsmältas": "hårdsmält",
    "hårdsmältast": "hårdsmält",
    "hårdsmältaste": "hårdsmält",
    "hårdsmältastes": "hårdsmält",
    "hårdsmältasts": "hårdsmält",
    "hårdsmälte": "hårdsmält",
    "hårdsmältes": "hårdsmält",
    "hårdsmältheten": "hårdsmälthet",
    "hårdsmälthetens": "hårdsmälthet",
    "hårdsmälthets": "hårdsmälthet",
    "hårdsmälts": "hårdsmält",
    "hårdträn": "hårdträna",
    "hårdtränad": "hårdträna",
    "hårdtränade": "hårdträna",
    "hårdtränades": "hårdträna",
    "hårdtränads": "hårdträna",
    "hårdtränande": "hårdträna",
    "hårdtränanden": "hårdtränande",
    "hårdtränandena": "hårdtränande",
    "hårdtränandenas": "hårdtränande",
    "hårdtränandens": "hårdtränande",
    "hårdtränandes": "hårdtränande",
    "hårdtränandet": "hårdtränande",
    "hårdtränandets": "hårdtränande",
    "hårdtränar": "hårdträna",
    "hårdtränas": "hårdträna",
    "hårdtränat": "hårdträna",
    "hårdtränats": "hårdträna",
    "hårdträningar": "hårdträning",
    "hårdträningarna": "hårdträning",
    "hårdträningarnas": "hårdträning",
    "hårdträningars": "hårdträning",
    "hårdträningen": "hårdträning",
    "hårdträningens": "hårdträning",
    "hårdtränings": "hårdträning",
    "hårdtvinnade": "hårdtvinnad",
    "hårdtvinnades": "hårdtvinnad",
    "hårdtvinnads": "hårdtvinnad",
    "hårdtvinnat": "hårdtvinnad",
    "hårdtvinnats": "hårdtvinnad",
    "hårdvalutan": "hårdvaluta",
    "hårdvalutans": "hårdvaluta",
    "hårdvalutas": "hårdvaluta",
    "hårdvalute": "hårdvaluta",
    "hårdvalutor": "hårdvaluta",
    "hårdvalutorna": "hårdvaluta",
    "hårdvalutornas": "hårdvaluta",
    "hårdvalutors": "hårdvaluta",
    "hårdvar": "hårdvara",
    "hårdvaran": "hårdvara",
    "hårdvarans": "hårdvara",
    "hårdvaras": "hårdvara",
    "hårdvaror": "hårdvara",
    "hårdvarorna": "hårdvara",
    "hårdvarornas": "hårdvara",
    "hårdvarors": "hårdvara",
    "hårdvaru": "hårdvara",
    "hårdvarumässiga": "hårdvarumässig",
    "hårdvarumässigare": "hårdvarumässig",
    "hårdvarumässigares": "hårdvarumässig",
    "hårdvarumässigas": "hårdvarumässig",
    "hårdvarumässigast": "hårdvarumässig",
    "hårdvarumässigaste": "hårdvarumässig",
    "hårdvarumässigastes": "hårdvarumässig",
    "hårdvarumässigasts": "hårdvarumässig",
    "hårdvarumässige": "hårdvarumässig",
    "hårdvarumässiges": "hårdvarumässig",
    "hårdvarumässigs": "hårdvarumässig",
    "hårdvarumässigt": "hårdvarumässig",
    "hårdvarumässigts": "hårdvarumässig",
    "håren": "hår",
    "hårens": "hår",
    "håret": "hår",
    "hårets": "hår",
    "hårfina": "hårfin",
    "hårfinare": "hårfin",
    "hårfinares": "hårfin",
    "hårfinas": "hårfin",
    "hårfinast": "hårfin",
    "hårfinaste": "hårfin",
    "hårfinastes": "hårfin",
    "hårfinasts": "hårfin",
    "hårfine": "hårfin",
    "hårfines": "hårfin",
    "hårfins": "hårfin",
    "hårfint": "hårfin",
    "hårfints": "hårfin",
    "hårfriss": "hårfrissa",
    "hårfrissan": "hårfrissa",
    "hårfrissans": "hårfrissa",
    "hårfrissas": "hårfrissa",
    "hårfrisse": "hårfrissa",
    "hårfrissor": "hårfrissa",
    "hårfrissorna": "hårfrissa",
    "hårfrissornas": "hårfrissa",
    "hårfrissors": "hårfrissa",
    "hårfrisören": "hårfrisör",
    "hårfrisörens": "hårfrisör",
    "hårfrisörer": "hårfrisör",
    "hårfrisörerna": "hårfrisör",
    "hårfrisörernas": "hårfrisör",
    "hårfrisörers": "hårfrisör",
    "hårfrisörn": "hårfrisör",
    "hårfrisörns": "hårfrisör",
    "hårfrisörs": "hårfrisör",
    "hårfrisörskan": "hårfrisörska",
    "hårfrisörskans": "hårfrisörska",
    "hårfrisörskas": "hårfrisörska",
    "hårfrisörske": "hårfrisörska",
    "hårfrisörskor": "hårfrisörska",
    "hårfrisörskorna": "hårfrisörska",
    "hårfrisörskornas": "hårfrisörska",
    "hårfrisörskors": "hårfrisörska",
    "hårfällningar": "hårfällning",
    "hårfällningarna": "hårfällning",
    "hårfällningarnas": "hårfällning",
    "hårfällningars": "hårfällning",
    "hårfällningen": "hårfällning",
    "hårfällningens": "hårfällning",
    "hårfällnings": "hårfällning",
    "hårfärgen": "hårfärg",
    "hårfärgens": "hårfärg",
    "hårfärger": "hårfärg",
    "hårfärgerna": "hårfärg",
    "hårfärgernas": "hårfärg",
    "hårfärgers": "hårfärg",
    "hårfärgs": "hårfärg",
    "hårfäst": "hårfäste",
    "hårfästen": "hårfäste",
    "hårfästena": "hårfäste",
    "hårfästenas": "hårfäste",
    "hårfästens": "hårfäste",
    "hårfästes": "hårfäste",
    "hårfästet": "hårfäste",
    "hårfästets": "hårfäste",
    "hårfönar": "hårfön",
    "hårfönarna": "hårfön",
    "hårfönarnas": "hårfön",
    "hårfönars": "hårfön",
    "hårfönen": "hårfön",
    "hårfönens": "hårfön",
    "hårföns": "hårfön",
    "håriga": "hårig",
    "hårigare": "hårig",
    "hårigares": "hårig",
    "hårigas": "hårig",
    "hårigast": "hårig",
    "hårigaste": "hårig",
    "hårigastes": "hårig",
    "hårigasts": "hårig",
    "hårige": "hårig",
    "håriges": "hårig",
    "hårigs": "hårig",
    "hårigt": "hårig",
    "hårigts": "hårig",
    "hårklyverier": "hårklyveri",
    "hårklyverierna": "hårklyveri",
    "hårklyveriernas": "hårklyveri",
    "hårklyveriers": "hårklyveri",
    "hårklyveriet": "hårklyveri",
    "hårklyveriets": "hårklyveri",
    "hårklyveris": "hårklyveri",
    "hårklyverit": "hårklyveri",
    "hårklyverits": "hårklyveri",
    "hårknutar": "hårknut",
    "hårknutarna": "hårknut",
    "hårknutarnas": "hårknut",
    "hårknutars": "hårknut",
    "hårknuten": "hårknut",
    "hårknutens": "hårknut",
    "hårknuts": "hårknut",
    "hårkorsen": "hårkors",
    "hårkorsens": "hårkors",
    "hårkorset": "hårkors",
    "hårkorsets": "hårkors",
    "hårlagen": "hårlag",
    "hårlagens": "hårlag",
    "hårlaget": "hårlag",
    "hårlagets": "hårlag",
    "hårlags": "hårlag",
    "hårlockar": "hårlock",
    "hårlockarna": "hårlock",
    "hårlockarnas": "hårlock",
    "hårlockars": "hårlock",
    "hårlocken": "hårlock",
    "hårlockens": "hårlock",
    "hårlocks": "hårlock",
    "hårläggningar": "hårläggning",
    "hårläggningarna": "hårläggning",
    "hårläggningarnas": "hårläggning",
    "hårläggningars": "hårläggning",
    "hårläggningen": "hårläggning",
    "hårläggningens": "hårläggning",
    "hårläggnings": "hårläggning",
    "hårlösa": "hårlös",
    "hårlösare": "hårlös",
    "hårlösares": "hårlös",
    "hårlösas": "hårlös",
    "hårlösast": "hårlös",
    "hårlösaste": "hårlös",
    "hårlösastes": "hårlös",
    "hårlösasts": "hårlös",
    "hårlöse": "hårlös",
    "hårlöses": "hårlös",
    "hårlösheten": "hårlöshet",
    "hårlöshetens": "hårlöshet",
    "hårlöshets": "hårlöshet",
    "hårlöst": "hårlös",
    "hårlösts": "hårlös",
    "hårnålar": "hårnål",
    "hårnålarna": "hårnål",
    "hårnålarnas": "hårnål",
    "hårnålars": "hårnål",
    "hårnålen": "hårnål",
    "hårnålens": "hårnål",
    "hårnåls": "hårnål",
    "hårnålskurv": "hårnålskurva",
    "hårnålskurvan": "hårnålskurva",
    "hårnålskurvans": "hårnålskurva",
    "hårnålskurvas": "hårnålskurva",
    "hårnålskurve": "hårnålskurva",
    "hårnålskurvor": "hårnålskurva",
    "hårnålskurvorna": "hårnålskurva",
    "hårnålskurvornas": "hårnålskurva",
    "hårnålskurvors": "hårnålskurva",
    "hårnålskurvs": "hårnålskurva",
    "håroljan": "hårolja",
    "håroljans": "hårolja",
    "håroljas": "hårolja",
    "hårolje": "hårolja",
    "håroljor": "hårolja",
    "håroljorna": "hårolja",
    "håroljornas": "hårolja",
    "håroljors": "hårolja",
    "hårpenseln": "hårpensel",
    "hårpenselns": "hårpensel",
    "hårpensels": "hårpensel",
    "hårpenslar": "hårpensel",
    "hårpenslarna": "hårpensel",
    "hårpenslarnas": "hårpensel",
    "hårpenslars": "hårpensel",
    "hårpisk": "hårpiska",
    "hårpiskan": "hårpiska",
    "hårpiskans": "hårpiska",
    "hårpiskas": "hårpiska",
    "hårpiske": "hårpiska",
    "hårpiskor": "hårpiska",
    "hårpiskorna": "hårpiska",
    "hårpiskornas": "hårpiska",
    "hårpiskors": "hårpiska",
    "hårplattänger": "hårplattång",
    "hårplattängerna": "hårplattång",
    "hårplattängernas": "hårplattång",
    "hårplattängers": "hårplattång",
    "hårplattången": "hårplattång",
    "hårplattångens": "hårplattång",
    "hårplattångs": "hårplattång",
    "hårremmar": "hårrem",
    "hårremmarna": "hårrem",
    "hårremmarnas": "hårrem",
    "hårremmars": "hårrem",
    "hårremmen": "hårrem",
    "hårremmens": "hårrem",
    "hårrems": "hårrem",
    "hårrull": "hårrulle",
    "hårrullar": "hårrulle",
    "hårrullarna": "hårrulle",
    "hårrullarnas": "hårrulle",
    "hårrullars": "hårrulle",
    "hårrullen": "hårrulle",
    "hårrullens": "hårrulle",
    "hårrulles": "hårrulle",
    "hårrulls": "hårrulle",
    "hårrören": "hårrör",
    "hårrörens": "hårrör",
    "hårröret": "hårrör",
    "hårrörets": "hårrör",
    "hårrörs": "hårrör",
    "hårrörskraften": "hårrörskraft",
    "hårrörskraftens": "hårrörskraft",
    "hårrörskrafts": "hårrörskraft",
    "hårrörskärlen": "hårrörskärl",
    "hårrörskärlens": "hårrörskärl",
    "hårrörskärlet": "hårrörskärl",
    "hårrörskärlets": "hårrörskärl",
    "hårrörskärls": "hårrörskärl",
    "hårs": "hår",
    "hårsidan": "hårsida",
    "hårsidans": "hårsida",
    "hårsidas": "hårsida",
    "hårside": "hårsida",
    "hårsides": "hårsida",
    "hårsidor": "hårsida",
    "hårsidorna": "hårsida",
    "hårsidornas": "hårsida",
    "hårsidors": "hårsida",
    "hårsmånen": "hårsmån",
    "hårsmånens": "hårsmån",
    "hårsmåns": "hårsmån",
    "hårspännen": "hårspänne",
    "hårspännena": "hårspänne",
    "hårspännenas": "hårspänne",
    "hårspännens": "hårspänne",
    "hårspännes": "hårspänne",
    "hårspännet": "hårspänne",
    "hårspännets": "hårspänne",
    "hårstrået": "hårstrå",
    "hårstråets": "hårstrå",
    "hårstrån": "hårstrå",
    "hårstråna": "hårstrå",
    "hårstrånas": "hårstrå",
    "hårstråns": "hårstrå",
    "hårstrås": "hårstrå",
    "hårstråt": "hårstrå",
    "hårstråts": "hårstrå",
    "hårsvallen": "hårsvall",
    "hårsvallens": "hårsvall",
    "hårsvallet": "hårsvall",
    "hårsvallets": "hårsvall",
    "hårsvalls": "hårsvall",
    "hårsäckar": "hårsäck",
    "hårsäckarna": "hårsäck",
    "hårsäckarnas": "hårsäck",
    "hårsäckars": "hårsäck",
    "hårsäcken": "hårsäck",
    "hårsäckens": "hårsäck",
    "hårsäcks": "hårsäck",
    "hårt": "hård",
    "hårtestar": "hårtest",
    "hårtestarna": "hårtest",
    "hårtestarnas": "hårtest",
    "hårtestars": "hårtest",
    "hårtesten": "hårtest",
    "hårtestens": "hårtest",
    "hårtests": "hårtest",
    "hårtofsar": "hårtofs",
    "hårtofsarna": "hårtofs",
    "hårtofsarnas": "hårtofs",
    "hårtofsars": "hårtofs",
    "hårtofsen": "hårtofs",
    "hårtofsens": "hårtofs",
    "hårtorkar": "hårtork",
    "hårtorkarna": "hårtork",
    "hårtorkarnas": "hårtork",
    "hårtorkars": "hårtork",
    "hårtorken": "hårtork",
    "hårtorkens": "hårtork",
    "hårtorks": "hårtork",
    "hårts": "hård",
    "hårtussar": "hårtuss",
    "hårtussarna": "hårtuss",
    "hårtussarnas": "hårtuss",
    "hårtussars": "hårtuss",
    "hårtussen": "hårtuss",
    "hårtussens": "hårtuss",
    "hårtvättar": "hårtvätt",
    "hårtvättarna": "hårtvätt",
    "hårtvättarnas": "hårtvätt",
    "hårtvättars": "hårtvätt",
    "hårtvätten": "hårtvätt",
    "hårtvättens": "hårtvätt",
    "hårtvätts": "hårtvätt",
    "håruppsättningar": "håruppsättning",
    "håruppsättningarna": "håruppsättning",
    "håruppsättningarnas": "håruppsättning",
    "håruppsättningars": "håruppsättning",
    "håruppsättningen": "håruppsättning",
    "håruppsättningens": "håruppsättning",
    "håruppsättnings": "håruppsättning",
    "hårvattens": "hårvatten",
    "hårvattnen": "hårvatten",
    "hårvattnens": "hårvatten",
    "hårvattnet": "hårvatten",
    "hårvattnets": "hårvatten",
    "hårväxten": "hårväxt",
    "hårväxtens": "hårväxt",
    "hårväxts": "hårväxt",
    "hårvården": "hårvård",
    "hårvårdens": "hårvård",
    "hårvårds": "hårvård",
    "håv": "håva",
    "håvad": "håva",
    "håvade": "håva",
    "håvades": "håva",
    "håvads": "håva",
    "håvande": "håva",
    "håvanden": "håvande",
    "håvandena": "håvande",
    "håvandenas": "håvande",
    "håvandens": "håvande",
    "håvandes": "håvande",
    "håvandet": "håvande",
    "håvandets": "håvande",
    "håvar": "håva",
    "håvarna": "håv",
    "håvarnas": "håv",
    "håvars": "håv",
    "håvas": "håva",
    "håvat": "håva",
    "håvats": "håva",
    "håven": "håv",
    "håvens": "håv",
    "håvorna": "håvor",
    "håvornas": "håvor",
    "håvors": "håvor",
    "håvs": "håv",
    "höet": "hö",
    "höets": "hö",
    "höfebern": "höfeber",
    "höfeberns": "höfeber",
    "höfebers": "höfeber",
    "höftbenen": "höftben",
    "höftbenens": "höftben",
    "höftbenet": "höftben",
    "höftbenets": "höftben",
    "höftbens": "höftben",
    "höften": "höft",
    "höftens": "höft",
    "höfter": "höft",
    "höfterna": "höft",
    "höfternas": "höft",
    "höfters": "höft",
    "höftfästes": "höftfäste",
    "höftfästet": "höftfäste",
    "höftfästets": "höftfäste",
    "höfthållar": "höfthållare",
    "höfthållaren": "höfthållare",
    "höfthållarens": "höfthållare",
    "höfthållares": "höfthållare",
    "höfthållarna": "höfthållare",
    "höfthållarnas": "höfthållare",
    "höftkurv": "höftkurva",
    "höftkurvan": "höftkurva",
    "höftkurvans": "höftkurva",
    "höftkurvas": "höftkurva",
    "höftkurve": "höftkurva",
    "höftkurvor": "höftkurva",
    "höftkurvorna": "höftkurva",
    "höftkurvornas": "höftkurva",
    "höftkurvors": "höftkurva",
    "höftkurvs": "höftkurva",
    "höftleden": "höftled",
    "höftledens": "höftled",
    "höftleder": "höftled",
    "höftlederna": "höftled",
    "höftledernas": "höftled",
    "höftleders": "höftled",
    "höftleds": "höftled",
    "höftledsoperationen": "höftledsoperation",
    "höftledsoperationens": "höftledsoperation",
    "höftledsoperationer": "höftledsoperation",
    "höftledsoperationerna": "höftledsoperation",
    "höftledsoperationernas": "höftledsoperation",
    "höftledsoperationers": "höftledsoperation",
    "höftledsoperations": "höftledsoperation",
    "höftlinjen": "höftlinje",
    "höftlinjens": "höftlinje",
    "höftlinjer": "höftlinje",
    "höftlinjerna": "höftlinje",
    "höftlinjernas": "höftlinje",
    "höftlinjers": "höftlinje",
    "höftlinjes": "höftlinje",
    "höftmåttet": "höftmått",
    "höftmåttets": "höftmått",
    "höftmåtts": "höftmått",
    "höftpartier": "höftparti",
    "höftpartierna": "höftparti",
    "höftpartiernas": "höftparti",
    "höftpartiers": "höftparti",
    "höftpartiet": "höftparti",
    "höftpartiets": "höftparti",
    "höftpartis": "höftparti",
    "höftpartit": "höftparti",
    "höftpartits": "höftparti",
    "höfts": "höft",
    "höftskynken": "höftskynke",
    "höftskynkena": "höftskynke",
    "höftskynkenas": "höftskynke",
    "höftskynkens": "höftskynke",
    "höftskynkes": "höftskynke",
    "höftskynket": "höftskynke",
    "höftskynkets": "höftskynke",
    "höftskynks": "höftskynke",
    "höga": "hög",
    "högadeln": "högadel",
    "högadelns": "högadel",
    "högadels": "högadel",
    "högaffeln": "högaffel",
    "högaffelns": "högaffel",
    "högaffels": "högaffel",
    "högafflar": "högaffel",
    "högafflarna": "högaffel",
    "högafflarnas": "högaffel",
    "högafflars": "högaffel",
    "högakt": "högakta",
    "högaktad": "högakta",
    "högaktade": "högakta",
    "högaktades": "högakta",
    "högaktads": "högakta",
    "högaktande": "högakta",
    "högaktanden": "högaktande",
    "högaktandena": "högaktande",
    "högaktandenas": "högaktande",
    "högaktandens": "högaktande",
    "högaktandes": "högaktande",
    "högaktandet": "högaktande",
    "högaktandets": "högaktande",
    "högaktar": "högakta",
    "högaktas": "högakta",
    "högaktat": "högakta",
    "högaktats": "högakta",
    "högaktiva": "högaktiv",
    "högaktivare": "högaktiv",
    "högaktivares": "högaktiv",
    "högaktivas": "högaktiv",
    "högaktivast": "högaktiv",
    "högaktivaste": "högaktiv",
    "högaktivastes": "högaktiv",
    "högaktivasts": "högaktiv",
    "högaktive": "högaktiv",
    "högaktives": "högaktiv",
    "högaktivs": "högaktiv",
    "högaktivt": "högaktiv",
    "högaktivts": "högaktiv",
    "högaktningar": "högaktning",
    "högaktningarna": "högaktning",
    "högaktningarnas": "högaktning",
    "högaktningars": "högaktning",
    "högaktningen": "högaktning",
    "högaktningens": "högaktning",
    "högaktnings": "högaktning",
    "högaktningsfulla": "högaktningsfull",
    "högaktningsfullare": "högaktningsfull",
    "högaktningsfullares": "högaktningsfull",
    "högaktningsfullas": "högaktningsfull",
    "högaktningsfullast": "högaktningsfull",
    "högaktningsfullaste": "högaktningsfull",
    "högaktningsfullastes": "högaktningsfull",
    "högaktningsfullasts": "högaktningsfull",
    "högaktningsfulle": "högaktningsfull",
    "högaktningsfulles": "högaktningsfull",
    "högaktningsfullheten": "högaktningsfullhet",
    "högaktningsfullhetens": "högaktningsfullhet",
    "högaktningsfullhets": "högaktningsfullhet",
    "högaktningsfulls": "högaktningsfull",
    "högaktningsfullt": "högaktningsfull",
    "högaktningsfullts": "högaktningsfull",
    "högaktuella": "högaktuell",
    "högaktuellare": "högaktuell",
    "högaktuellares": "högaktuell",
    "högaktuellas": "högaktuell",
    "högaktuellast": "högaktuell",
    "högaktuellaste": "högaktuell",
    "högaktuellastes": "högaktuell",
    "högaktuellasts": "högaktuell",
    "högaktuelle": "högaktuell",
    "högaktuelles": "högaktuell",
    "högaktuells": "högaktuell",
    "högaktuellt": "högaktuell",
    "högaktuellts": "högaktuell",
    "högaltar": "högaltare",
    "högaltaren": "högaltare",
    "högaltarens": "högaltare",
    "högaltares": "högaltare",
    "högaltaret": "högaltare",
    "högaltarets": "högaltare",
    "högaltarna": "högaltare",
    "högaltarnas": "högaltare",
    "högar": "hög",
    "högarna": "hög",
    "högarnas": "hög",
    "högars": "hög",
    "högas": "hög",
    "högbanan": "högbana",
    "högbanans": "högbana",
    "högbanas": "högbana",
    "högbane": "högbana",
    "högbanor": "högbana",
    "högbanorna": "högbana",
    "högbanornas": "högbana",
    "högbanors": "högbana",
    "högbenen": "högben",
    "högbenens": "högben",
    "högbenet": "högben",
    "högbenets": "högben",
    "högbens": "högben",
    "högbladen": "högblad",
    "högbladens": "högblad",
    "högbladet": "högblad",
    "högbladets": "högblad",
    "högblads": "högblad",
    "högborenheten": "högborenhet",
    "högborenhetens": "högborenhet",
    "högborenhets": "högborenhet",
    "högborens": "högboren",
    "högboret": "högboren",
    "högborets": "högboren",
    "högborgar": "högborg",
    "högborgarna": "högborg",
    "högborgarnas": "högborg",
    "högborgars": "högborg",
    "högborgen": "högborg",
    "högborgens": "högborg",
    "högborgerliga": "högborgerlig",
    "högborgerligare": "högborgerlig",
    "högborgerligares": "högborgerlig",
    "högborgerligas": "högborgerlig",
    "högborgerligast": "högborgerlig",
    "högborgerligaste": "högborgerlig",
    "högborgerligastes": "högborgerlig",
    "högborgerligasts": "högborgerlig",
    "högborgerlige": "högborgerlig",
    "högborgerliges": "högborgerlig",
    "högborgerligheten": "högborgerlighet",
    "högborgerlighetens": "högborgerlighet",
    "högborgerlighets": "högborgerlighet",
    "högborgerligs": "högborgerlig",
    "högborgerligt": "högborgerlig",
    "högborgerligts": "högborgerlig",
    "högborgs": "högborg",
    "högborna": "högboren",
    "högbornare": "högboren",
    "högbornares": "högboren",
    "högbornas": "högboren",
    "högbornast": "högboren",
    "högbornaste": "högboren",
    "högbornastes": "högboren",
    "högbornasts": "högboren",
    "högborne": "högboren",
    "högbornes": "högboren",
    "högburens": "högburen",
    "högburet": "högburen",
    "högburets": "högburen",
    "högburna": "högburen",
    "högburnare": "högburen",
    "högburnares": "högburen",
    "högburnas": "högburen",
    "högburnast": "högburen",
    "högburnaste": "högburen",
    "högburnastes": "högburen",
    "högburnasts": "högburen",
    "högburne": "högburen",
    "högburnes": "högburen",
    "högbänkar": "högbänk",
    "högbänkarna": "högbänk",
    "högbänkarnas": "högbänk",
    "högbänkars": "högbänk",
    "högbänken": "högbänk",
    "högbänkens": "högbänk",
    "högbänks": "högbänk",
    "högdjuren": "högdjur",
    "högdjurens": "högdjur",
    "högdjuret": "högdjur",
    "högdjurets": "högdjur",
    "högdjurs": "högdjur",
    "högdragenheten": "högdragenhet",
    "högdragenhetens": "högdragenhet",
    "högdragenhets": "högdragenhet",
    "högdragens": "högdragen",
    "högdraget": "högdragen",
    "högdragets": "högdragen",
    "högdragna": "högdragen",
    "högdragnare": "högdragen",
    "högdragnares": "högdragen",
    "högdragnas": "högdragen",
    "högdragnast": "högdragen",
    "högdragnaste": "högdragen",
    "högdragnastes": "högdragen",
    "högdragnasts": "högdragen",
    "högdragne": "högdragen",
    "högdragnes": "högdragen",
    "höge": "hög",
    "högeffektiva": "högeffektiv",
    "högeffektivas": "högeffektiv",
    "högeffektive": "högeffektiv",
    "högeffektives": "högeffektiv",
    "högeffektivs": "högeffektiv",
    "högeffektivt": "högeffektiv",
    "högeffektivts": "högeffektiv",
    "högen": "hög",
    "högenergien": "högenergi",
    "högenergiens": "högenergi",
    "högenergikollisionen": "högenergikollision",
    "högenergikollisionens": "högenergikollision",
    "högenergikollisioner": "högenergikollision",
    "högenergikollisionerna": "högenergikollision",
    "högenergikollisionernas": "högenergikollision",
    "högenergikollisioners": "högenergikollision",
    "högenergikollisions": "högenergikollision",
    "högenergin": "högenergi",
    "högenergins": "högenergi",
    "högenergis": "högenergi",
    "högens": "hög",
    "högerarmar": "högerarm",
    "högerarmarna": "högerarm",
    "högerarmarnas": "högerarm",
    "högerarmars": "högerarm",
    "högerarmen": "högerarm",
    "högerarmens": "högerarm",
    "högerarms": "högerarm",
    "högerbenen": "högerben",
    "högerbenens": "högerben",
    "högerbenet": "högerben",
    "högerbenets": "högerben",
    "högerbens": "högerben",
    "högerextrema": "högerextrem",
    "högerextremare": "högerextrem",
    "högerextremares": "högerextrem",
    "högerextremas": "högerextrem",
    "högerextremast": "högerextrem",
    "högerextremaste": "högerextrem",
    "högerextremastes": "högerextrem",
    "högerextremasts": "högerextrem",
    "högerextreme": "högerextrem",
    "högerextremes": "högerextrem",
    "högerextremistiska": "högerextremistisk",
    "högerextremistiskare": "högerextremistisk",
    "högerextremistiskares": "högerextremistisk",
    "högerextremistiskas": "högerextremistisk",
    "högerextremistiskast": "högerextremistisk",
    "högerextremistiskaste": "högerextremistisk",
    "högerextremistiskastes": "högerextremistisk",
    "högerextremistiskasts": "högerextremistisk",
    "högerextremistiske": "högerextremistisk",
    "högerextremistiskes": "högerextremistisk",
    "högerextremistisks": "högerextremistisk",
    "högerextremistiskt": "högerextremistisk",
    "högerextremistiskts": "högerextremistisk",
    "högerextrems": "högerextrem",
    "högerextremt": "högerextrem",
    "högerextremts": "högerextrem",
    "högerflygeln": "högerflygel",
    "högerflygelns": "högerflygel",
    "högerflygels": "högerflygel",
    "högerflyglar": "högerflygel",
    "högerflyglarna": "högerflygel",
    "högerflyglarnas": "högerflygel",
    "högerflyglars": "högerflygel",
    "högerfoten": "högerfot",
    "högerfotens": "högerfot",
    "högerfots": "högerfot",
    "högerfötter": "högerfot",
    "högerfötterna": "högerfot",
    "högerfötternas": "högerfot",
    "högerfötters": "högerfot",
    "högergirar": "högergir",
    "högergirarna": "högergir",
    "högergirarnas": "högergir",
    "högergirars": "högergir",
    "högergiren": "högergir",
    "högergirens": "högergir",
    "högergirs": "högergir",
    "högergängade": "högergängad",
    "högergängades": "högergängad",
    "högergängads": "högergängad",
    "högergängat": "högergängad",
    "högergängats": "högergängad",
    "högerhanden": "högerhand",
    "högerhandens": "högerhand",
    "högerhands": "högerhand",
    "högerhänder": "högerhand",
    "högerhänderna": "högerhand",
    "högerhändernas": "högerhand",
    "högerhänders": "högerhand",
    "högerhänta": "högerhänt",
    "högerhäntare": "högerhänt",
    "högerhäntares": "högerhänt",
    "högerhäntas": "högerhänt",
    "högerhäntast": "högerhänt",
    "högerhäntaste": "högerhänt",
    "högerhäntastes": "högerhänt",
    "högerhäntasts": "högerhänt",
    "högerhänte": "högerhänt",
    "högerhäntes": "högerhänt",
    "högerhäntheten": "högerhänthet",
    "högerhänthetens": "högerhänthet",
    "högerhänthets": "högerhänthet",
    "högerhänts": "högerhänt",
    "högerknappar": "högerknapp",
    "högerknapparna": "högerknapp",
    "högerknapparnas": "högerknapp",
    "högerknappars": "högerknapp",
    "högerknappen": "högerknapp",
    "högerknappens": "högerknapp",
    "högerknapps": "högerknapp",
    "högerkristenheten": "högerkristenhet",
    "högerkristenhetens": "högerkristenhet",
    "högerkristenhets": "högerkristenhet",
    "högerkristens": "högerkristen",
    "högerkristet": "högerkristen",
    "högerkristets": "högerkristen",
    "högerkristna": "högerkristen",
    "högerkristnare": "högerkristen",
    "högerkristnares": "högerkristen",
    "högerkristnas": "högerkristen",
    "högerkristnast": "högerkristen",
    "högerkristnaste": "högerkristen",
    "högerkristnastes": "högerkristen",
    "högerkristnasts": "högerkristen",
    "högerkristne": "högerkristen",
    "högerkristnes": "högerkristen",
    "högerkrokar": "högerkrok",
    "högerkrokarna": "högerkrok",
    "högerkrokarnas": "högerkrok",
    "högerkrokars": "högerkrok",
    "högerkroken": "högerkrok",
    "högerkrokens": "högerkrok",
    "högerkroks": "högerkrok",
    "högerkurv": "högerkurva",
    "högerkurvan": "högerkurva",
    "högerkurvans": "högerkurva",
    "högerkurvas": "högerkurva",
    "högerkurve": "högerkurva",
    "högerkurvor": "högerkurva",
    "högerkurvorna": "högerkurva",
    "högerkurvornas": "högerkurva",
    "högerkurvors": "högerkurva",
    "högerkurvs": "högerkurva",
    "högerledar": "högerledare",
    "högerledaren": "högerledare",
    "högerledarens": "högerledare",
    "högerledares": "högerledare",
    "högerledarna": "högerledare",
    "högerledarnas": "högerledare",
    "högermajoriteten": "högermajoritet",
    "högermajoritetens": "högermajoritet",
    "högermajoriteter": "högermajoritet",
    "högermajoriteterna": "högermajoritet",
    "högermajoriteternas": "högermajoritet",
    "högermajoriteters": "högermajoritet",
    "högermajoritets": "högermajoritet",
    "högermannen": "högerman",
    "högermannens": "högerman",
    "högermans": "högerman",
    "högermyten": "högermyt",
    "högermytens": "högermyt",
    "högermyter": "högermyt",
    "högermyterna": "högermyt",
    "högermyternas": "högermyt",
    "högermyters": "högermyt",
    "högermyts": "högermyt",
    "högermän": "högerman",
    "högermännen": "högerman",
    "högermännens": "högerman",
    "högermäns": "högerman",
    "högern": "höger",
    "högerns": "höger",
    "högerpartier": "högerparti",
    "högerpartierna": "högerparti",
    "högerpartiernas": "högerparti",
    "högerpartiers": "högerparti",
    "högerpartiet": "högerparti",
    "högerpartiets": "högerparti",
    "högerpartis": "högerparti",
    "högerpartit": "högerparti",
    "högerpartits": "högerparti",
    "högerpolitiken": "högerpolitik",
    "högerpolitikens": "högerpolitik",
    "högerpolitikern": "högerpolitiker",
    "högerpolitikerna": "högerpolitiker",
    "högerpolitikernas": "högerpolitiker",
    "högerpolitikerns": "högerpolitiker",
    "högerpolitikers": "högerpolitiker",
    "högerpolitiks": "högerpolitik",
    "högerpolitiska": "högerpolitisk",
    "högerpolitiskas": "högerpolitisk",
    "högerpolitiske": "högerpolitisk",
    "högerpolitiskes": "högerpolitisk",
    "högerpolitisks": "högerpolitisk",
    "högerpolitiskt": "högerpolitisk",
    "högerpolitiskts": "högerpolitisk",
    "högerpopulismen": "högerpopulism",
    "högerpopulismens": "högerpopulism",
    "högerpopulisms": "högerpopulism",
    "högerpopulistiska": "högerpopulistisk",
    "högerpopulistiskas": "högerpopulistisk",
    "högerpopulistiske": "högerpopulistisk",
    "högerpopulistiskes": "högerpopulistisk",
    "högerpopulistisks": "högerpopulistisk",
    "högerpopulistiskt": "högerpopulistisk",
    "högerpopulistiskts": "högerpopulistisk",
    "högerregeln": "högerregel",
    "högerregelns": "högerregel",
    "högerregels": "högerregel",
    "högerregeringar": "högerregering",
    "högerregeringarna": "högerregering",
    "högerregeringarnas": "högerregering",
    "högerregeringars": "högerregering",
    "högerregeringen": "högerregering",
    "högerregeringens": "högerregering",
    "högerregerings": "högerregering",
    "högers": "höger",
    "högersvängar": "högersväng",
    "högersvängarna": "högersväng",
    "högersvängarnas": "högersväng",
    "högersvängars": "högersväng",
    "högersvängen": "högersväng",
    "högersvängens": "högersväng",
    "högersvängs": "högersväng",
    "högertrafiken": "högertrafik",
    "högertrafikens": "högertrafik",
    "högertrafiks": "högertrafik",
    "högervindar": "högervind",
    "högervindarna": "högervind",
    "högervindarnas": "högervind",
    "högervindars": "högervind",
    "högervinden": "högervind",
    "högervindens": "högervind",
    "högervinds": "högervind",
    "högervridningar": "högervridning",
    "högervridningarna": "högervridning",
    "högervridningarnas": "högervridning",
    "högervridningars": "högervridning",
    "högervridningen": "högervridning",
    "högervridningens": "högervridning",
    "högervridnings": "högervridning",
    "högervågen": "högervåg",
    "högervågens": "högervåg",
    "högervågor": "högervåg",
    "högervågorna": "högervåg",
    "högervågornas": "högervåg",
    "högervågors": "högervåg",
    "högervågs": "högervåg",
    "högeråran": "högeråra",
    "högerårans": "högeråra",
    "högeråras": "högeråra",
    "högeråre": "högeråra",
    "högeråror": "högeråra",
    "högerårorna": "högeråra",
    "högerårornas": "högeråra",
    "högerårors": "högeråra",
    "högerögas": "högeröga",
    "högerögat": "högeröga",
    "högerögats": "högeröga",
    "högerögon": "högeröga",
    "högerögonen": "högeröga",
    "högerögonens": "högeröga",
    "högerögons": "högeröga",
    "högeröras": "högeröra",
    "högerörat": "högeröra",
    "högerörats": "högeröra",
    "högeröron": "högeröra",
    "högeröronen": "högeröra",
    "högeröronens": "högeröra",
    "högerörons": "högeröra",
    "höges": "hög",
    "högexplosiva": "högexplosiv",
    "högexplosivare": "högexplosiv",
    "högexplosivares": "högexplosiv",
    "högexplosivas": "högexplosiv",
    "högexplosivast": "högexplosiv",
    "högexplosivaste": "högexplosiv",
    "högexplosivastes": "högexplosiv",
    "högexplosivasts": "högexplosiv",
    "högexplosive": "högexplosiv",
    "högexplosives": "högexplosiv",
    "högexplosivs": "högexplosiv",
    "högexplosivt": "högexplosiv",
    "högexplosivts": "högexplosiv",
    "högfjällen": "högfjäll",
    "högfjällens": "högfjäll",
    "högfjället": "högfjäll",
    "högfjällets": "högfjäll",
    "högfjälls": "högfjäll",
    "högfjällsområden": "högfjällsområde",
    "högfjällsområdena": "högfjällsområde",
    "högfjällsområdenas": "högfjällsområde",
    "högfjällsområdens": "högfjällsområde",
    "högfjällsområdes": "högfjällsområde",
    "högfjällsområdet": "högfjällsområde",
    "högfjällsområdets": "högfjällsområde",
    "högfloden": "högflod",
    "högflodens": "högflod",
    "högflods": "högflod",
    "högformen": "högform",
    "högformens": "högform",
    "högformer": "högform",
    "högformerna": "högform",
    "högformernas": "högform",
    "högformers": "högform",
    "högforms": "högform",
    "högfrekvensen": "högfrekvens",
    "högfrekvensens": "högfrekvens",
    "högfrekvenser": "högfrekvens",
    "högfrekvenserna": "högfrekvens",
    "högfrekvensernas": "högfrekvens",
    "högfrekvensers": "högfrekvens",
    "högfrekventa": "högfrekvent",
    "högfrekventare": "högfrekvent",
    "högfrekventares": "högfrekvent",
    "högfrekventas": "högfrekvent",
    "högfrekventast": "högfrekvent",
    "högfrekventaste": "högfrekvent",
    "högfrekventastes": "högfrekvent",
    "högfrekventasts": "högfrekvent",
    "högfrekvente": "högfrekvent",
    "högfrekventes": "högfrekvent",
    "högfrekvents": "högfrekvent",
    "högfärden": "högfärd",
    "högfärdens": "högfärd",
    "högfärdiga": "högfärdig",
    "högfärdigare": "högfärdig",
    "högfärdigares": "högfärdig",
    "högfärdigas": "högfärdig",
    "högfärdigast": "högfärdig",
    "högfärdigaste": "högfärdig",
    "högfärdigastes": "högfärdig",
    "högfärdigasts": "högfärdig",
    "högfärdige": "högfärdig",
    "högfärdiges": "högfärdig",
    "högfärdigheten": "högfärdighet",
    "högfärdighetens": "högfärdighet",
    "högfärdighets": "högfärdighet",
    "högfärdigs": "högfärdig",
    "högfärdigt": "högfärdig",
    "högfärdigts": "högfärdig",
    "högfärds": "högfärd",
    "högfärdsblås": "högfärdsblåsa",
    "högfärdsblåsan": "högfärdsblåsa",
    "högfärdsblåsans": "högfärdsblåsa",
    "högfärdsblåsas": "högfärdsblåsa",
    "högfärdsblåse": "högfärdsblåsa",
    "högfärdsblåsor": "högfärdsblåsa",
    "högfärdsblåsorna": "högfärdsblåsa",
    "högfärdsblåsornas": "högfärdsblåsa",
    "högfärdsblåsors": "högfärdsblåsa",
    "högfärdsdjävulen": "högfärdsdjävul",
    "högfärdsdjävulens": "högfärdsdjävul",
    "högfärdsdjävuls": "högfärdsdjävul",
    "högförnäma": "högförnäm",
    "högförnämare": "högförnäm",
    "högförnämares": "högförnäm",
    "högförnämas": "högförnäm",
    "högförnämast": "högförnäm",
    "högförnämaste": "högförnäm",
    "högförnämastes": "högförnäm",
    "högförnämasts": "högförnäm",
    "högförnäme": "högförnäm",
    "högförnämes": "högförnäm",
    "högförnämheten": "högförnämhet",
    "högförnämhetens": "högförnämhet",
    "högförnämhets": "högförnämhet",
    "högförnäms": "högförnäm",
    "högförnämt": "högförnäm",
    "högförnämts": "högförnäm",
    "högförrädar": "högförrädare",
    "högförrädaren": "högförrädare",
    "högförrädarens": "högförrädare",
    "högförrädares": "högförrädare",
    "högförrädarna": "högförrädare",
    "högförrädarnas": "högförrädare",
    "högförräderier": "högförräderi",
    "högförräderierna": "högförräderi",
    "högförräderiernas": "högförräderi",
    "högförräderiers": "högförräderi",
    "högförräderiet": "högförräderi",
    "högförräderiets": "högförräderi",
    "högförräderis": "högförräderi",
    "högförräderit": "högförräderi",
    "högförräderits": "högförräderi",
    "högg": "hugga",
    "högge": "hugga",
    "högges": "hugga",
    "högglansen": "högglans",
    "högglansens": "högglans",
    "högglansvaxen": "högglansvax",
    "högglansvaxens": "högglansvax",
    "högglansvaxer": "högglansvax",
    "högglansvaxerna": "högglansvax",
    "högglansvaxernas": "högglansvax",
    "högglansvaxers": "högglansvax",
    "höggradiga": "höggradig",
    "höggradigare": "höggradig",
    "höggradigares": "höggradig",
    "höggradigas": "höggradig",
    "höggradigast": "höggradig",
    "höggradigaste": "höggradig",
    "höggradigastes": "höggradig",
    "höggradigasts": "höggradig",
    "höggradige": "höggradig",
    "höggradiges": "höggradig",
    "höggradigs": "höggradig",
    "höggradigt": "höggradig",
    "höggradigts": "höggradig",
    "höggravida": "höggravid",
    "höggravidare": "höggravid",
    "höggravidares": "höggravid",
    "höggravidas": "höggravid",
    "höggravidast": "höggravid",
    "höggravidaste": "höggravid",
    "höggravidastes": "höggravid",
    "höggravidasts": "höggravid",
    "höggravide": "höggravid",
    "höggravides": "höggravid",
    "höggravids": "höggravid",
    "höggs": "hugga",
    "höghalsade": "höghalsad",
    "höghalsades": "höghalsad",
    "höghalsads": "höghalsad",
    "höghalsat": "höghalsad",
    "höghalsats": "höghalsad",
    "höghastighetskameran": "höghastighetskamera",
    "höghastighetskamerans": "höghastighetskamera",
    "höghastighetskameras": "höghastighetskamera",
    "höghastighetskameror": "höghastighetskamera",
    "höghastighetskamerorna": "höghastighetskamera",
    "höghastighetskamerornas": "höghastighetskamera",
    "höghastighetskamerors": "höghastighetskamera",
    "högheten": "höghet",
    "höghetens": "höghet",
    "högheter": "höghet",
    "högheterna": "höghet",
    "högheternas": "höghet",
    "högheters": "höghet",
    "höghets": "höghet",
    "höghusen": "höghus",
    "höghusens": "höghus",
    "höghuset": "höghus",
    "höghusets": "höghus",
    "höginkomst": "höginkomster",
    "höginkomsterna": "höginkomster",
    "höginkomsternas": "höginkomster",
    "höginkomsters": "höginkomster",
    "höginkomsttagar": "höginkomsttagare",
    "höginkomsttagaren": "höginkomsttagare",
    "höginkomsttagarens": "höginkomsttagare",
    "höginkomsttagares": "höginkomsttagare",
    "höginkomsttagarna": "höginkomsttagare",
    "höginkomsttagarnas": "höginkomsttagare",
    "högkinesisk": "högkinesiska",
    "högkinesiskan": "högkinesiska",
    "högkinesiskans": "högkinesiska",
    "högkinesiskas": "högkinesiska",
    "högklackade": "högklackad",
    "högklackades": "högklackad",
    "högklackads": "högklackad",
    "högklackat": "högklackad",
    "högklackats": "högklackad",
    "högklassiga": "högklassig",
    "högklassigare": "högklassig",
    "högklassigares": "högklassig",
    "högklassigas": "högklassig",
    "högklassigast": "högklassig",
    "högklassigaste": "högklassig",
    "högklassigastes": "högklassig",
    "högklassigasts": "högklassig",
    "högklassige": "högklassig",
    "högklassiges": "högklassig",
    "högklassigheten": "högklassighet",
    "högklassighetens": "högklassighet",
    "högklassighets": "högklassighet",
    "högklassigs": "högklassig",
    "högklassigt": "högklassig",
    "högklassigts": "högklassig",
    "högkonjunkturen": "högkonjunktur",
    "högkonjunkturens": "högkonjunktur",
    "högkonjunkturer": "högkonjunktur",
    "högkonjunkturerna": "högkonjunktur",
    "högkonjunkturernas": "högkonjunktur",
    "högkonjunkturers": "högkonjunktur",
    "högkonjunkturs": "högkonjunktur",
    "högkulturen": "högkultur",
    "högkulturens": "högkultur",
    "högkulturer": "högkultur",
    "högkulturerna": "högkultur",
    "högkulturernas": "högkultur",
    "högkulturers": "högkultur",
    "högkulturs": "högkultur",
    "högkvarteren": "högkvarter",
    "högkvarterens": "högkvarter",
    "högkvarteret": "högkvarter",
    "högkvarterets": "högkvarter",
    "högkvarters": "högkvarter",
    "högkyrkliga": "högkyrklig",
    "högkyrkligare": "högkyrklig",
    "högkyrkligares": "högkyrklig",
    "högkyrkligas": "högkyrklig",
    "högkyrkligast": "högkyrklig",
    "högkyrkligaste": "högkyrklig",
    "högkyrkligastes": "högkyrklig",
    "högkyrkligasts": "högkyrklig",
    "högkyrklige": "högkyrklig",
    "högkyrkliges": "högkyrklig",
    "högkyrkligheten": "högkyrklighet",
    "högkyrklighetens": "högkyrklighet",
    "högkyrklighets": "högkyrklighet",
    "högkyrkligs": "högkyrklig",
    "högkyrkligt": "högkyrklig",
    "högkyrkligts": "högkyrklig",
    "höglagerna": "höglager",
    "höglagernas": "höglager",
    "höglagers": "höglager",
    "höglagren": "höglager",
    "höglagrens": "höglager",
    "höglagret": "höglager",
    "höglagrets": "höglager",
    "höglandet": "högland",
    "höglandets": "högland",
    "höglands": "högland",
    "högljudda": "högljudd",
    "högljuddare": "högljudd",
    "högljuddares": "högljudd",
    "högljuddas": "högljudd",
    "högljuddast": "högljudd",
    "högljuddaste": "högljudd",
    "högljuddastes": "högljudd",
    "högljuddasts": "högljudd",
    "högljudde": "högljudd",
    "högljuddes": "högljudd",
    "högljuddheten": "högljuddhet",
    "högljuddhetens": "högljuddhet",
    "högljuddhets": "högljuddhet",
    "högljudds": "högljudd",
    "högljutt": "högljudd",
    "högljutts": "högljudd",
    "högländar": "högländare",
    "högländaren": "högländare",
    "högländarens": "högländare",
    "högländares": "högländare",
    "högländarna": "högländare",
    "högländarnas": "högländare",
    "högländer": "högland",
    "högländerna": "högland",
    "högländernas": "högland",
    "högländers": "högland",
    "höglänta": "höglänt",
    "högläntare": "höglänt",
    "högläntares": "höglänt",
    "högläntas": "höglänt",
    "högläntast": "höglänt",
    "högläntaste": "höglänt",
    "högläntastes": "höglänt",
    "högläntasts": "höglänt",
    "höglänte": "höglänt",
    "högläntes": "höglänt",
    "högläntheten": "höglänthet",
    "höglänthetens": "höglänthet",
    "höglänthets": "höglänthet",
    "höglänts": "höglänt",
    "högläsningar": "högläsning",
    "högläsningarna": "högläsning",
    "högläsningarnas": "högläsning",
    "högläsningars": "högläsning",
    "högläsningen": "högläsning",
    "högläsningens": "högläsning",
    "högläsnings": "högläsning",
    "höglönejobben": "höglönejobb",
    "höglönejobbens": "höglönejobb",
    "höglönejobbet": "höglönejobb",
    "höglönejobbets": "höglönejobb",
    "höglönejobbs": "höglönejobb",
    "högmodet": "högmod",
    "högmodets": "högmod",
    "högmodiga": "högmodig",
    "högmodigare": "högmodig",
    "högmodigares": "högmodig",
    "högmodigas": "högmodig",
    "högmodigast": "högmodig",
    "högmodigaste": "högmodig",
    "högmodigastes": "högmodig",
    "högmodigasts": "högmodig",
    "högmodige": "högmodig",
    "högmodiges": "högmodig",
    "högmodigheten": "högmodighet",
    "högmodighetens": "högmodighet",
    "högmodighets": "högmodighet",
    "högmodigs": "högmodig",
    "högmodigt": "högmodig",
    "högmodigts": "högmodig",
    "högmods": "högmod",
    "högmolekylära": "högmolekylär",
    "högmolekylärare": "högmolekylär",
    "högmolekylärares": "högmolekylär",
    "högmolekyläras": "högmolekylär",
    "högmolekylärast": "högmolekylär",
    "högmolekyläraste": "högmolekylär",
    "högmolekylärastes": "högmolekylär",
    "högmolekylärasts": "högmolekylär",
    "högmolekyläre": "högmolekylär",
    "högmolekyläres": "högmolekylär",
    "högmolekylärs": "högmolekylär",
    "högmolekylärt": "högmolekylär",
    "högmolekylärts": "högmolekylär",
    "högmäss": "högmässa",
    "högmässan": "högmässa",
    "högmässans": "högmässa",
    "högmässas": "högmässa",
    "högmässe": "högmässa",
    "högmässor": "högmässa",
    "högmässorna": "högmässa",
    "högmässornas": "högmässa",
    "högmässors": "högmässa",
    "högmålsbrotten": "högmålsbrott",
    "högmålsbrottens": "högmålsbrott",
    "högmålsbrottet": "högmålsbrott",
    "högmålsbrottets": "högmålsbrott",
    "högmålsbrotts": "högmålsbrott",
    "högoddsar": "högoddsare",
    "högoddsaren": "högoddsare",
    "högoddsarens": "högoddsare",
    "högoddsares": "högoddsare",
    "högoddsarna": "högoddsare",
    "högoddsarnas": "högoddsare",
    "högoktaniga": "högoktanig",
    "högoktanigare": "högoktanig",
    "högoktanigares": "högoktanig",
    "högoktanigas": "högoktanig",
    "högoktanigast": "högoktanig",
    "högoktanigaste": "högoktanig",
    "högoktanigastes": "högoktanig",
    "högoktanigasts": "högoktanig",
    "högoktanige": "högoktanig",
    "högoktaniges": "högoktanig",
    "högoktanigs": "högoktanig",
    "högoktanigt": "högoktanig",
    "högoktanigts": "högoktanig",
    "högplatåer": "högplatå",
    "högplatåerna": "högplatå",
    "högplatåernas": "högplatå",
    "högplatåers": "högplatå",
    "högplatån": "högplatå",
    "högplatåns": "högplatå",
    "högplatås": "högplatå",
    "högprioriterad": "högprioritera",
    "högprioriterade": "högprioritera",
    "högprioriterades": "högprioritera",
    "högprioriterads": "högprioritera",
    "högprioriterande": "högprioritera",
    "högprioriterandes": "högprioritera",
    "högprioriterar": "högprioritera",
    "högprioriteras": "högprioritera",
    "högprioriterat": "högprioritera",
    "högprioriterats": "högprioritera",
    "högprosan": "högprosa",
    "högprosans": "högprosa",
    "högprosas": "högprosa",
    "högra": "höger",
    "högras": "höger",
    "högre": "hög",
    "högres": "hög",
    "högresta": "högrest",
    "högrestare": "högrest",
    "högrestares": "högrest",
    "högrestas": "högrest",
    "högrestast": "högrest",
    "högrestaste": "högrest",
    "högrestastes": "högrest",
    "högrestasts": "högrest",
    "högreste": "högrest",
    "högrestes": "högrest",
    "högrestheten": "högresthet",
    "högresthetens": "högresthet",
    "högresthets": "högresthet",
    "högrests": "högrest",
    "högreståndsdamen": "högreståndsdam",
    "högreståndsdamens": "högreståndsdam",
    "högreståndsdamer": "högreståndsdam",
    "högreståndsdamerna": "högreståndsdam",
    "högreståndsdamernas": "högreståndsdam",
    "högreståndsdamers": "högreståndsdam",
    "högreståndsdams": "högreståndsdam",
    "högreståndskulturen": "högreståndskultur",
    "högreståndskulturens": "högreståndskultur",
    "högreståndskulturer": "högreståndskultur",
    "högreståndskulturerna": "högreståndskultur",
    "högreståndskulturernas": "högreståndskultur",
    "högreståndskulturers": "högreståndskultur",
    "högreståndskulturs": "högreståndskultur",
    "högreståndsmässiga": "högreståndsmässig",
    "högreståndsmässigare": "högreståndsmässig",
    "högreståndsmässigares": "högreståndsmässig",
    "högreståndsmässigas": "högreståndsmässig",
    "högreståndsmässigast": "högreståndsmässig",
    "högreståndsmässigaste": "högreståndsmässig",
    "högreståndsmässigastes": "högreståndsmässig",
    "högreståndsmässigasts": "högreståndsmässig",
    "högreståndsmässige": "högreståndsmässig",
    "högreståndsmässiges": "högreståndsmässig",
    "högreståndsmässigs": "högreståndsmässig",
    "högreståndsmässigt": "högreståndsmässig",
    "högreståndsmässigts": "högreståndsmässig",
    "högreven": "högrev",
    "högrevens": "högrev",
    "högrevet": "högrev",
    "högrevets": "högrev",
    "högrevs": "högrev",
    "högriskfonden": "högriskfond",
    "högriskfondens": "högriskfond",
    "högriskfonder": "högriskfond",
    "högriskfonderna": "högriskfond",
    "högriskfondernas": "högriskfond",
    "högriskfonders": "högriskfond",
    "högriskfonds": "högriskfond",
    "högriskmatchen": "högriskmatch",
    "högriskmatchens": "högriskmatch",
    "högriskmatcher": "högriskmatch",
    "högriskmatcherna": "högriskmatch",
    "högriskmatchernas": "högriskmatch",
    "högriskmatchers": "högriskmatch",
    "högriskmatchs": "högriskmatch",
    "högromantiska": "högromantisk",
    "högromantiskare": "högromantisk",
    "högromantiskares": "högromantisk",
    "högromantiskas": "högromantisk",
    "högromantiskast": "högromantisk",
    "högromantiskaste": "högromantisk",
    "högromantiskastes": "högromantisk",
    "högromantiskasts": "högromantisk",
    "högromantiske": "högromantisk",
    "högromantiskes": "högromantisk",
    "högromantisks": "högromantisk",
    "högromantiskt": "högromantisk",
    "högromantiskts": "högromantisk",
    "högröda": "högröd",
    "högrödare": "högröd",
    "högrödares": "högröd",
    "högrödas": "högröd",
    "högrödast": "högröd",
    "högrödaste": "högröd",
    "högrödastes": "högröd",
    "högrödasts": "högröd",
    "högröde": "högröd",
    "högrödes": "högröd",
    "högröds": "högröd",
    "högröstade": "högröstad",
    "högröstades": "högröstad",
    "högröstads": "högröstad",
    "högröstat": "högröstad",
    "högröstats": "högröstad",
    "högrött": "högröd",
    "högrötts": "högröd",
    "högs": "hög",
    "högsinnade": "högsinnad",
    "högsinnades": "högsinnad",
    "högsinnads": "högsinnad",
    "högsinnat": "högsinnad",
    "högsinnats": "högsinnad",
    "högsinta": "högsint",
    "högsintare": "högsint",
    "högsintares": "högsint",
    "högsintas": "högsint",
    "högsintast": "högsint",
    "högsintaste": "högsint",
    "högsintastes": "högsint",
    "högsintasts": "högsint",
    "högsinte": "högsint",
    "högsintes": "högsint",
    "högsintheten": "högsinthet",
    "högsinthetens": "högsinthet",
    "högsinthets": "högsinthet",
    "högsints": "högsint",
    "högsjöflott": "högsjöflotta",
    "högsjöflottan": "högsjöflotta",
    "högsjöflottans": "högsjöflotta",
    "högsjöflottas": "högsjöflotta",
    "högsjöflotte": "högsjöflotta",
    "högsjöflottor": "högsjöflotta",
    "högsjöflottorna": "högsjöflotta",
    "högsjöflottornas": "högsjöflotta",
    "högsjöflottors": "högsjöflotta",
    "högsjöflotts": "högsjöflotta",
    "högskaftade": "högskaftad",
    "högskaftades": "högskaftad",
    "högskaftads": "högskaftad",
    "högskaftat": "högskaftad",
    "högskaftats": "högskaftad",
    "högskolan": "högskola",
    "högskolans": "högskola",
    "högskolas": "högskola",
    "högskole": "högskola",
    "högskoleadjunkten": "högskoleadjunkt",
    "högskoleadjunktens": "högskoleadjunkt",
    "högskoleadjunkter": "högskoleadjunkt",
    "högskoleadjunkterna": "högskoleadjunkt",
    "högskoleadjunkternas": "högskoleadjunkt",
    "högskoleadjunkters": "högskoleadjunkt",
    "högskoleadjunkts": "högskoleadjunkt",
    "högskoleexamens": "högskoleexamen",
    "högskoleexamina": "högskoleexamen",
    "högskoleexaminas": "högskoleexamen",
    "högskoleguiden": "högskoleguide",
    "högskoleguidens": "högskoleguide",
    "högskoleguider": "högskoleguide",
    "högskoleguiderna": "högskoleguide",
    "högskoleguidernas": "högskoleguide",
    "högskoleguiders": "högskoleguide",
    "högskoleguides": "högskoleguide",
    "högskolelektorer": "högskolelektor",
    "högskolelektorerna": "högskolelektor",
    "högskolelektorernas": "högskolelektor",
    "högskolelektorers": "högskolelektor",
    "högskolelektorn": "högskolelektor",
    "högskolelektorns": "högskolelektor",
    "högskolelektors": "högskolelektor",
    "högskolemässiga": "högskolemässig",
    "högskolemässigare": "högskolemässig",
    "högskolemässigares": "högskolemässig",
    "högskolemässigas": "högskolemässig",
    "högskolemässigast": "högskolemässig",
    "högskolemässigaste": "högskolemässig",
    "högskolemässigastes": "högskolemässig",
    "högskolemässigasts": "högskolemässig",
    "högskolemässige": "högskolemässig",
    "högskolemässiges": "högskolemässig",
    "högskolemässigs": "högskolemässig",
    "högskolemässigt": "högskolemässig",
    "högskolemässigts": "högskolemässig",
    "högskoleplatsen": "högskoleplats",
    "högskoleplatsens": "högskoleplats",
    "högskoleplatser": "högskoleplats",
    "högskoleplatserna": "högskoleplats",
    "högskoleplatsernas": "högskoleplats",
    "högskoleplatsers": "högskoleplats",
    "högskoleutbildningar": "högskoleutbildning",
    "högskoleutbildningarna": "högskoleutbildning",
    "högskoleutbildningarnas": "högskoleutbildning",
    "högskoleutbildningars": "högskoleutbildning",
    "högskoleutbildningen": "högskoleutbildning",
    "högskoleutbildningens": "högskoleutbildning",
    "högskoleutbildnings": "högskoleutbildning",
    "högskolor": "högskola",
    "högskolorna": "högskola",
    "högskolornas": "högskola",
    "högskolors": "högskola",
    "högslätten": "högslätt",
    "högslättens": "högslätt",
    "högslätter": "högslätt",
    "högslätterna": "högslätt",
    "högslätternas": "högslätt",
    "högslätters": "högslätt",
    "högslätts": "högslätt",
    "högsommaren": "högsommar",
    "högsommarens": "högsommar",
    "högsommarn": "högsommar",
    "högsommarns": "högsommar",
    "högsommars": "högsommar",
    "högsomrar": "högsommar",
    "högsomrarna": "högsommar",
    "högsomrarnas": "högsommar",
    "högsomrars": "högsommar",
    "högspecialiserade": "högspecialiserad",
    "högspecialiserades": "högspecialiserad",
    "högspecialiserads": "högspecialiserad",
    "högspecialiserat": "högspecialiserad",
    "högspecialiserats": "högspecialiserad",
    "högspända": "högspänd",
    "högspändare": "högspänd",
    "högspändares": "högspänd",
    "högspändas": "högspänd",
    "högspändast": "högspänd",
    "högspändaste": "högspänd",
    "högspändastes": "högspänd",
    "högspändasts": "högspänd",
    "högspände": "högspänd",
    "högspändes": "högspänd",
    "högspänds": "högspänd",
    "högspänningar": "högspänning",
    "högspänningarna": "högspänning",
    "högspänningarnas": "högspänning",
    "högspänningars": "högspänning",
    "högspänningen": "högspänning",
    "högspänningens": "högspänning",
    "högspännings": "högspänning",
    "högspänt": "högspänd",
    "högspänts": "högspänd",
    "högst": "hög",
    "högsta": "hög",
    "högstadie": "högstadium",
    "högstadielärar": "högstadielärare",
    "högstadieläraren": "högstadielärare",
    "högstadielärarens": "högstadielärare",
    "högstadielärares": "högstadielärare",
    "högstadielärarna": "högstadielärare",
    "högstadielärarnas": "högstadielärare",
    "högstadier": "högstadium",
    "högstadierna": "högstadium",
    "högstadiernas": "högstadium",
    "högstadiers": "högstadium",
    "högstadiet": "högstadium",
    "högstadiets": "högstadium",
    "högstadieungar": "högstadieunge",
    "högstadieungarna": "högstadieunge",
    "högstadieungarnas": "högstadieunge",
    "högstadieungars": "högstadieunge",
    "högstadieungen": "högstadieunge",
    "högstadieungens": "högstadieunge",
    "högstadieunges": "högstadieunge",
    "högstadiums": "högstadium",
    "högstas": "hög",
    "högstatusen": "högstatus",
    "högstatusens": "högstatus",
    "högstdensammes": "högstdensamme",
    "högstdesamma": "högstdensamme",
    "högstdesammas": "högstdensamme",
    "högstdetsamma": "högstdensamme",
    "högstdetsammas": "högstdensamme",
    "högste": "hög",
    "högstes": "hög",
    "högsts": "hög",
    "högstämda": "högstämd",
    "högstämdare": "högstämd",
    "högstämdares": "högstämd",
    "högstämdas": "högstämd",
    "högstämdast": "högstämd",
    "högstämdaste": "högstämd",
    "högstämdastes": "högstämd",
    "högstämdasts": "högstämd",
    "högstämde": "högstämd",
    "högstämdes": "högstämd",
    "högstämdheten": "högstämdhet",
    "högstämdhetens": "högstämdhet",
    "högstämdhets": "högstämdhet",
    "högstämds": "högstämd",
    "högstämt": "högstämd",
    "högstämts": "högstämd",
    "högsäsongen": "högsäsong",
    "högsäsongens": "högsäsong",
    "högsäsonger": "högsäsong",
    "högsäsongerna": "högsäsong",
    "högsäsongernas": "högsäsong",
    "högsäsongers": "högsäsong",
    "högsäsongs": "högsäsong",
    "högsäten": "högsäte",
    "högsätena": "högsäte",
    "högsätenas": "högsäte",
    "högsätens": "högsäte",
    "högsätes": "högsäte",
    "högsätet": "högsäte",
    "högsätets": "högsäte",
    "högt": "hög",
    "högtalar": "högtalare",
    "högtalaren": "högtalare",
    "högtalarens": "högtalare",
    "högtalares": "högtalare",
    "högtalarna": "högtalare",
    "högtalarnas": "högtalare",
    "högteknologien": "högteknologi",
    "högteknologiens": "högteknologi",
    "högteknologier": "högteknologi",
    "högteknologierna": "högteknologi",
    "högteknologiernas": "högteknologi",
    "högteknologiers": "högteknologi",
    "högteknologin": "högteknologi",
    "högteknologins": "högteknologi",
    "högteknologis": "högteknologi",
    "högteknologiska": "högteknologisk",
    "högteknologiskare": "högteknologisk",
    "högteknologiskares": "högteknologisk",
    "högteknologiskas": "högteknologisk",
    "högteknologiskast": "högteknologisk",
    "högteknologiskaste": "högteknologisk",
    "högteknologiskastes": "högteknologisk",
    "högteknologiskasts": "högteknologisk",
    "högteknologiske": "högteknologisk",
    "högteknologiskes": "högteknologisk",
    "högteknologisks": "högteknologisk",
    "högteknologiskt": "högteknologisk",
    "högteknologiskts": "högteknologisk",
    "högtiden": "högtid",
    "högtidens": "högtid",
    "högtider": "högtid",
    "högtiderna": "högtid",
    "högtidernas": "högtid",
    "högtiders": "högtid",
    "högtidliga": "högtidlig",
    "högtidligare": "högtidlig",
    "högtidligares": "högtidlig",
    "högtidligas": "högtidlig",
    "högtidligast": "högtidlig",
    "högtidligaste": "högtidlig",
    "högtidligastes": "högtidlig",
    "högtidligasts": "högtidlig",
    "högtidlige": "högtidlig",
    "högtidliges": "högtidlig",
    "högtidligheten": "högtidlighet",
    "högtidlighetens": "högtidlighet",
    "högtidligheter": "högtidlighet",
    "högtidligheterna": "högtidlighet",
    "högtidligheternas": "högtidlighet",
    "högtidligheters": "högtidlighet",
    "högtidlighets": "högtidlighet",
    "högtidlighåll": "högtidlighålla",
    "högtidlighållande": "högtidlighålla",
    "högtidlighållanden": "högtidlighållande",
    "högtidlighållandena": "högtidlighållande",
    "högtidlighållandenas": "högtidlighållande",
    "högtidlighållandens": "högtidlighållande",
    "högtidlighållandes": "högtidlighållande",
    "högtidlighållandet": "högtidlighållande",
    "högtidlighållandets": "högtidlighållande",
    "högtidlighållas": "högtidlighålla",
    "högtidlighålle": "högtidlighålla",
    "högtidlighållen": "högtidlighålla",
    "högtidlighållens": "högtidlighålla",
    "högtidlighåller": "högtidlighålla",
    "högtidlighålles": "högtidlighålla",
    "högtidlighållet": "högtidlighålla",
    "högtidlighållets": "högtidlighålla",
    "högtidlighållit": "högtidlighålla",
    "högtidlighållits": "högtidlighålla",
    "högtidlighållna": "högtidlighålla",
    "högtidlighållnas": "högtidlighålla",
    "högtidlighållne": "högtidlighålla",
    "högtidlighållnes": "högtidlighålla",
    "högtidlighålls": "högtidlighålla",
    "högtidlighöll": "högtidlighålla",
    "högtidlighölle": "högtidlighålla",
    "högtidlighölles": "högtidlighålla",
    "högtidlighölls": "högtidlighålla",
    "högtidligs": "högtidlig",
    "högtidligt": "högtidlig",
    "högtidligts": "högtidlig",
    "högtids": "högtid",
    "högtidsdagar": "högtidsdag",
    "högtidsdagarna": "högtidsdag",
    "högtidsdagarnas": "högtidsdag",
    "högtidsdagars": "högtidsdag",
    "högtidsdagen": "högtidsdag",
    "högtidsdagens": "högtidsdag",
    "högtidsdags": "högtidsdag",
    "högtidsdräkten": "högtidsdräkt",
    "högtidsdräktens": "högtidsdräkt",
    "högtidsdräkter": "högtidsdräkt",
    "högtidsdräkterna": "högtidsdräkt",
    "högtidsdräkternas": "högtidsdräkt",
    "högtidsdräkters": "högtidsdräkt",
    "högtidsdräkts": "högtidsdräkt",
    "högtidsstunden": "högtidsstund",
    "högtidsstundens": "högtidsstund",
    "högtidsstunder": "högtidsstund",
    "högtidsstunderna": "högtidsstund",
    "högtidsstundernas": "högtidsstund",
    "högtidsstunders": "högtidsstund",
    "högtidsstunds": "högtidsstund",
    "högtidstalen": "högtidstal",
    "högtidstalens": "högtidstal",
    "högtidstalet": "högtidstal",
    "högtidstalets": "högtidstal",
    "högtidstals": "högtidstal",
    "högtidsåren": "högtidsår",
    "högtidsårens": "högtidsår",
    "högtidsåret": "högtidsår",
    "högtidsårets": "högtidsår",
    "högtidsårs": "högtidsår",
    "högtrafiken": "högtrafik",
    "högtrafikens": "högtrafik",
    "högtrafiks": "högtrafik",
    "högtrycken": "högtryck",
    "högtryckens": "högtryck",
    "högtrycket": "högtryck",
    "högtryckets": "högtryck",
    "högtrycks": "högtryck",
    "högtryckskabeln": "högtryckskabel",
    "högtryckskabelns": "högtryckskabel",
    "högtryckskabels": "högtryckskabel",
    "högtryckskablar": "högtryckskabel",
    "högtryckskablarna": "högtryckskabel",
    "högtryckskablarnas": "högtryckskabel",
    "högtryckskablars": "högtryckskabel",
    "högtrycksryggar": "högtrycksrygg",
    "högtrycksryggarna": "högtrycksrygg",
    "högtrycksryggarnas": "högtrycksrygg",
    "högtrycksryggars": "högtrycksrygg",
    "högtrycksryggen": "högtrycksrygg",
    "högtrycksryggens": "högtrycksrygg",
    "högtrycksryggs": "högtrycksrygg",
    "högtryckstvättar": "högtryckstvätt",
    "högtryckstvättarna": "högtryckstvätt",
    "högtryckstvättarnas": "högtryckstvätt",
    "högtryckstvättars": "högtryckstvätt",
    "högtryckstvätten": "högtryckstvätt",
    "högtryckstvättens": "högtryckstvätt",
    "högtryckstvätts": "högtryckstvätt",
    "högts": "hög",
    "högtysk": "högtyska",
    "högtyska": "högtysk",
    "högtyskan": "högtyska",
    "högtyskans": "högtyska",
    "högtyskare": "högtysk",
    "högtyskares": "högtysk",
    "högtyskas": "högtyska",
    "högtyskast": "högtysk",
    "högtyskaste": "högtysk",
    "högtyskastes": "högtysk",
    "högtyskasts": "högtysk",
    "högtyske": "högtysk",
    "högtyskes": "högtysk",
    "högtysks": "högtysk",
    "högtyskt": "högtysk",
    "högtyskts": "högtysk",
    "högvakten": "högvakt",
    "högvaktens": "högvakt",
    "högvakter": "högvakt",
    "högvakterna": "högvakt",
    "högvakternas": "högvakt",
    "högvakters": "högvakt",
    "högvakts": "högvakt",
    "högvallar": "högvall",
    "högvallarna": "högvall",
    "högvallarnas": "högvall",
    "högvallars": "högvall",
    "högvallen": "högvall",
    "högvallens": "högvall",
    "högvalls": "högvall",
    "högvallsklövern": "högvallsklöver",
    "högvallsklöverna": "högvallsklöver",
    "högvallsklövernas": "högvallsklöver",
    "högvallsklöverns": "högvallsklöver",
    "högvallsklövers": "högvallsklöver",
    "högvarven": "högvarv",
    "högvarvens": "högvarv",
    "högvarvet": "högvarv",
    "högvarvets": "högvarv",
    "högvarvs": "högvarv",
    "högvattens": "högvatten",
    "högvattnen": "högvatten",
    "högvattnens": "högvatten",
    "högvattnet": "högvatten",
    "högvattnets": "högvatten",
    "högviltet": "högvilt",
    "högviltets": "högvilt",
    "högvilts": "högvilt",
    "högvuxenheten": "högvuxenhet",
    "högvuxenhetens": "högvuxenhet",
    "högvuxenhets": "högvuxenhet",
    "högvuxens": "högvuxen",
    "högvuxet": "högvuxen",
    "högvuxets": "högvuxen",
    "högvuxna": "högvuxen",
    "högvuxnare": "högvuxen",
    "högvuxnares": "högvuxen",
    "högvuxnas": "högvuxen",
    "högvuxnast": "högvuxen",
    "högvuxnaste": "högvuxen",
    "högvuxnastes": "högvuxen",
    "högvuxnasts": "högvuxen",
    "högvuxne": "högvuxen",
    "högvuxnes": "högvuxen",
    "högvälborenheten": "högvälborenhet",
    "högvälborenhetens": "högvälborenhet",
    "högvälborenhets": "högvälborenhet",
    "högvälborens": "högvälboren",
    "högvälboret": "högvälboren",
    "högvälborets": "högvälboren",
    "högvälborna": "högvälboren",
    "högvälbornare": "högvälboren",
    "högvälbornares": "högvälboren",
    "högvälbornas": "högvälboren",
    "högvälbornast": "högvälboren",
    "högvälbornaste": "högvälboren",
    "högvälbornastes": "högvälboren",
    "högvälbornasts": "högvälboren",
    "högvälborne": "högvälboren",
    "högvälbornes": "högvälboren",
    "högvärdiga": "högvärdig",
    "högvärdigare": "högvärdig",
    "högvärdigares": "högvärdig",
    "högvärdigas": "högvärdig",
    "högvärdigast": "högvärdig",
    "högvärdigaste": "högvärdig",
    "högvärdigastes": "högvärdig",
    "högvärdigasts": "högvärdig",
    "högvärdige": "högvärdig",
    "högvärdiges": "högvärdig",
    "högvärdigheten": "högvärdighet",
    "högvärdighetens": "högvärdighet",
    "högvärdighets": "högvärdighet",
    "högvärdigs": "högvärdig",
    "högvärdigt": "högvärdig",
    "högvärdigts": "högvärdig",
    "högväxta": "högväxt",
    "högväxtare": "högväxt",
    "högväxtares": "högväxt",
    "högväxtas": "högväxt",
    "högväxtast": "högväxt",
    "högväxtaste": "högväxt",
    "högväxtastes": "högväxt",
    "högväxtasts": "högväxt",
    "högväxte": "högväxt",
    "högväxtes": "högväxt",
    "högväxtheten": "högväxthet",
    "högväxthetens": "högväxthet",
    "högväxthets": "högväxthet",
    "högväxts": "högväxt",
    "högvördiga": "högvördig",
    "högvördigare": "högvördig",
    "högvördigares": "högvördig",
    "högvördigas": "högvördig",
    "högvördigast": "högvördig",
    "högvördigaste": "högvördig",
    "högvördigastes": "högvördig",
    "högvördigasts": "högvördig",
    "högvördige": "högvördig",
    "högvördiges": "högvördig",
    "högvördigheten": "högvördighet",
    "högvördighetens": "högvördighet",
    "högvördigheter": "högvördighet",
    "högvördigheterna": "högvördighet",
    "högvördigheternas": "högvördighet",
    "högvördigheters": "högvördighet",
    "högvördighets": "högvördighet",
    "högvördigs": "högvördig",
    "högvördigt": "högvördig",
    "högvördigts": "högvördig",
    "högättade": "högättad",
    "högättades": "högättad",
    "högättads": "högättad",
    "högättat": "högättad",
    "högättats": "högättad",
    "högönskliga": "högönsklig",
    "högönskligare": "högönsklig",
    "högönskligares": "högönsklig",
    "högönskligas": "högönsklig",
    "högönskligast": "högönsklig",
    "högönskligaste": "högönsklig",
    "högönskligastes": "högönsklig",
    "högönskligasts": "högönsklig",
    "högönsklige": "högönsklig",
    "högönskliges": "högönsklig",
    "högönskligheten": "högönsklighet",
    "högönsklighetens": "högönsklighet",
    "högönsklighets": "högönsklighet",
    "högönskligs": "högönsklig",
    "högönskligt": "högönsklig",
    "högönskligts": "högönsklig",
    "höj": "höja",
    "höjande": "höja",
    "höjanden": "höjande",
    "höjandena": "höjande",
    "höjandenas": "höjande",
    "höjandens": "höjande",
    "höjandes": "höjande",
    "höjandet": "höjande",
    "höjandets": "höjande",
    "höjas": "höja",
    "höjd": "höja",
    "höjda": "höja",
    "höjdar": "höjdare",
    "höjdaren": "höjdare",
    "höjdarens": "höjdare",
    "höjdares": "höjdare",
    "höjdarna": "höjdare",
    "höjdarnas": "höjdare",
    "höjdas": "höja",
    "höjdbestämningar": "höjdbestämning",
    "höjdbestämningarna": "höjdbestämning",
    "höjdbestämningarnas": "höjdbestämning",
    "höjdbestämningars": "höjdbestämning",
    "höjdbestämningen": "höjdbestämning",
    "höjdbestämningens": "höjdbestämning",
    "höjdbestämnings": "höjdbestämning",
    "höjde": "höja",
    "höjden": "höjd",
    "höjdens": "höjd",
    "höjder": "höjd",
    "höjderna": "höjd",
    "höjdernas": "höjd",
    "höjders": "höjd",
    "höjdes": "höja",
    "höjdhoppar": "höjdhoppare",
    "höjdhopparen": "höjdhoppare",
    "höjdhopparens": "höjdhoppare",
    "höjdhoppares": "höjdhoppare",
    "höjdhopparna": "höjdhoppare",
    "höjdhopparnas": "höjdhoppare",
    "höjdhoppen": "höjdhopp",
    "höjdhoppens": "höjdhopp",
    "höjdhoppet": "höjdhopp",
    "höjdhoppets": "höjdhopp",
    "höjdhopps": "höjdhopp",
    "höjdhoppstävlingar": "höjdhoppstävling",
    "höjdhoppstävlingarna": "höjdhoppstävling",
    "höjdhoppstävlingarnas": "höjdhoppstävling",
    "höjdhoppstävlingars": "höjdhoppstävling",
    "höjdhoppstävlingen": "höjdhoppstävling",
    "höjdhoppstävlingens": "höjdhoppstävling",
    "höjdhoppstävlings": "höjdhoppstävling",
    "höjdinställningar": "höjdinställning",
    "höjdinställningarna": "höjdinställning",
    "höjdinställningarnas": "höjdinställning",
    "höjdinställningars": "höjdinställning",
    "höjdinställningen": "höjdinställning",
    "höjdinställningens": "höjdinställning",
    "höjdinställnings": "höjdinställning",
    "höjdkart": "höjdkarta",
    "höjdkartan": "höjdkarta",
    "höjdkartans": "höjdkarta",
    "höjdkartas": "höjdkarta",
    "höjdkarte": "höjdkarta",
    "höjdkartor": "höjdkarta",
    "höjdkartorna": "höjdkarta",
    "höjdkartornas": "höjdkarta",
    "höjdkartors": "höjdkarta",
    "höjdkarts": "höjdkarta",
    "höjdkurv": "höjdkurva",
    "höjdkurvan": "höjdkurva",
    "höjdkurvans": "höjdkurva",
    "höjdkurvas": "höjdkurva",
    "höjdkurve": "höjdkurva",
    "höjdkurvor": "höjdkurva",
    "höjdkurvorna": "höjdkurva",
    "höjdkurvornas": "höjdkurva",
    "höjdkurvors": "höjdkurva",
    "höjdkurvs": "höjdkurva",
    "höjdleden": "höjdled",
    "höjdledens": "höjdled",
    "höjdleds": "höjdled",
    "höjdlägen": "höjdläge",
    "höjdlägena": "höjdläge",
    "höjdlägenas": "höjdläge",
    "höjdlägens": "höjdläge",
    "höjdläges": "höjdläge",
    "höjdläget": "höjdläge",
    "höjdlägets": "höjdläge",
    "höjdmässiga": "höjdmässig",
    "höjdmässigare": "höjdmässig",
    "höjdmässigares": "höjdmässig",
    "höjdmässigas": "höjdmässig",
    "höjdmässigast": "höjdmässig",
    "höjdmässigaste": "höjdmässig",
    "höjdmässigastes": "höjdmässig",
    "höjdmässigasts": "höjdmässig",
    "höjdmässige": "höjdmässig",
    "höjdmässiges": "höjdmässig",
    "höjdmässigs": "höjdmässig",
    "höjdmässigt": "höjdmässig",
    "höjdmässigts": "höjdmässig",
    "höjdmätar": "höjdmätare",
    "höjdmätaren": "höjdmätare",
    "höjdmätarens": "höjdmätare",
    "höjdmätares": "höjdmätare",
    "höjdmätarna": "höjdmätare",
    "höjdmätarnas": "höjdmätare",
    "höjdmätningar": "höjdmätning",
    "höjdmätningarna": "höjdmätning",
    "höjdmätningarnas": "höjdmätning",
    "höjdmätningars": "höjdmätning",
    "höjdmätningen": "höjdmätning",
    "höjdmätningens": "höjdmätning",
    "höjdmätnings": "höjdmätning",
    "höjdpunkten": "höjdpunkt",
    "höjdpunktens": "höjdpunkt",
    "höjdpunkter": "höjdpunkt",
    "höjdpunkterna": "höjdpunkt",
    "höjdpunkternas": "höjdpunkt",
    "höjdpunkters": "höjdpunkt",
    "höjdpunkts": "höjdpunkt",
    "höjdryggar": "höjdrygg",
    "höjdryggarna": "höjdrygg",
    "höjdryggarnas": "höjdrygg",
    "höjdryggars": "höjdrygg",
    "höjdryggen": "höjdrygg",
    "höjdryggens": "höjdrygg",
    "höjdryggs": "höjdrygg",
    "höjds": "höjd",
    "höjdskillnaden": "höjdskillnad",
    "höjdskillnadens": "höjdskillnad",
    "höjdskillnader": "höjdskillnad",
    "höjdskillnaderna": "höjdskillnad",
    "höjdskillnadernas": "höjdskillnad",
    "höjdskillnaders": "höjdskillnad",
    "höjdskillnads": "höjdskillnad",
    "höjdsträckningar": "höjdsträckning",
    "höjdsträckningarna": "höjdsträckning",
    "höjdsträckningarnas": "höjdsträckning",
    "höjdsträckningars": "höjdsträckning",
    "höjdsträckningen": "höjdsträckning",
    "höjdsträckningens": "höjdsträckning",
    "höjdsträcknings": "höjdsträckning",
    "höjer": "höja",
    "höjes": "höja",
    "höjningar": "höjning",
    "höjningarna": "höjning",
    "höjningarnas": "höjning",
    "höjningars": "höjning",
    "höjningen": "höjning",
    "höjningens": "höjning",
    "höjnings": "höjning",
    "höjs": "höja",
    "höjt": "höja",
    "höjts": "höja",
    "hökar": "hökare",
    "hökaren": "hökare",
    "hökarens": "hökare",
    "hökares": "hökare",
    "hökarna": "hökare",
    "hökarnas": "hökare",
    "hökars": "hök",
    "höken": "hök",
    "hökens": "hök",
    "hökerier": "hökeri",
    "hökerierna": "hökeri",
    "hökeriernas": "hökeri",
    "hökeriers": "hökeri",
    "hökeriet": "hökeri",
    "hökeriets": "hökeri",
    "hökeris": "hökeri",
    "hökerit": "hökeri",
    "hökerits": "hökeri",
    "höknatn": "höknatt",
    "höknatns": "höknatt",
    "höknatten": "höknatt",
    "höknattens": "höknatt",
    "höknatts": "höknatt",
    "höknätter": "höknatt",
    "höknätterna": "höknatt",
    "höknätternas": "höknatt",
    "höknätters": "höknatt",
    "hökpolitiken": "hökpolitik",
    "hökpolitikens": "hökpolitik",
    "hökpolitiks": "hökpolitik",
    "höks": "hök",
    "hökugglan": "hökuggla",
    "hökugglans": "hökuggla",
    "hökugglas": "hökuggla",
    "hökuggle": "hökuggla",
    "hökugglor": "hökuggla",
    "hökugglorna": "hökuggla",
    "hökugglornas": "hökuggla",
    "hökugglors": "hökuggla",
    "hölj": "hölja",
    "höljan": "hölja",
    "höljande": "hölja",
    "höljanden": "höljande",
    "höljandena": "höljande",
    "höljandenas": "höljande",
    "höljandens": "höljande",
    "höljandes": "höljande",
    "höljandet": "höljande",
    "höljandets": "höljande",
    "höljans": "hölja",
    "höljas": "hölja",
    "höljd": "hölja",
    "höljda": "hölja",
    "höljdas": "hölja",
    "höljde": "hölja",
    "höljdes": "hölja",
    "höljds": "hölja",
    "hölje": "hölja",
    "höljen": "hölje",
    "höljena": "hölje",
    "höljenas": "hölje",
    "höljens": "hölje",
    "höljer": "hölja",
    "höljes": "hölje",
    "höljet": "hölje",
    "höljets": "hölje",
    "höljor": "hölja",
    "höljorna": "hölja",
    "höljornas": "hölja",
    "höljors": "hölja",
    "höljs": "hölje",
    "höljt": "hölja",
    "höljts": "hölja",
    "höll": "hålla",
    "hölle": "hålla",
    "hölles": "hålla",
    "hölls": "hållas",
    "hölsterna": "hölster",
    "hölsternas": "hölster",
    "hölsters": "hölster",
    "hölstren": "hölster",
    "hölstrens": "hölster",
    "hölstret": "hölster",
    "hölstrets": "hölster",
    "hön": "höna",
    "hönan": "höna",
    "hönans": "höna",
    "hönas": "höna",
    "höne": "höna",
    "hönor": "höna",
    "hönorna": "höna",
    "hönornas": "höna",
    "hönors": "höna",
    "höns": "höna",
    "hönsarv": "hönsarve",
    "hönsarvar": "hönsarve",
    "hönsarvarna": "hönsarve",
    "hönsarvarnas": "hönsarve",
    "hönsarvars": "hönsarve",
    "hönsarven": "hönsarve",
    "hönsarvens": "hönsarve",
    "hönsarves": "hönsarve",
    "hönsarvs": "hönsarve",
    "hönsburar": "hönsbur",
    "hönsburarna": "hönsbur",
    "hönsburarnas": "hönsbur",
    "hönsburars": "hönsbur",
    "hönsburen": "hönsbur",
    "hönsburens": "hönsbur",
    "hönsburs": "hönsbur",
    "hönsbären": "hönsbär",
    "hönsbärens": "hönsbär",
    "hönsbäret": "hönsbär",
    "hönsbärets": "hönsbär",
    "hönsbärs": "hönsbär",
    "hönsen": "höns",
    "hönsens": "höns",
    "hönserier": "hönseri",
    "hönserierna": "hönseri",
    "hönseriernas": "hönseri",
    "hönseriers": "hönseri",
    "hönseriet": "hönseri",
    "hönseriets": "hönseri",
    "hönseris": "hönseri",
    "hönserit": "hönseri",
    "hönserits": "hönseri",
    "hönset": "höns",
    "hönsets": "höns",
    "hönsfågeln": "hönsfågel",
    "hönsfågelns": "hönsfågel",
    "hönsfågels": "hönsfågel",
    "hönsfåglar": "hönsfågel",
    "hönsfåglarna": "hönsfågel",
    "hönsfåglarnas": "hönsfågel",
    "hönsfåglars": "hönsfågel",
    "hönsgrytan": "hönsgryta",
    "hönsgrytans": "hönsgryta",
    "hönsgrytas": "hönsgryta",
    "hönsgryte": "hönsgryta",
    "hönsgrytor": "hönsgryta",
    "hönsgrytorna": "hönsgryta",
    "hönsgrytornas": "hönsgryta",
    "hönsgrytors": "hönsgryta",
    "hönsgårdar": "hönsgård",
    "hönsgårdarna": "hönsgård",
    "hönsgårdarnas": "hönsgård",
    "hönsgårdars": "hönsgård",
    "hönsgården": "hönsgård",
    "hönsgårdens": "hönsgård",
    "hönsgårds": "hönsgård",
    "hönshjärn": "hönshjärna",
    "hönshjärnan": "hönshjärna",
    "hönshjärnans": "hönshjärna",
    "hönshjärnas": "hönshjärna",
    "hönshjärne": "hönshjärna",
    "hönshjärnor": "hönshjärna",
    "hönshjärnorna": "hönshjärna",
    "hönshjärnornas": "hönshjärna",
    "hönshjärnors": "hönshjärna",
    "hönshjärns": "hönshjärna",
    "hönsiga": "hönsig",
    "hönsigare": "hönsig",
    "hönsigares": "hönsig",
    "hönsigas": "hönsig",
    "hönsigast": "hönsig",
    "hönsigaste": "hönsig",
    "hönsigastes": "hönsig",
    "hönsigasts": "hönsig",
    "hönsige": "hönsig",
    "hönsiges": "hönsig",
    "hönsigheten": "hönsighet",
    "hönsighetens": "hönsighet",
    "hönsighets": "hönsighet",
    "hönsigs": "hönsig",
    "hönsigt": "hönsig",
    "hönsigts": "hönsig",
    "hönsminnes": "hönsminne",
    "hönsminnet": "hönsminne",
    "hönsminnets": "hönsminne",
    "hönsnäten": "hönsnät",
    "hönsnätens": "hönsnät",
    "hönsnätet": "hönsnät",
    "hönsnätets": "hönsnät",
    "hönsnäts": "hönsnät",
    "hönsäggen": "hönsägg",
    "hönsäggens": "hönsägg",
    "hönsägget": "hönsägg",
    "hönsäggets": "hönsägg",
    "hönsäggs": "hönsägg",
    "hör": "höra",
    "hörande": "höra",
    "höranden": "hörande",
    "hörandena": "hörande",
    "hörandenas": "hörande",
    "hörandens": "hörande",
    "hörandes": "hörande",
    "hörandet": "hörande",
    "hörandets": "hörande",
    "hörapparaten": "hörapparat",
    "hörapparatens": "hörapparat",
    "hörapparater": "hörapparat",
    "hörapparaterna": "hörapparat",
    "hörapparaternas": "hörapparat",
    "hörapparaters": "hörapparat",
    "hörapparats": "hörapparat",
    "höras": "höra",
    "hörbara": "hörbar",
    "hörbarare": "hörbar",
    "hörbarares": "hörbar",
    "hörbaras": "hörbar",
    "hörbarast": "hörbar",
    "hörbaraste": "hörbar",
    "hörbarastes": "hörbar",
    "hörbarasts": "hörbar",
    "hörbare": "hörbar",
    "hörbares": "hörbar",
    "hörbarheten": "hörbarhet",
    "hörbarhetens": "hörbarhet",
    "hörbarheter": "hörbarhet",
    "hörbarheterna": "hörbarhet",
    "hörbarheternas": "hörbarhet",
    "hörbarheters": "hörbarhet",
    "hörbarhets": "hörbarhet",
    "hörbarhetströskeln": "hörbarhetströskel",
    "hörbarhetströskelns": "hörbarhetströskel",
    "hörbarhetströskels": "hörbarhetströskel",
    "hörbars": "hörbar",
    "hörbart": "hörbar",
    "hörbarts": "hörbar",
    "hörd": "höra",
    "hörda": "höra",
    "hördas": "höra",
    "hörde": "höra",
    "hördes": "höra",
    "hörds": "höra",
    "höres": "höra",
    "hörglasögonen": "hörglasögon",
    "hörglasögonens": "hörglasögon",
    "hörglasögons": "hörglasögon",
    "hörhålls": "hörhåll",
    "hörlurar": "hörlur",
    "hörlurarna": "hörlur",
    "hörlurarnas": "hörlur",
    "hörlurars": "hörlur",
    "hörluren": "hörlur",
    "hörlurens": "hörlur",
    "hörlurs": "hörlur",
    "hörn": "hörna",
    "hörnan": "hörna",
    "hörnans": "hörna",
    "hörnas": "hörna",
    "hörne": "hörna",
    "hörnen": "hörn",
    "hörnens": "hörn",
    "hörnet": "hörn",
    "hörnets": "hörn",
    "hörnflagg": "hörnflagga",
    "hörnflaggan": "hörnflagga",
    "hörnflaggans": "hörnflagga",
    "hörnflaggas": "hörnflagga",
    "hörnflagge": "hörnflagga",
    "hörnflaggor": "hörnflagga",
    "hörnflaggorna": "hörnflagga",
    "hörnflaggornas": "hörnflagga",
    "hörnflaggors": "hörnflagga",
    "hörnflaggs": "hörnflagga",
    "hörnhusen": "hörnhus",
    "hörnhusens": "hörnhus",
    "hörnhuset": "hörnhus",
    "hörnhusets": "hörnhus",
    "hörniga": "hörnig",
    "hörnigare": "hörnig",
    "hörnigares": "hörnig",
    "hörnigas": "hörnig",
    "hörnigast": "hörnig",
    "hörnigaste": "hörnig",
    "hörnigastes": "hörnig",
    "hörnigasts": "hörnig",
    "hörnige": "hörnig",
    "hörniges": "hörnig",
    "hörnigs": "hörnig",
    "hörnigt": "hörnig",
    "hörnigts": "hörnig",
    "hörningar": "hörning",
    "hörningarna": "hörning",
    "hörningarnas": "hörning",
    "hörningars": "hörning",
    "hörningen": "hörning",
    "hörningens": "hörning",
    "hörnings": "hörning",
    "hörnor": "hörna",
    "hörnorna": "hörna",
    "hörnornas": "hörna",
    "hörnors": "hörna",
    "hörnpelar": "hörnpelare",
    "hörnpelaren": "hörnpelare",
    "hörnpelarens": "hörnpelare",
    "hörnpelares": "hörnpelare",
    "hörnpelarna": "hörnpelare",
    "hörnpelarnas": "hörnpelare",
    "hörns": "hörna",
    "hörnskåpen": "hörnskåp",
    "hörnskåpens": "hörnskåp",
    "hörnskåpet": "hörnskåp",
    "hörnskåpets": "hörnskåp",
    "hörnskåps": "hörnskåp",
    "hörnstenar": "hörnsten",
    "hörnstenarna": "hörnsten",
    "hörnstenarnas": "hörnsten",
    "hörnstenars": "hörnsten",
    "hörnstenen": "hörnsten",
    "hörnstenens": "hörnsten",
    "hörnstens": "hörnsten",
    "hörntanden": "hörntand",
    "hörntandens": "hörntand",
    "hörntands": "hörntand",
    "hörntornen": "hörntorn",
    "hörntornens": "hörntorn",
    "hörntornet": "hörntorn",
    "hörntornets": "hörntorn",
    "hörntorns": "hörntorn",
    "hörntänder": "hörntand",
    "hörntänderna": "hörntand",
    "hörntändernas": "hörntand",
    "hörntänders": "hörntand",
    "hörs": "höra",
    "hörsagan": "hörsaga",
    "hörsagans": "hörsaga",
    "hörsagas": "hörsaga",
    "hörsage": "hörsaga",
    "hörsago": "hörsaga",
    "hörsagor": "hörsaga",
    "hörsagorna": "hörsaga",
    "hörsagornas": "hörsaga",
    "hörsagors": "hörsaga",
    "hörsalar": "hörsal",
    "hörsalarna": "hörsal",
    "hörsalarnas": "hörsal",
    "hörsalars": "hörsal",
    "hörsalen": "hörsal",
    "hörsalens": "hörsal",
    "hörsals": "hörsal",
    "hörsamheten": "hörsamhet",
    "hörsamhetens": "hörsamhet",
    "hörsamhets": "hörsamhet",
    "hörsamma": "hörsam",
    "hörsammad": "hörsamma",
    "hörsammade": "hörsamma",
    "hörsammades": "hörsamma",
    "hörsammads": "hörsamma",
    "hörsammande": "hörsamma",
    "hörsammanden": "hörsammande",
    "hörsammandena": "hörsammande",
    "hörsammandenas": "hörsammande",
    "hörsammandens": "hörsammande",
    "hörsammandes": "hörsammande",
    "hörsammandet": "hörsammande",
    "hörsammandets": "hörsammande",
    "hörsammar": "hörsamma",
    "hörsammare": "hörsam",
    "hörsammares": "hörsam",
    "hörsammas": "hörsamma",
    "hörsammast": "hörsam",
    "hörsammaste": "hörsam",
    "hörsammastes": "hörsam",
    "hörsammasts": "hörsam",
    "hörsammat": "hörsamma",
    "hörsammats": "hörsamma",
    "hörsamme": "hörsam",
    "hörsammes": "hörsam",
    "hörsams": "hörsam",
    "hörsamt": "hörsam",
    "hörsamts": "hörsam",
    "hörselbenen": "hörselben",
    "hörselbenens": "hörselben",
    "hörselbenet": "hörselben",
    "hörselbenets": "hörselben",
    "hörselbens": "hörselben",
    "hörselklassen": "hörselklass",
    "hörselklassens": "hörselklass",
    "hörselklasser": "hörselklass",
    "hörselklasserna": "hörselklass",
    "hörselklassernas": "hörselklass",
    "hörselklassers": "hörselklass",
    "hörseln": "hörsel",
    "hörselns": "hörsel",
    "hörselorganen": "hörselorgan",
    "hörselorganens": "hörselorgan",
    "hörselorganet": "hörselorgan",
    "hörselorganets": "hörselorgan",
    "hörselorgans": "hörselorgan",
    "hörsels": "hörsel",
    "hörselsinnes": "hörselsinne",
    "hörselsinnet": "hörselsinne",
    "hörselsinnets": "hörselsinne",
    "hörselskadade": "hörselskadad",
    "hörselskadades": "hörselskadad",
    "hörselskadads": "hörselskadad",
    "hörselskadan": "hörselskada",
    "hörselskadans": "hörselskada",
    "hörselskadas": "hörselskada",
    "hörselskadat": "hörselskadad",
    "hörselskadats": "hörselskadad",
    "hörselskade": "hörselskada",
    "hörselskador": "hörselskada",
    "hörselskadorna": "hörselskada",
    "hörselskadornas": "hörselskada",
    "hörselskadors": "hörselskada",
    "hörselskydden": "hörselskydd",
    "hörselskyddens": "hörselskydd",
    "hörselskyddet": "hörselskydd",
    "hörselskyddets": "hörselskydd",
    "hörselskydds": "hörselskydd",
    "hörspelen": "hörspel",
    "hörspelens": "hörspel",
    "hörspelet": "hörspel",
    "hörspelets": "hörspel",
    "hörspels": "hörspel",
    "hörsägenn": "hörsägen",
    "hörsägenns": "hörsägen",
    "hörsägens": "hörsägen",
    "hörsägner": "hörsägen",
    "hörsägnerna": "hörsägen",
    "hörsägnernas": "hörsägen",
    "hörsägners": "hörsägen",
    "hört": "höra",
    "hörtelefonen": "hörtelefon",
    "hörtelefonens": "hörtelefon",
    "hörtelefoner": "hörtelefon",
    "hörtelefonerna": "hörtelefon",
    "hörtelefonernas": "hörtelefon",
    "hörtelefoners": "hörtelefon",
    "hörtelefons": "hörtelefon",
    "hörts": "höra",
    "hös": "hö",
    "höskull": "höskulle",
    "höskullar": "höskulle",
    "höskullarna": "höskulle",
    "höskullarnas": "höskulle",
    "höskullars": "höskulle",
    "höskullen": "höskulle",
    "höskullens": "höskulle",
    "höskulles": "höskulle",
    "höskulls": "höskulle",
    "hösnuvan": "hösnuva",
    "hösnuvans": "hösnuva",
    "hösnuvas": "hösnuva",
    "höst": "hösta",
    "höstackar": "höstack",
    "höstackarna": "höstack",
    "höstackarnas": "höstack",
    "höstackars": "höstack",
    "höstacken": "höstack",
    "höstackens": "höstack",
    "höstacks": "höstack",
    "höstade": "hösta",
    "höstades": "höstas",
    "höstande": "hösta",
    "höstanden": "höstande",
    "höstandena": "höstande",
    "höstandenas": "höstande",
    "höstandens": "höstande",
    "höstandes": "höstande",
    "höstandet": "höstande",
    "höstandets": "höstande",
    "höstar": "hösta",
    "höstarna": "höst",
    "höstarnas": "höst",
    "höstars": "höst",
    "höstas": "hösta",
    "höstat": "hösta",
    "höstats": "höstas",
    "höstbruket": "höstbruk",
    "höstbrukets": "höstbruk",
    "höstbruks": "höstbruk",
    "höstdagjämningar": "höstdagjämning",
    "höstdagjämningarna": "höstdagjämning",
    "höstdagjämningarnas": "höstdagjämning",
    "höstdagjämningars": "höstdagjämning",
    "höstdagjämningen": "höstdagjämning",
    "höstdagjämningens": "höstdagjämning",
    "höstdagjämnings": "höstdagjämning",
    "hösten": "höst",
    "höstens": "höst",
    "höstfrosten": "höstfrost",
    "höstfrostens": "höstfrost",
    "höstfrosts": "höstfrost",
    "höstgrytan": "höstgryta",
    "höstgrytans": "höstgryta",
    "höstgrytas": "höstgryta",
    "höstgryte": "höstgryta",
    "höstgrytor": "höstgryta",
    "höstgrytorna": "höstgryta",
    "höstgrytornas": "höstgryta",
    "höstgrytors": "höstgryta",
    "höstkantarellen": "höstkantarell",
    "höstkantarellens": "höstkantarell",
    "höstkantareller": "höstkantarell",
    "höstkantarellerna": "höstkantarell",
    "höstkantarellernas": "höstkantarell",
    "höstkantarellers": "höstkantarell",
    "höstkantarells": "höstkantarell",
    "höstkylan": "höstkyla",
    "höstkylans": "höstkyla",
    "höstkylas": "höstkyla",
    "höstkyle": "höstkyla",
    "höstliga": "höstlig",
    "höstligare": "höstlig",
    "höstligares": "höstlig",
    "höstligas": "höstlig",
    "höstligast": "höstlig",
    "höstligaste": "höstlig",
    "höstligastes": "höstlig",
    "höstligasts": "höstlig",
    "höstlige": "höstlig",
    "höstliges": "höstlig",
    "höstligs": "höstlig",
    "höstligt": "höstlig",
    "höstligts": "höstlig",
    "höstloven": "höstlov",
    "höstlovens": "höstlov",
    "höstlovet": "höstlov",
    "höstlovets": "höstlov",
    "höstlovs": "höstlov",
    "höstlöven": "höstlöv",
    "höstlövens": "höstlöv",
    "höstlövet": "höstlöv",
    "höstlövets": "höstlöv",
    "höstlövs": "höstlöv",
    "höstmånaden": "höstmånad",
    "höstmånadens": "höstmånad",
    "höstmånader": "höstmånad",
    "höstmånaderna": "höstmånad",
    "höstmånadernas": "höstmånad",
    "höstmånaders": "höstmånad",
    "höstmånads": "höstmånad",
    "höstmörkers": "höstmörker",
    "höstmörkret": "höstmörker",
    "höstmörkrets": "höstmörker",
    "höstorienteringar": "höstorientering",
    "höstorienteringarna": "höstorientering",
    "höstorienteringarnas": "höstorientering",
    "höstorienteringars": "höstorientering",
    "höstorienteringen": "höstorientering",
    "höstorienteringens": "höstorientering",
    "höstorienterings": "höstorientering",
    "höstrusket": "höstrusk",
    "höstruskets": "höstrusk",
    "höstrusks": "höstrusk",
    "hösts": "höst",
    "höstslakten": "höstslakt",
    "höstslaktens": "höstslakt",
    "höstslakter": "höstslakt",
    "höstslakterna": "höstslakt",
    "höstslakternas": "höstslakt",
    "höstslakters": "höstslakt",
    "höstslakts": "höstslakt",
    "höststormar": "höststorm",
    "höststormarna": "höststorm",
    "höststormarnas": "höststorm",
    "höststormars": "höststorm",
    "höststormen": "höststorm",
    "höststormens": "höststorm",
    "höststormiga": "höststormig",
    "höststormigare": "höststormig",
    "höststormigares": "höststormig",
    "höststormigas": "höststormig",
    "höststormigast": "höststormig",
    "höststormigaste": "höststormig",
    "höststormigastes": "höststormig",
    "höststormigasts": "höststormig",
    "höststormige": "höststormig",
    "höststormiges": "höststormig",
    "höststormigs": "höststormig",
    "höststormigt": "höststormig",
    "höststormigts": "höststormig",
    "höststorms": "höststorm",
    "höstsäden": "höstsäd",
    "höstsädens": "höstsäd",
    "höstsädes": "höstsäd",
    "höstsäds": "höstsäd",
    "höstsäsongen": "höstsäsong",
    "höstsäsongens": "höstsäsong",
    "höstsäsonger": "höstsäsong",
    "höstsäsongerna": "höstsäsong",
    "höstsäsongernas": "höstsäsong",
    "höstsäsongers": "höstsäsong",
    "höstsäsongs": "höstsäsong",
    "höstsådden": "höstsådd",
    "höstsåddens": "höstsådd",
    "höstsådds": "höstsådd",
    "höstterminen": "hösttermin",
    "höstterminens": "hösttermin",
    "höstterminer": "hösttermin",
    "höstterminerna": "hösttermin",
    "höstterminernas": "hösttermin",
    "höstterminers": "hösttermin",
    "hösttermins": "hösttermin",
    "höstväderna": "höstväder",
    "höstvädernas": "höstväder",
    "höstväders": "höstväder",
    "höstvädren": "höstväder",
    "höstvädrens": "höstväder",
    "höstvädret": "höstväder",
    "höstvädrets": "höstväder",
    "hösäckar": "hösäck",
    "hösäckarna": "hösäck",
    "hösäckarnas": "hösäck",
    "hösäckars": "hösäck",
    "hösäcken": "hösäck",
    "hösäckens": "hösäck",
    "hösäcks": "hösäck",
    "hösåt": "hösåte",
    "hösåtar": "hösåte",
    "hösåtarna": "hösåte",
    "hösåtarnas": "hösåte",
    "hösåtars": "hösåte",
    "hösåten": "hösåte",
    "hösåtens": "hösåte",
    "hösåtes": "hösåte",
    "hösåts": "hösåte",
    "höt": "höta",
    "hötande": "höta",
    "hötanden": "hötande",
    "hötandena": "hötande",
    "hötandenas": "hötande",
    "hötandens": "hötande",
    "hötandes": "hötande",
    "hötandet": "hötande",
    "hötandets": "hötande",
    "hötappar": "hötapp",
    "hötapparna": "hötapp",
    "hötapparnas": "hötapp",
    "hötappars": "hötapp",
    "hötappen": "hötapp",
    "hötappens": "hötapp",
    "hötapps": "hötapp",
    "hötas": "höta",
    "höter": "höta",
    "hötes": "höta",
    "hötjug": "hötjuga",
    "hötjugan": "hötjuga",
    "hötjugans": "hötjuga",
    "hötjugas": "hötjuga",
    "hötjuge": "hötjuga",
    "hötjugor": "hötjuga",
    "hötjugorna": "hötjuga",
    "hötjugornas": "hötjuga",
    "hötjugors": "hötjuga",
    "hötjugs": "hötjuga",
    "hötorgskonsten": "hötorgskonst",
    "hötorgskonstens": "hötorgskonst",
    "hötorgskonsts": "hötorgskonst",
    "hötorkar": "hötork",
    "hötorkarna": "hötork",
    "hötorkarnas": "hötork",
    "hötorkars": "hötork",
    "hötorken": "hötork",
    "hötorkens": "hötork",
    "hötorks": "hötork",
    "höts": "höta",
    "hött": "hötta",
    "höttad": "hötta",
    "höttade": "hötta",
    "höttades": "hötta",
    "höttads": "hötta",
    "höttande": "hötta",
    "höttanden": "höttande",
    "höttandena": "höttande",
    "höttandenas": "höttande",
    "höttandens": "höttande",
    "höttandes": "höttande",
    "höttandet": "höttande",
    "höttandets": "höttande",
    "höttas": "hötta",
    "höttat": "hötta",
    "höttats": "hötta",
    "hötte": "hötta",
    "hötter": "hötta",
    "höttes": "hötta",
    "hötts": "hötta",
    "hövdes": "hövas",
    "hövdingar": "hövding",
    "hövdingarna": "hövding",
    "hövdingarnas": "hövding",
    "hövdingars": "hövding",
    "hövdingasamhällen": "hövdingasamhälle",
    "hövdingasamhällena": "hövdingasamhälle",
    "hövdingasamhällenas": "hövdingasamhälle",
    "hövdingasamhällens": "hövdingasamhälle",
    "hövdingasamhälles": "hövdingasamhälle",
    "hövdingasamhället": "hövdingasamhälle",
    "hövdingasamhällets": "hövdingasamhälle",
    "hövdingasamhälls": "hövdingasamhälle",
    "hövdingen": "hövding",
    "hövdingens": "hövding",
    "hövdings": "hövding",
    "höves": "hövas",
    "höviska": "hövisk",
    "höviskare": "hövisk",
    "höviskares": "hövisk",
    "höviskas": "hövisk",
    "höviskast": "hövisk",
    "höviskaste": "hövisk",
    "höviskastes": "hövisk",
    "höviskasts": "hövisk",
    "höviske": "hövisk",
    "höviskes": "hövisk",
    "hövisks": "hövisk",
    "höviskt": "hövisk",
    "höviskts": "hövisk",
    "hövitsmannen": "hövitsman",
    "hövitsmannens": "hövitsman",
    "hövitsmans": "hövitsman",
    "hövitsmän": "hövitsman",
    "hövitsmännen": "hövitsman",
    "hövitsmännens": "hövitsman",
    "hövitsmäns": "hövitsman",
    "hövliga": "hövlig",
    "hövligare": "hövlig",
    "hövligares": "hövlig",
    "hövligas": "hövlig",
    "hövligast": "hövlig",
    "hövligaste": "hövlig",
    "hövligastes": "hövlig",
    "hövligasts": "hövlig",
    "hövlige": "hövlig",
    "hövliges": "hövlig",
    "hövligheten": "hövlighet",
    "hövlighetens": "hövlighet",
    "hövligheter": "hövlighet",
    "hövligheterna": "hövlighet",
    "hövligheternas": "hövlighet",
    "hövligheters": "hövlighet",
    "hövlighets": "hövlighet",
    "hövlighetsvisiten": "hövlighetsvisit",
    "hövlighetsvisitens": "hövlighetsvisit",
    "hövlighetsvisiter": "hövlighetsvisit",
    "hövlighetsvisiterna": "hövlighetsvisit",
    "hövlighetsvisiternas": "hövlighetsvisit",
    "hövlighetsvisiters": "hövlighetsvisit",
    "hövlighetsvisits": "hövlighetsvisit",
    "hövligs": "hövlig",
    "hövligt": "hövlig",
    "hövligts": "hövlig",
    "hövolmar": "hövolm",
    "hövolmarna": "hövolm",
    "hövolmarnas": "hövolm",
    "hövolmars": "hövolm",
    "hövolmen": "hövolm",
    "hövolmens": "hövolm",
    "hövolms": "hövolm",
    "hövts": "hövas",
    "hövändar": "hövändare",
    "hövändaren": "hövändare",
    "hövändarens": "hövändare",
    "hövändares": "hövändare",
    "hövändarna": "hövändare",
    "hövändarnas": "hövändare",
    "hövålmar": "hövålm",
    "hövålmarna": "hövålm",
    "hövålmarnas": "hövålm",
    "hövålmars": "hövålm",
    "hövålmen": "hövålm",
    "hövålmens": "hövålm",
    "hövålms": "hövålm",
    "i-en": "i",
    "i-ens": "i",
    "i-et": "i",
    "i-ets": "i",
    "i-landets": "i-land",
    "i-ländernas": "i-land",
    "i-länders": "i-land",
    "i-n": "i",
    "i-na": "i",
    "i-nas": "i",
    "i-ns": "i",
    "i-t": "i",
    "i-ts": "i",
    "i:en": "i",
    "i:ens": "i",
    "i:et": "i",
    "i:ets": "i",
    "i:n": "i",
    "i:na": "i",
    "i:nas": "i",
    "i:ns": "i",
    "i:s": "i",
    "i:t": "i",
    "i:ts": "i",
    "iPhonar": "iPhone",
    "iPhonarna": "iPhone",
    "iPhonarnas": "iPhone",
    "iPhonars": "iPhone",
    "iPhonen": "iPhone",
    "iPhonena": "iPhone",
    "iPhonenas": "iPhone",
    "iPhonens": "iPhone",
    "iPhones": "iPhone",
    "iPhonesarna": "iPhone",
    "iPhonesarnas": "iPhone",
    "iakttag": "iaktta",
    "iakttaga": "iaktta",
    "iakttagande": "iaktta",
    "iakttaganden": "iakttagande",
    "iakttagandena": "iakttagande",
    "iakttagandenas": "iakttagande",
    "iakttagandens": "iakttagande",
    "iakttagandes": "iakttagande",
    "iakttagandet": "iakttagande",
    "iakttagandets": "iakttagande",
    "iakttagar": "iakttagare",
    "iakttagaren": "iakttagare",
    "iakttagarens": "iakttagare",
    "iakttagares": "iakttagare",
    "iakttagarna": "iakttagare",
    "iakttagarnas": "iakttagare",
    "iakttagas": "iaktta",
    "iakttage": "iaktta",
    "iakttagelseförmågan": "iakttagelseförmåga",
    "iakttagelseförmågans": "iakttagelseförmåga",
    "iakttagelseförmågas": "iakttagelseförmåga",
    "iakttagelseförmåge": "iakttagelseförmåga",
    "iakttagelseförmågor": "iakttagelseförmåga",
    "iakttagelseförmågorna": "iakttagelseförmåga",
    "iakttagelseförmågornas": "iakttagelseförmåga",
    "iakttagelseförmågors": "iakttagelseförmåga",
    "iakttagelsen": "iakttagelse",
    "iakttagelsens": "iakttagelse",
    "iakttagelser": "iakttagelse",
    "iakttagelserna": "iakttagelse",
    "iakttagelsernas": "iakttagelse",
    "iakttagelsers": "iakttagelse",
    "iakttagelses": "iakttagelse",
    "iakttagen": "iaktta",
    "iakttagens": "iaktta",
    "iakttager": "iaktta",
    "iakttages": "iaktta",
    "iakttaget": "iaktta",
    "iakttagets": "iaktta",
    "iakttagit": "iaktta",
    "iakttagits": "iaktta",
    "iakttagna": "iaktta",
    "iakttagnas": "iaktta",
    "iakttagne": "iaktta",
    "iakttagnes": "iaktta",
    "iakttags": "iaktta",
    "iakttar": "iaktta",
    "iakttas": "iaktta",
    "iakttog": "iaktta",
    "iakttoge": "iaktta",
    "iakttoges": "iaktta",
    "iakttogs": "iaktta",
    "iberiska": "iberisk",
    "iberiskare": "iberisk",
    "iberiskares": "iberisk",
    "iberiskas": "iberisk",
    "iberiskast": "iberisk",
    "iberiskaste": "iberisk",
    "iberiskastes": "iberisk",
    "iberiskasts": "iberisk",
    "iberiske": "iberisk",
    "iberiskes": "iberisk",
    "iberisks": "iberisk",
    "iberiskt": "iberisk",
    "iberiskts": "iberisk",
    "ibero-amerikanska": "ibero-amerikansk",
    "ibero-amerikanskare": "ibero-amerikansk",
    "ibero-amerikanskares": "ibero-amerikansk",
    "ibero-amerikanskas": "ibero-amerikansk",
    "ibero-amerikanskast": "ibero-amerikansk",
    "ibero-amerikanskaste": "ibero-amerikansk",
    "ibero-amerikanskastes": "ibero-amerikansk",
    "ibero-amerikanskasts": "ibero-amerikansk",
    "ibero-amerikanske": "ibero-amerikansk",
    "ibero-amerikanskes": "ibero-amerikansk",
    "ibero-amerikansks": "ibero-amerikansk",
    "ibero-amerikanskt": "ibero-amerikansk",
    "ibero-amerikanskts": "ibero-amerikansk",
    "ibisar": "ibis",
    "ibisarna": "ibis",
    "ibisarnas": "ibis",
    "ibisars": "ibis",
    "ibisen": "ibis",
    "ibisens": "ibis",
    "ibisfågeln": "ibisfågel",
    "ibisfågelns": "ibisfågel",
    "ibisfågels": "ibisfågel",
    "ibisfåglar": "ibisfågel",
    "ibisfåglarna": "ibisfågel",
    "ibisfåglarnas": "ibisfågel",
    "ibisfåglars": "ibisfågel",
    "ibisrosen": "ibisros",
    "ibisrosens": "ibisros",
    "ibisrosor": "ibisros",
    "ibisrosorna": "ibisros",
    "ibisrosornas": "ibisros",
    "ibisrosors": "ibisros",
    "icingar": "icing",
    "icingarna": "icing",
    "icingarnas": "icing",
    "icingars": "icing",
    "icingen": "icing",
    "icingens": "icing",
    "icings": "icing",
    "icke-angreppspakten": "icke-angreppspakt",
    "icke-angreppspaktens": "icke-angreppspakt",
    "icke-angreppspakter": "icke-angreppspakt",
    "icke-angreppspakterna": "icke-angreppspakt",
    "icke-angreppspakternas": "icke-angreppspakt",
    "icke-angreppspakters": "icke-angreppspakt",
    "icke-angreppspakts": "icke-angreppspakt",
    "icke-darwinistiska": "icke-darwinistisk",
    "icke-darwinistiskare": "icke-darwinistisk",
    "icke-darwinistiskares": "icke-darwinistisk",
    "icke-darwinistiskas": "icke-darwinistisk",
    "icke-darwinistiskast": "icke-darwinistisk",
    "icke-darwinistiskaste": "icke-darwinistisk",
    "icke-darwinistiskastes": "icke-darwinistisk",
    "icke-darwinistiskasts": "icke-darwinistisk",
    "icke-darwinistiske": "icke-darwinistisk",
    "icke-darwinistiskes": "icke-darwinistisk",
    "icke-darwinistisks": "icke-darwinistisk",
    "icke-darwinistiskt": "icke-darwinistisk",
    "icke-darwinistiskts": "icke-darwinistisk",
    "icke-euklidiska": "icke-euklidisk",
    "icke-euklidiskare": "icke-euklidisk",
    "icke-euklidiskares": "icke-euklidisk",
    "icke-euklidiskas": "icke-euklidisk",
    "icke-euklidiskast": "icke-euklidisk",
    "icke-euklidiskaste": "icke-euklidisk",
    "icke-euklidiskastes": "icke-euklidisk",
    "icke-euklidiskasts": "icke-euklidisk",
    "icke-euklidiske": "icke-euklidisk",
    "icke-euklidiskes": "icke-euklidisk",
    "icke-euklidisks": "icke-euklidisk",
    "icke-euklidiskt": "icke-euklidisk",
    "icke-euklidiskts": "icke-euklidisk",
    "icke-händelsen": "icke-händelse",
    "icke-händelsens": "icke-händelse",
    "icke-händelser": "icke-händelse",
    "icke-händelserna": "icke-händelse",
    "icke-händelsernas": "icke-händelse",
    "icke-händelsers": "icke-händelse",
    "icke-händelses": "icke-händelse",
    "icke-individuella": "icke-individuell",
    "icke-individuellare": "icke-individuell",
    "icke-individuellares": "icke-individuell",
    "icke-individuellas": "icke-individuell",
    "icke-individuellast": "icke-individuell",
    "icke-individuellaste": "icke-individuell",
    "icke-individuellastes": "icke-individuell",
    "icke-individuellasts": "icke-individuell",
    "icke-individuelle": "icke-individuell",
    "icke-individuelles": "icke-individuell",
    "icke-individuells": "icke-individuell",
    "icke-individuellt": "icke-individuell",
    "icke-individuellts": "icke-individuell",
    "icke-kristens": "icke-kristen",
    "icke-kristet": "icke-kristen",
    "icke-kristets": "icke-kristen",
    "icke-kristna": "icke-kristen",
    "icke-kristnare": "icke-kristen",
    "icke-kristnares": "icke-kristen",
    "icke-kristnas": "icke-kristen",
    "icke-kristnast": "icke-kristen",
    "icke-kristnaste": "icke-kristen",
    "icke-kristnastes": "icke-kristen",
    "icke-kristnasts": "icke-kristen",
    "icke-kristne": "icke-kristen",
    "icke-kristnes": "icke-kristen",
    "icke-linjära": "icke-linjär",
    "icke-linjärare": "icke-linjär",
    "icke-linjärares": "icke-linjär",
    "icke-linjäras": "icke-linjär",
    "icke-linjärast": "icke-linjär",
    "icke-linjäraste": "icke-linjär",
    "icke-linjärastes": "icke-linjär",
    "icke-linjärasts": "icke-linjär",
    "icke-linjäre": "icke-linjär",
    "icke-linjäres": "icke-linjär",
    "icke-linjärs": "icke-linjär",
    "icke-linjärt": "icke-linjär",
    "icke-linjärts": "icke-linjär",
    "icke-metallen": "icke-metall",
    "icke-metallens": "icke-metall",
    "icke-metaller": "icke-metall",
    "icke-metallerna": "icke-metall",
    "icke-metallernas": "icke-metall",
    "icke-metallers": "icke-metall",
    "icke-metalls": "icke-metall",
    "icke-muslimen": "icke-muslim",
    "icke-muslimens": "icke-muslim",
    "icke-muslimer": "icke-muslim",
    "icke-muslimerna": "icke-muslim",
    "icke-muslimernas": "icke-muslim",
    "icke-muslimers": "icke-muslim",
    "icke-muslims": "icke-muslim",
    "icke-periodiska": "icke-periodisk",
    "icke-periodiskare": "icke-periodisk",
    "icke-periodiskares": "icke-periodisk",
    "icke-periodiskas": "icke-periodisk",
    "icke-periodiskast": "icke-periodisk",
    "icke-periodiskaste": "icke-periodisk",
    "icke-periodiskastes": "icke-periodisk",
    "icke-periodiskasts": "icke-periodisk",
    "icke-periodiske": "icke-periodisk",
    "icke-periodiskes": "icke-periodisk",
    "icke-periodisks": "icke-periodisk",
    "icke-periodiskt": "icke-periodisk",
    "icke-periodiskts": "icke-periodisk",
    "icke-politiska": "icke-politisk",
    "icke-politiskas": "icke-politisk",
    "icke-politiske": "icke-politisk",
    "icke-politiskes": "icke-politisk",
    "icke-politisks": "icke-politisk",
    "icke-politiskt": "icke-politisk",
    "icke-politiskts": "icke-politisk",
    "icke-rökar": "icke-rökare",
    "icke-rökaren": "icke-rökare",
    "icke-rökarens": "icke-rökare",
    "icke-rökares": "icke-rökare",
    "icke-rökarna": "icke-rökare",
    "icke-rökarnas": "icke-rökare",
    "icke-specialisten": "icke-specialist",
    "icke-specialistens": "icke-specialist",
    "icke-specialister": "icke-specialist",
    "icke-specialisterna": "icke-specialist",
    "icke-specialisternas": "icke-specialist",
    "icke-specialisters": "icke-specialist",
    "icke-specialists": "icke-specialist",
    "icke-spridningsavtalen": "icke-spridningsavtal",
    "icke-spridningsavtalens": "icke-spridningsavtal",
    "icke-spridningsavtalet": "icke-spridningsavtal",
    "icke-spridningsavtalets": "icke-spridningsavtal",
    "icke-spridningsavtals": "icke-spridningsavtal",
    "icke-symmetriska": "icke-symmetrisk",
    "icke-symmetriskare": "icke-symmetrisk",
    "icke-symmetriskares": "icke-symmetrisk",
    "icke-symmetriskas": "icke-symmetrisk",
    "icke-symmetriskast": "icke-symmetrisk",
    "icke-symmetriskaste": "icke-symmetrisk",
    "icke-symmetriskastes": "icke-symmetrisk",
    "icke-symmetriskasts": "icke-symmetrisk",
    "icke-symmetriske": "icke-symmetrisk",
    "icke-symmetriskes": "icke-symmetrisk",
    "icke-symmetrisks": "icke-symmetrisk",
    "icke-symmetriskt": "icke-symmetrisk",
    "icke-symmetriskts": "icke-symmetrisk",
    "icke-verbala": "icke-verbal",
    "icke-verbalare": "icke-verbal",
    "icke-verbalares": "icke-verbal",
    "icke-verbalas": "icke-verbal",
    "icke-verbalast": "icke-verbal",
    "icke-verbalaste": "icke-verbal",
    "icke-verbalastes": "icke-verbal",
    "icke-verbalasts": "icke-verbal",
    "icke-verbale": "icke-verbal",
    "icke-verbales": "icke-verbal",
    "icke-verbals": "icke-verbal",
    "icke-verbalt": "icke-verbal",
    "icke-verbalts": "icke-verbal",
    "icke-våldet": "icke-våld",
    "icke-våldets": "icke-våld",
    "icke-vålds": "icke-våld",
    "ickemuslimska": "ickemuslimsk",
    "ickemuslimskare": "ickemuslimsk",
    "ickemuslimskares": "ickemuslimsk",
    "ickemuslimskas": "ickemuslimsk",
    "ickemuslimskast": "ickemuslimsk",
    "ickemuslimskaste": "ickemuslimsk",
    "ickemuslimskastes": "ickemuslimsk",
    "ickemuslimskasts": "ickemuslimsk",
    "ickemuslimske": "ickemuslimsk",
    "ickemuslimskes": "ickemuslimsk",
    "ickemuslimsks": "ickemuslimsk",
    "ickemuslimskt": "ickemuslimsk",
    "ickemuslimskts": "ickemuslimsk",
    "ickepolitiska": "ickepolitisk",
    "ickepolitiskas": "ickepolitisk",
    "ickepolitiske": "ickepolitisk",
    "ickepolitiskes": "ickepolitisk",
    "ickepolitisks": "ickepolitisk",
    "ickepolitiskt": "ickepolitisk",
    "ickepolitiskts": "ickepolitisk",
    "ickerökar": "ickerökare",
    "ickerökaren": "ickerökare",
    "ickerökarens": "ickerökare",
    "ickerökares": "ickerökare",
    "ickerökarna": "ickerökare",
    "ickerökarnas": "ickerökare",
    "ickeverbala": "ickeverbal",
    "ickeverbalare": "ickeverbal",
    "ickeverbalares": "ickeverbal",
    "ickeverbalas": "ickeverbal",
    "ickeverbalast": "ickeverbal",
    "ickeverbalaste": "ickeverbal",
    "ickeverbalastes": "ickeverbal",
    "ickeverbalasts": "ickeverbal",
    "ickeverbale": "ickeverbal",
    "ickeverbales": "ickeverbal",
    "ickeverbals": "ickeverbal",
    "ickeverbalt": "ickeverbal",
    "ickeverbalts": "ickeverbal",
    "ickevåldet": "ickevåld",
    "ickevåldets": "ickevåld",
    "ickevålds": "ickevåld",
    "ickevåldsentusiasten": "ickevåldsentusiast",
    "ickevåldsentusiastens": "ickevåldsentusiast",
    "ickevåldsentusiaster": "ickevåldsentusiast",
    "ickevåldsentusiasterna": "ickevåldsentusiast",
    "ickevåldsentusiasternas": "ickevåldsentusiast",
    "ickevåldsentusiasters": "ickevåldsentusiast",
    "ickevåldsentusiasts": "ickevåldsentusiast",
    "id-korten": "id-kort",
    "id-kortets": "id-kort",
    "idar": "id",
    "idarna": "id",
    "idarnas": "id",
    "idars": "id",
    "idats": "idas",
    "iddes": "idas",
    "ideala": "ideal",
    "idealare": "ideal",
    "idealares": "ideal",
    "idealas": "ideal",
    "idealast": "ideal",
    "idealaste": "ideal",
    "idealastes": "ideal",
    "idealasts": "ideal",
    "idealbilden": "idealbild",
    "idealbildens": "idealbild",
    "idealbilder": "idealbild",
    "idealbilderna": "idealbild",
    "idealbildernas": "idealbild",
    "idealbilders": "idealbild",
    "idealbilds": "idealbild",
    "ideale": "ideal",
    "idealen": "ideal",
    "idealens": "ideal",
    "ideales": "ideal",
    "idealet": "ideal",
    "idealets": "ideal",
    "idealiserad": "idealisera",
    "idealiserade": "idealisera",
    "idealiserades": "idealisera",
    "idealiserads": "idealisera",
    "idealiserande": "idealisera",
    "idealiseranden": "idealiserande",
    "idealiserandena": "idealiserande",
    "idealiserandenas": "idealiserande",
    "idealiserandens": "idealiserande",
    "idealiserandes": "idealiserande",
    "idealiserandet": "idealiserande",
    "idealiserandets": "idealiserande",
    "idealiserar": "idealisera",
    "idealiseras": "idealisera",
    "idealiserat": "idealisera",
    "idealiserats": "idealisera",
    "idealiserbara": "idealiserbar",
    "idealiserbarare": "idealiserbar",
    "idealiserbarares": "idealiserbar",
    "idealiserbaras": "idealiserbar",
    "idealiserbarast": "idealiserbar",
    "idealiserbaraste": "idealiserbar",
    "idealiserbarastes": "idealiserbar",
    "idealiserbarasts": "idealiserbar",
    "idealiserbare": "idealiserbar",
    "idealiserbares": "idealiserbar",
    "idealiserbarheten": "idealiserbarhet",
    "idealiserbarhetens": "idealiserbarhet",
    "idealiserbarhets": "idealiserbarhet",
    "idealiserbars": "idealiserbar",
    "idealiserbart": "idealiserbar",
    "idealiserbarts": "idealiserbar",
    "idealiseringar": "idealisering",
    "idealiseringarna": "idealisering",
    "idealiseringarnas": "idealisering",
    "idealiseringars": "idealisering",
    "idealiseringen": "idealisering",
    "idealiseringens": "idealisering",
    "idealiserings": "idealisering",
    "idealiska": "idealisk",
    "idealiskare": "idealisk",
    "idealiskares": "idealisk",
    "idealiskas": "idealisk",
    "idealiskast": "idealisk",
    "idealiskaste": "idealisk",
    "idealiskastes": "idealisk",
    "idealiskasts": "idealisk",
    "idealiske": "idealisk",
    "idealiskes": "idealisk",
    "idealisks": "idealisk",
    "idealiskt": "idealisk",
    "idealiskts": "idealisk",
    "idealismen": "idealism",
    "idealismens": "idealism",
    "idealismer": "idealism",
    "idealismerna": "idealism",
    "idealismernas": "idealism",
    "idealismers": "idealism",
    "idealisms": "idealism",
    "idealisten": "idealist",
    "idealistens": "idealist",
    "idealister": "idealist",
    "idealisterna": "idealist",
    "idealisternas": "idealist",
    "idealisters": "idealist",
    "idealistiska": "idealistisk",
    "idealistiskare": "idealistisk",
    "idealistiskares": "idealistisk",
    "idealistiskas": "idealistisk",
    "idealistiskast": "idealistisk",
    "idealistiskaste": "idealistisk",
    "idealistiskastes": "idealistisk",
    "idealistiskasts": "idealistisk",
    "idealistiske": "idealistisk",
    "idealistiskes": "idealistisk",
    "idealistisks": "idealistisk",
    "idealistiskt": "idealistisk",
    "idealistiskts": "idealistisk",
    "idealists": "idealist",
    "idealiteten": "idealitet",
    "idealitetens": "idealitet",
    "idealiteter": "idealitet",
    "idealiteterna": "idealitet",
    "idealiteternas": "idealitet",
    "idealiteters": "idealitet",
    "idealitets": "idealitet",
    "ideals": "ideal",
    "idealsamhällen": "idealsamhälle",
    "idealsamhällena": "idealsamhälle",
    "idealsamhällenas": "idealsamhälle",
    "idealsamhällens": "idealsamhälle",
    "idealsamhälles": "idealsamhälle",
    "idealsamhället": "idealsamhälle",
    "idealsamhällets": "idealsamhälle",
    "idealsamhälls": "idealsamhälle",
    "idealt": "ideal",
    "idealts": "ideal",
    "idealvärldar": "idealvärld",
    "idealvärldarna": "idealvärld",
    "idealvärldarnas": "idealvärld",
    "idealvärldars": "idealvärld",
    "idealvärlden": "idealvärld",
    "idealvärldens": "idealvärld",
    "idealvärlds": "idealvärld",
    "ideella": "ideell",
    "ideellare": "ideell",
    "ideellares": "ideell",
    "ideellas": "ideell",
    "ideellast": "ideell",
    "ideellaste": "ideell",
    "ideellastes": "ideell",
    "ideellasts": "ideell",
    "ideelle": "ideell",
    "ideelles": "ideell",
    "ideells": "ideell",
    "ideellt": "ideell",
    "ideellts": "ideell",
    "idegranar": "idegran",
    "idegranarna": "idegran",
    "idegranarnas": "idegran",
    "idegranars": "idegran",
    "idegranen": "idegran",
    "idegranens": "idegran",
    "idegrans": "idegran",
    "ideliga": "idelig",
    "ideligare": "idelig",
    "ideligares": "idelig",
    "ideligas": "idelig",
    "ideligast": "idelig",
    "ideligaste": "idelig",
    "ideligastes": "idelig",
    "ideligasts": "idelig",
    "idelige": "idelig",
    "ideliges": "idelig",
    "ideligheten": "idelighet",
    "idelighetens": "idelighet",
    "idelighets": "idelighet",
    "ideligs": "idelig",
    "ideligt": "idelig",
    "ideligts": "idelig",
    "iden": "ide",
    "idena": "ide",
    "idenas": "ide",
    "idens": "ide",
    "identifierad": "identifiera",
    "identifierade": "identifiera",
    "identifierades": "identifiera",
    "identifierads": "identifiera",
    "identifierande": "identifiera",
    "identifieranden": "identifierande",
    "identifierandena": "identifierande",
    "identifierandenas": "identifierande",
    "identifierandens": "identifierande",
    "identifierandes": "identifierande",
    "identifierandet": "identifierande",
    "identifierandets": "identifierande",
    "identifierar": "identifiera",
    "identifieras": "identifiera",
    "identifierat": "identifiera",
    "identifierats": "identifiera",
    "identifierbara": "identifierbar",
    "identifierbarare": "identifierbar",
    "identifierbarares": "identifierbar",
    "identifierbaras": "identifierbar",
    "identifierbarast": "identifierbar",
    "identifierbaraste": "identifierbar",
    "identifierbarastes": "identifierbar",
    "identifierbarasts": "identifierbar",
    "identifierbare": "identifierbar",
    "identifierbares": "identifierbar",
    "identifierbarheten": "identifierbarhet",
    "identifierbarhetens": "identifierbarhet",
    "identifierbarhets": "identifierbarhet",
    "identifierbars": "identifierbar",
    "identifierbart": "identifierbar",
    "identifierbarts": "identifierbar",
    "identifieringar": "identifiering",
    "identifieringarna": "identifiering",
    "identifieringarnas": "identifiering",
    "identifieringars": "identifiering",
    "identifieringen": "identifiering",
    "identifieringens": "identifiering",
    "identifierings": "identifiering",
    "identifikationen": "identifikation",
    "identifikationens": "identifikation",
    "identifikationer": "identifikation",
    "identifikationerna": "identifikation",
    "identifikationernas": "identifikation",
    "identifikationers": "identifikation",
    "identifikations": "identifikation",
    "identifikationsprocessen": "identifikationsprocess",
    "identifikationsprocessens": "identifikationsprocess",
    "identifikationsprocesser": "identifikationsprocess",
    "identifikationsprocesserna": "identifikationsprocess",
    "identifikationsprocessernas": "identifikationsprocess",
    "identifikationsprocessers": "identifikationsprocess",
    "identiska": "identisk",
    "identiskare": "identisk",
    "identiskares": "identisk",
    "identiskas": "identisk",
    "identiskast": "identisk",
    "identiskaste": "identisk",
    "identiskastes": "identisk",
    "identiskasts": "identisk",
    "identiske": "identisk",
    "identiskes": "identisk",
    "identisks": "identisk",
    "identiskt": "identisk",
    "identiskts": "identisk",
    "identiteten": "identitet",
    "identitetens": "identitet",
    "identiteter": "identitet",
    "identiteterna": "identitet",
    "identiteternas": "identitet",
    "identiteters": "identitet",
    "identitets": "identitet",
    "identitetsbrick": "identitetsbricka",
    "identitetsbrickan": "identitetsbricka",
    "identitetsbrickans": "identitetsbricka",
    "identitetsbrickas": "identitetsbricka",
    "identitetsbricke": "identitetsbricka",
    "identitetsbrickor": "identitetsbricka",
    "identitetsbrickorna": "identitetsbricka",
    "identitetsbrickornas": "identitetsbricka",
    "identitetsbrickors": "identitetsbricka",
    "identitetsbricks": "identitetsbricka",
    "identitetskorten": "identitetskort",
    "identitetskortens": "identitetskort",
    "identitetskortet": "identitetskort",
    "identitetskortets": "identitetskort",
    "identitetskorts": "identitetskort",
    "identitetskrisen": "identitetskris",
    "identitetskrisens": "identitetskris",
    "identitetskriser": "identitetskris",
    "identitetskriserna": "identitetskris",
    "identitetskrisernas": "identitetskris",
    "identitetskrisers": "identitetskris",
    "identitetsmässiga": "identitetsmässig",
    "identitetsmässigare": "identitetsmässig",
    "identitetsmässigares": "identitetsmässig",
    "identitetsmässigas": "identitetsmässig",
    "identitetsmässigast": "identitetsmässig",
    "identitetsmässigaste": "identitetsmässig",
    "identitetsmässigastes": "identitetsmässig",
    "identitetsmässigasts": "identitetsmässig",
    "identitetsmässige": "identitetsmässig",
    "identitetsmässiges": "identitetsmässig",
    "identitetsmässigs": "identitetsmässig",
    "identitetsmässigt": "identitetsmässig",
    "identitetsmässigts": "identitetsmässig",
    "identitetssökanden": "identitetssökande",
    "identitetssökandena": "identitetssökande",
    "identitetssökandenas": "identitetssökande",
    "identitetssökandens": "identitetssökande",
    "identitetssökandes": "identitetssökande",
    "ideografien": "ideografi",
    "ideografiens": "ideografi",
    "ideografin": "ideografi",
    "ideografins": "ideografi",
    "ideografis": "ideografi",
    "ideografiska": "ideografisk",
    "ideografiskare": "ideografisk",
    "ideografiskares": "ideografisk",
    "ideografiskas": "ideografisk",
    "ideografiskast": "ideografisk",
    "ideografiskaste": "ideografisk",
    "ideografiskastes": "ideografisk",
    "ideografiskasts": "ideografisk",
    "ideografiske": "ideografisk",
    "ideografiskes": "ideografisk",
    "ideografisks": "ideografisk",
    "ideografiskt": "ideografisk",
    "ideografiskts": "ideografisk",
    "ideogrammen": "ideogram",
    "ideogrammens": "ideogram",
    "ideogrammet": "ideogram",
    "ideogrammets": "ideogram",
    "ideograms": "ideogram",
    "ideologen": "ideolog",
    "ideologens": "ideolog",
    "ideologer": "ideolog",
    "ideologerna": "ideolog",
    "ideologernas": "ideolog",
    "ideologers": "ideolog",
    "ideologien": "ideologi",
    "ideologiens": "ideologi",
    "ideologier": "ideologi",
    "ideologierna": "ideologi",
    "ideologiernas": "ideologi",
    "ideologiers": "ideologi",
    "ideologin": "ideologi",
    "ideologins": "ideologi",
    "ideologis": "ideologi",
    "ideologiska": "ideologisk",
    "ideologiskare": "ideologisk",
    "ideologiskares": "ideologisk",
    "ideologiskas": "ideologisk",
    "ideologiskast": "ideologisk",
    "ideologiskaste": "ideologisk",
    "ideologiskastes": "ideologisk",
    "ideologiskasts": "ideologisk",
    "ideologiske": "ideologisk",
    "ideologiskes": "ideologisk",
    "ideologisks": "ideologisk",
    "ideologiskt": "ideologisk",
    "ideologiskts": "ideologisk",
    "ideologs": "ideolog",
    "ides": "ide",
    "idet": "ide",
    "idets": "ide",
    "idiolekten": "idiolekt",
    "idiolektens": "idiolekt",
    "idiolekter": "idiolekt",
    "idiolekterna": "idiolekt",
    "idiolekternas": "idiolekt",
    "idiolekters": "idiolekt",
    "idiolekts": "idiolekt",
    "idiomatiska": "idiomatisk",
    "idiomatiskare": "idiomatisk",
    "idiomatiskares": "idiomatisk",
    "idiomatiskas": "idiomatisk",
    "idiomatiskast": "idiomatisk",
    "idiomatiskaste": "idiomatisk",
    "idiomatiskastes": "idiomatisk",
    "idiomatiskasts": "idiomatisk",
    "idiomatiske": "idiomatisk",
    "idiomatiskes": "idiomatisk",
    "idiomatisks": "idiomatisk",
    "idiomatiskt": "idiomatisk",
    "idiomatiskts": "idiomatisk",
    "idiomen": "idiom",
    "idiomens": "idiom",
    "idiomet": "idiom",
    "idiomets": "idiom",
    "idioms": "idiom",
    "idiopatien": "idiopati",
    "idiopatiens": "idiopati",
    "idiopatin": "idiopati",
    "idiopatins": "idiopati",
    "idiopatis": "idiopati",
    "idiopatiska": "idiopatisk",
    "idiopatiskare": "idiopatisk",
    "idiopatiskares": "idiopatisk",
    "idiopatiskas": "idiopatisk",
    "idiopatiskast": "idiopatisk",
    "idiopatiskaste": "idiopatisk",
    "idiopatiskastes": "idiopatisk",
    "idiopatiskasts": "idiopatisk",
    "idiopatiske": "idiopatisk",
    "idiopatiskes": "idiopatisk",
    "idiopatisks": "idiopatisk",
    "idiopatiskt": "idiopatisk",
    "idiopatiskts": "idiopatisk",
    "idiosynkrasien": "idiosynkrasi",
    "idiosynkrasiens": "idiosynkrasi",
    "idiosynkrasier": "idiosynkrasi",
    "idiosynkrasierna": "idiosynkrasi",
    "idiosynkrasiernas": "idiosynkrasi",
    "idiosynkrasiers": "idiosynkrasi",
    "idiosynkrasin": "idiosynkrasi",
    "idiosynkrasins": "idiosynkrasi",
    "idiosynkrasis": "idiosynkrasi",
    "idioten": "idiot",
    "idiotens": "idiot",
    "idioter": "idiot",
    "idioterna": "idiot",
    "idioternas": "idiot",
    "idioters": "idiot",
    "idiotförklarad": "idiotförklara",
    "idiotförklarade": "idiotförklara",
    "idiotförklarades": "idiotförklara",
    "idiotförklarads": "idiotförklara",
    "idiotförklarande": "idiotförklara",
    "idiotförklaranden": "idiotförklarande",
    "idiotförklarandena": "idiotförklarande",
    "idiotförklarandenas": "idiotförklarande",
    "idiotförklarandens": "idiotförklarande",
    "idiotförklarandes": "idiotförklarande",
    "idiotförklarandet": "idiotförklarande",
    "idiotförklarandets": "idiotförklarande",
    "idiotförklarar": "idiotförklara",
    "idiotförklaras": "idiotförklara",
    "idiotförklarat": "idiotförklara",
    "idiotförklarats": "idiotförklara",
    "idiotien": "idioti",
    "idiotiens": "idioti",
    "idiotier": "idioti",
    "idiotierna": "idioti",
    "idiotiernas": "idioti",
    "idiotiers": "idioti",
    "idiotin": "idioti",
    "idiotins": "idioti",
    "idiotis": "idioti",
    "idiotiska": "idiotisk",
    "idiotiskare": "idiotisk",
    "idiotiskares": "idiotisk",
    "idiotiskas": "idiotisk",
    "idiotiskast": "idiotisk",
    "idiotiskaste": "idiotisk",
    "idiotiskastes": "idiotisk",
    "idiotiskasts": "idiotisk",
    "idiotiske": "idiotisk",
    "idiotiskes": "idiotisk",
    "idiotisks": "idiotisk",
    "idiotiskt": "idiotisk",
    "idiotiskts": "idiotisk",
    "idiots": "idiot",
    "idiotsäkerheten": "idiotsäkerhet",
    "idiotsäkerhetens": "idiotsäkerhet",
    "idiotsäkerhets": "idiotsäkerhet",
    "idiotsäkers": "idiotsäker",
    "idiotsäkert": "idiotsäker",
    "idiotsäkerts": "idiotsäker",
    "idiotsäkra": "idiotsäker",
    "idiotsäkrare": "idiotsäker",
    "idiotsäkrares": "idiotsäker",
    "idiotsäkras": "idiotsäker",
    "idiotsäkrast": "idiotsäker",
    "idiotsäkraste": "idiotsäker",
    "idiotsäkrastes": "idiotsäker",
    "idiotsäkrasts": "idiotsäker",
    "idiotsäkre": "idiotsäker",
    "idiotsäkres": "idiotsäker",
    "idissel": "idissla",
    "idisslad": "idissla",
    "idisslade": "idissla",
    "idisslades": "idissla",
    "idisslads": "idissla",
    "idisslande": "idissla",
    "idisslanden": "idisslande",
    "idisslandena": "idisslande",
    "idisslandenas": "idisslande",
    "idisslandens": "idisslande",
    "idisslandes": "idisslande",
    "idisslandet": "idisslande",
    "idisslandets": "idisslande",
    "idisslar": "idisslare",
    "idisslaren": "idisslare",
    "idisslarens": "idisslare",
    "idisslares": "idisslare",
    "idisslarna": "idisslare",
    "idisslarnas": "idisslare",
    "idisslas": "idissla",
    "idisslat": "idissla",
    "idisslats": "idissla",
    "idk": "idka",
    "idkad": "idka",
    "idkade": "idka",
    "idkades": "idka",
    "idkads": "idka",
    "idkande": "idka",
    "idkanden": "idkande",
    "idkandena": "idkande",
    "idkandenas": "idkande",
    "idkandens": "idkande",
    "idkandes": "idkande",
    "idkandet": "idkande",
    "idkandets": "idkande",
    "idkar": "idkare",
    "idkaren": "idkare",
    "idkarens": "idkare",
    "idkares": "idkare",
    "idkarna": "idkare",
    "idkarnas": "idkare",
    "idkas": "idka",
    "idkat": "idka",
    "idkats": "idka",
    "idoga": "idog",
    "idogare": "idog",
    "idogares": "idog",
    "idogas": "idog",
    "idogast": "idog",
    "idogaste": "idog",
    "idogastes": "idog",
    "idogasts": "idog",
    "idoge": "idog",
    "idoges": "idog",
    "idogs": "idog",
    "idogt": "idog",
    "idogts": "idog",
    "idolen": "idol",
    "idolens": "idol",
    "idoler": "idol",
    "idolerna": "idol",
    "idolernas": "idol",
    "idolers": "idol",
    "idolporträtten": "idolporträtt",
    "idolporträttens": "idolporträtt",
    "idolporträttet": "idolporträtt",
    "idolporträttets": "idolporträtt",
    "idolporträtts": "idolporträtt",
    "idolskapen": "idolskap",
    "idolskapens": "idolskap",
    "idolskapet": "idolskap",
    "idolskapets": "idolskap",
    "idolskaps": "idolskap",
    "idos": "ido",
    "idrottade": "idrotta",
    "idrottades": "idrotta",
    "idrottande": "idrotta",
    "idrottanden": "idrottande",
    "idrottandena": "idrottande",
    "idrottandenas": "idrottande",
    "idrottandens": "idrottande",
    "idrottandes": "idrottande",
    "idrottandet": "idrottande",
    "idrottandets": "idrottande",
    "idrottar": "idrotta",
    "idrottas": "idrotta",
    "idrottat": "idrotta",
    "idrottats": "idrotta",
    "idrotten": "idrott",
    "idrottens": "idrott",
    "idrotter": "idrott",
    "idrotterna": "idrott",
    "idrotternas": "idrott",
    "idrotters": "idrott",
    "idrotts": "idrott",
    "idrottsarenan": "idrottsarena",
    "idrottsarenans": "idrottsarena",
    "idrottsarenas": "idrottsarena",
    "idrottsarenor": "idrottsarena",
    "idrottsarenorna": "idrottsarena",
    "idrottsarenornas": "idrottsarena",
    "idrottsarenors": "idrottsarena",
    "idrottsbragden": "idrottsbragd",
    "idrottsbragdens": "idrottsbragd",
    "idrottsbragder": "idrottsbragd",
    "idrottsbragderna": "idrottsbragd",
    "idrottsbragdernas": "idrottsbragd",
    "idrottsbragders": "idrottsbragd",
    "idrottsbragds": "idrottsbragd",
    "idrottsdagar": "idrottsdag",
    "idrottsdagarna": "idrottsdag",
    "idrottsdagarnas": "idrottsdag",
    "idrottsdagars": "idrottsdag",
    "idrottsdagen": "idrottsdag",
    "idrottsdagens": "idrottsdag",
    "idrottsdags": "idrottsdag",
    "idrottsdräkten": "idrottsdräkt",
    "idrottsdräktens": "idrottsdräkt",
    "idrottsdräkter": "idrottsdräkt",
    "idrottsdräkterna": "idrottsdräkt",
    "idrottsdräkternas": "idrottsdräkt",
    "idrottsdräkters": "idrottsdräkt",
    "idrottsdräkts": "idrottsdräkt",
    "idrottsföreningar": "idrottsförening",
    "idrottsföreningarna": "idrottsförening",
    "idrottsföreningarnas": "idrottsförening",
    "idrottsföreningars": "idrottsförening",
    "idrottsföreningen": "idrottsförening",
    "idrottsföreningens": "idrottsförening",
    "idrottsförenings": "idrottsförening",
    "idrottsgrenar": "idrottsgren",
    "idrottsgrenarna": "idrottsgren",
    "idrottsgrenarnas": "idrottsgren",
    "idrottsgrenars": "idrottsgren",
    "idrottsgrenen": "idrottsgren",
    "idrottsgrenens": "idrottsgren",
    "idrottsgrens": "idrottsgren",
    "idrottsgymnasie": "idrottsgymnasium",
    "idrottsgymnasier": "idrottsgymnasium",
    "idrottsgymnasierna": "idrottsgymnasium",
    "idrottsgymnasiernas": "idrottsgymnasium",
    "idrottsgymnasiers": "idrottsgymnasium",
    "idrottsgymnasiet": "idrottsgymnasium",
    "idrottsgymnasiets": "idrottsgymnasium",
    "idrottsgymnasiums": "idrottsgymnasium",
    "idrottsgymnastiken": "idrottsgymnastik",
    "idrottsgymnastikens": "idrottsgymnastik",
    "idrottsgymnastiks": "idrottsgymnastik",
    "idrottshallar": "idrottshall",
    "idrottshallarna": "idrottshall",
    "idrottshallarnas": "idrottshall",
    "idrottshallars": "idrottshall",
    "idrottshallen": "idrottshall",
    "idrottshallens": "idrottshall",
    "idrottshalls": "idrottshall",
    "idrottsklubbar": "idrottsklubb",
    "idrottsklubbarna": "idrottsklubb",
    "idrottsklubbarnas": "idrottsklubb",
    "idrottsklubbars": "idrottsklubb",
    "idrottsklubben": "idrottsklubb",
    "idrottsklubbens": "idrottsklubb",
    "idrottsklubbs": "idrottsklubb",
    "idrottskompanier": "idrottskompani",
    "idrottskompanierna": "idrottskompani",
    "idrottskompaniernas": "idrottskompani",
    "idrottskompaniers": "idrottskompani",
    "idrottskompaniet": "idrottskompani",
    "idrottskompaniets": "idrottskompani",
    "idrottskompanis": "idrottskompani",
    "idrottskompanit": "idrottskompani",
    "idrottskompanits": "idrottskompani",
    "idrottskvinnan": "idrottskvinna",
    "idrottskvinnans": "idrottskvinna",
    "idrottskvinnas": "idrottskvinna",
    "idrottskvinne": "idrottskvinna",
    "idrottskvinno": "idrottskvinna",
    "idrottskvinnor": "idrottskvinna",
    "idrottskvinnorna": "idrottskvinna",
    "idrottskvinnornas": "idrottskvinna",
    "idrottskvinnors": "idrottskvinna",
    "idrottslagen": "idrottslag",
    "idrottslagens": "idrottslag",
    "idrottslaget": "idrottslag",
    "idrottslagets": "idrottslag",
    "idrottslags": "idrottslag",
    "idrottsledar": "idrottsledare",
    "idrottsledaren": "idrottsledare",
    "idrottsledarens": "idrottsledare",
    "idrottsledares": "idrottsledare",
    "idrottsledarna": "idrottsledare",
    "idrottsledarnas": "idrottsledare",
    "idrottsliga": "idrottslig",
    "idrottsligare": "idrottslig",
    "idrottsligares": "idrottslig",
    "idrottsligas": "idrottslig",
    "idrottsligast": "idrottslig",
    "idrottsligaste": "idrottslig",
    "idrottsligastes": "idrottslig",
    "idrottsligasts": "idrottslig",
    "idrottslige": "idrottslig",
    "idrottsliges": "idrottslig",
    "idrottsligheten": "idrottslighet",
    "idrottslighetens": "idrottslighet",
    "idrottslighets": "idrottslighet",
    "idrottsligs": "idrottslig",
    "idrottsligt": "idrottslig",
    "idrottsligts": "idrottslig",
    "idrottsmannen": "idrottsman",
    "idrottsmannens": "idrottsman",
    "idrottsmans": "idrottsman",
    "idrottsmedicinen": "idrottsmedicin",
    "idrottsmedicinens": "idrottsmedicin",
    "idrottsmedicins": "idrottsmedicin",
    "idrottsmän": "idrottsman",
    "idrottsmännen": "idrottsman",
    "idrottsmännens": "idrottsman",
    "idrottsmäns": "idrottsman",
    "idrottsmässiga": "idrottsmässig",
    "idrottsmässigare": "idrottsmässig",
    "idrottsmässigares": "idrottsmässig",
    "idrottsmässigas": "idrottsmässig",
    "idrottsmässigast": "idrottsmässig",
    "idrottsmässigaste": "idrottsmässig",
    "idrottsmässigastes": "idrottsmässig",
    "idrottsmässigasts": "idrottsmässig",
    "idrottsmässige": "idrottsmässig",
    "idrottsmässiges": "idrottsmässig",
    "idrottsmässigs": "idrottsmässig",
    "idrottsmässigt": "idrottsmässig",
    "idrottsmässigts": "idrottsmässig",
    "idrottsplatsen": "idrottsplats",
    "idrottsplatsens": "idrottsplats",
    "idrottsplatser": "idrottsplats",
    "idrottsplatserna": "idrottsplats",
    "idrottsplatsernas": "idrottsplats",
    "idrottsplatsers": "idrottsplats",
    "idrottsprestationen": "idrottsprestation",
    "idrottsprestationens": "idrottsprestation",
    "idrottsprestationer": "idrottsprestation",
    "idrottsprestationerna": "idrottsprestation",
    "idrottsprestationernas": "idrottsprestation",
    "idrottsprestationers": "idrottsprestation",
    "idrottsprestations": "idrottsprestation",
    "idrottsreferaten": "idrottsreferat",
    "idrottsreferatens": "idrottsreferat",
    "idrottsreferatet": "idrottsreferat",
    "idrottsreferatets": "idrottsreferat",
    "idrottsreferats": "idrottsreferat",
    "idrottsrörelsen": "idrottsrörelse",
    "idrottsrörelsens": "idrottsrörelse",
    "idrottsrörelser": "idrottsrörelse",
    "idrottsrörelserna": "idrottsrörelse",
    "idrottsrörelsernas": "idrottsrörelse",
    "idrottsrörelsers": "idrottsrörelse",
    "idrottsrörelses": "idrottsrörelse",
    "idrottsskon": "idrottssko",
    "idrottsskons": "idrottssko",
    "idrottsskor": "idrottssko",
    "idrottsskorna": "idrottssko",
    "idrottsskornas": "idrottssko",
    "idrottsskors": "idrottssko",
    "idrottsskos": "idrottssko",
    "idrottsstjärnan": "idrottsstjärna",
    "idrottsstjärnans": "idrottsstjärna",
    "idrottsstjärnas": "idrottsstjärna",
    "idrottsstjärne": "idrottsstjärna",
    "idrottsstjärnor": "idrottsstjärna",
    "idrottsstjärnorna": "idrottsstjärna",
    "idrottsstjärnornas": "idrottsstjärna",
    "idrottsstjärnors": "idrottsstjärna",
    "idrottstävlingar": "idrottstävling",
    "idrottstävlingarna": "idrottstävling",
    "idrottstävlingarnas": "idrottstävling",
    "idrottstävlingars": "idrottstävling",
    "idrottstävlingen": "idrottstävling",
    "idrottstävlingens": "idrottstävling",
    "idrottstävlings": "idrottstävling",
    "ids": "ide",
    "idunsäpplen": "idunsäpple",
    "idunsäpplena": "idunsäpple",
    "idunsäpplenas": "idunsäpple",
    "idunsäpplens": "idunsäpple",
    "idunsäpples": "idunsäpple",
    "idunsäpplet": "idunsäpple",
    "idunsäpplets": "idunsäpple",
    "idunsäppls": "idunsäpple",
    "idyllen": "idyll",
    "idyllens": "idyll",
    "idyller": "idyll",
    "idyllerna": "idyll",
    "idyllernas": "idyll",
    "idyllers": "idyll",
    "idyllikern": "idylliker",
    "idyllikerna": "idylliker",
    "idyllikernas": "idylliker",
    "idyllikerns": "idylliker",
    "idyllikers": "idylliker",
    "idylliska": "idyllisk",
    "idylliskare": "idyllisk",
    "idylliskares": "idyllisk",
    "idylliskas": "idyllisk",
    "idylliskast": "idyllisk",
    "idylliskaste": "idyllisk",
    "idylliskastes": "idyllisk",
    "idylliskasts": "idyllisk",
    "idylliske": "idyllisk",
    "idylliskes": "idyllisk",
    "idyllisks": "idyllisk",
    "idylliskt": "idyllisk",
    "idylliskts": "idyllisk",
    "idylls": "idyll",
    "idéassociationen": "idéassociation",
    "idéassociationens": "idéassociation",
    "idéassociationer": "idéassociation",
    "idéassociationerna": "idéassociation",
    "idéassociationernas": "idéassociation",
    "idéassociationers": "idéassociation",
    "idéassociations": "idéassociation",
    "idédraman": "idédrama",
    "idédramana": "idédrama",
    "idédramanas": "idédrama",
    "idédramans": "idédrama",
    "idédramas": "idédrama",
    "idédramat": "idédrama",
    "idédramats": "idédrama",
    "idédramer": "idédrama",
    "idédramerna": "idédrama",
    "idédramernas": "idédrama",
    "idédramers": "idédrama",
    "idéen": "idé",
    "idéens": "idé",
    "idéer": "idé",
    "idéerna": "idé",
    "idéernas": "idé",
    "idéers": "idé",
    "idéfattiga": "idéfattig",
    "idéfattigare": "idéfattig",
    "idéfattigares": "idéfattig",
    "idéfattigas": "idéfattig",
    "idéfattigast": "idéfattig",
    "idéfattigaste": "idéfattig",
    "idéfattigastes": "idéfattig",
    "idéfattigasts": "idéfattig",
    "idéfattige": "idéfattig",
    "idéfattiges": "idéfattig",
    "idéfattigheten": "idéfattighet",
    "idéfattighetens": "idéfattighet",
    "idéfattighets": "idéfattighet",
    "idéfattigs": "idéfattig",
    "idéfattigt": "idéfattig",
    "idéfattigts": "idéfattig",
    "idéflykten": "idéflykt",
    "idéflyktens": "idéflykt",
    "idéflykts": "idéflykt",
    "idégivar": "idégivare",
    "idégivaren": "idégivare",
    "idégivarens": "idégivare",
    "idégivares": "idégivare",
    "idégivarna": "idégivare",
    "idégivarnas": "idégivare",
    "idéhistorian": "idéhistoria",
    "idéhistorians": "idéhistoria",
    "idéhistorias": "idéhistoria",
    "idéhistorien": "idéhistoria",
    "idéhistoriens": "idéhistoria",
    "idékläckningar": "idékläckning",
    "idékläckningarna": "idékläckning",
    "idékläckningarnas": "idékläckning",
    "idékläckningars": "idékläckning",
    "idékläckningen": "idékläckning",
    "idékläckningens": "idékläckning",
    "idékläcknings": "idékläckning",
    "idémässiga": "idémässig",
    "idémässigare": "idémässig",
    "idémässigares": "idémässig",
    "idémässigas": "idémässig",
    "idémässigast": "idémässig",
    "idémässigaste": "idémässig",
    "idémässigastes": "idémässig",
    "idémässigasts": "idémässig",
    "idémässige": "idémässig",
    "idémässiges": "idémässig",
    "idémässigs": "idémässig",
    "idémässigt": "idémässig",
    "idémässigts": "idémässig",
    "idémöten": "idémöte",
    "idémötena": "idémöte",
    "idémötenas": "idémöte",
    "idémötens": "idémöte",
    "idémötes": "idémöte",
    "idémötet": "idémöte",
    "idémötets": "idémöte",
    "idén": "idé",
    "idéns": "idé",
    "idérika": "idérik",
    "idérikare": "idérik",
    "idérikares": "idérik",
    "idérikas": "idérik",
    "idérikast": "idérik",
    "idérikaste": "idérik",
    "idérikastes": "idérik",
    "idérikasts": "idérik",
    "idérike": "idérik",
    "idérikes": "idérik",
    "idérikheten": "idérikhet",
    "idérikhetens": "idérikhet",
    "idérikhets": "idérikhet",
    "idériks": "idérik",
    "idérikt": "idérik",
    "idérikts": "idérik",
    "idés": "idé",
    "idéspektra": "idéspektrum",
    "idéspektrana": "idéspektrum",
    "idéspektranas": "idéspektrum",
    "idéspektras": "idéspektrum",
    "idéspektrena": "idéspektrum",
    "idéspektrenas": "idéspektrum",
    "idéspektrer": "idéspektrum",
    "idéspektrers": "idéspektrum",
    "idéspektret": "idéspektrum",
    "idéspektrets": "idéspektrum",
    "idéspektrumen": "idéspektrum",
    "idéspektrumens": "idéspektrum",
    "idéspektrumet": "idéspektrum",
    "idéspektrumets": "idéspektrum",
    "idéspektrums": "idéspektrum",
    "idésprut": "idéspruta",
    "idésprutan": "idéspruta",
    "idésprutans": "idéspruta",
    "idésprutas": "idéspruta",
    "idésprute": "idéspruta",
    "idésprutor": "idéspruta",
    "idésprutorna": "idéspruta",
    "idésprutornas": "idéspruta",
    "idésprutors": "idéspruta",
    "idéspruts": "idéspruta",
    "idévärldar": "idévärld",
    "idévärldarna": "idévärld",
    "idévärldarnas": "idévärld",
    "idévärldars": "idévärld",
    "idévärlden": "idévärld",
    "idévärldens": "idévärld",
    "idévärlds": "idévärld",
    "ien": "i",
    "iens": "i",
    "iet": "i",
    "iets": "i",
    "ifrågakom": "ifrågakomma",
    "ifrågakomet": "ifrågakomma",
    "ifrågakomets": "ifrågakomma",
    "ifrågakommande": "ifrågakomma",
    "ifrågakommanden": "ifrågakommande",
    "ifrågakommandena": "ifrågakommande",
    "ifrågakommandenas": "ifrågakommande",
    "ifrågakommandens": "ifrågakommande",
    "ifrågakommandes": "ifrågakommande",
    "ifrågakommandet": "ifrågakommande",
    "ifrågakommandets": "ifrågakommande",
    "ifrågakommas": "ifrågakomma",
    "ifrågakomme": "ifrågakomma",
    "ifrågakommen": "ifrågakomma",
    "ifrågakommens": "ifrågakomma",
    "ifrågakommer": "ifrågakomma",
    "ifrågakommes": "ifrågakomma",
    "ifrågakommit": "ifrågakomma",
    "ifrågakommits": "ifrågakomma",
    "ifrågakomna": "ifrågakomma",
    "ifrågakomnas": "ifrågakomma",
    "ifrågakomne": "ifrågakomma",
    "ifrågakomnes": "ifrågakomma",
    "ifrågakoms": "ifrågakomma",
    "ifrågasatt": "ifrågasätta",
    "ifrågasatta": "ifrågasätta",
    "ifrågasattas": "ifrågasätta",
    "ifrågasatte": "ifrågasätta",
    "ifrågasattes": "ifrågasätta",
    "ifrågasatts": "ifrågasätta",
    "ifrågasätt": "ifrågasätta",
    "ifrågasättande": "ifrågasätta",
    "ifrågasättanden": "ifrågasättande",
    "ifrågasättandena": "ifrågasättande",
    "ifrågasättandenas": "ifrågasättande",
    "ifrågasättandens": "ifrågasättande",
    "ifrågasättandes": "ifrågasättande",
    "ifrågasättandet": "ifrågasättande",
    "ifrågasättandets": "ifrågasättande",
    "ifrågasättas": "ifrågasätta",
    "ifrågasätter": "ifrågasätta",
    "ifrågasättes": "ifrågasätta",
    "ifrågasätts": "ifrågasätta",
    "ifyllnadsproven": "ifyllnadsprov",
    "ifyllnadsprovens": "ifyllnadsprov",
    "ifyllnadsprovet": "ifyllnadsprov",
    "ifyllnadsprovets": "ifyllnadsprov",
    "ifyllnadsprovs": "ifyllnadsprov",
    "iförde": "iförd",
    "ifördes": "iförd",
    "iförds": "iförd",
    "ifört": "iförd",
    "iförts": "iförd",
    "igelkottar": "igelkott",
    "igelkottarna": "igelkott",
    "igelkottarnas": "igelkott",
    "igelkottars": "igelkott",
    "igelkotten": "igelkott",
    "igelkottens": "igelkott",
    "igelkotts": "igelkott",
    "igelkottsförsvaret": "igelkottsförsvar",
    "igelkottsförsvarets": "igelkottsförsvar",
    "igelkottsförsvars": "igelkottsförsvar",
    "igeln": "igel",
    "igelns": "igel",
    "igels": "igel",
    "igenbommade": "igenbommad",
    "igenbommades": "igenbommad",
    "igenbommads": "igenbommad",
    "igenbommat": "igenbommad",
    "igenbommats": "igenbommad",
    "igengrodda": "igengrodd",
    "igengroddare": "igengrodd",
    "igengroddares": "igengrodd",
    "igengroddas": "igengrodd",
    "igengroddast": "igengrodd",
    "igengroddaste": "igengrodd",
    "igengroddastes": "igengrodd",
    "igengroddasts": "igengrodd",
    "igengrodde": "igengrodd",
    "igengroddes": "igengrodd",
    "igengrodds": "igengrodd",
    "igengrott": "igengrodd",
    "igengrotts": "igengrodd",
    "igenkorkade": "igenkorkad",
    "igenkorkades": "igenkorkad",
    "igenkorkads": "igenkorkad",
    "igenkorkat": "igenkorkad",
    "igenkorkats": "igenkorkad",
    "igenkänd": "igenkänna",
    "igenkända": "igenkänna",
    "igenkändas": "igenkänna",
    "igenkände": "igenkänna",
    "igenkändes": "igenkänna",
    "igenkänds": "igenkänna",
    "igenkänn": "igenkänna",
    "igenkännande": "igenkänna",
    "igenkännandes": "igenkännande",
    "igenkännandet": "igenkännande",
    "igenkännandets": "igenkännande",
    "igenkännas": "igenkänna",
    "igenkänner": "igenkänna",
    "igenkännes": "igenkänna",
    "igenkänningsfaktorer": "igenkänningsfaktor",
    "igenkänningsfaktorerna": "igenkänningsfaktor",
    "igenkänningsfaktorernas": "igenkänningsfaktor",
    "igenkänningsfaktorers": "igenkänningsfaktor",
    "igenkänningsfaktorn": "igenkänningsfaktor",
    "igenkänningsfaktorns": "igenkänningsfaktor",
    "igenkänningsfaktors": "igenkänningsfaktor",
    "igenkänningssignalen": "igenkänningssignal",
    "igenkänningssignalens": "igenkänningssignal",
    "igenkänningssignaler": "igenkänningssignal",
    "igenkänningssignalerna": "igenkänningssignal",
    "igenkänningssignalernas": "igenkänningssignal",
    "igenkänningssignalers": "igenkänningssignal",
    "igenkänningssignals": "igenkänningssignal",
    "igenkänningsteckens": "igenkänningstecken",
    "igenkänningstecknen": "igenkänningstecken",
    "igenkänningstecknens": "igenkänningstecken",
    "igenkänningstecknet": "igenkänningstecken",
    "igenkänningstecknets": "igenkänningstecken",
    "igenkännliga": "igenkännlig",
    "igenkännligare": "igenkännlig",
    "igenkännligares": "igenkännlig",
    "igenkännligas": "igenkännlig",
    "igenkännligast": "igenkännlig",
    "igenkännligaste": "igenkännlig",
    "igenkännligastes": "igenkännlig",
    "igenkännligasts": "igenkännlig",
    "igenkännlige": "igenkännlig",
    "igenkännliges": "igenkännlig",
    "igenkännligheten": "igenkännlighet",
    "igenkännlighetens": "igenkännlighet",
    "igenkännlighets": "igenkännlighet",
    "igenkännligs": "igenkännlig",
    "igenkännligt": "igenkännlig",
    "igenkännligts": "igenkännlig",
    "igenkänns": "igenkänna",
    "igenkänt": "igenkänna",
    "igenkänts": "igenkänna",
    "igenmulens": "igenmulen",
    "igenmulet": "igenmulen",
    "igenmulets": "igenmulen",
    "igenmulna": "igenmulen",
    "igenmulnare": "igenmulen",
    "igenmulnares": "igenmulen",
    "igenmulnas": "igenmulen",
    "igenmulnast": "igenmulen",
    "igenmulnaste": "igenmulen",
    "igenmulnastes": "igenmulen",
    "igenmulnasts": "igenmulen",
    "igenmulne": "igenmulen",
    "igenmulnes": "igenmulen",
    "igenmurade": "igenmurad",
    "igenmurades": "igenmurad",
    "igenmurads": "igenmurad",
    "igenmurat": "igenmurad",
    "igenmurats": "igenmurad",
    "igensnöade": "igensnöad",
    "igensnöades": "igensnöad",
    "igensnöads": "igensnöad",
    "igensnöat": "igensnöad",
    "igensnöats": "igensnöad",
    "igenvuxens": "igenvuxen",
    "igenvuxet": "igenvuxen",
    "igenvuxets": "igenvuxen",
    "igenvuxna": "igenvuxen",
    "igenvuxnare": "igenvuxen",
    "igenvuxnares": "igenvuxen",
    "igenvuxnas": "igenvuxen",
    "igenvuxnast": "igenvuxen",
    "igenvuxnaste": "igenvuxen",
    "igenvuxnastes": "igenvuxen",
    "igenvuxnasts": "igenvuxen",
    "igenvuxne": "igenvuxen",
    "igenvuxnes": "igenvuxen",
    "igenväxta": "igenväxt",
    "igenväxtare": "igenväxt",
    "igenväxtares": "igenväxt",
    "igenväxtas": "igenväxt",
    "igenväxtast": "igenväxt",
    "igenväxtaste": "igenväxt",
    "igenväxtastes": "igenväxt",
    "igenväxtasts": "igenväxt",
    "igenväxte": "igenväxt",
    "igenväxtes": "igenväxt",
    "igenväxts": "igenväxt",
    "iglar": "igel",
    "iglarna": "igel",
    "iglarnas": "igel",
    "iglars": "igel",
    "igloer": "iglo",
    "igloerna": "iglo",
    "igloernas": "iglo",
    "igloers": "iglo",
    "iglon": "iglo",
    "iglons": "iglo",
    "iglooer": "igloo",
    "iglooerna": "igloo",
    "iglooernas": "igloo",
    "iglooers": "igloo",
    "igloon": "igloo",
    "igloons": "igloo",
    "igloor": "igloo",
    "igloorna": "igloo",
    "igloornas": "igloo",
    "igloors": "igloo",
    "igloos": "igloo",
    "igloosar": "igloo",
    "igloosarna": "igloo",
    "igloosarnas": "igloo",
    "igloosars": "igloo",
    "iglor": "iglo",
    "iglorna": "iglo",
    "iglornas": "iglo",
    "iglors": "iglo",
    "iglos": "iglo",
    "iglosar": "iglo",
    "iglosarna": "iglo",
    "iglosarnas": "iglo",
    "iglosars": "iglo",
    "ignoransen": "ignorans",
    "ignoransens": "ignorans",
    "ignoranta": "ignorant",
    "ignorantare": "ignorant",
    "ignorantares": "ignorant",
    "ignorantas": "ignorant",
    "ignorantast": "ignorant",
    "ignorantaste": "ignorant",
    "ignorantastes": "ignorant",
    "ignorantasts": "ignorant",
    "ignorante": "ignorant",
    "ignoranten": "ignorant",
    "ignorantens": "ignorant",
    "ignoranter": "ignorant",
    "ignoranterna": "ignorant",
    "ignoranternas": "ignorant",
    "ignoranters": "ignorant",
    "ignorantes": "ignorant",
    "ignorants": "ignorant",
    "ignorerad": "ignorera",
    "ignorerade": "ignorera",
    "ignorerades": "ignorera",
    "ignorerads": "ignorera",
    "ignorerande": "ignorera",
    "ignoreranden": "ignorerande",
    "ignorerandena": "ignorerande",
    "ignorerandenas": "ignorerande",
    "ignorerandens": "ignorerande",
    "ignorerandes": "ignorerande",
    "ignorerandet": "ignorerande",
    "ignorerandets": "ignorerande",
    "ignorerar": "ignorera",
    "ignoreras": "ignorera",
    "ignorerat": "ignorera",
    "ignorerats": "ignorera",
    "ignorerbara": "ignorerbar",
    "ignorerbarare": "ignorerbar",
    "ignorerbarares": "ignorerbar",
    "ignorerbaras": "ignorerbar",
    "ignorerbarast": "ignorerbar",
    "ignorerbaraste": "ignorerbar",
    "ignorerbarastes": "ignorerbar",
    "ignorerbarasts": "ignorerbar",
    "ignorerbare": "ignorerbar",
    "ignorerbares": "ignorerbar",
    "ignorerbarheten": "ignorerbarhet",
    "ignorerbarhetens": "ignorerbarhet",
    "ignorerbarhets": "ignorerbarhet",
    "ignorerbars": "ignorerbar",
    "ignorerbart": "ignorerbar",
    "ignorerbarts": "ignorerbar",
    "ignoreringar": "ignorering",
    "ignoreringarna": "ignorering",
    "ignoreringarnas": "ignorering",
    "ignoreringars": "ignorering",
    "ignoreringen": "ignorering",
    "ignoreringens": "ignorering",
    "ignorerings": "ignorering",
    "igångsatt": "igångsätta",
    "igångsatta": "igångsätta",
    "igångsattas": "igångsätta",
    "igångsatte": "igångsätta",
    "igångsattes": "igångsätta",
    "igångsatts": "igångsätta",
    "igångsätt": "igångsätta",
    "igångsättande": "igångsätta",
    "igångsättanden": "igångsättande",
    "igångsättandena": "igångsättande",
    "igångsättandenas": "igångsättande",
    "igångsättandens": "igångsättande",
    "igångsättandes": "igångsättande",
    "igångsättandet": "igångsättande",
    "igångsättandets": "igångsättande",
    "igångsättas": "igångsätta",
    "igångsätter": "igångsätta",
    "igångsättes": "igångsätta",
    "igångsättningar": "igångsättning",
    "igångsättningarna": "igångsättning",
    "igångsättningarnas": "igångsättning",
    "igångsättningars": "igångsättning",
    "igångsättningen": "igångsättning",
    "igångsättningens": "igångsättning",
    "igångsättnings": "igångsättning",
    "igångsätts": "igångsätta",
    "ihjälskjutens": "ihjälskjuten",
    "ihjälskjutet": "ihjälskjuten",
    "ihjälskjutets": "ihjälskjuten",
    "ihjälskjutna": "ihjälskjuten",
    "ihjälskjutnas": "ihjälskjuten",
    "ihjälskjutne": "ihjälskjuten",
    "ihjälskjutnes": "ihjälskjuten",
    "ihjälskrämde": "ihjälskrämd",
    "ihjälskrämdes": "ihjälskrämd",
    "ihjälskrämds": "ihjälskrämd",
    "ihjälskrämt": "ihjälskrämd",
    "ihjälskrämts": "ihjälskrämd",
    "ihopbuntanden": "ihopbuntande",
    "ihopbuntandena": "ihopbuntande",
    "ihopbuntandenas": "ihopbuntande",
    "ihopbuntandens": "ihopbuntande",
    "ihopbuntandes": "ihopbuntande",
    "ihopbuntandet": "ihopbuntande",
    "ihopbuntandets": "ihopbuntande",
    "ihopfällbara": "ihopfällbar",
    "ihopfällbarare": "ihopfällbar",
    "ihopfällbarares": "ihopfällbar",
    "ihopfällbaras": "ihopfällbar",
    "ihopfällbarast": "ihopfällbar",
    "ihopfällbaraste": "ihopfällbar",
    "ihopfällbarastes": "ihopfällbar",
    "ihopfällbarasts": "ihopfällbar",
    "ihopfällbare": "ihopfällbar",
    "ihopfällbares": "ihopfällbar",
    "ihopfällbarheten": "ihopfällbarhet",
    "ihopfällbarhetens": "ihopfällbarhet",
    "ihopfällbarhets": "ihopfällbarhet",
    "ihopfällbars": "ihopfällbar",
    "ihopfällbart": "ihopfällbar",
    "ihopfällbarts": "ihopfällbar",
    "ihopfällda": "ihopfälld",
    "ihopfälldare": "ihopfälld",
    "ihopfälldares": "ihopfälld",
    "ihopfälldas": "ihopfälld",
    "ihopfälldast": "ihopfälld",
    "ihopfälldaste": "ihopfälld",
    "ihopfälldastes": "ihopfälld",
    "ihopfälldasts": "ihopfälld",
    "ihopfällde": "ihopfälld",
    "ihopfälldes": "ihopfälld",
    "ihopfällds": "ihopfälld",
    "ihopfällt": "ihopfälld",
    "ihopfällts": "ihopfälld",
    "ihopknycklanden": "ihopknycklande",
    "ihopknycklandena": "ihopknycklande",
    "ihopknycklandenas": "ihopknycklande",
    "ihopknycklandens": "ihopknycklande",
    "ihopknycklandes": "ihopknycklande",
    "ihopknycklandet": "ihopknycklande",
    "ihopknycklandets": "ihopknycklande",
    "ihopkopplanden": "ihopkopplande",
    "ihopkopplandena": "ihopkopplande",
    "ihopkopplandenas": "ihopkopplande",
    "ihopkopplandens": "ihopkopplande",
    "ihopkopplandes": "ihopkopplande",
    "ihopkopplandet": "ihopkopplande",
    "ihopkopplandets": "ihopkopplande",
    "ihoplagde": "ihoplagd",
    "ihoplagdes": "ihoplagd",
    "ihoplagds": "ihoplagd",
    "ihoplagt": "ihoplagd",
    "ihoplagts": "ihoplagd",
    "ihoppackanden": "ihoppackande",
    "ihoppackandena": "ihoppackande",
    "ihoppackandenas": "ihoppackande",
    "ihoppackandens": "ihoppackande",
    "ihoppackandes": "ihoppackande",
    "ihoppackandet": "ihoppackande",
    "ihoppackandets": "ihoppackande",
    "ihopskjutanden": "ihopskjutande",
    "ihopskjutandena": "ihopskjutande",
    "ihopskjutandenas": "ihopskjutande",
    "ihopskjutandens": "ihopskjutande",
    "ihopskjutandes": "ihopskjutande",
    "ihopskjutandet": "ihopskjutande",
    "ihopskjutandets": "ihopskjutande",
    "ihärdiga": "ihärdig",
    "ihärdigare": "ihärdig",
    "ihärdigares": "ihärdig",
    "ihärdigas": "ihärdig",
    "ihärdigast": "ihärdig",
    "ihärdigaste": "ihärdig",
    "ihärdigastes": "ihärdig",
    "ihärdigasts": "ihärdig",
    "ihärdige": "ihärdig",
    "ihärdiges": "ihärdig",
    "ihärdigheten": "ihärdighet",
    "ihärdighetens": "ihärdighet",
    "ihärdighets": "ihärdighet",
    "ihärdigs": "ihärdig",
    "ihärdigt": "ihärdig",
    "ihärdigts": "ihärdig",
    "ihågkom": "ihågkomma",
    "ihågkomet": "ihågkomma",
    "ihågkomets": "ihågkomma",
    "ihågkommande": "ihågkomma",
    "ihågkommanden": "ihågkommande",
    "ihågkommandena": "ihågkommande",
    "ihågkommandenas": "ihågkommande",
    "ihågkommandens": "ihågkommande",
    "ihågkommandes": "ihågkommande",
    "ihågkommandet": "ihågkommande",
    "ihågkommandets": "ihågkommande",
    "ihågkommas": "ihågkomma",
    "ihågkomme": "ihågkomma",
    "ihågkommen": "ihågkomma",
    "ihågkommens": "ihågkomma",
    "ihågkommer": "ihågkomma",
    "ihågkommes": "ihågkomma",
    "ihågkommit": "ihågkomma",
    "ihågkommits": "ihågkomma",
    "ihågkomna": "ihågkomma",
    "ihågkomnas": "ihågkomma",
    "ihågkomne": "ihågkomma",
    "ihågkomnes": "ihågkomma",
    "ihågkoms": "ihågkomma",
    "ihågkomsten": "ihågkomst",
    "ihågkomstens": "ihågkomst",
    "ihågkomster": "ihågkomst",
    "ihågkomsterna": "ihågkomst",
    "ihågkomsternas": "ihågkomst",
    "ihågkomsters": "ihågkomst",
    "ihågkomsts": "ihågkomst",
    "ihåliga": "ihålig",
    "ihåligare": "ihålig",
    "ihåligares": "ihålig",
    "ihåligas": "ihålig",
    "ihåligast": "ihålig",
    "ihåligaste": "ihålig",
    "ihåligastes": "ihålig",
    "ihåligasts": "ihålig",
    "ihålige": "ihålig",
    "ihåliges": "ihålig",
    "ihåligheten": "ihålighet",
    "ihålighetens": "ihålighet",
    "ihåligheter": "ihålighet",
    "ihåligheterna": "ihålighet",
    "ihåligheternas": "ihålighet",
    "ihåligheters": "ihålighet",
    "ihålighets": "ihålighet",
    "ihåligs": "ihålig",
    "ihåligt": "ihålig",
    "ihåligts": "ihålig",
    "ikaten": "ikat",
    "ikatens": "ikat",
    "ikats": "ikat",
    "ikläd": "iklä",
    "ikläda": "iklä",
    "iklädande": "iklä",
    "iklädanden": "iklädande",
    "iklädandena": "iklädande",
    "iklädandenas": "iklädande",
    "iklädandens": "iklädande",
    "iklädandes": "iklädande",
    "iklädandet": "iklädande",
    "iklädandets": "iklädande",
    "iklädas": "iklä",
    "iklädd": "iklä",
    "iklädda": "iklä",
    "ikläddas": "iklä",
    "iklädde": "iklä",
    "ikläddes": "iklä",
    "iklädds": "iklä",
    "ikläder": "iklä",
    "ikläds": "iklä",
    "ikläende": "iklä",
    "ikläendes": "iklä",
    "iklär": "iklä",
    "ikläs": "iklä",
    "iklätt": "iklä",
    "iklätts": "iklä",
    "ikonen": "ikon",
    "ikonens": "ikon",
    "ikoner": "ikon",
    "ikonerna": "ikon",
    "ikonernas": "ikon",
    "ikoners": "ikon",
    "ikoniska": "ikonisk",
    "ikoniskare": "ikonisk",
    "ikoniskares": "ikonisk",
    "ikoniskas": "ikonisk",
    "ikoniskast": "ikonisk",
    "ikoniskaste": "ikonisk",
    "ikoniskastes": "ikonisk",
    "ikoniskasts": "ikonisk",
    "ikoniske": "ikonisk",
    "ikoniskes": "ikonisk",
    "ikonisks": "ikonisk",
    "ikoniskt": "ikonisk",
    "ikoniskts": "ikonisk",
    "ikonografien": "ikonografi",
    "ikonografiens": "ikonografi",
    "ikonografin": "ikonografi",
    "ikonografins": "ikonografi",
    "ikonografis": "ikonografi",
    "ikonostasen": "ikonostas",
    "ikonostasens": "ikonostas",
    "ikonostaser": "ikonostas",
    "ikonostaserna": "ikonostas",
    "ikonostasernas": "ikonostas",
    "ikonostasers": "ikonostas",
    "ikons": "ikon",
    "ikosaedern": "ikosaeder",
    "ikosaederns": "ikosaeder",
    "ikosaeders": "ikosaeder",
    "ikosaedrar": "ikosaeder",
    "ikosaedrarna": "ikosaeder",
    "ikosaedrarnas": "ikosaeder",
    "ikosaedrars": "ikosaeder",
    "iktusen": "iktus",
    "iktusens": "iktus",
    "iktyologen": "iktyolog",
    "iktyologens": "iktyolog",
    "iktyologer": "iktyolog",
    "iktyologerna": "iktyolog",
    "iktyologernas": "iktyolog",
    "iktyologers": "iktyolog",
    "iktyologien": "iktyologi",
    "iktyologiens": "iktyologi",
    "iktyologin": "iktyologi",
    "iktyologins": "iktyologi",
    "iktyologis": "iktyologi",
    "iktyologiska": "iktyologisk",
    "iktyologiskare": "iktyologisk",
    "iktyologiskares": "iktyologisk",
    "iktyologiskas": "iktyologisk",
    "iktyologiskast": "iktyologisk",
    "iktyologiskaste": "iktyologisk",
    "iktyologiskastes": "iktyologisk",
    "iktyologiskasts": "iktyologisk",
    "iktyologiske": "iktyologisk",
    "iktyologiskes": "iktyologisk",
    "iktyologisks": "iktyologisk",
    "iktyologiskt": "iktyologisk",
    "iktyologiskts": "iktyologisk",
    "iktyologs": "iktyolog",
    "ilade": "ila",
    "ilades": "ila",
    "ilande": "ila",
    "ilanden": "ilande",
    "ilandena": "ilande",
    "ilandenas": "ilande",
    "ilandens": "ilande",
    "ilandes": "ilande",
    "ilandet": "ilande",
    "ilandets": "ilande",
    "ilandflutens": "ilandfluten",
    "ilandflutet": "ilandfluten",
    "ilandflutets": "ilandfluten",
    "ilandflutna": "ilandfluten",
    "ilandflutnas": "ilandfluten",
    "ilandflutne": "ilandfluten",
    "ilandflutnes": "ilandfluten",
    "ilandsatt": "ilandsätta",
    "ilandsatta": "ilandsätta",
    "ilandsattas": "ilandsätta",
    "ilandsatte": "ilandsätta",
    "ilandsattes": "ilandsätta",
    "ilandsatts": "ilandsätta",
    "ilandsätt": "ilandsätta",
    "ilandsättande": "ilandsätta",
    "ilandsättanden": "ilandsättande",
    "ilandsättandena": "ilandsättande",
    "ilandsättandenas": "ilandsättande",
    "ilandsättandens": "ilandsättande",
    "ilandsättandes": "ilandsättande",
    "ilandsättandet": "ilandsättande",
    "ilandsättandets": "ilandsättande",
    "ilandsättas": "ilandsätta",
    "ilandsätter": "ilandsätta",
    "ilandsättes": "ilandsätta",
    "ilandsätts": "ilandsätta",
    "ilar": "ila",
    "ilarna": "il",
    "ilarnas": "il",
    "ilars": "il",
    "ilas": "ila",
    "ilat": "ila",
    "ilats": "ila",
    "ilbuden": "ilbud",
    "ilbudens": "ilbud",
    "ilbudet": "ilbud",
    "ilbudets": "ilbud",
    "ilbuds": "ilbud",
    "ilen": "il",
    "ilens": "il",
    "ilexar": "ilex",
    "ilexarna": "ilex",
    "ilexarnas": "ilex",
    "ilexars": "ilex",
    "ilexen": "ilex",
    "ilexens": "ilex",
    "ilgodset": "ilgods",
    "ilgodsets": "ilgods",
    "illamåendes": "illamående",
    "illamåendet": "illamående",
    "illamåendets": "illamående",
    "illasinnade": "illasinnad",
    "illasinnades": "illasinnad",
    "illasinnads": "illasinnad",
    "illasinnat": "illasinnad",
    "illasinnats": "illasinnad",
    "illavulenheten": "illavulenhet",
    "illavulenhetens": "illavulenhet",
    "illavulenhets": "illavulenhet",
    "illavulens": "illavulen",
    "illavulet": "illavulen",
    "illavulets": "illavulen",
    "illavulna": "illavulen",
    "illavulnare": "illavulen",
    "illavulnares": "illavulen",
    "illavulnas": "illavulen",
    "illavulnast": "illavulen",
    "illavulnaste": "illavulen",
    "illavulnastes": "illavulen",
    "illavulnasts": "illavulen",
    "illavulne": "illavulen",
    "illavulnes": "illavulen",
    "illbattingar": "illbatting",
    "illbattingarna": "illbatting",
    "illbattingarnas": "illbatting",
    "illbattingars": "illbatting",
    "illbattingen": "illbatting",
    "illbattingens": "illbatting",
    "illbattings": "illbatting",
    "illdåden": "illdåd",
    "illdådens": "illdåd",
    "illdådet": "illdåd",
    "illdådets": "illdåd",
    "illdåds": "illdåd",
    "illegala": "illegal",
    "illegalare": "illegal",
    "illegalares": "illegal",
    "illegalas": "illegal",
    "illegalast": "illegal",
    "illegalaste": "illegal",
    "illegalastes": "illegal",
    "illegalasts": "illegal",
    "illegale": "illegal",
    "illegales": "illegal",
    "illegals": "illegal",
    "illegalt": "illegal",
    "illegalts": "illegal",
    "illegitima": "illegitim",
    "illegitimare": "illegitim",
    "illegitimares": "illegitim",
    "illegitimas": "illegitim",
    "illegitimast": "illegitim",
    "illegitimaste": "illegitim",
    "illegitimastes": "illegitim",
    "illegitimasts": "illegitim",
    "illegitime": "illegitim",
    "illegitimes": "illegitim",
    "illegitims": "illegitim",
    "illegitimt": "illegitim",
    "illegitimts": "illegitim",
    "illern": "iller",
    "illerns": "iller",
    "illers": "iller",
    "illfundiga": "illfundig",
    "illfundigare": "illfundig",
    "illfundigares": "illfundig",
    "illfundigas": "illfundig",
    "illfundigast": "illfundig",
    "illfundigaste": "illfundig",
    "illfundigastes": "illfundig",
    "illfundigasts": "illfundig",
    "illfundige": "illfundig",
    "illfundiges": "illfundig",
    "illfundigheten": "illfundighet",
    "illfundighetens": "illfundighet",
    "illfundighets": "illfundighet",
    "illfundigs": "illfundig",
    "illfundigt": "illfundig",
    "illfundigts": "illfundig",
    "illfänades": "illfänas",
    "illfänats": "illfänas",
    "illgärningar": "illgärning",
    "illgärningarna": "illgärning",
    "illgärningarnas": "illgärning",
    "illgärningars": "illgärning",
    "illgärningen": "illgärning",
    "illgärningens": "illgärning",
    "illgärnings": "illgärning",
    "illgärningsmannen": "illgärningsman",
    "illgärningsmannens": "illgärningsman",
    "illgärningsmans": "illgärningsman",
    "illgärningsmän": "illgärningsman",
    "illgärningsmännen": "illgärningsman",
    "illgärningsmännens": "illgärningsman",
    "illgärningsmäns": "illgärningsman",
    "illistiga": "illistig",
    "illistigare": "illistig",
    "illistigares": "illistig",
    "illistigas": "illistig",
    "illistigast": "illistig",
    "illistigaste": "illistig",
    "illistigastes": "illistig",
    "illistigasts": "illistig",
    "illistige": "illistig",
    "illistiges": "illistig",
    "illistigheten": "illistighet",
    "illistighetens": "illistighet",
    "illistighets": "illistighet",
    "illistigs": "illistig",
    "illistigt": "illistig",
    "illistigts": "illistig",
    "illitterata": "illitterat",
    "illitteratare": "illitterat",
    "illitteratares": "illitterat",
    "illitteratas": "illitterat",
    "illitteratast": "illitterat",
    "illitterataste": "illitterat",
    "illitteratastes": "illitterat",
    "illitteratasts": "illitterat",
    "illitterate": "illitterat",
    "illitterates": "illitterat",
    "illitterats": "illitterat",
    "illmariga": "illmarig",
    "illmarigare": "illmarig",
    "illmarigares": "illmarig",
    "illmarigas": "illmarig",
    "illmarigast": "illmarig",
    "illmarigaste": "illmarig",
    "illmarigastes": "illmarig",
    "illmarigasts": "illmarig",
    "illmarige": "illmarig",
    "illmariges": "illmarig",
    "illmarigheten": "illmarighet",
    "illmarighetens": "illmarighet",
    "illmarighets": "illmarighet",
    "illmarigs": "illmarig",
    "illmarigt": "illmarig",
    "illmarigts": "illmarig",
    "illojala": "illojal",
    "illojalare": "illojal",
    "illojalares": "illojal",
    "illojalas": "illojal",
    "illojalast": "illojal",
    "illojalaste": "illojal",
    "illojalastes": "illojal",
    "illojalasts": "illojal",
    "illojale": "illojal",
    "illojales": "illojal",
    "illojals": "illojal",
    "illojalt": "illojal",
    "illojalts": "illojal",
    "illpariga": "illparig",
    "illparigare": "illparig",
    "illparigares": "illparig",
    "illparigas": "illparig",
    "illparigast": "illparig",
    "illparigaste": "illparig",
    "illparigastes": "illparig",
    "illparigasts": "illparig",
    "illparige": "illparig",
    "illpariges": "illparig",
    "illparigheten": "illparighet",
    "illparighetens": "illparighet",
    "illparighets": "illparighet",
    "illparigs": "illparig",
    "illparigt": "illparig",
    "illparigts": "illparig",
    "illrar": "iller",
    "illrarna": "iller",
    "illrarnas": "iller",
    "illrars": "iller",
    "illröda": "illröd",
    "illrödare": "illröd",
    "illrödares": "illröd",
    "illrödas": "illröd",
    "illrödast": "illröd",
    "illrödaste": "illröd",
    "illrödastes": "illröd",
    "illrödasts": "illröd",
    "illröde": "illröd",
    "illrödes": "illröd",
    "illröds": "illröd",
    "illrött": "illröd",
    "illrötts": "illröd",
    "illtjut": "illtjuta",
    "illtjutande": "illtjuta",
    "illtjutanden": "illtjutande",
    "illtjutandena": "illtjutande",
    "illtjutandenas": "illtjutande",
    "illtjutandens": "illtjutande",
    "illtjutandes": "illtjutande",
    "illtjutandet": "illtjutande",
    "illtjutandets": "illtjutande",
    "illtjutas": "illtjuta",
    "illtjute": "illtjuta",
    "illtjuten": "illtjut",
    "illtjutens": "illtjut",
    "illtjuter": "illtjuta",
    "illtjutes": "illtjuta",
    "illtjutet": "illtjut",
    "illtjutets": "illtjut",
    "illtjutit": "illtjuta",
    "illtjutits": "illtjuta",
    "illtjuts": "illtjuta",
    "illtjöt": "illtjuta",
    "illtjöte": "illtjuta",
    "illtjötes": "illtjuta",
    "illtjöts": "illtjuta",
    "illuderade": "illudera",
    "illuderades": "illudera",
    "illuderande": "illudera",
    "illuderanden": "illuderande",
    "illuderandena": "illuderande",
    "illuderandenas": "illuderande",
    "illuderandens": "illuderande",
    "illuderandes": "illuderande",
    "illuderandet": "illuderande",
    "illuderandets": "illuderande",
    "illuderar": "illudera",
    "illuderas": "illudera",
    "illuderat": "illudera",
    "illuderats": "illudera",
    "illuderingar": "illudering",
    "illuderingarna": "illudering",
    "illuderingarnas": "illudering",
    "illuderingars": "illudering",
    "illuderingen": "illudering",
    "illuderingens": "illudering",
    "illuderings": "illudering",
    "illuminationen": "illumination",
    "illuminationens": "illumination",
    "illuminationer": "illumination",
    "illuminationerna": "illumination",
    "illuminationernas": "illumination",
    "illuminationers": "illumination",
    "illuminations": "illumination",
    "illuminerad": "illuminera",
    "illuminerade": "illuminera",
    "illuminerades": "illuminera",
    "illuminerads": "illuminera",
    "illuminerande": "illuminera",
    "illumineranden": "illuminerande",
    "illuminerandena": "illuminerande",
    "illuminerandenas": "illuminerande",
    "illuminerandens": "illuminerande",
    "illuminerandes": "illuminerande",
    "illuminerandet": "illuminerande",
    "illuminerandets": "illuminerande",
    "illuminerar": "illuminera",
    "illumineras": "illuminera",
    "illuminerat": "illuminera",
    "illuminerats": "illuminera",
    "illuminerbara": "illuminerbar",
    "illuminerbarare": "illuminerbar",
    "illuminerbarares": "illuminerbar",
    "illuminerbaras": "illuminerbar",
    "illuminerbarast": "illuminerbar",
    "illuminerbaraste": "illuminerbar",
    "illuminerbarastes": "illuminerbar",
    "illuminerbarasts": "illuminerbar",
    "illuminerbare": "illuminerbar",
    "illuminerbares": "illuminerbar",
    "illuminerbarheten": "illuminerbarhet",
    "illuminerbarhetens": "illuminerbarhet",
    "illuminerbarhets": "illuminerbarhet",
    "illuminerbars": "illuminerbar",
    "illuminerbart": "illuminerbar",
    "illuminerbarts": "illuminerbar",
    "illumineringar": "illuminering",
    "illumineringarna": "illuminering",
    "illumineringarnas": "illuminering",
    "illumineringars": "illuminering",
    "illumineringen": "illuminering",
    "illumineringens": "illuminering",
    "illuminerings": "illuminering",
    "illusionen": "illusion",
    "illusionens": "illusion",
    "illusioner": "illusion",
    "illusionerna": "illusion",
    "illusionernas": "illusion",
    "illusioners": "illusion",
    "illusionisten": "illusionist",
    "illusionistens": "illusionist",
    "illusionister": "illusionist",
    "illusionisterna": "illusionist",
    "illusionisternas": "illusionist",
    "illusionisters": "illusionist",
    "illusionists": "illusionist",
    "illusions": "illusion",
    "illusionsfria": "illusionsfri",
    "illusionsfriare": "illusionsfri",
    "illusionsfriares": "illusionsfri",
    "illusionsfrias": "illusionsfri",
    "illusionsfriast": "illusionsfri",
    "illusionsfriaste": "illusionsfri",
    "illusionsfriastes": "illusionsfri",
    "illusionsfriasts": "illusionsfri",
    "illusionsfrie": "illusionsfri",
    "illusionsfries": "illusionsfri",
    "illusionsfris": "illusionsfri",
    "illusionsfritt": "illusionsfri",
    "illusionsfritts": "illusionsfri",
    "illusionslösa": "illusionslös",
    "illusionslösare": "illusionslös",
    "illusionslösares": "illusionslös",
    "illusionslösas": "illusionslös",
    "illusionslösast": "illusionslös",
    "illusionslösaste": "illusionslös",
    "illusionslösastes": "illusionslös",
    "illusionslösasts": "illusionslös",
    "illusionslöse": "illusionslös",
    "illusionslöses": "illusionslös",
    "illusionslösheten": "illusionslöshet",
    "illusionslöshetens": "illusionslöshet",
    "illusionslösheter": "illusionslöshet",
    "illusionslösheterna": "illusionslöshet",
    "illusionslösheternas": "illusionslöshet",
    "illusionslösheters": "illusionslöshet",
    "illusionslöshets": "illusionslöshet",
    "illusionslöst": "illusionslös",
    "illusionslösts": "illusionslös",
    "illusionsnummerna": "illusionsnummer",
    "illusionsnummernas": "illusionsnummer",
    "illusionsnummers": "illusionsnummer",
    "illusionsnumren": "illusionsnummer",
    "illusionsnumrens": "illusionsnummer",
    "illusionsnumret": "illusionsnummer",
    "illusionsnumrets": "illusionsnummer",
    "illusoriska": "illusorisk",
    "illusoriskare": "illusorisk",
    "illusoriskares": "illusorisk",
    "illusoriskas": "illusorisk",
    "illusoriskast": "illusorisk",
    "illusoriskaste": "illusorisk",
    "illusoriskastes": "illusorisk",
    "illusoriskasts": "illusorisk",
    "illusoriske": "illusorisk",
    "illusoriskes": "illusorisk",
    "illusorisks": "illusorisk",
    "illusoriskt": "illusorisk",
    "illusoriskts": "illusorisk",
    "illusters": "illuster",
    "illustert": "illuster",
    "illusterts": "illuster",
    "illustra": "illuster",
    "illustrare": "illuster",
    "illustrares": "illuster",
    "illustras": "illuster",
    "illustrast": "illuster",
    "illustraste": "illuster",
    "illustrastes": "illuster",
    "illustrasts": "illuster",
    "illustrationen": "illustration",
    "illustrationens": "illustration",
    "illustrationer": "illustration",
    "illustrationerna": "illustration",
    "illustrationernas": "illustration",
    "illustrationers": "illustration",
    "illustrations": "illustration",
    "illustrativa": "illustrativ",
    "illustrativare": "illustrativ",
    "illustrativares": "illustrativ",
    "illustrativas": "illustrativ",
    "illustrativast": "illustrativ",
    "illustrativaste": "illustrativ",
    "illustrativastes": "illustrativ",
    "illustrativasts": "illustrativ",
    "illustrative": "illustrativ",
    "illustratives": "illustrativ",
    "illustrativs": "illustrativ",
    "illustrativt": "illustrativ",
    "illustrativts": "illustrativ",
    "illustratören": "illustratör",
    "illustratörens": "illustratör",
    "illustratörer": "illustratör",
    "illustratörerna": "illustratör",
    "illustratörernas": "illustratör",
    "illustratörers": "illustratör",
    "illustratörs": "illustratör",
    "illustre": "illuster",
    "illustrerad": "illustrera",
    "illustrerade": "illustrera",
    "illustrerades": "illustrera",
    "illustrerads": "illustrera",
    "illustrerande": "illustrera",
    "illustreranden": "illustrerande",
    "illustrerandena": "illustrerande",
    "illustrerandenas": "illustrerande",
    "illustrerandens": "illustrerande",
    "illustrerandes": "illustrerande",
    "illustrerandet": "illustrerande",
    "illustrerandets": "illustrerande",
    "illustrerar": "illustrera",
    "illustreras": "illustrera",
    "illustrerat": "illustrera",
    "illustrerats": "illustrera",
    "illustrerbara": "illustrerbar",
    "illustrerbarare": "illustrerbar",
    "illustrerbarares": "illustrerbar",
    "illustrerbaras": "illustrerbar",
    "illustrerbarast": "illustrerbar",
    "illustrerbaraste": "illustrerbar",
    "illustrerbarastes": "illustrerbar",
    "illustrerbarasts": "illustrerbar",
    "illustrerbare": "illustrerbar",
    "illustrerbares": "illustrerbar",
    "illustrerbarheten": "illustrerbarhet",
    "illustrerbarhetens": "illustrerbarhet",
    "illustrerbarhets": "illustrerbarhet",
    "illustrerbars": "illustrerbar",
    "illustrerbart": "illustrerbar",
    "illustrerbarts": "illustrerbar",
    "illustreringar": "illustrering",
    "illustreringarna": "illustrering",
    "illustreringarnas": "illustrering",
    "illustreringars": "illustrering",
    "illustreringen": "illustrering",
    "illustreringens": "illustrering",
    "illustrerings": "illustrering",
    "illustres": "illuster",
    "illviljan": "illvilja",
    "illviljans": "illvilja",
    "illviljas": "illvilja",
    "illvilliga": "illvillig",
    "illvilligare": "illvillig",
    "illvilligares": "illvillig",
    "illvilligas": "illvillig",
    "illvilligast": "illvillig",
    "illvilligaste": "illvillig",
    "illvilligastes": "illvillig",
    "illvilligasts": "illvillig",
    "illvillige": "illvillig",
    "illvilliges": "illvillig",
    "illvilligheten": "illvillighet",
    "illvillighetens": "illvillighet",
    "illvilligheter": "illvillighet",
    "illvilligheterna": "illvillighet",
    "illvilligheternas": "illvillighet",
    "illvilligheters": "illvillighet",
    "illvillighets": "illvillighet",
    "illvilligs": "illvillig",
    "illvilligt": "illvillig",
    "illvilligts": "illvillig",
    "illvrålade": "illvråla",
    "illvrålades": "illvråla",
    "illvrålande": "illvråla",
    "illvrålanden": "illvrålande",
    "illvrålandena": "illvrålande",
    "illvrålandenas": "illvrålande",
    "illvrålandens": "illvrålande",
    "illvrålandes": "illvrålande",
    "illvrålandet": "illvrålande",
    "illvrålandets": "illvrålande",
    "illvrålar": "illvråla",
    "illvrålas": "illvråla",
    "illvrålat": "illvråla",
    "illvrålats": "illvråla",
    "illvrålen": "illvrål",
    "illvrålens": "illvrål",
    "illvrålet": "illvrål",
    "illvrålets": "illvrål",
    "illvråls": "illvrål",
    "illyren": "illyr",
    "illyrens": "illyr",
    "illyrer": "illyr",
    "illyrerna": "illyr",
    "illyrernas": "illyr",
    "illyrers": "illyr",
    "illyriska": "illyrisk",
    "illyriskare": "illyrisk",
    "illyriskares": "illyrisk",
    "illyriskas": "illyrisk",
    "illyriskast": "illyrisk",
    "illyriskaste": "illyrisk",
    "illyriskastes": "illyrisk",
    "illyriskasts": "illyrisk",
    "illyriske": "illyrisk",
    "illyriskes": "illyrisk",
    "illyrisks": "illyrisk",
    "illyriskt": "illyrisk",
    "illyriskts": "illyrisk",
    "illyrs": "illyr",
    "ilmarschen": "ilmarsch",
    "ilmarschens": "ilmarsch",
    "ilmarscher": "ilmarsch",
    "ilmarscherna": "ilmarsch",
    "ilmarschernas": "ilmarsch",
    "ilmarschers": "ilmarsch",
    "ilmarschs": "ilmarsch",
    "ilningar": "ilning",
    "ilningarna": "ilning",
    "ilningarnas": "ilning",
    "ilningars": "ilning",
    "ilningen": "ilning",
    "ilningens": "ilning",
    "ilnings": "ilning",
    "ils": "il",
    "ilsamtalen": "ilsamtal",
    "ilsamtalens": "ilsamtal",
    "ilsamtalet": "ilsamtal",
    "ilsamtalets": "ilsamtal",
    "ilsamtals": "ilsamtal",
    "ilska": "ilsk",
    "ilskan": "ilska",
    "ilskans": "ilska",
    "ilskare": "ilsk",
    "ilskares": "ilsk",
    "ilskas": "ilska",
    "ilskast": "ilsk",
    "ilskaste": "ilsk",
    "ilskastes": "ilsk",
    "ilskasts": "ilsk",
    "ilske": "ilsk",
    "ilskenheten": "ilskenhet",
    "ilskenhetens": "ilskenhet",
    "ilskenhets": "ilskenhet",
    "ilskens": "ilsken",
    "ilskes": "ilsk",
    "ilsket": "ilsken",
    "ilskets": "ilsken",
    "ilskheten": "ilskhet",
    "ilskhetens": "ilskhet",
    "ilskhets": "ilskhet",
    "ilskna": "ilsken",
    "ilsknare": "ilsken",
    "ilsknares": "ilsken",
    "ilsknas": "ilsken",
    "ilsknast": "ilsken",
    "ilsknaste": "ilsken",
    "ilsknastes": "ilsken",
    "ilsknasts": "ilsken",
    "ilskne": "ilsken",
    "ilsknes": "ilsken",
    "ilsks": "ilsk",
    "ilskt": "ilsk",
    "ilskts": "ilsk",
    "imagemässiga": "imagemässig",
    "imagemässigare": "imagemässig",
    "imagemässigares": "imagemässig",
    "imagemässigas": "imagemässig",
    "imagemässigast": "imagemässig",
    "imagemässigaste": "imagemässig",
    "imagemässigastes": "imagemässig",
    "imagemässigasts": "imagemässig",
    "imagemässige": "imagemässig",
    "imagemässiges": "imagemässig",
    "imagemässigs": "imagemässig",
    "imagemässigt": "imagemässig",
    "imagemässigts": "imagemässig",
    "imagen": "image",
    "imagens": "image",
    "images": "image",
    "imaginära": "imaginär",
    "imaginärare": "imaginär",
    "imaginärares": "imaginär",
    "imaginäras": "imaginär",
    "imaginärast": "imaginär",
    "imaginäraste": "imaginär",
    "imaginärastes": "imaginär",
    "imaginärasts": "imaginär",
    "imaginäre": "imaginär",
    "imaginäres": "imaginär",
    "imaginärs": "imaginär",
    "imaginärt": "imaginär",
    "imaginärts": "imaginär",
    "imbecilla": "imbecill",
    "imbecillare": "imbecill",
    "imbecillares": "imbecill",
    "imbecillas": "imbecill",
    "imbecillast": "imbecill",
    "imbecillaste": "imbecill",
    "imbecillastes": "imbecill",
    "imbecillasts": "imbecill",
    "imbecille": "imbecill",
    "imbecilles": "imbecill",
    "imbecillheten": "imbecillhet",
    "imbecillhetens": "imbecillhet",
    "imbecillhets": "imbecillhet",
    "imbecills": "imbecill",
    "imbecillt": "imbecill",
    "imbecillts": "imbecill",
    "imitationen": "imitation",
    "imitationens": "imitation",
    "imitationer": "imitation",
    "imitationerna": "imitation",
    "imitationernas": "imitation",
    "imitationers": "imitation",
    "imitations": "imitation",
    "imitatören": "imitatör",
    "imitatörens": "imitatör",
    "imitatörer": "imitatör",
    "imitatörerna": "imitatör",
    "imitatörernas": "imitatör",
    "imitatörers": "imitatör",
    "imitatörs": "imitatör",
    "imiterad": "imitera",
    "imiterade": "imitera",
    "imiterades": "imitera",
    "imiterads": "imitera",
    "imiterande": "imitera",
    "imiteranden": "imiterande",
    "imiterandena": "imiterande",
    "imiterandenas": "imiterande",
    "imiterandens": "imiterande",
    "imiterandes": "imiterande",
    "imiterandet": "imiterande",
    "imiterandets": "imiterande",
    "imiterar": "imitera",
    "imiteras": "imitera",
    "imiterat": "imitera",
    "imiterats": "imitera",
    "imiterbara": "imiterbar",
    "imiterbarare": "imiterbar",
    "imiterbarares": "imiterbar",
    "imiterbaras": "imiterbar",
    "imiterbarast": "imiterbar",
    "imiterbaraste": "imiterbar",
    "imiterbarastes": "imiterbar",
    "imiterbarasts": "imiterbar",
    "imiterbare": "imiterbar",
    "imiterbares": "imiterbar",
    "imiterbarheten": "imiterbarhet",
    "imiterbarhetens": "imiterbarhet",
    "imiterbarhets": "imiterbarhet",
    "imiterbars": "imiterbar",
    "imiterbart": "imiterbar",
    "imiterbarts": "imiterbar",
    "imiteringar": "imitering",
    "imiteringarna": "imitering",
    "imiteringarnas": "imitering",
    "imiteringars": "imitering",
    "imiteringen": "imitering",
    "imiteringens": "imitering",
    "imiterings": "imitering",
    "immade": "imma",
    "immades": "imma",
    "imman": "imma",
    "immande": "imma",
    "immanden": "immande",
    "immandena": "immande",
    "immandenas": "immande",
    "immandens": "immande",
    "immandes": "immande",
    "immandet": "immande",
    "immandets": "immande",
    "immanensen": "immanens",
    "immanensens": "immanens",
    "immanenta": "immanent",
    "immanentare": "immanent",
    "immanentares": "immanent",
    "immanentas": "immanent",
    "immanentast": "immanent",
    "immanentaste": "immanent",
    "immanentastes": "immanent",
    "immanentasts": "immanent",
    "immanente": "immanent",
    "immanentes": "immanent",
    "immanents": "immanent",
    "immans": "imma",
    "immar": "imma",
    "immas": "imma",
    "immat": "imma",
    "immaterialrätten": "immaterialrätt",
    "immaterialrättens": "immaterialrätt",
    "immaterialrätts": "immaterialrätt",
    "immateriella": "immateriell",
    "immateriellare": "immateriell",
    "immateriellares": "immateriell",
    "immateriellas": "immateriell",
    "immateriellast": "immateriell",
    "immateriellaste": "immateriell",
    "immateriellastes": "immateriell",
    "immateriellasts": "immateriell",
    "immaterielle": "immateriell",
    "immaterielles": "immateriell",
    "immateriells": "immateriell",
    "immateriellt": "immateriell",
    "immateriellts": "immateriell",
    "immatrikulationen": "immatrikulation",
    "immatrikulationens": "immatrikulation",
    "immatrikulationer": "immatrikulation",
    "immatrikulationerna": "immatrikulation",
    "immatrikulationernas": "immatrikulation",
    "immatrikulationers": "immatrikulation",
    "immatrikulations": "immatrikulation",
    "immatrikulerad": "immatrikulera",
    "immatrikulerade": "immatrikulera",
    "immatrikulerades": "immatrikulera",
    "immatrikulerads": "immatrikulera",
    "immatrikulerande": "immatrikulera",
    "immatrikuleranden": "immatrikulerande",
    "immatrikulerandena": "immatrikulerande",
    "immatrikulerandenas": "immatrikulerande",
    "immatrikulerandens": "immatrikulerande",
    "immatrikulerandes": "immatrikulerande",
    "immatrikulerandet": "immatrikulerande",
    "immatrikulerandets": "immatrikulerande",
    "immatrikulerar": "immatrikulera",
    "immatrikuleras": "immatrikulera",
    "immatrikulerat": "immatrikulera",
    "immatrikulerats": "immatrikulera",
    "immatrikulerbara": "immatrikulerbar",
    "immatrikulerbarare": "immatrikulerbar",
    "immatrikulerbarares": "immatrikulerbar",
    "immatrikulerbaras": "immatrikulerbar",
    "immatrikulerbarast": "immatrikulerbar",
    "immatrikulerbaraste": "immatrikulerbar",
    "immatrikulerbarastes": "immatrikulerbar",
    "immatrikulerbarasts": "immatrikulerbar",
    "immatrikulerbare": "immatrikulerbar",
    "immatrikulerbares": "immatrikulerbar",
    "immatrikulerbarheten": "immatrikulerbarhet",
    "immatrikulerbarhetens": "immatrikulerbarhet",
    "immatrikulerbarhets": "immatrikulerbarhet",
    "immatrikulerbars": "immatrikulerbar",
    "immatrikulerbart": "immatrikulerbar",
    "immatrikulerbarts": "immatrikulerbar",
    "immatrikuleringar": "immatrikulering",
    "immatrikuleringarna": "immatrikulering",
    "immatrikuleringarnas": "immatrikulering",
    "immatrikuleringars": "immatrikulering",
    "immatrikuleringen": "immatrikulering",
    "immatrikuleringens": "immatrikulering",
    "immatrikulerings": "immatrikulering",
    "immats": "imma",
    "immiga": "immig",
    "immigare": "immig",
    "immigares": "immig",
    "immigas": "immig",
    "immigast": "immig",
    "immigaste": "immig",
    "immigastes": "immig",
    "immigasts": "immig",
    "immige": "immig",
    "immiges": "immig",
    "immigheten": "immighet",
    "immighetens": "immighet",
    "immighets": "immighet",
    "immigranten": "immigrant",
    "immigrantens": "immigrant",
    "immigranter": "immigrant",
    "immigranterna": "immigrant",
    "immigranternas": "immigrant",
    "immigranters": "immigrant",
    "immigrants": "immigrant",
    "immigrationen": "immigration",
    "immigrationens": "immigration",
    "immigrationer": "immigration",
    "immigrationerna": "immigration",
    "immigrationernas": "immigration",
    "immigrationers": "immigration",
    "immigrations": "immigration",
    "immigrerad": "immigrera",
    "immigrerade": "immigrera",
    "immigrerades": "immigrera",
    "immigrerads": "immigrera",
    "immigrerande": "immigrera",
    "immigreranden": "immigrerande",
    "immigrerandena": "immigrerande",
    "immigrerandenas": "immigrerande",
    "immigrerandens": "immigrerande",
    "immigrerandes": "immigrerande",
    "immigrerandet": "immigrerande",
    "immigrerandets": "immigrerande",
    "immigrerar": "immigrera",
    "immigreras": "immigrera",
    "immigrerat": "immigrera",
    "immigrerats": "immigrera",
    "immigrerbara": "immigrerbar",
    "immigrerbarare": "immigrerbar",
    "immigrerbarares": "immigrerbar",
    "immigrerbaras": "immigrerbar",
    "immigrerbarast": "immigrerbar",
    "immigrerbaraste": "immigrerbar",
    "immigrerbarastes": "immigrerbar",
    "immigrerbarasts": "immigrerbar",
    "immigrerbare": "immigrerbar",
    "immigrerbares": "immigrerbar",
    "immigrerbarheten": "immigrerbarhet",
    "immigrerbarhetens": "immigrerbarhet",
    "immigrerbarhets": "immigrerbarhet",
    "immigrerbars": "immigrerbar",
    "immigrerbart": "immigrerbar",
    "immigrerbarts": "immigrerbar",
    "immigreringar": "immigrering",
    "immigreringarna": "immigrering",
    "immigreringarnas": "immigrering",
    "immigreringars": "immigrering",
    "immigreringen": "immigrering",
    "immigreringens": "immigrering",
    "immigrerings": "immigrering",
    "immigs": "immig",
    "immigt": "immig",
    "immigts": "immig",
    "immissionen": "immission",
    "immissionens": "immission",
    "immissioner": "immission",
    "immissionerna": "immission",
    "immissionernas": "immission",
    "immissioners": "immission",
    "immissions": "immission",
    "immobila": "immobil",
    "immobilare": "immobil",
    "immobilares": "immobil",
    "immobilas": "immobil",
    "immobilast": "immobil",
    "immobilaste": "immobil",
    "immobilastes": "immobil",
    "immobilasts": "immobil",
    "immobile": "immobil",
    "immobiles": "immobil",
    "immobils": "immobil",
    "immobilt": "immobil",
    "immobilts": "immobil",
    "immuna": "immun",
    "immunare": "immun",
    "immunares": "immun",
    "immunas": "immun",
    "immunast": "immun",
    "immunaste": "immun",
    "immunastes": "immun",
    "immunasts": "immun",
    "immune": "immun",
    "immunes": "immun",
    "immunförsvaret": "immunförsvar",
    "immunförsvarets": "immunförsvar",
    "immunförsvars": "immunförsvar",
    "immuniserad": "immunisera",
    "immuniserade": "immunisera",
    "immuniserades": "immunisera",
    "immuniserads": "immunisera",
    "immuniserande": "immunisera",
    "immuniseranden": "immuniserande",
    "immuniserandena": "immuniserande",
    "immuniserandenas": "immuniserande",
    "immuniserandens": "immuniserande",
    "immuniserandes": "immuniserande",
    "immuniserandet": "immuniserande",
    "immuniserandets": "immuniserande",
    "immuniserar": "immunisera",
    "immuniseras": "immunisera",
    "immuniserat": "immunisera",
    "immuniserats": "immunisera",
    "immuniserbara": "immuniserbar",
    "immuniserbarare": "immuniserbar",
    "immuniserbarares": "immuniserbar",
    "immuniserbaras": "immuniserbar",
    "immuniserbarast": "immuniserbar",
    "immuniserbaraste": "immuniserbar",
    "immuniserbarastes": "immuniserbar",
    "immuniserbarasts": "immuniserbar",
    "immuniserbare": "immuniserbar",
    "immuniserbares": "immuniserbar",
    "immuniserbarheten": "immuniserbarhet",
    "immuniserbarhetens": "immuniserbarhet",
    "immuniserbarhets": "immuniserbarhet",
    "immuniserbars": "immuniserbar",
    "immuniserbart": "immuniserbar",
    "immuniserbarts": "immuniserbar",
    "immuniseringar": "immunisering",
    "immuniseringarna": "immunisering",
    "immuniseringarnas": "immunisering",
    "immuniseringars": "immunisering",
    "immuniseringen": "immunisering",
    "immuniseringens": "immunisering",
    "immuniserings": "immunisering",
    "immuniteten": "immunitet",
    "immunitetens": "immunitet",
    "immuniteter": "immunitet",
    "immuniteterna": "immunitet",
    "immuniteternas": "immunitet",
    "immuniteters": "immunitet",
    "immunitets": "immunitet",
    "immunologen": "immunolog",
    "immunologens": "immunolog",
    "immunologer": "immunolog",
    "immunologerna": "immunolog",
    "immunologernas": "immunolog",
    "immunologers": "immunolog",
    "immunologien": "immunologi",
    "immunologiens": "immunologi",
    "immunologin": "immunologi",
    "immunologins": "immunologi",
    "immunologis": "immunologi",
    "immunologiska": "immunologisk",
    "immunologiskare": "immunologisk",
    "immunologiskares": "immunologisk",
    "immunologiskas": "immunologisk",
    "immunologiskast": "immunologisk",
    "immunologiskaste": "immunologisk",
    "immunologiskastes": "immunologisk",
    "immunologiskasts": "immunologisk",
    "immunologiske": "immunologisk",
    "immunologiskes": "immunologisk",
    "immunologisks": "immunologisk",
    "immunologiskt": "immunologisk",
    "immunologiskts": "immunologisk",
    "immunologs": "immunolog",
    "immuns": "immun",
    "immunt": "immun",
    "immunts": "immun",
    "imp": "impa",
    "impad": "impa",
    "impade": "impa",
    "impades": "impa",
    "impads": "impa",
    "impande": "impa",
    "impanden": "impande",
    "impandena": "impande",
    "impandenas": "impande",
    "impandens": "impande",
    "impandes": "impande",
    "impandet": "impande",
    "impandets": "impande",
    "impar": "impa",
    "impas": "impa",
    "impat": "impa",
    "impats": "impa",
    "impedansen": "impedans",
    "impedansens": "impedans",
    "impedimenten": "impediment",
    "impedimentens": "impediment",
    "impedimentet": "impediment",
    "impedimentets": "impediment",
    "impediments": "impediment",
    "imperativen": "imperativ",
    "imperativens": "imperativ",
    "imperativer": "imperativ",
    "imperativerna": "imperativ",
    "imperativernas": "imperativ",
    "imperativers": "imperativ",
    "imperativet": "imperativ",
    "imperativets": "imperativ",
    "imperativiska": "imperativisk",
    "imperativiskare": "imperativisk",
    "imperativiskares": "imperativisk",
    "imperativiskas": "imperativisk",
    "imperativiskast": "imperativisk",
    "imperativiskaste": "imperativisk",
    "imperativiskastes": "imperativisk",
    "imperativiskasts": "imperativisk",
    "imperativiske": "imperativisk",
    "imperativiskes": "imperativisk",
    "imperativisks": "imperativisk",
    "imperativiskt": "imperativisk",
    "imperativiskts": "imperativisk",
    "imperativs": "imperativ",
    "imperatorer": "imperator",
    "imperatorerna": "imperator",
    "imperatorernas": "imperator",
    "imperatorers": "imperator",
    "imperatoriska": "imperatorisk",
    "imperatoriskare": "imperatorisk",
    "imperatoriskares": "imperatorisk",
    "imperatoriskas": "imperatorisk",
    "imperatoriskast": "imperatorisk",
    "imperatoriskaste": "imperatorisk",
    "imperatoriskastes": "imperatorisk",
    "imperatoriskasts": "imperatorisk",
    "imperatoriske": "imperatorisk",
    "imperatoriskes": "imperatorisk",
    "imperatorisks": "imperatorisk",
    "imperatoriskt": "imperatorisk",
    "imperatoriskts": "imperatorisk",
    "imperatorn": "imperator",
    "imperatorns": "imperator",
    "imperators": "imperator",
    "imperfekt": "imperfektum",
    "imperfekten": "imperfektum",
    "imperfektens": "imperfektum",
    "imperfekter": "imperfektum",
    "imperfekterna": "imperfektum",
    "imperfekternas": "imperfektum",
    "imperfekters": "imperfektum",
    "imperfektet": "imperfektum",
    "imperfektets": "imperfektum",
    "imperfekts": "imperfektum",
    "imperfektumet": "imperfektum",
    "imperfektumets": "imperfektum",
    "imperfektums": "imperfektum",
    "imperialformaten": "imperialformat",
    "imperialformatens": "imperialformat",
    "imperialformatet": "imperialformat",
    "imperialformatets": "imperialformat",
    "imperialformats": "imperialformat",
    "imperialismen": "imperialism",
    "imperialismens": "imperialism",
    "imperialismer": "imperialism",
    "imperialismerna": "imperialism",
    "imperialismernas": "imperialism",
    "imperialismers": "imperialism",
    "imperialisms": "imperialism",
    "imperialisten": "imperialist",
    "imperialistens": "imperialist",
    "imperialister": "imperialist",
    "imperialisterna": "imperialist",
    "imperialisternas": "imperialist",
    "imperialisters": "imperialist",
    "imperialistiska": "imperialistisk",
    "imperialistiskare": "imperialistisk",
    "imperialistiskares": "imperialistisk",
    "imperialistiskas": "imperialistisk",
    "imperialistiskast": "imperialistisk",
    "imperialistiskaste": "imperialistisk",
    "imperialistiskastes": "imperialistisk",
    "imperialistiskasts": "imperialistisk",
    "imperialistiske": "imperialistisk",
    "imperialistiskes": "imperialistisk",
    "imperialistisks": "imperialistisk",
    "imperialistiskt": "imperialistisk",
    "imperialistiskts": "imperialistisk",
    "imperialists": "imperialist",
    "imperialoktaven": "imperialoktav",
    "imperialoktavens": "imperialoktav",
    "imperialoktaver": "imperialoktav",
    "imperialoktaverna": "imperialoktav",
    "imperialoktavernas": "imperialoktav",
    "imperialoktavers": "imperialoktav",
    "imperialoktavs": "imperialoktav",
    "imperialsängar": "imperialsäng",
    "imperialsängarna": "imperialsäng",
    "imperialsängarnas": "imperialsäng",
    "imperialsängars": "imperialsäng",
    "imperialsängen": "imperialsäng",
    "imperialsängens": "imperialsäng",
    "imperialsängs": "imperialsäng",
    "imperie": "imperium",
    "imperiekrigen": "imperiekrig",
    "imperiekrigens": "imperiekrig",
    "imperiekriget": "imperiekrig",
    "imperiekrigets": "imperiekrig",
    "imperiekrigs": "imperiekrig",
    "imperier": "imperium",
    "imperierna": "imperium",
    "imperiernas": "imperium",
    "imperiers": "imperium",
    "imperiet": "imperium",
    "imperiets": "imperium",
    "imperiums": "imperium",
    "impertinensen": "impertinens",
    "impertinensens": "impertinens",
    "impertinenser": "impertinens",
    "impertinenserna": "impertinens",
    "impertinensernas": "impertinens",
    "impertinensers": "impertinens",
    "impertinenta": "impertinent",
    "impertinentare": "impertinent",
    "impertinentares": "impertinent",
    "impertinentas": "impertinent",
    "impertinentast": "impertinent",
    "impertinentaste": "impertinent",
    "impertinentastes": "impertinent",
    "impertinentasts": "impertinent",
    "impertinente": "impertinent",
    "impertinentes": "impertinent",
    "impertinents": "impertinent",
    "impetigon": "impetigo",
    "impetigons": "impetigo",
    "impetigos": "impetigo",
    "implantaten": "implantat",
    "implantatens": "implantat",
    "implantatet": "implantat",
    "implantatets": "implantat",
    "implantats": "implantat",
    "implanterad": "implantera",
    "implanterade": "implantera",
    "implanterades": "implantera",
    "implanterads": "implantera",
    "implanterande": "implantera",
    "implanteranden": "implanterande",
    "implanterandena": "implanterande",
    "implanterandenas": "implanterande",
    "implanterandens": "implanterande",
    "implanterandes": "implanterande",
    "implanterandet": "implanterande",
    "implanterandets": "implanterande",
    "implanterar": "implantera",
    "implanteras": "implantera",
    "implanterat": "implantera",
    "implanterats": "implantera",
    "implanterbara": "implanterbar",
    "implanterbarare": "implanterbar",
    "implanterbarares": "implanterbar",
    "implanterbaras": "implanterbar",
    "implanterbarast": "implanterbar",
    "implanterbaraste": "implanterbar",
    "implanterbarastes": "implanterbar",
    "implanterbarasts": "implanterbar",
    "implanterbare": "implanterbar",
    "implanterbares": "implanterbar",
    "implanterbarheten": "implanterbarhet",
    "implanterbarhetens": "implanterbarhet",
    "implanterbarhets": "implanterbarhet",
    "implanterbars": "implanterbar",
    "implanterbart": "implanterbar",
    "implanterbarts": "implanterbar",
    "implicerad": "implicera",
    "implicerade": "implicera",
    "implicerades": "implicera",
    "implicerads": "implicera",
    "implicerande": "implicera",
    "impliceranden": "implicerande",
    "implicerandena": "implicerande",
    "implicerandenas": "implicerande",
    "implicerandens": "implicerande",
    "implicerandes": "implicerande",
    "implicerandet": "implicerande",
    "implicerandets": "implicerande",
    "implicerar": "implicera",
    "impliceras": "implicera",
    "implicerat": "implicera",
    "implicerats": "implicera",
    "implicerbara": "implicerbar",
    "implicerbarare": "implicerbar",
    "implicerbarares": "implicerbar",
    "implicerbaras": "implicerbar",
    "implicerbarast": "implicerbar",
    "implicerbaraste": "implicerbar",
    "implicerbarastes": "implicerbar",
    "implicerbarasts": "implicerbar",
    "implicerbare": "implicerbar",
    "implicerbares": "implicerbar",
    "implicerbarheten": "implicerbarhet",
    "implicerbarhetens": "implicerbarhet",
    "implicerbarhets": "implicerbarhet",
    "implicerbars": "implicerbar",
    "implicerbart": "implicerbar",
    "implicerbarts": "implicerbar",
    "impliceringar": "implicering",
    "impliceringarna": "implicering",
    "impliceringarnas": "implicering",
    "impliceringars": "implicering",
    "impliceringen": "implicering",
    "impliceringens": "implicering",
    "implicerings": "implicering",
    "implicita": "implicit",
    "implicitare": "implicit",
    "implicitares": "implicit",
    "implicitas": "implicit",
    "implicitast": "implicit",
    "implicitaste": "implicit",
    "implicitastes": "implicit",
    "implicitasts": "implicit",
    "implicite": "implicit",
    "implicites": "implicit",
    "implicitheten": "implicithet",
    "implicithetens": "implicithet",
    "implicithets": "implicithet",
    "implicits": "implicit",
    "implikationen": "implikation",
    "implikationens": "implikation",
    "implikationer": "implikation",
    "implikationerna": "implikation",
    "implikationernas": "implikation",
    "implikationers": "implikation",
    "implikations": "implikation",
    "imploderad": "implodera",
    "imploderade": "implodera",
    "imploderades": "implodera",
    "imploderads": "implodera",
    "imploderande": "implodera",
    "imploderanden": "imploderande",
    "imploderandena": "imploderande",
    "imploderandenas": "imploderande",
    "imploderandens": "imploderande",
    "imploderandes": "imploderande",
    "imploderandet": "imploderande",
    "imploderandets": "imploderande",
    "imploderar": "implodera",
    "imploderas": "implodera",
    "imploderat": "implodera",
    "imploderats": "implodera",
    "imploderbara": "imploderbar",
    "imploderbarare": "imploderbar",
    "imploderbarares": "imploderbar",
    "imploderbaras": "imploderbar",
    "imploderbarast": "imploderbar",
    "imploderbaraste": "imploderbar",
    "imploderbarastes": "imploderbar",
    "imploderbarasts": "imploderbar",
    "imploderbare": "imploderbar",
    "imploderbares": "imploderbar",
    "imploderbarheten": "imploderbarhet",
    "imploderbarhetens": "imploderbarhet",
    "imploderbarhets": "imploderbarhet",
    "imploderbars": "imploderbar",
    "imploderbart": "imploderbar",
    "imploderbarts": "imploderbar",
    "imploderingar": "implodering",
    "imploderingarna": "implodering",
    "imploderingarnas": "implodering",
    "imploderingars": "implodering",
    "imploderingen": "implodering",
    "imploderingens": "implodering",
    "imploderings": "implodering",
    "implosionen": "implosion",
    "implosionens": "implosion",
    "implosioner": "implosion",
    "implosionerna": "implosion",
    "implosionernas": "implosion",
    "implosioners": "implosion",
    "implosions": "implosion",
    "imponderabil": "imponderabilia",
    "imponderabili": "imponderabilier",
    "imponderabiliana": "imponderabilia",
    "imponderabilianas": "imponderabilia",
    "imponderabilias": "imponderabilia",
    "imponderabilierna": "imponderabilier",
    "imponderabiliernas": "imponderabilier",
    "imponderabiliers": "imponderabilier",
    "imponerad": "imponera",
    "imponerade": "imponera",
    "imponerades": "imponera",
    "imponerads": "imponera",
    "imponerande": "imponera",
    "imponeranden": "imponerande",
    "imponerandena": "imponerande",
    "imponerandenas": "imponerande",
    "imponerandens": "imponerande",
    "imponerandes": "imponerande",
    "imponerandet": "imponerande",
    "imponerandets": "imponerande",
    "imponerar": "imponera",
    "imponeras": "imponera",
    "imponerat": "imponera",
    "imponerats": "imponera",
    "imponerbara": "imponerbar",
    "imponerbarare": "imponerbar",
    "imponerbarares": "imponerbar",
    "imponerbaras": "imponerbar",
    "imponerbarast": "imponerbar",
    "imponerbaraste": "imponerbar",
    "imponerbarastes": "imponerbar",
    "imponerbarasts": "imponerbar",
    "imponerbare": "imponerbar",
    "imponerbares": "imponerbar",
    "imponerbarheten": "imponerbarhet",
    "imponerbarhetens": "imponerbarhet",
    "imponerbarhets": "imponerbarhet",
    "imponerbars": "imponerbar",
    "imponerbart": "imponerbar",
    "imponerbarts": "imponerbar",
    "imponeringar": "imponering",
    "imponeringarna": "imponering",
    "imponeringarnas": "imponering",
    "imponeringars": "imponering",
    "imponeringen": "imponering",
    "imponeringens": "imponering",
    "imponerings": "imponering",
    "impopulariteten": "impopularitet",
    "impopularitetens": "impopularitet",
    "impopulariteter": "impopularitet",
    "impopulariteterna": "impopularitet",
    "impopulariteternas": "impopularitet",
    "impopulariteters": "impopularitet",
    "impopularitets": "impopularitet",
    "impopulära": "impopulär",
    "impopulärare": "impopulär",
    "impopulärares": "impopulär",
    "impopuläras": "impopulär",
    "impopulärast": "impopulär",
    "impopuläraste": "impopulär",
    "impopulärastes": "impopulär",
    "impopulärasts": "impopulär",
    "impopuläre": "impopulär",
    "impopuläres": "impopulär",
    "impopulärs": "impopulär",
    "impopulärt": "impopulär",
    "impopulärts": "impopulär",
    "importavgiften": "importavgift",
    "importavgiftens": "importavgift",
    "importavgifter": "importavgift",
    "importavgifterna": "importavgift",
    "importavgifternas": "importavgift",
    "importavgifters": "importavgift",
    "importavgifts": "importavgift",
    "importen": "import",
    "importens": "import",
    "importer": "import",
    "importerad": "importera",
    "importerade": "importera",
    "importerades": "importera",
    "importerads": "importera",
    "importerande": "importera",
    "importeranden": "importerande",
    "importerandena": "importerande",
    "importerandenas": "importerande",
    "importerandens": "importerande",
    "importerandes": "importerande",
    "importerandet": "importerande",
    "importerandets": "importerande",
    "importerar": "importera",
    "importeras": "importera",
    "importerat": "importera",
    "importerats": "importera",
    "importerbara": "importerbar",
    "importerbarare": "importerbar",
    "importerbarares": "importerbar",
    "importerbaras": "importerbar",
    "importerbarast": "importerbar",
    "importerbaraste": "importerbar",
    "importerbarastes": "importerbar",
    "importerbarasts": "importerbar",
    "importerbare": "importerbar",
    "importerbares": "importerbar",
    "importerbarheten": "importerbarhet",
    "importerbarhetens": "importerbarhet",
    "importerbarhets": "importerbarhet",
    "importerbars": "importerbar",
    "importerbart": "importerbar",
    "importerbarts": "importerbar",
    "importeringar": "importering",
    "importeringarna": "importering",
    "importeringarnas": "importering",
    "importeringars": "importering",
    "importeringen": "importering",
    "importeringens": "importering",
    "importerings": "importering",
    "importerna": "import",
    "importernas": "import",
    "importers": "import",
    "importförbuden": "importförbud",
    "importförbudens": "importförbud",
    "importförbudet": "importförbud",
    "importförbudets": "importförbud",
    "importförbuds": "importförbud",
    "importkvoten": "importkvot",
    "importkvotens": "importkvot",
    "importkvoter": "importkvot",
    "importkvoterna": "importkvot",
    "importkvoternas": "importkvot",
    "importkvoters": "importkvot",
    "importkvots": "importkvot",
    "imports": "import",
    "importören": "importör",
    "importörens": "importör",
    "importörer": "importör",
    "importörerna": "importör",
    "importörernas": "importör",
    "importörers": "importör",
    "importörs": "importör",
    "imposanta": "imposant",
    "imposantare": "imposant",
    "imposantares": "imposant",
    "imposantas": "imposant",
    "imposantast": "imposant",
    "imposantaste": "imposant",
    "imposantastes": "imposant",
    "imposantasts": "imposant",
    "imposante": "imposant",
    "imposantes": "imposant",
    "imposants": "imposant",
    "imposten": "impost",
    "impostens": "impost",
    "imposter": "impost",
    "imposterna": "impost",
    "imposternas": "impost",
    "imposters": "impost",
    "imposts": "impost",
    "impotensen": "impotens",
    "impotensens": "impotens",
    "impotenta": "impotent",
    "impotentare": "impotent",
    "impotentares": "impotent",
    "impotentas": "impotent",
    "impotentast": "impotent",
    "impotentaste": "impotent",
    "impotentastes": "impotent",
    "impotentasts": "impotent",
    "impotente": "impotent",
    "impotentes": "impotent",
    "impotents": "impotent",
    "impregnerad": "impregnera",
    "impregnerade": "impregnera",
    "impregnerades": "impregnera",
    "impregnerads": "impregnera",
    "impregnerande": "impregnera",
    "impregneranden": "impregnerande",
    "impregnerandena": "impregnerande",
    "impregnerandenas": "impregnerande",
    "impregnerandens": "impregnerande",
    "impregnerandes": "impregnerande",
    "impregnerandet": "impregnerande",
    "impregnerandets": "impregnerande",
    "impregnerar": "impregnera",
    "impregneras": "impregnera",
    "impregnerat": "impregnera",
    "impregnerats": "impregnera",
    "impregnerbara": "impregnerbar",
    "impregnerbarare": "impregnerbar",
    "impregnerbarares": "impregnerbar",
    "impregnerbaras": "impregnerbar",
    "impregnerbarast": "impregnerbar",
    "impregnerbaraste": "impregnerbar",
    "impregnerbarastes": "impregnerbar",
    "impregnerbarasts": "impregnerbar",
    "impregnerbare": "impregnerbar",
    "impregnerbares": "impregnerbar",
    "impregnerbarheten": "impregnerbarhet",
    "impregnerbarhetens": "impregnerbarhet",
    "impregnerbarhets": "impregnerbarhet",
    "impregnerbars": "impregnerbar",
    "impregnerbart": "impregnerbar",
    "impregnerbarts": "impregnerbar",
    "impregneringar": "impregnering",
    "impregneringarna": "impregnering",
    "impregneringarnas": "impregnering",
    "impregneringars": "impregnering",
    "impregneringen": "impregnering",
    "impregneringens": "impregnering",
    "impregnerings": "impregnering",
    "impressarier": "impressario",
    "impressarierna": "impressario",
    "impressariernas": "impressario",
    "impressariers": "impressario",
    "impressarion": "impressario",
    "impressarions": "impressario",
    "impressarios": "impressario",
    "impressionismen": "impressionism",
    "impressionismens": "impressionism",
    "impressionismer": "impressionism",
    "impressionismerna": "impressionism",
    "impressionismernas": "impressionism",
    "impressionismers": "impressionism",
    "impressionisms": "impressionism",
    "impressionisten": "impressionist",
    "impressionistens": "impressionist",
    "impressionister": "impressionist",
    "impressionisterna": "impressionist",
    "impressionisternas": "impressionist",
    "impressionisters": "impressionist",
    "impressionistiska": "impressionistisk",
    "impressionistiskare": "impressionistisk",
    "impressionistiskares": "impressionistisk",
    "impressionistiskas": "impressionistisk",
    "impressionistiskast": "impressionistisk",
    "impressionistiskaste": "impressionistisk",
    "impressionistiskastes": "impressionistisk",
    "impressionistiskasts": "impressionistisk",
    "impressionistiske": "impressionistisk",
    "impressionistiskes": "impressionistisk",
    "impressionistisks": "impressionistisk",
    "impressionistiskt": "impressionistisk",
    "impressionistiskts": "impressionistisk",
    "impressionists": "impressionist",
    "imprimaturs": "imprimatur",
    "improduktiva": "improduktiv",
    "improduktivare": "improduktiv",
    "improduktivares": "improduktiv",
    "improduktivas": "improduktiv",
    "improduktivast": "improduktiv",
    "improduktivaste": "improduktiv",
    "improduktivastes": "improduktiv",
    "improduktivasts": "improduktiv",
    "improduktive": "improduktiv",
    "improduktives": "improduktiv",
    "improduktivs": "improduktiv",
    "improduktivt": "improduktiv",
    "improduktivts": "improduktiv",
    "impromptun": "impromptu",
    "impromptuna": "impromptu",
    "impromptunas": "impromptu",
    "impromptuns": "impromptu",
    "impromptus": "impromptu",
    "impromptut": "impromptu",
    "impromptuts": "impromptu",
    "improvisationen": "improvisation",
    "improvisationens": "improvisation",
    "improvisationer": "improvisation",
    "improvisationerna": "improvisation",
    "improvisationernas": "improvisation",
    "improvisationers": "improvisation",
    "improvisations": "improvisation",
    "improvisatoriska": "improvisatorisk",
    "improvisatoriskare": "improvisatorisk",
    "improvisatoriskares": "improvisatorisk",
    "improvisatoriskas": "improvisatorisk",
    "improvisatoriskast": "improvisatorisk",
    "improvisatoriskaste": "improvisatorisk",
    "improvisatoriskastes": "improvisatorisk",
    "improvisatoriskasts": "improvisatorisk",
    "improvisatoriske": "improvisatorisk",
    "improvisatoriskes": "improvisatorisk",
    "improvisatorisks": "improvisatorisk",
    "improvisatoriskt": "improvisatorisk",
    "improvisatoriskts": "improvisatorisk",
    "improvisatören": "improvisatör",
    "improvisatörens": "improvisatör",
    "improvisatörer": "improvisatör",
    "improvisatörerna": "improvisatör",
    "improvisatörernas": "improvisatör",
    "improvisatörers": "improvisatör",
    "improvisatörs": "improvisatör",
    "improviserad": "improvisera",
    "improviserade": "improvisera",
    "improviserades": "improvisera",
    "improviserads": "improvisera",
    "improviserande": "improvisera",
    "improviseranden": "improviserande",
    "improviserandena": "improviserande",
    "improviserandenas": "improviserande",
    "improviserandens": "improviserande",
    "improviserandes": "improviserande",
    "improviserandet": "improviserande",
    "improviserandets": "improviserande",
    "improviserar": "improvisera",
    "improviseras": "improvisera",
    "improviserat": "improvisera",
    "improviserats": "improvisera",
    "improviserbara": "improviserbar",
    "improviserbarare": "improviserbar",
    "improviserbarares": "improviserbar",
    "improviserbaras": "improviserbar",
    "improviserbarast": "improviserbar",
    "improviserbaraste": "improviserbar",
    "improviserbarastes": "improviserbar",
    "improviserbarasts": "improviserbar",
    "improviserbare": "improviserbar",
    "improviserbares": "improviserbar",
    "improviserbarheten": "improviserbarhet",
    "improviserbarhetens": "improviserbarhet",
    "improviserbarhets": "improviserbarhet",
    "improviserbars": "improviserbar",
    "improviserbart": "improviserbar",
    "improviserbarts": "improviserbar",
    "improviseringar": "improvisering",
    "improviseringarna": "improvisering",
    "improviseringarnas": "improvisering",
    "improviseringars": "improvisering",
    "improviseringen": "improvisering",
    "improviseringens": "improvisering",
    "improviserings": "improvisering",
    "impulsen": "impuls",
    "impulsens": "impuls",
    "impulser": "impuls",
    "impulserna": "impuls",
    "impulsernas": "impuls",
    "impulsers": "impuls",
    "impulsiva": "impulsiv",
    "impulsivare": "impulsiv",
    "impulsivares": "impulsiv",
    "impulsivas": "impulsiv",
    "impulsivast": "impulsiv",
    "impulsivaste": "impulsiv",
    "impulsivastes": "impulsiv",
    "impulsivasts": "impulsiv",
    "impulsive": "impulsiv",
    "impulsives": "impulsiv",
    "impulsiviteten": "impulsivitet",
    "impulsivitetens": "impulsivitet",
    "impulsiviteter": "impulsivitet",
    "impulsiviteterna": "impulsivitet",
    "impulsiviteternas": "impulsivitet",
    "impulsiviteters": "impulsivitet",
    "impulsivitets": "impulsivitet",
    "impulsivs": "impulsiv",
    "impulsivt": "impulsiv",
    "impulsivts": "impulsiv",
    "impulsköpen": "impulsköp",
    "impulsköpens": "impulsköp",
    "impulsköpet": "impulsköp",
    "impulsköpets": "impulsköp",
    "impulsköps": "impulsköp",
    "imrutan": "imruta",
    "imrutans": "imruta",
    "imrutas": "imruta",
    "imrute": "imruta",
    "imrutor": "imruta",
    "imrutorna": "imruta",
    "imrutornas": "imruta",
    "imrutors": "imruta",
    "imrören": "imrör",
    "imrörens": "imrör",
    "imröret": "imrör",
    "imrörets": "imrör",
    "imrörs": "imrör",
    "imskydden": "imskydd",
    "imskyddens": "imskydd",
    "imskyddet": "imskydd",
    "imskyddets": "imskydd",
    "imskydds": "imskydd",
    "in": "i",
    "ina": "i",
    "inackorderad": "inackordera",
    "inackorderade": "inackordera",
    "inackorderades": "inackordera",
    "inackorderads": "inackordera",
    "inackorderande": "inackordera",
    "inackorderanden": "inackorderande",
    "inackorderandena": "inackorderande",
    "inackorderandenas": "inackorderande",
    "inackorderandens": "inackorderande",
    "inackorderandes": "inackorderande",
    "inackorderandet": "inackorderande",
    "inackorderandets": "inackorderande",
    "inackorderar": "inackordera",
    "inackorderas": "inackordera",
    "inackorderat": "inackordera",
    "inackorderats": "inackordera",
    "inackorderbara": "inackorderbar",
    "inackorderbarare": "inackorderbar",
    "inackorderbarares": "inackorderbar",
    "inackorderbaras": "inackorderbar",
    "inackorderbarast": "inackorderbar",
    "inackorderbaraste": "inackorderbar",
    "inackorderbarastes": "inackorderbar",
    "inackorderbarasts": "inackorderbar",
    "inackorderbare": "inackorderbar",
    "inackorderbares": "inackorderbar",
    "inackorderbarheten": "inackorderbarhet",
    "inackorderbarhetens": "inackorderbarhet",
    "inackorderbarhets": "inackorderbarhet",
    "inackorderbars": "inackorderbar",
    "inackorderbart": "inackorderbar",
    "inackorderbarts": "inackorderbar",
    "inackorderingar": "inackordering",
    "inackorderingarna": "inackordering",
    "inackorderingarnas": "inackordering",
    "inackorderingars": "inackordering",
    "inackorderingen": "inackordering",
    "inackorderingens": "inackordering",
    "inackorderings": "inackordering",
    "inackorderingshemmen": "inackorderingshem",
    "inackorderingshemmens": "inackorderingshem",
    "inackorderingshemmet": "inackorderingshem",
    "inackorderingshemmets": "inackorderingshem",
    "inackorderingshems": "inackorderingshem",
    "inadekvata": "inadekvat",
    "inadekvatare": "inadekvat",
    "inadekvatares": "inadekvat",
    "inadekvatas": "inadekvat",
    "inadekvatast": "inadekvat",
    "inadekvataste": "inadekvat",
    "inadekvatastes": "inadekvat",
    "inadekvatasts": "inadekvat",
    "inadekvate": "inadekvat",
    "inadekvates": "inadekvat",
    "inadekvats": "inadekvat",
    "inadvertensen": "inadvertens",
    "inadvertensens": "inadvertens",
    "inadvertenser": "inadvertens",
    "inadvertenserna": "inadvertens",
    "inadvertensernas": "inadvertens",
    "inadvertensers": "inadvertens",
    "inaktiva": "inaktiv",
    "inaktivare": "inaktiv",
    "inaktivares": "inaktiv",
    "inaktivas": "inaktiv",
    "inaktivast": "inaktiv",
    "inaktivaste": "inaktiv",
    "inaktivastes": "inaktiv",
    "inaktivasts": "inaktiv",
    "inaktive": "inaktiv",
    "inaktives": "inaktiv",
    "inaktiviteten": "inaktivitet",
    "inaktivitetens": "inaktivitet",
    "inaktiviteter": "inaktivitet",
    "inaktiviteterna": "inaktivitet",
    "inaktiviteternas": "inaktivitet",
    "inaktiviteters": "inaktivitet",
    "inaktivitets": "inaktivitet",
    "inaktivs": "inaktiv",
    "inaktivt": "inaktiv",
    "inaktivts": "inaktiv",
    "inaktuella": "inaktuell",
    "inaktuellare": "inaktuell",
    "inaktuellares": "inaktuell",
    "inaktuellas": "inaktuell",
    "inaktuellast": "inaktuell",
    "inaktuellaste": "inaktuell",
    "inaktuellastes": "inaktuell",
    "inaktuellasts": "inaktuell",
    "inaktuelle": "inaktuell",
    "inaktuelles": "inaktuell",
    "inaktuells": "inaktuell",
    "inaktuellt": "inaktuell",
    "inaktuellts": "inaktuell",
    "inandades": "inandas",
    "inandats": "inandas",
    "inandningar": "inandning",
    "inandningarna": "inandning",
    "inandningarnas": "inandning",
    "inandningars": "inandning",
    "inandningen": "inandning",
    "inandningens": "inandning",
    "inandnings": "inandning",
    "inarbet": "inarbeta",
    "inarbetad": "inarbeta",
    "inarbetade": "inarbeta",
    "inarbetades": "inarbeta",
    "inarbetads": "inarbeta",
    "inarbetande": "inarbeta",
    "inarbetanden": "inarbetande",
    "inarbetandena": "inarbetande",
    "inarbetandenas": "inarbetande",
    "inarbetandens": "inarbetande",
    "inarbetandes": "inarbetande",
    "inarbetandet": "inarbetande",
    "inarbetandets": "inarbetande",
    "inarbetar": "inarbeta",
    "inarbetas": "inarbeta",
    "inarbetat": "inarbeta",
    "inarbetats": "inarbeta",
    "inas": "i",
    "inaugurationen": "inauguration",
    "inaugurationens": "inauguration",
    "inaugurationer": "inauguration",
    "inaugurationerna": "inauguration",
    "inaugurationernas": "inauguration",
    "inaugurationers": "inauguration",
    "inaugurations": "inauguration",
    "inaugurerad": "inaugurera",
    "inaugurerade": "inaugurera",
    "inaugurerades": "inaugurera",
    "inaugurerads": "inaugurera",
    "inaugurerande": "inaugurera",
    "inaugureranden": "inaugurerande",
    "inaugurerandena": "inaugurerande",
    "inaugurerandenas": "inaugurerande",
    "inaugurerandens": "inaugurerande",
    "inaugurerandes": "inaugurerande",
    "inaugurerandet": "inaugurerande",
    "inaugurerandets": "inaugurerande",
    "inaugurerar": "inaugurera",
    "inaugureras": "inaugurera",
    "inaugurerat": "inaugurera",
    "inaugurerats": "inaugurera",
    "inaugurerbara": "inaugurerbar",
    "inaugurerbarare": "inaugurerbar",
    "inaugurerbarares": "inaugurerbar",
    "inaugurerbaras": "inaugurerbar",
    "inaugurerbarast": "inaugurerbar",
    "inaugurerbaraste": "inaugurerbar",
    "inaugurerbarastes": "inaugurerbar",
    "inaugurerbarasts": "inaugurerbar",
    "inaugurerbare": "inaugurerbar",
    "inaugurerbares": "inaugurerbar",
    "inaugurerbarheten": "inaugurerbarhet",
    "inaugurerbarhetens": "inaugurerbarhet",
    "inaugurerbarhets": "inaugurerbarhet",
    "inaugurerbars": "inaugurerbar",
    "inaugurerbart": "inaugurerbar",
    "inaugurerbarts": "inaugurerbar",
    "inaugureringar": "inaugurering",
    "inaugureringarna": "inaugurering",
    "inaugureringarnas": "inaugurering",
    "inaugureringars": "inaugurering",
    "inaugureringen": "inaugurering",
    "inaugureringens": "inaugurering",
    "inaugurerings": "inaugurering",
    "inaveln": "inavel",
    "inavelns": "inavel",
    "inavels": "inavel",
    "inbak": "inbaka",
    "inbakad": "inbaka",
    "inbakade": "inbakad",
    "inbakades": "inbakad",
    "inbakads": "inbakad",
    "inbakande": "inbaka",
    "inbakanden": "inbakande",
    "inbakandena": "inbakande",
    "inbakandenas": "inbakande",
    "inbakandens": "inbakande",
    "inbakandes": "inbakande",
    "inbakandet": "inbakande",
    "inbakandets": "inbakande",
    "inbakar": "inbaka",
    "inbakas": "inbaka",
    "inbakat": "inbakad",
    "inbakats": "inbakad",
    "inbegrep": "inbegripa",
    "inbegreppen": "inbegrepp",
    "inbegreppens": "inbegrepp",
    "inbegreppet": "inbegrepp",
    "inbegreppets": "inbegrepp",
    "inbegrepps": "inbegrepp",
    "inbegreps": "inbegripa",
    "inbegrip": "inbegripa",
    "inbegripande": "inbegripa",
    "inbegripanden": "inbegripande",
    "inbegripandena": "inbegripande",
    "inbegripandenas": "inbegripande",
    "inbegripandens": "inbegripande",
    "inbegripandes": "inbegripande",
    "inbegripandet": "inbegripande",
    "inbegripandets": "inbegripande",
    "inbegripas": "inbegripa",
    "inbegripe": "inbegripa",
    "inbegripen": "inbegripa",
    "inbegripens": "inbegripen",
    "inbegriper": "inbegripa",
    "inbegripes": "inbegripa",
    "inbegripet": "inbegripen",
    "inbegripets": "inbegripen",
    "inbegripit": "inbegripa",
    "inbegripits": "inbegripa",
    "inbegripna": "inbegripen",
    "inbegripnare": "inbegripen",
    "inbegripnares": "inbegripen",
    "inbegripnas": "inbegripen",
    "inbegripnast": "inbegripen",
    "inbegripnaste": "inbegripen",
    "inbegripnastes": "inbegripen",
    "inbegripnasts": "inbegripen",
    "inbegripne": "inbegripen",
    "inbegripnes": "inbegripen",
    "inbegrips": "inbegripa",
    "inberäkn": "inberäkna",
    "inberäknad": "inberäkna",
    "inberäknade": "inberäkna",
    "inberäknades": "inberäkna",
    "inberäknads": "inberäkna",
    "inberäknande": "inberäkna",
    "inberäknanden": "inberäknande",
    "inberäknandena": "inberäknande",
    "inberäknandenas": "inberäknande",
    "inberäknandens": "inberäknande",
    "inberäknandes": "inberäknande",
    "inberäknandet": "inberäknande",
    "inberäknandets": "inberäknande",
    "inberäknar": "inberäkna",
    "inberäknas": "inberäkna",
    "inberäknat": "inberäkna",
    "inberäknats": "inberäkna",
    "inbespar": "inbespara",
    "inbesparad": "inbespara",
    "inbesparade": "inbespara",
    "inbesparades": "inbespara",
    "inbesparads": "inbespara",
    "inbesparande": "inbespara",
    "inbesparanden": "inbesparande",
    "inbesparandena": "inbesparande",
    "inbesparandenas": "inbesparande",
    "inbesparandens": "inbesparande",
    "inbesparandes": "inbesparande",
    "inbesparandet": "inbesparande",
    "inbesparandets": "inbesparande",
    "inbesparar": "inbespara",
    "inbesparas": "inbespara",
    "inbesparat": "inbespara",
    "inbesparats": "inbespara",
    "inbesparingar": "inbesparing",
    "inbesparingarna": "inbesparing",
    "inbesparingarnas": "inbesparing",
    "inbesparingars": "inbesparing",
    "inbesparingen": "inbesparing",
    "inbesparingens": "inbesparing",
    "inbesparings": "inbesparing",
    "inbetal": "inbetala",
    "inbetalad": "inbetala",
    "inbetalade": "inbetala",
    "inbetalades": "inbetala",
    "inbetalads": "inbetala",
    "inbetalande": "inbetala",
    "inbetalanden": "inbetalande",
    "inbetalandena": "inbetalande",
    "inbetalandenas": "inbetalande",
    "inbetalandens": "inbetalande",
    "inbetalandes": "inbetalande",
    "inbetalandet": "inbetalande",
    "inbetalandets": "inbetalande",
    "inbetalar": "inbetala",
    "inbetalas": "inbetala",
    "inbetalat": "inbetala",
    "inbetalats": "inbetala",
    "inbetald": "inbetala",
    "inbetalda": "inbetala",
    "inbetaldas": "inbetala",
    "inbetalde": "inbetala",
    "inbetaldes": "inbetala",
    "inbetalds": "inbetala",
    "inbetalningar": "inbetalning",
    "inbetalningarna": "inbetalning",
    "inbetalningarnas": "inbetalning",
    "inbetalningars": "inbetalning",
    "inbetalningen": "inbetalning",
    "inbetalningens": "inbetalning",
    "inbetalnings": "inbetalning",
    "inbetalningskorten": "inbetalningskort",
    "inbetalningskortens": "inbetalningskort",
    "inbetalningskortet": "inbetalningskort",
    "inbetalningskortets": "inbetalningskort",
    "inbetalningskorts": "inbetalningskort",
    "inbetalt": "inbetala",
    "inbetalte": "inbetala",
    "inbetaltes": "inbetala",
    "inbetalts": "inbetala",
    "inbill": "inbilla",
    "inbillad": "inbilla",
    "inbillade": "inbilla",
    "inbillades": "inbilla",
    "inbillads": "inbilla",
    "inbillande": "inbilla",
    "inbillanden": "inbillande",
    "inbillandena": "inbillande",
    "inbillandenas": "inbillande",
    "inbillandens": "inbillande",
    "inbillandes": "inbillande",
    "inbillandet": "inbillande",
    "inbillandets": "inbillande",
    "inbillar": "inbilla",
    "inbillas": "inbilla",
    "inbillat": "inbilla",
    "inbillats": "inbilla",
    "inbillningar": "inbillning",
    "inbillningarna": "inbillning",
    "inbillningarnas": "inbillning",
    "inbillningars": "inbillning",
    "inbillningen": "inbillning",
    "inbillningens": "inbillning",
    "inbillnings": "inbillning",
    "inbillningsfosterna": "inbillningsfoster",
    "inbillningsfosternas": "inbillningsfoster",
    "inbillningsfosters": "inbillningsfoster",
    "inbillningsfostren": "inbillningsfoster",
    "inbillningsfostrens": "inbillningsfoster",
    "inbillningsfostret": "inbillningsfoster",
    "inbillningsfostrets": "inbillningsfoster",
    "inbillningssjuka": "inbillningssjuk",
    "inbillningssjukare": "inbillningssjuk",
    "inbillningssjukares": "inbillningssjuk",
    "inbillningssjukas": "inbillningssjuk",
    "inbillningssjukast": "inbillningssjuk",
    "inbillningssjukaste": "inbillningssjuk",
    "inbillningssjukastes": "inbillningssjuk",
    "inbillningssjukasts": "inbillningssjuk",
    "inbillningssjuke": "inbillningssjuk",
    "inbillningssjukes": "inbillningssjuk",
    "inbillningssjukheten": "inbillningssjukhet",
    "inbillningssjukhetens": "inbillningssjukhet",
    "inbillningssjukhets": "inbillningssjukhet",
    "inbillningssjuks": "inbillningssjuk",
    "inbillningssjukt": "inbillningssjuk",
    "inbillningssjukts": "inbillningssjuk",
    "inbilska": "inbilsk",
    "inbilskare": "inbilsk",
    "inbilskares": "inbilsk",
    "inbilskas": "inbilsk",
    "inbilskast": "inbilsk",
    "inbilskaste": "inbilsk",
    "inbilskastes": "inbilsk",
    "inbilskasts": "inbilsk",
    "inbilske": "inbilsk",
    "inbilskes": "inbilsk",
    "inbilsks": "inbilsk",
    "inbilskt": "inbilsk",
    "inbilskts": "inbilsk",
    "inbitenheten": "inbitenhet",
    "inbitenhetens": "inbitenhet",
    "inbitenhets": "inbitenhet",
    "inbitens": "inbiten",
    "inbitet": "inbiten",
    "inbitets": "inbiten",
    "inbitna": "inbiten",
    "inbitnare": "inbiten",
    "inbitnares": "inbiten",
    "inbitnas": "inbiten",
    "inbitnast": "inbiten",
    "inbitnaste": "inbiten",
    "inbitnastes": "inbiten",
    "inbitnasts": "inbiten",
    "inbitne": "inbiten",
    "inbitnes": "inbiten",
    "inbjud": "inbjuda",
    "inbjudande": "inbjuda",
    "inbjudandes": "inbjuda",
    "inbjudans": "inbjudan",
    "inbjudas": "inbjuda",
    "inbjude": "inbjuda",
    "inbjuder": "inbjuda",
    "inbjudes": "inbjuda",
    "inbjudit": "inbjuda",
    "inbjudits": "inbjuda",
    "inbjudningar": "inbjudning",
    "inbjudningarna": "inbjudning",
    "inbjudningarnas": "inbjudning",
    "inbjudningars": "inbjudning",
    "inbjudningen": "inbjudning",
    "inbjudningens": "inbjudning",
    "inbjudnings": "inbjudning",
    "inbjudningskorten": "inbjudningskort",
    "inbjudningskortens": "inbjudningskort",
    "inbjudningskortet": "inbjudningskort",
    "inbjudningskortets": "inbjudningskort",
    "inbjudningskorts": "inbjudningskort",
    "inbjudningsskriften": "inbjudningsskrift",
    "inbjudningsskriftens": "inbjudningsskrift",
    "inbjudningsskrifter": "inbjudningsskrift",
    "inbjudningsskrifterna": "inbjudningsskrift",
    "inbjudningsskrifternas": "inbjudningsskrift",
    "inbjudningsskrifters": "inbjudningsskrift",
    "inbjudningsskrifts": "inbjudningsskrift",
    "inbjuds": "inbjuda",
    "inbjöd": "inbjuda",
    "inbjöde": "inbjuda",
    "inbjödes": "inbjuda",
    "inbjöds": "inbjuda",
    "inblandade": "inblandad",
    "inblandades": "inblandad",
    "inblandads": "inblandad",
    "inblandande": "inblanda",
    "inblandandes": "inblanda",
    "inblandar": "inblanda",
    "inblandas": "inblanda",
    "inblandat": "inblandad",
    "inblandats": "inblandad",
    "inblandningar": "inblandning",
    "inblandningarna": "inblandning",
    "inblandningarnas": "inblandning",
    "inblandningars": "inblandning",
    "inblandningen": "inblandning",
    "inblandningens": "inblandning",
    "inblandnings": "inblandning",
    "inblickar": "inblick",
    "inblickarna": "inblick",
    "inblickarnas": "inblick",
    "inblickars": "inblick",
    "inblicken": "inblick",
    "inblickens": "inblick",
    "inblicks": "inblick",
    "inblåsningen": "inblåsning",
    "inblåsningens": "inblåsning",
    "inblåsnings": "inblåsning",
    "inbokningar": "inbokning",
    "inbokningarna": "inbokning",
    "inbokningarnas": "inbokning",
    "inbokningars": "inbokning",
    "inbokningen": "inbokning",
    "inbokningens": "inbokning",
    "inboknings": "inbokning",
    "inbragt": "inbringa",
    "inbragte": "inbringa",
    "inbragtes": "inbringa",
    "inbragts": "inbringa",
    "inbring": "inbringa",
    "inbringad": "inbringa",
    "inbringade": "inbringa",
    "inbringades": "inbringa",
    "inbringads": "inbringa",
    "inbringande": "inbringa",
    "inbringanden": "inbringande",
    "inbringandena": "inbringande",
    "inbringandenas": "inbringande",
    "inbringandens": "inbringande",
    "inbringandes": "inbringande",
    "inbringandet": "inbringande",
    "inbringandets": "inbringande",
    "inbringar": "inbringa",
    "inbringas": "inbringa",
    "inbringat": "inbringa",
    "inbringats": "inbringa",
    "inbromsningar": "inbromsning",
    "inbromsningarna": "inbromsning",
    "inbromsningarnas": "inbromsning",
    "inbromsningars": "inbromsning",
    "inbromsningen": "inbromsning",
    "inbromsningens": "inbromsning",
    "inbromsnings": "inbromsning",
    "inbrotten": "inbrott",
    "inbrottens": "inbrott",
    "inbrottet": "inbrott",
    "inbrottets": "inbrott",
    "inbrotts": "inbrott",
    "inbrottstjuvar": "inbrottstjuv",
    "inbrottstjuvarna": "inbrottstjuv",
    "inbrottstjuvarnas": "inbrottstjuv",
    "inbrottstjuvars": "inbrottstjuv",
    "inbrottstjuven": "inbrottstjuv",
    "inbrottstjuvens": "inbrottstjuv",
    "inbrottstjuvs": "inbrottstjuv",
    "inbrytningar": "inbrytning",
    "inbrytningarna": "inbrytning",
    "inbrytningarnas": "inbrytning",
    "inbrytningars": "inbrytning",
    "inbrytningen": "inbrytning",
    "inbrytningens": "inbrytning",
    "inbrytnings": "inbrytning",
    "inbuktningar": "inbuktning",
    "inbuktningarna": "inbuktning",
    "inbuktningarnas": "inbuktning",
    "inbuktningars": "inbuktning",
    "inbuktningen": "inbuktning",
    "inbuktningens": "inbuktning",
    "inbuktnings": "inbuktning",
    "inbundenheten": "inbundenhet",
    "inbundenhetens": "inbundenhet",
    "inbundenhets": "inbundenhet",
    "inbundens": "inbunden",
    "inbundet": "inbunden",
    "inbundets": "inbunden",
    "inbundna": "inbunden",
    "inbundnare": "inbunden",
    "inbundnares": "inbunden",
    "inbundnas": "inbunden",
    "inbundnast": "inbunden",
    "inbundnaste": "inbunden",
    "inbundnastes": "inbunden",
    "inbundnasts": "inbunden",
    "inbundne": "inbunden",
    "inbundnes": "inbunden",
    "inbygg": "inbygga",
    "inbyggande": "inbygga",
    "inbygganden": "inbyggande",
    "inbyggandena": "inbyggande",
    "inbyggandenas": "inbyggande",
    "inbyggandens": "inbyggande",
    "inbyggandes": "inbyggande",
    "inbyggandet": "inbyggande",
    "inbyggandets": "inbyggande",
    "inbyggar": "inbyggare",
    "inbyggaren": "inbyggare",
    "inbyggarens": "inbyggare",
    "inbyggares": "inbyggare",
    "inbyggarna": "inbyggare",
    "inbyggarnas": "inbyggare",
    "inbyggas": "inbygga",
    "inbyggd": "inbygga",
    "inbyggda": "inbyggd",
    "inbyggdare": "inbyggd",
    "inbyggdares": "inbyggd",
    "inbyggdas": "inbyggd",
    "inbyggdast": "inbyggd",
    "inbyggdaste": "inbyggd",
    "inbyggdastes": "inbyggd",
    "inbyggdasts": "inbyggd",
    "inbyggde": "inbyggd",
    "inbyggdes": "inbyggd",
    "inbyggds": "inbyggd",
    "inbygger": "inbygga",
    "inbygges": "inbygga",
    "inbyggs": "inbygga",
    "inbyggt": "inbyggd",
    "inbyggts": "inbyggd",
    "inbyten": "inbyte",
    "inbytena": "inbyte",
    "inbytenas": "inbyte",
    "inbytens": "inbyte",
    "inbytes": "inbyte",
    "inbytet": "inbyte",
    "inbytets": "inbyte",
    "inbäddade": "inbäddad",
    "inbäddades": "inbäddad",
    "inbäddads": "inbäddad",
    "inbäddat": "inbäddad",
    "inbäddats": "inbäddad",
    "inbördeskrigen": "inbördeskrig",
    "inbördeskrigens": "inbördeskrig",
    "inbördeskriget": "inbördeskrig",
    "inbördeskrigets": "inbördeskrig",
    "inbördeskrigs": "inbördeskrig",
    "incabären": "incabär",
    "incabärens": "incabär",
    "incabäret": "incabär",
    "incabärets": "incabär",
    "incabärs": "incabär",
    "incesten": "incest",
    "incestens": "incest",
    "incester": "incest",
    "incesterna": "incest",
    "incesternas": "incest",
    "incesters": "incest",
    "incests": "incest",
    "incestuösa": "incestuös",
    "incestuösare": "incestuös",
    "incestuösares": "incestuös",
    "incestuösas": "incestuös",
    "incestuösast": "incestuös",
    "incestuösaste": "incestuös",
    "incestuösastes": "incestuös",
    "incestuösasts": "incestuös",
    "incestuöse": "incestuös",
    "incestuöses": "incestuös",
    "incestuöst": "incestuös",
    "incestuösts": "incestuös",
    "incidentberedskapen": "incidentberedskap",
    "incidentberedskapens": "incidentberedskap",
    "incidentberedskaps": "incidentberedskap",
    "incidenten": "incident",
    "incidentens": "incident",
    "incidenter": "incident",
    "incidenterna": "incident",
    "incidenternas": "incident",
    "incidenters": "incident",
    "incidents": "incident",
    "incitamenten": "incitament",
    "incitamentens": "incitament",
    "incitamentet": "incitament",
    "incitamentets": "incitament",
    "incitaments": "incitament",
    "indefinita": "indefinit",
    "indefinitare": "indefinit",
    "indefinitares": "indefinit",
    "indefinitas": "indefinit",
    "indefinitast": "indefinit",
    "indefinitaste": "indefinit",
    "indefinitastes": "indefinit",
    "indefinitasts": "indefinit",
    "indefinite": "indefinit",
    "indefinites": "indefinit",
    "indefinitheten": "indefinithet",
    "indefinithetens": "indefinithet",
    "indefinithets": "indefinithet",
    "indefinits": "indefinit",
    "indel": "indela",
    "indelad": "indela",
    "indelade": "indela",
    "indelades": "indela",
    "indelads": "indela",
    "indelande": "indela",
    "indelanden": "indelande",
    "indelandena": "indelande",
    "indelandenas": "indelande",
    "indelandens": "indelande",
    "indelandes": "indelande",
    "indelandet": "indelande",
    "indelandets": "indelande",
    "indelar": "indela",
    "indelas": "indela",
    "indelat": "indela",
    "indelats": "indela",
    "indelningar": "indelning",
    "indelningarna": "indelning",
    "indelningarnas": "indelning",
    "indelningars": "indelning",
    "indelningen": "indelning",
    "indelningens": "indelning",
    "indelnings": "indelning",
    "indelningsgrunden": "indelningsgrund",
    "indelningsgrundens": "indelningsgrund",
    "indelningsgrunder": "indelningsgrund",
    "indelningsgrunderna": "indelningsgrund",
    "indelningsgrundernas": "indelningsgrund",
    "indelningsgrunders": "indelningsgrund",
    "indelningsgrunds": "indelningsgrund",
    "indelningsverket": "indelningsverk",
    "indelningsverkets": "indelningsverk",
    "indelningsverks": "indelningsverk",
    "indelta": "indelt",
    "indeltare": "indelt",
    "indeltares": "indelt",
    "indeltas": "indelt",
    "indeltast": "indelt",
    "indeltaste": "indelt",
    "indeltastes": "indelt",
    "indeltasts": "indelt",
    "indelte": "indelt",
    "indeltes": "indelt",
    "indelts": "indelt",
    "independenten": "independent",
    "independentens": "independent",
    "independenter": "independent",
    "independenterna": "independent",
    "independenternas": "independent",
    "independenters": "independent",
    "independents": "independent",
    "indexavtalen": "indexavtal",
    "indexavtalens": "indexavtal",
    "indexavtalet": "indexavtal",
    "indexavtalets": "indexavtal",
    "indexavtals": "indexavtal",
    "indexen": "index",
    "indexens": "index",
    "indexerad": "indexera",
    "indexerade": "indexera",
    "indexerades": "indexera",
    "indexerads": "indexera",
    "indexerande": "indexera",
    "indexeranden": "indexerande",
    "indexerandena": "indexerande",
    "indexerandenas": "indexerande",
    "indexerandens": "indexerande",
    "indexerandes": "indexerande",
    "indexerandet": "indexerande",
    "indexerandets": "indexerande",
    "indexerar": "indexera",
    "indexeras": "indexera",
    "indexerat": "indexera",
    "indexerats": "indexera",
    "indexerbara": "indexerbar",
    "indexerbarare": "indexerbar",
    "indexerbarares": "indexerbar",
    "indexerbaras": "indexerbar",
    "indexerbarast": "indexerbar",
    "indexerbaraste": "indexerbar",
    "indexerbarastes": "indexerbar",
    "indexerbarasts": "indexerbar",
    "indexerbare": "indexerbar",
    "indexerbares": "indexerbar",
    "indexerbarheten": "indexerbarhet",
    "indexerbarhetens": "indexerbarhet",
    "indexerbarhets": "indexerbarhet",
    "indexerbars": "indexerbar",
    "indexerbart": "indexerbar",
    "indexerbarts": "indexerbar",
    "indexeringar": "indexering",
    "indexeringarna": "indexering",
    "indexeringarnas": "indexering",
    "indexeringars": "indexering",
    "indexeringen": "indexering",
    "indexeringens": "indexering",
    "indexerings": "indexering",
    "indexet": "index",
    "indexets": "index",
    "indexreglerad": "indexreglera",
    "indexreglerade": "indexreglera",
    "indexreglerades": "indexreglera",
    "indexreglerads": "indexreglera",
    "indexreglerande": "indexreglera",
    "indexregleranden": "indexreglerande",
    "indexreglerandena": "indexreglerande",
    "indexreglerandenas": "indexreglerande",
    "indexreglerandens": "indexreglerande",
    "indexreglerandes": "indexreglerande",
    "indexreglerandet": "indexreglerande",
    "indexreglerandets": "indexreglerande",
    "indexreglerar": "indexreglera",
    "indexregleras": "indexreglera",
    "indexreglerat": "indexreglera",
    "indexreglerats": "indexreglera",
    "indexreglerbara": "indexreglerbar",
    "indexreglerbarare": "indexreglerbar",
    "indexreglerbarares": "indexreglerbar",
    "indexreglerbaras": "indexreglerbar",
    "indexreglerbarast": "indexreglerbar",
    "indexreglerbaraste": "indexreglerbar",
    "indexreglerbarastes": "indexreglerbar",
    "indexreglerbarasts": "indexreglerbar",
    "indexreglerbare": "indexreglerbar",
    "indexreglerbares": "indexreglerbar",
    "indexreglerbarheten": "indexreglerbarhet",
    "indexreglerbarhetens": "indexreglerbarhet",
    "indexreglerbarhets": "indexreglerbarhet",
    "indexreglerbars": "indexreglerbar",
    "indexreglerbart": "indexreglerbar",
    "indexreglerbarts": "indexreglerbar",
    "indexregleringar": "indexreglering",
    "indexregleringarna": "indexreglering",
    "indexregleringarnas": "indexreglering",
    "indexregleringars": "indexreglering",
    "indexregleringen": "indexreglering",
    "indexregleringens": "indexreglering",
    "indexreglerings": "indexreglering",
    "indianen": "indian",
    "indianens": "indian",
    "indianer": "indian",
    "indianerna": "indian",
    "indianernas": "indian",
    "indianers": "indian",
    "indianfolken": "indianfolk",
    "indianfolkens": "indianfolk",
    "indianfolket": "indianfolk",
    "indianfolkets": "indianfolk",
    "indianfolks": "indianfolk",
    "indianhydd": "indianhydda",
    "indianhyddan": "indianhydda",
    "indianhyddans": "indianhydda",
    "indianhyddas": "indianhydda",
    "indianhydde": "indianhydda",
    "indianhyddor": "indianhydda",
    "indianhyddorna": "indianhydda",
    "indianhyddornas": "indianhydda",
    "indianhyddors": "indianhydda",
    "indianhydds": "indianhydda",
    "indianhövdingar": "indianhövding",
    "indianhövdingarna": "indianhövding",
    "indianhövdingarnas": "indianhövding",
    "indianhövdingars": "indianhövding",
    "indianhövdingen": "indianhövding",
    "indianhövdingens": "indianhövding",
    "indianhövdings": "indianhövding",
    "indiankvinnan": "indiankvinna",
    "indiankvinnans": "indiankvinna",
    "indiankvinnas": "indiankvinna",
    "indiankvinne": "indiankvinna",
    "indiankvinno": "indiankvinna",
    "indiankvinnor": "indiankvinna",
    "indiankvinnorna": "indiankvinna",
    "indiankvinnornas": "indiankvinna",
    "indiankvinnors": "indiankvinna",
    "indianlivet": "indianliv",
    "indianlivets": "indianliv",
    "indianlivs": "indianliv",
    "indianreservaten": "indianreservat",
    "indianreservatens": "indianreservat",
    "indianreservatet": "indianreservat",
    "indianreservatets": "indianreservat",
    "indianreservats": "indianreservat",
    "indians": "indian",
    "indianska": "indiansk",
    "indianskan": "indianska",
    "indianskans": "indianska",
    "indianskare": "indiansk",
    "indianskares": "indiansk",
    "indianskas": "indianska",
    "indianskast": "indiansk",
    "indianskaste": "indiansk",
    "indianskastes": "indiansk",
    "indianskasts": "indiansk",
    "indianske": "indianska",
    "indianskes": "indiansk",
    "indianskor": "indianska",
    "indianskorna": "indianska",
    "indianskornas": "indianska",
    "indianskors": "indianska",
    "indiansks": "indiansk",
    "indianskt": "indiansk",
    "indianskts": "indiansk",
    "indiansommaren": "indiansommar",
    "indiansommarens": "indiansommar",
    "indiansommarn": "indiansommar",
    "indiansommarns": "indiansommar",
    "indiansommars": "indiansommar",
    "indiansomrar": "indiansommar",
    "indiansomrarna": "indiansommar",
    "indiansomrarnas": "indiansommar",
    "indiansomrars": "indiansommar",
    "indianstammar": "indianstam",
    "indianstammarna": "indianstam",
    "indianstammarnas": "indianstam",
    "indianstammars": "indianstam",
    "indianstammen": "indianstam",
    "indianstammens": "indianstam",
    "indianstams": "indianstam",
    "indiantjuten": "indiantjut",
    "indiantjutens": "indiantjut",
    "indiantjutet": "indiantjut",
    "indiantjutets": "indiantjut",
    "indiantjuts": "indiantjut",
    "indicerad": "indicera",
    "indicerade": "indicera",
    "indicerades": "indicera",
    "indicerads": "indicera",
    "indicerande": "indicera",
    "indiceranden": "indicerande",
    "indicerandena": "indicerande",
    "indicerandenas": "indicerande",
    "indicerandens": "indicerande",
    "indicerandes": "indicerande",
    "indicerandet": "indicerande",
    "indicerandets": "indicerande",
    "indicerar": "indicera",
    "indiceras": "indicera",
    "indicerat": "indicera",
    "indicerats": "indicera",
    "indicerbara": "indicerbar",
    "indicerbarare": "indicerbar",
    "indicerbarares": "indicerbar",
    "indicerbaras": "indicerbar",
    "indicerbarast": "indicerbar",
    "indicerbaraste": "indicerbar",
    "indicerbarastes": "indicerbar",
    "indicerbarasts": "indicerbar",
    "indicerbare": "indicerbar",
    "indicerbares": "indicerbar",
    "indicerbarheten": "indicerbarhet",
    "indicerbarhetens": "indicerbarhet",
    "indicerbarhets": "indicerbarhet",
    "indicerbars": "indicerbar",
    "indicerbart": "indicerbar",
    "indicerbarts": "indicerbar",
    "indiceringar": "indicering",
    "indiceringarna": "indicering",
    "indiceringarnas": "indicering",
    "indiceringars": "indicering",
    "indiceringen": "indicering",
    "indiceringens": "indicering",
    "indicerings": "indicering",
    "indicie": "indicium",
    "indicier": "indicium",
    "indicierna": "indicium",
    "indiciernas": "indicium",
    "indiciers": "indicium",
    "indiciet": "indicium",
    "indiciets": "indicium",
    "indiciums": "indicium",
    "indiern": "indier",
    "indierna": "indier",
    "indiernas": "indier",
    "indierns": "indier",
    "indiers": "indier",
    "indiet": "indium",
    "indiets": "indium",
    "indifferensen": "indifferens",
    "indifferensens": "indifferens",
    "indifferenta": "indifferent",
    "indifferentare": "indifferent",
    "indifferentares": "indifferent",
    "indifferentas": "indifferent",
    "indifferentast": "indifferent",
    "indifferentaste": "indifferent",
    "indifferentastes": "indifferent",
    "indifferentasts": "indifferent",
    "indifferente": "indifferent",
    "indifferentes": "indifferent",
    "indifferentismen": "indifferentism",
    "indifferentismens": "indifferentism",
    "indifferentismer": "indifferentism",
    "indifferentismerna": "indifferentism",
    "indifferentismernas": "indifferentism",
    "indifferentismers": "indifferentism",
    "indifferentisms": "indifferentism",
    "indifferents": "indifferent",
    "indigenatsrätten": "indigenatsrätt",
    "indigenatsrättens": "indigenatsrätt",
    "indigenatsrätts": "indigenatsrätt",
    "indigestionen": "indigestion",
    "indigestionens": "indigestion",
    "indigestioner": "indigestion",
    "indigestionerna": "indigestion",
    "indigestionernas": "indigestion",
    "indigestioners": "indigestion",
    "indigestions": "indigestion",
    "indignationen": "indignation",
    "indignationens": "indignation",
    "indignationer": "indignation",
    "indignationerna": "indignation",
    "indignationernas": "indignation",
    "indignationers": "indignation",
    "indignations": "indignation",
    "indignationslitteraturen": "indignationslitteratur",
    "indignationslitteraturens": "indignationslitteratur",
    "indignationslitteraturs": "indignationslitteratur",
    "indignerade": "indignerad",
    "indignerades": "indigneras",
    "indignerads": "indignerad",
    "indignerat": "indignerad",
    "indignerats": "indigneras",
    "indigon": "indigo",
    "indigons": "indigo",
    "indigos": "indigo",
    "indikationen": "indikation",
    "indikationens": "indikation",
    "indikationer": "indikation",
    "indikationerna": "indikation",
    "indikationernas": "indikation",
    "indikationers": "indikation",
    "indikations": "indikation",
    "indikativa": "indikativ",
    "indikativare": "indikativ",
    "indikativares": "indikativ",
    "indikativas": "indikativ",
    "indikativast": "indikativ",
    "indikativaste": "indikativ",
    "indikativastes": "indikativ",
    "indikativasts": "indikativ",
    "indikative": "indikativ",
    "indikativen": "indikativ",
    "indikativens": "indikativ",
    "indikativer": "indikativ",
    "indikativerna": "indikativ",
    "indikativernas": "indikativ",
    "indikativers": "indikativ",
    "indikatives": "indikativ",
    "indikativs": "indikativ",
    "indikativt": "indikativ",
    "indikativts": "indikativ",
    "indikatorer": "indikator",
    "indikatorerna": "indikator",
    "indikatorernas": "indikator",
    "indikatorers": "indikator",
    "indikatorlamp": "indikatorlampa",
    "indikatorlampan": "indikatorlampa",
    "indikatorlampans": "indikatorlampa",
    "indikatorlampas": "indikatorlampa",
    "indikatorlampe": "indikatorlampa",
    "indikatorlampor": "indikatorlampa",
    "indikatorlamporna": "indikatorlampa",
    "indikatorlampornas": "indikatorlampa",
    "indikatorlampors": "indikatorlampa",
    "indikatorlamps": "indikatorlampa",
    "indikatorn": "indikator",
    "indikatorns": "indikator",
    "indikators": "indikator",
    "indikerad": "indikera",
    "indikerade": "indikera",
    "indikerades": "indikera",
    "indikerads": "indikera",
    "indikerande": "indikera",
    "indikeranden": "indikerande",
    "indikerandena": "indikerande",
    "indikerandenas": "indikerande",
    "indikerandens": "indikerande",
    "indikerandes": "indikerande",
    "indikerandet": "indikerande",
    "indikerandets": "indikerande",
    "indikerar": "indikera",
    "indikeras": "indikera",
    "indikerat": "indikera",
    "indikerats": "indikera",
    "indikerbara": "indikerbar",
    "indikerbarare": "indikerbar",
    "indikerbarares": "indikerbar",
    "indikerbaras": "indikerbar",
    "indikerbarast": "indikerbar",
    "indikerbaraste": "indikerbar",
    "indikerbarastes": "indikerbar",
    "indikerbarasts": "indikerbar",
    "indikerbare": "indikerbar",
    "indikerbares": "indikerbar",
    "indikerbarheten": "indikerbarhet",
    "indikerbarhetens": "indikerbarhet",
    "indikerbarhets": "indikerbarhet",
    "indikerbars": "indikerbar",
    "indikerbart": "indikerbar",
    "indikerbarts": "indikerbar",
    "indikeringar": "indikering",
    "indikeringarna": "indikering",
    "indikeringarnas": "indikering",
    "indikeringars": "indikering",
    "indikeringen": "indikering",
    "indikeringens": "indikering",
    "indikerings": "indikering",
    "indirekta": "indirekt",
    "indirektare": "indirekt",
    "indirektares": "indirekt",
    "indirektas": "indirekt",
    "indirektast": "indirekt",
    "indirektaste": "indirekt",
    "indirektastes": "indirekt",
    "indirektasts": "indirekt",
    "indirekte": "indirekt",
    "indirektes": "indirekt",
    "indirektheten": "indirekthet",
    "indirekthetens": "indirekthet",
    "indirekthets": "indirekthet",
    "indirekts": "indirekt",
    "indiska": "indisk",
    "indiskan": "indiska",
    "indiskans": "indiska",
    "indiskare": "indisk",
    "indiskares": "indisk",
    "indiskas": "indiska",
    "indiskast": "indisk",
    "indiskaste": "indisk",
    "indiskastes": "indisk",
    "indiskasts": "indisk",
    "indiske": "indiska",
    "indiskes": "indisk",
    "indiskor": "indiska",
    "indiskorna": "indiska",
    "indiskornas": "indiska",
    "indiskors": "indiska",
    "indiskreta": "indiskret",
    "indiskretare": "indiskret",
    "indiskretares": "indiskret",
    "indiskretas": "indiskret",
    "indiskretast": "indiskret",
    "indiskretaste": "indiskret",
    "indiskretastes": "indiskret",
    "indiskretasts": "indiskret",
    "indiskrete": "indiskret",
    "indiskretes": "indiskret",
    "indiskretheten": "indiskrethet",
    "indiskrethetens": "indiskrethet",
    "indiskrethets": "indiskrethet",
    "indiskretionen": "indiskretion",
    "indiskretionens": "indiskretion",
    "indiskretioner": "indiskretion",
    "indiskretionerna": "indiskretion",
    "indiskretionernas": "indiskretion",
    "indiskretioners": "indiskretion",
    "indiskretions": "indiskretion",
    "indiskrets": "indiskret",
    "indisks": "indisk",
    "indiskt": "indisk",
    "indiskts": "indisk",
    "indisponerade": "indisponerad",
    "indisponerades": "indisponerad",
    "indisponerads": "indisponerad",
    "indisponerat": "indisponerad",
    "indisponerats": "indisponerad",
    "indisponibels": "indisponibel",
    "indisponibelt": "indisponibel",
    "indisponibelts": "indisponibel",
    "indisponibla": "indisponibel",
    "indisponiblare": "indisponibel",
    "indisponiblares": "indisponibel",
    "indisponiblas": "indisponibel",
    "indisponiblast": "indisponibel",
    "indisponiblaste": "indisponibel",
    "indisponiblastes": "indisponibel",
    "indisponiblasts": "indisponibel",
    "indisponible": "indisponibel",
    "indisponibles": "indisponibel",
    "indispositionen": "indisposition",
    "indispositionens": "indisposition",
    "indispositioner": "indisposition",
    "indispositionerna": "indisposition",
    "indispositionernas": "indisposition",
    "indispositioners": "indisposition",
    "indispositions": "indisposition",
    "indiumet": "indium",
    "indiumets": "indium",
    "indiums": "indium",
    "individen": "individ",
    "individens": "individ",
    "individer": "individ",
    "individerna": "individ",
    "individernas": "individ",
    "individers": "individ",
    "individet": "individ",
    "individets": "individ",
    "individrelaterade": "individrelaterad",
    "individrelaterades": "individrelaterad",
    "individrelaterads": "individrelaterad",
    "individrelaterat": "individrelaterad",
    "individrelaterats": "individrelaterad",
    "individs": "individ",
    "individualiserad": "individualisera",
    "individualiserade": "individualisera",
    "individualiserades": "individualisera",
    "individualiserads": "individualisera",
    "individualiserande": "individualisera",
    "individualiseranden": "individualiserande",
    "individualiserandena": "individualiserande",
    "individualiserandenas": "individualiserande",
    "individualiserandens": "individualiserande",
    "individualiserandes": "individualiserande",
    "individualiserandet": "individualiserande",
    "individualiserandets": "individualiserande",
    "individualiserar": "individualisera",
    "individualiseras": "individualisera",
    "individualiserat": "individualisera",
    "individualiserats": "individualisera",
    "individualiserbara": "individualiserbar",
    "individualiserbarare": "individualiserbar",
    "individualiserbarares": "individualiserbar",
    "individualiserbaras": "individualiserbar",
    "individualiserbarast": "individualiserbar",
    "individualiserbaraste": "individualiserbar",
    "individualiserbarastes": "individualiserbar",
    "individualiserbarasts": "individualiserbar",
    "individualiserbare": "individualiserbar",
    "individualiserbares": "individualiserbar",
    "individualiserbarheten": "individualiserbarhet",
    "individualiserbarhetens": "individualiserbarhet",
    "individualiserbarhets": "individualiserbarhet",
    "individualiserbars": "individualiserbar",
    "individualiserbart": "individualiserbar",
    "individualiserbarts": "individualiserbar",
    "individualiseringar": "individualisering",
    "individualiseringarna": "individualisering",
    "individualiseringarnas": "individualisering",
    "individualiseringars": "individualisering",
    "individualiseringen": "individualisering",
    "individualiseringens": "individualisering",
    "individualiserings": "individualisering",
    "individualismen": "individualism",
    "individualismens": "individualism",
    "individualismer": "individualism",
    "individualismerna": "individualism",
    "individualismernas": "individualism",
    "individualismers": "individualism",
    "individualisms": "individualism",
    "individualisten": "individualist",
    "individualistens": "individualist",
    "individualister": "individualist",
    "individualisterna": "individualist",
    "individualisternas": "individualist",
    "individualisters": "individualist",
    "individualistiska": "individualistisk",
    "individualistiskare": "individualistisk",
    "individualistiskares": "individualistisk",
    "individualistiskas": "individualistisk",
    "individualistiskast": "individualistisk",
    "individualistiskaste": "individualistisk",
    "individualistiskastes": "individualistisk",
    "individualistiskasts": "individualistisk",
    "individualistiske": "individualistisk",
    "individualistiskes": "individualistisk",
    "individualistisks": "individualistisk",
    "individualistiskt": "individualistisk",
    "individualistiskts": "individualistisk",
    "individualists": "individualist",
    "individualiteten": "individualitet",
    "individualitetens": "individualitet",
    "individualiteter": "individualitet",
    "individualiteterna": "individualitet",
    "individualiteternas": "individualitet",
    "individualiteters": "individualitet",
    "individualitets": "individualitet",
    "individualpreventionen": "individualprevention",
    "individualpreventionens": "individualprevention",
    "individualpreventioner": "individualprevention",
    "individualpreventionerna": "individualprevention",
    "individualpreventionernas": "individualprevention",
    "individualpreventioners": "individualprevention",
    "individualpreventions": "individualprevention",
    "individualpsykologien": "individualpsykologi",
    "individualpsykologiens": "individualpsykologi",
    "individualpsykologin": "individualpsykologi",
    "individualpsykologins": "individualpsykologi",
    "individualpsykologis": "individualpsykologi",
    "individuella": "individuell",
    "individuellare": "individuell",
    "individuellares": "individuell",
    "individuellas": "individuell",
    "individuellast": "individuell",
    "individuellaste": "individuell",
    "individuellastes": "individuell",
    "individuellasts": "individuell",
    "individuelle": "individuell",
    "individuelles": "individuell",
    "individuells": "individuell",
    "individuellt": "individuell",
    "individuellts": "individuell",
    "indoeuropeiska": "indoeuropeisk",
    "indoeuropeiskare": "indoeuropeisk",
    "indoeuropeiskares": "indoeuropeisk",
    "indoeuropeiskas": "indoeuropeisk",
    "indoeuropeiskast": "indoeuropeisk",
    "indoeuropeiskaste": "indoeuropeisk",
    "indoeuropeiskastes": "indoeuropeisk",
    "indoeuropeiskasts": "indoeuropeisk",
    "indoeuropeiske": "indoeuropeisk",
    "indoeuropeiskes": "indoeuropeisk",
    "indoeuropeisks": "indoeuropeisk",
    "indoeuropeiskt": "indoeuropeisk",
    "indoeuropeiskts": "indoeuropeisk",
    "indoeuropéen": "indoeuropé",
    "indoeuropéens": "indoeuropé",
    "indoeuropéer": "indoeuropé",
    "indoeuropéerna": "indoeuropé",
    "indoeuropéernas": "indoeuropé",
    "indoeuropéers": "indoeuropé",
    "indoeuropén": "indoeuropé",
    "indoeuropéns": "indoeuropé",
    "indoeuropés": "indoeuropé",
    "indokinesiska": "indokinesisk",
    "indokinesiskare": "indokinesisk",
    "indokinesiskares": "indokinesisk",
    "indokinesiskas": "indokinesisk",
    "indokinesiskast": "indokinesisk",
    "indokinesiskaste": "indokinesisk",
    "indokinesiskastes": "indokinesisk",
    "indokinesiskasts": "indokinesisk",
    "indokinesiske": "indokinesisk",
    "indokinesiskes": "indokinesisk",
    "indokinesisks": "indokinesisk",
    "indokinesiskt": "indokinesisk",
    "indokinesiskts": "indokinesisk",
    "indoktrinerad": "indoktrinera",
    "indoktrinerade": "indoktrinera",
    "indoktrinerades": "indoktrinera",
    "indoktrinerads": "indoktrinera",
    "indoktrinerande": "indoktrinera",
    "indoktrineranden": "indoktrinerande",
    "indoktrinerandena": "indoktrinerande",
    "indoktrinerandenas": "indoktrinerande",
    "indoktrinerandens": "indoktrinerande",
    "indoktrinerandes": "indoktrinerande",
    "indoktrinerandet": "indoktrinerande",
    "indoktrinerandets": "indoktrinerande",
    "indoktrinerar": "indoktrinera",
    "indoktrineras": "indoktrinera",
    "indoktrinerat": "indoktrinera",
    "indoktrinerats": "indoktrinera",
    "indoktrinerbara": "indoktrinerbar",
    "indoktrinerbarare": "indoktrinerbar",
    "indoktrinerbarares": "indoktrinerbar",
    "indoktrinerbaras": "indoktrinerbar",
    "indoktrinerbarast": "indoktrinerbar",
    "indoktrinerbaraste": "indoktrinerbar",
    "indoktrinerbarastes": "indoktrinerbar",
    "indoktrinerbarasts": "indoktrinerbar",
    "indoktrinerbare": "indoktrinerbar",
    "indoktrinerbares": "indoktrinerbar",
    "indoktrinerbarheten": "indoktrinerbarhet",
    "indoktrinerbarhetens": "indoktrinerbarhet",
    "indoktrinerbarhets": "indoktrinerbarhet",
    "indoktrinerbars": "indoktrinerbar",
    "indoktrinerbart": "indoktrinerbar",
    "indoktrinerbarts": "indoktrinerbar",
    "indoktrineringar": "indoktrinering",
    "indoktrineringarna": "indoktrinering",
    "indoktrineringarnas": "indoktrinering",
    "indoktrineringars": "indoktrinering",
    "indoktrineringen": "indoktrinering",
    "indoktrineringens": "indoktrinering",
    "indoktrinerings": "indoktrinering",
    "indolensen": "indolens",
    "indolensens": "indolens",
    "indolenta": "indolent",
    "indolentare": "indolent",
    "indolentares": "indolent",
    "indolentas": "indolent",
    "indolentast": "indolent",
    "indolentaste": "indolent",
    "indolentastes": "indolent",
    "indolentasts": "indolent",
    "indolente": "indolent",
    "indolentes": "indolent",
    "indolents": "indolent",
    "indologen": "indolog",
    "indologens": "indolog",
    "indologer": "indolog",
    "indologerna": "indolog",
    "indologernas": "indolog",
    "indologers": "indolog",
    "indologien": "indologi",
    "indologiens": "indologi",
    "indologin": "indologi",
    "indologins": "indologi",
    "indologis": "indologi",
    "indologs": "indolog",
    "indonesen": "indones",
    "indonesens": "indones",
    "indoneser": "indones",
    "indoneserna": "indones",
    "indonesernas": "indones",
    "indonesers": "indones",
    "indonesisk": "indonesiska",
    "indonesiska": "indonesisk",
    "indonesiskan": "indonesiska",
    "indonesiskans": "indonesiska",
    "indonesiskare": "indonesisk",
    "indonesiskares": "indonesisk",
    "indonesiskas": "indonesiska",
    "indonesiskast": "indonesisk",
    "indonesiskaste": "indonesisk",
    "indonesiskastes": "indonesisk",
    "indonesiskasts": "indonesisk",
    "indonesiske": "indonesiska",
    "indonesiskes": "indonesisk",
    "indonesiskor": "indonesiska",
    "indonesiskorna": "indonesiska",
    "indonesiskornas": "indonesiska",
    "indonesiskors": "indonesiska",
    "indonesisks": "indonesisk",
    "indonesiskt": "indonesisk",
    "indonesiskts": "indonesisk",
    "indrag": "indra",
    "indraga": "indra",
    "indragande": "indra",
    "indraganden": "indragande",
    "indragandena": "indragande",
    "indragandenas": "indragande",
    "indragandens": "indragande",
    "indragandes": "indragande",
    "indragandet": "indragande",
    "indragandets": "indragande",
    "indragas": "indra",
    "indrage": "indra",
    "indragen": "indrag",
    "indragens": "indragen",
    "indrager": "indra",
    "indrages": "indra",
    "indraget": "indragen",
    "indragets": "indragen",
    "indragit": "indra",
    "indragits": "indra",
    "indragna": "indragen",
    "indragnare": "indragen",
    "indragnares": "indragen",
    "indragnas": "indragen",
    "indragnast": "indragen",
    "indragnaste": "indragen",
    "indragnastes": "indragen",
    "indragnasts": "indragen",
    "indragne": "indragen",
    "indragnes": "indragen",
    "indragningar": "indragning",
    "indragningarna": "indragning",
    "indragningarnas": "indragning",
    "indragningars": "indragning",
    "indragningen": "indragning",
    "indragningens": "indragning",
    "indragnings": "indragning",
    "indrags": "indrag",
    "indrar": "indra",
    "indras": "indra",
    "indrev": "indriva",
    "indrevs": "indriva",
    "indriv": "indriva",
    "indrivande": "indriva",
    "indrivanden": "indrivande",
    "indrivandena": "indrivande",
    "indrivandenas": "indrivande",
    "indrivandens": "indrivande",
    "indrivandes": "indrivande",
    "indrivandet": "indrivande",
    "indrivandets": "indrivande",
    "indrivas": "indriva",
    "indrive": "indriva",
    "indriven": "indriva",
    "indrivens": "indriva",
    "indriver": "indriva",
    "indrives": "indriva",
    "indrivet": "indriva",
    "indrivets": "indriva",
    "indrivit": "indriva",
    "indrivits": "indriva",
    "indrivna": "indriva",
    "indrivnas": "indriva",
    "indrivne": "indriva",
    "indrivnes": "indriva",
    "indrivningar": "indrivning",
    "indrivningarna": "indrivning",
    "indrivningarnas": "indrivning",
    "indrivningars": "indrivning",
    "indrivningen": "indrivning",
    "indrivningens": "indrivning",
    "indrivnings": "indrivning",
    "indrivs": "indriva",
    "indrog": "indra",
    "indroge": "indra",
    "indroges": "indra",
    "indrogs": "indra",
    "indräktiga": "indräktig",
    "indräktigare": "indräktig",
    "indräktigares": "indräktig",
    "indräktigas": "indräktig",
    "indräktigast": "indräktig",
    "indräktigaste": "indräktig",
    "indräktigastes": "indräktig",
    "indräktigasts": "indräktig",
    "indräktige": "indräktig",
    "indräktiges": "indräktig",
    "indräktigs": "indräktig",
    "indräktigt": "indräktig",
    "indräktigts": "indräktig",
    "indränk": "indränka",
    "indränkande": "indränka",
    "indränkanden": "indränkande",
    "indränkandena": "indränkande",
    "indränkandenas": "indränkande",
    "indränkandens": "indränkande",
    "indränkandes": "indränkande",
    "indränkandet": "indränkande",
    "indränkandets": "indränkande",
    "indränkas": "indränka",
    "indränker": "indränka",
    "indränkes": "indränka",
    "indränks": "indränka",
    "indränkt": "indränka",
    "indränkta": "indränka",
    "indränktas": "indränka",
    "indränkte": "indränka",
    "indränktes": "indränka",
    "indränkts": "indränka",
    "inducerad": "inducera",
    "inducerade": "inducera",
    "inducerades": "inducera",
    "inducerads": "inducera",
    "inducerande": "inducera",
    "induceranden": "inducerande",
    "inducerandena": "inducerande",
    "inducerandenas": "inducerande",
    "inducerandens": "inducerande",
    "inducerandes": "inducerande",
    "inducerandet": "inducerande",
    "inducerandets": "inducerande",
    "inducerar": "inducera",
    "induceras": "inducera",
    "inducerat": "inducera",
    "inducerats": "inducera",
    "inducerbara": "inducerbar",
    "inducerbarare": "inducerbar",
    "inducerbarares": "inducerbar",
    "inducerbaras": "inducerbar",
    "inducerbarast": "inducerbar",
    "inducerbaraste": "inducerbar",
    "inducerbarastes": "inducerbar",
    "inducerbarasts": "inducerbar",
    "inducerbare": "inducerbar",
    "inducerbares": "inducerbar",
    "inducerbarheten": "inducerbarhet",
    "inducerbarhetens": "inducerbarhet",
    "inducerbarhets": "inducerbarhet",
    "inducerbars": "inducerbar",
    "inducerbart": "inducerbar",
    "inducerbarts": "inducerbar",
    "induceringar": "inducering",
    "induceringarna": "inducering",
    "induceringarnas": "inducering",
    "induceringars": "inducering",
    "induceringen": "inducering",
    "induceringens": "inducering",
    "inducerings": "inducering",
    "induktansen": "induktans",
    "induktansens": "induktans",
    "induktionen": "induktion",
    "induktionens": "induktion",
    "induktioner": "induktion",
    "induktionerna": "induktion",
    "induktionernas": "induktion",
    "induktioners": "induktion",
    "induktions": "induktion",
    "induktionsapparaten": "induktionsapparat",
    "induktionsapparatens": "induktionsapparat",
    "induktionsapparater": "induktionsapparat",
    "induktionsapparaterna": "induktionsapparat",
    "induktionsapparaternas": "induktionsapparat",
    "induktionsapparaters": "induktionsapparat",
    "induktionsapparats": "induktionsapparat",
    "induktionsmotorer": "induktionsmotor",
    "induktionsmotorerna": "induktionsmotor",
    "induktionsmotorernas": "induktionsmotor",
    "induktionsmotorers": "induktionsmotor",
    "induktionsmotorn": "induktionsmotor",
    "induktionsmotorns": "induktionsmotor",
    "induktionsmotors": "induktionsmotor",
    "induktionsspol": "induktionsspole",
    "induktionsspolar": "induktionsspole",
    "induktionsspolarna": "induktionsspole",
    "induktionsspolarnas": "induktionsspole",
    "induktionsspolars": "induktionsspole",
    "induktionsspolen": "induktionsspole",
    "induktionsspolens": "induktionsspole",
    "induktionsspoles": "induktionsspole",
    "induktionsspols": "induktionsspole",
    "induktiva": "induktiv",
    "induktivare": "induktiv",
    "induktivares": "induktiv",
    "induktivas": "induktiv",
    "induktivast": "induktiv",
    "induktivaste": "induktiv",
    "induktivastes": "induktiv",
    "induktivasts": "induktiv",
    "induktive": "induktiv",
    "induktives": "induktiv",
    "induktivs": "induktiv",
    "induktivt": "induktiv",
    "induktivts": "induktiv",
    "induktorer": "induktor",
    "induktorerna": "induktor",
    "induktorernas": "induktor",
    "induktorers": "induktor",
    "induktorn": "induktor",
    "induktorns": "induktor",
    "induktors": "induktor",
    "indunst": "indunsta",
    "indunstad": "indunsta",
    "indunstade": "indunsta",
    "indunstades": "indunsta",
    "indunstads": "indunsta",
    "indunstande": "indunsta",
    "indunstanden": "indunstande",
    "indunstandena": "indunstande",
    "indunstandenas": "indunstande",
    "indunstandens": "indunstande",
    "indunstandes": "indunstande",
    "indunstandet": "indunstande",
    "indunstandets": "indunstande",
    "indunstar": "indunsta",
    "indunstas": "indunsta",
    "indunstat": "indunsta",
    "indunstats": "indunsta",
    "indunstningar": "indunstning",
    "indunstningarna": "indunstning",
    "indunstningarnas": "indunstning",
    "indunstningars": "indunstning",
    "indunstningen": "indunstning",
    "indunstningens": "indunstning",
    "indunstnings": "indunstning",
    "industriaktien": "industriaktie",
    "industriaktiens": "industriaktie",
    "industriaktier": "industriaktie",
    "industriaktierna": "industriaktie",
    "industriaktiernas": "industriaktie",
    "industriaktiers": "industriaktie",
    "industriakties": "industriaktie",
    "industrialiserad": "industrialisera",
    "industrialiserade": "industrialisera",
    "industrialiserades": "industrialisera",
    "industrialiserads": "industrialisera",
    "industrialiserande": "industrialisera",
    "industrialiseranden": "industrialiserande",
    "industrialiserandena": "industrialiserande",
    "industrialiserandenas": "industrialiserande",
    "industrialiserandens": "industrialiserande",
    "industrialiserandes": "industrialiserande",
    "industrialiserandet": "industrialiserande",
    "industrialiserandets": "industrialiserande",
    "industrialiserar": "industrialisera",
    "industrialiseras": "industrialisera",
    "industrialiserat": "industrialisera",
    "industrialiserats": "industrialisera",
    "industrialiserbara": "industrialiserbar",
    "industrialiserbarare": "industrialiserbar",
    "industrialiserbarares": "industrialiserbar",
    "industrialiserbaras": "industrialiserbar",
    "industrialiserbarast": "industrialiserbar",
    "industrialiserbaraste": "industrialiserbar",
    "industrialiserbarastes": "industrialiserbar",
    "industrialiserbarasts": "industrialiserbar",
    "industrialiserbare": "industrialiserbar",
    "industrialiserbares": "industrialiserbar",
    "industrialiserbarheten": "industrialiserbarhet",
    "industrialiserbarhetens": "industrialiserbarhet",
    "industrialiserbarhets": "industrialiserbarhet",
    "industrialiserbars": "industrialiserbar",
    "industrialiserbart": "industrialiserbar",
    "industrialiserbarts": "industrialiserbar",
    "industrialiseringar": "industrialisering",
    "industrialiseringarna": "industrialisering",
    "industrialiseringarnas": "industrialisering",
    "industrialiseringars": "industrialisering",
    "industrialiseringen": "industrialisering",
    "industrialiseringens": "industrialisering",
    "industrialiserings": "industrialisering",
    "industrialismen": "industrialism",
    "industrialismens": "industrialism",
    "industrialismer": "industrialism",
    "industrialismerna": "industrialism",
    "industrialismernas": "industrialism",
    "industrialismers": "industrialism",
    "industrialisms": "industrialism",
    "industrialistiska": "industrialistisk",
    "industrialistiskas": "industrialistisk",
    "industrialistiske": "industrialistisk",
    "industrialistiskes": "industrialistisk",
    "industrialistisks": "industrialistisk",
    "industrialistiskt": "industrialistisk",
    "industrialistiskts": "industrialistisk",
    "industriarbetar": "industriarbetare",
    "industriarbetaren": "industriarbetare",
    "industriarbetarens": "industriarbetare",
    "industriarbetares": "industriarbetare",
    "industriarbetarna": "industriarbetare",
    "industriarbetarnas": "industriarbetare",
    "industridiamanten": "industridiamant",
    "industridiamantens": "industridiamant",
    "industridiamanter": "industridiamant",
    "industridiamanterna": "industridiamant",
    "industridiamanternas": "industridiamant",
    "industridiamanters": "industridiamant",
    "industridiamants": "industridiamant",
    "industridöden": "industridöd",
    "industridödens": "industridöd",
    "industridöds": "industridöd",
    "industriella": "industriell",
    "industriellare": "industriell",
    "industriellares": "industriell",
    "industriellas": "industriell",
    "industriellast": "industriell",
    "industriellaste": "industriell",
    "industriellastes": "industriell",
    "industriellasts": "industriell",
    "industrielle": "industriell",
    "industrielles": "industriell",
    "industriells": "industriell",
    "industriellt": "industriell",
    "industriellts": "industriell",
    "industrien": "industri",
    "industriens": "industri",
    "industrier": "industri",
    "industrierna": "industri",
    "industriernas": "industri",
    "industriers": "industri",
    "industriförbunden": "industriförbund",
    "industriförbundens": "industriförbund",
    "industriförbundet": "industriförbund",
    "industriförbundets": "industriförbund",
    "industriförbunds": "industriförbund",
    "industrilandet": "industriland",
    "industrilandets": "industriland",
    "industrilands": "industriland",
    "industrilokalen": "industrilokal",
    "industrilokalens": "industrilokal",
    "industrilokaler": "industrilokal",
    "industrilokalerna": "industrilokal",
    "industrilokalernas": "industrilokal",
    "industrilokalers": "industrilokal",
    "industrilokals": "industrilokal",
    "industriländer": "industriland",
    "industriländerna": "industriland",
    "industriländernas": "industriland",
    "industriländers": "industriland",
    "industrimässiga": "industrimässig",
    "industrimässigare": "industrimässig",
    "industrimässigares": "industrimässig",
    "industrimässigas": "industrimässig",
    "industrimässigast": "industrimässig",
    "industrimässigaste": "industrimässig",
    "industrimässigastes": "industrimässig",
    "industrimässigasts": "industrimässig",
    "industrimässige": "industrimässig",
    "industrimässiges": "industrimässig",
    "industrimässigs": "industrimässig",
    "industrimässigt": "industrimässig",
    "industrimässigts": "industrimässig",
    "industrin": "industri",
    "industrins": "industri",
    "industrioljan": "industriolja",
    "industrioljans": "industriolja",
    "industrioljas": "industriolja",
    "industriolje": "industriolja",
    "industrioljor": "industriolja",
    "industrioljorna": "industriolja",
    "industrioljornas": "industriolja",
    "industrioljors": "industriolja",
    "industriolyck": "industriolycka",
    "industriolyckan": "industriolycka",
    "industriolyckans": "industriolycka",
    "industriolyckas": "industriolycka",
    "industriolycke": "industriolycka",
    "industriolyckor": "industriolycka",
    "industriolyckorna": "industriolycka",
    "industriolyckornas": "industriolycka",
    "industriolyckors": "industriolycka",
    "industriolycks": "industriolycka",
    "industriområden": "industriområde",
    "industriområdena": "industriområde",
    "industriområdenas": "industriområde",
    "industriområdens": "industriområde",
    "industriområdes": "industriområde",
    "industriområdet": "industriområde",
    "industriområdets": "industriområde",
    "industripolitiken": "industripolitik",
    "industripolitikens": "industripolitik",
    "industripolitiks": "industripolitik",
    "industripolitiska": "industripolitisk",
    "industripolitiskas": "industripolitisk",
    "industripolitiske": "industripolitisk",
    "industripolitiskes": "industripolitisk",
    "industripolitisks": "industripolitisk",
    "industripolitiskt": "industripolitisk",
    "industripolitiskts": "industripolitisk",
    "industriprodukten": "industriprodukt",
    "industriproduktens": "industriprodukt",
    "industriprodukter": "industriprodukt",
    "industriprodukterna": "industriprodukt",
    "industriprodukternas": "industriprodukt",
    "industriprodukters": "industriprodukt",
    "industriprodukts": "industriprodukt",
    "industriregionen": "industriregion",
    "industriregionens": "industriregion",
    "industriregioner": "industriregion",
    "industriregionerna": "industriregion",
    "industriregionernas": "industriregion",
    "industriregioners": "industriregion",
    "industriregions": "industriregion",
    "industrirobotar": "industrirobot",
    "industrirobotarna": "industrirobot",
    "industrirobotarnas": "industrirobot",
    "industrirobotars": "industrirobot",
    "industriroboten": "industrirobot",
    "industrirobotens": "industrirobot",
    "industrirobots": "industrirobot",
    "industris": "industri",
    "industrisamhällen": "industrisamhälle",
    "industrisamhällena": "industrisamhälle",
    "industrisamhällenas": "industrisamhälle",
    "industrisamhällens": "industrisamhälle",
    "industrisamhälles": "industrisamhälle",
    "industrisamhället": "industrisamhälle",
    "industrisamhällets": "industrisamhälle",
    "industrisamhälls": "industrisamhälle",
    "industrisemestern": "industrisemester",
    "industrisemesterns": "industrisemester",
    "industrisemesters": "industrisemester",
    "industrisemestrar": "industrisemester",
    "industrisemestrarna": "industrisemester",
    "industrisemestrarnas": "industrisemester",
    "industrisemestrars": "industrisemester",
    "industrispionages": "industrispionage",
    "industrispionaget": "industrispionage",
    "industrispionagets": "industrispionage",
    "ineffektiva": "ineffektiv",
    "ineffektivare": "ineffektiv",
    "ineffektivares": "ineffektiv",
    "ineffektivas": "ineffektiv",
    "ineffektivast": "ineffektiv",
    "ineffektivaste": "ineffektiv",
    "ineffektivastes": "ineffektiv",
    "ineffektivasts": "ineffektiv",
    "ineffektive": "ineffektiv",
    "ineffektives": "ineffektiv",
    "ineffektivs": "ineffektiv",
    "ineffektivt": "ineffektiv",
    "ineffektivts": "ineffektiv",
    "inessiven": "inessiv",
    "inessivens": "inessiv",
    "inessiver": "inessiv",
    "inessiverna": "inessiv",
    "inessivernas": "inessiv",
    "inessivers": "inessiv",
    "inessivs": "inessiv",
    "inexakta": "inexakt",
    "inexaktare": "inexakt",
    "inexaktares": "inexakt",
    "inexaktas": "inexakt",
    "inexaktast": "inexakt",
    "inexaktaste": "inexakt",
    "inexaktastes": "inexakt",
    "inexaktasts": "inexakt",
    "inexakte": "inexakt",
    "inexaktes": "inexakt",
    "inexaktheten": "inexakthet",
    "inexakthetens": "inexakthet",
    "inexakthets": "inexakthet",
    "inexakts": "inexakt",
    "infall": "infalla",
    "infallande": "infalla",
    "infallanden": "infallande",
    "infallandena": "infallande",
    "infallandenas": "infallande",
    "infallandens": "infallande",
    "infallandes": "infallande",
    "infallandet": "infallande",
    "infallandets": "infallande",
    "infallas": "infalla",
    "infalle": "infalla",
    "infallen": "infalla",
    "infallens": "infallen",
    "infaller": "infalla",
    "infalles": "infalla",
    "infallet": "infallen",
    "infallets": "infallen",
    "infallit": "infalla",
    "infallits": "infalla",
    "infallna": "infallen",
    "infallnare": "infallen",
    "infallnares": "infallen",
    "infallnas": "infallen",
    "infallnast": "infallen",
    "infallnaste": "infallen",
    "infallnastes": "infallen",
    "infallnasts": "infallen",
    "infallne": "infallen",
    "infallnes": "infallen",
    "infalls": "infalla",
    "infallsrika": "infallsrik",
    "infallsrikare": "infallsrik",
    "infallsrikares": "infallsrik",
    "infallsrikas": "infallsrik",
    "infallsrikast": "infallsrik",
    "infallsrikaste": "infallsrik",
    "infallsrikastes": "infallsrik",
    "infallsrikasts": "infallsrik",
    "infallsrike": "infallsrik",
    "infallsrikes": "infallsrik",
    "infallsrikheten": "infallsrikhet",
    "infallsrikhetens": "infallsrikhet",
    "infallsrikhets": "infallsrikhet",
    "infallsriks": "infallsrik",
    "infallsrikt": "infallsrik",
    "infallsrikts": "infallsrik",
    "infallsvinkeln": "infallsvinkel",
    "infallsvinkelns": "infallsvinkel",
    "infallsvinkels": "infallsvinkel",
    "infallsvinklar": "infallsvinkel",
    "infallsvinklarna": "infallsvinkel",
    "infallsvinklarnas": "infallsvinkel",
    "infallsvinklars": "infallsvinkel",
    "infama": "infam",
    "infamare": "infam",
    "infamares": "infam",
    "infamas": "infam",
    "infamast": "infam",
    "infamaste": "infam",
    "infamastes": "infam",
    "infamasts": "infam",
    "infame": "infam",
    "infames": "infam",
    "infamien": "infami",
    "infamiens": "infami",
    "infamier": "infami",
    "infamierna": "infami",
    "infamiernas": "infami",
    "infamiers": "infami",
    "infamin": "infami",
    "infamins": "infami",
    "infamis": "infami",
    "infams": "infam",
    "infamt": "infam",
    "infamts": "infam",
    "infanten": "infant",
    "infantens": "infant",
    "infanter": "infant",
    "infanteriet": "infanteri",
    "infanteriets": "infanteri",
    "infanterikompanier": "infanterikompani",
    "infanterikompanierna": "infanterikompani",
    "infanterikompaniernas": "infanterikompani",
    "infanterikompaniers": "infanterikompani",
    "infanterikompaniet": "infanterikompani",
    "infanterikompaniets": "infanterikompani",
    "infanterikompanis": "infanterikompani",
    "infanterikompanit": "infanterikompani",
    "infanterikompanits": "infanterikompani",
    "infanterimarschen": "infanterimarsch",
    "infanterimarschens": "infanterimarsch",
    "infanterimarscher": "infanterimarsch",
    "infanterimarscherna": "infanterimarsch",
    "infanterimarschernas": "infanterimarsch",
    "infanterimarschers": "infanterimarsch",
    "infanterimarschs": "infanterimarsch",
    "infanteris": "infanteri",
    "infanteristen": "infanterist",
    "infanteristens": "infanterist",
    "infanterister": "infanterist",
    "infanteristerna": "infanterist",
    "infanteristernas": "infanterist",
    "infanteristers": "infanterist",
    "infanterists": "infanterist",
    "infanterit": "infanteri",
    "infanterits": "infanteri",
    "infanterna": "infant",
    "infanternas": "infant",
    "infanters": "infant",
    "infantila": "infantil",
    "infantilare": "infantil",
    "infantilares": "infantil",
    "infantilas": "infantil",
    "infantilast": "infantil",
    "infantilaste": "infantil",
    "infantilastes": "infantil",
    "infantilasts": "infantil",
    "infantile": "infantil",
    "infantiles": "infantil",
    "infantilismen": "infantilism",
    "infantilismens": "infantilism",
    "infantilismer": "infantilism",
    "infantilismerna": "infantilism",
    "infantilismernas": "infantilism",
    "infantilismers": "infantilism",
    "infantilisms": "infantilism",
    "infantils": "infantil",
    "infantilt": "infantil",
    "infantilts": "infantil",
    "infantinnan": "infantinna",
    "infantinnans": "infantinna",
    "infantinnas": "infantinna",
    "infantinne": "infantinna",
    "infantinnor": "infantinna",
    "infantinnorna": "infantinna",
    "infantinnornas": "infantinna",
    "infantinnors": "infantinna",
    "infants": "infant",
    "infarkten": "infarkt",
    "infarktens": "infarkt",
    "infarkter": "infarkt",
    "infarkterna": "infarkt",
    "infarkternas": "infarkt",
    "infarkters": "infarkt",
    "infarkts": "infarkt",
    "infarten": "infart",
    "infartens": "infart",
    "infarter": "infart",
    "infarterna": "infart",
    "infarternas": "infart",
    "infarters": "infart",
    "infarts": "infart",
    "infartsleden": "infartsled",
    "infartsledens": "infartsled",
    "infartsleder": "infartsled",
    "infartslederna": "infartsled",
    "infartsledernas": "infartsled",
    "infartsleders": "infartsled",
    "infartsleds": "infartsled",
    "infartsportar": "infartsport",
    "infartsportarna": "infartsport",
    "infartsportarnas": "infartsport",
    "infartsportars": "infartsport",
    "infartsporten": "infartsport",
    "infartsportens": "infartsport",
    "infartsports": "infartsport",
    "infartsränn": "infartsränna",
    "infartsrännan": "infartsränna",
    "infartsrännans": "infartsränna",
    "infartsrännas": "infartsränna",
    "infartsränne": "infartsränna",
    "infartsrännor": "infartsränna",
    "infartsrännorna": "infartsränna",
    "infartsrännornas": "infartsränna",
    "infartsrännors": "infartsränna",
    "infartsränns": "infartsränna",
    "infatt": "infatta",
    "infattad": "infatta",
    "infattade": "infatta",
    "infattades": "infatta",
    "infattads": "infatta",
    "infattande": "infatta",
    "infattanden": "infattande",
    "infattandena": "infattande",
    "infattandenas": "infattande",
    "infattandens": "infattande",
    "infattandes": "infattande",
    "infattandet": "infattande",
    "infattandets": "infattande",
    "infattar": "infatta",
    "infattas": "infatta",
    "infattat": "infatta",
    "infattats": "infatta",
    "infattningar": "infattning",
    "infattningarna": "infattning",
    "infattningarnas": "infattning",
    "infattningars": "infattning",
    "infattningen": "infattning",
    "infattningens": "infattning",
    "infattnings": "infattning",
    "infekterad": "infektera",
    "infekterade": "infektera",
    "infekterades": "infektera",
    "infekterads": "infektera",
    "infekterande": "infektera",
    "infekteranden": "infekterande",
    "infekterandena": "infekterande",
    "infekterandenas": "infekterande",
    "infekterandens": "infekterande",
    "infekterandes": "infekterande",
    "infekterandet": "infekterande",
    "infekterandets": "infekterande",
    "infekterar": "infektera",
    "infekteras": "infektera",
    "infekterat": "infektera",
    "infekterats": "infektera",
    "infekterbara": "infekterbar",
    "infekterbarare": "infekterbar",
    "infekterbarares": "infekterbar",
    "infekterbaras": "infekterbar",
    "infekterbarast": "infekterbar",
    "infekterbaraste": "infekterbar",
    "infekterbarastes": "infekterbar",
    "infekterbarasts": "infekterbar",
    "infekterbare": "infekterbar",
    "infekterbares": "infekterbar",
    "infekterbarheten": "infekterbarhet",
    "infekterbarhetens": "infekterbarhet",
    "infekterbarhets": "infekterbarhet",
    "infekterbars": "infekterbar",
    "infekterbart": "infekterbar",
    "infekterbarts": "infekterbar",
    "infekteringar": "infektering",
    "infekteringarna": "infektering",
    "infekteringarnas": "infektering",
    "infekteringars": "infektering",
    "infekteringen": "infektering",
    "infekteringens": "infektering",
    "infekterings": "infektering",
    "infektionen": "infektion",
    "infektionens": "infektion",
    "infektioner": "infektion",
    "infektionerna": "infektion",
    "infektionernas": "infektion",
    "infektioners": "infektion",
    "infektions": "infektion",
    "infektionshärdar": "infektionshärd",
    "infektionshärdarna": "infektionshärd",
    "infektionshärdarnas": "infektionshärd",
    "infektionshärdars": "infektionshärd",
    "infektionshärden": "infektionshärd",
    "infektionshärdens": "infektionshärd",
    "infektionshärds": "infektionshärd",
    "infektionssjukdomar": "infektionssjukdom",
    "infektionssjukdomarna": "infektionssjukdom",
    "infektionssjukdomarnas": "infektionssjukdom",
    "infektionssjukdomars": "infektionssjukdom",
    "infektionssjukdomen": "infektionssjukdom",
    "infektionssjukdomens": "infektionssjukdom",
    "infektionssjukdoms": "infektionssjukdom",
    "infektiösa": "infektiös",
    "infektiösare": "infektiös",
    "infektiösares": "infektiös",
    "infektiösas": "infektiös",
    "infektiösast": "infektiös",
    "infektiösaste": "infektiös",
    "infektiösastes": "infektiös",
    "infektiösasts": "infektiös",
    "infektiöse": "infektiös",
    "infektiöses": "infektiös",
    "infektiöst": "infektiös",
    "infektiösts": "infektiös",
    "infernaliska": "infernalisk",
    "infernaliskare": "infernalisk",
    "infernaliskares": "infernalisk",
    "infernaliskas": "infernalisk",
    "infernaliskast": "infernalisk",
    "infernaliskaste": "infernalisk",
    "infernaliskastes": "infernalisk",
    "infernaliskasts": "infernalisk",
    "infernaliske": "infernalisk",
    "infernaliskes": "infernalisk",
    "infernalisks": "infernalisk",
    "infernaliskt": "infernalisk",
    "infernaliskts": "infernalisk",
    "infernon": "inferno",
    "infernona": "inferno",
    "infernonas": "inferno",
    "infernons": "inferno",
    "infernos": "inferno",
    "infernot": "inferno",
    "infernots": "inferno",
    "infett": "infetta",
    "infettad": "infetta",
    "infettade": "infetta",
    "infettades": "infetta",
    "infettads": "infetta",
    "infettande": "infetta",
    "infettanden": "infettande",
    "infettandena": "infettande",
    "infettandenas": "infettande",
    "infettandens": "infettande",
    "infettandes": "infettande",
    "infettandet": "infettande",
    "infettandets": "infettande",
    "infettar": "infetta",
    "infettas": "infetta",
    "infettat": "infetta",
    "infettats": "infetta",
    "infiltrationen": "infiltration",
    "infiltrationens": "infiltration",
    "infiltrationer": "infiltration",
    "infiltrationerna": "infiltration",
    "infiltrationernas": "infiltration",
    "infiltrationers": "infiltration",
    "infiltrations": "infiltration",
    "infiltratören": "infiltratör",
    "infiltratörens": "infiltratör",
    "infiltratörer": "infiltratör",
    "infiltratörerna": "infiltratör",
    "infiltratörernas": "infiltratör",
    "infiltratörers": "infiltratör",
    "infiltratörs": "infiltratör",
    "infiltrerad": "infiltrera",
    "infiltrerade": "infiltrera",
    "infiltrerades": "infiltrera",
    "infiltrerads": "infiltrera",
    "infiltrerande": "infiltrera",
    "infiltreranden": "infiltrerande",
    "infiltrerandena": "infiltrerande",
    "infiltrerandenas": "infiltrerande",
    "infiltrerandens": "infiltrerande",
    "infiltrerandes": "infiltrerande",
    "infiltrerandet": "infiltrerande",
    "infiltrerandets": "infiltrerande",
    "infiltrerar": "infiltrera",
    "infiltreras": "infiltrera",
    "infiltrerat": "infiltrera",
    "infiltrerats": "infiltrera",
    "infiltrerbara": "infiltrerbar",
    "infiltrerbarare": "infiltrerbar",
    "infiltrerbarares": "infiltrerbar",
    "infiltrerbaras": "infiltrerbar",
    "infiltrerbarast": "infiltrerbar",
    "infiltrerbaraste": "infiltrerbar",
    "infiltrerbarastes": "infiltrerbar",
    "infiltrerbarasts": "infiltrerbar",
    "infiltrerbare": "infiltrerbar",
    "infiltrerbares": "infiltrerbar",
    "infiltrerbarheten": "infiltrerbarhet",
    "infiltrerbarhetens": "infiltrerbarhet",
    "infiltrerbarhets": "infiltrerbarhet",
    "infiltrerbars": "infiltrerbar",
    "infiltrerbart": "infiltrerbar",
    "infiltrerbarts": "infiltrerbar",
    "infiltreringar": "infiltrering",
    "infiltreringarna": "infiltrering",
    "infiltreringarnas": "infiltrering",
    "infiltreringars": "infiltrering",
    "infiltreringen": "infiltrering",
    "infiltreringens": "infiltrering",
    "infiltrerings": "infiltrering",
    "infinita": "infinit",
    "infinitare": "infinit",
    "infinitares": "infinit",
    "infinitas": "infinit",
    "infinitast": "infinit",
    "infinitaste": "infinit",
    "infinitastes": "infinit",
    "infinitasts": "infinit",
    "infinite": "infinit",
    "infinites": "infinit",
    "infinitheten": "infinithet",
    "infinithetens": "infinithet",
    "infinithets": "infinithet",
    "infinitiven": "infinitiv",
    "infinitivens": "infinitiv",
    "infinitiver": "infinitiv",
    "infinitiverna": "infinitiv",
    "infinitivernas": "infinitiv",
    "infinitivers": "infinitiv",
    "infinitivmärken": "infinitivmärke",
    "infinitivmärkena": "infinitivmärke",
    "infinitivmärkenas": "infinitivmärke",
    "infinitivmärkens": "infinitivmärke",
    "infinitivmärkes": "infinitivmärke",
    "infinitivmärket": "infinitivmärke",
    "infinitivmärkets": "infinitivmärke",
    "infinitivs": "infinitiv",
    "infinits": "infinit",
    "infixen": "infix",
    "infixens": "infix",
    "infixet": "infix",
    "infixets": "infix",
    "inflammationen": "inflammation",
    "inflammationens": "inflammation",
    "inflammationer": "inflammation",
    "inflammationerna": "inflammation",
    "inflammationernas": "inflammation",
    "inflammationers": "inflammation",
    "inflammations": "inflammation",
    "inflammationshärdar": "inflammationshärd",
    "inflammationshärdarna": "inflammationshärd",
    "inflammationshärdarnas": "inflammationshärd",
    "inflammationshärdars": "inflammationshärd",
    "inflammationshärden": "inflammationshärd",
    "inflammationshärdens": "inflammationshärd",
    "inflammationshärds": "inflammationshärd",
    "inflammatoriska": "inflammatorisk",
    "inflammatoriskare": "inflammatorisk",
    "inflammatoriskares": "inflammatorisk",
    "inflammatoriskas": "inflammatorisk",
    "inflammatoriskast": "inflammatorisk",
    "inflammatoriskaste": "inflammatorisk",
    "inflammatoriskastes": "inflammatorisk",
    "inflammatoriskasts": "inflammatorisk",
    "inflammatoriske": "inflammatorisk",
    "inflammatoriskes": "inflammatorisk",
    "inflammatorisks": "inflammatorisk",
    "inflammatoriskt": "inflammatorisk",
    "inflammatoriskts": "inflammatorisk",
    "inflammerad": "inflammera",
    "inflammerade": "inflammerad",
    "inflammerades": "inflammerad",
    "inflammerads": "inflammerad",
    "inflammerande": "inflammera",
    "inflammeranden": "inflammerande",
    "inflammerandena": "inflammerande",
    "inflammerandenas": "inflammerande",
    "inflammerandens": "inflammerande",
    "inflammerandes": "inflammerande",
    "inflammerandet": "inflammerande",
    "inflammerandets": "inflammerande",
    "inflammerar": "inflammera",
    "inflammeras": "inflammera",
    "inflammerat": "inflammerad",
    "inflammerats": "inflammerad",
    "inflammerbara": "inflammerbar",
    "inflammerbarare": "inflammerbar",
    "inflammerbarares": "inflammerbar",
    "inflammerbaras": "inflammerbar",
    "inflammerbarast": "inflammerbar",
    "inflammerbaraste": "inflammerbar",
    "inflammerbarastes": "inflammerbar",
    "inflammerbarasts": "inflammerbar",
    "inflammerbare": "inflammerbar",
    "inflammerbares": "inflammerbar",
    "inflammerbarheten": "inflammerbarhet",
    "inflammerbarhetens": "inflammerbarhet",
    "inflammerbarhets": "inflammerbarhet",
    "inflammerbars": "inflammerbar",
    "inflammerbart": "inflammerbar",
    "inflammerbarts": "inflammerbar",
    "inflammeringar": "inflammering",
    "inflammeringarna": "inflammering",
    "inflammeringarnas": "inflammering",
    "inflammeringars": "inflammering",
    "inflammeringen": "inflammering",
    "inflammeringens": "inflammering",
    "inflammerings": "inflammering",
    "inflationen": "inflation",
    "inflationens": "inflation",
    "inflationer": "inflation",
    "inflationerna": "inflation",
    "inflationernas": "inflation",
    "inflationers": "inflation",
    "inflationistiska": "inflationistisk",
    "inflationistiskare": "inflationistisk",
    "inflationistiskares": "inflationistisk",
    "inflationistiskas": "inflationistisk",
    "inflationistiskast": "inflationistisk",
    "inflationistiskaste": "inflationistisk",
    "inflationistiskastes": "inflationistisk",
    "inflationistiskasts": "inflationistisk",
    "inflationistiske": "inflationistisk",
    "inflationistiskes": "inflationistisk",
    "inflationistisks": "inflationistisk",
    "inflationistiskt": "inflationistisk",
    "inflationistiskts": "inflationistisk",
    "inflations": "inflation",
    "inflationsfasen": "inflationsfas",
    "inflationsfasens": "inflationsfas",
    "inflationsfaser": "inflationsfas",
    "inflationsfaserna": "inflationsfas",
    "inflationsfasernas": "inflationsfas",
    "inflationsfasers": "inflationsfas",
    "inflationsmodellen": "inflationsmodell",
    "inflationsmodellens": "inflationsmodell",
    "inflationsmodeller": "inflationsmodell",
    "inflationsmodellerna": "inflationsmodell",
    "inflationsmodellernas": "inflationsmodell",
    "inflationsmodellers": "inflationsmodell",
    "inflationsmodells": "inflationsmodell",
    "inflationsskydden": "inflationsskydd",
    "inflationsskyddens": "inflationsskydd",
    "inflationsskyddet": "inflationsskydd",
    "inflationsskyddets": "inflationsskydd",
    "inflationsskydds": "inflationsskydd",
    "inflationsspiralen": "inflationsspiral",
    "inflationsspiralens": "inflationsspiral",
    "inflationsspiraler": "inflationsspiral",
    "inflationsspiralerna": "inflationsspiral",
    "inflationsspiralernas": "inflationsspiral",
    "inflationsspiralers": "inflationsspiral",
    "inflationsspirals": "inflationsspiral",
    "inflationstakten": "inflationstakt",
    "inflationstaktens": "inflationstakt",
    "inflationstakter": "inflationstakt",
    "inflationstakterna": "inflationstakt",
    "inflationstakternas": "inflationstakt",
    "inflationstakters": "inflationstakt",
    "inflationstakts": "inflationstakt",
    "inflationsteorien": "inflationsteori",
    "inflationsteoriens": "inflationsteori",
    "inflationsteorier": "inflationsteori",
    "inflationsteorierna": "inflationsteori",
    "inflationsteoriernas": "inflationsteori",
    "inflationsteoriers": "inflationsteori",
    "inflationsteorin": "inflationsteori",
    "inflationsteorins": "inflationsteori",
    "inflationsteoris": "inflationsteori",
    "inflatoriska": "inflatorisk",
    "inflatoriskare": "inflatorisk",
    "inflatoriskares": "inflatorisk",
    "inflatoriskas": "inflatorisk",
    "inflatoriskast": "inflatorisk",
    "inflatoriskaste": "inflatorisk",
    "inflatoriskastes": "inflatorisk",
    "inflatoriskasts": "inflatorisk",
    "inflatoriske": "inflatorisk",
    "inflatoriskes": "inflatorisk",
    "inflatorisks": "inflatorisk",
    "inflatoriskt": "inflatorisk",
    "inflatoriskts": "inflatorisk",
    "inflick": "inflicka",
    "inflickad": "inflicka",
    "inflickade": "inflicka",
    "inflickades": "inflicka",
    "inflickads": "inflicka",
    "inflickande": "inflicka",
    "inflickanden": "inflickande",
    "inflickandena": "inflickande",
    "inflickandenas": "inflickande",
    "inflickandens": "inflickande",
    "inflickandes": "inflickande",
    "inflickandet": "inflickande",
    "inflickandets": "inflickande",
    "inflickar": "inflicka",
    "inflickas": "inflicka",
    "inflickat": "inflicka",
    "inflickats": "inflicka",
    "inflik": "inflika",
    "inflikad": "inflika",
    "inflikade": "inflika",
    "inflikades": "inflika",
    "inflikads": "inflika",
    "inflikande": "inflika",
    "inflikanden": "inflikande",
    "inflikandena": "inflikande",
    "inflikandenas": "inflikande",
    "inflikandens": "inflikande",
    "inflikandes": "inflikande",
    "inflikandet": "inflikande",
    "inflikandets": "inflikande",
    "inflikar": "inflika",
    "inflikas": "inflika",
    "inflikat": "inflika",
    "inflikats": "inflika",
    "influensadödsfallen": "influensadödsfall",
    "influensadödsfallens": "influensadödsfall",
    "influensadödsfallet": "influensadödsfall",
    "influensadödsfallets": "influensadödsfall",
    "influensadödsfalls": "influensadödsfall",
    "influensafallen": "influensafall",
    "influensafallens": "influensafall",
    "influensafallet": "influensafall",
    "influensafallets": "influensafall",
    "influensafalls": "influensafall",
    "influensamedicinen": "influensamedicin",
    "influensamedicinens": "influensamedicin",
    "influensamediciner": "influensamedicin",
    "influensamedicinerna": "influensamedicin",
    "influensamedicinernas": "influensamedicin",
    "influensamediciners": "influensamedicin",
    "influensamedicins": "influensamedicin",
    "influensan": "influensa",
    "influensans": "influensa",
    "influensas": "influensa",
    "influensen": "influens",
    "influensens": "influens",
    "influenser": "influens",
    "influenserna": "influens",
    "influensernas": "influens",
    "influensers": "influens",
    "influensmaskinen": "influensmaskin",
    "influensmaskinens": "influensmaskin",
    "influensmaskiner": "influensmaskin",
    "influensmaskinerna": "influensmaskin",
    "influensmaskinernas": "influensmaskin",
    "influensmaskiners": "influensmaskin",
    "influensmaskins": "influensmaskin",
    "influensor": "influensa",
    "influensorna": "influensa",
    "influensornas": "influensa",
    "influensors": "influensa",
    "influerad": "influera",
    "influerade": "influera",
    "influerades": "influera",
    "influerads": "influera",
    "influerande": "influera",
    "influeranden": "influerande",
    "influerandena": "influerande",
    "influerandenas": "influerande",
    "influerandens": "influerande",
    "influerandes": "influerande",
    "influerandet": "influerande",
    "influerandets": "influerande",
    "influerar": "influera",
    "influeras": "influera",
    "influerat": "influera",
    "influerats": "influera",
    "influerbara": "influerbar",
    "influerbarare": "influerbar",
    "influerbarares": "influerbar",
    "influerbaras": "influerbar",
    "influerbarast": "influerbar",
    "influerbaraste": "influerbar",
    "influerbarastes": "influerbar",
    "influerbarasts": "influerbar",
    "influerbare": "influerbar",
    "influerbares": "influerbar",
    "influerbarheten": "influerbarhet",
    "influerbarhetens": "influerbarhet",
    "influerbarhets": "influerbarhet",
    "influerbars": "influerbar",
    "influerbart": "influerbar",
    "influerbarts": "influerbar",
    "influeringar": "influering",
    "influeringarna": "influering",
    "influeringarnas": "influering",
    "influeringars": "influering",
    "influeringen": "influering",
    "influeringens": "influering",
    "influerings": "influering",
    "influten": "inflyta",
    "influtens": "inflyta",
    "influtet": "inflyta",
    "influtets": "inflyta",
    "influtit": "inflyta",
    "influtits": "inflyta",
    "influtna": "inflyta",
    "influtnas": "inflyta",
    "influtne": "inflyta",
    "influtnes": "inflyta",
    "inflygningar": "inflygning",
    "inflygningarna": "inflygning",
    "inflygningarnas": "inflygning",
    "inflygningars": "inflygning",
    "inflygningen": "inflygning",
    "inflygningens": "inflygning",
    "inflygnings": "inflygning",
    "inflyt": "inflyta",
    "inflytande": "inflyta",
    "inflytanden": "inflytande",
    "inflytandena": "inflytande",
    "inflytandenas": "inflytande",
    "inflytandens": "inflytande",
    "inflytandes": "inflytande",
    "inflytandet": "inflytande",
    "inflytandets": "inflytande",
    "inflytas": "inflyta",
    "inflyte": "inflyta",
    "inflytelsen": "inflytelse",
    "inflytelsens": "inflytelse",
    "inflytelser": "inflytelse",
    "inflytelserika": "inflytelserik",
    "inflytelserikare": "inflytelserik",
    "inflytelserikares": "inflytelserik",
    "inflytelserikas": "inflytelserik",
    "inflytelserikast": "inflytelserik",
    "inflytelserikaste": "inflytelserik",
    "inflytelserikastes": "inflytelserik",
    "inflytelserikasts": "inflytelserik",
    "inflytelserike": "inflytelserik",
    "inflytelserikes": "inflytelserik",
    "inflytelserikheten": "inflytelserikhet",
    "inflytelserikhetens": "inflytelserikhet",
    "inflytelserikhets": "inflytelserikhet",
    "inflytelseriks": "inflytelserik",
    "inflytelserikt": "inflytelserik",
    "inflytelserikts": "inflytelserik",
    "inflytelserna": "inflytelse",
    "inflytelsernas": "inflytelse",
    "inflytelsers": "inflytelse",
    "inflytelses": "inflytelse",
    "inflyter": "inflyta",
    "inflytes": "inflyta",
    "inflyts": "inflyta",
    "inflytt": "inflytta",
    "inflyttad": "inflytta",
    "inflyttade": "inflytta",
    "inflyttades": "inflytta",
    "inflyttads": "inflytta",
    "inflyttande": "inflytta",
    "inflyttanden": "inflyttande",
    "inflyttandena": "inflyttande",
    "inflyttandenas": "inflyttande",
    "inflyttandens": "inflyttande",
    "inflyttandes": "inflyttande",
    "inflyttandet": "inflyttande",
    "inflyttandets": "inflyttande",
    "inflyttar": "inflytta",
    "inflyttas": "inflytta",
    "inflyttat": "inflytta",
    "inflyttats": "inflytta",
    "inflyttningar": "inflyttning",
    "inflyttningarna": "inflyttning",
    "inflyttningarnas": "inflyttning",
    "inflyttningars": "inflyttning",
    "inflyttningen": "inflyttning",
    "inflyttningens": "inflyttning",
    "inflyttnings": "inflyttning",
    "inflät": "infläta",
    "inflätad": "infläta",
    "inflätade": "infläta",
    "inflätades": "infläta",
    "inflätads": "infläta",
    "inflätande": "infläta",
    "inflätanden": "inflätande",
    "inflätandena": "inflätande",
    "inflätandenas": "inflätande",
    "inflätandens": "inflätande",
    "inflätandes": "inflätande",
    "inflätandet": "inflätande",
    "inflätandets": "inflätande",
    "inflätar": "infläta",
    "inflätas": "infläta",
    "inflätat": "infläta",
    "inflätats": "infläta",
    "inflöden": "inflöde",
    "inflödena": "inflöde",
    "inflödenas": "inflöde",
    "inflödens": "inflöde",
    "inflödes": "inflöde",
    "inflödet": "inflöde",
    "inflödets": "inflöde",
    "inflöt": "inflyta",
    "inflöte": "inflyta",
    "inflötes": "inflyta",
    "inflöts": "inflyta",
    "infodrad": "infodra",
    "infodrade": "infodra",
    "infodrades": "infodra",
    "infodrads": "infodra",
    "infodrande": "infodra",
    "infodranden": "infodrande",
    "infodrandena": "infodrande",
    "infodrandenas": "infodrande",
    "infodrandens": "infodrande",
    "infodrandes": "infodrande",
    "infodrandet": "infodrande",
    "infodrandets": "infodrande",
    "infodrar": "infodra",
    "infodras": "infodra",
    "infodrat": "infodra",
    "infodrats": "infodra",
    "infog": "infoga",
    "infogad": "infoga",
    "infogade": "infoga",
    "infogades": "infoga",
    "infogads": "infoga",
    "infogande": "infoga",
    "infoganden": "infogande",
    "infogandena": "infogande",
    "infogandenas": "infogande",
    "infogandens": "infogande",
    "infogandes": "infogande",
    "infogandet": "infogande",
    "infogandets": "infogande",
    "infogar": "infoga",
    "infogas": "infoga",
    "infogat": "infoga",
    "infogats": "infoga",
    "infordrad": "infordra",
    "infordrade": "infordra",
    "infordrades": "infordra",
    "infordrads": "infordra",
    "infordrande": "infordra",
    "infordranden": "infordrande",
    "infordrandena": "infordrande",
    "infordrandenas": "infordrande",
    "infordrandens": "infordrande",
    "infordrandes": "infordrande",
    "infordrandet": "infordrande",
    "infordrandets": "infordrande",
    "infordrar": "infordra",
    "infordras": "infordra",
    "infordrat": "infordra",
    "infordrats": "infordra",
    "infordringar": "infordring",
    "infordringarna": "infordring",
    "infordringarnas": "infordring",
    "infordringars": "infordring",
    "infordringen": "infordring",
    "infordringens": "infordring",
    "infordrings": "infordring",
    "informanten": "informant",
    "informantens": "informant",
    "informanter": "informant",
    "informanterna": "informant",
    "informanternas": "informant",
    "informanters": "informant",
    "informants": "informant",
    "informationen": "information",
    "informationens": "information",
    "informationer": "information",
    "informationerna": "information",
    "informationernas": "information",
    "informationers": "information",
    "informations": "information",
    "informationsansvariga": "informationsansvarig",
    "informationsansvarigas": "informationsansvarig",
    "informationsansvarige": "informationsansvarig",
    "informationsansvariges": "informationsansvarig",
    "informationsansvarigs": "informationsansvarig",
    "informationsansvarigt": "informationsansvarig",
    "informationsansvarigts": "informationsansvarig",
    "informationsbehandlingar": "informationsbehandling",
    "informationsbehandlingarna": "informationsbehandling",
    "informationsbehandlingarnas": "informationsbehandling",
    "informationsbehandlingars": "informationsbehandling",
    "informationsbehandlingen": "informationsbehandling",
    "informationsbehandlingens": "informationsbehandling",
    "informationsbehandlings": "informationsbehandling",
    "informationsbroschyren": "informationsbroschyr",
    "informationsbroschyrens": "informationsbroschyr",
    "informationsbroschyrer": "informationsbroschyr",
    "informationsbroschyrerna": "informationsbroschyr",
    "informationsbroschyrernas": "informationsbroschyr",
    "informationsbroschyrers": "informationsbroschyr",
    "informationsbroschyrs": "informationsbroschyr",
    "informationsbyråer": "informationsbyrå",
    "informationsbyråerna": "informationsbyrå",
    "informationsbyråernas": "informationsbyrå",
    "informationsbyråers": "informationsbyrå",
    "informationsbyrån": "informationsbyrå",
    "informationsbyråns": "informationsbyrå",
    "informationsbyrås": "informationsbyrå",
    "informationschefen": "informationschef",
    "informationschefens": "informationschef",
    "informationschefer": "informationschef",
    "informationscheferna": "informationschef",
    "informationschefernas": "informationschef",
    "informationschefers": "informationschef",
    "informationschefs": "informationschef",
    "informationsdiskar": "informationsdisk",
    "informationsdiskarna": "informationsdisk",
    "informationsdiskarnas": "informationsdisk",
    "informationsdiskars": "informationsdisk",
    "informationsdisken": "informationsdisk",
    "informationsdiskens": "informationsdisk",
    "informationsdisks": "informationsdisk",
    "informationsflöden": "informationsflöde",
    "informationsflödena": "informationsflöde",
    "informationsflödenas": "informationsflöde",
    "informationsflödens": "informationsflöde",
    "informationsflödes": "informationsflöde",
    "informationsflödet": "informationsflöde",
    "informationsflödets": "informationsflöde",
    "informationsförelägganden": "informationsföreläggande",
    "informationsföreläggandena": "informationsföreläggande",
    "informationsföreläggandenas": "informationsföreläggande",
    "informationsföreläggandens": "informationsföreläggande",
    "informationsföreläggandes": "informationsföreläggande",
    "informationsföreläggandet": "informationsföreläggande",
    "informationsföreläggandets": "informationsföreläggande",
    "informationskrigföringen": "informationskrigföring",
    "informationskrigföringens": "informationskrigföring",
    "informationskrigförings": "informationskrigföring",
    "informationsmässiga": "informationsmässig",
    "informationsmässigare": "informationsmässig",
    "informationsmässigares": "informationsmässig",
    "informationsmässigas": "informationsmässig",
    "informationsmässigast": "informationsmässig",
    "informationsmässigaste": "informationsmässig",
    "informationsmässigastes": "informationsmässig",
    "informationsmässigasts": "informationsmässig",
    "informationsmässige": "informationsmässig",
    "informationsmässiges": "informationsmässig",
    "informationsmässigs": "informationsmässig",
    "informationsmässigt": "informationsmässig",
    "informationsmässigts": "informationsmässig",
    "informationsmöten": "informationsmöte",
    "informationsmötena": "informationsmöte",
    "informationsmötenas": "informationsmöte",
    "informationsmötens": "informationsmöte",
    "informationsmötes": "informationsmöte",
    "informationsmötet": "informationsmöte",
    "informationsmötets": "informationsmöte",
    "informationsrika": "informationsrik",
    "informationsrikare": "informationsrik",
    "informationsrikares": "informationsrik",
    "informationsrikas": "informationsrik",
    "informationsrikast": "informationsrik",
    "informationsrikaste": "informationsrik",
    "informationsrikastes": "informationsrik",
    "informationsrikasts": "informationsrik",
    "informationsrike": "informationsrik",
    "informationsrikes": "informationsrik",
    "informationsrikheten": "informationsrikhet",
    "informationsrikhetens": "informationsrikhet",
    "informationsrikhets": "informationsrikhet",
    "informationsriks": "informationsrik",
    "informationsrikt": "informationsrik",
    "informationsrikts": "informationsrik",
    "informationssamhällen": "informationssamhälle",
    "informationssamhällena": "informationssamhälle",
    "informationssamhällenas": "informationssamhälle",
    "informationssamhällens": "informationssamhälle",
    "informationssamhälles": "informationssamhälle",
    "informationssamhället": "informationssamhälle",
    "informationssamhällets": "informationssamhälle",
    "informationssamhälls": "informationssamhälle",
    "informationsstressen": "informationsstress",
    "informationsstressens": "informationsstress",
    "informationssökningar": "informationssökning",
    "informationssökningarna": "informationssökning",
    "informationssökningarnas": "informationssökning",
    "informationssökningars": "informationssökning",
    "informationssökningen": "informationssökning",
    "informationssökningens": "informationssökning",
    "informationssöknings": "informationssökning",
    "informationsteknologien": "informationsteknologi",
    "informationsteknologiens": "informationsteknologi",
    "informationsteknologier": "informationsteknologi",
    "informationsteknologierna": "informationsteknologi",
    "informationsteknologiernas": "informationsteknologi",
    "informationsteknologiers": "informationsteknologi",
    "informationsteknologin": "informationsteknologi",
    "informationsteknologins": "informationsteknologi",
    "informationsteknologis": "informationsteknologi",
    "informationsteorien": "informationsteori",
    "informationsteoriens": "informationsteori",
    "informationsteorin": "informationsteori",
    "informationsteorins": "informationsteori",
    "informationsteoris": "informationsteori",
    "informationsutbyten": "informationsutbyte",
    "informationsutbytena": "informationsutbyte",
    "informationsutbytenas": "informationsutbyte",
    "informationsutbytens": "informationsutbyte",
    "informationsutbytes": "informationsutbyte",
    "informationsutbytet": "informationsutbyte",
    "informationsutbytets": "informationsutbyte",
    "informativa": "informativ",
    "informativare": "informativ",
    "informativares": "informativ",
    "informativas": "informativ",
    "informativast": "informativ",
    "informativaste": "informativ",
    "informativastes": "informativ",
    "informativasts": "informativ",
    "informative": "informativ",
    "informatives": "informativ",
    "informativs": "informativ",
    "informativt": "informativ",
    "informativts": "informativ",
    "informatorer": "informator",
    "informatorerna": "informator",
    "informatorernas": "informator",
    "informatorers": "informator",
    "informatorn": "informator",
    "informatorns": "informator",
    "informators": "informator",
    "informatören": "informatör",
    "informatörens": "informatör",
    "informatörer": "informatör",
    "informatörerna": "informatör",
    "informatörernas": "informatör",
    "informatörers": "informatör",
    "informatörs": "informatör",
    "informella": "informell",
    "informellare": "informell",
    "informellares": "informell",
    "informellas": "informell",
    "informellast": "informell",
    "informellaste": "informell",
    "informellastes": "informell",
    "informellasts": "informell",
    "informelle": "informell",
    "informelles": "informell",
    "informells": "informell",
    "informellt": "informell",
    "informellts": "informell",
    "informerad": "informera",
    "informerade": "informera",
    "informerades": "informera",
    "informerads": "informera",
    "informerande": "informera",
    "informeranden": "informerande",
    "informerandena": "informerande",
    "informerandenas": "informerande",
    "informerandens": "informerande",
    "informerandes": "informerande",
    "informerandet": "informerande",
    "informerandets": "informerande",
    "informerar": "informera",
    "informeras": "informera",
    "informerat": "informera",
    "informerats": "informera",
    "informerbara": "informerbar",
    "informerbarare": "informerbar",
    "informerbarares": "informerbar",
    "informerbaras": "informerbar",
    "informerbarast": "informerbar",
    "informerbaraste": "informerbar",
    "informerbarastes": "informerbar",
    "informerbarasts": "informerbar",
    "informerbare": "informerbar",
    "informerbares": "informerbar",
    "informerbarheten": "informerbarhet",
    "informerbarhetens": "informerbarhet",
    "informerbarhets": "informerbarhet",
    "informerbars": "informerbar",
    "informerbart": "informerbar",
    "informerbarts": "informerbar",
    "informeringar": "informering",
    "informeringarna": "informering",
    "informeringarnas": "informering",
    "informeringars": "informering",
    "informeringen": "informering",
    "informeringens": "informering",
    "informerings": "informering",
    "infragrillar": "infragrill",
    "infragrillarna": "infragrill",
    "infragrillarnas": "infragrill",
    "infragrillars": "infragrill",
    "infragrillen": "infragrill",
    "infragrillens": "infragrill",
    "infragrills": "infragrill",
    "infraljuden": "infraljud",
    "infraljudens": "infraljud",
    "infraljudet": "infraljud",
    "infraljudets": "infraljud",
    "infraljuds": "infraljud",
    "infraröda": "infraröd",
    "infrarödare": "infraröd",
    "infrarödares": "infraröd",
    "infrarödas": "infraröd",
    "infrarödast": "infraröd",
    "infrarödaste": "infraröd",
    "infrarödastes": "infraröd",
    "infrarödasts": "infraröd",
    "infraröde": "infraröd",
    "infrarödes": "infraröd",
    "infraröds": "infraröd",
    "infrarött": "infraröd",
    "infrarötts": "infraröd",
    "infrastrukturen": "infrastruktur",
    "infrastrukturens": "infrastruktur",
    "infrastrukturer": "infrastruktur",
    "infrastrukturerna": "infrastruktur",
    "infrastrukturernas": "infrastruktur",
    "infrastrukturers": "infrastruktur",
    "infrastrukturministern": "infrastrukturminister",
    "infrastrukturministerns": "infrastrukturminister",
    "infrastrukturministers": "infrastrukturminister",
    "infrastrukturministrar": "infrastrukturminister",
    "infrastrukturministrarna": "infrastrukturminister",
    "infrastrukturministrarnas": "infrastrukturminister",
    "infrastrukturministrars": "infrastrukturminister",
    "infrastrukturs": "infrastruktur",
    "infrastruktursatsningar": "infrastruktursatsning",
    "infrastruktursatsningarna": "infrastruktursatsning",
    "infrastruktursatsningarnas": "infrastruktursatsning",
    "infrastruktursatsningars": "infrastruktursatsning",
    "infrastruktursatsningen": "infrastruktursatsning",
    "infrastruktursatsningens": "infrastruktursatsning",
    "infrastruktursatsnings": "infrastruktursatsning",
    "infravärmen": "infravärme",
    "infravärmens": "infravärme",
    "infravärmes": "infravärme",
    "infravärmet": "infravärme",
    "infravärmets": "infravärme",
    "infri": "infria",
    "infriad": "infria",
    "infriade": "infria",
    "infriades": "infria",
    "infriads": "infria",
    "infriande": "infria",
    "infrianden": "infriande",
    "infriandena": "infriande",
    "infriandenas": "infriande",
    "infriandens": "infriande",
    "infriandes": "infriande",
    "infriandet": "infriande",
    "infriandets": "infriande",
    "infriar": "infria",
    "infrias": "infria",
    "infriat": "infria",
    "infriats": "infria",
    "infrusens": "infrusen",
    "infruset": "infrusen",
    "infrusets": "infrusen",
    "infrusna": "infrusen",
    "infrusnare": "infrusen",
    "infrusnares": "infrusen",
    "infrusnas": "infrusen",
    "infrusnast": "infrusen",
    "infrusnaste": "infrusen",
    "infrusnastes": "infrusen",
    "infrusnasts": "infrusen",
    "infrusne": "infrusen",
    "infrusnes": "infrusen",
    "infusionen": "infusion",
    "infusionens": "infusion",
    "infusioner": "infusion",
    "infusionerna": "infusion",
    "infusionernas": "infusion",
    "infusioners": "infusion",
    "infusions": "infusion",
    "infusionsdjuren": "infusionsdjur",
    "infusionsdjurens": "infusionsdjur",
    "infusionsdjuret": "infusionsdjur",
    "infusionsdjurets": "infusionsdjur",
    "infusionsdjurs": "infusionsdjur",
    "infällde": "infälld",
    "infälldes": "infälld",
    "infällds": "infälld",
    "infällt": "infälld",
    "infällts": "infälld",
    "infång": "infånga",
    "infångad": "infånga",
    "infångade": "infånga",
    "infångades": "infånga",
    "infångads": "infånga",
    "infångande": "infånga",
    "infånganden": "infångande",
    "infångandena": "infångande",
    "infångandenas": "infångande",
    "infångandens": "infångande",
    "infångandes": "infångande",
    "infångandet": "infångande",
    "infångandets": "infångande",
    "infångar": "infånga",
    "infångas": "infånga",
    "infångat": "infånga",
    "infångats": "infånga",
    "infödda": "infödd",
    "inföddare": "infödd",
    "inföddares": "infödd",
    "inföddas": "infödd",
    "inföddast": "infödd",
    "inföddaste": "infödd",
    "inföddastes": "infödd",
    "inföddasts": "infödd",
    "infödde": "infödd",
    "inföddes": "infödd",
    "inföddheten": "inföddhet",
    "inföddhetens": "inföddhet",
    "inföddhets": "inföddhet",
    "infödds": "infödd",
    "infödingar": "inföding",
    "infödingarna": "inföding",
    "infödingarnas": "inföding",
    "infödingars": "inföding",
    "infödingen": "inföding",
    "infödingens": "inföding",
    "infödings": "inföding",
    "inföll": "infalla",
    "infölle": "infalla",
    "infölles": "infalla",
    "infölls": "infalla",
    "inför": "införa",
    "införande": "införa",
    "införanden": "införande",
    "införandena": "införande",
    "införandenas": "införande",
    "införandens": "införande",
    "införandes": "införande",
    "införandet": "införande",
    "införandets": "införande",
    "införas": "införa",
    "införd": "införa",
    "införda": "införa",
    "infördas": "införa",
    "införde": "införa",
    "infördes": "införa",
    "införds": "införa",
    "införes": "införa",
    "införliv": "införliva",
    "införlivad": "införliva",
    "införlivade": "införliva",
    "införlivades": "införliva",
    "införlivads": "införliva",
    "införlivande": "införliva",
    "införlivanden": "införlivande",
    "införlivandena": "införlivande",
    "införlivandenas": "införlivande",
    "införlivandens": "införlivande",
    "införlivandes": "införlivande",
    "införlivandet": "införlivande",
    "införlivandets": "införlivande",
    "införlivar": "införliva",
    "införlivas": "införliva",
    "införlivat": "införliva",
    "införlivats": "införliva",
    "införs": "införa",
    "införseln": "införsel",
    "införselns": "införsel",
    "införsels": "införsel",
    "införskaff": "införskaffa",
    "införskaffad": "införskaffa",
    "införskaffade": "införskaffa",
    "införskaffades": "införskaffa",
    "införskaffads": "införskaffa",
    "införskaffande": "införskaffa",
    "införskaffanden": "införskaffande",
    "införskaffandena": "införskaffande",
    "införskaffandenas": "införskaffande",
    "införskaffandens": "införskaffande",
    "införskaffandes": "införskaffande",
    "införskaffandet": "införskaffande",
    "införskaffandets": "införskaffande",
    "införskaffar": "införskaffa",
    "införskaffas": "införskaffa",
    "införskaffat": "införskaffa",
    "införskaffats": "införskaffa",
    "införstådda": "införstådd",
    "införståddare": "införstådd",
    "införståddares": "införstådd",
    "införståddas": "införstådd",
    "införståddast": "införstådd",
    "införståddaste": "införstådd",
    "införståddastes": "införstådd",
    "införståddasts": "införstådd",
    "införstådde": "införstådd",
    "införståddes": "införstådd",
    "införstådds": "införstådd",
    "införstått": "införstådd",
    "införståtts": "införstådd",
    "infört": "införa",
    "införts": "införa",
    "infött": "infödd",
    "infötts": "infödd",
    "inga": "ingen",
    "ingadera": "ingendera",
    "ingaderas": "ingendera",
    "ingas": "ingen",
    "ingav": "inge",
    "ingavs": "inge",
    "ingeende": "inge",
    "ingeendes": "inge",
    "ingefäran": "ingefära",
    "ingefärans": "ingefära",
    "ingefäras": "ingefära",
    "ingefärsdrickan": "ingefärsdricka",
    "ingefärsdrickans": "ingefärsdricka",
    "ingefärsdrickas": "ingefärsdricka",
    "ingefärsväxten": "ingefärsväxt",
    "ingefärsväxtens": "ingefärsväxt",
    "ingefärsväxter": "ingefärsväxt",
    "ingefärsväxterna": "ingefärsväxt",
    "ingefärsväxternas": "ingefärsväxt",
    "ingefärsväxters": "ingefärsväxt",
    "ingefärsväxts": "ingefärsväxt",
    "ingenderas": "ingendera",
    "ingenie": "ingenium",
    "ingenier": "ingenium",
    "ingenierna": "ingenium",
    "ingeniernas": "ingenium",
    "ingeniers": "ingenium",
    "ingeniet": "ingenium",
    "ingeniets": "ingenium",
    "ingeniums": "ingenium",
    "ingenjören": "ingenjör",
    "ingenjörens": "ingenjör",
    "ingenjörer": "ingenjör",
    "ingenjörerna": "ingenjör",
    "ingenjörernas": "ingenjör",
    "ingenjörers": "ingenjör",
    "ingenjörn": "ingenjör",
    "ingenjörns": "ingenjör",
    "ingenjörs": "ingenjör",
    "ingenjörsmässiga": "ingenjörsmässig",
    "ingenjörsmässigare": "ingenjörsmässig",
    "ingenjörsmässigares": "ingenjörsmässig",
    "ingenjörsmässigas": "ingenjörsmässig",
    "ingenjörsmässigast": "ingenjörsmässig",
    "ingenjörsmässigaste": "ingenjörsmässig",
    "ingenjörsmässigastes": "ingenjörsmässig",
    "ingenjörsmässigasts": "ingenjörsmässig",
    "ingenjörsmässige": "ingenjörsmässig",
    "ingenjörsmässiges": "ingenjörsmässig",
    "ingenjörsmässigs": "ingenjörsmässig",
    "ingenjörsmässigt": "ingenjörsmässig",
    "ingenjörsmässigts": "ingenjörsmässig",
    "ingenjörsstudenten": "ingenjörsstudent",
    "ingenjörsstudentens": "ingenjörsstudent",
    "ingenjörsstudenter": "ingenjörsstudent",
    "ingenjörsstudenterna": "ingenjörsstudent",
    "ingenjörsstudenternas": "ingenjörsstudent",
    "ingenjörsstudenters": "ingenjörsstudent",
    "ingenjörsstudents": "ingenjörsstudent",
    "ingenjörstruppen": "ingenjörstrupp",
    "ingenjörstruppens": "ingenjörstrupp",
    "ingenjörstrupper": "ingenjörstrupp",
    "ingenjörstrupperna": "ingenjörstrupp",
    "ingenjörstruppernas": "ingenjörstrupp",
    "ingenjörstruppers": "ingenjörstrupp",
    "ingenjörstrupps": "ingenjörstrupp",
    "ingenjörsutbildningar": "ingenjörsutbildning",
    "ingenjörsutbildningarna": "ingenjörsutbildning",
    "ingenjörsutbildningarnas": "ingenjörsutbildning",
    "ingenjörsutbildningars": "ingenjörsutbildning",
    "ingenjörsutbildningen": "ingenjörsutbildning",
    "ingenjörsutbildningens": "ingenjörsutbildning",
    "ingenjörsutbildnings": "ingenjörsutbildning",
    "ingenjörsvetenskapen": "ingenjörsvetenskap",
    "ingenjörsvetenskapens": "ingenjörsvetenskap",
    "ingenjörsvetenskaper": "ingenjörsvetenskap",
    "ingenjörsvetenskaperna": "ingenjörsvetenskap",
    "ingenjörsvetenskapernas": "ingenjörsvetenskap",
    "ingenjörsvetenskapers": "ingenjörsvetenskap",
    "ingenjörsvetenskaps": "ingenjörsvetenskap",
    "ingenjörsvetenskapsakademien": "ingenjörsvetenskapsakademi",
    "ingenjörsvetenskapsakademiens": "ingenjörsvetenskapsakademi",
    "ingenjörsvetenskapsakademier": "ingenjörsvetenskapsakademi",
    "ingenjörsvetenskapsakademierna": "ingenjörsvetenskapsakademi",
    "ingenjörsvetenskapsakademiernas": "ingenjörsvetenskapsakademi",
    "ingenjörsvetenskapsakademiers": "ingenjörsvetenskapsakademi",
    "ingenjörsvetenskapsakademin": "ingenjörsvetenskapsakademi",
    "ingenjörsvetenskapsakademins": "ingenjörsvetenskapsakademi",
    "ingenjörsvetenskapsakademis": "ingenjörsvetenskapsakademi",
    "ingenmanslandet": "ingenmansland",
    "ingenmanslandets": "ingenmansland",
    "ingenmanslands": "ingenmansland",
    "ingens": "ingen",
    "ingentings": "ingenting",
    "ingenyer": "ingeny",
    "ingenyerna": "ingeny",
    "ingenyernas": "ingeny",
    "ingenyers": "ingeny",
    "ingenyn": "ingeny",
    "ingenyns": "ingeny",
    "ingenys": "ingeny",
    "inger": "inge",
    "inges": "inge",
    "inget": "ingen",
    "ingetdera": "ingendera",
    "ingetderas": "ingendera",
    "ingets": "ingen",
    "ingett": "inge",
    "ingetts": "inge",
    "ingick": "ingå",
    "ingicks": "ingå",
    "ingifta": "ingift",
    "ingiftare": "ingift",
    "ingiftares": "ingift",
    "ingiftas": "ingift",
    "ingiftast": "ingift",
    "ingiftaste": "ingift",
    "ingiftastes": "ingift",
    "ingiftasts": "ingift",
    "ingifte": "ingift",
    "ingiften": "ingifte",
    "ingiftena": "ingifte",
    "ingiftenas": "ingifte",
    "ingiftens": "ingifte",
    "ingiftes": "ingifte",
    "ingiftet": "ingifte",
    "ingiftets": "ingifte",
    "ingifts": "ingift",
    "inginge": "ingå",
    "inginges": "ingå",
    "ingiv": "inge",
    "ingiva": "inge",
    "ingivande": "inge",
    "ingivanden": "ingivande",
    "ingivandena": "ingivande",
    "ingivandenas": "ingivande",
    "ingivandens": "ingivande",
    "ingivandes": "ingivande",
    "ingivandet": "ingivande",
    "ingivandets": "ingivande",
    "ingivas": "inge",
    "ingive": "inge",
    "ingivelsen": "ingivelse",
    "ingivelsens": "ingivelse",
    "ingivelser": "ingivelse",
    "ingivelserna": "ingivelse",
    "ingivelsernas": "ingivelse",
    "ingivelsers": "ingivelse",
    "ingivelses": "ingivelse",
    "ingiven": "inge",
    "ingivens": "inge",
    "ingiver": "inge",
    "ingives": "inge",
    "ingivet": "inge",
    "ingivets": "inge",
    "ingivit": "inge",
    "ingivits": "inge",
    "ingivna": "inge",
    "ingivnas": "inge",
    "ingivne": "inge",
    "ingivnes": "inge",
    "ingivs": "inge",
    "ingjut": "ingjuta",
    "ingjutande": "ingjuta",
    "ingjutanden": "ingjutande",
    "ingjutandena": "ingjutande",
    "ingjutandenas": "ingjutande",
    "ingjutandens": "ingjutande",
    "ingjutandes": "ingjutande",
    "ingjutandet": "ingjutande",
    "ingjutandets": "ingjutande",
    "ingjutas": "ingjuta",
    "ingjute": "ingjuta",
    "ingjuten": "ingjuta",
    "ingjutens": "ingjuta",
    "ingjuter": "ingjuta",
    "ingjutes": "ingjuta",
    "ingjutet": "ingjuta",
    "ingjutets": "ingjuta",
    "ingjutit": "ingjuta",
    "ingjutits": "ingjuta",
    "ingjutna": "ingjuta",
    "ingjutnas": "ingjuta",
    "ingjutne": "ingjuta",
    "ingjutnes": "ingjuta",
    "ingjuts": "ingjuta",
    "inglasade": "inglasad",
    "inglasades": "inglasad",
    "inglasads": "inglasad",
    "inglasat": "inglasad",
    "inglasats": "inglasad",
    "ingraverad": "ingravera",
    "ingraverade": "ingravera",
    "ingraverades": "ingravera",
    "ingraverads": "ingravera",
    "ingraverande": "ingravera",
    "ingraveranden": "ingraverande",
    "ingraverandena": "ingraverande",
    "ingraverandenas": "ingraverande",
    "ingraverandens": "ingraverande",
    "ingraverandes": "ingraverande",
    "ingraverandet": "ingraverande",
    "ingraverandets": "ingraverande",
    "ingraverar": "ingravera",
    "ingraveras": "ingravera",
    "ingraverat": "ingravera",
    "ingraverats": "ingravera",
    "ingraverbara": "ingraverbar",
    "ingraverbarare": "ingraverbar",
    "ingraverbarares": "ingraverbar",
    "ingraverbaras": "ingraverbar",
    "ingraverbarast": "ingraverbar",
    "ingraverbaraste": "ingraverbar",
    "ingraverbarastes": "ingraverbar",
    "ingraverbarasts": "ingraverbar",
    "ingraverbare": "ingraverbar",
    "ingraverbares": "ingraverbar",
    "ingraverbarheten": "ingraverbarhet",
    "ingraverbarhetens": "ingraverbarhet",
    "ingraverbarhets": "ingraverbarhet",
    "ingraverbars": "ingraverbar",
    "ingraverbart": "ingraverbar",
    "ingraverbarts": "ingraverbar",
    "ingraveringar": "ingravering",
    "ingraveringarna": "ingravering",
    "ingraveringarnas": "ingravering",
    "ingraveringars": "ingravering",
    "ingraveringen": "ingravering",
    "ingraveringens": "ingravering",
    "ingraverings": "ingravering",
    "ingrediensen": "ingrediens",
    "ingrediensens": "ingrediens",
    "ingredienser": "ingrediens",
    "ingredienserna": "ingrediens",
    "ingrediensernas": "ingrediens",
    "ingrediensers": "ingrediens",
    "ingrep": "ingripa",
    "ingreppen": "ingrepp",
    "ingreppens": "ingrepp",
    "ingreppet": "ingrepp",
    "ingreppets": "ingrepp",
    "ingrepps": "ingrepp",
    "ingreps": "ingripa",
    "ingressen": "ingress",
    "ingressens": "ingress",
    "ingresser": "ingress",
    "ingresserna": "ingress",
    "ingressernas": "ingress",
    "ingressers": "ingress",
    "ingrip": "ingripa",
    "ingripande": "ingripa",
    "ingripanden": "ingripande",
    "ingripandena": "ingripande",
    "ingripandenas": "ingripande",
    "ingripandens": "ingripande",
    "ingripandes": "ingripande",
    "ingripandet": "ingripande",
    "ingripandets": "ingripande",
    "ingripas": "ingripa",
    "ingripe": "ingripa",
    "ingriper": "ingripa",
    "ingripes": "ingripa",
    "ingripit": "ingripa",
    "ingripits": "ingripa",
    "ingrips": "ingripa",
    "ingrodda": "ingrodd",
    "ingroddare": "ingrodd",
    "ingroddares": "ingrodd",
    "ingroddas": "ingrodd",
    "ingroddast": "ingrodd",
    "ingroddaste": "ingrodd",
    "ingroddastes": "ingrodd",
    "ingroddasts": "ingrodd",
    "ingrodde": "ingrodd",
    "ingroddes": "ingrodd",
    "ingroddheten": "ingroddhet",
    "ingroddhetens": "ingroddhet",
    "ingroddhets": "ingroddhet",
    "ingrodds": "ingrodd",
    "ingrott": "ingrodd",
    "ingrotts": "ingrodd",
    "ingälden": "ingäld",
    "ingäldens": "ingäld",
    "ingälder": "ingäld",
    "ingälderna": "ingäld",
    "ingäldernas": "ingäld",
    "ingälders": "ingäld",
    "ingälds": "ingäld",
    "ingående": "ingå",
    "ingåenden": "ingående",
    "ingåendena": "ingående",
    "ingåendenas": "ingående",
    "ingåendens": "ingående",
    "ingåendes": "ingående",
    "ingåendet": "ingående",
    "ingåendets": "ingående",
    "ingångar": "ingång",
    "ingångarna": "ingång",
    "ingångarnas": "ingång",
    "ingångars": "ingång",
    "ingånge": "ingå",
    "ingången": "ingång",
    "ingångens": "ingång",
    "ingånges": "ingå",
    "ingånget": "ingå",
    "ingångets": "ingå",
    "ingångna": "ingå",
    "ingångnas": "ingå",
    "ingångne": "ingå",
    "ingångnes": "ingå",
    "ingångs": "ingång",
    "ingångsmarschen": "ingångsmarsch",
    "ingångsmarschens": "ingångsmarsch",
    "ingångsmarscher": "ingångsmarsch",
    "ingångsmarscherna": "ingångsmarsch",
    "ingångsmarschernas": "ingångsmarsch",
    "ingångsmarschers": "ingångsmarsch",
    "ingångsmarschs": "ingångsmarsch",
    "ingångspsalmen": "ingångspsalm",
    "ingångspsalmens": "ingångspsalm",
    "ingångspsalmer": "ingångspsalm",
    "ingångspsalmerna": "ingångspsalm",
    "ingångspsalmernas": "ingångspsalm",
    "ingångspsalmers": "ingångspsalm",
    "ingångspsalms": "ingångspsalm",
    "ingångsspänningar": "ingångsspänning",
    "ingångsspänningarna": "ingångsspänning",
    "ingångsspänningarnas": "ingångsspänning",
    "ingångsspänningars": "ingångsspänning",
    "ingångsspänningen": "ingångsspänning",
    "ingångsspänningens": "ingångsspänning",
    "ingångsspännings": "ingångsspänning",
    "ingår": "ingå",
    "ingås": "ingå",
    "ingått": "ingå",
    "ingåtts": "ingå",
    "ingåve": "inge",
    "ingåves": "inge",
    "ingöt": "ingjuta",
    "ingöte": "ingjuta",
    "ingöten": "ingöte",
    "ingötena": "ingöte",
    "ingötenas": "ingöte",
    "ingötens": "ingöte",
    "ingötes": "ingöte",
    "ingötet": "ingöte",
    "ingötets": "ingöte",
    "ingöts": "ingöte",
    "inhalationen": "inhalation",
    "inhalationens": "inhalation",
    "inhalationer": "inhalation",
    "inhalationerna": "inhalation",
    "inhalationernas": "inhalation",
    "inhalationers": "inhalation",
    "inhalations": "inhalation",
    "inhalatorer": "inhalator",
    "inhalatorerna": "inhalator",
    "inhalatorernas": "inhalator",
    "inhalatorers": "inhalator",
    "inhalatorn": "inhalator",
    "inhalatorns": "inhalator",
    "inhalators": "inhalator",
    "inhalerad": "inhalera",
    "inhalerade": "inhalera",
    "inhalerades": "inhalera",
    "inhalerads": "inhalera",
    "inhalerande": "inhalera",
    "inhaleranden": "inhalerande",
    "inhalerandena": "inhalerande",
    "inhalerandenas": "inhalerande",
    "inhalerandens": "inhalerande",
    "inhalerandes": "inhalerande",
    "inhalerandet": "inhalerande",
    "inhalerandets": "inhalerande",
    "inhalerar": "inhalera",
    "inhaleras": "inhalera",
    "inhalerat": "inhalera",
    "inhalerats": "inhalera",
    "inhalerbara": "inhalerbar",
    "inhalerbarare": "inhalerbar",
    "inhalerbarares": "inhalerbar",
    "inhalerbaras": "inhalerbar",
    "inhalerbarast": "inhalerbar",
    "inhalerbaraste": "inhalerbar",
    "inhalerbarastes": "inhalerbar",
    "inhalerbarasts": "inhalerbar",
    "inhalerbare": "inhalerbar",
    "inhalerbares": "inhalerbar",
    "inhalerbarheten": "inhalerbarhet",
    "inhalerbarhetens": "inhalerbarhet",
    "inhalerbarhets": "inhalerbarhet",
    "inhalerbars": "inhalerbar",
    "inhalerbart": "inhalerbar",
    "inhalerbarts": "inhalerbar",
    "inhaleringar": "inhalering",
    "inhaleringarna": "inhalering",
    "inhaleringarnas": "inhalering",
    "inhaleringars": "inhalering",
    "inhaleringen": "inhalering",
    "inhaleringens": "inhalering",
    "inhalerings": "inhalering",
    "inhamnar": "inhamn",
    "inhamnarna": "inhamn",
    "inhamnarnas": "inhamn",
    "inhamnars": "inhamn",
    "inhamnen": "inhamn",
    "inhamnens": "inhamn",
    "inhamns": "inhamn",
    "inhandlad": "inhandla",
    "inhandlade": "inhandla",
    "inhandlades": "inhandla",
    "inhandlads": "inhandla",
    "inhandlande": "inhandla",
    "inhandlanden": "inhandlande",
    "inhandlandena": "inhandlande",
    "inhandlandenas": "inhandlande",
    "inhandlandens": "inhandlande",
    "inhandlandes": "inhandlande",
    "inhandlandet": "inhandlande",
    "inhandlandets": "inhandlande",
    "inhandlar": "inhandla",
    "inhandlas": "inhandla",
    "inhandlat": "inhandla",
    "inhandlats": "inhandla",
    "inhaven": "inhav",
    "inhavens": "inhav",
    "inhavet": "inhav",
    "inhavets": "inhav",
    "inhavs": "inhav",
    "inhemska": "inhemsk",
    "inhemskare": "inhemsk",
    "inhemskares": "inhemsk",
    "inhemskas": "inhemsk",
    "inhemskast": "inhemsk",
    "inhemskaste": "inhemsk",
    "inhemskastes": "inhemsk",
    "inhemskasts": "inhemsk",
    "inhemske": "inhemsk",
    "inhemskes": "inhemsk",
    "inhemsks": "inhemsk",
    "inhemskt": "inhemsk",
    "inhemskts": "inhemsk",
    "inherenta": "inherent",
    "inherentare": "inherent",
    "inherentares": "inherent",
    "inherentas": "inherent",
    "inherentast": "inherent",
    "inherentaste": "inherent",
    "inherentastes": "inherent",
    "inherentasts": "inherent",
    "inherente": "inherent",
    "inherentes": "inherent",
    "inherents": "inherent",
    "inhiberad": "inhibera",
    "inhiberade": "inhibera",
    "inhiberades": "inhibera",
    "inhiberads": "inhibera",
    "inhiberande": "inhibera",
    "inhiberanden": "inhiberande",
    "inhiberandena": "inhiberande",
    "inhiberandenas": "inhiberande",
    "inhiberandens": "inhiberande",
    "inhiberandes": "inhiberande",
    "inhiberandet": "inhiberande",
    "inhiberandets": "inhiberande",
    "inhiberar": "inhibera",
    "inhiberas": "inhibera",
    "inhiberat": "inhibera",
    "inhiberats": "inhibera",
    "inhiberbara": "inhiberbar",
    "inhiberbarare": "inhiberbar",
    "inhiberbarares": "inhiberbar",
    "inhiberbaras": "inhiberbar",
    "inhiberbarast": "inhiberbar",
    "inhiberbaraste": "inhiberbar",
    "inhiberbarastes": "inhiberbar",
    "inhiberbarasts": "inhiberbar",
    "inhiberbare": "inhiberbar",
    "inhiberbares": "inhiberbar",
    "inhiberbarheten": "inhiberbarhet",
    "inhiberbarhetens": "inhiberbarhet",
    "inhiberbarhets": "inhiberbarhet",
    "inhiberbars": "inhiberbar",
    "inhiberbart": "inhiberbar",
    "inhiberbarts": "inhiberbar",
    "inhiberingar": "inhibering",
    "inhiberingarna": "inhibering",
    "inhiberingarnas": "inhibering",
    "inhiberingars": "inhibering",
    "inhiberingen": "inhibering",
    "inhiberingens": "inhibering",
    "inhiberings": "inhibering",
    "inhibiterad": "inhibitera",
    "inhibiterade": "inhibitera",
    "inhibiterades": "inhibitera",
    "inhibiterads": "inhibitera",
    "inhibiterande": "inhibitera",
    "inhibiteranden": "inhibiterande",
    "inhibiterandena": "inhibiterande",
    "inhibiterandenas": "inhibiterande",
    "inhibiterandens": "inhibiterande",
    "inhibiterandes": "inhibiterande",
    "inhibiterandet": "inhibiterande",
    "inhibiterandets": "inhibiterande",
    "inhibiterar": "inhibitera",
    "inhibiteras": "inhibitera",
    "inhibiterat": "inhibitera",
    "inhibiterats": "inhibitera",
    "inhibiterbara": "inhibiterbar",
    "inhibiterbarare": "inhibiterbar",
    "inhibiterbarares": "inhibiterbar",
    "inhibiterbaras": "inhibiterbar",
    "inhibiterbarast": "inhibiterbar",
    "inhibiterbaraste": "inhibiterbar",
    "inhibiterbarastes": "inhibiterbar",
    "inhibiterbarasts": "inhibiterbar",
    "inhibiterbare": "inhibiterbar",
    "inhibiterbares": "inhibiterbar",
    "inhibiterbarheten": "inhibiterbarhet",
    "inhibiterbarhetens": "inhibiterbarhet",
    "inhibiterbarhets": "inhibiterbarhet",
    "inhibiterbars": "inhibiterbar",
    "inhibiterbart": "inhibiterbar",
    "inhibiterbarts": "inhibiterbar",
    "inhibiteringar": "inhibitering",
    "inhibiteringarna": "inhibitering",
    "inhibiteringarnas": "inhibitering",
    "inhibiteringars": "inhibitering",
    "inhibiteringen": "inhibitering",
    "inhibiteringens": "inhibitering",
    "inhibiterings": "inhibitering",
    "inhibitorer": "inhibitor",
    "inhibitorerna": "inhibitor",
    "inhibitorernas": "inhibitor",
    "inhibitorers": "inhibitor",
    "inhibitorn": "inhibitor",
    "inhibitorns": "inhibitor",
    "inhibitors": "inhibitor",
    "inhoppar": "inhoppare",
    "inhopparen": "inhoppare",
    "inhopparens": "inhoppare",
    "inhoppares": "inhoppare",
    "inhopparna": "inhoppare",
    "inhopparnas": "inhoppare",
    "inhoppen": "inhopp",
    "inhoppens": "inhopp",
    "inhoppet": "inhopp",
    "inhoppets": "inhopp",
    "inhopps": "inhopp",
    "inhumana": "inhuman",
    "inhumanare": "inhuman",
    "inhumanares": "inhuman",
    "inhumanas": "inhuman",
    "inhumanast": "inhuman",
    "inhumanaste": "inhuman",
    "inhumanastes": "inhuman",
    "inhumanasts": "inhuman",
    "inhumane": "inhuman",
    "inhumanes": "inhuman",
    "inhumans": "inhuman",
    "inhumant": "inhuman",
    "inhumants": "inhuman",
    "inhys": "inhysa",
    "inhysande": "inhysa",
    "inhysanden": "inhysande",
    "inhysandena": "inhysande",
    "inhysandenas": "inhysande",
    "inhysandens": "inhysande",
    "inhysandes": "inhysande",
    "inhysandet": "inhysande",
    "inhysandets": "inhysande",
    "inhysas": "inhysa",
    "inhyser": "inhysa",
    "inhyses": "inhysa",
    "inhysingar": "inhysing",
    "inhysingarna": "inhysing",
    "inhysingarnas": "inhysing",
    "inhysingars": "inhysing",
    "inhysingen": "inhysing",
    "inhysingens": "inhysing",
    "inhysings": "inhysing",
    "inhyst": "inhysa",
    "inhysta": "inhysa",
    "inhystas": "inhysa",
    "inhyste": "inhysa",
    "inhystes": "inhysa",
    "inhysts": "inhysa",
    "inhägn": "inhägna",
    "inhägnad": "inhägna",
    "inhägnade": "inhägna",
    "inhägnaden": "inhägnad",
    "inhägnadens": "inhägnad",
    "inhägnader": "inhägnad",
    "inhägnaderna": "inhägnad",
    "inhägnadernas": "inhägnad",
    "inhägnaders": "inhägnad",
    "inhägnades": "inhägna",
    "inhägnads": "inhägnad",
    "inhägnande": "inhägna",
    "inhägnanden": "inhägnande",
    "inhägnandena": "inhägnande",
    "inhägnandenas": "inhägnande",
    "inhägnandens": "inhägnande",
    "inhägnandes": "inhägnande",
    "inhägnandet": "inhägnande",
    "inhägnandets": "inhägnande",
    "inhägnar": "inhägna",
    "inhägnas": "inhägna",
    "inhägnat": "inhägna",
    "inhägnats": "inhägna",
    "inhämt": "inhämta",
    "inhämtad": "inhämta",
    "inhämtade": "inhämta",
    "inhämtades": "inhämta",
    "inhämtads": "inhämta",
    "inhämtande": "inhämta",
    "inhämtanden": "inhämtande",
    "inhämtandena": "inhämtande",
    "inhämtandenas": "inhämtande",
    "inhämtandens": "inhämtande",
    "inhämtandes": "inhämtande",
    "inhämtandet": "inhämtande",
    "inhämtandets": "inhämtande",
    "inhämtar": "inhämta",
    "inhämtas": "inhämta",
    "inhämtat": "inhämta",
    "inhämtats": "inhämta",
    "inhöst": "inhösta",
    "inhöstad": "inhösta",
    "inhöstade": "inhösta",
    "inhöstades": "inhösta",
    "inhöstads": "inhösta",
    "inhöstande": "inhösta",
    "inhöstanden": "inhöstande",
    "inhöstandena": "inhöstande",
    "inhöstandenas": "inhöstande",
    "inhöstandens": "inhöstande",
    "inhöstandes": "inhöstande",
    "inhöstandet": "inhöstande",
    "inhöstandets": "inhöstande",
    "inhöstar": "inhösta",
    "inhöstas": "inhösta",
    "inhöstat": "inhösta",
    "inhöstats": "inhösta",
    "initiala": "initial",
    "initialare": "initial",
    "initialares": "initial",
    "initialas": "initial",
    "initialast": "initial",
    "initialaste": "initial",
    "initialastes": "initial",
    "initialasts": "initial",
    "initiale": "initial",
    "initialen": "initial",
    "initialens": "initial",
    "initialer": "initial",
    "initialerna": "initial",
    "initialernas": "initial",
    "initialers": "initial",
    "initiales": "initial",
    "initialorden": "initialord",
    "initialordens": "initialord",
    "initialordet": "initialord",
    "initialordets": "initialord",
    "initialords": "initialord",
    "initials": "initial",
    "initialt": "initial",
    "initialts": "initial",
    "initiationen": "initiation",
    "initiationens": "initiation",
    "initiationer": "initiation",
    "initiationerna": "initiation",
    "initiationernas": "initiation",
    "initiationers": "initiation",
    "initiations": "initiation",
    "initiationsriten": "initiationsrit",
    "initiationsritens": "initiationsrit",
    "initiationsriter": "initiationsrit",
    "initiationsriterna": "initiationsrit",
    "initiationsriternas": "initiationsrit",
    "initiationsriters": "initiationsrit",
    "initiationsrits": "initiationsrit",
    "initiativen": "initiativ",
    "initiativens": "initiativ",
    "initiativet": "initiativ",
    "initiativets": "initiativ",
    "initiativkraften": "initiativkraft",
    "initiativkraftens": "initiativkraft",
    "initiativkrafts": "initiativkraft",
    "initiativrika": "initiativrik",
    "initiativrikare": "initiativrik",
    "initiativrikares": "initiativrik",
    "initiativrikas": "initiativrik",
    "initiativrikast": "initiativrik",
    "initiativrikaste": "initiativrik",
    "initiativrikastes": "initiativrik",
    "initiativrikasts": "initiativrik",
    "initiativrike": "initiativrik",
    "initiativrikes": "initiativrik",
    "initiativrikheten": "initiativrikhet",
    "initiativrikhetens": "initiativrikhet",
    "initiativrikhets": "initiativrikhet",
    "initiativriks": "initiativrik",
    "initiativrikt": "initiativrik",
    "initiativrikts": "initiativrik",
    "initiativs": "initiativ",
    "initiativtagar": "initiativtagare",
    "initiativtagaren": "initiativtagare",
    "initiativtagarens": "initiativtagare",
    "initiativtagares": "initiativtagare",
    "initiativtagarna": "initiativtagare",
    "initiativtagarnas": "initiativtagare",
    "initierad": "initiera",
    "initierade": "initierad",
    "initierades": "initierad",
    "initierads": "initierad",
    "initierande": "initiera",
    "initieranden": "initierande",
    "initierandena": "initierande",
    "initierandenas": "initierande",
    "initierandens": "initierande",
    "initierandes": "initierande",
    "initierandet": "initierande",
    "initierandets": "initierande",
    "initierar": "initiera",
    "initieras": "initiera",
    "initierat": "initierad",
    "initierats": "initierad",
    "initierbara": "initierbar",
    "initierbarare": "initierbar",
    "initierbarares": "initierbar",
    "initierbaras": "initierbar",
    "initierbarast": "initierbar",
    "initierbaraste": "initierbar",
    "initierbarastes": "initierbar",
    "initierbarasts": "initierbar",
    "initierbare": "initierbar",
    "initierbares": "initierbar",
    "initierbarheten": "initierbarhet",
    "initierbarhetens": "initierbarhet",
    "initierbarhets": "initierbarhet",
    "initierbars": "initierbar",
    "initierbart": "initierbar",
    "initierbarts": "initierbar",
    "initieringar": "initiering",
    "initieringarna": "initiering",
    "initieringarnas": "initiering",
    "initieringars": "initiering",
    "initieringen": "initiering",
    "initieringens": "initiering",
    "initierings": "initiering",
    "injag": "injaga",
    "injagad": "injaga",
    "injagade": "injaga",
    "injagades": "injaga",
    "injagads": "injaga",
    "injagande": "injaga",
    "injaganden": "injagande",
    "injagandena": "injagande",
    "injagandenas": "injagande",
    "injagandens": "injagande",
    "injagandes": "injagande",
    "injagandet": "injagande",
    "injagandets": "injagande",
    "injagar": "injaga",
    "injagas": "injaga",
    "injagat": "injaga",
    "injagats": "injaga",
    "injekterad": "injektera",
    "injekterade": "injektera",
    "injekterades": "injektera",
    "injekterads": "injektera",
    "injekterande": "injektera",
    "injekteranden": "injekterande",
    "injekterandena": "injekterande",
    "injekterandenas": "injekterande",
    "injekterandens": "injekterande",
    "injekterandes": "injekterande",
    "injekterandet": "injekterande",
    "injekterandets": "injekterande",
    "injekterar": "injektera",
    "injekteras": "injektera",
    "injekterat": "injektera",
    "injekterats": "injektera",
    "injekterbara": "injekterbar",
    "injekterbarare": "injekterbar",
    "injekterbarares": "injekterbar",
    "injekterbaras": "injekterbar",
    "injekterbarast": "injekterbar",
    "injekterbaraste": "injekterbar",
    "injekterbarastes": "injekterbar",
    "injekterbarasts": "injekterbar",
    "injekterbare": "injekterbar",
    "injekterbares": "injekterbar",
    "injekterbarheten": "injekterbarhet",
    "injekterbarhetens": "injekterbarhet",
    "injekterbarhets": "injekterbarhet",
    "injekterbars": "injekterbar",
    "injekterbart": "injekterbar",
    "injekterbarts": "injekterbar",
    "injekteringar": "injektering",
    "injekteringarna": "injektering",
    "injekteringarnas": "injektering",
    "injekteringars": "injektering",
    "injekteringen": "injektering",
    "injekteringens": "injektering",
    "injekterings": "injektering",
    "injektionen": "injektion",
    "injektionens": "injektion",
    "injektioner": "injektion",
    "injektionerna": "injektion",
    "injektionernas": "injektion",
    "injektioners": "injektion",
    "injektions": "injektion",
    "injektionsnålar": "injektionsnål",
    "injektionsnålarna": "injektionsnål",
    "injektionsnålarnas": "injektionsnål",
    "injektionsnålars": "injektionsnål",
    "injektionsnålen": "injektionsnål",
    "injektionsnålens": "injektionsnål",
    "injektionsnåls": "injektionsnål",
    "injektionssprut": "injektionsspruta",
    "injektionssprutan": "injektionsspruta",
    "injektionssprutans": "injektionsspruta",
    "injektionssprutas": "injektionsspruta",
    "injektionssprute": "injektionsspruta",
    "injektionssprutor": "injektionsspruta",
    "injektionssprutorna": "injektionsspruta",
    "injektionssprutornas": "injektionsspruta",
    "injektionssprutors": "injektionsspruta",
    "injektionsspruts": "injektionsspruta",
    "injektionsställen": "injektionsställe",
    "injektionsställena": "injektionsställe",
    "injektionsställenas": "injektionsställe",
    "injektionsställens": "injektionsställe",
    "injektionsställes": "injektionsställe",
    "injektionsstället": "injektionsställe",
    "injektionsställets": "injektionsställe",
    "injektorer": "injektor",
    "injektorerna": "injektor",
    "injektorernas": "injektor",
    "injektorers": "injektor",
    "injektorn": "injektor",
    "injektorns": "injektor",
    "injektors": "injektor",
    "injicerad": "injicera",
    "injicerade": "injicera",
    "injicerades": "injicera",
    "injicerads": "injicera",
    "injicerande": "injicera",
    "injiceranden": "injicerande",
    "injicerandena": "injicerande",
    "injicerandenas": "injicerande",
    "injicerandens": "injicerande",
    "injicerandes": "injicerande",
    "injicerandet": "injicerande",
    "injicerandets": "injicerande",
    "injicerar": "injicera",
    "injiceras": "injicera",
    "injicerat": "injicera",
    "injicerats": "injicera",
    "injicerbara": "injicerbar",
    "injicerbarare": "injicerbar",
    "injicerbarares": "injicerbar",
    "injicerbaras": "injicerbar",
    "injicerbarast": "injicerbar",
    "injicerbaraste": "injicerbar",
    "injicerbarastes": "injicerbar",
    "injicerbarasts": "injicerbar",
    "injicerbare": "injicerbar",
    "injicerbares": "injicerbar",
    "injicerbarheten": "injicerbarhet",
    "injicerbarhetens": "injicerbarhet",
    "injicerbarhets": "injicerbarhet",
    "injicerbars": "injicerbar",
    "injicerbart": "injicerbar",
    "injicerbarts": "injicerbar",
    "injiceringar": "injicering",
    "injiceringarna": "injicering",
    "injiceringarnas": "injicering",
    "injiceringars": "injicering",
    "injiceringen": "injicering",
    "injiceringens": "injicering",
    "injicerings": "injicering",
    "injurien": "injurie",
    "injuriens": "injurie",
    "injurier": "injurie",
    "injurierna": "injurie",
    "injuriernas": "injurie",
    "injuriers": "injurie",
    "injuries": "injurie",
    "inkabären": "inkabär",
    "inkabärens": "inkabär",
    "inkabäret": "inkabär",
    "inkabärets": "inkabär",
    "inkabärs": "inkabär",
    "inkafolket": "inkafolk",
    "inkafolkets": "inkafolk",
    "inkafolks": "inkafolk",
    "inkaindianen": "inkaindian",
    "inkaindianens": "inkaindian",
    "inkaindianer": "inkaindian",
    "inkaindianerna": "inkaindian",
    "inkaindianernas": "inkaindian",
    "inkaindianers": "inkaindian",
    "inkaindians": "inkaindian",
    "inkall": "inkalla",
    "inkallad": "inkalla",
    "inkallade": "inkalla",
    "inkallades": "inkalla",
    "inkallads": "inkalla",
    "inkallae": "inkalla",
    "inkallaes": "inkalla",
    "inkallande": "inkalla",
    "inkallanden": "inkallande",
    "inkallandena": "inkallande",
    "inkallandenas": "inkallande",
    "inkallandens": "inkallande",
    "inkallandes": "inkallande",
    "inkallandet": "inkallande",
    "inkallandets": "inkallande",
    "inkallar": "inkalla",
    "inkallas": "inkalla",
    "inkallat": "inkalla",
    "inkallats": "inkalla",
    "inkallelsebreven": "inkallelsebrev",
    "inkallelsebrevens": "inkallelsebrev",
    "inkallelsebrevet": "inkallelsebrev",
    "inkallelsebrevets": "inkallelsebrev",
    "inkallelsebrevs": "inkallelsebrev",
    "inkallelsen": "inkallelse",
    "inkallelsens": "inkallelse",
    "inkallelseordern": "inkallelseorder",
    "inkallelseorderna": "inkallelseorder",
    "inkallelseordernas": "inkallelseorder",
    "inkallelseorderns": "inkallelseorder",
    "inkallelseorders": "inkallelseorder",
    "inkallelseordrar": "inkallelseorder",
    "inkallelseordrarna": "inkallelseorder",
    "inkallelseordrarnas": "inkallelseorder",
    "inkallelseordrars": "inkallelseorder",
    "inkallelser": "inkallelse",
    "inkallelserna": "inkallelse",
    "inkallelsernas": "inkallelse",
    "inkallelsers": "inkallelse",
    "inkallelses": "inkallelse",
    "inkallt": "inkalla",
    "inkallts": "inkalla",
    "inkan": "inka",
    "inkans": "inka",
    "inkapabels": "inkapabel",
    "inkapabelt": "inkapabel",
    "inkapabelts": "inkapabel",
    "inkapabla": "inkapabel",
    "inkapablare": "inkapabel",
    "inkapablares": "inkapabel",
    "inkapablas": "inkapabel",
    "inkapablast": "inkapabel",
    "inkapablaste": "inkapabel",
    "inkapablastes": "inkapabel",
    "inkapablasts": "inkapabel",
    "inkapable": "inkapabel",
    "inkapables": "inkapabel",
    "inkapslad": "inkapsla",
    "inkapslade": "inkapsla",
    "inkapslades": "inkapsla",
    "inkapslads": "inkapsla",
    "inkapslande": "inkapsla",
    "inkapslanden": "inkapslande",
    "inkapslandena": "inkapslande",
    "inkapslandenas": "inkapslande",
    "inkapslandens": "inkapslande",
    "inkapslandes": "inkapslande",
    "inkapslandet": "inkapslande",
    "inkapslandets": "inkapslande",
    "inkapslar": "inkapsla",
    "inkapslas": "inkapsla",
    "inkapslat": "inkapsla",
    "inkapslats": "inkapsla",
    "inkapslingar": "inkapsling",
    "inkapslingarna": "inkapsling",
    "inkapslingarnas": "inkapsling",
    "inkapslingars": "inkapsling",
    "inkapslingen": "inkapsling",
    "inkapslingens": "inkapsling",
    "inkapslings": "inkapsling",
    "inkar": "ink",
    "inkarna": "ink",
    "inkarnas": "ink",
    "inkarnationen": "inkarnation",
    "inkarnationens": "inkarnation",
    "inkarnationer": "inkarnation",
    "inkarnationerna": "inkarnation",
    "inkarnationernas": "inkarnation",
    "inkarnationers": "inkarnation",
    "inkarnations": "inkarnation",
    "inkarnerad": "inkarnera",
    "inkarnerade": "inkarnera",
    "inkarnerades": "inkarnera",
    "inkarnerads": "inkarnera",
    "inkarnerande": "inkarnera",
    "inkarneranden": "inkarnerande",
    "inkarnerandena": "inkarnerande",
    "inkarnerandenas": "inkarnerande",
    "inkarnerandens": "inkarnerande",
    "inkarnerandes": "inkarnerande",
    "inkarnerandet": "inkarnerande",
    "inkarnerandets": "inkarnerande",
    "inkarnerar": "inkarnera",
    "inkarneras": "inkarnera",
    "inkarnerat": "inkarnera",
    "inkarnerats": "inkarnera",
    "inkarnerbara": "inkarnerbar",
    "inkarnerbarare": "inkarnerbar",
    "inkarnerbarares": "inkarnerbar",
    "inkarnerbaras": "inkarnerbar",
    "inkarnerbarast": "inkarnerbar",
    "inkarnerbaraste": "inkarnerbar",
    "inkarnerbarastes": "inkarnerbar",
    "inkarnerbarasts": "inkarnerbar",
    "inkarnerbare": "inkarnerbar",
    "inkarnerbares": "inkarnerbar",
    "inkarnerbarheten": "inkarnerbarhet",
    "inkarnerbarhetens": "inkarnerbarhet",
    "inkarnerbarhets": "inkarnerbarhet",
    "inkarnerbars": "inkarnerbar",
    "inkarnerbart": "inkarnerbar",
    "inkarnerbarts": "inkarnerbar",
    "inkarneringar": "inkarnering",
    "inkarneringarna": "inkarnering",
    "inkarneringarnas": "inkarnering",
    "inkarneringars": "inkarnering",
    "inkarneringen": "inkarnering",
    "inkarneringens": "inkarnering",
    "inkarnerings": "inkarnering",
    "inkars": "ink",
    "inkas": "inka",
    "inkasserad": "inkassera",
    "inkasserade": "inkassera",
    "inkasserades": "inkassera",
    "inkasserads": "inkassera",
    "inkasserande": "inkassera",
    "inkasseranden": "inkasserande",
    "inkasserandena": "inkasserande",
    "inkasserandenas": "inkasserande",
    "inkasserandens": "inkasserande",
    "inkasserandes": "inkasserande",
    "inkasserandet": "inkasserande",
    "inkasserandets": "inkasserande",
    "inkasserar": "inkassera",
    "inkasseras": "inkassera",
    "inkasserat": "inkassera",
    "inkasserats": "inkassera",
    "inkasserbara": "inkasserbar",
    "inkasserbarare": "inkasserbar",
    "inkasserbarares": "inkasserbar",
    "inkasserbaras": "inkasserbar",
    "inkasserbarast": "inkasserbar",
    "inkasserbaraste": "inkasserbar",
    "inkasserbarastes": "inkasserbar",
    "inkasserbarasts": "inkasserbar",
    "inkasserbare": "inkasserbar",
    "inkasserbares": "inkasserbar",
    "inkasserbarheten": "inkasserbarhet",
    "inkasserbarhetens": "inkasserbarhet",
    "inkasserbarhets": "inkasserbarhet",
    "inkasserbars": "inkasserbar",
    "inkasserbart": "inkasserbar",
    "inkasserbarts": "inkasserbar",
    "inkasseringar": "inkassering",
    "inkasseringarna": "inkassering",
    "inkasseringarnas": "inkassering",
    "inkasseringars": "inkassering",
    "inkasseringen": "inkassering",
    "inkasseringens": "inkassering",
    "inkasserings": "inkassering",
    "inkassos": "inkasso",
    "inkassot": "inkasso",
    "inkassots": "inkasso",
    "inkasten": "inkast",
    "inkastens": "inkast",
    "inkastet": "inkast",
    "inkastets": "inkast",
    "inkasts": "inkast",
    "inken": "ink",
    "inkens": "ink",
    "inkietta": "inkiett",
    "inkiettare": "inkiett",
    "inkiettares": "inkiett",
    "inkiettas": "inkiett",
    "inkiettast": "inkiett",
    "inkiettaste": "inkiett",
    "inkiettastes": "inkiett",
    "inkiettasts": "inkiett",
    "inkiette": "inkiett",
    "inkiettes": "inkiett",
    "inkietts": "inkiett",
    "inkilade": "inkilad",
    "inkilades": "inkilad",
    "inkilads": "inkilad",
    "inkilat": "inkilad",
    "inkilats": "inkilad",
    "inklarerad": "inklarera",
    "inklarerade": "inklarera",
    "inklarerades": "inklarera",
    "inklarerads": "inklarera",
    "inklarerande": "inklarera",
    "inklareranden": "inklarerande",
    "inklarerandena": "inklarerande",
    "inklarerandenas": "inklarerande",
    "inklarerandens": "inklarerande",
    "inklarerandes": "inklarerande",
    "inklarerandet": "inklarerande",
    "inklarerandets": "inklarerande",
    "inklarerar": "inklarera",
    "inklareras": "inklarera",
    "inklarerat": "inklarera",
    "inklarerats": "inklarera",
    "inklarerbara": "inklarerbar",
    "inklarerbarare": "inklarerbar",
    "inklarerbarares": "inklarerbar",
    "inklarerbaras": "inklarerbar",
    "inklarerbarast": "inklarerbar",
    "inklarerbaraste": "inklarerbar",
    "inklarerbarastes": "inklarerbar",
    "inklarerbarasts": "inklarerbar",
    "inklarerbare": "inklarerbar",
    "inklarerbares": "inklarerbar",
    "inklarerbarheten": "inklarerbarhet",
    "inklarerbarhetens": "inklarerbarhet",
    "inklarerbarhets": "inklarerbarhet",
    "inklarerbars": "inklarerbar",
    "inklarerbart": "inklarerbar",
    "inklarerbarts": "inklarerbar",
    "inklareringar": "inklarering",
    "inklareringarna": "inklarering",
    "inklareringarnas": "inklarering",
    "inklareringars": "inklarering",
    "inklareringen": "inklarering",
    "inklareringens": "inklarering",
    "inklarerings": "inklarering",
    "inklinationen": "inklination",
    "inklinationens": "inklination",
    "inklinationer": "inklination",
    "inklinationerna": "inklination",
    "inklinationernas": "inklination",
    "inklinationers": "inklination",
    "inklinations": "inklination",
    "inklinationsnålar": "inklinationsnål",
    "inklinationsnålarna": "inklinationsnål",
    "inklinationsnålarnas": "inklinationsnål",
    "inklinationsnålars": "inklinationsnål",
    "inklinationsnålen": "inklinationsnål",
    "inklinationsnålens": "inklinationsnål",
    "inklinationsnåls": "inklinationsnål",
    "inkluderad": "inkludera",
    "inkluderade": "inkludera",
    "inkluderades": "inkludera",
    "inkluderads": "inkludera",
    "inkluderande": "inkludera",
    "inkluderanden": "inkluderande",
    "inkluderandena": "inkluderande",
    "inkluderandenas": "inkluderande",
    "inkluderandens": "inkluderande",
    "inkluderandes": "inkluderande",
    "inkluderandet": "inkluderande",
    "inkluderandets": "inkluderande",
    "inkluderar": "inkludera",
    "inkluderas": "inkludera",
    "inkluderat": "inkludera",
    "inkluderats": "inkludera",
    "inkluderbara": "inkluderbar",
    "inkluderbarare": "inkluderbar",
    "inkluderbarares": "inkluderbar",
    "inkluderbaras": "inkluderbar",
    "inkluderbarast": "inkluderbar",
    "inkluderbaraste": "inkluderbar",
    "inkluderbarastes": "inkluderbar",
    "inkluderbarasts": "inkluderbar",
    "inkluderbare": "inkluderbar",
    "inkluderbares": "inkluderbar",
    "inkluderbarheten": "inkluderbarhet",
    "inkluderbarhetens": "inkluderbarhet",
    "inkluderbarhets": "inkluderbarhet",
    "inkluderbars": "inkluderbar",
    "inkluderbart": "inkluderbar",
    "inkluderbarts": "inkluderbar",
    "inkluderingar": "inkludering",
    "inkluderingarna": "inkludering",
    "inkluderingarnas": "inkludering",
    "inkluderingars": "inkludering",
    "inkluderingen": "inkludering",
    "inkluderingens": "inkludering",
    "inkluderings": "inkludering",
    "inkoativa": "inkoativ",
    "inkoativare": "inkoativ",
    "inkoativares": "inkoativ",
    "inkoativas": "inkoativ",
    "inkoativast": "inkoativ",
    "inkoativaste": "inkoativ",
    "inkoativastes": "inkoativ",
    "inkoativasts": "inkoativ",
    "inkoative": "inkoativ",
    "inkoatives": "inkoativ",
    "inkoativs": "inkoativ",
    "inkoativt": "inkoativ",
    "inkoativts": "inkoativ",
    "inkognitos": "inkognito",
    "inkognitot": "inkognito",
    "inkognitots": "inkognito",
    "inkok": "inkoka",
    "inkokad": "inkoka",
    "inkokade": "inkoka",
    "inkokades": "inkoka",
    "inkokads": "inkoka",
    "inkokande": "inkoka",
    "inkokanden": "inkokande",
    "inkokandena": "inkokande",
    "inkokandenas": "inkokande",
    "inkokandens": "inkokande",
    "inkokandes": "inkokande",
    "inkokandet": "inkokande",
    "inkokandets": "inkokande",
    "inkokar": "inkoka",
    "inkokas": "inkoka",
    "inkokat": "inkoka",
    "inkokats": "inkoka",
    "inkoker": "inkoka",
    "inkokes": "inkoka",
    "inkoks": "inkoka",
    "inkokt": "inkoka",
    "inkokta": "inkoka",
    "inkoktas": "inkoka",
    "inkokte": "inkoka",
    "inkoktes": "inkoka",
    "inkokts": "inkoka",
    "inkom": "inkomma",
    "inkomet": "inkomma",
    "inkomets": "inkomma",
    "inkommande": "inkomma",
    "inkommanden": "inkommande",
    "inkommandena": "inkommande",
    "inkommandenas": "inkommande",
    "inkommandens": "inkommande",
    "inkommandes": "inkommande",
    "inkommandet": "inkommande",
    "inkommandets": "inkommande",
    "inkommas": "inkomma",
    "inkomme": "inkomma",
    "inkommen": "inkomma",
    "inkommens": "inkomma",
    "inkommensurabels": "inkommensurabel",
    "inkommensurabelt": "inkommensurabel",
    "inkommensurabelts": "inkommensurabel",
    "inkommensurabla": "inkommensurabel",
    "inkommensurablare": "inkommensurabel",
    "inkommensurablares": "inkommensurabel",
    "inkommensurablas": "inkommensurabel",
    "inkommensurablast": "inkommensurabel",
    "inkommensurablaste": "inkommensurabel",
    "inkommensurablastes": "inkommensurabel",
    "inkommensurablasts": "inkommensurabel",
    "inkommensurable": "inkommensurabel",
    "inkommensurables": "inkommensurabel",
    "inkommer": "inkomma",
    "inkommes": "inkomma",
    "inkommit": "inkomma",
    "inkommits": "inkomma",
    "inkomna": "inkomma",
    "inkomnas": "inkomma",
    "inkomne": "inkomma",
    "inkomnes": "inkomma",
    "inkompatibels": "inkompatibel",
    "inkompatibelt": "inkompatibel",
    "inkompatibelts": "inkompatibel",
    "inkompatibla": "inkompatibel",
    "inkompatiblare": "inkompatibel",
    "inkompatiblares": "inkompatibel",
    "inkompatiblas": "inkompatibel",
    "inkompatiblast": "inkompatibel",
    "inkompatiblaste": "inkompatibel",
    "inkompatiblastes": "inkompatibel",
    "inkompatiblasts": "inkompatibel",
    "inkompatible": "inkompatibel",
    "inkompatibles": "inkompatibel",
    "inkompetensen": "inkompetens",
    "inkompetensens": "inkompetens",
    "inkompetensförklarad": "inkompetensförklara",
    "inkompetensförklarade": "inkompetensförklara",
    "inkompetensförklarades": "inkompetensförklara",
    "inkompetensförklarads": "inkompetensförklara",
    "inkompetensförklarande": "inkompetensförklara",
    "inkompetensförklarandes": "inkompetensförklara",
    "inkompetensförklarar": "inkompetensförklara",
    "inkompetensförklaras": "inkompetensförklara",
    "inkompetensförklarat": "inkompetensförklara",
    "inkompetensförklarats": "inkompetensförklara",
    "inkompetenta": "inkompetent",
    "inkompetentare": "inkompetent",
    "inkompetentares": "inkompetent",
    "inkompetentas": "inkompetent",
    "inkompetentast": "inkompetent",
    "inkompetentaste": "inkompetent",
    "inkompetentastes": "inkompetent",
    "inkompetentasts": "inkompetent",
    "inkompetente": "inkompetent",
    "inkompetentes": "inkompetent",
    "inkompetents": "inkompetent",
    "inkoms": "inkomma",
    "inkomstbegreppen": "inkomstbegrepp",
    "inkomstbegreppens": "inkomstbegrepp",
    "inkomstbegreppet": "inkomstbegrepp",
    "inkomstbegreppets": "inkomstbegrepp",
    "inkomstbegrepps": "inkomstbegrepp",
    "inkomstbeskattningar": "inkomstbeskattning",
    "inkomstbeskattningarna": "inkomstbeskattning",
    "inkomstbeskattningarnas": "inkomstbeskattning",
    "inkomstbeskattningars": "inkomstbeskattning",
    "inkomstbeskattningen": "inkomstbeskattning",
    "inkomstbeskattningens": "inkomstbeskattning",
    "inkomstbeskattnings": "inkomstbeskattning",
    "inkomstbortfallen": "inkomstbortfall",
    "inkomstbortfallens": "inkomstbortfall",
    "inkomstbortfallet": "inkomstbortfall",
    "inkomstbortfallets": "inkomstbortfall",
    "inkomstbortfalls": "inkomstbortfall",
    "inkomsten": "inkomst",
    "inkomstens": "inkomst",
    "inkomster": "inkomst",
    "inkomsterna": "inkomst",
    "inkomsternas": "inkomst",
    "inkomsters": "inkomst",
    "inkomstgarantien": "inkomstgaranti",
    "inkomstgarantiens": "inkomstgaranti",
    "inkomstgarantier": "inkomstgaranti",
    "inkomstgarantierna": "inkomstgaranti",
    "inkomstgarantiernas": "inkomstgaranti",
    "inkomstgarantiers": "inkomstgaranti",
    "inkomstgarantin": "inkomstgaranti",
    "inkomstgarantins": "inkomstgaranti",
    "inkomstgarantis": "inkomstgaranti",
    "inkomstintervallen": "inkomstintervall",
    "inkomstintervallens": "inkomstintervall",
    "inkomstintervaller": "inkomstintervall",
    "inkomstintervallerna": "inkomstintervall",
    "inkomstintervallernas": "inkomstintervall",
    "inkomstintervallers": "inkomstintervall",
    "inkomstintervallet": "inkomstintervall",
    "inkomstintervallets": "inkomstintervall",
    "inkomstintervalls": "inkomstintervall",
    "inkomstklyftan": "inkomstklyfta",
    "inkomstklyftans": "inkomstklyfta",
    "inkomstklyftas": "inkomstklyfta",
    "inkomstklyfte": "inkomstklyfta",
    "inkomstklyftor": "inkomstklyfta",
    "inkomstklyftorna": "inkomstklyfta",
    "inkomstklyftornas": "inkomstklyfta",
    "inkomstklyftors": "inkomstklyfta",
    "inkomstkorten": "inkomstkort",
    "inkomstkortens": "inkomstkort",
    "inkomstkortet": "inkomstkort",
    "inkomstkortets": "inkomstkort",
    "inkomstkorts": "inkomstkort",
    "inkomstkäll": "inkomstkälla",
    "inkomstkällan": "inkomstkälla",
    "inkomstkällans": "inkomstkälla",
    "inkomstkällas": "inkomstkälla",
    "inkomstkälle": "inkomstkälla",
    "inkomstkällor": "inkomstkälla",
    "inkomstkällorna": "inkomstkälla",
    "inkomstkällornas": "inkomstkälla",
    "inkomstkällors": "inkomstkälla",
    "inkomstkälls": "inkomstkälla",
    "inkomstmässiga": "inkomstmässig",
    "inkomstmässigare": "inkomstmässig",
    "inkomstmässigares": "inkomstmässig",
    "inkomstmässigas": "inkomstmässig",
    "inkomstmässigast": "inkomstmässig",
    "inkomstmässigaste": "inkomstmässig",
    "inkomstmässigastes": "inkomstmässig",
    "inkomstmässigasts": "inkomstmässig",
    "inkomstmässige": "inkomstmässig",
    "inkomstmässiges": "inkomstmässig",
    "inkomstmässigs": "inkomstmässig",
    "inkomstmässigt": "inkomstmässig",
    "inkomstmässigts": "inkomstmässig",
    "inkomstmåtten": "inkomstmått",
    "inkomstmåttens": "inkomstmått",
    "inkomstmåttet": "inkomstmått",
    "inkomstmåttets": "inkomstmått",
    "inkomstmåtts": "inkomstmått",
    "inkomsts": "inkomst",
    "inkomstskatten": "inkomstskatt",
    "inkomstskattens": "inkomstskatt",
    "inkomstskatter": "inkomstskatt",
    "inkomstskatterna": "inkomstskatt",
    "inkomstskatternas": "inkomstskatt",
    "inkomstskatters": "inkomstskatt",
    "inkomstskatts": "inkomstskatt",
    "inkomstskillnaden": "inkomstskillnad",
    "inkomstskillnadens": "inkomstskillnad",
    "inkomstskillnader": "inkomstskillnad",
    "inkomstskillnaderna": "inkomstskillnad",
    "inkomstskillnadernas": "inkomstskillnad",
    "inkomstskillnaders": "inkomstskillnad",
    "inkomstskillnads": "inkomstskillnad",
    "inkomstslagen": "inkomstslag",
    "inkomstslagens": "inkomstslag",
    "inkomstslaget": "inkomstslag",
    "inkomstslagets": "inkomstslag",
    "inkomstslags": "inkomstslag",
    "inkomsttagar": "inkomsttagare",
    "inkomsttagaren": "inkomsttagare",
    "inkomsttagarens": "inkomsttagare",
    "inkomsttagares": "inkomsttagare",
    "inkomsttagarna": "inkomsttagare",
    "inkomsttagarnas": "inkomsttagare",
    "inkomsttaxerad": "inkomsttaxera",
    "inkomsttaxerade": "inkomsttaxera",
    "inkomsttaxerades": "inkomsttaxera",
    "inkomsttaxerads": "inkomsttaxera",
    "inkomsttaxerande": "inkomsttaxera",
    "inkomsttaxeranden": "inkomsttaxerande",
    "inkomsttaxerandena": "inkomsttaxerande",
    "inkomsttaxerandenas": "inkomsttaxerande",
    "inkomsttaxerandens": "inkomsttaxerande",
    "inkomsttaxerandes": "inkomsttaxerande",
    "inkomsttaxerandet": "inkomsttaxerande",
    "inkomsttaxerandets": "inkomsttaxerande",
    "inkomsttaxerar": "inkomsttaxera",
    "inkomsttaxeras": "inkomsttaxera",
    "inkomsttaxerat": "inkomsttaxera",
    "inkomsttaxerats": "inkomsttaxera",
    "inkomsttaxerbara": "inkomsttaxerbar",
    "inkomsttaxerbarare": "inkomsttaxerbar",
    "inkomsttaxerbarares": "inkomsttaxerbar",
    "inkomsttaxerbaras": "inkomsttaxerbar",
    "inkomsttaxerbarast": "inkomsttaxerbar",
    "inkomsttaxerbaraste": "inkomsttaxerbar",
    "inkomsttaxerbarastes": "inkomsttaxerbar",
    "inkomsttaxerbarasts": "inkomsttaxerbar",
    "inkomsttaxerbare": "inkomsttaxerbar",
    "inkomsttaxerbares": "inkomsttaxerbar",
    "inkomsttaxerbarheten": "inkomsttaxerbarhet",
    "inkomsttaxerbarhetens": "inkomsttaxerbarhet",
    "inkomsttaxerbarhets": "inkomsttaxerbarhet",
    "inkomsttaxerbars": "inkomsttaxerbar",
    "inkomsttaxerbart": "inkomsttaxerbar",
    "inkomsttaxerbarts": "inkomsttaxerbar",
    "inkomsttaxeringar": "inkomsttaxering",
    "inkomsttaxeringarna": "inkomsttaxering",
    "inkomsttaxeringarnas": "inkomsttaxering",
    "inkomsttaxeringars": "inkomsttaxering",
    "inkomsttaxeringen": "inkomsttaxering",
    "inkomsttaxeringens": "inkomsttaxering",
    "inkomsttaxerings": "inkomsttaxering",
    "inkomstökningar": "inkomstökning",
    "inkomstökningarna": "inkomstökning",
    "inkomstökningarnas": "inkomstökning",
    "inkomstökningars": "inkomstökning",
    "inkomstökningen": "inkomstökning",
    "inkomstökningens": "inkomstökning",
    "inkomstöknings": "inkomstökning",
    "inkongruensen": "inkongruens",
    "inkongruensens": "inkongruens",
    "inkongruenser": "inkongruens",
    "inkongruenserna": "inkongruens",
    "inkongruensernas": "inkongruens",
    "inkongruensers": "inkongruens",
    "inkongruenta": "inkongruent",
    "inkongruentare": "inkongruent",
    "inkongruentares": "inkongruent",
    "inkongruentas": "inkongruent",
    "inkongruentast": "inkongruent",
    "inkongruentaste": "inkongruent",
    "inkongruentastes": "inkongruent",
    "inkongruentasts": "inkongruent",
    "inkongruente": "inkongruent",
    "inkongruentes": "inkongruent",
    "inkongruents": "inkongruent",
    "inkonsekvensen": "inkonsekvens",
    "inkonsekvensens": "inkonsekvens",
    "inkonsekvenser": "inkonsekvens",
    "inkonsekvenserna": "inkonsekvens",
    "inkonsekvensernas": "inkonsekvens",
    "inkonsekvensers": "inkonsekvens",
    "inkonsekventa": "inkonsekvent",
    "inkonsekventare": "inkonsekvent",
    "inkonsekventares": "inkonsekvent",
    "inkonsekventas": "inkonsekvent",
    "inkonsekventast": "inkonsekvent",
    "inkonsekventaste": "inkonsekvent",
    "inkonsekventastes": "inkonsekvent",
    "inkonsekventasts": "inkonsekvent",
    "inkonsekvente": "inkonsekvent",
    "inkonsekventes": "inkonsekvent",
    "inkonsekvents": "inkonsekvent",
    "inkontinensen": "inkontinens",
    "inkontinensens": "inkontinens",
    "inkontinenta": "inkontinent",
    "inkontinentare": "inkontinent",
    "inkontinentares": "inkontinent",
    "inkontinentas": "inkontinent",
    "inkontinentast": "inkontinent",
    "inkontinentaste": "inkontinent",
    "inkontinentastes": "inkontinent",
    "inkontinentasts": "inkontinent",
    "inkontinente": "inkontinent",
    "inkontinentes": "inkontinent",
    "inkontinents": "inkontinent",
    "inkopplad": "inkoppla",
    "inkopplade": "inkoppla",
    "inkopplades": "inkoppla",
    "inkopplads": "inkoppla",
    "inkopplande": "inkoppla",
    "inkopplanden": "inkopplande",
    "inkopplandena": "inkopplande",
    "inkopplandenas": "inkopplande",
    "inkopplandens": "inkopplande",
    "inkopplandes": "inkopplande",
    "inkopplandet": "inkopplande",
    "inkopplandets": "inkopplande",
    "inkopplar": "inkoppla",
    "inkopplas": "inkoppla",
    "inkopplat": "inkoppla",
    "inkopplats": "inkoppla",
    "inkor": "inka",
    "inkorna": "inka",
    "inkornas": "inka",
    "inkorporerad": "inkorporera",
    "inkorporerade": "inkorporera",
    "inkorporerades": "inkorporera",
    "inkorporerads": "inkorporera",
    "inkorporerande": "inkorporera",
    "inkorporeranden": "inkorporerande",
    "inkorporerandena": "inkorporerande",
    "inkorporerandenas": "inkorporerande",
    "inkorporerandens": "inkorporerande",
    "inkorporerandes": "inkorporerande",
    "inkorporerandet": "inkorporerande",
    "inkorporerandets": "inkorporerande",
    "inkorporerar": "inkorporera",
    "inkorporeras": "inkorporera",
    "inkorporerat": "inkorporera",
    "inkorporerats": "inkorporera",
    "inkorporerbara": "inkorporerbar",
    "inkorporerbarare": "inkorporerbar",
    "inkorporerbarares": "inkorporerbar",
    "inkorporerbaras": "inkorporerbar",
    "inkorporerbarast": "inkorporerbar",
    "inkorporerbaraste": "inkorporerbar",
    "inkorporerbarastes": "inkorporerbar",
    "inkorporerbarasts": "inkorporerbar",
    "inkorporerbare": "inkorporerbar",
    "inkorporerbares": "inkorporerbar",
    "inkorporerbarheten": "inkorporerbarhet",
    "inkorporerbarhetens": "inkorporerbarhet",
    "inkorporerbarhets": "inkorporerbarhet",
    "inkorporerbars": "inkorporerbar",
    "inkorporerbart": "inkorporerbar",
    "inkorporerbarts": "inkorporerbar",
    "inkorporeringar": "inkorporering",
    "inkorporeringarna": "inkorporering",
    "inkorporeringarnas": "inkorporering",
    "inkorporeringars": "inkorporering",
    "inkorporeringen": "inkorporering",
    "inkorporeringens": "inkorporering",
    "inkorporerings": "inkorporering",
    "inkorrekta": "inkorrekt",
    "inkorrektare": "inkorrekt",
    "inkorrektares": "inkorrekt",
    "inkorrektas": "inkorrekt",
    "inkorrektast": "inkorrekt",
    "inkorrektaste": "inkorrekt",
    "inkorrektastes": "inkorrekt",
    "inkorrektasts": "inkorrekt",
    "inkorrekte": "inkorrekt",
    "inkorrektes": "inkorrekt",
    "inkorrektheten": "inkorrekthet",
    "inkorrekthetens": "inkorrekthet",
    "inkorrekthets": "inkorrekthet",
    "inkorrekts": "inkorrekt",
    "inkors": "inka",
    "inkrustationen": "inkrustation",
    "inkrustationens": "inkrustation",
    "inkrustationer": "inkrustation",
    "inkrustationerna": "inkrustation",
    "inkrustationernas": "inkrustation",
    "inkrustationers": "inkrustation",
    "inkrustations": "inkrustation",
    "inkräktade": "inkräkta",
    "inkräktades": "inkräkta",
    "inkräktande": "inkräkta",
    "inkräktanden": "inkräktande",
    "inkräktandena": "inkräktande",
    "inkräktandenas": "inkräktande",
    "inkräktandens": "inkräktande",
    "inkräktandes": "inkräktande",
    "inkräktandet": "inkräktande",
    "inkräktandets": "inkräktande",
    "inkräktar": "inkräktare",
    "inkräktaren": "inkräktare",
    "inkräktarens": "inkräktare",
    "inkräktares": "inkräktare",
    "inkräktarna": "inkräktare",
    "inkräktarnas": "inkräktare",
    "inkräktas": "inkräkta",
    "inkräktat": "inkräkta",
    "inkräktats": "inkräkta",
    "inkräv": "inkräva",
    "inkrävande": "inkräva",
    "inkrävanden": "inkrävande",
    "inkrävandena": "inkrävande",
    "inkrävandenas": "inkrävande",
    "inkrävandens": "inkrävande",
    "inkrävandes": "inkrävande",
    "inkrävandet": "inkrävande",
    "inkrävandets": "inkrävande",
    "inkrävas": "inkräva",
    "inkrävd": "inkräva",
    "inkrävda": "inkräva",
    "inkrävdas": "inkräva",
    "inkrävde": "inkräva",
    "inkrävdes": "inkräva",
    "inkrävds": "inkräva",
    "inkräver": "inkräva",
    "inkräves": "inkräva",
    "inkrävs": "inkräva",
    "inkrävt": "inkräva",
    "inkrävts": "inkräva",
    "inkråmet": "inkråm",
    "inkråmets": "inkråm",
    "inkråms": "inkråm",
    "inkrökta": "inkrökt",
    "inkröktare": "inkrökt",
    "inkröktares": "inkrökt",
    "inkröktas": "inkrökt",
    "inkröktast": "inkrökt",
    "inkröktaste": "inkrökt",
    "inkröktastes": "inkrökt",
    "inkröktasts": "inkrökt",
    "inkrökte": "inkrökt",
    "inkröktes": "inkrökt",
    "inkröktheten": "inkrökthet",
    "inkrökthetens": "inkrökthet",
    "inkrökthets": "inkrökthet",
    "inkrökts": "inkrökt",
    "inks": "ink",
    "inkubationen": "inkubation",
    "inkubationens": "inkubation",
    "inkubationer": "inkubation",
    "inkubationerna": "inkubation",
    "inkubationernas": "inkubation",
    "inkubationers": "inkubation",
    "inkubations": "inkubation",
    "inkubationstiden": "inkubationstid",
    "inkubationstidens": "inkubationstid",
    "inkubationstider": "inkubationstid",
    "inkubationstiderna": "inkubationstid",
    "inkubationstidernas": "inkubationstid",
    "inkubationstiders": "inkubationstid",
    "inkubationstids": "inkubationstid",
    "inkunabeln": "inkunabel",
    "inkunabelns": "inkunabel",
    "inkunabels": "inkunabel",
    "inkunabler": "inkunabel",
    "inkunablerna": "inkunabel",
    "inkunablernas": "inkunabel",
    "inkunablers": "inkunabel",
    "inkuraben": "inkurabel",
    "inkurabens": "inkurabel",
    "inkurabet": "inkurabel",
    "inkurabets": "inkurabel",
    "inkurabna": "inkurabel",
    "inkurabnas": "inkurabel",
    "inkurabne": "inkurabel",
    "inkurabnes": "inkurabel",
    "inkuranta": "inkurant",
    "inkurantare": "inkurant",
    "inkurantares": "inkurant",
    "inkurantas": "inkurant",
    "inkurantast": "inkurant",
    "inkurantaste": "inkurant",
    "inkurantastes": "inkurant",
    "inkurantasts": "inkurant",
    "inkurante": "inkurant",
    "inkurantes": "inkurant",
    "inkurants": "inkurant",
    "inkvarterad": "inkvartera",
    "inkvarterade": "inkvartera",
    "inkvarterades": "inkvartera",
    "inkvarterads": "inkvartera",
    "inkvarterande": "inkvartera",
    "inkvarteranden": "inkvarterande",
    "inkvarterandena": "inkvarterande",
    "inkvarterandenas": "inkvarterande",
    "inkvarterandens": "inkvarterande",
    "inkvarterandes": "inkvarterande",
    "inkvarterandet": "inkvarterande",
    "inkvarterandets": "inkvarterande",
    "inkvarterar": "inkvartera",
    "inkvarteras": "inkvartera",
    "inkvarterat": "inkvartera",
    "inkvarterats": "inkvartera",
    "inkvarterbara": "inkvarterbar",
    "inkvarterbarare": "inkvarterbar",
    "inkvarterbarares": "inkvarterbar",
    "inkvarterbaras": "inkvarterbar",
    "inkvarterbarast": "inkvarterbar",
    "inkvarterbaraste": "inkvarterbar",
    "inkvarterbarastes": "inkvarterbar",
    "inkvarterbarasts": "inkvarterbar",
    "inkvarterbare": "inkvarterbar",
    "inkvarterbares": "inkvarterbar",
    "inkvarterbarheten": "inkvarterbarhet",
    "inkvarterbarhetens": "inkvarterbarhet",
    "inkvarterbarhets": "inkvarterbarhet",
    "inkvarterbars": "inkvarterbar",
    "inkvarterbart": "inkvarterbar",
    "inkvarterbarts": "inkvarterbar",
    "inkvarteringar": "inkvartering",
    "inkvarteringarna": "inkvartering",
    "inkvarteringarnas": "inkvartering",
    "inkvarteringars": "inkvartering",
    "inkvarteringen": "inkvartering",
    "inkvarteringens": "inkvartering",
    "inkvarterings": "inkvartering",
    "inkvisitionen": "inkvisition",
    "inkvisitionens": "inkvisition",
    "inkvisitioner": "inkvisition",
    "inkvisitionerna": "inkvisition",
    "inkvisitionernas": "inkvisition",
    "inkvisitioners": "inkvisition",
    "inkvisitions": "inkvisition",
    "inkvisitorer": "inkvisitor",
    "inkvisitorerna": "inkvisitor",
    "inkvisitorernas": "inkvisitor",
    "inkvisitorers": "inkvisitor",
    "inkvisitoriska": "inkvisitorisk",
    "inkvisitoriskare": "inkvisitorisk",
    "inkvisitoriskares": "inkvisitorisk",
    "inkvisitoriskas": "inkvisitorisk",
    "inkvisitoriskast": "inkvisitorisk",
    "inkvisitoriskaste": "inkvisitorisk",
    "inkvisitoriskastes": "inkvisitorisk",
    "inkvisitoriskasts": "inkvisitorisk",
    "inkvisitoriske": "inkvisitorisk",
    "inkvisitoriskes": "inkvisitorisk",
    "inkvisitorisks": "inkvisitorisk",
    "inkvisitoriskt": "inkvisitorisk",
    "inkvisitoriskts": "inkvisitorisk",
    "inkvisitorn": "inkvisitor",
    "inkvisitorns": "inkvisitor",
    "inkvisitors": "inkvisitor",
    "inkännandes": "inkännande",
    "inkännandet": "inkännande",
    "inkännandets": "inkännande",
    "inköp": "inköpa",
    "inköpande": "inköpa",
    "inköpanden": "inköpande",
    "inköpandena": "inköpande",
    "inköpandenas": "inköpande",
    "inköpandens": "inköpande",
    "inköpandes": "inköpande",
    "inköpandet": "inköpande",
    "inköpandets": "inköpande",
    "inköpar": "inköpare",
    "inköparen": "inköpare",
    "inköparens": "inköpare",
    "inköpares": "inköpare",
    "inköparna": "inköpare",
    "inköparnas": "inköpare",
    "inköpas": "inköpa",
    "inköpen": "inköp",
    "inköpens": "inköp",
    "inköper": "inköpa",
    "inköpes": "inköpa",
    "inköpet": "inköp",
    "inköpets": "inköp",
    "inköps": "inköpa",
    "inköpsavdelningar": "inköpsavdelning",
    "inköpsavdelningarna": "inköpsavdelning",
    "inköpsavdelningarnas": "inköpsavdelning",
    "inköpsavdelningars": "inköpsavdelning",
    "inköpsavdelningen": "inköpsavdelning",
    "inköpsavdelningens": "inköpsavdelning",
    "inköpsavdelnings": "inköpsavdelning",
    "inköpslistan": "inköpslista",
    "inköpslistans": "inköpslista",
    "inköpslistas": "inköpslista",
    "inköpsliste": "inköpslista",
    "inköpslistor": "inköpslista",
    "inköpslistorna": "inköpslista",
    "inköpslistornas": "inköpslista",
    "inköpslistors": "inköpslista",
    "inköpsprisen": "inköpspris",
    "inköpsprisens": "inköpspris",
    "inköpspriser": "inköpspris",
    "inköpspriserna": "inköpspris",
    "inköpsprisernas": "inköpspris",
    "inköpsprisers": "inköpspris",
    "inköpspriset": "inköpspris",
    "inköpsprisets": "inköpspris",
    "inköpt": "inköpa",
    "inköpta": "inköpa",
    "inköptas": "inköpa",
    "inköpte": "inköpa",
    "inköptes": "inköpa",
    "inköpts": "inköpa",
    "inkörda": "inkörd",
    "inkördare": "inkörd",
    "inkördares": "inkörd",
    "inkördas": "inkörd",
    "inkördast": "inkörd",
    "inkördaste": "inkörd",
    "inkördastes": "inkörd",
    "inkördasts": "inkörd",
    "inkörde": "inkörd",
    "inkördes": "inkörd",
    "inkörds": "inkörd",
    "inkörningar": "inkörning",
    "inkörningarna": "inkörning",
    "inkörningarnas": "inkörning",
    "inkörningars": "inkörning",
    "inkörningen": "inkörning",
    "inkörningens": "inkörning",
    "inkörnings": "inkörning",
    "inkörningsperioden": "inkörningsperiod",
    "inkörningsperiodens": "inkörningsperiod",
    "inkörningsperioder": "inkörningsperiod",
    "inkörningsperioderna": "inkörningsperiod",
    "inkörningsperiodernas": "inkörningsperiod",
    "inkörningsperioders": "inkörningsperiod",
    "inkörningsperiods": "inkörningsperiod",
    "inkörsportar": "inkörsport",
    "inkörsportarna": "inkörsport",
    "inkörsportarnas": "inkörsport",
    "inkörsportars": "inkörsport",
    "inkörsporten": "inkörsport",
    "inkörsportens": "inkörsport",
    "inkörsports": "inkörsport",
    "inkört": "inkörd",
    "inkörts": "inkörd",
    "inla": "inlägga",
    "inlade": "inlägga",
    "inlades": "inlägga",
    "inlag": "inlaga",
    "inlagan": "inlaga",
    "inlagans": "inlaga",
    "inlagas": "inlaga",
    "inlagd": "inlägga",
    "inlagda": "inlägga",
    "inlagdare": "inlagd",
    "inlagdares": "inlagd",
    "inlagdas": "inlägga",
    "inlagdast": "inlagd",
    "inlagdaste": "inlagd",
    "inlagdastes": "inlagd",
    "inlagdasts": "inlagd",
    "inlagde": "inlägga",
    "inlagdes": "inlägga",
    "inlagds": "inlägga",
    "inlage": "inlaga",
    "inlagor": "inlaga",
    "inlagorna": "inlaga",
    "inlagornas": "inlaga",
    "inlagors": "inlaga",
    "inlags": "inlaga",
    "inlagt": "inlägga",
    "inlagts": "inlägga",
    "inlandet": "inland",
    "inlandets": "inland",
    "inlands": "inland",
    "inlandsbanan": "inlandsbana",
    "inlandsbanans": "inlandsbana",
    "inlandsbanas": "inlandsbana",
    "inlandsbane": "inlandsbana",
    "inlandsbanor": "inlandsbana",
    "inlandsbanorna": "inlandsbana",
    "inlandsbanornas": "inlandsbana",
    "inlandsbanors": "inlandsbana",
    "inlandsisar": "inlandsis",
    "inlandsisarna": "inlandsis",
    "inlandsisarnas": "inlandsis",
    "inlandsisars": "inlandsis",
    "inlandsisen": "inlandsis",
    "inlandsisens": "inlandsis",
    "inlandsklimatet": "inlandsklimat",
    "inlandsklimatets": "inlandsklimat",
    "inlandsklimats": "inlandsklimat",
    "inlas": "inlägga",
    "inled": "inleda",
    "inledande": "inleda",
    "inledanden": "inledande",
    "inledandena": "inledande",
    "inledandenas": "inledande",
    "inledandens": "inledande",
    "inledandes": "inledande",
    "inledandet": "inledande",
    "inledandets": "inledande",
    "inledar": "inledare",
    "inledaren": "inledare",
    "inledarens": "inledare",
    "inledares": "inledare",
    "inledarna": "inledare",
    "inledarnas": "inledare",
    "inledas": "inleda",
    "inledd": "inleda",
    "inledda": "inleda",
    "inleddas": "inleda",
    "inledde": "inleda",
    "inleddes": "inleda",
    "inledds": "inleda",
    "inleder": "inleda",
    "inledes": "inleda",
    "inledningar": "inledning",
    "inledningarna": "inledning",
    "inledningarnas": "inledning",
    "inledningars": "inledning",
    "inledningen": "inledning",
    "inledningens": "inledning",
    "inlednings": "inledning",
    "inledningsraden": "inledningsrad",
    "inledningsradens": "inledningsrad",
    "inledningsrader": "inledningsrad",
    "inledningsraderna": "inledningsrad",
    "inledningsradernas": "inledningsrad",
    "inledningsraders": "inledningsrad",
    "inledningsrads": "inledningsrad",
    "inleds": "inleda",
    "inlemmad": "inlemma",
    "inlemmade": "inlemma",
    "inlemmades": "inlemma",
    "inlemmads": "inlemma",
    "inlemmande": "inlemma",
    "inlemmanden": "inlemmande",
    "inlemmandena": "inlemmande",
    "inlemmandenas": "inlemmande",
    "inlemmandens": "inlemmande",
    "inlemmandes": "inlemmande",
    "inlemmandet": "inlemmande",
    "inlemmandets": "inlemmande",
    "inlemmar": "inlemma",
    "inlemmas": "inlemma",
    "inlemmat": "inlemma",
    "inlemmats": "inlemma",
    "inlett": "inleda",
    "inletts": "inleda",
    "inlevelsen": "inlevelse",
    "inlevelsens": "inlevelse",
    "inlevelses": "inlevelse",
    "inlind": "inlinda",
    "inlindad": "inlinda",
    "inlindade": "inlinda",
    "inlindades": "inlinda",
    "inlindads": "inlinda",
    "inlindande": "inlinda",
    "inlindanden": "inlindande",
    "inlindandena": "inlindande",
    "inlindandenas": "inlindande",
    "inlindandens": "inlindande",
    "inlindandes": "inlindande",
    "inlindandet": "inlindande",
    "inlindandets": "inlindande",
    "inlindar": "inlinda",
    "inlindas": "inlinda",
    "inlindat": "inlinda",
    "inlindats": "inlinda",
    "inljuden": "inljud",
    "inljudens": "inljud",
    "inljudet": "inljud",
    "inljudets": "inljud",
    "inljuds": "inljud",
    "inloggningar": "inloggning",
    "inloggningarna": "inloggning",
    "inloggningarnas": "inloggning",
    "inloggningars": "inloggning",
    "inloggningen": "inloggning",
    "inloggningens": "inloggning",
    "inloggnings": "inloggning",
    "inloppen": "inlopp",
    "inloppens": "inlopp",
    "inloppet": "inlopp",
    "inloppets": "inlopp",
    "inlopps": "inlopp",
    "inlägg": "inlägga",
    "inläggande": "inlägga",
    "inlägganden": "inläggande",
    "inläggandena": "inläggande",
    "inläggandenas": "inläggande",
    "inläggandens": "inläggande",
    "inläggandes": "inläggande",
    "inläggandet": "inläggande",
    "inläggandets": "inläggande",
    "inläggas": "inlägga",
    "inläggen": "inlägg",
    "inläggens": "inlägg",
    "inlägger": "inlägga",
    "inlägges": "inlägga",
    "inlägget": "inlägg",
    "inläggets": "inlägg",
    "inläggningar": "inläggning",
    "inläggningarna": "inläggning",
    "inläggningarnas": "inläggning",
    "inläggningars": "inläggning",
    "inläggningen": "inläggning",
    "inläggningens": "inläggning",
    "inläggnings": "inläggning",
    "inläggningsgurk": "inläggningsgurka",
    "inläggningsgurkan": "inläggningsgurka",
    "inläggningsgurkans": "inläggningsgurka",
    "inläggningsgurkas": "inläggningsgurka",
    "inläggningsgurke": "inläggningsgurka",
    "inläggningsgurkor": "inläggningsgurka",
    "inläggningsgurkorna": "inläggningsgurka",
    "inläggningsgurkornas": "inläggningsgurka",
    "inläggningsgurkors": "inläggningsgurka",
    "inläggningsgurks": "inläggningsgurka",
    "inläggs": "inlägga",
    "inlämnad": "inlämna",
    "inlämnade": "inlämna",
    "inlämnades": "inlämna",
    "inlämnads": "inlämna",
    "inlämnande": "inlämna",
    "inlämnanden": "inlämnande",
    "inlämnandena": "inlämnande",
    "inlämnandenas": "inlämnande",
    "inlämnandens": "inlämnande",
    "inlämnandes": "inlämnande",
    "inlämnandet": "inlämnande",
    "inlämnandets": "inlämnande",
    "inlämnar": "inlämna",
    "inlämnas": "inlämna",
    "inlämnat": "inlämna",
    "inlämnats": "inlämna",
    "inlämningar": "inlämning",
    "inlämningarna": "inlämning",
    "inlämningarnas": "inlämning",
    "inlämningars": "inlämning",
    "inlämningen": "inlämning",
    "inlämningens": "inlämning",
    "inlämnings": "inlämning",
    "inlämningsdagar": "inlämningsdag",
    "inlämningsdagarna": "inlämningsdag",
    "inlämningsdagarnas": "inlämningsdag",
    "inlämningsdagars": "inlämningsdag",
    "inlämningsdagen": "inlämningsdag",
    "inlämningsdagens": "inlämningsdag",
    "inlämningsdags": "inlämningsdag",
    "inlämningsdan": "inlämningsdag",
    "inlämningsdans": "inlämningsdag",
    "inlämningsdar": "inlämningsdag",
    "inlämningsdarna": "inlämningsdag",
    "inlämningsdarnas": "inlämningsdag",
    "inlämningsdars": "inlämningsdag",
    "inländska": "inländsk",
    "inländskare": "inländsk",
    "inländskares": "inländsk",
    "inländskas": "inländsk",
    "inländskast": "inländsk",
    "inländskaste": "inländsk",
    "inländskastes": "inländsk",
    "inländskasts": "inländsk",
    "inländske": "inländsk",
    "inländskes": "inländsk",
    "inländsks": "inländsk",
    "inländskt": "inländsk",
    "inländskts": "inländsk",
    "inlär": "inlära",
    "inlärande": "inlära",
    "inläranden": "inlärande",
    "inlärandena": "inlärande",
    "inlärandenas": "inlärande",
    "inlärandens": "inlärande",
    "inlärandes": "inlärande",
    "inlärandet": "inlärande",
    "inlärandets": "inlärande",
    "inläras": "inlära",
    "inlärd": "inlära",
    "inlärda": "inlära",
    "inlärdas": "inlära",
    "inlärde": "inlärd",
    "inlärdes": "inlärd",
    "inlärds": "inlärd",
    "inläres": "inlära",
    "inlärningar": "inlärning",
    "inlärningarna": "inlärning",
    "inlärningarnas": "inlärning",
    "inlärningars": "inlärning",
    "inlärningen": "inlärning",
    "inlärningens": "inlärning",
    "inlärnings": "inlärning",
    "inlärningsmässiga": "inlärningsmässig",
    "inlärningsmässigare": "inlärningsmässig",
    "inlärningsmässigares": "inlärningsmässig",
    "inlärningsmässigas": "inlärningsmässig",
    "inlärningsmässigast": "inlärningsmässig",
    "inlärningsmässigaste": "inlärningsmässig",
    "inlärningsmässigastes": "inlärningsmässig",
    "inlärningsmässigasts": "inlärningsmässig",
    "inlärningsmässige": "inlärningsmässig",
    "inlärningsmässiges": "inlärningsmässig",
    "inlärningsmässigs": "inlärningsmässig",
    "inlärningsmässigt": "inlärningsmässig",
    "inlärningsmässigts": "inlärningsmässig",
    "inlärningsplatåer": "inlärningsplatå",
    "inlärningsplatåerna": "inlärningsplatå",
    "inlärningsplatåernas": "inlärningsplatå",
    "inlärningsplatåers": "inlärningsplatå",
    "inlärningsplatån": "inlärningsplatå",
    "inlärningsplatåns": "inlärningsplatå",
    "inlärningsplatås": "inlärningsplatå",
    "inlärningsresultaten": "inlärningsresultat",
    "inlärningsresultatens": "inlärningsresultat",
    "inlärningsresultatet": "inlärningsresultat",
    "inlärningsresultatets": "inlärningsresultat",
    "inlärningsresultats": "inlärningsresultat",
    "inlärningsstudion": "inlärningsstudio",
    "inlärningsstudions": "inlärningsstudio",
    "inlärningsstudior": "inlärningsstudio",
    "inlärningsstudiorna": "inlärningsstudio",
    "inlärningsstudiornas": "inlärningsstudio",
    "inlärningsstudiors": "inlärningsstudio",
    "inlärningsstudios": "inlärningsstudio",
    "inlärningssvårigheten": "inlärningssvårighet",
    "inlärningssvårighetens": "inlärningssvårighet",
    "inlärningssvårighets": "inlärningssvårighet",
    "inlärs": "inlära",
    "inlärt": "inlärd",
    "inlärts": "inlärd",
    "inläsningar": "inläsning",
    "inläsningarna": "inläsning",
    "inläsningarnas": "inläsning",
    "inläsningars": "inläsning",
    "inläsningen": "inläsning",
    "inläsningens": "inläsning",
    "inläsnings": "inläsning",
    "inlästa": "inläst",
    "inlästare": "inläst",
    "inlästares": "inläst",
    "inlästas": "inläst",
    "inlästast": "inläst",
    "inlästaste": "inläst",
    "inlästastes": "inläst",
    "inlästasts": "inläst",
    "inläste": "inläst",
    "inlästes": "inläst",
    "inlästs": "inläst",
    "inlån": "inlåna",
    "inlånad": "inlåna",
    "inlånade": "inlåna",
    "inlånades": "inlåna",
    "inlånads": "inlåna",
    "inlånande": "inlåna",
    "inlånanden": "inlånande",
    "inlånandena": "inlånande",
    "inlånandenas": "inlånande",
    "inlånandens": "inlånande",
    "inlånandes": "inlånande",
    "inlånandet": "inlånande",
    "inlånandets": "inlånande",
    "inlånar": "inlåna",
    "inlånas": "inlåna",
    "inlånat": "inlåna",
    "inlånats": "inlåna",
    "inlåningar": "inlåning",
    "inlåningarna": "inlåning",
    "inlåningarnas": "inlåning",
    "inlåningars": "inlåning",
    "inlåningen": "inlåning",
    "inlåningens": "inlåning",
    "inlånings": "inlåning",
    "inlåningsräntan": "inlåningsränta",
    "inlåningsräntans": "inlåningsränta",
    "inlåningsräntas": "inlåningsränta",
    "inlåningsränte": "inlåningsränta",
    "inlåningsräntor": "inlåningsränta",
    "inlåningsräntorna": "inlåningsränta",
    "inlåningsräntornas": "inlåningsränta",
    "inlåningsräntors": "inlåningsränta",
    "inlöp": "inlöpa",
    "inlöpande": "inlöpa",
    "inlöpanden": "inlöpande",
    "inlöpandena": "inlöpande",
    "inlöpandenas": "inlöpande",
    "inlöpandens": "inlöpande",
    "inlöpandes": "inlöpande",
    "inlöpandet": "inlöpande",
    "inlöpandets": "inlöpande",
    "inlöpas": "inlöpa",
    "inlöper": "inlöpa",
    "inlöpes": "inlöpa",
    "inlöps": "inlöpa",
    "inlöpt": "inlöpa",
    "inlöpta": "inlöpa",
    "inlöptas": "inlöpa",
    "inlöpte": "inlöpa",
    "inlöptes": "inlöpa",
    "inlöpts": "inlöpa",
    "inlös": "inlösa",
    "inlösande": "inlösa",
    "inlösanden": "inlösande",
    "inlösandena": "inlösande",
    "inlösandenas": "inlösande",
    "inlösandens": "inlösande",
    "inlösandes": "inlösande",
    "inlösandet": "inlösande",
    "inlösandets": "inlösande",
    "inlösas": "inlösa",
    "inlösens": "inlösen",
    "inlöser": "inlösa",
    "inlöses": "inlösa",
    "inlöst": "inlösa",
    "inlösta": "inlösa",
    "inlöstas": "inlösa",
    "inlöste": "inlösa",
    "inlöstes": "inlösa",
    "inlösts": "inlösa",
    "inmarschen": "inmarsch",
    "inmarschens": "inmarsch",
    "inmarscher": "inmarsch",
    "inmarscherna": "inmarsch",
    "inmarschernas": "inmarsch",
    "inmarschers": "inmarsch",
    "inmarschs": "inmarsch",
    "inmat": "inmata",
    "inmatad": "inmata",
    "inmatade": "inmata",
    "inmatades": "inmata",
    "inmatads": "inmata",
    "inmatande": "inmata",
    "inmatanden": "inmatande",
    "inmatandena": "inmatande",
    "inmatandenas": "inmatande",
    "inmatandens": "inmatande",
    "inmatandes": "inmatande",
    "inmatandet": "inmatande",
    "inmatandets": "inmatande",
    "inmatar": "inmata",
    "inmatas": "inmata",
    "inmatat": "inmata",
    "inmatats": "inmata",
    "inmatningar": "inmatning",
    "inmatningarna": "inmatning",
    "inmatningarnas": "inmatning",
    "inmatningars": "inmatning",
    "inmatningen": "inmatning",
    "inmatningens": "inmatning",
    "inmatnings": "inmatning",
    "inmatningsbredden": "inmatningsbredd",
    "inmatningsbreddens": "inmatningsbredd",
    "inmatningsbredder": "inmatningsbredd",
    "inmatningsbredderna": "inmatningsbredd",
    "inmatningsbreddernas": "inmatningsbredd",
    "inmatningsbredders": "inmatningsbredd",
    "inmatningsbredds": "inmatningsbredd",
    "inmundig": "inmundiga",
    "inmundigad": "inmundiga",
    "inmundigade": "inmundiga",
    "inmundigades": "inmundiga",
    "inmundigads": "inmundiga",
    "inmundigande": "inmundiga",
    "inmundiganden": "inmundigande",
    "inmundigandena": "inmundigande",
    "inmundigandenas": "inmundigande",
    "inmundigandens": "inmundigande",
    "inmundigandes": "inmundigande",
    "inmundigandet": "inmundigande",
    "inmundigandets": "inmundigande",
    "inmundigar": "inmundiga",
    "inmundigas": "inmundiga",
    "inmundigat": "inmundiga",
    "inmundigats": "inmundiga",
    "inmut": "inmuta",
    "inmutad": "inmuta",
    "inmutade": "inmuta",
    "inmutades": "inmuta",
    "inmutads": "inmuta",
    "inmutande": "inmuta",
    "inmutanden": "inmutande",
    "inmutandena": "inmutande",
    "inmutandenas": "inmutande",
    "inmutandens": "inmutande",
    "inmutandes": "inmutande",
    "inmutandet": "inmutande",
    "inmutandets": "inmutande",
    "inmutar": "inmuta",
    "inmutas": "inmuta",
    "inmutat": "inmuta",
    "inmutats": "inmuta",
    "inmutningar": "inmutning",
    "inmutningarna": "inmutning",
    "inmutningarnas": "inmutning",
    "inmutningars": "inmutning",
    "inmutningen": "inmutning",
    "inmutningens": "inmutning",
    "inmutnings": "inmutning",
    "inmäng": "inmänga",
    "inmängande": "inmänga",
    "inmänganden": "inmängande",
    "inmängandena": "inmängande",
    "inmängandenas": "inmängande",
    "inmängandens": "inmängande",
    "inmängandes": "inmängande",
    "inmängandet": "inmängande",
    "inmängandets": "inmängande",
    "inmängas": "inmänga",
    "inmängd": "inmänga",
    "inmängda": "inmänga",
    "inmängdas": "inmänga",
    "inmängde": "inmänga",
    "inmängdes": "inmänga",
    "inmängds": "inmänga",
    "inmänger": "inmänga",
    "inmänges": "inmänga",
    "inmängs": "inmänga",
    "inmängt": "inmänga",
    "inmängts": "inmänga",
    "inmätningar": "inmätning",
    "inmätningarna": "inmätning",
    "inmätningarnas": "inmätning",
    "inmätningars": "inmätning",
    "inmätningen": "inmätning",
    "inmätningens": "inmätning",
    "inmätnings": "inmätning",
    "inmålade": "inmålad",
    "inmålades": "inmålad",
    "inmålads": "inmålad",
    "inmålat": "inmålad",
    "inmålats": "inmålad",
    "inmönstrad": "inmönstra",
    "inmönstrade": "inmönstra",
    "inmönstrades": "inmönstra",
    "inmönstrads": "inmönstra",
    "inmönstrande": "inmönstra",
    "inmönstranden": "inmönstrande",
    "inmönstrandena": "inmönstrande",
    "inmönstrandenas": "inmönstrande",
    "inmönstrandens": "inmönstrande",
    "inmönstrandes": "inmönstrande",
    "inmönstrandet": "inmönstrande",
    "inmönstrandets": "inmönstrande",
    "inmönstrar": "inmönstra",
    "inmönstras": "inmönstra",
    "inmönstrat": "inmönstra",
    "inmönstrats": "inmönstra",
    "inmönstringar": "inmönstring",
    "inmönstringarna": "inmönstring",
    "inmönstringarnas": "inmönstring",
    "inmönstringars": "inmönstring",
    "inmönstringen": "inmönstring",
    "inmönstringens": "inmönstring",
    "inmönstrings": "inmönstring",
    "innandömen": "innandöme",
    "innandömena": "innandöme",
    "innandömenas": "innandöme",
    "innandömens": "innandöme",
    "innandömes": "innandöme",
    "innandömet": "innandöme",
    "innandömets": "innandöme",
    "innanhaven": "innanhav",
    "innanhavens": "innanhav",
    "innanhavet": "innanhav",
    "innanhavets": "innanhav",
    "innanhavs": "innanhav",
    "innanläsningar": "innanläsning",
    "innanläsningarna": "innanläsning",
    "innanläsningarnas": "innanläsning",
    "innanläsningars": "innanläsning",
    "innanläsningen": "innanläsning",
    "innanläsningens": "innanläsning",
    "innanläsnings": "innanläsning",
    "innanlåren": "innanlår",
    "innanlårens": "innanlår",
    "innanlåret": "innanlår",
    "innanlårets": "innanlår",
    "innanlårs": "innanlår",
    "innanmäten": "innanmäte",
    "innanmätena": "innanmäte",
    "innanmätenas": "innanmäte",
    "innanmätens": "innanmäte",
    "innanmätes": "innanmäte",
    "innanmätet": "innanmäte",
    "innanmätets": "innanmäte",
    "innebar": "innebära",
    "innebars": "innebära",
    "innebruket": "innebruk",
    "innebrukets": "innebruk",
    "innebruks": "innebruk",
    "innebränndes": "innebrännas",
    "innebrännes": "innebrännas",
    "innebränns": "innebrännas",
    "innebrännts": "innebrännas",
    "innebure": "innebära",
    "innebures": "innebära",
    "inneburit": "innebära",
    "inneburits": "innebära",
    "innebyggar": "innebyggare",
    "innebyggaren": "innebyggare",
    "innebyggarens": "innebyggare",
    "innebyggares": "innebyggare",
    "innebyggarna": "innebyggare",
    "innebyggarnas": "innebyggare",
    "innebär": "innebära",
    "innebärande": "innebära",
    "innebäranden": "innebärande",
    "innebärandena": "innebärande",
    "innebärandenas": "innebärande",
    "innebärandens": "innebärande",
    "innebärandes": "innebärande",
    "innebärandet": "innebärande",
    "innebärandets": "innebärande",
    "innebäras": "innebära",
    "innebäre": "innebära",
    "innebäres": "innebära",
    "innebärs": "innebära",
    "innebörden": "innebörd",
    "innebördens": "innebörd",
    "innebörder": "innebörd",
    "innebörderna": "innebörd",
    "innebördernas": "innebörd",
    "innebörders": "innebörd",
    "innebörds": "innebörd",
    "innefatt": "innefatta",
    "innefattad": "innefatta",
    "innefattade": "innefatta",
    "innefattades": "innefatta",
    "innefattads": "innefatta",
    "innefattande": "innefatta",
    "innefattanden": "innefattande",
    "innefattandena": "innefattande",
    "innefattandenas": "innefattande",
    "innefattandens": "innefattande",
    "innefattandes": "innefattande",
    "innefattandet": "innefattande",
    "innefattandets": "innefattande",
    "innefattar": "innefatta",
    "innefattas": "innefatta",
    "innefattat": "innefatta",
    "innefattats": "innefatta",
    "innegrejen": "innegrej",
    "innegrejens": "innegrej",
    "innegrejer": "innegrej",
    "innegrejerna": "innegrej",
    "innegrejernas": "innegrej",
    "innegrejers": "innegrej",
    "innegrejs": "innegrej",
    "innehade": "inneha",
    "innehades": "inneha",
    "innehaft": "inneha",
    "innehafts": "inneha",
    "innehande": "inneha",
    "innehandes": "inneha",
    "innehar": "inneha",
    "innehas": "inneha",
    "innehava": "inneha",
    "innehavande": "inneha",
    "innehavanden": "innehavande",
    "innehavandena": "innehavande",
    "innehavandenas": "innehavande",
    "innehavandens": "innehavande",
    "innehavandes": "innehavande",
    "innehavandet": "innehavande",
    "innehavandets": "innehavande",
    "innehavar": "innehavare",
    "innehavaren": "innehavare",
    "innehavarens": "innehavare",
    "innehavares": "innehavare",
    "innehavarna": "innehavare",
    "innehavarnas": "innehavare",
    "innehavarpapperen": "innehavarpapper",
    "innehavarpapperens": "innehavarpapper",
    "innehavarpapperet": "innehavarpapper",
    "innehavarpapperets": "innehavarpapper",
    "innehavarpapperna": "innehavarpapper",
    "innehavarpappernas": "innehavarpapper",
    "innehavarpappers": "innehavarpapper",
    "innehavarpappren": "innehavarpapper",
    "innehavarpapprens": "innehavarpapper",
    "innehavarpappret": "innehavarpapper",
    "innehavarpapprets": "innehavarpapper",
    "innehavas": "inneha",
    "innehaven": "innehav",
    "innehavens": "innehav",
    "innehaver": "inneha",
    "innehavet": "innehav",
    "innehavets": "innehav",
    "innehavs": "innehav",
    "innehåll": "innehålla",
    "innehållande": "innehålla",
    "innehållanden": "innehållande",
    "innehållandena": "innehållande",
    "innehållandenas": "innehållande",
    "innehållandens": "innehållande",
    "innehållandes": "innehållande",
    "innehållandet": "innehållande",
    "innehållandets": "innehållande",
    "innehållas": "innehålla",
    "innehålle": "innehålla",
    "innehållen": "innehålla",
    "innehållens": "innehålla",
    "innehåller": "innehålla",
    "innehålles": "innehålla",
    "innehållet": "innehålla",
    "innehållets": "innehålla",
    "innehållit": "innehålla",
    "innehållits": "innehålla",
    "innehållna": "innehålla",
    "innehållnas": "innehålla",
    "innehållne": "innehålla",
    "innehållnes": "innehålla",
    "innehålls": "innehålla",
    "innehållsanalysen": "innehållsanalys",
    "innehållsanalysens": "innehållsanalys",
    "innehållsanalyser": "innehållsanalys",
    "innehållsanalyserna": "innehållsanalys",
    "innehållsanalysernas": "innehållsanalys",
    "innehållsanalysers": "innehållsanalys",
    "innehållsdeklarationen": "innehållsdeklaration",
    "innehållsdeklarationens": "innehållsdeklaration",
    "innehållsdeklarationer": "innehållsdeklaration",
    "innehållsdeklarationerna": "innehållsdeklaration",
    "innehållsdeklarationernas": "innehållsdeklaration",
    "innehållsdeklarationers": "innehållsdeklaration",
    "innehållsdeklarations": "innehållsdeklaration",
    "innehållsförteckningar": "innehållsförteckning",
    "innehållsförteckningarna": "innehållsförteckning",
    "innehållsförteckningarnas": "innehållsförteckning",
    "innehållsförteckningars": "innehållsförteckning",
    "innehållsförteckningen": "innehållsförteckning",
    "innehållsförteckningens": "innehållsförteckning",
    "innehållsförtecknings": "innehållsförteckning",
    "innehållsliga": "innehållslig",
    "innehållsligare": "innehållslig",
    "innehållsligares": "innehållslig",
    "innehållsligas": "innehållslig",
    "innehållsligast": "innehållslig",
    "innehållsligaste": "innehållslig",
    "innehållsligastes": "innehållslig",
    "innehållsligasts": "innehållslig",
    "innehållslige": "innehållslig",
    "innehållsliges": "innehållslig",
    "innehållsligheten": "innehållslighet",
    "innehållslighetens": "innehållslighet",
    "innehållslighets": "innehållslighet",
    "innehållsligs": "innehållslig",
    "innehållsligt": "innehållslig",
    "innehållsligts": "innehållslig",
    "innehållslösa": "innehållslös",
    "innehållslösare": "innehållslös",
    "innehållslösares": "innehållslös",
    "innehållslösas": "innehållslös",
    "innehållslösast": "innehållslös",
    "innehållslösaste": "innehållslös",
    "innehållslösastes": "innehållslös",
    "innehållslösasts": "innehållslös",
    "innehållslöse": "innehållslös",
    "innehållslöses": "innehållslös",
    "innehållslösheten": "innehållslöshet",
    "innehållslöshetens": "innehållslöshet",
    "innehållslöshets": "innehållslöshet",
    "innehållslöst": "innehållslös",
    "innehållslösts": "innehållslös",
    "innehållsmässiga": "innehållsmässig",
    "innehållsmässigare": "innehållsmässig",
    "innehållsmässigares": "innehållsmässig",
    "innehållsmässigas": "innehållsmässig",
    "innehållsmässigast": "innehållsmässig",
    "innehållsmässigaste": "innehållsmässig",
    "innehållsmässigastes": "innehållsmässig",
    "innehållsmässigasts": "innehållsmässig",
    "innehållsmässige": "innehållsmässig",
    "innehållsmässiges": "innehållsmässig",
    "innehållsmässigheten": "innehållsmässighet",
    "innehållsmässighetens": "innehållsmässighet",
    "innehållsmässighets": "innehållsmässighet",
    "innehållsmässigs": "innehållsmässig",
    "innehållsmässigt": "innehållsmässig",
    "innehållsmässigts": "innehållsmässig",
    "innehållsobjekten": "innehållsobjekt",
    "innehållsobjektens": "innehållsobjekt",
    "innehållsobjektet": "innehållsobjekt",
    "innehållsobjektets": "innehållsobjekt",
    "innehållsobjekts": "innehållsobjekt",
    "innehållsorden": "innehållsord",
    "innehållsordens": "innehållsord",
    "innehållsordet": "innehållsord",
    "innehållsordets": "innehållsord",
    "innehållsords": "innehållsord",
    "innehållsrelaterade": "innehållsrelaterad",
    "innehållsrelaterades": "innehållsrelaterad",
    "innehållsrelaterads": "innehållsrelaterad",
    "innehållsrelaterat": "innehållsrelaterad",
    "innehållsrelaterats": "innehållsrelaterad",
    "innehållsrika": "innehållsrik",
    "innehållsrikare": "innehållsrik",
    "innehållsrikares": "innehållsrik",
    "innehållsrikas": "innehållsrik",
    "innehållsrikast": "innehållsrik",
    "innehållsrikaste": "innehållsrik",
    "innehållsrikastes": "innehållsrik",
    "innehållsrikasts": "innehållsrik",
    "innehållsrike": "innehållsrik",
    "innehållsrikes": "innehållsrik",
    "innehållsrikheten": "innehållsrikhet",
    "innehållsrikhetens": "innehållsrikhet",
    "innehållsrikhets": "innehållsrikhet",
    "innehållsriks": "innehållsrik",
    "innehållsrikt": "innehållsrik",
    "innehållsrikts": "innehållsrik",
    "innehållstomheten": "innehållstomhet",
    "innehållstomhetens": "innehållstomhet",
    "innehållstomhets": "innehållstomhet",
    "innehållstomma": "innehållstom",
    "innehållstommare": "innehållstom",
    "innehållstommares": "innehållstom",
    "innehållstommas": "innehållstom",
    "innehållstommast": "innehållstom",
    "innehållstommaste": "innehållstom",
    "innehållstommastes": "innehållstom",
    "innehållstommasts": "innehållstom",
    "innehållstomme": "innehållstom",
    "innehållstommes": "innehållstom",
    "innehållstoms": "innehållstom",
    "innehållstomt": "innehållstom",
    "innehållstomts": "innehållstom",
    "innehållsöversikten": "innehållsöversikt",
    "innehållsöversiktens": "innehållsöversikt",
    "innehållsöversikter": "innehållsöversikt",
    "innehållsöversikterna": "innehållsöversikt",
    "innehållsöversikternas": "innehållsöversikt",
    "innehållsöversikters": "innehållsöversikt",
    "innehållsöversikts": "innehållsöversikt",
    "innehöll": "innehålla",
    "innehölle": "innehålla",
    "innehölles": "innehålla",
    "innehölls": "innehålla",
    "innerbanan": "innerbana",
    "innerbanans": "innerbana",
    "innerbanas": "innerbana",
    "innerbane": "innerbana",
    "innerbanor": "innerbana",
    "innerbanorna": "innerbana",
    "innerbanornas": "innerbana",
    "innerbanors": "innerbana",
    "innerdörrar": "innerdörr",
    "innerdörrarna": "innerdörr",
    "innerdörrarnas": "innerdörr",
    "innerdörrars": "innerdörr",
    "innerdörren": "innerdörr",
    "innerdörrens": "innerdörr",
    "innerdörrhandtagen": "innerdörrhandtag",
    "innerdörrhandtagens": "innerdörrhandtag",
    "innerdörrhandtaget": "innerdörrhandtag",
    "innerdörrhandtagets": "innerdörrhandtag",
    "innerdörrhandtags": "innerdörrhandtag",
    "innerdörrs": "innerdörr",
    "innerfick": "innerficka",
    "innerfickan": "innerficka",
    "innerfickans": "innerficka",
    "innerfickas": "innerficka",
    "innerficke": "innerficka",
    "innerfickor": "innerficka",
    "innerfickorna": "innerficka",
    "innerfickornas": "innerficka",
    "innerfickors": "innerficka",
    "innerficks": "innerficka",
    "innerhanden": "innerhand",
    "innerhandens": "innerhand",
    "innerhands": "innerhand",
    "innerkurv": "innerkurva",
    "innerkurvan": "innerkurva",
    "innerkurvans": "innerkurva",
    "innerkurvas": "innerkurva",
    "innerkurve": "innerkurva",
    "innerkurvor": "innerkurva",
    "innerkurvorna": "innerkurva",
    "innerkurvornas": "innerkurva",
    "innerkurvors": "innerkurva",
    "innerkurvs": "innerkurva",
    "innerliga": "innerlig",
    "innerligare": "innerlig",
    "innerligares": "innerlig",
    "innerligas": "innerlig",
    "innerligast": "innerlig",
    "innerligaste": "innerlig",
    "innerligastes": "innerlig",
    "innerligasts": "innerlig",
    "innerlige": "innerlig",
    "innerliges": "innerlig",
    "innerligheten": "innerlighet",
    "innerlighetens": "innerlighet",
    "innerlighets": "innerlighet",
    "innerligs": "innerlig",
    "innerligt": "innerlig",
    "innerligts": "innerlig",
    "innern": "inner",
    "innerns": "inner",
    "inners": "inner",
    "innersidan": "innersida",
    "innersidans": "innersida",
    "innersidas": "innersida",
    "innerside": "innersida",
    "innersides": "innersida",
    "innersidor": "innersida",
    "innersidorna": "innersida",
    "innersidornas": "innersida",
    "innersidors": "innersida",
    "innerskären": "innerskär",
    "innerskärens": "innerskär",
    "innerskäret": "innerskär",
    "innerskärets": "innerskär",
    "innerskärs": "innerskär",
    "innerslangar": "innerslang",
    "innerslangarna": "innerslang",
    "innerslangarnas": "innerslang",
    "innerslangars": "innerslang",
    "innerslangen": "innerslang",
    "innerslangens": "innerslang",
    "innerslangs": "innerslang",
    "innerstaden": "innerstad",
    "innerstadens": "innerstad",
    "innerstads": "innerstad",
    "innerstadsmässiga": "innerstadsmässig",
    "innerstadsmässigare": "innerstadsmässig",
    "innerstadsmässigares": "innerstadsmässig",
    "innerstadsmässigas": "innerstadsmässig",
    "innerstadsmässigast": "innerstadsmässig",
    "innerstadsmässigaste": "innerstadsmässig",
    "innerstadsmässigastes": "innerstadsmässig",
    "innerstadsmässigasts": "innerstadsmässig",
    "innerstadsmässige": "innerstadsmässig",
    "innerstadsmässiges": "innerstadsmässig",
    "innerstadsmässigs": "innerstadsmässig",
    "innerstadsmässigt": "innerstadsmässig",
    "innerstadsmässigts": "innerstadsmässig",
    "innerstan": "innerstad",
    "innerstans": "innerstad",
    "innerstas": "innersta",
    "innerstäder": "innerstad",
    "innerstäderna": "innerstad",
    "innerstädernas": "innerstad",
    "innerstäders": "innerstad",
    "innertaken": "innertak",
    "innertakens": "innertak",
    "innertaket": "innertak",
    "innertakets": "innertak",
    "innertaks": "innertak",
    "innervationen": "innervation",
    "innervationens": "innervation",
    "innervationer": "innervation",
    "innervationerna": "innervation",
    "innervationernas": "innervation",
    "innervationers": "innervation",
    "innervations": "innervation",
    "innerverad": "innervera",
    "innerverade": "innervera",
    "innerverades": "innervera",
    "innerverads": "innervera",
    "innerverande": "innervera",
    "innerveranden": "innerverande",
    "innerverandena": "innerverande",
    "innerverandenas": "innerverande",
    "innerverandens": "innerverande",
    "innerverandes": "innerverande",
    "innerverandet": "innerverande",
    "innerverandets": "innerverande",
    "innerverar": "innervera",
    "innerveras": "innervera",
    "innerverat": "innervera",
    "innerverats": "innervera",
    "innerverbara": "innerverbar",
    "innerverbarare": "innerverbar",
    "innerverbarares": "innerverbar",
    "innerverbaras": "innerverbar",
    "innerverbarast": "innerverbar",
    "innerverbaraste": "innerverbar",
    "innerverbarastes": "innerverbar",
    "innerverbarasts": "innerverbar",
    "innerverbare": "innerverbar",
    "innerverbares": "innerverbar",
    "innerverbarheten": "innerverbarhet",
    "innerverbarhetens": "innerverbarhet",
    "innerverbarhets": "innerverbarhet",
    "innerverbars": "innerverbar",
    "innerverbart": "innerverbar",
    "innerverbarts": "innerverbar",
    "innerveringar": "innervering",
    "innerveringarna": "innervering",
    "innerveringarnas": "innervering",
    "innerveringars": "innervering",
    "innerveringen": "innervering",
    "innerveringens": "innervering",
    "innerverings": "innervering",
    "innerväggar": "innervägg",
    "innerväggarna": "innervägg",
    "innerväggarnas": "innervägg",
    "innerväggars": "innervägg",
    "innerväggen": "innervägg",
    "innerväggens": "innervägg",
    "innerväggs": "innervägg",
    "inneröras": "inneröra",
    "innerörat": "inneröra",
    "innerörats": "inneröra",
    "inneröron": "inneröra",
    "inneröronen": "inneröra",
    "inneröronens": "inneröra",
    "innerörons": "inneröra",
    "innesittar": "innesittare",
    "innesittaren": "innesittare",
    "innesittarens": "innesittare",
    "innesittares": "innesittare",
    "innesittarna": "innesittare",
    "innesittarnas": "innesittare",
    "inneskon": "innesko",
    "inneskons": "innesko",
    "inneskor": "innesko",
    "inneskorna": "innesko",
    "inneskornas": "innesko",
    "inneskors": "innesko",
    "inneskos": "innesko",
    "inneslut": "innesluta",
    "inneslutande": "innesluta",
    "inneslutanden": "inneslutande",
    "inneslutandena": "inneslutande",
    "inneslutandenas": "inneslutande",
    "inneslutandens": "inneslutande",
    "inneslutandes": "inneslutande",
    "inneslutandet": "inneslutande",
    "inneslutandets": "inneslutande",
    "inneslutas": "innesluta",
    "inneslute": "innesluta",
    "innesluten": "innesluta",
    "inneslutens": "innesluta",
    "innesluter": "innesluta",
    "inneslutes": "innesluta",
    "inneslutet": "innesluta",
    "inneslutets": "innesluta",
    "inneslutit": "innesluta",
    "inneslutits": "innesluta",
    "inneslutna": "innesluta",
    "inneslutnas": "innesluta",
    "inneslutne": "innesluta",
    "inneslutnes": "innesluta",
    "inneslutningar": "inneslutning",
    "inneslutningarna": "inneslutning",
    "inneslutningarnas": "inneslutning",
    "inneslutningars": "inneslutning",
    "inneslutningen": "inneslutning",
    "inneslutningens": "inneslutning",
    "inneslutnings": "inneslutning",
    "innesluts": "innesluta",
    "inneslöt": "innesluta",
    "inneslöte": "innesluta",
    "inneslötes": "innesluta",
    "inneslöts": "innesluta",
    "innestäng": "innestänga",
    "innestängande": "innestänga",
    "innestänganden": "innestängande",
    "innestängandena": "innestängande",
    "innestängandenas": "innestängande",
    "innestängandens": "innestängande",
    "innestängandes": "innestängande",
    "innestängandet": "innestängande",
    "innestängandets": "innestängande",
    "innestängas": "innestänga",
    "innestängd": "innestänga",
    "innestängda": "innestänga",
    "innestängdas": "innestänga",
    "innestängde": "innestänga",
    "innestängdes": "innestänga",
    "innestängds": "innestänga",
    "innestänger": "innestänga",
    "innestänges": "innestänga",
    "innestängs": "innestänga",
    "innestängt": "innestänga",
    "innestängts": "innestänga",
    "innevånar": "innevånare",
    "innevånaren": "innevånare",
    "innevånarens": "innevånare",
    "innevånares": "innevånare",
    "innevånarna": "innevånare",
    "innevånarnas": "innevånare",
    "innovationen": "innovation",
    "innovationens": "innovation",
    "innovationer": "innovation",
    "innovationerna": "innovation",
    "innovationernas": "innovation",
    "innovationers": "innovation",
    "innovations": "innovation",
    "innovativa": "innovativ",
    "innovativare": "innovativ",
    "innovativares": "innovativ",
    "innovativas": "innovativ",
    "innovativast": "innovativ",
    "innovativaste": "innovativ",
    "innovativastes": "innovativ",
    "innovativasts": "innovativ",
    "innovative": "innovativ",
    "innovatives": "innovativ",
    "innovativs": "innovativ",
    "innovativt": "innovativ",
    "innovativts": "innovativ",
    "innovatören": "innovatör",
    "innovatörens": "innovatör",
    "innovatörer": "innovatör",
    "innovatörerna": "innovatör",
    "innovatörernas": "innovatör",
    "innovatörers": "innovatör",
    "innovatörs": "innovatör",
    "innrar": "inner",
    "innrarna": "inner",
    "innrarnas": "inner",
    "innrars": "inner",
    "innötningar": "innötning",
    "innötningarna": "innötning",
    "innötningarnas": "innötning",
    "innötningars": "innötning",
    "innötningen": "innötning",
    "innötningens": "innötning",
    "innötnings": "innötning",
    "inofficiella": "inofficiell",
    "inofficiellare": "inofficiell",
    "inofficiellares": "inofficiell",
    "inofficiellas": "inofficiell",
    "inofficiellast": "inofficiell",
    "inofficiellaste": "inofficiell",
    "inofficiellastes": "inofficiell",
    "inofficiellasts": "inofficiell",
    "inofficielle": "inofficiell",
    "inofficielles": "inofficiell",
    "inofficiells": "inofficiell",
    "inofficiellt": "inofficiell",
    "inofficiellts": "inofficiell",
    "inokulationen": "inokulation",
    "inokulationens": "inokulation",
    "inokulationer": "inokulation",
    "inokulationerna": "inokulation",
    "inokulationernas": "inokulation",
    "inokulationers": "inokulation",
    "inokulations": "inokulation",
    "inokulerad": "inokulera",
    "inokulerade": "inokulera",
    "inokulerades": "inokulera",
    "inokulerads": "inokulera",
    "inokulerande": "inokulera",
    "inokuleranden": "inokulerande",
    "inokulerandena": "inokulerande",
    "inokulerandenas": "inokulerande",
    "inokulerandens": "inokulerande",
    "inokulerandes": "inokulerande",
    "inokulerandet": "inokulerande",
    "inokulerandets": "inokulerande",
    "inokulerar": "inokulera",
    "inokuleras": "inokulera",
    "inokulerat": "inokulera",
    "inokulerats": "inokulera",
    "inokulerbara": "inokulerbar",
    "inokulerbarare": "inokulerbar",
    "inokulerbarares": "inokulerbar",
    "inokulerbaras": "inokulerbar",
    "inokulerbarast": "inokulerbar",
    "inokulerbaraste": "inokulerbar",
    "inokulerbarastes": "inokulerbar",
    "inokulerbarasts": "inokulerbar",
    "inokulerbare": "inokulerbar",
    "inokulerbares": "inokulerbar",
    "inokulerbarheten": "inokulerbarhet",
    "inokulerbarhetens": "inokulerbarhet",
    "inokulerbarhets": "inokulerbarhet",
    "inokulerbars": "inokulerbar",
    "inokulerbart": "inokulerbar",
    "inokulerbarts": "inokulerbar",
    "inokuleringar": "inokulering",
    "inokuleringarna": "inokulering",
    "inokuleringarnas": "inokulering",
    "inokuleringars": "inokulering",
    "inokuleringen": "inokulering",
    "inokuleringens": "inokulering",
    "inokulerings": "inokulering",
    "inolj": "inolja",
    "inoljad": "inolja",
    "inoljade": "inolja",
    "inoljades": "inolja",
    "inoljads": "inolja",
    "inoljande": "inolja",
    "inoljanden": "inoljande",
    "inoljandena": "inoljande",
    "inoljandenas": "inoljande",
    "inoljandens": "inoljande",
    "inoljandes": "inoljande",
    "inoljandet": "inoljande",
    "inoljandets": "inoljande",
    "inoljar": "inolja",
    "inoljas": "inolja",
    "inoljat": "inolja",
    "inoljats": "inolja",
    "inombordar": "inombordare",
    "inombordaren": "inombordare",
    "inombordarens": "inombordare",
    "inombordares": "inombordare",
    "inombordarna": "inombordare",
    "inombordarnas": "inombordare",
    "inombordsmotorer": "inombordsmotor",
    "inombordsmotorerna": "inombordsmotor",
    "inombordsmotorernas": "inombordsmotor",
    "inombordsmotorers": "inombordsmotor",
    "inombordsmotorn": "inombordsmotor",
    "inombordsmotorns": "inombordsmotor",
    "inombordsmotors": "inombordsmotor",
    "inomhusbelysningar": "inomhusbelysning",
    "inomhusbelysningarna": "inomhusbelysning",
    "inomhusbelysningarnas": "inomhusbelysning",
    "inomhusbelysningars": "inomhusbelysning",
    "inomhusbelysningen": "inomhusbelysning",
    "inomhusbelysningens": "inomhusbelysning",
    "inomhusbelysnings": "inomhusbelysning",
    "inomhusbruket": "inomhusbruk",
    "inomhusbrukets": "inomhusbruk",
    "inomhusbruks": "inomhusbruk",
    "inomhusforskningar": "inomhusforskning",
    "inomhusforskningarna": "inomhusforskning",
    "inomhusforskningarnas": "inomhusforskning",
    "inomhusforskningars": "inomhusforskning",
    "inomhusforskningen": "inomhusforskning",
    "inomhusforskningens": "inomhusforskning",
    "inomhusforsknings": "inomhusforskning",
    "inomhusgolven": "inomhusgolv",
    "inomhusgolvens": "inomhusgolv",
    "inomhusgolvet": "inomhusgolv",
    "inomhusgolvets": "inomhusgolv",
    "inomhusgolvs": "inomhusgolv",
    "inomhusidrotten": "inomhusidrott",
    "inomhusidrottens": "inomhusidrott",
    "inomhusidrotter": "inomhusidrott",
    "inomhusidrotterna": "inomhusidrott",
    "inomhusidrotternas": "inomhusidrott",
    "inomhusidrotters": "inomhusidrott",
    "inomhusidrotts": "inomhusidrott",
    "inomhusluften": "inomhusluft",
    "inomhusluftens": "inomhusluft",
    "inomhuslufter": "inomhusluft",
    "inomhuslufterna": "inomhusluft",
    "inomhuslufternas": "inomhusluft",
    "inomhuslufters": "inomhusluft",
    "inomhuslufts": "inomhusluft",
    "inomkatolska": "inomkatolsk",
    "inomkatolskare": "inomkatolsk",
    "inomkatolskares": "inomkatolsk",
    "inomkatolskas": "inomkatolsk",
    "inomkatolskast": "inomkatolsk",
    "inomkatolskaste": "inomkatolsk",
    "inomkatolskastes": "inomkatolsk",
    "inomkatolskasts": "inomkatolsk",
    "inomkatolske": "inomkatolsk",
    "inomkatolskes": "inomkatolsk",
    "inomkatolsks": "inomkatolsk",
    "inomkatolskt": "inomkatolsk",
    "inomkatolskts": "inomkatolsk",
    "inomvetenskapliga": "inomvetenskaplig",
    "inomvetenskapligare": "inomvetenskaplig",
    "inomvetenskapligares": "inomvetenskaplig",
    "inomvetenskapligas": "inomvetenskaplig",
    "inomvetenskapligast": "inomvetenskaplig",
    "inomvetenskapligaste": "inomvetenskaplig",
    "inomvetenskapligastes": "inomvetenskaplig",
    "inomvetenskapligasts": "inomvetenskaplig",
    "inomvetenskaplige": "inomvetenskaplig",
    "inomvetenskapliges": "inomvetenskaplig",
    "inomvetenskapligheten": "inomvetenskaplighet",
    "inomvetenskaplighetens": "inomvetenskaplighet",
    "inomvetenskaplighets": "inomvetenskaplighet",
    "inomvetenskapligs": "inomvetenskaplig",
    "inomvetenskapligt": "inomvetenskaplig",
    "inomvetenskapligts": "inomvetenskaplig",
    "inopportuna": "inopportun",
    "inopportunare": "inopportun",
    "inopportunares": "inopportun",
    "inopportunas": "inopportun",
    "inopportunast": "inopportun",
    "inopportunaste": "inopportun",
    "inopportunastes": "inopportun",
    "inopportunasts": "inopportun",
    "inopportune": "inopportun",
    "inopportunes": "inopportun",
    "inopportuns": "inopportun",
    "inopportunt": "inopportun",
    "inopportunts": "inopportun",
    "inordn": "inordna",
    "inordnad": "inordna",
    "inordnade": "inordna",
    "inordnades": "inordna",
    "inordnads": "inordna",
    "inordnande": "inordna",
    "inordnanden": "inordnande",
    "inordnandena": "inordnande",
    "inordnandenas": "inordnande",
    "inordnandens": "inordnande",
    "inordnandes": "inordnande",
    "inordnandet": "inordnande",
    "inordnandets": "inordnande",
    "inordnar": "inordna",
    "inordnas": "inordna",
    "inordnat": "inordna",
    "inordnats": "inordna",
    "inpackningar": "inpackning",
    "inpackningarna": "inpackning",
    "inpackningarnas": "inpackning",
    "inpackningars": "inpackning",
    "inpackningen": "inpackning",
    "inpackningens": "inpackning",
    "inpacknings": "inpackning",
    "inpass": "inpassa",
    "inpassad": "inpassa",
    "inpassade": "inpassa",
    "inpassades": "inpassa",
    "inpassads": "inpassa",
    "inpassande": "inpassa",
    "inpassanden": "inpassande",
    "inpassandena": "inpassande",
    "inpassandenas": "inpassande",
    "inpassandens": "inpassande",
    "inpassandes": "inpassande",
    "inpassandet": "inpassande",
    "inpassandets": "inpassande",
    "inpassar": "inpassa",
    "inpassas": "inpassa",
    "inpassat": "inpassa",
    "inpassats": "inpassa",
    "inpassen": "inpass",
    "inpassens": "inpass",
    "inpasset": "inpass",
    "inpassets": "inpass",
    "inpassningar": "inpassning",
    "inpassningarna": "inpassning",
    "inpassningarnas": "inpassning",
    "inpassningars": "inpassning",
    "inpassningen": "inpassning",
    "inpassningens": "inpassning",
    "inpassnings": "inpassning",
    "inpetade": "inpetad",
    "inpetades": "inpetad",
    "inpetads": "inpetad",
    "inpetat": "inpetad",
    "inpetats": "inpetad",
    "inpetningar": "inpetning",
    "inpetningarna": "inpetning",
    "inpetningarnas": "inpetning",
    "inpetningars": "inpetning",
    "inpetningen": "inpetning",
    "inpetningens": "inpetning",
    "inpetnings": "inpetning",
    "inpiskade": "inpiskad",
    "inpiskades": "inpiskad",
    "inpiskads": "inpiskad",
    "inpiskar": "inpiskare",
    "inpiskaren": "inpiskare",
    "inpiskarens": "inpiskare",
    "inpiskares": "inpiskare",
    "inpiskarna": "inpiskare",
    "inpiskarnas": "inpiskare",
    "inpiskat": "inpiskad",
    "inpiskats": "inpiskad",
    "inplant": "inplanta",
    "inplantad": "inplanta",
    "inplantade": "inplanta",
    "inplantades": "inplanta",
    "inplantads": "inplanta",
    "inplantande": "inplanta",
    "inplantanden": "inplantande",
    "inplantandena": "inplantande",
    "inplantandenas": "inplantande",
    "inplantandens": "inplantande",
    "inplantandes": "inplantande",
    "inplantandet": "inplantande",
    "inplantandets": "inplantande",
    "inplantar": "inplanta",
    "inplantas": "inplanta",
    "inplantat": "inplanta",
    "inplantats": "inplanta",
    "inplanterad": "inplantera",
    "inplanterade": "inplantera",
    "inplanterades": "inplantera",
    "inplanterads": "inplantera",
    "inplanterande": "inplantera",
    "inplanteranden": "inplanterande",
    "inplanterandena": "inplanterande",
    "inplanterandenas": "inplanterande",
    "inplanterandens": "inplanterande",
    "inplanterandes": "inplanterande",
    "inplanterandet": "inplanterande",
    "inplanterandets": "inplanterande",
    "inplanterar": "inplantera",
    "inplanteras": "inplantera",
    "inplanterat": "inplantera",
    "inplanterats": "inplantera",
    "inplanterbara": "inplanterbar",
    "inplanterbarare": "inplanterbar",
    "inplanterbarares": "inplanterbar",
    "inplanterbaras": "inplanterbar",
    "inplanterbarast": "inplanterbar",
    "inplanterbaraste": "inplanterbar",
    "inplanterbarastes": "inplanterbar",
    "inplanterbarasts": "inplanterbar",
    "inplanterbare": "inplanterbar",
    "inplanterbares": "inplanterbar",
    "inplanterbarheten": "inplanterbarhet",
    "inplanterbarhetens": "inplanterbarhet",
    "inplanterbarhets": "inplanterbarhet",
    "inplanterbars": "inplanterbar",
    "inplanterbart": "inplanterbar",
    "inplanterbarts": "inplanterbar",
    "inplanteringar": "inplantering",
    "inplanteringarna": "inplantering",
    "inplanteringarnas": "inplantering",
    "inplanteringars": "inplantering",
    "inplanteringen": "inplantering",
    "inplanteringens": "inplantering",
    "inplanterings": "inplantering",
    "inplastade": "inplastad",
    "inplastades": "inplastad",
    "inplastads": "inplastad",
    "inplastat": "inplastad",
    "inplastats": "inplastad",
    "inpress": "inpressa",
    "inpressad": "inpressa",
    "inpressade": "inpressa",
    "inpressades": "inpressa",
    "inpressads": "inpressa",
    "inpressande": "inpressa",
    "inpressanden": "inpressande",
    "inpressandena": "inpressande",
    "inpressandenas": "inpressande",
    "inpressandens": "inpressande",
    "inpressandes": "inpressande",
    "inpressandet": "inpressande",
    "inpressandets": "inpressande",
    "inpressar": "inpressa",
    "inpressas": "inpressa",
    "inpressat": "inpressa",
    "inpressats": "inpressa",
    "inprick": "inpricka",
    "inprickad": "inpricka",
    "inprickade": "inpricka",
    "inprickades": "inpricka",
    "inprickads": "inpricka",
    "inprickande": "inpricka",
    "inprickanden": "inprickande",
    "inprickandena": "inprickande",
    "inprickandenas": "inprickande",
    "inprickandens": "inprickande",
    "inprickandes": "inprickande",
    "inprickandet": "inprickande",
    "inprickandets": "inprickande",
    "inprickar": "inpricka",
    "inprickas": "inpricka",
    "inprickat": "inpricka",
    "inprickats": "inpricka",
    "inpräglad": "inprägla",
    "inpräglade": "inprägla",
    "inpräglades": "inprägla",
    "inpräglads": "inprägla",
    "inpräglande": "inprägla",
    "inpräglanden": "inpräglande",
    "inpräglandena": "inpräglande",
    "inpräglandenas": "inpräglande",
    "inpräglandens": "inpräglande",
    "inpräglandes": "inpräglande",
    "inpräglandet": "inpräglande",
    "inpräglandets": "inpräglande",
    "inpräglar": "inprägla",
    "inpräglas": "inprägla",
    "inpräglat": "inprägla",
    "inpräglats": "inprägla",
    "inpränt": "inpränta",
    "inpräntad": "inpränta",
    "inpräntade": "inpränta",
    "inpräntades": "inpränta",
    "inpräntads": "inpränta",
    "inpräntande": "inpränta",
    "inpräntanden": "inpräntande",
    "inpräntandena": "inpräntande",
    "inpräntandenas": "inpräntande",
    "inpräntandens": "inpräntande",
    "inpräntandes": "inpräntande",
    "inpräntandet": "inpräntande",
    "inpräntandets": "inpräntande",
    "inpräntar": "inpränta",
    "inpräntas": "inpränta",
    "inpräntat": "inpränta",
    "inpräntats": "inpränta",
    "inputen": "input",
    "inputens": "input",
    "inputs": "input",
    "inpyrda": "inpyrd",
    "inpyrdare": "inpyrd",
    "inpyrdares": "inpyrd",
    "inpyrdas": "inpyrd",
    "inpyrdast": "inpyrd",
    "inpyrdaste": "inpyrd",
    "inpyrdastes": "inpyrd",
    "inpyrdasts": "inpyrd",
    "inpyrde": "inpyrd",
    "inpyrdes": "inpyrd",
    "inpyrdheten": "inpyrdhet",
    "inpyrdhetens": "inpyrdhet",
    "inpyrdhets": "inpyrdhet",
    "inpyrds": "inpyrd",
    "inpyrt": "inpyrd",
    "inpyrts": "inpyrd",
    "inram": "inrama",
    "inramad": "inrama",
    "inramade": "inrama",
    "inramades": "inrama",
    "inramads": "inrama",
    "inramande": "inrama",
    "inramanden": "inramande",
    "inramandena": "inramande",
    "inramandenas": "inramande",
    "inramandens": "inramande",
    "inramandes": "inramande",
    "inramandet": "inramande",
    "inramandets": "inramande",
    "inramar": "inrama",
    "inramas": "inrama",
    "inramat": "inrama",
    "inramats": "inrama",
    "inramningar": "inramning",
    "inramningarna": "inramning",
    "inramningarnas": "inramning",
    "inramningars": "inramning",
    "inramningen": "inramning",
    "inramningens": "inramning",
    "inramnings": "inramning",
    "inrangerad": "inrangera",
    "inrangerade": "inrangera",
    "inrangerades": "inrangera",
    "inrangerads": "inrangera",
    "inrangerande": "inrangera",
    "inrangeranden": "inrangerande",
    "inrangerandena": "inrangerande",
    "inrangerandenas": "inrangerande",
    "inrangerandens": "inrangerande",
    "inrangerandes": "inrangerande",
    "inrangerandet": "inrangerande",
    "inrangerandets": "inrangerande",
    "inrangerar": "inrangera",
    "inrangeras": "inrangera",
    "inrangerat": "inrangera",
    "inrangerats": "inrangera",
    "inrangerbara": "inrangerbar",
    "inrangerbarare": "inrangerbar",
    "inrangerbarares": "inrangerbar",
    "inrangerbaras": "inrangerbar",
    "inrangerbarast": "inrangerbar",
    "inrangerbaraste": "inrangerbar",
    "inrangerbarastes": "inrangerbar",
    "inrangerbarasts": "inrangerbar",
    "inrangerbare": "inrangerbar",
    "inrangerbares": "inrangerbar",
    "inrangerbarheten": "inrangerbarhet",
    "inrangerbarhetens": "inrangerbarhet",
    "inrangerbarhets": "inrangerbarhet",
    "inrangerbars": "inrangerbar",
    "inrangerbart": "inrangerbar",
    "inrangerbarts": "inrangerbar",
    "inrangeringar": "inrangering",
    "inrangeringarna": "inrangering",
    "inrangeringarnas": "inrangering",
    "inrangeringars": "inrangering",
    "inrangeringen": "inrangering",
    "inrangeringens": "inrangering",
    "inrangerings": "inrangering",
    "inrapporterad": "inrapportera",
    "inrapporterade": "inrapportera",
    "inrapporterades": "inrapportera",
    "inrapporterads": "inrapportera",
    "inrapporterande": "inrapportera",
    "inrapporteranden": "inrapporterande",
    "inrapporterandena": "inrapporterande",
    "inrapporterandenas": "inrapporterande",
    "inrapporterandens": "inrapporterande",
    "inrapporterandes": "inrapporterande",
    "inrapporterandet": "inrapporterande",
    "inrapporterandets": "inrapporterande",
    "inrapporterar": "inrapportera",
    "inrapporteras": "inrapportera",
    "inrapporterat": "inrapportera",
    "inrapporterats": "inrapportera",
    "inrapporterbara": "inrapporterbar",
    "inrapporterbarare": "inrapporterbar",
    "inrapporterbarares": "inrapporterbar",
    "inrapporterbaras": "inrapporterbar",
    "inrapporterbarast": "inrapporterbar",
    "inrapporterbaraste": "inrapporterbar",
    "inrapporterbarastes": "inrapporterbar",
    "inrapporterbarasts": "inrapporterbar",
    "inrapporterbare": "inrapporterbar",
    "inrapporterbares": "inrapporterbar",
    "inrapporterbarheten": "inrapporterbarhet",
    "inrapporterbarhetens": "inrapporterbarhet",
    "inrapporterbarhets": "inrapporterbarhet",
    "inrapporterbars": "inrapporterbar",
    "inrapporterbart": "inrapporterbar",
    "inrapporterbarts": "inrapporterbar",
    "inrapporteringar": "inrapportering",
    "inrapporteringarna": "inrapportering",
    "inrapporteringarnas": "inrapportering",
    "inrapporteringars": "inrapportering",
    "inrapporteringen": "inrapportering",
    "inrapporteringens": "inrapportering",
    "inrapporterings": "inrapportering",
    "inrar": "inner",
    "inrarna": "inner",
    "inrarnas": "inner",
    "inrars": "inner",
    "inred": "inreda",
    "inredande": "inreda",
    "inredanden": "inredande",
    "inredandena": "inredande",
    "inredandenas": "inredande",
    "inredandens": "inredande",
    "inredandes": "inredande",
    "inredandet": "inredande",
    "inredandets": "inredande",
    "inredas": "inreda",
    "inredd": "inreda",
    "inredda": "inreda",
    "inreddas": "inreda",
    "inredde": "inreda",
    "inreddes": "inreda",
    "inredds": "inreda",
    "inreder": "inreda",
    "inredes": "inreda",
    "inredningar": "inredning",
    "inredningarna": "inredning",
    "inredningarnas": "inredning",
    "inredningars": "inredning",
    "inredningen": "inredning",
    "inredningens": "inredning",
    "inrednings": "inredning",
    "inredningsarkitekten": "inredningsarkitekt",
    "inredningsarkitektens": "inredningsarkitekt",
    "inredningsarkitekter": "inredningsarkitekt",
    "inredningsarkitekterna": "inredningsarkitekt",
    "inredningsarkitekternas": "inredningsarkitekt",
    "inredningsarkitekters": "inredningsarkitekt",
    "inredningsarkitekts": "inredningsarkitekt",
    "inredningsdetaljen": "inredningsdetalj",
    "inredningsdetaljens": "inredningsdetalj",
    "inredningsdetaljer": "inredningsdetalj",
    "inredningsdetaljerna": "inredningsdetalj",
    "inredningsdetaljernas": "inredningsdetalj",
    "inredningsdetaljers": "inredningsdetalj",
    "inredningsdetaljs": "inredningsdetalj",
    "inredningsintresserade": "inredningsintresserad",
    "inredningsintresserades": "inredningsintresserad",
    "inredningsintresserads": "inredningsintresserad",
    "inredningsintresserat": "inredningsintresserad",
    "inredningsintresserats": "inredningsintresserad",
    "inredningsmässiga": "inredningsmässig",
    "inredningsmässigare": "inredningsmässig",
    "inredningsmässigares": "inredningsmässig",
    "inredningsmässigas": "inredningsmässig",
    "inredningsmässigast": "inredningsmässig",
    "inredningsmässigaste": "inredningsmässig",
    "inredningsmässigastes": "inredningsmässig",
    "inredningsmässigasts": "inredningsmässig",
    "inredningsmässige": "inredningsmässig",
    "inredningsmässiges": "inredningsmässig",
    "inredningsmässigs": "inredningsmässig",
    "inredningsmässigt": "inredningsmässig",
    "inredningsmässigts": "inredningsmässig",
    "inreds": "inreda",
    "inregistrerad": "inregistrera",
    "inregistrerade": "inregistrera",
    "inregistrerades": "inregistrera",
    "inregistrerads": "inregistrera",
    "inregistrerande": "inregistrera",
    "inregistreranden": "inregistrerande",
    "inregistrerandena": "inregistrerande",
    "inregistrerandenas": "inregistrerande",
    "inregistrerandens": "inregistrerande",
    "inregistrerandes": "inregistrerande",
    "inregistrerandet": "inregistrerande",
    "inregistrerandets": "inregistrerande",
    "inregistrerar": "inregistrera",
    "inregistreras": "inregistrera",
    "inregistrerat": "inregistrera",
    "inregistrerats": "inregistrera",
    "inregistrerbara": "inregistrerbar",
    "inregistrerbarare": "inregistrerbar",
    "inregistrerbarares": "inregistrerbar",
    "inregistrerbaras": "inregistrerbar",
    "inregistrerbarast": "inregistrerbar",
    "inregistrerbaraste": "inregistrerbar",
    "inregistrerbarastes": "inregistrerbar",
    "inregistrerbarasts": "inregistrerbar",
    "inregistrerbare": "inregistrerbar",
    "inregistrerbares": "inregistrerbar",
    "inregistrerbarheten": "inregistrerbarhet",
    "inregistrerbarhetens": "inregistrerbarhet",
    "inregistrerbarhets": "inregistrerbarhet",
    "inregistrerbars": "inregistrerbar",
    "inregistrerbart": "inregistrerbar",
    "inregistrerbarts": "inregistrerbar",
    "inregistreringar": "inregistrering",
    "inregistreringarna": "inregistrering",
    "inregistreringarnas": "inregistrering",
    "inregistreringars": "inregistrering",
    "inregistreringen": "inregistrering",
    "inregistreringens": "inregistrering",
    "inregistrerings": "inregistrering",
    "inremedicinska": "inremedicinsk",
    "inremedicinskare": "inremedicinsk",
    "inremedicinskares": "inremedicinsk",
    "inremedicinskas": "inremedicinsk",
    "inremedicinskast": "inremedicinsk",
    "inremedicinskaste": "inremedicinsk",
    "inremedicinskastes": "inremedicinsk",
    "inremedicinskasts": "inremedicinsk",
    "inremedicinske": "inremedicinsk",
    "inremedicinskes": "inremedicinsk",
    "inremedicinsks": "inremedicinsk",
    "inremedicinskt": "inremedicinsk",
    "inremedicinskts": "inremedicinsk",
    "inremissionen": "inremission",
    "inremissionens": "inremission",
    "inremissioner": "inremission",
    "inremissionerna": "inremission",
    "inremissionernas": "inremission",
    "inremissioners": "inremission",
    "inremissions": "inremission",
    "inres": "inre",
    "inresan": "inresa",
    "inresans": "inresa",
    "inresas": "inresa",
    "inrese": "inresa",
    "inreseförbudet": "inreseförbud",
    "inreseförbudets": "inreseförbud",
    "inreseförbuds": "inreseförbud",
    "inresekretoriska": "inresekretorisk",
    "inresekretoriskare": "inresekretorisk",
    "inresekretoriskares": "inresekretorisk",
    "inresekretoriskas": "inresekretorisk",
    "inresekretoriskast": "inresekretorisk",
    "inresekretoriskaste": "inresekretorisk",
    "inresekretoriskastes": "inresekretorisk",
    "inresekretoriskasts": "inresekretorisk",
    "inresekretoriske": "inresekretorisk",
    "inresekretoriskes": "inresekretorisk",
    "inresekretorisks": "inresekretorisk",
    "inresekretoriskt": "inresekretorisk",
    "inresekretoriskts": "inresekretorisk",
    "inresetillstånden": "inresetillstånd",
    "inresetillståndens": "inresetillstånd",
    "inresetillståndet": "inresetillstånd",
    "inresetillståndets": "inresetillstånd",
    "inresetillstånds": "inresetillstånd",
    "inresevisa": "inresevisum",
    "inresevisana": "inresevisum",
    "inresevisanas": "inresevisum",
    "inresevisas": "inresevisum",
    "inresevisumen": "inresevisum",
    "inresevisumens": "inresevisum",
    "inresevisumet": "inresevisum",
    "inresevisumets": "inresevisum",
    "inresevisums": "inresevisum",
    "inresor": "inresa",
    "inresorna": "inresa",
    "inresornas": "inresa",
    "inresors": "inresa",
    "inrett": "inreda",
    "inretts": "inreda",
    "inriggade": "inriggad",
    "inriggades": "inriggad",
    "inriggads": "inriggad",
    "inriggar": "inriggare",
    "inriggaren": "inriggare",
    "inriggarens": "inriggare",
    "inriggares": "inriggare",
    "inriggarna": "inriggare",
    "inriggarnas": "inriggare",
    "inriggat": "inriggad",
    "inriggats": "inriggad",
    "inrikesdepartementen": "inrikesdepartement",
    "inrikesdepartementens": "inrikesdepartement",
    "inrikesdepartementet": "inrikesdepartement",
    "inrikesdepartementets": "inrikesdepartement",
    "inrikesdepartements": "inrikesdepartement",
    "inrikesflyget": "inrikesflyg",
    "inrikesflygets": "inrikesflyg",
    "inrikesflygs": "inrikesflyg",
    "inrikesministern": "inrikesminister",
    "inrikesministerns": "inrikesminister",
    "inrikesministers": "inrikesminister",
    "inrikesministrar": "inrikesminister",
    "inrikesministrarna": "inrikesminister",
    "inrikesministrarnas": "inrikesminister",
    "inrikesministrars": "inrikesminister",
    "inrikespolitiken": "inrikespolitik",
    "inrikespolitikens": "inrikespolitik",
    "inrikespolitiks": "inrikespolitik",
    "inrikespolitiska": "inrikespolitisk",
    "inrikespolitiskare": "inrikespolitisk",
    "inrikespolitiskares": "inrikespolitisk",
    "inrikespolitiskas": "inrikespolitisk",
    "inrikespolitiskast": "inrikespolitisk",
    "inrikespolitiskaste": "inrikespolitisk",
    "inrikespolitiskastes": "inrikespolitisk",
    "inrikespolitiskasts": "inrikespolitisk",
    "inrikespolitiske": "inrikespolitisk",
    "inrikespolitiskes": "inrikespolitisk",
    "inrikespolitisks": "inrikespolitisk",
    "inrikespolitiskt": "inrikespolitisk",
    "inrikespolitiskts": "inrikespolitisk",
    "inrikestrafiken": "inrikestrafik",
    "inrikestrafikens": "inrikestrafik",
    "inrikestrafiks": "inrikestrafik",
    "inriktad": "inrikta",
    "inriktade": "inrikta",
    "inriktades": "inrikta",
    "inriktads": "inrikta",
    "inriktande": "inrikta",
    "inriktanden": "inriktande",
    "inriktandena": "inriktande",
    "inriktandenas": "inriktande",
    "inriktandens": "inriktande",
    "inriktandes": "inriktande",
    "inriktandet": "inriktande",
    "inriktandets": "inriktande",
    "inriktar": "inrikta",
    "inriktas": "inrikta",
    "inriktat": "inrikta",
    "inriktats": "inrikta",
    "inriktningar": "inriktning",
    "inriktningarna": "inriktning",
    "inriktningarnas": "inriktning",
    "inriktningars": "inriktning",
    "inriktningen": "inriktning",
    "inriktningens": "inriktning",
    "inriktnings": "inriktning",
    "inrimmen": "inrim",
    "inrimmens": "inrim",
    "inrimmet": "inrim",
    "inrimmets": "inrim",
    "inrims": "inrim",
    "inring": "inringa",
    "inringad": "inringa",
    "inringade": "inringa",
    "inringades": "inringa",
    "inringads": "inringa",
    "inringande": "inringa",
    "inringanden": "inringande",
    "inringandena": "inringande",
    "inringandenas": "inringande",
    "inringandens": "inringande",
    "inringandes": "inringande",
    "inringandet": "inringande",
    "inringandets": "inringande",
    "inringar": "inringa",
    "inringas": "inringa",
    "inringat": "inringa",
    "inringats": "inringa",
    "inrist": "inrista",
    "inristad": "inrista",
    "inristade": "inrista",
    "inristades": "inrista",
    "inristads": "inrista",
    "inristande": "inrista",
    "inristanden": "inristande",
    "inristandena": "inristande",
    "inristandenas": "inristande",
    "inristandens": "inristande",
    "inristandes": "inristande",
    "inristandet": "inristande",
    "inristandets": "inristande",
    "inristar": "inrista",
    "inristas": "inrista",
    "inristat": "inrista",
    "inristats": "inrista",
    "inristningar": "inristning",
    "inristningarna": "inristning",
    "inristningarnas": "inristning",
    "inristningars": "inristning",
    "inristningen": "inristning",
    "inristningens": "inristning",
    "inristnings": "inristning",
    "inrop": "inropa",
    "inropad": "inropa",
    "inropade": "inropa",
    "inropades": "inropa",
    "inropads": "inropa",
    "inropande": "inropa",
    "inropanden": "inropande",
    "inropandena": "inropande",
    "inropandenas": "inropande",
    "inropandens": "inropande",
    "inropandes": "inropande",
    "inropandet": "inropande",
    "inropandets": "inropande",
    "inropar": "inropare",
    "inroparen": "inropare",
    "inroparens": "inropare",
    "inropares": "inropare",
    "inroparna": "inropare",
    "inroparnas": "inropare",
    "inropas": "inropa",
    "inropat": "inropa",
    "inropats": "inropa",
    "inropen": "inrop",
    "inropens": "inrop",
    "inropet": "inrop",
    "inropets": "inrop",
    "inropningar": "inropning",
    "inropningarna": "inropning",
    "inropningarnas": "inropning",
    "inropningars": "inropning",
    "inropningen": "inropning",
    "inropningens": "inropning",
    "inropnings": "inropning",
    "inrops": "inrop",
    "inrotade": "inrotad",
    "inrotades": "inrotad",
    "inrotads": "inrotad",
    "inrotat": "inrotad",
    "inrotats": "inrotad",
    "inrutade": "inrutad",
    "inrutades": "inrutad",
    "inrutads": "inrutad",
    "inrutat": "inrutad",
    "inrutats": "inrutad",
    "inryckningar": "inryckning",
    "inryckningarna": "inryckning",
    "inryckningarnas": "inryckning",
    "inryckningars": "inryckning",
    "inryckningen": "inryckning",
    "inryckningens": "inryckning",
    "inrycknings": "inryckning",
    "inrym": "inrymma",
    "inrymd": "inrymma",
    "inrymda": "inrymma",
    "inrymdas": "inrymma",
    "inrymde": "inrymma",
    "inrymdes": "inrymma",
    "inrymds": "inrymma",
    "inrymmande": "inrymma",
    "inrymmanden": "inrymmande",
    "inrymmandena": "inrymmande",
    "inrymmandenas": "inrymmande",
    "inrymmandens": "inrymmande",
    "inrymmandes": "inrymmande",
    "inrymmandet": "inrymmande",
    "inrymmandets": "inrymmande",
    "inrymmas": "inrymma",
    "inrymmer": "inrymma",
    "inryms": "inrymma",
    "inrymt": "inrymma",
    "inrymts": "inrymma",
    "inräkn": "inräkna",
    "inräknad": "inräkna",
    "inräknade": "inräkna",
    "inräknades": "inräkna",
    "inräknads": "inräkna",
    "inräknae": "inräkna",
    "inräknaes": "inräkna",
    "inräknande": "inräkna",
    "inräknanden": "inräknande",
    "inräknandena": "inräknande",
    "inräknandenas": "inräknande",
    "inräknandens": "inräknande",
    "inräknandes": "inräknande",
    "inräknandet": "inräknande",
    "inräknandets": "inräknande",
    "inräknar": "inräkna",
    "inräknas": "inräkna",
    "inräknat": "inräkna",
    "inräknats": "inräkna",
    "inräkningar": "inräkning",
    "inräkningarna": "inräkning",
    "inräkningarnas": "inräkning",
    "inräkningars": "inräkning",
    "inräkningen": "inräkning",
    "inräkningens": "inräkning",
    "inräknings": "inräkning",
    "inräknt": "inräkna",
    "inräknts": "inräkna",
    "inrätt": "inrätta",
    "inrättad": "inrätta",
    "inrättade": "inrätta",
    "inrättades": "inrätta",
    "inrättads": "inrätta",
    "inrättande": "inrätta",
    "inrättanden": "inrättande",
    "inrättandena": "inrättande",
    "inrättandenas": "inrättande",
    "inrättandens": "inrättande",
    "inrättandes": "inrättande",
    "inrättandet": "inrättande",
    "inrättandets": "inrättande",
    "inrättar": "inrätta",
    "inrättas": "inrätta",
    "inrättat": "inrätta",
    "inrättats": "inrätta",
    "inrättningar": "inrättning",
    "inrättningarna": "inrättning",
    "inrättningarnas": "inrättning",
    "inrättningars": "inrättning",
    "inrättningen": "inrättning",
    "inrättningens": "inrättning",
    "inrättnings": "inrättning",
    "inrådans": "inrådan",
    "inröstningar": "inröstning",
    "inröstningarna": "inröstning",
    "inröstningarnas": "inröstning",
    "inröstningars": "inröstning",
    "inröstningen": "inröstning",
    "inröstningens": "inröstning",
    "inröstnings": "inröstning",
    "ins": "i",
    "insamlad": "insamla",
    "insamlade": "insamla",
    "insamlades": "insamla",
    "insamlads": "insamla",
    "insamlande": "insamla",
    "insamlanden": "insamlande",
    "insamlandena": "insamlande",
    "insamlandenas": "insamlande",
    "insamlandens": "insamlande",
    "insamlandes": "insamlande",
    "insamlandet": "insamlande",
    "insamlandets": "insamlande",
    "insamlar": "insamla",
    "insamlas": "insamla",
    "insamlat": "insamla",
    "insamlats": "insamla",
    "insamlingar": "insamling",
    "insamlingarna": "insamling",
    "insamlingarnas": "insamling",
    "insamlingars": "insamling",
    "insamlingen": "insamling",
    "insamlingens": "insamling",
    "insamlings": "insamling",
    "insatsen": "insats",
    "insatsens": "insats",
    "insatser": "insats",
    "insatserna": "insats",
    "insatsernas": "insats",
    "insatsers": "insats",
    "insatslägenheten": "insatslägenhet",
    "insatslägenhetens": "insatslägenhet",
    "insatslägenheter": "insatslägenhet",
    "insatslägenheterna": "insatslägenhet",
    "insatslägenheternas": "insatslägenhet",
    "insatslägenheters": "insatslägenhet",
    "insatslägenhets": "insatslägenhet",
    "insatsstyrkan": "insatsstyrka",
    "insatsstyrkans": "insatsstyrka",
    "insatsstyrkas": "insatsstyrka",
    "insatsstyrke": "insatsstyrka",
    "insatsstyrkor": "insatsstyrka",
    "insatsstyrkorna": "insatsstyrka",
    "insatsstyrkornas": "insatsstyrka",
    "insatsstyrkors": "insatsstyrka",
    "insatt": "insätta",
    "insatta": "insätta",
    "insattare": "insatt",
    "insattares": "insatt",
    "insattas": "insätta",
    "insattast": "insatt",
    "insattaste": "insatt",
    "insattastes": "insatt",
    "insattasts": "insatt",
    "insatte": "insätta",
    "insattes": "insätta",
    "insatts": "insätta",
    "inscenerad": "inscenera",
    "inscenerade": "inscenera",
    "inscenerades": "inscenera",
    "inscenerads": "inscenera",
    "inscenerande": "inscenera",
    "insceneranden": "inscenerande",
    "inscenerandena": "inscenerande",
    "inscenerandenas": "inscenerande",
    "inscenerandens": "inscenerande",
    "inscenerandes": "inscenerande",
    "inscenerandet": "inscenerande",
    "inscenerandets": "inscenerande",
    "inscenerar": "inscenera",
    "insceneras": "inscenera",
    "inscenerat": "inscenera",
    "inscenerats": "inscenera",
    "inscenerbara": "inscenerbar",
    "inscenerbarare": "inscenerbar",
    "inscenerbarares": "inscenerbar",
    "inscenerbaras": "inscenerbar",
    "inscenerbarast": "inscenerbar",
    "inscenerbaraste": "inscenerbar",
    "inscenerbarastes": "inscenerbar",
    "inscenerbarasts": "inscenerbar",
    "inscenerbare": "inscenerbar",
    "inscenerbares": "inscenerbar",
    "inscenerbarheten": "inscenerbarhet",
    "inscenerbarhetens": "inscenerbarhet",
    "inscenerbarhets": "inscenerbarhet",
    "inscenerbars": "inscenerbar",
    "inscenerbart": "inscenerbar",
    "inscenerbarts": "inscenerbar",
    "insceneringar": "inscenering",
    "insceneringarna": "inscenering",
    "insceneringarnas": "inscenering",
    "insceneringars": "inscenering",
    "insceneringen": "inscenering",
    "insceneringens": "inscenering",
    "inscenerings": "inscenering",
    "insedd": "inse",
    "insedda": "inse",
    "inseddas": "inse",
    "insedde": "inse",
    "inseddes": "inse",
    "insedds": "inse",
    "inseende": "inse",
    "inseendes": "inseende",
    "inseendet": "inseende",
    "inseendets": "inseende",
    "insegels": "insegel",
    "inseglad": "insegla",
    "inseglade": "insegla",
    "inseglades": "insegla",
    "inseglads": "insegla",
    "inseglande": "insegla",
    "inseglanden": "inseglande",
    "inseglandena": "inseglande",
    "inseglandenas": "inseglande",
    "inseglandens": "inseglande",
    "inseglandes": "inseglande",
    "inseglandet": "inseglande",
    "inseglandets": "inseglande",
    "inseglar": "insegla",
    "inseglas": "insegla",
    "inseglat": "insegla",
    "inseglats": "insegla",
    "inseglen": "insegel",
    "inseglens": "insegel",
    "inseglet": "insegel",
    "inseglets": "insegel",
    "inseglingar": "insegling",
    "inseglingarna": "insegling",
    "inseglingarnas": "insegling",
    "inseglingars": "insegling",
    "inseglingen": "insegling",
    "inseglingens": "insegling",
    "inseglings": "insegling",
    "inseglingsfyrar": "inseglingsfyr",
    "inseglingsfyrarna": "inseglingsfyr",
    "inseglingsfyrarnas": "inseglingsfyr",
    "inseglingsfyrars": "inseglingsfyr",
    "inseglingsfyren": "inseglingsfyr",
    "inseglingsfyrens": "inseglingsfyr",
    "inseglingsfyrs": "inseglingsfyr",
    "inseglingsränn": "inseglingsränna",
    "inseglingsrännan": "inseglingsränna",
    "inseglingsrännans": "inseglingsränna",
    "inseglingsrännas": "inseglingsränna",
    "inseglingsränne": "inseglingsränna",
    "inseglingsrännor": "inseglingsränna",
    "inseglingsrännorna": "inseglingsränna",
    "inseglingsrännornas": "inseglingsränna",
    "inseglingsrännors": "inseglingsränna",
    "inseglingsränns": "inseglingsränna",
    "insekten": "insekt",
    "insektens": "insekt",
    "insekter": "insekt",
    "insekterna": "insekt",
    "insekternas": "insekt",
    "insekters": "insekt",
    "insekticiden": "insekticid",
    "insekticidens": "insekticid",
    "insekticider": "insekticid",
    "insekticiderna": "insekticid",
    "insekticidernas": "insekticid",
    "insekticiders": "insekticid",
    "insekticids": "insekticid",
    "insekts": "insekt",
    "insektsangreppen": "insektsangrepp",
    "insektsangreppens": "insektsangrepp",
    "insektsangreppet": "insektsangrepp",
    "insektsangreppets": "insektsangrepp",
    "insektsangrepps": "insektsangrepp",
    "insektsbefruktningar": "insektsbefruktning",
    "insektsbefruktningarna": "insektsbefruktning",
    "insektsbefruktningarnas": "insektsbefruktning",
    "insektsbefruktningars": "insektsbefruktning",
    "insektsbefruktningen": "insektsbefruktning",
    "insektsbefruktningens": "insektsbefruktning",
    "insektsbefruktnings": "insektsbefruktning",
    "insektsbetten": "insektsbett",
    "insektsbettens": "insektsbett",
    "insektsbettet": "insektsbett",
    "insektsbettets": "insektsbett",
    "insektsbetts": "insektsbett",
    "insektsblom": "insektsblomma",
    "insektsblomman": "insektsblomma",
    "insektsblommans": "insektsblomma",
    "insektsblommas": "insektsblomma",
    "insektsblomme": "insektsblomma",
    "insektsblommor": "insektsblomma",
    "insektsblommorna": "insektsblomma",
    "insektsblommornas": "insektsblomma",
    "insektsblommors": "insektsblomma",
    "insektsbloms": "insektsblomma",
    "insektsborttagar": "insektsborttagare",
    "insektsborttagaren": "insektsborttagare",
    "insektsborttagarens": "insektsborttagare",
    "insektsborttagares": "insektsborttagare",
    "insektsborttagarna": "insektsborttagare",
    "insektsborttagarnas": "insektsborttagare",
    "insektsgifter": "insektsgift",
    "insektsgifterna": "insektsgift",
    "insektsgifternas": "insektsgift",
    "insektsgifters": "insektsgift",
    "insektsgiftet": "insektsgift",
    "insektsgiftets": "insektsgift",
    "insektsgifts": "insektsgift",
    "insektskunniga": "insektskunnig",
    "insektskunnigare": "insektskunnig",
    "insektskunnigares": "insektskunnig",
    "insektskunnigas": "insektskunnig",
    "insektskunnigast": "insektskunnig",
    "insektskunnigaste": "insektskunnig",
    "insektskunnigastes": "insektskunnig",
    "insektskunnigasts": "insektskunnig",
    "insektskunnige": "insektskunnig",
    "insektskunniges": "insektskunnig",
    "insektskunnigheten": "insektskunnighet",
    "insektskunnighetens": "insektskunnighet",
    "insektskunnighets": "insektskunnighet",
    "insektskunnigs": "insektskunnig",
    "insektskunnigt": "insektskunnig",
    "insektskunnigts": "insektskunnig",
    "insektsmedels": "insektsmedel",
    "insektsmedlen": "insektsmedel",
    "insektsmedlens": "insektsmedel",
    "insektsmedlet": "insektsmedel",
    "insektsmedlets": "insektsmedel",
    "insektsnålar": "insektsnål",
    "insektsnålarna": "insektsnål",
    "insektsnålarnas": "insektsnål",
    "insektsnålars": "insektsnål",
    "insektsnålen": "insektsnål",
    "insektsnålens": "insektsnål",
    "insektsnåls": "insektsnål",
    "insektssamlingar": "insektssamling",
    "insektssamlingarna": "insektssamling",
    "insektssamlingarnas": "insektssamling",
    "insektssamlingars": "insektssamling",
    "insektssamlingen": "insektssamling",
    "insektssamlingens": "insektssamling",
    "insektssamlings": "insektssamling",
    "insektssaxar": "insektssax",
    "insektssaxarna": "insektssax",
    "insektssaxarnas": "insektssax",
    "insektssaxars": "insektssax",
    "insektssaxen": "insektssax",
    "insektssaxens": "insektssax",
    "insektsätar": "insektsätare",
    "insektsätaren": "insektsätare",
    "insektsätarens": "insektsätare",
    "insektsätares": "insektsätare",
    "insektsätarna": "insektsätare",
    "insektsätarnas": "insektsätare",
    "inseminationen": "insemination",
    "inseminationens": "insemination",
    "inseminationer": "insemination",
    "inseminationerna": "insemination",
    "inseminationernas": "insemination",
    "inseminationers": "insemination",
    "inseminations": "insemination",
    "inseminerad": "inseminera",
    "inseminerade": "inseminera",
    "inseminerades": "inseminera",
    "inseminerads": "inseminera",
    "inseminerande": "inseminera",
    "insemineranden": "inseminerande",
    "inseminerandena": "inseminerande",
    "inseminerandenas": "inseminerande",
    "inseminerandens": "inseminerande",
    "inseminerandes": "inseminerande",
    "inseminerandet": "inseminerande",
    "inseminerandets": "inseminerande",
    "inseminerar": "inseminera",
    "insemineras": "inseminera",
    "inseminerat": "inseminera",
    "inseminerats": "inseminera",
    "inseminerbara": "inseminerbar",
    "inseminerbarare": "inseminerbar",
    "inseminerbarares": "inseminerbar",
    "inseminerbaras": "inseminerbar",
    "inseminerbarast": "inseminerbar",
    "inseminerbaraste": "inseminerbar",
    "inseminerbarastes": "inseminerbar",
    "inseminerbarasts": "inseminerbar",
    "inseminerbare": "inseminerbar",
    "inseminerbares": "inseminerbar",
    "inseminerbarheten": "inseminerbarhet",
    "inseminerbarhetens": "inseminerbarhet",
    "inseminerbarhets": "inseminerbarhet",
    "inseminerbars": "inseminerbar",
    "inseminerbart": "inseminerbar",
    "inseminerbarts": "inseminerbar",
    "insemineringar": "inseminering",
    "insemineringarna": "inseminering",
    "insemineringarnas": "inseminering",
    "insemineringars": "inseminering",
    "insemineringen": "inseminering",
    "insemineringens": "inseminering",
    "inseminerings": "inseminering",
    "inser": "inse",
    "inses": "inse",
    "insett": "inse",
    "insetts": "inse",
    "insidan": "insida",
    "insidans": "insida",
    "insidas": "insida",
    "inside": "insida",
    "insidermålen": "insidermål",
    "insidermålens": "insidermål",
    "insidermålet": "insidermål",
    "insidermålets": "insidermål",
    "insidermåls": "insidermål",
    "insidern": "insider",
    "insiderns": "insider",
    "insiders": "insider",
    "insidersarna": "insider",
    "insidersarnas": "insider",
    "insidersen": "insider",
    "insidersens": "insider",
    "insideråtalen": "insideråtal",
    "insideråtalens": "insideråtal",
    "insideråtalet": "insideråtal",
    "insideråtalets": "insideråtal",
    "insideråtals": "insideråtal",
    "insides": "insida",
    "insidor": "insida",
    "insidorna": "insida",
    "insidornas": "insida",
    "insidors": "insida",
    "insidrar": "insider",
    "insidrarna": "insider",
    "insidrarnas": "insider",
    "insidrars": "insider",
    "insignie": "insignier",
    "insignierna": "insignier",
    "insigniernas": "insignier",
    "insigniers": "insignier",
    "insikten": "insikt",
    "insiktens": "insikt",
    "insikter": "insikt",
    "insikterna": "insikt",
    "insikternas": "insikt",
    "insikters": "insikt",
    "insikts": "insikt",
    "insiktsfulla": "insiktsfull",
    "insiktsfullare": "insiktsfull",
    "insiktsfullares": "insiktsfull",
    "insiktsfullas": "insiktsfull",
    "insiktsfullast": "insiktsfull",
    "insiktsfullaste": "insiktsfull",
    "insiktsfullastes": "insiktsfull",
    "insiktsfullasts": "insiktsfull",
    "insiktsfulle": "insiktsfull",
    "insiktsfulles": "insiktsfull",
    "insiktsfullheten": "insiktsfullhet",
    "insiktsfullhetens": "insiktsfullhet",
    "insiktsfullhets": "insiktsfullhet",
    "insiktsfulls": "insiktsfull",
    "insiktsfullt": "insiktsfull",
    "insiktsfullts": "insiktsfull",
    "insinuanta": "insinuant",
    "insinuantare": "insinuant",
    "insinuantares": "insinuant",
    "insinuantas": "insinuant",
    "insinuantast": "insinuant",
    "insinuantaste": "insinuant",
    "insinuantastes": "insinuant",
    "insinuantasts": "insinuant",
    "insinuante": "insinuant",
    "insinuantes": "insinuant",
    "insinuants": "insinuant",
    "insinuationen": "insinuation",
    "insinuationens": "insinuation",
    "insinuationer": "insinuation",
    "insinuationerna": "insinuation",
    "insinuationernas": "insinuation",
    "insinuationers": "insinuation",
    "insinuations": "insinuation",
    "insinuerad": "insinuera",
    "insinuerade": "insinuera",
    "insinuerades": "insinuera",
    "insinuerads": "insinuera",
    "insinuerande": "insinuera",
    "insinueranden": "insinuerande",
    "insinuerandena": "insinuerande",
    "insinuerandenas": "insinuerande",
    "insinuerandens": "insinuerande",
    "insinuerandes": "insinuerande",
    "insinuerandet": "insinuerande",
    "insinuerandets": "insinuerande",
    "insinuerar": "insinuera",
    "insinueras": "insinuera",
    "insinuerat": "insinuera",
    "insinuerats": "insinuera",
    "insinuerbara": "insinuerbar",
    "insinuerbarare": "insinuerbar",
    "insinuerbarares": "insinuerbar",
    "insinuerbaras": "insinuerbar",
    "insinuerbarast": "insinuerbar",
    "insinuerbaraste": "insinuerbar",
    "insinuerbarastes": "insinuerbar",
    "insinuerbarasts": "insinuerbar",
    "insinuerbare": "insinuerbar",
    "insinuerbares": "insinuerbar",
    "insinuerbarheten": "insinuerbarhet",
    "insinuerbarhetens": "insinuerbarhet",
    "insinuerbarhets": "insinuerbarhet",
    "insinuerbars": "insinuerbar",
    "insinuerbart": "insinuerbar",
    "insinuerbarts": "insinuerbar",
    "insinueringar": "insinuering",
    "insinueringarna": "insinuering",
    "insinueringarnas": "insinuering",
    "insinueringars": "insinuering",
    "insinueringen": "insinuering",
    "insinueringens": "insinuering",
    "insinuerings": "insinuering",
    "insisterad": "insistera",
    "insisterade": "insistera",
    "insisterades": "insistera",
    "insisterads": "insistera",
    "insisterande": "insistera",
    "insisteranden": "insisterande",
    "insisterandena": "insisterande",
    "insisterandenas": "insisterande",
    "insisterandens": "insisterande",
    "insisterandes": "insisterande",
    "insisterandet": "insisterande",
    "insisterandets": "insisterande",
    "insisterar": "insistera",
    "insisteras": "insistera",
    "insisterat": "insistera",
    "insisterats": "insistera",
    "insisteringar": "insistering",
    "insisteringarna": "insistering",
    "insisteringarnas": "insistering",
    "insisteringars": "insistering",
    "insisteringen": "insistering",
    "insisteringens": "insistering",
    "insisterings": "insistering",
    "insjukn": "insjukna",
    "insjuknad": "insjukna",
    "insjuknade": "insjukna",
    "insjuknades": "insjukna",
    "insjuknads": "insjukna",
    "insjuknande": "insjukna",
    "insjuknanden": "insjuknande",
    "insjuknandena": "insjuknande",
    "insjuknandenas": "insjuknande",
    "insjuknandens": "insjuknande",
    "insjuknandes": "insjuknande",
    "insjuknandet": "insjuknande",
    "insjuknandets": "insjuknande",
    "insjuknar": "insjukna",
    "insjuknas": "insjukna",
    "insjuknat": "insjukna",
    "insjuknats": "insjukna",
    "insjungningar": "insjungning",
    "insjungningarna": "insjungning",
    "insjungningarnas": "insjungning",
    "insjungningars": "insjungning",
    "insjungningen": "insjungning",
    "insjungningens": "insjungning",
    "insjungnings": "insjungning",
    "insjunkens": "insjunken",
    "insjunket": "insjunken",
    "insjunkets": "insjunken",
    "insjunkna": "insjunken",
    "insjunknare": "insjunken",
    "insjunknares": "insjunken",
    "insjunknas": "insjunken",
    "insjunknast": "insjunken",
    "insjunknaste": "insjunken",
    "insjunknastes": "insjunken",
    "insjunknasts": "insjunken",
    "insjunkne": "insjunken",
    "insjunknes": "insjunken",
    "insjöar": "insjö",
    "insjöarna": "insjö",
    "insjöarnas": "insjö",
    "insjöars": "insjö",
    "insjöfiskar": "insjöfisk",
    "insjöfiskarna": "insjöfisk",
    "insjöfiskarnas": "insjöfisk",
    "insjöfiskars": "insjöfisk",
    "insjöfisken": "insjöfisk",
    "insjöfiskens": "insjöfisk",
    "insjöfiskes": "insjöfiske",
    "insjöfisket": "insjöfiske",
    "insjöfiskets": "insjöfiske",
    "insjöfisks": "insjöfisk",
    "insjön": "insjö",
    "insjöns": "insjö",
    "insjös": "insjö",
    "inskaffad": "inskaffa",
    "inskaffade": "inskaffa",
    "inskaffades": "inskaffa",
    "inskaffads": "inskaffa",
    "inskaffande": "inskaffa",
    "inskaffandes": "inskaffa",
    "inskaffar": "inskaffa",
    "inskaffas": "inskaffa",
    "inskaffat": "inskaffa",
    "inskaffats": "inskaffa",
    "inskepp": "inskeppa",
    "inskeppad": "inskeppa",
    "inskeppade": "inskeppa",
    "inskeppades": "inskeppa",
    "inskeppads": "inskeppa",
    "inskeppande": "inskeppa",
    "inskeppanden": "inskeppande",
    "inskeppandena": "inskeppande",
    "inskeppandenas": "inskeppande",
    "inskeppandens": "inskeppande",
    "inskeppandes": "inskeppande",
    "inskeppandet": "inskeppande",
    "inskeppandets": "inskeppande",
    "inskeppar": "inskeppa",
    "inskeppas": "inskeppa",
    "inskeppat": "inskeppa",
    "inskeppats": "inskeppa",
    "inskjut": "inskjuta",
    "inskjutande": "inskjuta",
    "inskjutanden": "inskjutande",
    "inskjutandena": "inskjutande",
    "inskjutandenas": "inskjutande",
    "inskjutandens": "inskjutande",
    "inskjutandes": "inskjutande",
    "inskjutandet": "inskjutande",
    "inskjutandets": "inskjutande",
    "inskjutas": "inskjuta",
    "inskjute": "inskjuta",
    "inskjuten": "inskjuta",
    "inskjutens": "inskjuta",
    "inskjuter": "inskjuta",
    "inskjutes": "inskjuta",
    "inskjutet": "inskjuta",
    "inskjutets": "inskjuta",
    "inskjutit": "inskjuta",
    "inskjutits": "inskjuta",
    "inskjutna": "inskjuta",
    "inskjutnas": "inskjuta",
    "inskjutne": "inskjuta",
    "inskjutnes": "inskjuta",
    "inskjutningar": "inskjutning",
    "inskjutningarna": "inskjutning",
    "inskjutningarnas": "inskjutning",
    "inskjutningars": "inskjutning",
    "inskjutningen": "inskjutning",
    "inskjutningens": "inskjutning",
    "inskjutnings": "inskjutning",
    "inskjuts": "inskjuta",
    "inskol": "inskola",
    "inskolad": "inskola",
    "inskolade": "inskola",
    "inskolades": "inskola",
    "inskolads": "inskola",
    "inskolande": "inskola",
    "inskolanden": "inskolande",
    "inskolandena": "inskolande",
    "inskolandenas": "inskolande",
    "inskolandens": "inskolande",
    "inskolandes": "inskolande",
    "inskolandet": "inskolande",
    "inskolandets": "inskolande",
    "inskolar": "inskola",
    "inskolas": "inskola",
    "inskolat": "inskola",
    "inskolats": "inskola",
    "inskolningar": "inskolning",
    "inskolningarna": "inskolning",
    "inskolningarnas": "inskolning",
    "inskolningars": "inskolning",
    "inskolningen": "inskolning",
    "inskolningens": "inskolning",
    "inskolnings": "inskolning",
    "inskotten": "inskott",
    "inskottens": "inskott",
    "inskottet": "inskott",
    "inskottets": "inskott",
    "inskotts": "inskott",
    "inskottsvokalen": "inskottsvokal",
    "inskottsvokalens": "inskottsvokal",
    "inskottsvokaler": "inskottsvokal",
    "inskottsvokalerna": "inskottsvokal",
    "inskottsvokalernas": "inskottsvokal",
    "inskottsvokalers": "inskottsvokal",
    "inskottsvokals": "inskottsvokal",
    "inskred": "inskrida",
    "inskreds": "inskrida",
    "inskrev": "inskriva",
    "inskrevs": "inskriva",
    "inskrid": "inskrida",
    "inskridande": "inskrida",
    "inskridanden": "inskridande",
    "inskridandena": "inskridande",
    "inskridandenas": "inskridande",
    "inskridandens": "inskridande",
    "inskridandes": "inskridande",
    "inskridandet": "inskridande",
    "inskridandets": "inskridande",
    "inskridas": "inskrida",
    "inskride": "inskrida",
    "inskrider": "inskrida",
    "inskrides": "inskrida",
    "inskridit": "inskrida",
    "inskridits": "inskrida",
    "inskrids": "inskrida",
    "inskriften": "inskrift",
    "inskriftens": "inskrift",
    "inskrifter": "inskrift",
    "inskrifterna": "inskrift",
    "inskrifternas": "inskrift",
    "inskrifters": "inskrift",
    "inskrifts": "inskrift",
    "inskriptionen": "inskription",
    "inskriptionens": "inskription",
    "inskriptioner": "inskription",
    "inskriptionerna": "inskription",
    "inskriptionernas": "inskription",
    "inskriptioners": "inskription",
    "inskriptions": "inskription",
    "inskriv": "inskriva",
    "inskrivande": "inskriva",
    "inskrivanden": "inskrivande",
    "inskrivandena": "inskrivande",
    "inskrivandenas": "inskrivande",
    "inskrivandens": "inskrivande",
    "inskrivandes": "inskrivande",
    "inskrivandet": "inskrivande",
    "inskrivandets": "inskrivande",
    "inskrivas": "inskriva",
    "inskrive": "inskriva",
    "inskriven": "inskriva",
    "inskrivens": "inskriva",
    "inskriver": "inskriva",
    "inskrives": "inskriva",
    "inskrivet": "inskriva",
    "inskrivets": "inskriva",
    "inskrivit": "inskriva",
    "inskrivits": "inskriva",
    "inskrivna": "inskriva",
    "inskrivnas": "inskriva",
    "inskrivne": "inskriva",
    "inskrivnes": "inskriva",
    "inskrivningar": "inskrivning",
    "inskrivningarna": "inskrivning",
    "inskrivningarnas": "inskrivning",
    "inskrivningars": "inskrivning",
    "inskrivningen": "inskrivning",
    "inskrivningens": "inskrivning",
    "inskrivnings": "inskrivning",
    "inskrivningsboken": "inskrivningsbok",
    "inskrivningsbokens": "inskrivningsbok",
    "inskrivningsboks": "inskrivningsbok",
    "inskrivningsböcker": "inskrivningsbok",
    "inskrivningsböckerna": "inskrivningsbok",
    "inskrivningsböckernas": "inskrivningsbok",
    "inskrivningsböckers": "inskrivningsbok",
    "inskrivningsdomar": "inskrivningsdomare",
    "inskrivningsdomaren": "inskrivningsdomare",
    "inskrivningsdomarens": "inskrivningsdomare",
    "inskrivningsdomares": "inskrivningsdomare",
    "inskrivningsdomarna": "inskrivningsdomare",
    "inskrivningsdomarnas": "inskrivningsdomare",
    "inskrivs": "inskriva",
    "inskränk": "inskränka",
    "inskränkande": "inskränka",
    "inskränkanden": "inskränkande",
    "inskränkandena": "inskränkande",
    "inskränkandenas": "inskränkande",
    "inskränkandens": "inskränkande",
    "inskränkandes": "inskränkande",
    "inskränkandet": "inskränkande",
    "inskränkandets": "inskränkande",
    "inskränkas": "inskränka",
    "inskränker": "inskränka",
    "inskränkes": "inskränka",
    "inskränkningar": "inskränkning",
    "inskränkningarna": "inskränkning",
    "inskränkningarnas": "inskränkning",
    "inskränkningars": "inskränkning",
    "inskränkningen": "inskränkning",
    "inskränkningens": "inskränkning",
    "inskränknings": "inskränkning",
    "inskränks": "inskränka",
    "inskränkt": "inskränka",
    "inskränkta": "inskränkt",
    "inskränktare": "inskränkt",
    "inskränktares": "inskränkt",
    "inskränktas": "inskränkt",
    "inskränktast": "inskränkt",
    "inskränktaste": "inskränkt",
    "inskränktastes": "inskränkt",
    "inskränktasts": "inskränkt",
    "inskränkte": "inskränkt",
    "inskränktes": "inskränkt",
    "inskränktheten": "inskränkthet",
    "inskränkthetens": "inskränkthet",
    "inskränktheter": "inskränkthet",
    "inskränktheterna": "inskränkthet",
    "inskränktheternas": "inskränkthet",
    "inskränktheters": "inskränkthet",
    "inskränkthets": "inskränkthet",
    "inskränkts": "inskränkt",
    "inskärningar": "inskärning",
    "inskärningarna": "inskärning",
    "inskärningarnas": "inskärning",
    "inskärningars": "inskärning",
    "inskärningen": "inskärning",
    "inskärningens": "inskärning",
    "inskärnings": "inskärning",
    "inskärp": "inskärpa",
    "inskärpande": "inskärpa",
    "inskärpanden": "inskärpande",
    "inskärpandena": "inskärpande",
    "inskärpandenas": "inskärpande",
    "inskärpandens": "inskärpande",
    "inskärpandes": "inskärpande",
    "inskärpandet": "inskärpande",
    "inskärpandets": "inskärpande",
    "inskärpas": "inskärpa",
    "inskärper": "inskärpa",
    "inskärpes": "inskärpa",
    "inskärps": "inskärpa",
    "inskärpt": "inskärpa",
    "inskärpta": "inskärpa",
    "inskärptas": "inskärpa",
    "inskärpte": "inskärpa",
    "inskärptes": "inskärpa",
    "inskärpts": "inskärpa",
    "insköt": "inskjuta",
    "insköte": "inskjuta",
    "inskötes": "inskjuta",
    "insköts": "inskjuta",
    "inslagen": "inslag",
    "inslagens": "inslagen",
    "inslaget": "inslagen",
    "inslagets": "inslagen",
    "inslagna": "inslagen",
    "inslagnare": "inslagen",
    "inslagnares": "inslagen",
    "inslagnas": "inslagen",
    "inslagnast": "inslagen",
    "inslagnaste": "inslagen",
    "inslagnastes": "inslagen",
    "inslagnasts": "inslagen",
    "inslagne": "inslagen",
    "inslagnes": "inslagen",
    "inslags": "inslag",
    "inslussade": "inslussad",
    "inslussades": "inslussad",
    "inslussads": "inslussad",
    "inslussat": "inslussad",
    "inslussats": "inslussad",
    "insläpade": "insläpad",
    "insläpades": "insläpad",
    "insläpads": "insläpad",
    "insläpat": "insläpad",
    "insläpats": "insläpad",
    "insläppen": "insläpp",
    "insläppens": "insläpp",
    "insläppet": "insläpp",
    "insläppets": "insläpp",
    "insläpps": "insläpp",
    "insmugen": "insmyga",
    "insmugens": "insmyga",
    "insmuget": "insmyga",
    "insmugets": "insmyga",
    "insmugglade": "insmugglad",
    "insmugglades": "insmugglad",
    "insmugglads": "insmugglad",
    "insmugglat": "insmugglad",
    "insmugglats": "insmugglad",
    "insmugglingar": "insmuggling",
    "insmugglingarna": "insmuggling",
    "insmugglingarnas": "insmuggling",
    "insmugglingars": "insmuggling",
    "insmugglingen": "insmuggling",
    "insmugglingens": "insmuggling",
    "insmugglings": "insmuggling",
    "insmugit": "insmyga",
    "insmugits": "insmyga",
    "insmugna": "insmyga",
    "insmugnas": "insmyga",
    "insmugne": "insmyga",
    "insmugnes": "insmyga",
    "insmyg": "insmyga",
    "insmygande": "insmyga",
    "insmyganden": "insmygande",
    "insmygandena": "insmygande",
    "insmygandenas": "insmygande",
    "insmygandens": "insmygande",
    "insmygandes": "insmygande",
    "insmygandet": "insmygande",
    "insmygandets": "insmygande",
    "insmygas": "insmyga",
    "insmyge": "insmyga",
    "insmyger": "insmyga",
    "insmyges": "insmyga",
    "insmygs": "insmyga",
    "insmält": "insmälta",
    "insmältande": "insmälta",
    "insmältanden": "insmältande",
    "insmältandena": "insmältande",
    "insmältandenas": "insmältande",
    "insmältandens": "insmältande",
    "insmältandes": "insmältande",
    "insmältandet": "insmältande",
    "insmältandets": "insmältande",
    "insmältas": "insmälta",
    "insmälte": "insmälta",
    "insmälter": "insmälta",
    "insmältes": "insmälta",
    "insmälts": "insmälta",
    "insmög": "insmyga",
    "insmöge": "insmyga",
    "insmöges": "insmyga",
    "insmögs": "insmyga",
    "insnitten": "insnitt",
    "insnittens": "insnitt",
    "insnittet": "insnitt",
    "insnittets": "insnitt",
    "insnitts": "insnitt",
    "insnodda": "insnodd",
    "insnoddare": "insnodd",
    "insnoddares": "insnodd",
    "insnoddas": "insnodd",
    "insnoddast": "insnodd",
    "insnoddaste": "insnodd",
    "insnoddastes": "insnodd",
    "insnoddasts": "insnodd",
    "insnodde": "insnodd",
    "insnoddes": "insnodd",
    "insnodds": "insnodd",
    "insnott": "insnodd",
    "insnotts": "insnodd",
    "insnärjde": "insnärjd",
    "insnärjdes": "insnärjd",
    "insnärjds": "insnärjd",
    "insnärjt": "insnärjd",
    "insnärjts": "insnärjd",
    "insnöade": "insnöad",
    "insnöades": "insnöad",
    "insnöads": "insnöad",
    "insnöat": "insnöad",
    "insnöats": "insnöad",
    "insolationen": "insolation",
    "insolationens": "insolation",
    "insolationer": "insolation",
    "insolationerna": "insolation",
    "insolationernas": "insolation",
    "insolationers": "insolation",
    "insolations": "insolation",
    "insolvensen": "insolvens",
    "insolvensens": "insolvens",
    "insolventa": "insolvent",
    "insolventare": "insolvent",
    "insolventares": "insolvent",
    "insolventas": "insolvent",
    "insolventast": "insolvent",
    "insolventaste": "insolvent",
    "insolventastes": "insolvent",
    "insolventasts": "insolvent",
    "insolvente": "insolvent",
    "insolventes": "insolvent",
    "insolvents": "insolvent",
    "insomn": "insomna",
    "insomnad": "insomna",
    "insomnade": "insomna",
    "insomnades": "insomna",
    "insomnads": "insomna",
    "insomnande": "insomna",
    "insomnanden": "insomnande",
    "insomnandena": "insomnande",
    "insomnandenas": "insomnande",
    "insomnandens": "insomnande",
    "insomnandes": "insomnande",
    "insomnandet": "insomnande",
    "insomnandets": "insomnande",
    "insomnar": "insomna",
    "insomnas": "insomna",
    "insomnat": "insomna",
    "insomnats": "insomna",
    "insomningsdrömmar": "insomningsdröm",
    "insomningsdrömmarna": "insomningsdröm",
    "insomningsdrömmarnas": "insomningsdröm",
    "insomningsdrömmars": "insomningsdröm",
    "insomningsdrömmen": "insomningsdröm",
    "insomningsdrömmens": "insomningsdröm",
    "insomningsdröms": "insomningsdröm",
    "insparkar": "inspark",
    "insparkarna": "inspark",
    "insparkarnas": "inspark",
    "insparkars": "inspark",
    "insparken": "inspark",
    "insparkens": "inspark",
    "insparks": "inspark",
    "inspekterad": "inspektera",
    "inspekterade": "inspektera",
    "inspekterades": "inspektera",
    "inspekterads": "inspektera",
    "inspekterande": "inspektera",
    "inspekteranden": "inspekterande",
    "inspekterandena": "inspekterande",
    "inspekterandenas": "inspekterande",
    "inspekterandens": "inspekterande",
    "inspekterandes": "inspekterande",
    "inspekterandet": "inspekterande",
    "inspekterandets": "inspekterande",
    "inspekterar": "inspektera",
    "inspekteras": "inspektera",
    "inspekterat": "inspektera",
    "inspekterats": "inspektera",
    "inspekterbara": "inspekterbar",
    "inspekterbarare": "inspekterbar",
    "inspekterbarares": "inspekterbar",
    "inspekterbaras": "inspekterbar",
    "inspekterbarast": "inspekterbar",
    "inspekterbaraste": "inspekterbar",
    "inspekterbarastes": "inspekterbar",
    "inspekterbarasts": "inspekterbar",
    "inspekterbare": "inspekterbar",
    "inspekterbares": "inspekterbar",
    "inspekterbarheten": "inspekterbarhet",
    "inspekterbarhetens": "inspekterbarhet",
    "inspekterbarhets": "inspekterbarhet",
    "inspekterbars": "inspekterbar",
    "inspekterbart": "inspekterbar",
    "inspekterbarts": "inspekterbar",
    "inspekteringar": "inspektering",
    "inspekteringarna": "inspektering",
    "inspekteringarnas": "inspektering",
    "inspekteringars": "inspektering",
    "inspekteringen": "inspektering",
    "inspekteringens": "inspektering",
    "inspekterings": "inspektering",
    "inspektionen": "inspektion",
    "inspektionens": "inspektion",
    "inspektioner": "inspektion",
    "inspektionerna": "inspektion",
    "inspektionernas": "inspektion",
    "inspektioners": "inspektion",
    "inspektions": "inspektion",
    "inspektorer": "inspektor",
    "inspektorerna": "inspektor",
    "inspektorernas": "inspektor",
    "inspektorers": "inspektor",
    "inspektorn": "inspektor",
    "inspektorns": "inspektor",
    "inspektors": "inspektor",
    "inspektören": "inspektör",
    "inspektörens": "inspektör",
    "inspektörer": "inspektör",
    "inspektörerna": "inspektör",
    "inspektörernas": "inspektör",
    "inspektörers": "inspektör",
    "inspektörn": "inspektör",
    "inspektörns": "inspektör",
    "inspektörs": "inspektör",
    "inspel": "inspela",
    "inspelad": "inspela",
    "inspelade": "inspela",
    "inspelades": "inspela",
    "inspelads": "inspela",
    "inspelande": "inspela",
    "inspelanden": "inspelande",
    "inspelandena": "inspelande",
    "inspelandenas": "inspelande",
    "inspelandens": "inspelande",
    "inspelandes": "inspelande",
    "inspelandet": "inspelande",
    "inspelandets": "inspelande",
    "inspelar": "inspela",
    "inspelas": "inspela",
    "inspelat": "inspela",
    "inspelats": "inspela",
    "inspelningar": "inspelning",
    "inspelningarna": "inspelning",
    "inspelningarnas": "inspelning",
    "inspelningars": "inspelning",
    "inspelningen": "inspelning",
    "inspelningens": "inspelning",
    "inspelnings": "inspelning",
    "inspelningsknappar": "inspelningsknapp",
    "inspelningsknapparna": "inspelningsknapp",
    "inspelningsknapparnas": "inspelningsknapp",
    "inspelningsknappars": "inspelningsknapp",
    "inspelningsknappen": "inspelningsknapp",
    "inspelningsknappens": "inspelningsknapp",
    "inspelningsknapps": "inspelningsknapp",
    "inspelningsstudion": "inspelningsstudio",
    "inspelningsstudions": "inspelningsstudio",
    "inspelningsstudior": "inspelningsstudio",
    "inspelningsstudiorna": "inspelningsstudio",
    "inspelningsstudiornas": "inspelningsstudio",
    "inspelningsstudiors": "inspelningsstudio",
    "inspelningsstudios": "inspelningsstudio",
    "inspicienten": "inspicient",
    "inspicientens": "inspicient",
    "inspicienter": "inspicient",
    "inspicienterna": "inspicient",
    "inspicienternas": "inspicient",
    "inspicienters": "inspicient",
    "inspicients": "inspicient",
    "inspirationen": "inspiration",
    "inspirationens": "inspiration",
    "inspirationer": "inspiration",
    "inspirationerna": "inspiration",
    "inspirationernas": "inspiration",
    "inspirationers": "inspiration",
    "inspirations": "inspiration",
    "inspirationskäll": "inspirationskälla",
    "inspirationskällan": "inspirationskälla",
    "inspirationskällans": "inspirationskälla",
    "inspirationskällas": "inspirationskälla",
    "inspirationskälle": "inspirationskälla",
    "inspirationskällor": "inspirationskälla",
    "inspirationskällorna": "inspirationskälla",
    "inspirationskällornas": "inspirationskälla",
    "inspirationskällors": "inspirationskälla",
    "inspirationskälls": "inspirationskälla",
    "inspirationsmässiga": "inspirationsmässig",
    "inspirationsmässigare": "inspirationsmässig",
    "inspirationsmässigares": "inspirationsmässig",
    "inspirationsmässigas": "inspirationsmässig",
    "inspirationsmässigast": "inspirationsmässig",
    "inspirationsmässigaste": "inspirationsmässig",
    "inspirationsmässigastes": "inspirationsmässig",
    "inspirationsmässigasts": "inspirationsmässig",
    "inspirationsmässige": "inspirationsmässig",
    "inspirationsmässiges": "inspirationsmässig",
    "inspirationsmässigs": "inspirationsmässig",
    "inspirationsmässigt": "inspirationsmässig",
    "inspirationsmässigts": "inspirationsmässig",
    "inspiratören": "inspiratör",
    "inspiratörens": "inspiratör",
    "inspiratörer": "inspiratör",
    "inspiratörerna": "inspiratör",
    "inspiratörernas": "inspiratör",
    "inspiratörers": "inspiratör",
    "inspiratörs": "inspiratör",
    "inspirerad": "inspirera",
    "inspirerade": "inspirerad",
    "inspirerades": "inspirerad",
    "inspirerads": "inspirerad",
    "inspirerande": "inspirera",
    "inspireranden": "inspirerande",
    "inspirerandena": "inspirerande",
    "inspirerandenas": "inspirerande",
    "inspirerandens": "inspirerande",
    "inspirerandes": "inspirerande",
    "inspirerandet": "inspirerande",
    "inspirerandets": "inspirerande",
    "inspirerar": "inspirera",
    "inspireras": "inspirera",
    "inspirerat": "inspirerad",
    "inspirerats": "inspirerad",
    "inspirerbara": "inspirerbar",
    "inspirerbarare": "inspirerbar",
    "inspirerbarares": "inspirerbar",
    "inspirerbaras": "inspirerbar",
    "inspirerbarast": "inspirerbar",
    "inspirerbaraste": "inspirerbar",
    "inspirerbarastes": "inspirerbar",
    "inspirerbarasts": "inspirerbar",
    "inspirerbare": "inspirerbar",
    "inspirerbares": "inspirerbar",
    "inspirerbarheten": "inspirerbarhet",
    "inspirerbarhetens": "inspirerbarhet",
    "inspirerbarhets": "inspirerbarhet",
    "inspirerbars": "inspirerbar",
    "inspirerbart": "inspirerbar",
    "inspirerbarts": "inspirerbar",
    "inspireringar": "inspirering",
    "inspireringarna": "inspirering",
    "inspireringarnas": "inspirering",
    "inspireringars": "inspirering",
    "inspireringen": "inspirering",
    "inspireringens": "inspirering",
    "inspirerings": "inspirering",
    "insprutningar": "insprutning",
    "insprutningarna": "insprutning",
    "insprutningarnas": "insprutning",
    "insprutningars": "insprutning",
    "insprutningen": "insprutning",
    "insprutningens": "insprutning",
    "insprutnings": "insprutning",
    "insprutningsmotorer": "insprutningsmotor",
    "insprutningsmotorerna": "insprutningsmotor",
    "insprutningsmotorernas": "insprutningsmotor",
    "insprutningsmotorers": "insprutningsmotor",
    "insprutningsmotorn": "insprutningsmotor",
    "insprutningsmotorns": "insprutningsmotor",
    "insprutningsmotors": "insprutningsmotor",
    "insprutningsmunstycken": "insprutningsmunstycke",
    "insprutningsmunstyckena": "insprutningsmunstycke",
    "insprutningsmunstyckenas": "insprutningsmunstycke",
    "insprutningsmunstyckens": "insprutningsmunstycke",
    "insprutningsmunstyckes": "insprutningsmunstycke",
    "insprutningsmunstycket": "insprutningsmunstycke",
    "insprutningsmunstyckets": "insprutningsmunstycke",
    "insprutningsmunstycks": "insprutningsmunstycke",
    "insprängda": "insprängd",
    "insprängdare": "insprängd",
    "insprängdares": "insprängd",
    "insprängdas": "insprängd",
    "insprängdast": "insprängd",
    "insprängdaste": "insprängd",
    "insprängdastes": "insprängd",
    "insprängdasts": "insprängd",
    "insprängde": "insprängd",
    "insprängdes": "insprängd",
    "insprängds": "insprängd",
    "insprängt": "insprängd",
    "insprängts": "insprängd",
    "inspärr": "inspärra",
    "inspärrade": "inspärra",
    "inspärrades": "inspärra",
    "inspärrande": "inspärra",
    "inspärranden": "inspärrande",
    "inspärrandena": "inspärrande",
    "inspärrandenas": "inspärrande",
    "inspärrandens": "inspärrande",
    "inspärrandes": "inspärrande",
    "inspärrandet": "inspärrande",
    "inspärrandets": "inspärrande",
    "inspärrar": "inspärra",
    "inspärras": "inspärra",
    "inspärrat": "inspärra",
    "inspärrats": "inspärra",
    "instabila": "instabil",
    "instabilare": "instabil",
    "instabilares": "instabil",
    "instabilas": "instabil",
    "instabilast": "instabil",
    "instabilaste": "instabil",
    "instabilastes": "instabil",
    "instabilasts": "instabil",
    "instabile": "instabil",
    "instabiles": "instabil",
    "instabiliteten": "instabilitet",
    "instabilitetens": "instabilitet",
    "instabiliteter": "instabilitet",
    "instabiliteterna": "instabilitet",
    "instabiliteternas": "instabilitet",
    "instabiliteters": "instabilitet",
    "instabilitets": "instabilitet",
    "instabils": "instabil",
    "instabilt": "instabil",
    "instabilts": "instabil",
    "installanden": "installand",
    "installandens": "installand",
    "installander": "installand",
    "installanderna": "installand",
    "installandernas": "installand",
    "installanders": "installand",
    "installands": "installand",
    "installationen": "installation",
    "installationens": "installation",
    "installationer": "installation",
    "installationerna": "installation",
    "installationernas": "installation",
    "installationers": "installation",
    "installations": "installation",
    "installationsföreläsningar": "installationsföreläsning",
    "installationsföreläsningarna": "installationsföreläsning",
    "installationsföreläsningarnas": "installationsföreläsning",
    "installationsföreläsningars": "installationsföreläsning",
    "installationsföreläsningen": "installationsföreläsning",
    "installationsföreläsningens": "installationsföreläsning",
    "installationsföreläsnings": "installationsföreläsning",
    "installationskabeln": "installationskabel",
    "installationskabelns": "installationskabel",
    "installationskabels": "installationskabel",
    "installationskablar": "installationskabel",
    "installationskablarna": "installationskabel",
    "installationskablarnas": "installationskabel",
    "installationskablars": "installationskabel",
    "installationstalen": "installationstal",
    "installationstalens": "installationstal",
    "installationstalet": "installationstal",
    "installationstalets": "installationstal",
    "installationstals": "installationstal",
    "installatorer": "installator",
    "installatorerna": "installator",
    "installatorernas": "installator",
    "installatorers": "installator",
    "installatorn": "installator",
    "installatorns": "installator",
    "installators": "installator",
    "installatören": "installatör",
    "installatörens": "installatör",
    "installatörer": "installatör",
    "installatörerna": "installatör",
    "installatörernas": "installatör",
    "installatörers": "installatör",
    "installatörs": "installatör",
    "installerad": "installera",
    "installerade": "installera",
    "installerades": "installera",
    "installerads": "installera",
    "installerande": "installera",
    "installeranden": "installerande",
    "installerandena": "installerande",
    "installerandenas": "installerande",
    "installerandens": "installerande",
    "installerandes": "installerande",
    "installerandet": "installerande",
    "installerandets": "installerande",
    "installerar": "installera",
    "installeras": "installera",
    "installerat": "installera",
    "installerats": "installera",
    "installerbara": "installerbar",
    "installerbarare": "installerbar",
    "installerbarares": "installerbar",
    "installerbaras": "installerbar",
    "installerbarast": "installerbar",
    "installerbaraste": "installerbar",
    "installerbarastes": "installerbar",
    "installerbarasts": "installerbar",
    "installerbare": "installerbar",
    "installerbares": "installerbar",
    "installerbarheten": "installerbarhet",
    "installerbarhetens": "installerbarhet",
    "installerbarhets": "installerbarhet",
    "installerbars": "installerbar",
    "installerbart": "installerbar",
    "installerbarts": "installerbar",
    "installeringar": "installering",
    "installeringarna": "installering",
    "installeringarnas": "installering",
    "installeringars": "installering",
    "installeringen": "installering",
    "installeringens": "installering",
    "installerings": "installering",
    "instansen": "instans",
    "instansens": "instans",
    "instanser": "instans",
    "instanserna": "instans",
    "instansernas": "instans",
    "instansers": "instans",
    "instegs": "insteg",
    "instift": "instifta",
    "instiftad": "instifta",
    "instiftade": "instifta",
    "instiftades": "instifta",
    "instiftads": "instifta",
    "instiftande": "instifta",
    "instiftanden": "instiftande",
    "instiftandena": "instiftande",
    "instiftandenas": "instiftande",
    "instiftandens": "instiftande",
    "instiftandes": "instiftande",
    "instiftandet": "instiftande",
    "instiftandets": "instiftande",
    "instiftar": "instiftare",
    "instiftaren": "instiftare",
    "instiftarens": "instiftare",
    "instiftares": "instiftare",
    "instiftarna": "instiftare",
    "instiftarnas": "instiftare",
    "instiftas": "instifta",
    "instiftat": "instifta",
    "instiftats": "instifta",
    "instiftelsen": "instiftelse",
    "instiftelsens": "instiftelse",
    "instiftelser": "instiftelse",
    "instiftelserna": "instiftelse",
    "instiftelsernas": "instiftelse",
    "instiftelsers": "instiftelse",
    "instiftelses": "instiftelse",
    "instinkten": "instinkt",
    "instinktens": "instinkt",
    "instinkter": "instinkt",
    "instinkterna": "instinkt",
    "instinkternas": "instinkt",
    "instinkters": "instinkt",
    "instinktiva": "instinktiv",
    "instinktivare": "instinktiv",
    "instinktivares": "instinktiv",
    "instinktivas": "instinktiv",
    "instinktivast": "instinktiv",
    "instinktivaste": "instinktiv",
    "instinktivastes": "instinktiv",
    "instinktivasts": "instinktiv",
    "instinktive": "instinktiv",
    "instinktives": "instinktiv",
    "instinktivs": "instinktiv",
    "instinktivt": "instinktiv",
    "instinktivts": "instinktiv",
    "instinktlivet": "instinktliv",
    "instinktlivets": "instinktliv",
    "instinktlivs": "instinktliv",
    "instinktmässiga": "instinktmässig",
    "instinktmässigare": "instinktmässig",
    "instinktmässigares": "instinktmässig",
    "instinktmässigas": "instinktmässig",
    "instinktmässigast": "instinktmässig",
    "instinktmässigaste": "instinktmässig",
    "instinktmässigastes": "instinktmässig",
    "instinktmässigasts": "instinktmässig",
    "instinktmässige": "instinktmässig",
    "instinktmässiges": "instinktmässig",
    "instinktmässigs": "instinktmässig",
    "instinktmässigt": "instinktmässig",
    "instinktmässigts": "instinktmässig",
    "instinkts": "instinkt",
    "instituten": "institut",
    "institutens": "institut",
    "institutet": "institut",
    "institutets": "institut",
    "institutionaliserad": "institutionalisera",
    "institutionaliserade": "institutionalisera",
    "institutionaliserades": "institutionalisera",
    "institutionaliserads": "institutionalisera",
    "institutionaliserande": "institutionalisera",
    "institutionaliseranden": "institutionaliserande",
    "institutionaliserandena": "institutionaliserande",
    "institutionaliserandenas": "institutionaliserande",
    "institutionaliserandens": "institutionaliserande",
    "institutionaliserandes": "institutionaliserande",
    "institutionaliserandet": "institutionaliserande",
    "institutionaliserandets": "institutionaliserande",
    "institutionaliserar": "institutionalisera",
    "institutionaliseras": "institutionalisera",
    "institutionaliserat": "institutionalisera",
    "institutionaliserats": "institutionalisera",
    "institutionaliserbara": "institutionaliserbar",
    "institutionaliserbarare": "institutionaliserbar",
    "institutionaliserbarares": "institutionaliserbar",
    "institutionaliserbaras": "institutionaliserbar",
    "institutionaliserbarast": "institutionaliserbar",
    "institutionaliserbaraste": "institutionaliserbar",
    "institutionaliserbarastes": "institutionaliserbar",
    "institutionaliserbarasts": "institutionaliserbar",
    "institutionaliserbare": "institutionaliserbar",
    "institutionaliserbares": "institutionaliserbar",
    "institutionaliserbarheten": "institutionaliserbarhet",
    "institutionaliserbarhetens": "institutionaliserbarhet",
    "institutionaliserbarhets": "institutionaliserbarhet",
    "institutionaliserbars": "institutionaliserbar",
    "institutionaliserbart": "institutionaliserbar",
    "institutionaliserbarts": "institutionaliserbar",
    "institutionaliseringar": "institutionalisering",
    "institutionaliseringarna": "institutionalisering",
    "institutionaliseringarnas": "institutionalisering",
    "institutionaliseringars": "institutionalisering",
    "institutionaliseringen": "institutionalisering",
    "institutionaliseringens": "institutionalisering",
    "institutionaliserings": "institutionalisering",
    "institutionella": "institutionell",
    "institutionellare": "institutionell",
    "institutionellares": "institutionell",
    "institutionellas": "institutionell",
    "institutionellast": "institutionell",
    "institutionellaste": "institutionell",
    "institutionellastes": "institutionell",
    "institutionellasts": "institutionell",
    "institutionelle": "institutionell",
    "institutionelles": "institutionell",
    "institutionells": "institutionell",
    "institutionellt": "institutionell",
    "institutionellts": "institutionell",
    "institutionen": "institution",
    "institutionens": "institution",
    "institutioner": "institution",
    "institutionerna": "institution",
    "institutionernas": "institution",
    "institutioners": "institution",
    "institutions": "institution",
    "institutionsskadade": "institutionsskadad",
    "institutionsskadades": "institutionsskadad",
    "institutionsskadads": "institutionsskadad",
    "institutionsskadan": "institutionsskada",
    "institutionsskadans": "institutionsskada",
    "institutionsskadas": "institutionsskada",
    "institutionsskadat": "institutionsskadad",
    "institutionsskadats": "institutionsskadad",
    "institutionsskade": "institutionsskada",
    "institutionsskador": "institutionsskada",
    "institutionsskadorna": "institutionsskada",
    "institutionsskadornas": "institutionsskada",
    "institutionsskadors": "institutionsskada",
    "instituts": "institut",
    "instroduktionsföreläsningar": "instroduktionsföreläsning",
    "instroduktionsföreläsningarna": "instroduktionsföreläsning",
    "instroduktionsföreläsningarnas": "instroduktionsföreläsning",
    "instroduktionsföreläsningars": "instroduktionsföreläsning",
    "instroduktionsföreläsningen": "instroduktionsföreläsning",
    "instroduktionsföreläsningens": "instroduktionsföreläsning",
    "instroduktionsföreläsnings": "instroduktionsföreläsning",
    "instruerad": "instruera",
    "instruerade": "instruera",
    "instruerades": "instruera",
    "instruerads": "instruera",
    "instruerande": "instruera",
    "instrueranden": "instruerande",
    "instruerandena": "instruerande",
    "instruerandenas": "instruerande",
    "instruerandens": "instruerande",
    "instruerandes": "instruerande",
    "instruerandet": "instruerande",
    "instruerandets": "instruerande",
    "instruerar": "instruera",
    "instrueras": "instruera",
    "instruerat": "instruera",
    "instruerats": "instruera",
    "instruerbara": "instruerbar",
    "instruerbarare": "instruerbar",
    "instruerbarares": "instruerbar",
    "instruerbaras": "instruerbar",
    "instruerbarast": "instruerbar",
    "instruerbaraste": "instruerbar",
    "instruerbarastes": "instruerbar",
    "instruerbarasts": "instruerbar",
    "instruerbare": "instruerbar",
    "instruerbares": "instruerbar",
    "instruerbarheten": "instruerbarhet",
    "instruerbarhetens": "instruerbarhet",
    "instruerbarhets": "instruerbarhet",
    "instruerbars": "instruerbar",
    "instruerbart": "instruerbar",
    "instruerbarts": "instruerbar",
    "instrueringar": "instruering",
    "instrueringarna": "instruering",
    "instrueringarnas": "instruering",
    "instrueringars": "instruering",
    "instrueringen": "instruering",
    "instrueringens": "instruering",
    "instruerings": "instruering",
    "instruktionen": "instruktion",
    "instruktionens": "instruktion",
    "instruktioner": "instruktion",
    "instruktionerna": "instruktion",
    "instruktionernas": "instruktion",
    "instruktioners": "instruktion",
    "instruktions": "instruktion",
    "instruktiva": "instruktiv",
    "instruktivare": "instruktiv",
    "instruktivares": "instruktiv",
    "instruktivas": "instruktiv",
    "instruktivast": "instruktiv",
    "instruktivaste": "instruktiv",
    "instruktivastes": "instruktiv",
    "instruktivasts": "instruktiv",
    "instruktive": "instruktiv",
    "instruktives": "instruktiv",
    "instruktivs": "instruktiv",
    "instruktivt": "instruktiv",
    "instruktivts": "instruktiv",
    "instruktören": "instruktör",
    "instruktörens": "instruktör",
    "instruktörer": "instruktör",
    "instruktörerna": "instruktör",
    "instruktörernas": "instruktör",
    "instruktörers": "instruktör",
    "instruktörn": "instruktör",
    "instruktörns": "instruktör",
    "instruktörs": "instruktör",
    "instrumentala": "instrumental",
    "instrumentalare": "instrumental",
    "instrumentalares": "instrumental",
    "instrumentalas": "instrumental",
    "instrumentalast": "instrumental",
    "instrumentalaste": "instrumental",
    "instrumentalastes": "instrumental",
    "instrumentalasts": "instrumental",
    "instrumentale": "instrumental",
    "instrumentales": "instrumental",
    "instrumentalisen": "instrumentalis",
    "instrumentalisens": "instrumentalis",
    "instrumentalisten": "instrumentalist",
    "instrumentalistens": "instrumentalist",
    "instrumentalister": "instrumentalist",
    "instrumentalisterna": "instrumentalist",
    "instrumentalisternas": "instrumentalist",
    "instrumentalisters": "instrumentalist",
    "instrumentalists": "instrumentalist",
    "instrumentalmusiken": "instrumentalmusik",
    "instrumentalmusikens": "instrumentalmusik",
    "instrumentalmusiks": "instrumentalmusik",
    "instrumentals": "instrumental",
    "instrumentalt": "instrumental",
    "instrumentalts": "instrumental",
    "instrumentarie": "instrumentarium",
    "instrumentarier": "instrumentarium",
    "instrumentarierna": "instrumentarium",
    "instrumentariernas": "instrumentarium",
    "instrumentariers": "instrumentarium",
    "instrumentariet": "instrumentarium",
    "instrumentariets": "instrumentarium",
    "instrumentariums": "instrumentarium",
    "instrumentationen": "instrumentation",
    "instrumentationens": "instrumentation",
    "instrumentationer": "instrumentation",
    "instrumentationerna": "instrumentation",
    "instrumentationernas": "instrumentation",
    "instrumentationers": "instrumentation",
    "instrumentations": "instrumentation",
    "instrumentbelysningar": "instrumentbelysning",
    "instrumentbelysningarna": "instrumentbelysning",
    "instrumentbelysningarnas": "instrumentbelysning",
    "instrumentbelysningars": "instrumentbelysning",
    "instrumentbelysningen": "instrumentbelysning",
    "instrumentbelysningens": "instrumentbelysning",
    "instrumentbelysnings": "instrumentbelysning",
    "instrumentbräd": "instrumentbräda",
    "instrumentbrädan": "instrumentbräda",
    "instrumentbrädans": "instrumentbräda",
    "instrumentbrädas": "instrumentbräda",
    "instrumentbräde": "instrumentbräda",
    "instrumentbräden": "instrumentbräde",
    "instrumentbrädena": "instrumentbräde",
    "instrumentbrädenas": "instrumentbräde",
    "instrumentbrädens": "instrumentbräde",
    "instrumentbrädes": "instrumentbräde",
    "instrumentbrädet": "instrumentbräde",
    "instrumentbrädets": "instrumentbräde",
    "instrumentbrädor": "instrumentbräda",
    "instrumentbrädorna": "instrumentbräda",
    "instrumentbrädornas": "instrumentbräda",
    "instrumentbrädors": "instrumentbräda",
    "instrumentbräds": "instrumentbräda",
    "instrumentella": "instrumentell",
    "instrumentellare": "instrumentell",
    "instrumentellares": "instrumentell",
    "instrumentellas": "instrumentell",
    "instrumentellast": "instrumentell",
    "instrumentellaste": "instrumentell",
    "instrumentellastes": "instrumentell",
    "instrumentellasts": "instrumentell",
    "instrumentelle": "instrumentell",
    "instrumentelles": "instrumentell",
    "instrumentells": "instrumentell",
    "instrumentellt": "instrumentell",
    "instrumentellts": "instrumentell",
    "instrumenten": "instrument",
    "instrumentens": "instrument",
    "instrumenterad": "instrumentera",
    "instrumenterade": "instrumentera",
    "instrumenterades": "instrumentera",
    "instrumenterads": "instrumentera",
    "instrumenterande": "instrumentera",
    "instrumenteranden": "instrumenterande",
    "instrumenterandena": "instrumenterande",
    "instrumenterandenas": "instrumenterande",
    "instrumenterandens": "instrumenterande",
    "instrumenterandes": "instrumenterande",
    "instrumenterandet": "instrumenterande",
    "instrumenterandets": "instrumenterande",
    "instrumenterar": "instrumentera",
    "instrumenteras": "instrumentera",
    "instrumenterat": "instrumentera",
    "instrumenterats": "instrumentera",
    "instrumenterbara": "instrumenterbar",
    "instrumenterbarare": "instrumenterbar",
    "instrumenterbarares": "instrumenterbar",
    "instrumenterbaras": "instrumenterbar",
    "instrumenterbarast": "instrumenterbar",
    "instrumenterbaraste": "instrumenterbar",
    "instrumenterbarastes": "instrumenterbar",
    "instrumenterbarasts": "instrumenterbar",
    "instrumenterbare": "instrumenterbar",
    "instrumenterbares": "instrumenterbar",
    "instrumenterbarheten": "instrumenterbarhet",
    "instrumenterbarhetens": "instrumenterbarhet",
    "instrumenterbarhets": "instrumenterbarhet",
    "instrumenterbars": "instrumenterbar",
    "instrumenterbart": "instrumenterbar",
    "instrumenterbarts": "instrumenterbar",
    "instrumenteringar": "instrumentering",
    "instrumenteringarna": "instrumentering",
    "instrumenteringarnas": "instrumentering",
    "instrumenteringars": "instrumentering",
    "instrumenteringen": "instrumentering",
    "instrumenteringens": "instrumentering",
    "instrumenterings": "instrumentering",
    "instrumentet": "instrument",
    "instrumentets": "instrument",
    "instrumentflygningar": "instrumentflygning",
    "instrumentflygningarna": "instrumentflygning",
    "instrumentflygningarnas": "instrumentflygning",
    "instrumentflygningars": "instrumentflygning",
    "instrumentflygningen": "instrumentflygning",
    "instrumentflygningens": "instrumentflygning",
    "instrumentflygnings": "instrumentflygning",
    "instrumentlåd": "instrumentlåda",
    "instrumentlådan": "instrumentlåda",
    "instrumentlådans": "instrumentlåda",
    "instrumentlådas": "instrumentlåda",
    "instrumentlåde": "instrumentlåda",
    "instrumentlådor": "instrumentlåda",
    "instrumentlådorna": "instrumentlåda",
    "instrumentlådornas": "instrumentlåda",
    "instrumentlådors": "instrumentlåda",
    "instrumentlåds": "instrumentlåda",
    "instrumentpanelen": "instrumentpanel",
    "instrumentpanelens": "instrumentpanel",
    "instrumentpaneler": "instrumentpanel",
    "instrumentpanelerna": "instrumentpanel",
    "instrumentpanelernas": "instrumentpanel",
    "instrumentpanelers": "instrumentpanel",
    "instrumentpanels": "instrumentpanel",
    "instruments": "instrument",
    "instrål": "instråla",
    "instrålad": "instråla",
    "instrålade": "instråla",
    "instrålades": "instråla",
    "instrålads": "instråla",
    "instrålande": "instråla",
    "instrålanden": "instrålande",
    "instrålandena": "instrålande",
    "instrålandenas": "instrålande",
    "instrålandens": "instrålande",
    "instrålandes": "instrålande",
    "instrålandet": "instrålande",
    "instrålandets": "instrålande",
    "instrålar": "instråla",
    "instrålas": "instråla",
    "instrålat": "instråla",
    "instrålats": "instråla",
    "instrålningar": "instrålning",
    "instrålningarna": "instrålning",
    "instrålningarnas": "instrålning",
    "instrålningars": "instrålning",
    "instrålningen": "instrålning",
    "instrålningens": "instrålning",
    "instrålnings": "instrålning",
    "inströmmar": "inström",
    "inströmmarna": "inström",
    "inströmmarnas": "inström",
    "inströmmars": "inström",
    "inströmmen": "inström",
    "inströmmens": "inström",
    "inströms": "inström",
    "instuderad": "instudera",
    "instuderade": "instudera",
    "instuderades": "instudera",
    "instuderads": "instudera",
    "instuderande": "instudera",
    "instuderanden": "instuderande",
    "instuderandena": "instuderande",
    "instuderandenas": "instuderande",
    "instuderandens": "instuderande",
    "instuderandes": "instuderande",
    "instuderandet": "instuderande",
    "instuderandets": "instuderande",
    "instuderar": "instudera",
    "instuderas": "instudera",
    "instuderat": "instudera",
    "instuderats": "instudera",
    "instuderbara": "instuderbar",
    "instuderbarare": "instuderbar",
    "instuderbarares": "instuderbar",
    "instuderbaras": "instuderbar",
    "instuderbarast": "instuderbar",
    "instuderbaraste": "instuderbar",
    "instuderbarastes": "instuderbar",
    "instuderbarasts": "instuderbar",
    "instuderbare": "instuderbar",
    "instuderbares": "instuderbar",
    "instuderbarheten": "instuderbarhet",
    "instuderbarhetens": "instuderbarhet",
    "instuderbarhets": "instuderbarhet",
    "instuderbars": "instuderbar",
    "instuderbart": "instuderbar",
    "instuderbarts": "instuderbar",
    "instuderingar": "instudering",
    "instuderingarna": "instudering",
    "instuderingarnas": "instudering",
    "instuderingars": "instudering",
    "instuderingen": "instudering",
    "instuderingens": "instudering",
    "instuderings": "instudering",
    "instundade": "instunda",
    "instundades": "instunda",
    "instundande": "instunda",
    "instundanden": "instundande",
    "instundandena": "instundande",
    "instundandenas": "instundande",
    "instundandens": "instundande",
    "instundandes": "instundande",
    "instundandet": "instundande",
    "instundandets": "instundande",
    "instundar": "instunda",
    "instundas": "instunda",
    "instundat": "instunda",
    "instundats": "instunda",
    "inställ": "inställa",
    "inställande": "inställa",
    "inställanden": "inställande",
    "inställandena": "inställande",
    "inställandenas": "inställande",
    "inställandens": "inställande",
    "inställandes": "inställande",
    "inställandet": "inställande",
    "inställandets": "inställande",
    "inställas": "inställa",
    "inställbara": "inställbar",
    "inställbarare": "inställbar",
    "inställbarares": "inställbar",
    "inställbaras": "inställbar",
    "inställbarast": "inställbar",
    "inställbaraste": "inställbar",
    "inställbarastes": "inställbar",
    "inställbarasts": "inställbar",
    "inställbare": "inställbar",
    "inställbares": "inställbar",
    "inställbarheten": "inställbarhet",
    "inställbarhetens": "inställbarhet",
    "inställbarhets": "inställbarhet",
    "inställbars": "inställbar",
    "inställbart": "inställbar",
    "inställbarts": "inställbar",
    "inställd": "inställa",
    "inställda": "inställd",
    "inställdare": "inställd",
    "inställdares": "inställd",
    "inställdas": "inställd",
    "inställdast": "inställd",
    "inställdaste": "inställd",
    "inställdastes": "inställd",
    "inställdasts": "inställd",
    "inställde": "inställd",
    "inställdes": "inställd",
    "inställds": "inställd",
    "inställelsen": "inställelse",
    "inställelsens": "inställelse",
    "inställelser": "inställelse",
    "inställelserna": "inställelse",
    "inställelsernas": "inställelse",
    "inställelsers": "inställelse",
    "inställelses": "inställelse",
    "inställer": "inställa",
    "inställes": "inställa",
    "inställningar": "inställning",
    "inställningarna": "inställning",
    "inställningarnas": "inställning",
    "inställningars": "inställning",
    "inställningen": "inställning",
    "inställningens": "inställning",
    "inställnings": "inställning",
    "inställningsbara": "inställningsbar",
    "inställningsbarare": "inställningsbar",
    "inställningsbarares": "inställningsbar",
    "inställningsbaras": "inställningsbar",
    "inställningsbarast": "inställningsbar",
    "inställningsbaraste": "inställningsbar",
    "inställningsbarastes": "inställningsbar",
    "inställningsbarasts": "inställningsbar",
    "inställningsbare": "inställningsbar",
    "inställningsbares": "inställningsbar",
    "inställningsbarheten": "inställningsbarhet",
    "inställningsbarhetens": "inställningsbarhet",
    "inställningsbarhets": "inställningsbarhet",
    "inställningsbars": "inställningsbar",
    "inställningsbart": "inställningsbar",
    "inställningsbarts": "inställningsbar",
    "inställs": "inställa",
    "inställsamheten": "inställsamhet",
    "inställsamhetens": "inställsamhet",
    "inställsamheter": "inställsamhet",
    "inställsamheterna": "inställsamhet",
    "inställsamheternas": "inställsamhet",
    "inställsamheters": "inställsamhet",
    "inställsamhets": "inställsamhet",
    "inställsamma": "inställsam",
    "inställsammare": "inställsam",
    "inställsammares": "inställsam",
    "inställsammas": "inställsam",
    "inställsammast": "inställsam",
    "inställsammaste": "inställsam",
    "inställsammastes": "inställsam",
    "inställsammasts": "inställsam",
    "inställsamme": "inställsam",
    "inställsammes": "inställsam",
    "inställsams": "inställsam",
    "inställsamt": "inställsam",
    "inställsamts": "inställsam",
    "inställt": "inställd",
    "inställts": "inställd",
    "instäm": "instämma",
    "instämd": "instämma",
    "instämda": "instämma",
    "instämdas": "instämma",
    "instämde": "instämma",
    "instämdes": "instämma",
    "instämds": "instämma",
    "instämmande": "instämma",
    "instämmanden": "instämmande",
    "instämmandena": "instämmande",
    "instämmandenas": "instämmande",
    "instämmandens": "instämmande",
    "instämmandes": "instämmande",
    "instämmandet": "instämmande",
    "instämmandets": "instämmande",
    "instämmas": "instämma",
    "instämmer": "instämma",
    "instäms": "instämma",
    "instämt": "instämma",
    "instämts": "instämma",
    "instäng": "instänga",
    "instängande": "instänga",
    "instänganden": "instängande",
    "instängandena": "instängande",
    "instängandenas": "instängande",
    "instängandens": "instängande",
    "instängandes": "instängande",
    "instängandet": "instängande",
    "instängandets": "instängande",
    "instängas": "instänga",
    "instängd": "instänga",
    "instängda": "instängd",
    "instängdare": "instängd",
    "instängdares": "instängd",
    "instängdas": "instängd",
    "instängdast": "instängd",
    "instängdaste": "instängd",
    "instängdastes": "instängd",
    "instängdasts": "instängd",
    "instängde": "instängd",
    "instängdes": "instängd",
    "instängdheten": "instängdhet",
    "instängdhetens": "instängdhet",
    "instängdhets": "instängdhet",
    "instängds": "instängd",
    "instänger": "instänga",
    "instänges": "instänga",
    "instängs": "instänga",
    "instängt": "instängd",
    "instängts": "instängd",
    "insubordinationen": "insubordination",
    "insubordinationens": "insubordination",
    "insubordinationer": "insubordination",
    "insubordinationerna": "insubordination",
    "insubordinationernas": "insubordination",
    "insubordinationers": "insubordination",
    "insubordinations": "insubordination",
    "insufficiensen": "insufficiens",
    "insufficiensens": "insufficiens",
    "insufficienser": "insufficiens",
    "insufficienserna": "insufficiens",
    "insufficiensernas": "insufficiens",
    "insufficiensers": "insufficiens",
    "insug": "insuga",
    "insugande": "insuga",
    "insuganden": "insugande",
    "insugandena": "insugande",
    "insugandenas": "insugande",
    "insugandens": "insugande",
    "insugandes": "insugande",
    "insugandet": "insugande",
    "insugandets": "insugande",
    "insugas": "insuga",
    "insuge": "insuga",
    "insugen": "insuga",
    "insugens": "insuga",
    "insuger": "insuga",
    "insuges": "insuga",
    "insuget": "insuga",
    "insugets": "insuga",
    "insugit": "insuga",
    "insugits": "insuga",
    "insugna": "insuga",
    "insugnas": "insuga",
    "insugne": "insuga",
    "insugnes": "insuga",
    "insugningsventilen": "insugningsventil",
    "insugningsventilens": "insugningsventil",
    "insugningsventiler": "insugningsventil",
    "insugningsventilerna": "insugningsventil",
    "insugningsventilernas": "insugningsventil",
    "insugningsventilers": "insugningsventil",
    "insugningsventils": "insugningsventil",
    "insugs": "insuga",
    "insulinchocken": "insulinchock",
    "insulinchockens": "insulinchock",
    "insulinchocker": "insulinchock",
    "insulinchockerna": "insulinchock",
    "insulinchockernas": "insulinchock",
    "insulinchockers": "insulinchock",
    "insulinchocks": "insulinchock",
    "insulinen": "insulin",
    "insulinens": "insulin",
    "insuliner": "insulin",
    "insulinerna": "insulin",
    "insulinernas": "insulin",
    "insuliners": "insulin",
    "insulinet": "insulin",
    "insulinets": "insulin",
    "insulins": "insulin",
    "insulära": "insulär",
    "insulärare": "insulär",
    "insulärares": "insulär",
    "insuläras": "insulär",
    "insulärast": "insulär",
    "insuläraste": "insulär",
    "insulärastes": "insulär",
    "insulärasts": "insulär",
    "insuläre": "insulär",
    "insuläres": "insulär",
    "insulärs": "insulär",
    "insulärt": "insulär",
    "insulärts": "insulär",
    "insup": "insupa",
    "insupande": "insupa",
    "insupanden": "insupande",
    "insupandena": "insupande",
    "insupandenas": "insupande",
    "insupandens": "insupande",
    "insupandes": "insupande",
    "insupandet": "insupande",
    "insupandets": "insupande",
    "insupas": "insupa",
    "insupe": "insupa",
    "insupen": "insupa",
    "insupens": "insupa",
    "insuper": "insupa",
    "insupes": "insupa",
    "insupet": "insupa",
    "insupets": "insupa",
    "insupit": "insupa",
    "insupits": "insupa",
    "insupna": "insupa",
    "insupnas": "insupa",
    "insupne": "insupa",
    "insupnes": "insupa",
    "insups": "insupa",
    "insurgenten": "insurgent",
    "insurgentens": "insurgent",
    "insurgenter": "insurgent",
    "insurgenterna": "insurgent",
    "insurgenternas": "insurgent",
    "insurgenters": "insurgent",
    "insurgents": "insurgent",
    "insvep": "insvepa",
    "insvepande": "insvepa",
    "insvepanden": "insvepande",
    "insvepandena": "insvepande",
    "insvepandenas": "insvepande",
    "insvepandens": "insvepande",
    "insvepandes": "insvepande",
    "insvepandet": "insvepande",
    "insvepandets": "insvepande",
    "insvepas": "insvepa",
    "insveper": "insvepa",
    "insvepes": "insvepa",
    "insveps": "insvepa",
    "insvept": "insvepa",
    "insvepta": "insvepa",
    "insveptas": "insvepa",
    "insvepte": "insvepa",
    "insveptes": "insvepa",
    "insvepts": "insvepa",
    "insvängda": "insvängd",
    "insvängdare": "insvängd",
    "insvängdares": "insvängd",
    "insvängdas": "insvängd",
    "insvängdast": "insvängd",
    "insvängdaste": "insvängd",
    "insvängdastes": "insvängd",
    "insvängdasts": "insvängd",
    "insvängde": "insvängd",
    "insvängdes": "insvängd",
    "insvängds": "insvängd",
    "insvängningar": "insvängning",
    "insvängningarna": "insvängning",
    "insvängningarnas": "insvängning",
    "insvängningars": "insvängning",
    "insvängningen": "insvängning",
    "insvängningens": "insvängning",
    "insvängnings": "insvängning",
    "insvängt": "insvängd",
    "insvängts": "insvängd",
    "insydda": "insydd",
    "insyddare": "insydd",
    "insyddares": "insydd",
    "insyddas": "insydd",
    "insyddast": "insydd",
    "insyddaste": "insydd",
    "insyddastes": "insydd",
    "insyddasts": "insydd",
    "insydde": "insydd",
    "insyddes": "insydd",
    "insydds": "insydd",
    "insyltade": "insyltad",
    "insyltades": "insyltad",
    "insyltads": "insyltad",
    "insyltat": "insyltad",
    "insyltats": "insyltad",
    "insynen": "insyn",
    "insynens": "insyn",
    "insyns": "insyn",
    "insytt": "insydd",
    "insytts": "insydd",
    "insänd": "insända",
    "insändande": "insända",
    "insändanden": "insändande",
    "insändandena": "insändande",
    "insändandenas": "insändande",
    "insändandens": "insändande",
    "insändandes": "insändande",
    "insändandet": "insändande",
    "insändandets": "insändande",
    "insändar": "insändare",
    "insändaren": "insändare",
    "insändarens": "insändare",
    "insändares": "insändare",
    "insändarna": "insändare",
    "insändarnas": "insändare",
    "insändas": "insända",
    "insände": "insända",
    "insänder": "insända",
    "insändes": "insända",
    "insänds": "insända",
    "insänt": "insända",
    "insänts": "insända",
    "insätt": "insätta",
    "insättande": "insätta",
    "insättanden": "insättande",
    "insättandena": "insättande",
    "insättandenas": "insättande",
    "insättandens": "insättande",
    "insättandes": "insättande",
    "insättandet": "insättande",
    "insättandets": "insättande",
    "insättas": "insätta",
    "insätter": "insätta",
    "insättes": "insätta",
    "insättningar": "insättning",
    "insättningarna": "insättning",
    "insättningarnas": "insättning",
    "insättningars": "insättning",
    "insättningen": "insättning",
    "insättningens": "insättning",
    "insättnings": "insättning",
    "insätts": "insätta",
    "insåg": "inse",
    "insåge": "inse",
    "insåges": "inse",
    "insågs": "inse",
    "insög": "insuga",
    "insöge": "insuga",
    "insöges": "insuga",
    "insögs": "insuga",
    "insöndrad": "insöndra",
    "insöndrade": "insöndra",
    "insöndrades": "insöndra",
    "insöndrads": "insöndra",
    "insöndrande": "insöndra",
    "insöndranden": "insöndrande",
    "insöndrandena": "insöndrande",
    "insöndrandenas": "insöndrande",
    "insöndrandens": "insöndrande",
    "insöndrandes": "insöndrande",
    "insöndrandet": "insöndrande",
    "insöndrandets": "insöndrande",
    "insöndrar": "insöndra",
    "insöndras": "insöndra",
    "insöndrat": "insöndra",
    "insöndrats": "insöndra",
    "insöndringar": "insöndring",
    "insöndringarna": "insöndring",
    "insöndringarnas": "insöndring",
    "insöndringars": "insöndring",
    "insöndringen": "insöndring",
    "insöndringens": "insöndring",
    "insöndrings": "insöndring",
    "insöp": "insupa",
    "insöpe": "insupa",
    "insöpes": "insupa",
    "insöps": "insupa",
    "intag": "inta",
    "intaga": "inta",
    "intagande": "inta",
    "intaganden": "intagande",
    "intagandena": "intagande",
    "intagandenas": "intagande",
    "intagandens": "intagande",
    "intagandes": "intagande",
    "intagandet": "intagande",
    "intagandets": "intagande",
    "intagas": "inta",
    "intage": "inta",
    "intagen": "intag",
    "intagens": "intagen",
    "intager": "inta",
    "intages": "inta",
    "intaget": "intagen",
    "intagets": "intagen",
    "intagit": "inta",
    "intagits": "inta",
    "intagna": "intagen",
    "intagnare": "intagen",
    "intagnares": "intagen",
    "intagnas": "intagen",
    "intagnast": "intagen",
    "intagnaste": "intagen",
    "intagnastes": "intagen",
    "intagnasts": "intagen",
    "intagne": "intagen",
    "intagnes": "intagen",
    "intagningar": "intagning",
    "intagningarna": "intagning",
    "intagningarnas": "intagning",
    "intagningars": "intagning",
    "intagningen": "intagning",
    "intagningens": "intagning",
    "intagnings": "intagning",
    "intagningshandlingar": "intagningshandling",
    "intagningshandlingarna": "intagningshandling",
    "intagningshandlingarnas": "intagningshandling",
    "intagningshandlingars": "intagningshandling",
    "intagningshandlingen": "intagningshandling",
    "intagningshandlingens": "intagningshandling",
    "intagningshandlings": "intagningshandling",
    "intags": "intag",
    "intagsdammar": "intagsdamm",
    "intagsdammarna": "intagsdamm",
    "intagsdammarnas": "intagsdamm",
    "intagsdammars": "intagsdamm",
    "intagsdammen": "intagsdamm",
    "intagsdammens": "intagsdamm",
    "intagsdamms": "intagsdamm",
    "intakta": "intakt",
    "intaktare": "intakt",
    "intaktares": "intakt",
    "intaktas": "intakt",
    "intaktast": "intakt",
    "intaktaste": "intakt",
    "intaktastes": "intakt",
    "intaktasts": "intakt",
    "intakte": "intakt",
    "intaktes": "intakt",
    "intakts": "intakt",
    "intalade": "intala",
    "intalades": "intala",
    "intalande": "intala",
    "intalanden": "intalande",
    "intalandena": "intalande",
    "intalandenas": "intalande",
    "intalandens": "intalande",
    "intalandes": "intalande",
    "intalandet": "intalande",
    "intalandets": "intalande",
    "intalans": "intalan",
    "intalar": "intala",
    "intalas": "intala",
    "intalat": "intala",
    "intalats": "intala",
    "intar": "inta",
    "intarsi": "intarsia",
    "intarsian": "intarsia",
    "intarsians": "intarsia",
    "intarsias": "intarsia",
    "intarsie": "intarsia",
    "intarsior": "intarsia",
    "intarsiorna": "intarsia",
    "intarsiornas": "intarsia",
    "intarsiors": "intarsia",
    "intarsis": "intarsia",
    "intas": "inta",
    "inteckn": "inteckna",
    "intecknad": "inteckna",
    "intecknade": "inteckna",
    "intecknades": "inteckna",
    "intecknads": "inteckna",
    "intecknande": "inteckna",
    "intecknanden": "intecknande",
    "intecknandena": "intecknande",
    "intecknandenas": "intecknande",
    "intecknandens": "intecknande",
    "intecknandes": "intecknande",
    "intecknandet": "intecknande",
    "intecknandets": "intecknande",
    "intecknar": "inteckna",
    "intecknas": "inteckna",
    "intecknat": "inteckna",
    "intecknats": "inteckna",
    "inteckningar": "inteckning",
    "inteckningarna": "inteckning",
    "inteckningarnas": "inteckning",
    "inteckningars": "inteckning",
    "inteckningen": "inteckning",
    "inteckningens": "inteckning",
    "intecknings": "inteckning",
    "inteckningslånen": "inteckningslån",
    "inteckningslånens": "inteckningslån",
    "inteckningslånet": "inteckningslån",
    "inteckningslånets": "inteckningslån",
    "inteckningslåns": "inteckningslån",
    "integralen": "integral",
    "integralens": "integral",
    "integraler": "integral",
    "integralerna": "integral",
    "integralernas": "integral",
    "integralers": "integral",
    "integralhjälmar": "integralhjälm",
    "integralhjälmarna": "integralhjälm",
    "integralhjälmarnas": "integralhjälm",
    "integralhjälmars": "integralhjälm",
    "integralhjälmen": "integralhjälm",
    "integralhjälmens": "integralhjälm",
    "integralhjälms": "integralhjälm",
    "integralkalkylen": "integralkalkyl",
    "integralkalkylens": "integralkalkyl",
    "integralkalkyler": "integralkalkyl",
    "integralkalkylerna": "integralkalkyl",
    "integralkalkylernas": "integralkalkyl",
    "integralkalkylers": "integralkalkyl",
    "integralkalkyls": "integralkalkyl",
    "integrals": "integral",
    "integranden": "integrand",
    "integrandens": "integrand",
    "integrander": "integrand",
    "integranderna": "integrand",
    "integrandernas": "integrand",
    "integranders": "integrand",
    "integrands": "integrand",
    "integrationen": "integration",
    "integrationens": "integration",
    "integrationer": "integration",
    "integrationerna": "integration",
    "integrationernas": "integration",
    "integrationers": "integration",
    "integrations": "integration",
    "integrationsdebatten": "integrationsdebatt",
    "integrationsdebattens": "integrationsdebatt",
    "integrationsdebatter": "integrationsdebatt",
    "integrationsdebatterna": "integrationsdebatt",
    "integrationsdebatternas": "integrationsdebatt",
    "integrationsdebatters": "integrationsdebatt",
    "integrationsdebatts": "integrationsdebatt",
    "integrationspolitiken": "integrationspolitik",
    "integrationspolitikens": "integrationspolitik",
    "integrationspolitiks": "integrationspolitik",
    "integrationspolitiska": "integrationspolitisk",
    "integrationspolitiskas": "integrationspolitisk",
    "integrationspolitiske": "integrationspolitisk",
    "integrationspolitiskes": "integrationspolitisk",
    "integrationspolitisks": "integrationspolitisk",
    "integrationspolitiskt": "integrationspolitisk",
    "integrationspolitiskts": "integrationspolitisk",
    "integrerad": "integrera",
    "integrerade": "integrera",
    "integrerades": "integrera",
    "integrerads": "integrera",
    "integrerande": "integrera",
    "integreranden": "integrerande",
    "integrerandena": "integrerande",
    "integrerandenas": "integrerande",
    "integrerandens": "integrerande",
    "integrerandes": "integrerande",
    "integrerandet": "integrerande",
    "integrerandets": "integrerande",
    "integrerar": "integrera",
    "integreras": "integrera",
    "integrerat": "integrera",
    "integrerats": "integrera",
    "integrerbara": "integrerbar",
    "integrerbarare": "integrerbar",
    "integrerbarares": "integrerbar",
    "integrerbaras": "integrerbar",
    "integrerbarast": "integrerbar",
    "integrerbaraste": "integrerbar",
    "integrerbarastes": "integrerbar",
    "integrerbarasts": "integrerbar",
    "integrerbare": "integrerbar",
    "integrerbares": "integrerbar",
    "integrerbarheten": "integrerbarhet",
    "integrerbarhetens": "integrerbarhet",
    "integrerbarhets": "integrerbarhet",
    "integrerbars": "integrerbar",
    "integrerbart": "integrerbar",
    "integrerbarts": "integrerbar",
    "integreringar": "integrering",
    "integreringarna": "integrering",
    "integreringarnas": "integrering",
    "integreringars": "integrering",
    "integreringen": "integrering",
    "integreringens": "integrering",
    "integrerings": "integrering",
    "integriteten": "integritet",
    "integritetens": "integritet",
    "integriteter": "integritet",
    "integriteterna": "integritet",
    "integriteternas": "integritet",
    "integriteters": "integritet",
    "integritets": "integritet",
    "integritetsmässiga": "integritetsmässig",
    "integritetsmässigare": "integritetsmässig",
    "integritetsmässigares": "integritetsmässig",
    "integritetsmässigas": "integritetsmässig",
    "integritetsmässigast": "integritetsmässig",
    "integritetsmässigaste": "integritetsmässig",
    "integritetsmässigastes": "integritetsmässig",
    "integritetsmässigasts": "integritetsmässig",
    "integritetsmässige": "integritetsmässig",
    "integritetsmässiges": "integritetsmässig",
    "integritetsmässigs": "integritetsmässig",
    "integritetsmässigt": "integritetsmässig",
    "integritetsmässigts": "integritetsmässig",
    "intellekten": "intellekt",
    "intellektens": "intellekt",
    "intellektet": "intellekt",
    "intellektets": "intellekt",
    "intellekts": "intellekt",
    "intellektualiserad": "intellektualisera",
    "intellektualiserade": "intellektualisera",
    "intellektualiserades": "intellektualisera",
    "intellektualiserads": "intellektualisera",
    "intellektualiserande": "intellektualisera",
    "intellektualiseranden": "intellektualiserande",
    "intellektualiserandena": "intellektualiserande",
    "intellektualiserandenas": "intellektualiserande",
    "intellektualiserandens": "intellektualiserande",
    "intellektualiserandes": "intellektualiserande",
    "intellektualiserandet": "intellektualiserande",
    "intellektualiserandets": "intellektualiserande",
    "intellektualiserar": "intellektualisera",
    "intellektualiseras": "intellektualisera",
    "intellektualiserat": "intellektualisera",
    "intellektualiserats": "intellektualisera",
    "intellektualiserbara": "intellektualiserbar",
    "intellektualiserbarare": "intellektualiserbar",
    "intellektualiserbarares": "intellektualiserbar",
    "intellektualiserbaras": "intellektualiserbar",
    "intellektualiserbarast": "intellektualiserbar",
    "intellektualiserbaraste": "intellektualiserbar",
    "intellektualiserbarastes": "intellektualiserbar",
    "intellektualiserbarasts": "intellektualiserbar",
    "intellektualiserbare": "intellektualiserbar",
    "intellektualiserbares": "intellektualiserbar",
    "intellektualiserbarheten": "intellektualiserbarhet",
    "intellektualiserbarhetens": "intellektualiserbarhet",
    "intellektualiserbarhets": "intellektualiserbarhet",
    "intellektualiserbars": "intellektualiserbar",
    "intellektualiserbart": "intellektualiserbar",
    "intellektualiserbarts": "intellektualiserbar",
    "intellektualiseringar": "intellektualisering",
    "intellektualiseringarna": "intellektualisering",
    "intellektualiseringarnas": "intellektualisering",
    "intellektualiseringars": "intellektualisering",
    "intellektualiseringen": "intellektualisering",
    "intellektualiseringens": "intellektualisering",
    "intellektualiserings": "intellektualisering",
    "intellektualismen": "intellektualism",
    "intellektualismens": "intellektualism",
    "intellektualismer": "intellektualism",
    "intellektualismerna": "intellektualism",
    "intellektualismernas": "intellektualism",
    "intellektualismers": "intellektualism",
    "intellektualisms": "intellektualism",
    "intellektualisten": "intellektualist",
    "intellektualistens": "intellektualist",
    "intellektualister": "intellektualist",
    "intellektualisterna": "intellektualist",
    "intellektualisternas": "intellektualist",
    "intellektualisters": "intellektualist",
    "intellektualistiska": "intellektualistisk",
    "intellektualistiskas": "intellektualistisk",
    "intellektualistiske": "intellektualistisk",
    "intellektualistiskes": "intellektualistisk",
    "intellektualistisks": "intellektualistisk",
    "intellektualistiskt": "intellektualistisk",
    "intellektualistiskts": "intellektualistisk",
    "intellektualists": "intellektualist",
    "intellektuella": "intellektuell",
    "intellektuellare": "intellektuell",
    "intellektuellares": "intellektuell",
    "intellektuellas": "intellektuell",
    "intellektuellast": "intellektuell",
    "intellektuellaste": "intellektuell",
    "intellektuellastes": "intellektuell",
    "intellektuellasts": "intellektuell",
    "intellektuelle": "intellektuell",
    "intellektuelles": "intellektuell",
    "intellektuells": "intellektuell",
    "intellektuellt": "intellektuell",
    "intellektuellts": "intellektuell",
    "intelligensaristokraten": "intelligensaristokrat",
    "intelligensaristokratens": "intelligensaristokrat",
    "intelligensaristokrater": "intelligensaristokrat",
    "intelligensaristokraterna": "intelligensaristokrat",
    "intelligensaristokraternas": "intelligensaristokrat",
    "intelligensaristokraters": "intelligensaristokrat",
    "intelligensaristokrats": "intelligensaristokrat",
    "intelligensen": "intelligens",
    "intelligensens": "intelligens",
    "intelligenser": "intelligens",
    "intelligenserna": "intelligens",
    "intelligensernas": "intelligens",
    "intelligensers": "intelligens",
    "intelligenskvoten": "intelligenskvot",
    "intelligenskvotens": "intelligenskvot",
    "intelligenskvoter": "intelligenskvot",
    "intelligenskvoterna": "intelligenskvot",
    "intelligenskvoternas": "intelligenskvot",
    "intelligenskvoters": "intelligenskvot",
    "intelligenskvots": "intelligenskvot",
    "intelligensmässiga": "intelligensmässig",
    "intelligensmässigare": "intelligensmässig",
    "intelligensmässigares": "intelligensmässig",
    "intelligensmässigas": "intelligensmässig",
    "intelligensmässigast": "intelligensmässig",
    "intelligensmässigaste": "intelligensmässig",
    "intelligensmässigastes": "intelligensmässig",
    "intelligensmässigasts": "intelligensmässig",
    "intelligensmässige": "intelligensmässig",
    "intelligensmässiges": "intelligensmässig",
    "intelligensmässigs": "intelligensmässig",
    "intelligensmässigt": "intelligensmässig",
    "intelligensmässigts": "intelligensmässig",
    "intelligensmätningar": "intelligensmätning",
    "intelligensmätningarna": "intelligensmätning",
    "intelligensmätningarnas": "intelligensmätning",
    "intelligensmätningars": "intelligensmätning",
    "intelligensmätningen": "intelligensmätning",
    "intelligensmätningens": "intelligensmätning",
    "intelligensmätnings": "intelligensmätning",
    "intelligenstesten": "intelligenstest",
    "intelligenstestens": "intelligenstest",
    "intelligenstester": "intelligenstest",
    "intelligenstesterna": "intelligenstest",
    "intelligenstesternas": "intelligenstest",
    "intelligenstesters": "intelligenstest",
    "intelligenstestet": "intelligenstest",
    "intelligenstestets": "intelligenstest",
    "intelligenstests": "intelligenstest",
    "intelligensåldern": "intelligensålder",
    "intelligensålderns": "intelligensålder",
    "intelligensålders": "intelligensålder",
    "intelligensåldrar": "intelligensålder",
    "intelligensåldrarna": "intelligensålder",
    "intelligensåldrarnas": "intelligensålder",
    "intelligensåldrars": "intelligensålder",
    "intelligenta": "intelligent",
    "intelligentare": "intelligent",
    "intelligentares": "intelligent",
    "intelligentas": "intelligent",
    "intelligentast": "intelligent",
    "intelligentaste": "intelligent",
    "intelligentastes": "intelligent",
    "intelligentasts": "intelligent",
    "intelligente": "intelligent",
    "intelligentes": "intelligent",
    "intelligentian": "intelligentia",
    "intelligentians": "intelligentia",
    "intelligentias": "intelligentia",
    "intelligents": "intelligent",
    "intelligentsi": "intelligentsia",
    "intelligentsian": "intelligentsia",
    "intelligentsians": "intelligentsia",
    "intelligentsias": "intelligentsia",
    "intelligentsie": "intelligentsia",
    "intelligentsior": "intelligentsia",
    "intelligentsiorna": "intelligentsia",
    "intelligentsiornas": "intelligentsia",
    "intelligentsiors": "intelligentsia",
    "intelligentsis": "intelligentsia",
    "intendenten": "intendent",
    "intendentens": "intendent",
    "intendenter": "intendent",
    "intendenterna": "intendent",
    "intendenternas": "intendent",
    "intendenters": "intendent",
    "intendents": "intendent",
    "intendenturen": "intendentur",
    "intendenturens": "intendentur",
    "intendenturer": "intendentur",
    "intendenturerna": "intendentur",
    "intendenturernas": "intendentur",
    "intendenturers": "intendentur",
    "intendenturs": "intendentur",
    "intendenturtjänsten": "intendenturtjänst",
    "intendenturtjänstens": "intendenturtjänst",
    "intendenturtjänster": "intendenturtjänst",
    "intendenturtjänsterna": "intendenturtjänst",
    "intendenturtjänsternas": "intendenturtjänst",
    "intendenturtjänsters": "intendenturtjänst",
    "intendenturtjänsts": "intendenturtjänst",
    "intensifierad": "intensifiera",
    "intensifierade": "intensifiera",
    "intensifierades": "intensifiera",
    "intensifierads": "intensifiera",
    "intensifierande": "intensifiera",
    "intensifieranden": "intensifierande",
    "intensifierandena": "intensifierande",
    "intensifierandenas": "intensifierande",
    "intensifierandens": "intensifierande",
    "intensifierandes": "intensifierande",
    "intensifierandet": "intensifierande",
    "intensifierandets": "intensifierande",
    "intensifierar": "intensifiera",
    "intensifieras": "intensifiera",
    "intensifierat": "intensifiera",
    "intensifierats": "intensifiera",
    "intensifierbara": "intensifierbar",
    "intensifierbarare": "intensifierbar",
    "intensifierbarares": "intensifierbar",
    "intensifierbaras": "intensifierbar",
    "intensifierbarast": "intensifierbar",
    "intensifierbaraste": "intensifierbar",
    "intensifierbarastes": "intensifierbar",
    "intensifierbarasts": "intensifierbar",
    "intensifierbare": "intensifierbar",
    "intensifierbares": "intensifierbar",
    "intensifierbarheten": "intensifierbarhet",
    "intensifierbarhetens": "intensifierbarhet",
    "intensifierbarhets": "intensifierbarhet",
    "intensifierbars": "intensifierbar",
    "intensifierbart": "intensifierbar",
    "intensifierbarts": "intensifierbar",
    "intensifieringar": "intensifiering",
    "intensifieringarna": "intensifiering",
    "intensifieringarnas": "intensifiering",
    "intensifieringars": "intensifiering",
    "intensifieringen": "intensifiering",
    "intensifieringens": "intensifiering",
    "intensifierings": "intensifiering",
    "intensionen": "intension",
    "intensionens": "intension",
    "intensioner": "intension",
    "intensionerna": "intension",
    "intensionernas": "intension",
    "intensioners": "intension",
    "intensions": "intension",
    "intensiteten": "intensitet",
    "intensitetens": "intensitet",
    "intensiteter": "intensitet",
    "intensiteterna": "intensitet",
    "intensiteternas": "intensitet",
    "intensiteters": "intensitet",
    "intensitets": "intensitet",
    "intensiva": "intensiv",
    "intensivare": "intensiv",
    "intensivares": "intensiv",
    "intensivas": "intensiv",
    "intensivast": "intensiv",
    "intensivaste": "intensiv",
    "intensivastes": "intensiv",
    "intensivasts": "intensiv",
    "intensive": "intensiv",
    "intensiven": "intensiv",
    "intensivens": "intensiv",
    "intensiver": "intensiv",
    "intensiverad": "intensivera",
    "intensiverade": "intensivera",
    "intensiverades": "intensivera",
    "intensiverads": "intensivera",
    "intensiverande": "intensivera",
    "intensiveranden": "intensiverande",
    "intensiverandena": "intensiverande",
    "intensiverandenas": "intensiverande",
    "intensiverandens": "intensiverande",
    "intensiverandes": "intensiverande",
    "intensiverandet": "intensiverande",
    "intensiverandets": "intensiverande",
    "intensiverar": "intensivera",
    "intensiveras": "intensivera",
    "intensiverat": "intensivera",
    "intensiverats": "intensivera",
    "intensiverbara": "intensiverbar",
    "intensiverbarare": "intensiverbar",
    "intensiverbarares": "intensiverbar",
    "intensiverbaras": "intensiverbar",
    "intensiverbarast": "intensiverbar",
    "intensiverbaraste": "intensiverbar",
    "intensiverbarastes": "intensiverbar",
    "intensiverbarasts": "intensiverbar",
    "intensiverbare": "intensiverbar",
    "intensiverbares": "intensiverbar",
    "intensiverbarheten": "intensiverbarhet",
    "intensiverbarhetens": "intensiverbarhet",
    "intensiverbarhets": "intensiverbarhet",
    "intensiverbars": "intensiverbar",
    "intensiverbart": "intensiverbar",
    "intensiverbarts": "intensiverbar",
    "intensiveringar": "intensivering",
    "intensiveringarna": "intensivering",
    "intensiveringarnas": "intensivering",
    "intensiveringars": "intensivering",
    "intensiveringen": "intensivering",
    "intensiveringens": "intensivering",
    "intensiverings": "intensivering",
    "intensiverna": "intensiv",
    "intensivernas": "intensiv",
    "intensivers": "intensiv",
    "intensives": "intensiv",
    "intensivs": "intensiv",
    "intensivt": "intensiv",
    "intensivts": "intensiv",
    "intensivundersökningar": "intensivundersökning",
    "intensivundersökningarna": "intensivundersökning",
    "intensivundersökningarnas": "intensivundersökning",
    "intensivundersökningars": "intensivundersökning",
    "intensivundersökningen": "intensivundersökning",
    "intensivundersökningens": "intensivundersökning",
    "intensivundersöknings": "intensivundersökning",
    "intensivvården": "intensivvård",
    "intensivvårdens": "intensivvård",
    "intensivvårds": "intensivvård",
    "intensivvårdsavdelningar": "intensivvårdsavdelning",
    "intensivvårdsavdelningarna": "intensivvårdsavdelning",
    "intensivvårdsavdelningarnas": "intensivvårdsavdelning",
    "intensivvårdsavdelningars": "intensivvårdsavdelning",
    "intensivvårdsavdelningen": "intensivvårdsavdelning",
    "intensivvårdsavdelningens": "intensivvårdsavdelning",
    "intensivvårdsavdelnings": "intensivvårdsavdelning",
    "intensivvårdsutrustningar": "intensivvårdsutrustning",
    "intensivvårdsutrustningarna": "intensivvårdsutrustning",
    "intensivvårdsutrustningarnas": "intensivvårdsutrustning",
    "intensivvårdsutrustningars": "intensivvårdsutrustning",
    "intensivvårdsutrustningen": "intensivvårdsutrustning",
    "intensivvårdsutrustningens": "intensivvårdsutrustning",
    "intensivvårdsutrustnings": "intensivvårdsutrustning",
    "intentionen": "intention",
    "intentionens": "intention",
    "intentioner": "intention",
    "intentionerna": "intention",
    "intentionernas": "intention",
    "intentioners": "intention",
    "intentions": "intention",
    "intentionsdjupen": "intentionsdjup",
    "intentionsdjupens": "intentionsdjup",
    "intentionsdjupet": "intentionsdjup",
    "intentionsdjupets": "intentionsdjup",
    "intentionsdjups": "intentionsdjup",
    "interagerade": "interagera",
    "interagerades": "interagera",
    "interagerande": "interagera",
    "interageranden": "interagerande",
    "interagerandena": "interagerande",
    "interagerandenas": "interagerande",
    "interagerandens": "interagerande",
    "interagerandes": "interagerande",
    "interagerandet": "interagerande",
    "interagerandets": "interagerande",
    "interagerar": "interagera",
    "interageras": "interagera",
    "interagerat": "interagera",
    "interagerats": "interagera",
    "interageringar": "interagering",
    "interageringarna": "interagering",
    "interageringarnas": "interagering",
    "interageringars": "interagering",
    "interageringen": "interagering",
    "interageringens": "interagering",
    "interagerings": "interagering",
    "interaktionen": "interaktion",
    "interaktionens": "interaktion",
    "interaktioner": "interaktion",
    "interaktionerna": "interaktion",
    "interaktionernas": "interaktion",
    "interaktioners": "interaktion",
    "interaktions": "interaktion",
    "interaktiva": "interaktiv",
    "interaktivare": "interaktiv",
    "interaktivares": "interaktiv",
    "interaktivas": "interaktiv",
    "interaktivast": "interaktiv",
    "interaktivaste": "interaktiv",
    "interaktivastes": "interaktiv",
    "interaktivasts": "interaktiv",
    "interaktive": "interaktiv",
    "interaktives": "interaktiv",
    "interaktivs": "interaktiv",
    "interaktivt": "interaktiv",
    "interaktivts": "interaktiv",
    "intercitytågen": "intercitytåg",
    "intercitytågens": "intercitytåg",
    "intercitytåget": "intercitytåg",
    "intercitytågets": "intercitytåg",
    "intercitytågs": "intercitytåg",
    "interdentala": "interdental",
    "interdentalare": "interdental",
    "interdentalares": "interdental",
    "interdentalas": "interdental",
    "interdentalast": "interdental",
    "interdentalaste": "interdental",
    "interdentalastes": "interdental",
    "interdentalasts": "interdental",
    "interdentale": "interdental",
    "interdentalen": "interdental",
    "interdentalens": "interdental",
    "interdentaler": "interdental",
    "interdentalerna": "interdental",
    "interdentalernas": "interdental",
    "interdentalers": "interdental",
    "interdentales": "interdental",
    "interdentals": "interdental",
    "interdentalt": "interdental",
    "interdentalts": "interdental",
    "interdikten": "interdikt",
    "interdiktens": "interdikt",
    "interdiktet": "interdikt",
    "interdiktets": "interdikt",
    "interdikts": "interdikt",
    "interetniska": "interetnisk",
    "interetniskas": "interetnisk",
    "interetniske": "interetnisk",
    "interetniskes": "interetnisk",
    "interetnisks": "interetnisk",
    "interetniskt": "interetnisk",
    "interetniskts": "interetnisk",
    "interferensen": "interferens",
    "interferensens": "interferens",
    "interferenser": "interferens",
    "interferenserna": "interferens",
    "interferensernas": "interferens",
    "interferensers": "interferens",
    "interferensmönsterna": "interferensmönster",
    "interferensmönsternas": "interferensmönster",
    "interferensmönsters": "interferensmönster",
    "interferensmönstren": "interferensmönster",
    "interferensmönstrens": "interferensmönster",
    "interferensmönstret": "interferensmönster",
    "interferensmönstrets": "interferensmönster",
    "interfererade": "interferera",
    "interfererades": "interferera",
    "interfererande": "interferera",
    "interfereranden": "interfererande",
    "interfererandena": "interfererande",
    "interfererandenas": "interfererande",
    "interfererandens": "interfererande",
    "interfererandes": "interfererande",
    "interfererandet": "interfererande",
    "interfererandets": "interfererande",
    "interfererar": "interferera",
    "interfereras": "interferera",
    "interfererat": "interferera",
    "interfererats": "interferera",
    "interfereringar": "interferering",
    "interfereringarna": "interferering",
    "interfereringarnas": "interferering",
    "interfereringars": "interferering",
    "interfereringen": "interferering",
    "interfereringens": "interferering",
    "interfererings": "interferering",
    "interferonet": "interferon",
    "interferonets": "interferon",
    "interferons": "interferon",
    "interfolierad": "interfoliera",
    "interfolierade": "interfoliera",
    "interfolierades": "interfoliera",
    "interfolierads": "interfoliera",
    "interfolierande": "interfoliera",
    "interfolieranden": "interfolierande",
    "interfolierandena": "interfolierande",
    "interfolierandenas": "interfolierande",
    "interfolierandens": "interfolierande",
    "interfolierandes": "interfolierande",
    "interfolierandet": "interfolierande",
    "interfolierandets": "interfolierande",
    "interfolierar": "interfoliera",
    "interfolieras": "interfoliera",
    "interfolierat": "interfoliera",
    "interfolierats": "interfoliera",
    "interfolierbara": "interfolierbar",
    "interfolierbarare": "interfolierbar",
    "interfolierbarares": "interfolierbar",
    "interfolierbaras": "interfolierbar",
    "interfolierbarast": "interfolierbar",
    "interfolierbaraste": "interfolierbar",
    "interfolierbarastes": "interfolierbar",
    "interfolierbarasts": "interfolierbar",
    "interfolierbare": "interfolierbar",
    "interfolierbares": "interfolierbar",
    "interfolierbarheten": "interfolierbarhet",
    "interfolierbarhetens": "interfolierbarhet",
    "interfolierbarhets": "interfolierbarhet",
    "interfolierbars": "interfolierbar",
    "interfolierbart": "interfolierbar",
    "interfolierbarts": "interfolierbar",
    "interfolieringar": "interfoliering",
    "interfolieringarna": "interfoliering",
    "interfolieringarnas": "interfoliering",
    "interfolieringars": "interfoliering",
    "interfolieringen": "interfoliering",
    "interfolieringens": "interfoliering",
    "interfolierings": "interfoliering",
    "interglaciala": "interglacial",
    "interglacialare": "interglacial",
    "interglacialares": "interglacial",
    "interglacialas": "interglacial",
    "interglacialast": "interglacial",
    "interglacialaste": "interglacial",
    "interglacialastes": "interglacial",
    "interglacialasts": "interglacial",
    "interglaciale": "interglacial",
    "interglacialen": "interglacial",
    "interglacialens": "interglacial",
    "interglacialer": "interglacial",
    "interglacialerna": "interglacial",
    "interglacialernas": "interglacial",
    "interglacialers": "interglacial",
    "interglaciales": "interglacial",
    "interglacials": "interglacial",
    "interglacialt": "interglacial",
    "interglacialts": "interglacial",
    "interimistiska": "interimistisk",
    "interimistiskare": "interimistisk",
    "interimistiskares": "interimistisk",
    "interimistiskas": "interimistisk",
    "interimistiskast": "interimistisk",
    "interimistiskaste": "interimistisk",
    "interimistiskastes": "interimistisk",
    "interimistiskasts": "interimistisk",
    "interimistiske": "interimistisk",
    "interimistiskes": "interimistisk",
    "interimistisks": "interimistisk",
    "interimistiskt": "interimistisk",
    "interimistiskts": "interimistisk",
    "interimsbevisen": "interimsbevis",
    "interimsbevisens": "interimsbevis",
    "interimsbeviset": "interimsbevis",
    "interimsbevisets": "interimsbevis",
    "interimsregeringar": "interimsregering",
    "interimsregeringarna": "interimsregering",
    "interimsregeringarnas": "interimsregering",
    "interimsregeringars": "interimsregering",
    "interimsregeringen": "interimsregering",
    "interimsregeringens": "interimsregering",
    "interimsregerings": "interimsregering",
    "interimsstyrelsen": "interimsstyrelse",
    "interimsstyrelsens": "interimsstyrelse",
    "interimsstyrelser": "interimsstyrelse",
    "interimsstyrelserna": "interimsstyrelse",
    "interimsstyrelsernas": "interimsstyrelse",
    "interimsstyrelsers": "interimsstyrelse",
    "interimsstyrelses": "interimsstyrelse",
    "interiörbelysningar": "interiörbelysning",
    "interiörbelysningarna": "interiörbelysning",
    "interiörbelysningarnas": "interiörbelysning",
    "interiörbelysningars": "interiörbelysning",
    "interiörbelysningen": "interiörbelysning",
    "interiörbelysningens": "interiörbelysning",
    "interiörbelysnings": "interiörbelysning",
    "interiören": "interiör",
    "interiörens": "interiör",
    "interiörer": "interiör",
    "interiörerna": "interiör",
    "interiörernas": "interiör",
    "interiörers": "interiör",
    "interiörs": "interiör",
    "interjektionen": "interjektion",
    "interjektionens": "interjektion",
    "interjektioner": "interjektion",
    "interjektionerna": "interjektion",
    "interjektionernas": "interjektion",
    "interjektioners": "interjektion",
    "interjektions": "interjektion",
    "interkontinentala": "interkontinental",
    "interkontinentalare": "interkontinental",
    "interkontinentalares": "interkontinental",
    "interkontinentalas": "interkontinental",
    "interkontinentalast": "interkontinental",
    "interkontinentalaste": "interkontinental",
    "interkontinentalastes": "interkontinental",
    "interkontinentalasts": "interkontinental",
    "interkontinentale": "interkontinental",
    "interkontinentales": "interkontinental",
    "interkontinentals": "interkontinental",
    "interkontinentalt": "interkontinental",
    "interkontinentalts": "interkontinental",
    "interlokutören": "interlokutör",
    "interlokutörens": "interlokutör",
    "interlokutörer": "interlokutör",
    "interlokutörerna": "interlokutör",
    "interlokutörernas": "interlokutör",
    "interlokutörers": "interlokutör",
    "interlokutörs": "interlokutör",
    "interludie": "interludium",
    "interludier": "interludium",
    "interludierna": "interludium",
    "interludiernas": "interludium",
    "interludiers": "interludium",
    "interludiet": "interludium",
    "interludiets": "interludium",
    "interludiums": "interludium",
    "intermezzon": "intermezzo",
    "intermezzona": "intermezzo",
    "intermezzonas": "intermezzo",
    "intermezzons": "intermezzo",
    "intermezzos": "intermezzo",
    "intermezzot": "intermezzo",
    "intermezzots": "intermezzo",
    "intermittenta": "intermittent",
    "intermittentare": "intermittent",
    "intermittentares": "intermittent",
    "intermittentas": "intermittent",
    "intermittentast": "intermittent",
    "intermittentaste": "intermittent",
    "intermittentastes": "intermittent",
    "intermittentasts": "intermittent",
    "intermittente": "intermittent",
    "intermittentes": "intermittent",
    "intermittents": "intermittent",
    "interna": "intern",
    "internaliserad": "internalisera",
    "internaliserade": "internalisera",
    "internaliserades": "internalisera",
    "internaliserads": "internalisera",
    "internaliserande": "internalisera",
    "internaliseranden": "internaliserande",
    "internaliserandena": "internaliserande",
    "internaliserandenas": "internaliserande",
    "internaliserandens": "internaliserande",
    "internaliserandes": "internaliserande",
    "internaliserandet": "internaliserande",
    "internaliserandets": "internaliserande",
    "internaliserar": "internalisera",
    "internaliseras": "internalisera",
    "internaliserat": "internalisera",
    "internaliserats": "internalisera",
    "internaliserbara": "internaliserbar",
    "internaliserbarare": "internaliserbar",
    "internaliserbarares": "internaliserbar",
    "internaliserbaras": "internaliserbar",
    "internaliserbarast": "internaliserbar",
    "internaliserbaraste": "internaliserbar",
    "internaliserbarastes": "internaliserbar",
    "internaliserbarasts": "internaliserbar",
    "internaliserbare": "internaliserbar",
    "internaliserbares": "internaliserbar",
    "internaliserbarheten": "internaliserbarhet",
    "internaliserbarhetens": "internaliserbarhet",
    "internaliserbarhets": "internaliserbarhet",
    "internaliserbars": "internaliserbar",
    "internaliserbart": "internaliserbar",
    "internaliserbarts": "internaliserbar",
    "internaliseringar": "internalisering",
    "internaliseringarna": "internalisering",
    "internaliseringarnas": "internalisering",
    "internaliseringars": "internalisering",
    "internaliseringen": "internalisering",
    "internaliseringens": "internalisering",
    "internaliserings": "internalisering",
    "internare": "intern",
    "internares": "intern",
    "internas": "intern",
    "internast": "intern",
    "internaste": "intern",
    "internastes": "intern",
    "internasts": "intern",
    "internaten": "internat",
    "internatens": "internat",
    "internatet": "internat",
    "internatets": "internat",
    "internationalen": "international",
    "internationalens": "international",
    "internationaler": "international",
    "internationalerna": "international",
    "internationalernas": "international",
    "internationalers": "international",
    "internationaliserad": "internationalisera",
    "internationaliserade": "internationalisera",
    "internationaliserades": "internationalisera",
    "internationaliserads": "internationalisera",
    "internationaliserande": "internationalisera",
    "internationaliseranden": "internationaliserande",
    "internationaliserandena": "internationaliserande",
    "internationaliserandenas": "internationaliserande",
    "internationaliserandens": "internationaliserande",
    "internationaliserandes": "internationaliserande",
    "internationaliserandet": "internationaliserande",
    "internationaliserandets": "internationaliserande",
    "internationaliserar": "internationalisera",
    "internationaliseras": "internationalisera",
    "internationaliserat": "internationalisera",
    "internationaliserats": "internationalisera",
    "internationaliserbara": "internationaliserbar",
    "internationaliserbarare": "internationaliserbar",
    "internationaliserbarares": "internationaliserbar",
    "internationaliserbaras": "internationaliserbar",
    "internationaliserbarast": "internationaliserbar",
    "internationaliserbaraste": "internationaliserbar",
    "internationaliserbarastes": "internationaliserbar",
    "internationaliserbarasts": "internationaliserbar",
    "internationaliserbare": "internationaliserbar",
    "internationaliserbares": "internationaliserbar",
    "internationaliserbarheten": "internationaliserbarhet",
    "internationaliserbarhetens": "internationaliserbarhet",
    "internationaliserbarhets": "internationaliserbarhet",
    "internationaliserbars": "internationaliserbar",
    "internationaliserbart": "internationaliserbar",
    "internationaliserbarts": "internationaliserbar",
    "internationaliseringar": "internationalisering",
    "internationaliseringarna": "internationalisering",
    "internationaliseringarnas": "internationalisering",
    "internationaliseringars": "internationalisering",
    "internationaliseringen": "internationalisering",
    "internationaliseringens": "internationalisering",
    "internationaliserings": "internationalisering",
    "internationalismen": "internationalism",
    "internationalismens": "internationalism",
    "internationalismer": "internationalism",
    "internationalismerna": "internationalism",
    "internationalismernas": "internationalism",
    "internationalismers": "internationalism",
    "internationalisms": "internationalism",
    "internationalisten": "internationalist",
    "internationalistens": "internationalist",
    "internationalister": "internationalist",
    "internationalisterna": "internationalist",
    "internationalisternas": "internationalist",
    "internationalisters": "internationalist",
    "internationalistiska": "internationalistisk",
    "internationalistiskas": "internationalistisk",
    "internationalistiske": "internationalistisk",
    "internationalistiskes": "internationalistisk",
    "internationalistisks": "internationalistisk",
    "internationalistiskt": "internationalistisk",
    "internationalistiskts": "internationalistisk",
    "internationalists": "internationalist",
    "internationals": "international",
    "internationella": "internationell",
    "internationellare": "internationell",
    "internationellares": "internationell",
    "internationellas": "internationell",
    "internationellast": "internationell",
    "internationellaste": "internationell",
    "internationellastes": "internationell",
    "internationellasts": "internationell",
    "internationelle": "internationell",
    "internationelles": "internationell",
    "internationells": "internationell",
    "internationellt": "internationell",
    "internationellts": "internationell",
    "internats": "internat",
    "internatskolan": "internatskola",
    "internatskolans": "internatskola",
    "internatskolas": "internatskola",
    "internatskole": "internatskola",
    "internatskolor": "internatskola",
    "internatskolorna": "internatskola",
    "internatskolornas": "internatskola",
    "internatskolors": "internatskola",
    "interne": "intern",
    "internen": "intern",
    "internens": "intern",
    "interner": "intern",
    "internerad": "internera",
    "internerade": "internera",
    "internerades": "internera",
    "internerads": "internera",
    "internerande": "internera",
    "interneranden": "internerande",
    "internerandena": "internerande",
    "internerandenas": "internerande",
    "internerandens": "internerande",
    "internerandes": "internerande",
    "internerandet": "internerande",
    "internerandets": "internerande",
    "internerar": "internera",
    "interneras": "internera",
    "internerat": "internera",
    "internerats": "internera",
    "internerbara": "internerbar",
    "internerbarare": "internerbar",
    "internerbarares": "internerbar",
    "internerbaras": "internerbar",
    "internerbarast": "internerbar",
    "internerbaraste": "internerbar",
    "internerbarastes": "internerbar",
    "internerbarasts": "internerbar",
    "internerbare": "internerbar",
    "internerbares": "internerbar",
    "internerbarheten": "internerbarhet",
    "internerbarhetens": "internerbarhet",
    "internerbarhets": "internerbarhet",
    "internerbars": "internerbar",
    "internerbart": "internerbar",
    "internerbarts": "internerbar",
    "interneringar": "internering",
    "interneringarna": "internering",
    "interneringarnas": "internering",
    "interneringars": "internering",
    "interneringen": "internering",
    "interneringens": "internering",
    "internerings": "internering",
    "interneringslägerna": "interneringsläger",
    "interneringslägernas": "interneringsläger",
    "interneringslägers": "interneringsläger",
    "interneringslägren": "interneringsläger",
    "interneringslägrens": "interneringsläger",
    "interneringslägret": "interneringsläger",
    "interneringslägrets": "interneringsläger",
    "internerna": "intern",
    "internernas": "intern",
    "interners": "intern",
    "internes": "intern",
    "internetanvändar": "internetanvändare",
    "internetanvändaren": "internetanvändare",
    "internetanvändarens": "internetanvändare",
    "internetanvändares": "internetanvändare",
    "internetanvändarna": "internetanvändare",
    "internetanvändarnas": "internetanvändare",
    "internetartikeln": "internetartikel",
    "internetartikelns": "internetartikel",
    "internetartikels": "internetartikel",
    "internetartiklar": "internetartikel",
    "internetartiklarna": "internetartikel",
    "internetartiklarnas": "internetartikel",
    "internetartiklars": "internetartikel",
    "internetoperatören": "internetoperatör",
    "internetoperatörens": "internetoperatör",
    "internetoperatörer": "internetoperatör",
    "internetoperatörerna": "internetoperatör",
    "internetoperatörernas": "internetoperatör",
    "internetoperatörers": "internetoperatör",
    "internetoperatörs": "internetoperatör",
    "internetrelaterade": "internetrelaterad",
    "internetrelaterades": "internetrelaterad",
    "internetrelaterads": "internetrelaterad",
    "internetrelaterat": "internetrelaterad",
    "internetrelaterats": "internetrelaterad",
    "internetsidan": "internetsida",
    "internetsidans": "internetsida",
    "internetsidas": "internetsida",
    "internetside": "internetsida",
    "internetsides": "internetsida",
    "internetsidor": "internetsida",
    "internetsidorna": "internetsida",
    "internetsidornas": "internetsida",
    "internetsidors": "internetsida",
    "internisten": "internist",
    "internistens": "internist",
    "internister": "internist",
    "internisterna": "internist",
    "internisternas": "internist",
    "internisters": "internist",
    "internists": "internist",
    "internordiska": "internordisk",
    "internordiskare": "internordisk",
    "internordiskares": "internordisk",
    "internordiskas": "internordisk",
    "internordiskast": "internordisk",
    "internordiskaste": "internordisk",
    "internordiskastes": "internordisk",
    "internordiskasts": "internordisk",
    "internordiske": "internordisk",
    "internordiskes": "internordisk",
    "internordisks": "internordisk",
    "internordiskt": "internordisk",
    "internordiskts": "internordisk",
    "interns": "intern",
    "internt": "intern",
    "internts": "intern",
    "internutbildningar": "internutbildning",
    "internutbildningarna": "internutbildning",
    "internutbildningarnas": "internutbildning",
    "internutbildningars": "internutbildning",
    "internutbildningen": "internutbildning",
    "internutbildningens": "internutbildning",
    "internutbildnings": "internutbildning",
    "internutredningar": "internutredning",
    "internutredningarna": "internutredning",
    "internutredningarnas": "internutredning",
    "internutredningars": "internutredning",
    "internutredningen": "internutredning",
    "internutredningens": "internutredning",
    "internutrednings": "internutredning",
    "internutredningsgruppen": "internutredningsgrupp",
    "internutredningsgruppens": "internutredningsgrupp",
    "internutredningsgrupper": "internutredningsgrupp",
    "internutredningsgrupperna": "internutredningsgrupp",
    "internutredningsgruppernas": "internutredningsgrupp",
    "internutredningsgruppers": "internutredningsgrupp",
    "internutredningsgrupps": "internutredningsgrupp",
    "interpellanten": "interpellant",
    "interpellantens": "interpellant",
    "interpellanter": "interpellant",
    "interpellanterna": "interpellant",
    "interpellanternas": "interpellant",
    "interpellanters": "interpellant",
    "interpellants": "interpellant",
    "interpellationen": "interpellation",
    "interpellationens": "interpellation",
    "interpellationer": "interpellation",
    "interpellationerna": "interpellation",
    "interpellationernas": "interpellation",
    "interpellationers": "interpellation",
    "interpellations": "interpellation",
    "interpellationsdebatten": "interpellationsdebatt",
    "interpellationsdebattens": "interpellationsdebatt",
    "interpellationsdebatter": "interpellationsdebatt",
    "interpellationsdebatterna": "interpellationsdebatt",
    "interpellationsdebatternas": "interpellationsdebatt",
    "interpellationsdebatters": "interpellationsdebatt",
    "interpellationsdebatts": "interpellationsdebatt",
    "interpellerad": "interpellera",
    "interpellerade": "interpellera",
    "interpellerades": "interpellera",
    "interpellerads": "interpellera",
    "interpellerande": "interpellera",
    "interpelleranden": "interpellerande",
    "interpellerandena": "interpellerande",
    "interpellerandenas": "interpellerande",
    "interpellerandens": "interpellerande",
    "interpellerandes": "interpellerande",
    "interpellerandet": "interpellerande",
    "interpellerandets": "interpellerande",
    "interpellerar": "interpellera",
    "interpelleras": "interpellera",
    "interpellerat": "interpellera",
    "interpellerats": "interpellera",
    "interpellerbara": "interpellerbar",
    "interpellerbarare": "interpellerbar",
    "interpellerbarares": "interpellerbar",
    "interpellerbaras": "interpellerbar",
    "interpellerbarast": "interpellerbar",
    "interpellerbaraste": "interpellerbar",
    "interpellerbarastes": "interpellerbar",
    "interpellerbarasts": "interpellerbar",
    "interpellerbare": "interpellerbar",
    "interpellerbares": "interpellerbar",
    "interpellerbarheten": "interpellerbarhet",
    "interpellerbarhetens": "interpellerbarhet",
    "interpellerbarhets": "interpellerbarhet",
    "interpellerbars": "interpellerbar",
    "interpellerbart": "interpellerbar",
    "interpellerbarts": "interpellerbar",
    "interpelleringar": "interpellering",
    "interpelleringarna": "interpellering",
    "interpelleringarnas": "interpellering",
    "interpelleringars": "interpellering",
    "interpelleringen": "interpellering",
    "interpelleringens": "interpellering",
    "interpellerings": "interpellering",
    "interplanetariska": "interplanetarisk",
    "interplanetariskare": "interplanetarisk",
    "interplanetariskares": "interplanetarisk",
    "interplanetariskas": "interplanetarisk",
    "interplanetariskast": "interplanetarisk",
    "interplanetariskaste": "interplanetarisk",
    "interplanetariskastes": "interplanetarisk",
    "interplanetariskasts": "interplanetarisk",
    "interplanetariske": "interplanetarisk",
    "interplanetariskes": "interplanetarisk",
    "interplanetarisks": "interplanetarisk",
    "interplanetariskt": "interplanetarisk",
    "interplanetariskts": "interplanetarisk",
    "interpolationen": "interpolation",
    "interpolationens": "interpolation",
    "interpolationer": "interpolation",
    "interpolationerna": "interpolation",
    "interpolationernas": "interpolation",
    "interpolationers": "interpolation",
    "interpolations": "interpolation",
    "interpolerad": "interpolera",
    "interpolerade": "interpolera",
    "interpolerades": "interpolera",
    "interpolerads": "interpolera",
    "interpolerande": "interpolera",
    "interpoleranden": "interpolerande",
    "interpolerandena": "interpolerande",
    "interpolerandenas": "interpolerande",
    "interpolerandens": "interpolerande",
    "interpolerandes": "interpolerande",
    "interpolerandet": "interpolerande",
    "interpolerandets": "interpolerande",
    "interpolerar": "interpolera",
    "interpoleras": "interpolera",
    "interpolerat": "interpolera",
    "interpolerats": "interpolera",
    "interpolerbara": "interpolerbar",
    "interpolerbarare": "interpolerbar",
    "interpolerbarares": "interpolerbar",
    "interpolerbaras": "interpolerbar",
    "interpolerbarast": "interpolerbar",
    "interpolerbaraste": "interpolerbar",
    "interpolerbarastes": "interpolerbar",
    "interpolerbarasts": "interpolerbar",
    "interpolerbare": "interpolerbar",
    "interpolerbares": "interpolerbar",
    "interpolerbarheten": "interpolerbarhet",
    "interpolerbarhetens": "interpolerbarhet",
    "interpolerbarhets": "interpolerbarhet",
    "interpolerbars": "interpolerbar",
    "interpolerbart": "interpolerbar",
    "interpolerbarts": "interpolerbar",
    "interpoleringar": "interpolering",
    "interpoleringarna": "interpolering",
    "interpoleringarnas": "interpolering",
    "interpoleringars": "interpolering",
    "interpoleringen": "interpolering",
    "interpoleringens": "interpolering",
    "interpolerings": "interpolering",
    "interpretationen": "interpretation",
    "interpretationens": "interpretation",
    "interpretationer": "interpretation",
    "interpretationerna": "interpretation",
    "interpretationernas": "interpretation",
    "interpretationers": "interpretation",
    "interpretations": "interpretation",
    "interpreten": "interpret",
    "interpretens": "interpret",
    "interpreter": "interpret",
    "interpreterad": "interpretera",
    "interpreterade": "interpretera",
    "interpreterades": "interpretera",
    "interpreterads": "interpretera",
    "interpreterande": "interpretera",
    "interpreteranden": "interpreterande",
    "interpreterandena": "interpreterande",
    "interpreterandenas": "interpreterande",
    "interpreterandens": "interpreterande",
    "interpreterandes": "interpreterande",
    "interpreterandet": "interpreterande",
    "interpreterandets": "interpreterande",
    "interpreterar": "interpretera",
    "interpreteras": "interpretera",
    "interpreterat": "interpretera",
    "interpreterats": "interpretera",
    "interpreterbara": "interpreterbar",
    "interpreterbarare": "interpreterbar",
    "interpreterbarares": "interpreterbar",
    "interpreterbaras": "interpreterbar",
    "interpreterbarast": "interpreterbar",
    "interpreterbaraste": "interpreterbar",
    "interpreterbarastes": "interpreterbar",
    "interpreterbarasts": "interpreterbar",
    "interpreterbare": "interpreterbar",
    "interpreterbares": "interpreterbar",
    "interpreterbarheten": "interpreterbarhet",
    "interpreterbarhetens": "interpreterbarhet",
    "interpreterbarhets": "interpreterbarhet",
    "interpreterbars": "interpreterbar",
    "interpreterbart": "interpreterbar",
    "interpreterbarts": "interpreterbar",
    "interpreteringar": "interpretering",
    "interpreteringarna": "interpretering",
    "interpreteringarnas": "interpretering",
    "interpreteringars": "interpretering",
    "interpreteringen": "interpretering",
    "interpreteringens": "interpretering",
    "interpreterings": "interpretering",
    "interpreterna": "interpret",
    "interpreternas": "interpret",
    "interpreters": "interpret",
    "interprets": "interpret",
    "interpunkterad": "interpunktera",
    "interpunkterade": "interpunktera",
    "interpunkterades": "interpunktera",
    "interpunkterads": "interpunktera",
    "interpunkterande": "interpunktera",
    "interpunkteranden": "interpunkterande",
    "interpunkterandena": "interpunkterande",
    "interpunkterandenas": "interpunkterande",
    "interpunkterandens": "interpunkterande",
    "interpunkterandes": "interpunkterande",
    "interpunkterandet": "interpunkterande",
    "interpunkterandets": "interpunkterande",
    "interpunkterar": "interpunktera",
    "interpunkteras": "interpunktera",
    "interpunkterat": "interpunktera",
    "interpunkterats": "interpunktera",
    "interpunkterbara": "interpunkterbar",
    "interpunkterbarare": "interpunkterbar",
    "interpunkterbarares": "interpunkterbar",
    "interpunkterbaras": "interpunkterbar",
    "interpunkterbarast": "interpunkterbar",
    "interpunkterbaraste": "interpunkterbar",
    "interpunkterbarastes": "interpunkterbar",
    "interpunkterbarasts": "interpunkterbar",
    "interpunkterbare": "interpunkterbar",
    "interpunkterbares": "interpunkterbar",
    "interpunkterbarheten": "interpunkterbarhet",
    "interpunkterbarhetens": "interpunkterbarhet",
    "interpunkterbarhets": "interpunkterbarhet",
    "interpunkterbars": "interpunkterbar",
    "interpunkterbart": "interpunkterbar",
    "interpunkterbarts": "interpunkterbar",
    "interpunkteringar": "interpunktering",
    "interpunkteringarna": "interpunktering",
    "interpunkteringarnas": "interpunktering",
    "interpunkteringars": "interpunktering",
    "interpunkteringen": "interpunktering",
    "interpunkteringens": "interpunktering",
    "interpunkterings": "interpunktering",
    "interpunktionen": "interpunktion",
    "interpunktionens": "interpunktion",
    "interpunktioner": "interpunktion",
    "interpunktionerna": "interpunktion",
    "interpunktionernas": "interpunktion",
    "interpunktioners": "interpunktion",
    "interpunktions": "interpunktion",
    "interregnumen": "interregnum",
    "interregnumens": "interregnum",
    "interregnumet": "interregnum",
    "interregnumets": "interregnum",
    "interregnums": "interregnum",
    "interrimspresidenten": "interrimspresident",
    "interrimspresidentens": "interrimspresident",
    "interrimspresidenter": "interrimspresident",
    "interrimspresidenterna": "interrimspresident",
    "interrimspresidenternas": "interrimspresident",
    "interrimspresidenters": "interrimspresident",
    "interrimspresidents": "interrimspresident",
    "interrogativa": "interrogativ",
    "interrogativare": "interrogativ",
    "interrogativares": "interrogativ",
    "interrogativas": "interrogativ",
    "interrogativast": "interrogativ",
    "interrogativaste": "interrogativ",
    "interrogativastes": "interrogativ",
    "interrogativasts": "interrogativ",
    "interrogative": "interrogativ",
    "interrogatives": "interrogativ",
    "interrogativs": "interrogativ",
    "interrogativt": "interrogativ",
    "interrogativts": "interrogativ",
    "interstellära": "interstellär",
    "interstellärare": "interstellär",
    "interstellärares": "interstellär",
    "interstelläras": "interstellär",
    "interstellärast": "interstellär",
    "interstelläraste": "interstellär",
    "interstellärastes": "interstellär",
    "interstellärasts": "interstellär",
    "interstelläre": "interstellär",
    "interstelläres": "interstellär",
    "interstellärs": "interstellär",
    "interstellärt": "interstellär",
    "interstellärts": "interstellär",
    "interurbana": "interurban",
    "interurbanare": "interurban",
    "interurbanares": "interurban",
    "interurbanas": "interurban",
    "interurbanast": "interurban",
    "interurbanaste": "interurban",
    "interurbanastes": "interurban",
    "interurbanasts": "interurban",
    "interurbane": "interurban",
    "interurbanes": "interurban",
    "interurbans": "interurban",
    "interurbant": "interurban",
    "interurbants": "interurban",
    "intervallen": "intervall",
    "intervallens": "intervall",
    "intervaller": "intervall",
    "intervallerna": "intervall",
    "intervallernas": "intervall",
    "intervallers": "intervall",
    "intervallet": "intervall",
    "intervallets": "intervall",
    "intervalls": "intervall",
    "intervenerad": "intervenera",
    "intervenerade": "intervenera",
    "intervenerades": "intervenera",
    "intervenerads": "intervenera",
    "intervenerande": "intervenera",
    "interveneranden": "intervenerande",
    "intervenerandena": "intervenerande",
    "intervenerandenas": "intervenerande",
    "intervenerandens": "intervenerande",
    "intervenerandes": "intervenerande",
    "intervenerandet": "intervenerande",
    "intervenerandets": "intervenerande",
    "intervenerar": "intervenera",
    "interveneras": "intervenera",
    "intervenerat": "intervenera",
    "intervenerats": "intervenera",
    "intervenerbara": "intervenerbar",
    "intervenerbarare": "intervenerbar",
    "intervenerbarares": "intervenerbar",
    "intervenerbaras": "intervenerbar",
    "intervenerbarast": "intervenerbar",
    "intervenerbaraste": "intervenerbar",
    "intervenerbarastes": "intervenerbar",
    "intervenerbarasts": "intervenerbar",
    "intervenerbare": "intervenerbar",
    "intervenerbares": "intervenerbar",
    "intervenerbarheten": "intervenerbarhet",
    "intervenerbarhetens": "intervenerbarhet",
    "intervenerbarhets": "intervenerbarhet",
    "intervenerbars": "intervenerbar",
    "intervenerbart": "intervenerbar",
    "intervenerbarts": "intervenerbar",
    "interveneringar": "intervenering",
    "interveneringarna": "intervenering",
    "interveneringarnas": "intervenering",
    "interveneringars": "intervenering",
    "interveneringen": "intervenering",
    "interveneringens": "intervenering",
    "intervenerings": "intervenering",
    "interventionen": "intervention",
    "interventionens": "intervention",
    "interventioner": "intervention",
    "interventionerna": "intervention",
    "interventionernas": "intervention",
    "interventioners": "intervention",
    "interventions": "intervention",
    "intervju": "intervjua",
    "intervjuad": "intervjua",
    "intervjuade": "intervjua",
    "intervjuades": "intervjua",
    "intervjuads": "intervjua",
    "intervjuande": "intervjua",
    "intervjuanden": "intervjuande",
    "intervjuandena": "intervjuande",
    "intervjuandenas": "intervjuande",
    "intervjuandens": "intervjuande",
    "intervjuandes": "intervjuande",
    "intervjuandet": "intervjuande",
    "intervjuandets": "intervjuande",
    "intervjuar": "intervjuare",
    "intervjuaren": "intervjuare",
    "intervjuarens": "intervjuare",
    "intervjuares": "intervjuare",
    "intervjuarna": "intervjuare",
    "intervjuarnas": "intervjuare",
    "intervjuas": "intervjua",
    "intervjuat": "intervjua",
    "intervjuats": "intervjua",
    "intervjuer": "intervju",
    "intervjuerna": "intervju",
    "intervjuernas": "intervju",
    "intervjuers": "intervju",
    "intervjufrågan": "intervjufråga",
    "intervjufrågans": "intervjufråga",
    "intervjufrågas": "intervjufråga",
    "intervjufråge": "intervjufråga",
    "intervjufrågor": "intervjufråga",
    "intervjufrågorna": "intervjufråga",
    "intervjufrågornas": "intervjufråga",
    "intervjufrågors": "intervjufråga",
    "intervjun": "intervju",
    "intervjuns": "intervju",
    "intervjuobjekten": "intervjuobjekt",
    "intervjuobjektens": "intervjuobjekt",
    "intervjuobjektet": "intervjuobjekt",
    "intervjuobjektets": "intervjuobjekt",
    "intervjuobjekts": "intervjuobjekt",
    "intervjuoffers": "intervjuoffer",
    "intervjuoffren": "intervjuoffer",
    "intervjuoffrens": "intervjuoffer",
    "intervjuoffret": "intervjuoffer",
    "intervjuoffrets": "intervjuoffer",
    "intervjus": "intervju",
    "intervjuundersökningar": "intervjuundersökning",
    "intervjuundersökningarna": "intervjuundersökning",
    "intervjuundersökningarnas": "intervjuundersökning",
    "intervjuundersökningars": "intervjuundersökning",
    "intervjuundersökningen": "intervjuundersökning",
    "intervjuundersökningens": "intervjuundersökning",
    "intervjuundersöknings": "intervjuundersökning",
    "intervokaliska": "intervokalisk",
    "intervokaliskare": "intervokalisk",
    "intervokaliskares": "intervokalisk",
    "intervokaliskas": "intervokalisk",
    "intervokaliskast": "intervokalisk",
    "intervokaliskaste": "intervokalisk",
    "intervokaliskastes": "intervokalisk",
    "intervokaliskasts": "intervokalisk",
    "intervokaliske": "intervokalisk",
    "intervokaliskes": "intervokalisk",
    "intervokalisks": "intervokalisk",
    "intervokaliskt": "intervokalisk",
    "intervokaliskts": "intervokalisk",
    "intestatarven": "intestatarv",
    "intestatarvens": "intestatarv",
    "intestatarvet": "intestatarv",
    "intestatarvets": "intestatarv",
    "intestatarvs": "intestatarv",
    "intetderas": "intetdera",
    "intets": "intet",
    "intiga": "intig",
    "intigare": "intig",
    "intigares": "intig",
    "intigas": "intig",
    "intigast": "intig",
    "intigaste": "intig",
    "intigastes": "intig",
    "intigasts": "intig",
    "intige": "intig",
    "intiges": "intig",
    "intigheten": "intighet",
    "intighetens": "intighet",
    "intigheter": "intighet",
    "intigheterna": "intighet",
    "intigheternas": "intighet",
    "intigheters": "intighet",
    "intighets": "intighet",
    "intigs": "intig",
    "intigt": "intig",
    "intigts": "intig",
    "intima": "intim",
    "intimare": "intim",
    "intimares": "intim",
    "intimas": "intim",
    "intimast": "intim",
    "intimaste": "intim",
    "intimastes": "intim",
    "intimasts": "intim",
    "intime": "intim",
    "intimes": "intim",
    "intimhygienen": "intimhygien",
    "intimhygienens": "intimhygien",
    "intimhygiens": "intimhygien",
    "intimisten": "intimist",
    "intimistens": "intimist",
    "intimister": "intimist",
    "intimisterna": "intimist",
    "intimisternas": "intimist",
    "intimisters": "intimist",
    "intimists": "intimist",
    "intimiteten": "intimitet",
    "intimitetens": "intimitet",
    "intimiteter": "intimitet",
    "intimiteterna": "intimitet",
    "intimiteternas": "intimitet",
    "intimiteters": "intimitet",
    "intimitets": "intimitet",
    "intimitetsstörningar": "intimitetsstörning",
    "intimitetsstörningarna": "intimitetsstörning",
    "intimitetsstörningarnas": "intimitetsstörning",
    "intimitetsstörningars": "intimitetsstörning",
    "intimitetsstörningen": "intimitetsstörning",
    "intimitetsstörningens": "intimitetsstörning",
    "intimitetsstörnings": "intimitetsstörning",
    "intimrakningen": "intimrakning",
    "intimrakningens": "intimrakning",
    "intimraknings": "intimrakning",
    "intims": "intim",
    "intimsfären": "intimsfär",
    "intimsfärens": "intimsfär",
    "intimsfärs": "intimsfär",
    "intimt": "intim",
    "intimts": "intim",
    "intjacken": "intjack",
    "intjackens": "intjack",
    "intjacket": "intjack",
    "intjackets": "intjack",
    "intjacks": "intjack",
    "intjänandetiden": "intjänandetid",
    "intjänandetidens": "intjänandetid",
    "intjänandetider": "intjänandetid",
    "intjänandetiderna": "intjänandetid",
    "intjänandetidernas": "intjänandetid",
    "intjänandetiders": "intjänandetid",
    "intjänandetids": "intjänandetid",
    "intog": "inta",
    "intoge": "inta",
    "intoges": "inta",
    "intogs": "inta",
    "intolerabels": "intolerabel",
    "intolerabelt": "intolerabel",
    "intolerabelts": "intolerabel",
    "intolerabla": "intolerabel",
    "intolerablare": "intolerabel",
    "intolerablares": "intolerabel",
    "intolerablas": "intolerabel",
    "intolerablast": "intolerabel",
    "intolerablaste": "intolerabel",
    "intolerablastes": "intolerabel",
    "intolerablasts": "intolerabel",
    "intolerable": "intolerabel",
    "intolerables": "intolerabel",
    "intoleransen": "intolerans",
    "intoleransens": "intolerans",
    "intoleranta": "intolerant",
    "intolerantare": "intolerant",
    "intolerantares": "intolerant",
    "intolerantas": "intolerant",
    "intolerantast": "intolerant",
    "intolerantaste": "intolerant",
    "intolerantastes": "intolerant",
    "intolerantasts": "intolerant",
    "intolerante": "intolerant",
    "intolerantes": "intolerant",
    "intolerants": "intolerant",
    "intolk": "intolka",
    "intolkad": "intolka",
    "intolkade": "intolka",
    "intolkades": "intolka",
    "intolkads": "intolka",
    "intolkande": "intolka",
    "intolkanden": "intolkande",
    "intolkandena": "intolkande",
    "intolkandenas": "intolkande",
    "intolkandens": "intolkande",
    "intolkandes": "intolkande",
    "intolkandet": "intolkande",
    "intolkandets": "intolkande",
    "intolkar": "intolka",
    "intolkas": "intolka",
    "intolkat": "intolka",
    "intolkats": "intolka",
    "intonationen": "intonation",
    "intonationens": "intonation",
    "intonationer": "intonation",
    "intonationerna": "intonation",
    "intonationernas": "intonation",
    "intonationers": "intonation",
    "intonations": "intonation",
    "intonerad": "intonera",
    "intonerade": "intonera",
    "intonerades": "intonera",
    "intonerads": "intonera",
    "intonerande": "intonera",
    "intoneranden": "intonerande",
    "intonerandena": "intonerande",
    "intonerandenas": "intonerande",
    "intonerandens": "intonerande",
    "intonerandes": "intonerande",
    "intonerandet": "intonerande",
    "intonerandets": "intonerande",
    "intonerar": "intonera",
    "intoneras": "intonera",
    "intonerat": "intonera",
    "intonerats": "intonera",
    "intonerbara": "intonerbar",
    "intonerbarare": "intonerbar",
    "intonerbarares": "intonerbar",
    "intonerbaras": "intonerbar",
    "intonerbarast": "intonerbar",
    "intonerbaraste": "intonerbar",
    "intonerbarastes": "intonerbar",
    "intonerbarasts": "intonerbar",
    "intonerbare": "intonerbar",
    "intonerbares": "intonerbar",
    "intonerbarheten": "intonerbarhet",
    "intonerbarhetens": "intonerbarhet",
    "intonerbarhets": "intonerbarhet",
    "intonerbars": "intonerbar",
    "intonerbart": "intonerbar",
    "intonerbarts": "intonerbar",
    "intoneringar": "intonering",
    "intoneringarna": "intonering",
    "intoneringarnas": "intonering",
    "intoneringars": "intonering",
    "intoneringen": "intonering",
    "intoneringens": "intonering",
    "intonerings": "intonering",
    "intorkningar": "intorkning",
    "intorkningarna": "intorkning",
    "intorkningarnas": "intorkning",
    "intorkningars": "intorkning",
    "intorkningen": "intorkning",
    "intorkningens": "intorkning",
    "intorknings": "intorkning",
    "intoxikationen": "intoxikation",
    "intoxikationens": "intoxikation",
    "intoxikationer": "intoxikation",
    "intoxikationerna": "intoxikation",
    "intoxikationernas": "intoxikation",
    "intoxikationers": "intoxikation",
    "intoxikations": "intoxikation",
    "intransigenta": "intransigent",
    "intransigentare": "intransigent",
    "intransigentares": "intransigent",
    "intransigentas": "intransigent",
    "intransigentast": "intransigent",
    "intransigentaste": "intransigent",
    "intransigentastes": "intransigent",
    "intransigentasts": "intransigent",
    "intransigente": "intransigent",
    "intransigentes": "intransigent",
    "intransigents": "intransigent",
    "intransitiva": "intransitiv",
    "intransitivare": "intransitiv",
    "intransitivares": "intransitiv",
    "intransitivas": "intransitiv",
    "intransitivast": "intransitiv",
    "intransitivaste": "intransitiv",
    "intransitivastes": "intransitiv",
    "intransitivasts": "intransitiv",
    "intransitive": "intransitiv",
    "intransitives": "intransitiv",
    "intransitivs": "intransitiv",
    "intransitivt": "intransitiv",
    "intransitivts": "intransitiv",
    "intranäten": "intranät",
    "intranätens": "intranät",
    "intranätet": "intranät",
    "intranätets": "intranät",
    "intranäts": "intranät",
    "intravenösa": "intravenös",
    "intravenösare": "intravenös",
    "intravenösares": "intravenös",
    "intravenösas": "intravenös",
    "intravenösast": "intravenös",
    "intravenösaste": "intravenös",
    "intravenösastes": "intravenös",
    "intravenösasts": "intravenös",
    "intravenöse": "intravenös",
    "intravenöses": "intravenös",
    "intravenöst": "intravenös",
    "intravenösts": "intravenös",
    "intressanta": "intressant",
    "intressantare": "intressant",
    "intressantares": "intressant",
    "intressantas": "intressant",
    "intressantast": "intressant",
    "intressantaste": "intressant",
    "intressantastes": "intressant",
    "intressantasts": "intressant",
    "intressante": "intressant",
    "intressantes": "intressant",
    "intressants": "intressant",
    "intressegemenskapen": "intressegemenskap",
    "intressegemenskapens": "intressegemenskap",
    "intressegemenskaper": "intressegemenskap",
    "intressegemenskaperna": "intressegemenskap",
    "intressegemenskapernas": "intressegemenskap",
    "intressegemenskapers": "intressegemenskap",
    "intressegemenskaps": "intressegemenskap",
    "intressegruppen": "intressegrupp",
    "intressegruppens": "intressegrupp",
    "intressegrupper": "intressegrupp",
    "intressegrupperna": "intressegrupp",
    "intressegruppernas": "intressegrupp",
    "intressegruppers": "intressegrupp",
    "intressegrupps": "intressegrupp",
    "intressekonflikten": "intressekonflikt",
    "intressekonfliktens": "intressekonflikt",
    "intressekonflikter": "intressekonflikt",
    "intressekonflikterna": "intressekonflikt",
    "intressekonflikternas": "intressekonflikt",
    "intressekonflikters": "intressekonflikt",
    "intressekonflikts": "intressekonflikt",
    "intresselösa": "intresselös",
    "intresselösare": "intresselös",
    "intresselösares": "intresselös",
    "intresselösas": "intresselös",
    "intresselösast": "intresselös",
    "intresselösaste": "intresselös",
    "intresselösastes": "intresselös",
    "intresselösasts": "intresselös",
    "intresselöse": "intresselös",
    "intresselöses": "intresselös",
    "intresselösheten": "intresselöshet",
    "intresselöshetens": "intresselöshet",
    "intresselöshets": "intresselöshet",
    "intresselöst": "intresselös",
    "intresselösts": "intresselös",
    "intressemässiga": "intressemässig",
    "intressemässigare": "intressemässig",
    "intressemässigares": "intressemässig",
    "intressemässigas": "intressemässig",
    "intressemässigast": "intressemässig",
    "intressemässigaste": "intressemässig",
    "intressemässigastes": "intressemässig",
    "intressemässigasts": "intressemässig",
    "intressemässige": "intressemässig",
    "intressemässiges": "intressemässig",
    "intressemässigs": "intressemässig",
    "intressemässigt": "intressemässig",
    "intressemässigts": "intressemässig",
    "intressen": "intresse",
    "intressena": "intresse",
    "intressenas": "intresse",
    "intressens": "intresse",
    "intressenten": "intressent",
    "intressentens": "intressent",
    "intressenter": "intressent",
    "intressenterna": "intressent",
    "intressenternas": "intressent",
    "intressenters": "intressent",
    "intressents": "intressent",
    "intresseområden": "intresseområde",
    "intresseområdena": "intresseområde",
    "intresseområdenas": "intresseområde",
    "intresseområdens": "intresseområde",
    "intresseområdes": "intresseområde",
    "intresseområdet": "intresseområde",
    "intresseområdets": "intresseområde",
    "intresseorganisationen": "intresseorganisation",
    "intresseorganisationens": "intresseorganisation",
    "intresseorganisationer": "intresseorganisation",
    "intresseorganisationerna": "intresseorganisation",
    "intresseorganisationernas": "intresseorganisation",
    "intresseorganisationers": "intresseorganisation",
    "intresseorganisations": "intresseorganisation",
    "intresserad": "intressera",
    "intresserade": "intresserad",
    "intresserades": "intresserad",
    "intresserads": "intresserad",
    "intresserande": "intressera",
    "intresseranden": "intresserande",
    "intresserandena": "intresserande",
    "intresserandenas": "intresserande",
    "intresserandens": "intresserande",
    "intresserandes": "intresserande",
    "intresserandet": "intresserande",
    "intresserandets": "intresserande",
    "intresserar": "intressera",
    "intresseras": "intressera",
    "intresserat": "intresserad",
    "intresserats": "intresserad",
    "intresserbara": "intresserbar",
    "intresserbarare": "intresserbar",
    "intresserbarares": "intresserbar",
    "intresserbaras": "intresserbar",
    "intresserbarast": "intresserbar",
    "intresserbaraste": "intresserbar",
    "intresserbarastes": "intresserbar",
    "intresserbarasts": "intresserbar",
    "intresserbare": "intresserbar",
    "intresserbares": "intresserbar",
    "intresserbarheten": "intresserbarhet",
    "intresserbarhetens": "intresserbarhet",
    "intresserbarhets": "intresserbarhet",
    "intresserbars": "intresserbar",
    "intresserbart": "intresserbar",
    "intresserbarts": "intresserbar",
    "intresseringar": "intressering",
    "intresseringarna": "intressering",
    "intresseringarnas": "intressering",
    "intresseringars": "intressering",
    "intresseringen": "intressering",
    "intresseringens": "intressering",
    "intresserings": "intressering",
    "intresses": "intresse",
    "intressesfären": "intressesfär",
    "intressesfärens": "intressesfär",
    "intressesfärer": "intressesfär",
    "intressesfärerna": "intressesfär",
    "intressesfärernas": "intressesfär",
    "intressesfärers": "intressesfär",
    "intressesfärs": "intressesfär",
    "intresset": "intresse",
    "intressets": "intresse",
    "intriganta": "intrigant",
    "intrigantare": "intrigant",
    "intrigantares": "intrigant",
    "intrigantas": "intrigant",
    "intrigantast": "intrigant",
    "intrigantaste": "intrigant",
    "intrigantastes": "intrigant",
    "intrigantasts": "intrigant",
    "intrigante": "intrigant",
    "intriganten": "intrigant",
    "intrigantens": "intrigant",
    "intriganter": "intrigant",
    "intriganterna": "intrigant",
    "intriganternas": "intrigant",
    "intriganters": "intrigant",
    "intrigantes": "intrigant",
    "intrigants": "intrigant",
    "intrigen": "intrig",
    "intrigens": "intrig",
    "intriger": "intrig",
    "intrigerade": "intrigera",
    "intrigerades": "intrigera",
    "intrigerande": "intrigera",
    "intrigeranden": "intrigerande",
    "intrigerandena": "intrigerande",
    "intrigerandenas": "intrigerande",
    "intrigerandens": "intrigerande",
    "intrigerandes": "intrigerande",
    "intrigerandet": "intrigerande",
    "intrigerandets": "intrigerande",
    "intrigerar": "intrigera",
    "intrigeras": "intrigera",
    "intrigerat": "intrigera",
    "intrigerats": "intrigera",
    "intrigeringar": "intrigering",
    "intrigeringarna": "intrigering",
    "intrigeringarnas": "intrigering",
    "intrigeringars": "intrigering",
    "intrigeringen": "intrigering",
    "intrigeringens": "intrigering",
    "intrigerings": "intrigering",
    "intrigerna": "intrig",
    "intrigernas": "intrig",
    "intrigers": "intrig",
    "intrigmässiga": "intrigmässig",
    "intrigmässigare": "intrigmässig",
    "intrigmässigares": "intrigmässig",
    "intrigmässigas": "intrigmässig",
    "intrigmässigast": "intrigmässig",
    "intrigmässigaste": "intrigmässig",
    "intrigmässigastes": "intrigmässig",
    "intrigmässigasts": "intrigmässig",
    "intrigmässige": "intrigmässig",
    "intrigmässiges": "intrigmässig",
    "intrigmässigs": "intrigmässig",
    "intrigmässigt": "intrigmässig",
    "intrigmässigts": "intrigmässig",
    "intrigs": "intrig",
    "intrigören": "intrigör",
    "intrigörens": "intrigör",
    "intrigörer": "intrigör",
    "intrigörerna": "intrigör",
    "intrigörernas": "intrigör",
    "intrigörers": "intrigör",
    "intrigörs": "intrigör",
    "intrikata": "intrikat",
    "intrikatare": "intrikat",
    "intrikatares": "intrikat",
    "intrikatas": "intrikat",
    "intrikatast": "intrikat",
    "intrikataste": "intrikat",
    "intrikatastes": "intrikat",
    "intrikatasts": "intrikat",
    "intrikate": "intrikat",
    "intrikates": "intrikat",
    "intrikats": "intrikat",
    "intrimningar": "intrimning",
    "intrimningarna": "intrimning",
    "intrimningarnas": "intrimning",
    "intrimningars": "intrimning",
    "intrimningen": "intrimning",
    "intrimningens": "intrimning",
    "intrimnings": "intrimning",
    "intrinsiska": "intrinsisk",
    "intrinsiskas": "intrinsisk",
    "intrinsiske": "intrinsisk",
    "intrinsiskes": "intrinsisk",
    "intrinsisks": "intrinsisk",
    "intrinsiskt": "intrinsisk",
    "intrinsiskts": "intrinsisk",
    "introducerad": "introducera",
    "introducerade": "introducera",
    "introducerades": "introducera",
    "introducerads": "introducera",
    "introducerande": "introducera",
    "introduceranden": "introducerande",
    "introducerandena": "introducerande",
    "introducerandenas": "introducerande",
    "introducerandens": "introducerande",
    "introducerandes": "introducerande",
    "introducerandet": "introducerande",
    "introducerandets": "introducerande",
    "introducerar": "introducera",
    "introduceras": "introducera",
    "introducerat": "introducera",
    "introducerats": "introducera",
    "introducerbara": "introducerbar",
    "introducerbarare": "introducerbar",
    "introducerbarares": "introducerbar",
    "introducerbaras": "introducerbar",
    "introducerbarast": "introducerbar",
    "introducerbaraste": "introducerbar",
    "introducerbarastes": "introducerbar",
    "introducerbarasts": "introducerbar",
    "introducerbare": "introducerbar",
    "introducerbares": "introducerbar",
    "introducerbarheten": "introducerbarhet",
    "introducerbarhetens": "introducerbarhet",
    "introducerbarhets": "introducerbarhet",
    "introducerbars": "introducerbar",
    "introducerbart": "introducerbar",
    "introducerbarts": "introducerbar",
    "introduceringar": "introducering",
    "introduceringarna": "introducering",
    "introduceringarnas": "introducering",
    "introduceringars": "introducering",
    "introduceringen": "introducering",
    "introduceringens": "introducering",
    "introducerings": "introducering",
    "introduktionen": "introduktion",
    "introduktionens": "introduktion",
    "introduktioner": "introduktion",
    "introduktionerna": "introduktion",
    "introduktionernas": "introduktion",
    "introduktioners": "introduktion",
    "introduktions": "introduktion",
    "introduktionsbreven": "introduktionsbrev",
    "introduktionsbrevens": "introduktionsbrev",
    "introduktionsbrevet": "introduktionsbrev",
    "introduktionsbrevets": "introduktionsbrev",
    "introduktionsbrevs": "introduktionsbrev",
    "introduktionserbjudanden": "introduktionserbjudande",
    "introduktionserbjudandena": "introduktionserbjudande",
    "introduktionserbjudandenas": "introduktionserbjudande",
    "introduktionserbjudandens": "introduktionserbjudande",
    "introduktionserbjudandes": "introduktionserbjudande",
    "introduktionserbjudandet": "introduktionserbjudande",
    "introduktionserbjudandets": "introduktionserbjudande",
    "introduktionskursen": "introduktionskurs",
    "introduktionskursens": "introduktionskurs",
    "introduktionskurser": "introduktionskurs",
    "introduktionskurserna": "introduktionskurs",
    "introduktionskursernas": "introduktionskurs",
    "introduktionskursers": "introduktionskurs",
    "introduktionsprogrammen": "introduktionsprogram",
    "introduktionsprogrammens": "introduktionsprogram",
    "introduktionsprogrammet": "introduktionsprogram",
    "introduktionsprogrammets": "introduktionsprogram",
    "introduktionsprograms": "introduktionsprogram",
    "introduktören": "introduktör",
    "introduktörens": "introduktör",
    "introduktörer": "introduktör",
    "introduktörerna": "introduktör",
    "introduktörernas": "introduktör",
    "introduktörers": "introduktör",
    "introduktörs": "introduktör",
    "introspektionen": "introspektion",
    "introspektionens": "introspektion",
    "introspektioner": "introspektion",
    "introspektionerna": "introspektion",
    "introspektionernas": "introspektion",
    "introspektioners": "introspektion",
    "introspektions": "introspektion",
    "introspektiva": "introspektiv",
    "introspektivare": "introspektiv",
    "introspektivares": "introspektiv",
    "introspektivas": "introspektiv",
    "introspektivast": "introspektiv",
    "introspektivaste": "introspektiv",
    "introspektivastes": "introspektiv",
    "introspektivasts": "introspektiv",
    "introspektive": "introspektiv",
    "introspektives": "introspektiv",
    "introspektivs": "introspektiv",
    "introspektivt": "introspektiv",
    "introspektivts": "introspektiv",
    "introversionen": "introversion",
    "introversionens": "introversion",
    "introversioner": "introversion",
    "introversionerna": "introversion",
    "introversionernas": "introversion",
    "introversioners": "introversion",
    "introversions": "introversion",
    "introverta": "introvert",
    "introvertare": "introvert",
    "introvertares": "introvert",
    "introvertas": "introvert",
    "introvertast": "introvert",
    "introvertaste": "introvert",
    "introvertastes": "introvert",
    "introvertasts": "introvert",
    "introverte": "introvert",
    "introvertes": "introvert",
    "introvertheten": "introverthet",
    "introverthetens": "introverthet",
    "introverthets": "introverthet",
    "introverts": "introvert",
    "intrumf": "intrumfa",
    "intrumfad": "intrumfa",
    "intrumfade": "intrumfa",
    "intrumfades": "intrumfa",
    "intrumfads": "intrumfa",
    "intrumfande": "intrumfa",
    "intrumfanden": "intrumfande",
    "intrumfandena": "intrumfande",
    "intrumfandenas": "intrumfande",
    "intrumfandens": "intrumfande",
    "intrumfandes": "intrumfande",
    "intrumfandet": "intrumfande",
    "intrumfandets": "intrumfande",
    "intrumfar": "intrumfa",
    "intrumfas": "intrumfa",
    "intrumfat": "intrumfa",
    "intrumfats": "intrumfa",
    "intrycken": "intryck",
    "intryckens": "intryck",
    "intrycket": "intryck",
    "intryckets": "intryck",
    "intrycks": "intryck",
    "intryckta": "intryckt",
    "intrycktas": "intryckt",
    "intryckte": "intryckt",
    "intrycktes": "intryckt",
    "intryckts": "intryckt",
    "inträd": "inträda",
    "inträdande": "inträda",
    "inträdanden": "inträdande",
    "inträdandena": "inträdande",
    "inträdandenas": "inträdande",
    "inträdandens": "inträdande",
    "inträdandes": "inträdande",
    "inträdandet": "inträdande",
    "inträdandets": "inträdande",
    "inträdas": "inträda",
    "inträdd": "inträda",
    "inträdda": "inträda",
    "inträddas": "inträda",
    "inträdde": "inträda",
    "inträddes": "inträda",
    "inträdds": "inträda",
    "inträden": "inträde",
    "inträdena": "inträde",
    "inträdenas": "inträde",
    "inträdens": "inträde",
    "inträder": "inträda",
    "inträdes": "inträde",
    "inträdesavgiften": "inträdesavgift",
    "inträdesavgiftens": "inträdesavgift",
    "inträdesavgifter": "inträdesavgift",
    "inträdesavgifterna": "inträdesavgift",
    "inträdesavgifternas": "inträdesavgift",
    "inträdesavgifters": "inträdesavgift",
    "inträdesavgifts": "inträdesavgift",
    "inträdesproven": "inträdesprov",
    "inträdesprovens": "inträdesprov",
    "inträdesprovet": "inträdesprov",
    "inträdesprovets": "inträdesprov",
    "inträdesprovs": "inträdesprov",
    "inträdestalen": "inträdestal",
    "inträdestalens": "inträdestal",
    "inträdestalet": "inträdestal",
    "inträdestalets": "inträdestal",
    "inträdestals": "inträdestal",
    "inträdet": "inträde",
    "inträdets": "inträde",
    "inträds": "inträda",
    "inträffad": "inträffa",
    "inträffade": "inträffa",
    "inträffades": "inträffa",
    "inträffads": "inträffa",
    "inträffande": "inträffa",
    "inträffanden": "inträffande",
    "inträffandena": "inträffande",
    "inträffandenas": "inträffande",
    "inträffandens": "inträffande",
    "inträffandes": "inträffande",
    "inträffandet": "inträffande",
    "inträffandets": "inträffande",
    "inträffar": "inträffa",
    "inträffas": "inträffa",
    "inträffat": "inträffa",
    "inträffats": "inträffa",
    "intränade": "intränad",
    "intränades": "intränad",
    "intränads": "intränad",
    "intränat": "intränad",
    "intränats": "intränad",
    "inträng": "intränga",
    "inträngande": "intränga",
    "intränganden": "inträngande",
    "inträngandena": "inträngande",
    "inträngandenas": "inträngande",
    "inträngandens": "inträngande",
    "inträngandes": "inträngande",
    "inträngandet": "inträngande",
    "inträngandets": "inträngande",
    "inträngas": "intränga",
    "inträngd": "intränga",
    "inträngda": "intränga",
    "inträngdas": "intränga",
    "inträngde": "intränga",
    "inträngdes": "intränga",
    "inträngds": "intränga",
    "intränger": "intränga",
    "intränges": "intränga",
    "intränglingar": "inträngling",
    "intränglingarna": "inträngling",
    "intränglingarnas": "inträngling",
    "intränglingars": "inträngling",
    "intränglingen": "inträngling",
    "intränglingens": "inträngling",
    "intränglings": "inträngling",
    "inträngs": "intränga",
    "inträngt": "intränga",
    "inträngts": "intränga",
    "inträtt": "inträda",
    "inträtts": "inträda",
    "intrånget": "intrång",
    "intrångets": "intrång",
    "intrångs": "intrång",
    "intubationen": "intubation",
    "intubationens": "intubation",
    "intubationer": "intubation",
    "intubationerna": "intubation",
    "intubationernas": "intubation",
    "intubationers": "intubation",
    "intubations": "intubation",
    "intuitionen": "intuition",
    "intuitionens": "intuition",
    "intuitioner": "intuition",
    "intuitionerna": "intuition",
    "intuitionernas": "intuition",
    "intuitioners": "intuition",
    "intuitions": "intuition",
    "intuitiva": "intuitiv",
    "intuitivare": "intuitiv",
    "intuitivares": "intuitiv",
    "intuitivas": "intuitiv",
    "intuitivast": "intuitiv",
    "intuitivaste": "intuitiv",
    "intuitivastes": "intuitiv",
    "intuitivasts": "intuitiv",
    "intuitive": "intuitiv",
    "intuitives": "intuitiv",
    "intuitivs": "intuitiv",
    "intuitivt": "intuitiv",
    "intuitivts": "intuitiv",
    "intumningar": "intumning",
    "intumningarna": "intumning",
    "intumningarnas": "intumning",
    "intumningars": "intumning",
    "intumningen": "intumning",
    "intumningens": "intumning",
    "intumnings": "intumning",
    "intyg": "intyga",
    "intygad": "intyga",
    "intygade": "intyga",
    "intygades": "intyga",
    "intygads": "intyga",
    "intygande": "intyga",
    "intyganden": "intygande",
    "intygandena": "intygande",
    "intygandenas": "intygande",
    "intygandens": "intygande",
    "intygandes": "intygande",
    "intygandet": "intygande",
    "intygandets": "intygande",
    "intygar": "intyga",
    "intygas": "intyga",
    "intygat": "intyga",
    "intygats": "intyga",
    "intygen": "intyg",
    "intygens": "intyg",
    "intyget": "intyg",
    "intygets": "intyg",
    "intygs": "intyg",
    "intäkten": "intäkt",
    "intäktens": "intäkt",
    "intäkter": "intäkt",
    "intäkterna": "intäkt",
    "intäkternas": "intäkt",
    "intäkters": "intäkt",
    "intäkts": "intäkt",
    "intäktschablonen": "intäktschablon",
    "intäktschablonens": "intäktschablon",
    "intäktschabloner": "intäktschablon",
    "intäktschablonerna": "intäktschablon",
    "intäktschablonernas": "intäktschablon",
    "intäktschabloners": "intäktschablon",
    "intäktschablons": "intäktschablon",
    "intåg": "intåga",
    "intågad": "intåga",
    "intågade": "intåga",
    "intågades": "intåga",
    "intågads": "intåga",
    "intågande": "intåga",
    "intåganden": "intågande",
    "intågandena": "intågande",
    "intågandenas": "intågande",
    "intågandens": "intågande",
    "intågandes": "intågande",
    "intågandet": "intågande",
    "intågandets": "intågande",
    "intågar": "intåga",
    "intågas": "intåga",
    "intågat": "intåga",
    "intågats": "intåga",
    "intågen": "intåg",
    "intågens": "intåg",
    "intåget": "intåg",
    "intågets": "intåg",
    "intågs": "intåg",
    "inuiten": "inuit",
    "inuitens": "inuit",
    "inuiter": "inuit",
    "inuiterna": "inuit",
    "inuiternas": "inuit",
    "inuiters": "inuit",
    "inuits": "inuit",
    "invaderad": "invadera",
    "invaderade": "invadera",
    "invaderades": "invadera",
    "invaderads": "invadera",
    "invaderande": "invadera",
    "invaderanden": "invaderande",
    "invaderandena": "invaderande",
    "invaderandenas": "invaderande",
    "invaderandens": "invaderande",
    "invaderandes": "invaderande",
    "invaderandet": "invaderande",
    "invaderandets": "invaderande",
    "invaderar": "invadera",
    "invaderas": "invadera",
    "invaderat": "invadera",
    "invaderats": "invadera",
    "invaderbara": "invaderbar",
    "invaderbarare": "invaderbar",
    "invaderbarares": "invaderbar",
    "invaderbaras": "invaderbar",
    "invaderbarast": "invaderbar",
    "invaderbaraste": "invaderbar",
    "invaderbarastes": "invaderbar",
    "invaderbarasts": "invaderbar",
    "invaderbare": "invaderbar",
    "invaderbares": "invaderbar",
    "invaderbarheten": "invaderbarhet",
    "invaderbarhetens": "invaderbarhet",
    "invaderbarhets": "invaderbarhet",
    "invaderbars": "invaderbar",
    "invaderbart": "invaderbar",
    "invaderbarts": "invaderbar",
    "invaderingar": "invadering",
    "invaderingarna": "invadering",
    "invaderingarnas": "invadering",
    "invaderingars": "invadering",
    "invaderingen": "invadering",
    "invaderingens": "invadering",
    "invaderings": "invadering",
    "invagg": "invagga",
    "invaggad": "invagga",
    "invaggade": "invagga",
    "invaggades": "invagga",
    "invaggads": "invagga",
    "invaggande": "invagga",
    "invagganden": "invaggande",
    "invaggandena": "invaggande",
    "invaggandenas": "invaggande",
    "invaggandens": "invaggande",
    "invaggandes": "invaggande",
    "invaggandet": "invaggande",
    "invaggandets": "invaggande",
    "invaggar": "invagga",
    "invaggas": "invagga",
    "invaggat": "invagga",
    "invaggats": "invagga",
    "invald": "invälja",
    "invalda": "invälja",
    "invaldas": "invälja",
    "invalde": "invälja",
    "invaldes": "invälja",
    "invalds": "invälja",
    "invalen": "inval",
    "invalens": "inval",
    "invalet": "inval",
    "invalets": "inval",
    "invaliden": "invalid",
    "invalidens": "invalid",
    "invalider": "invalid",
    "invaliderna": "invalid",
    "invalidernas": "invalid",
    "invaliders": "invalid",
    "invalidiserad": "invalidisera",
    "invalidiserade": "invalidisera",
    "invalidiserades": "invalidisera",
    "invalidiserads": "invalidisera",
    "invalidiserande": "invalidisera",
    "invalidiseranden": "invalidiserande",
    "invalidiserandena": "invalidiserande",
    "invalidiserandenas": "invalidiserande",
    "invalidiserandens": "invalidiserande",
    "invalidiserandes": "invalidiserande",
    "invalidiserandet": "invalidiserande",
    "invalidiserandets": "invalidiserande",
    "invalidiserar": "invalidisera",
    "invalidiseras": "invalidisera",
    "invalidiserat": "invalidisera",
    "invalidiserats": "invalidisera",
    "invalidiserbara": "invalidiserbar",
    "invalidiserbarare": "invalidiserbar",
    "invalidiserbarares": "invalidiserbar",
    "invalidiserbaras": "invalidiserbar",
    "invalidiserbarast": "invalidiserbar",
    "invalidiserbaraste": "invalidiserbar",
    "invalidiserbarastes": "invalidiserbar",
    "invalidiserbarasts": "invalidiserbar",
    "invalidiserbare": "invalidiserbar",
    "invalidiserbares": "invalidiserbar",
    "invalidiserbarheten": "invalidiserbarhet",
    "invalidiserbarhetens": "invalidiserbarhet",
    "invalidiserbarhets": "invalidiserbarhet",
    "invalidiserbars": "invalidiserbar",
    "invalidiserbart": "invalidiserbar",
    "invalidiserbarts": "invalidiserbar",
    "invalidiseringar": "invalidisering",
    "invalidiseringarna": "invalidisering",
    "invalidiseringarnas": "invalidisering",
    "invalidiseringars": "invalidisering",
    "invalidiseringen": "invalidisering",
    "invalidiseringens": "invalidisering",
    "invalidiserings": "invalidisering",
    "invaliditeten": "invaliditet",
    "invaliditetens": "invaliditet",
    "invaliditeter": "invaliditet",
    "invaliditeterna": "invaliditet",
    "invaliditeternas": "invaliditet",
    "invaliditeters": "invaliditet",
    "invaliditets": "invaliditet",
    "invalids": "invalid",
    "invals": "inval",
    "invalt": "invälja",
    "invalts": "invälja",
    "invanda": "invand",
    "invandare": "invand",
    "invandares": "invand",
    "invandas": "invand",
    "invandast": "invand",
    "invandaste": "invand",
    "invandastes": "invand",
    "invandasts": "invand",
    "invande": "invand",
    "invandes": "invand",
    "invandheten": "invandhet",
    "invandhetens": "invandhet",
    "invandhets": "invandhet",
    "invandrad": "invandra",
    "invandrade": "invandra",
    "invandrades": "invandra",
    "invandrads": "invandra",
    "invandrande": "invandra",
    "invandranden": "invandrande",
    "invandrandena": "invandrande",
    "invandrandenas": "invandrande",
    "invandrandens": "invandrande",
    "invandrandes": "invandrande",
    "invandrandet": "invandrande",
    "invandrandets": "invandrande",
    "invandrar": "invandrare",
    "invandrarbefolkningar": "invandrarbefolkning",
    "invandrarbefolkningarna": "invandrarbefolkning",
    "invandrarbefolkningarnas": "invandrarbefolkning",
    "invandrarbefolkningars": "invandrarbefolkning",
    "invandrarbefolkningen": "invandrarbefolkning",
    "invandrarbefolkningens": "invandrarbefolkning",
    "invandrarbefolknings": "invandrarbefolkning",
    "invandrarbröllopen": "invandrarbröllop",
    "invandrarbröllopens": "invandrarbröllop",
    "invandrarbröllopet": "invandrarbröllop",
    "invandrarbröllopets": "invandrarbröllop",
    "invandrarbröllops": "invandrarbröllop",
    "invandraren": "invandrare",
    "invandrarens": "invandrare",
    "invandrares": "invandrare",
    "invandrarfientliga": "invandrarfientlig",
    "invandrarfientligare": "invandrarfientlig",
    "invandrarfientligares": "invandrarfientlig",
    "invandrarfientligas": "invandrarfientlig",
    "invandrarfientligast": "invandrarfientlig",
    "invandrarfientligaste": "invandrarfientlig",
    "invandrarfientligastes": "invandrarfientlig",
    "invandrarfientligasts": "invandrarfientlig",
    "invandrarfientlige": "invandrarfientlig",
    "invandrarfientliges": "invandrarfientlig",
    "invandrarfientligheten": "invandrarfientlighet",
    "invandrarfientlighetens": "invandrarfientlighet",
    "invandrarfientlighets": "invandrarfientlighet",
    "invandrarfientligs": "invandrarfientlig",
    "invandrarfientligt": "invandrarfientlig",
    "invandrarfientligts": "invandrarfientlig",
    "invandrargruppen": "invandrargrupp",
    "invandrargruppens": "invandrargrupp",
    "invandrargrupper": "invandrargrupp",
    "invandrargrupperna": "invandrargrupp",
    "invandrargruppernas": "invandrargrupp",
    "invandrargruppers": "invandrargrupp",
    "invandrargrupps": "invandrargrupp",
    "invandrarklassen": "invandrarklass",
    "invandrarklassens": "invandrarklass",
    "invandrarklasser": "invandrarklass",
    "invandrarklasserna": "invandrarklass",
    "invandrarklassernas": "invandrarklass",
    "invandrarklassers": "invandrarklass",
    "invandrarna": "invandrare",
    "invandrarnas": "invandrare",
    "invandrarpolitiken": "invandrarpolitik",
    "invandrarpolitikens": "invandrarpolitik",
    "invandrarpolitikern": "invandrarpolitiker",
    "invandrarpolitikerna": "invandrarpolitiker",
    "invandrarpolitikernas": "invandrarpolitiker",
    "invandrarpolitikerns": "invandrarpolitiker",
    "invandrarpolitikers": "invandrarpolitiker",
    "invandrarpolitiks": "invandrarpolitik",
    "invandrarpolitiska": "invandrarpolitisk",
    "invandrarpolitiskas": "invandrarpolitisk",
    "invandrarpolitiske": "invandrarpolitisk",
    "invandrarpolitiskes": "invandrarpolitisk",
    "invandrarpolitisks": "invandrarpolitisk",
    "invandrarpolitiskt": "invandrarpolitisk",
    "invandrarpolitiskts": "invandrarpolitisk",
    "invandrarteatergruppen": "invandrarteatergrupp",
    "invandrarteatergruppens": "invandrarteatergrupp",
    "invandrarteatergrupper": "invandrarteatergrupp",
    "invandrarteatergrupperna": "invandrarteatergrupp",
    "invandrarteatergruppernas": "invandrarteatergrupp",
    "invandrarteatergruppers": "invandrarteatergrupp",
    "invandrarteatergrupps": "invandrarteatergrupp",
    "invandrarteatern": "invandrarteater",
    "invandrarteaterns": "invandrarteater",
    "invandrarteaters": "invandrarteater",
    "invandrarteatrar": "invandrarteater",
    "invandrarteatrarna": "invandrarteater",
    "invandrarteatrarnas": "invandrarteater",
    "invandrarteatrars": "invandrarteater",
    "invandrartäta": "invandrartät",
    "invandrartätare": "invandrartät",
    "invandrartätares": "invandrartät",
    "invandrartätas": "invandrartät",
    "invandrartätast": "invandrartät",
    "invandrartätaste": "invandrartät",
    "invandrartätastes": "invandrartät",
    "invandrartätasts": "invandrartät",
    "invandrartäte": "invandrartät",
    "invandrartätes": "invandrartät",
    "invandrartätheten": "invandrartäthet",
    "invandrartäthetens": "invandrartäthet",
    "invandrartäthets": "invandrartäthet",
    "invandrartäts": "invandrartät",
    "invandrartätt": "invandrartät",
    "invandrartätts": "invandrartät",
    "invandrarverken": "invandrarverk",
    "invandrarverkens": "invandrarverk",
    "invandrarverket": "invandrarverk",
    "invandrarverkets": "invandrarverk",
    "invandrarverks": "invandrarverk",
    "invandras": "invandra",
    "invandrat": "invandra",
    "invandrats": "invandra",
    "invandringar": "invandring",
    "invandringarna": "invandring",
    "invandringarnas": "invandring",
    "invandringars": "invandring",
    "invandringen": "invandring",
    "invandringens": "invandring",
    "invandrings": "invandring",
    "invandringskritiska": "invandringskritisk",
    "invandringskritiskare": "invandringskritisk",
    "invandringskritiskares": "invandringskritisk",
    "invandringskritiskas": "invandringskritisk",
    "invandringskritiskast": "invandringskritisk",
    "invandringskritiskaste": "invandringskritisk",
    "invandringskritiskastes": "invandringskritisk",
    "invandringskritiskasts": "invandringskritisk",
    "invandringskritiske": "invandringskritisk",
    "invandringskritiskes": "invandringskritisk",
    "invandringskritisks": "invandringskritisk",
    "invandringskritiskt": "invandringskritisk",
    "invandringskritiskts": "invandringskritisk",
    "invandringskvoten": "invandringskvot",
    "invandringskvotens": "invandringskvot",
    "invandringskvoter": "invandringskvot",
    "invandringskvoterna": "invandringskvot",
    "invandringskvoternas": "invandringskvot",
    "invandringskvoters": "invandringskvot",
    "invandringskvots": "invandringskvot",
    "invandringspolitiken": "invandringspolitik",
    "invandringspolitikens": "invandringspolitik",
    "invandringspolitiks": "invandringspolitik",
    "invandringspolitiska": "invandringspolitisk",
    "invandringspolitiskas": "invandringspolitisk",
    "invandringspolitiske": "invandringspolitisk",
    "invandringspolitiskes": "invandringspolitisk",
    "invandringspolitisks": "invandringspolitisk",
    "invandringspolitiskt": "invandringspolitisk",
    "invandringspolitiskts": "invandringspolitisk",
    "invandringsvägar": "invandringsväg",
    "invandringsvägarna": "invandringsväg",
    "invandringsvägarnas": "invandringsväg",
    "invandringsvägars": "invandringsväg",
    "invandringsvägen": "invandringsväg",
    "invandringsvägens": "invandringsväg",
    "invandringsvägs": "invandringsväg",
    "invands": "invand",
    "invant": "invand",
    "invants": "invand",
    "invariabels": "invariabel",
    "invariabelt": "invariabel",
    "invariabelts": "invariabel",
    "invariabla": "invariabel",
    "invariablare": "invariabel",
    "invariablares": "invariabel",
    "invariablas": "invariabel",
    "invariablast": "invariabel",
    "invariablaste": "invariabel",
    "invariablastes": "invariabel",
    "invariablasts": "invariabel",
    "invariable": "invariabel",
    "invariables": "invariabel",
    "invarianta": "invariant",
    "invariantare": "invariant",
    "invariantares": "invariant",
    "invariantas": "invariant",
    "invariantast": "invariant",
    "invariantaste": "invariant",
    "invariantastes": "invariant",
    "invariantasts": "invariant",
    "invariante": "invariant",
    "invariantes": "invariant",
    "invariants": "invariant",
    "invasionen": "invasion",
    "invasionens": "invasion",
    "invasioner": "invasion",
    "invasionerna": "invasion",
    "invasionernas": "invasion",
    "invasioners": "invasion",
    "invasions": "invasion",
    "invasionsarméer": "invasionsarmé",
    "invasionsarméerna": "invasionsarmé",
    "invasionsarméernas": "invasionsarmé",
    "invasionsarméers": "invasionsarmé",
    "invasionsarmén": "invasionsarmé",
    "invasionsarméns": "invasionsarmé",
    "invasionsarmés": "invasionsarmé",
    "invecklad": "inveckla",
    "invecklade": "invecklad",
    "invecklades": "invecklad",
    "invecklads": "invecklad",
    "invecklande": "inveckla",
    "invecklanden": "invecklande",
    "invecklandena": "invecklande",
    "invecklandenas": "invecklande",
    "invecklandens": "invecklande",
    "invecklandes": "invecklande",
    "invecklandet": "invecklande",
    "invecklandets": "invecklande",
    "invecklar": "inveckla",
    "invecklas": "inveckla",
    "invecklat": "invecklad",
    "invecklats": "invecklad",
    "invektiven": "invektiv",
    "invektivens": "invektiv",
    "invektivet": "invektiv",
    "invektivets": "invektiv",
    "invektivs": "invektiv",
    "inventarie": "inventarium",
    "inventarieboken": "inventariebok",
    "inventariebokens": "inventariebok",
    "inventarieboks": "inventariebok",
    "inventarieböcker": "inventariebok",
    "inventarieböckerna": "inventariebok",
    "inventarieböckernas": "inventariebok",
    "inventarieböckers": "inventariebok",
    "inventarieförteckningar": "inventarieförteckning",
    "inventarieförteckningarna": "inventarieförteckning",
    "inventarieförteckningarnas": "inventarieförteckning",
    "inventarieförteckningars": "inventarieförteckning",
    "inventarieförteckningen": "inventarieförteckning",
    "inventarieförteckningens": "inventarieförteckning",
    "inventarieförtecknings": "inventarieförteckning",
    "inventarier": "inventarium",
    "inventarierna": "inventarium",
    "inventariernas": "inventarium",
    "inventariers": "inventarium",
    "inventariet": "inventarium",
    "inventariets": "inventarium",
    "inventariums": "inventarium",
    "inventerad": "inventera",
    "inventerade": "inventera",
    "inventerades": "inventera",
    "inventerads": "inventera",
    "inventerande": "inventera",
    "inventeranden": "inventerande",
    "inventerandena": "inventerande",
    "inventerandenas": "inventerande",
    "inventerandens": "inventerande",
    "inventerandes": "inventerande",
    "inventerandet": "inventerande",
    "inventerandets": "inventerande",
    "inventerar": "inventera",
    "inventeras": "inventera",
    "inventerat": "inventera",
    "inventerats": "inventera",
    "inventerbara": "inventerbar",
    "inventerbarare": "inventerbar",
    "inventerbarares": "inventerbar",
    "inventerbaras": "inventerbar",
    "inventerbarast": "inventerbar",
    "inventerbaraste": "inventerbar",
    "inventerbarastes": "inventerbar",
    "inventerbarasts": "inventerbar",
    "inventerbare": "inventerbar",
    "inventerbares": "inventerbar",
    "inventerbarheten": "inventerbarhet",
    "inventerbarhetens": "inventerbarhet",
    "inventerbarhets": "inventerbarhet",
    "inventerbars": "inventerbar",
    "inventerbart": "inventerbar",
    "inventerbarts": "inventerbar",
    "inventeringar": "inventering",
    "inventeringarna": "inventering",
    "inventeringarnas": "inventering",
    "inventeringars": "inventering",
    "inventeringen": "inventering",
    "inventeringens": "inventering",
    "inventerings": "inventering",
    "inventiösa": "inventiös",
    "inventiösare": "inventiös",
    "inventiösares": "inventiös",
    "inventiösas": "inventiös",
    "inventiösast": "inventiös",
    "inventiösaste": "inventiös",
    "inventiösastes": "inventiös",
    "inventiösasts": "inventiös",
    "inventiöse": "inventiös",
    "inventiöses": "inventiös",
    "inventiöst": "inventiös",
    "inventiösts": "inventiös",
    "inverkade": "inverka",
    "inverkades": "inverka",
    "inverkande": "inverka",
    "inverkanden": "inverkande",
    "inverkandena": "inverkande",
    "inverkandenas": "inverkande",
    "inverkandens": "inverkande",
    "inverkandes": "inverkande",
    "inverkandet": "inverkande",
    "inverkandets": "inverkande",
    "inverkans": "inverkan",
    "inverkar": "inverka",
    "inverkas": "inverka",
    "inverkat": "inverka",
    "inverkats": "inverka",
    "inverkningar": "inverkning",
    "inverkningarna": "inverkning",
    "inverkningarnas": "inverkning",
    "inverkningars": "inverkning",
    "inverkningen": "inverkning",
    "inverkningens": "inverkning",
    "inverknings": "inverkning",
    "inversen": "invers",
    "inversens": "invers",
    "inverser": "invers",
    "inverserna": "invers",
    "inversernas": "invers",
    "inversers": "invers",
    "inversionen": "inversion",
    "inversionens": "inversion",
    "inversioner": "inversion",
    "inversionerna": "inversion",
    "inversionernas": "inversion",
    "inversioners": "inversion",
    "inversions": "inversion",
    "invertebraten": "invertebrat",
    "invertebratens": "invertebrat",
    "invertebrater": "invertebrat",
    "invertebraterna": "invertebrat",
    "invertebraternas": "invertebrat",
    "invertebraters": "invertebrat",
    "invertebrats": "invertebrat",
    "inverterad": "invertera",
    "inverterade": "invertera",
    "inverterades": "invertera",
    "inverterads": "invertera",
    "inverterande": "invertera",
    "inverteranden": "inverterande",
    "inverterandena": "inverterande",
    "inverterandenas": "inverterande",
    "inverterandens": "inverterande",
    "inverterandes": "inverterande",
    "inverterandet": "inverterande",
    "inverterandets": "inverterande",
    "inverterar": "invertera",
    "inverteras": "invertera",
    "inverterat": "invertera",
    "inverterats": "invertera",
    "inverterbara": "inverterbar",
    "inverterbarare": "inverterbar",
    "inverterbarares": "inverterbar",
    "inverterbaras": "inverterbar",
    "inverterbarast": "inverterbar",
    "inverterbaraste": "inverterbar",
    "inverterbarastes": "inverterbar",
    "inverterbarasts": "inverterbar",
    "inverterbare": "inverterbar",
    "inverterbares": "inverterbar",
    "inverterbarheten": "inverterbarhet",
    "inverterbarhetens": "inverterbarhet",
    "inverterbarhets": "inverterbarhet",
    "inverterbars": "inverterbar",
    "inverterbart": "inverterbar",
    "inverterbarts": "inverterbar",
    "inverterelverken": "inverterelverk",
    "inverterelverkens": "inverterelverk",
    "inverterelverket": "inverterelverk",
    "inverterelverkets": "inverterelverk",
    "inverterelverks": "inverterelverk",
    "inverteringar": "invertering",
    "inverteringarna": "invertering",
    "inverteringarnas": "invertering",
    "inverteringars": "invertering",
    "inverteringen": "invertering",
    "inverteringens": "invertering",
    "inverterings": "invertering",
    "invertsockers": "invertsocker",
    "invertsockret": "invertsocker",
    "invertsockrets": "invertsocker",
    "invertsåp": "invertsåpa",
    "invertsåpan": "invertsåpa",
    "invertsåpans": "invertsåpa",
    "invertsåpas": "invertsåpa",
    "invertsåpe": "invertsåpa",
    "invertsåpor": "invertsåpa",
    "invertsåporna": "invertsåpa",
    "invertsåpornas": "invertsåpa",
    "invertsåpors": "invertsåpa",
    "invertsåps": "invertsåpa",
    "investerad": "investera",
    "investerade": "investera",
    "investerades": "investera",
    "investerads": "investera",
    "investerande": "investera",
    "investeranden": "investerande",
    "investerandena": "investerande",
    "investerandenas": "investerande",
    "investerandens": "investerande",
    "investerandes": "investerande",
    "investerandet": "investerande",
    "investerandets": "investerande",
    "investerar": "investerare",
    "investeraren": "investerare",
    "investerarens": "investerare",
    "investerares": "investerare",
    "investerarna": "investerare",
    "investerarnas": "investerare",
    "investeras": "investera",
    "investerat": "investera",
    "investerats": "investera",
    "investerbara": "investerbar",
    "investerbarare": "investerbar",
    "investerbarares": "investerbar",
    "investerbaras": "investerbar",
    "investerbarast": "investerbar",
    "investerbaraste": "investerbar",
    "investerbarastes": "investerbar",
    "investerbarasts": "investerbar",
    "investerbare": "investerbar",
    "investerbares": "investerbar",
    "investerbarheten": "investerbarhet",
    "investerbarhetens": "investerbarhet",
    "investerbarhets": "investerbarhet",
    "investerbars": "investerbar",
    "investerbart": "investerbar",
    "investerbarts": "investerbar",
    "investeringar": "investering",
    "investeringarna": "investering",
    "investeringarnas": "investering",
    "investeringars": "investering",
    "investeringen": "investering",
    "investeringens": "investering",
    "investerings": "investering",
    "investeringsbanken": "investeringsbank",
    "investeringsbankens": "investeringsbank",
    "investeringsbanker": "investeringsbank",
    "investeringsbankerna": "investeringsbank",
    "investeringsbankernas": "investeringsbank",
    "investeringsbankers": "investeringsbank",
    "investeringsbanks": "investeringsbank",
    "investeringsfonden": "investeringsfond",
    "investeringsfondens": "investeringsfond",
    "investeringsfonder": "investeringsfond",
    "investeringsfonderna": "investeringsfond",
    "investeringsfondernas": "investeringsfond",
    "investeringsfonders": "investeringsfond",
    "investeringsfonds": "investeringsfond",
    "investeringsformen": "investeringsform",
    "investeringsformens": "investeringsform",
    "investeringsformer": "investeringsform",
    "investeringsformerna": "investeringsform",
    "investeringsformernas": "investeringsform",
    "investeringsformers": "investeringsform",
    "investeringsforms": "investeringsform",
    "investituren": "investitur",
    "investiturens": "investitur",
    "investiturs": "investitur",
    "investmentbanken": "investmentbank",
    "investmentbankens": "investmentbank",
    "investmentbanker": "investmentbank",
    "investmentbankerna": "investmentbank",
    "investmentbankernas": "investmentbank",
    "investmentbankers": "investmentbank",
    "investmentbanks": "investmentbank",
    "investmentbolagen": "investmentbolag",
    "investmentbolagens": "investmentbolag",
    "investmentbolaget": "investmentbolag",
    "investmentbolagets": "investmentbolag",
    "investmentbolags": "investmentbolag",
    "invig": "inviga",
    "invigande": "inviga",
    "inviganden": "invigande",
    "invigandena": "invigande",
    "invigandenas": "invigande",
    "invigandens": "invigande",
    "invigandes": "invigande",
    "invigandet": "invigande",
    "invigandets": "invigande",
    "invigas": "inviga",
    "invigd": "inviga",
    "invigda": "inviga",
    "invigdas": "inviga",
    "invigde": "inviga",
    "invigdes": "inviga",
    "invigds": "inviga",
    "inviger": "inviga",
    "inviges": "inviga",
    "invigningar": "invigning",
    "invigningarna": "invigning",
    "invigningarnas": "invigning",
    "invigningars": "invigning",
    "invigningen": "invigning",
    "invigningens": "invigning",
    "invignings": "invigning",
    "invigs": "inviga",
    "invigt": "inviga",
    "invigts": "inviga",
    "invikta": "invikt",
    "inviktas": "invikt",
    "invikte": "invikt",
    "inviktes": "invikt",
    "invikts": "invikt",
    "invintrade": "invintra",
    "invintrades": "invintra",
    "invintrande": "invintra",
    "invintranden": "invintrande",
    "invintrandena": "invintrande",
    "invintrandenas": "invintrande",
    "invintrandens": "invintrande",
    "invintrandes": "invintrande",
    "invintrandet": "invintrande",
    "invintrandets": "invintrande",
    "invintrar": "invintra",
    "invintras": "invintra",
    "invintrat": "invintra",
    "invintrats": "invintra",
    "invintringar": "invintring",
    "invintringarna": "invintring",
    "invintringarnas": "invintring",
    "invintringars": "invintring",
    "invintringen": "invintring",
    "invintringens": "invintring",
    "invintrings": "invintring",
    "invintringsprocessen": "invintringsprocess",
    "invintringsprocessens": "invintringsprocess",
    "invintringsprocesser": "invintringsprocess",
    "invintringsprocesserna": "invintringsprocess",
    "invintringsprocessernas": "invintringsprocess",
    "invintringsprocessers": "invintringsprocess",
    "invitationen": "invitation",
    "invitationens": "invitation",
    "invitationer": "invitation",
    "invitationerna": "invitation",
    "invitationernas": "invitation",
    "invitationers": "invitation",
    "invitations": "invitation",
    "inviten": "invit",
    "invitens": "invit",
    "inviter": "invit",
    "inviterad": "invitera",
    "inviterade": "invitera",
    "inviterades": "invitera",
    "inviterads": "invitera",
    "inviterande": "invitera",
    "inviteranden": "inviterande",
    "inviterandena": "inviterande",
    "inviterandenas": "inviterande",
    "inviterandens": "inviterande",
    "inviterandes": "inviterande",
    "inviterandet": "inviterande",
    "inviterandets": "inviterande",
    "inviterar": "invitera",
    "inviteras": "invitera",
    "inviterat": "invitera",
    "inviterats": "invitera",
    "inviterbara": "inviterbar",
    "inviterbarare": "inviterbar",
    "inviterbarares": "inviterbar",
    "inviterbaras": "inviterbar",
    "inviterbarast": "inviterbar",
    "inviterbaraste": "inviterbar",
    "inviterbarastes": "inviterbar",
    "inviterbarasts": "inviterbar",
    "inviterbare": "inviterbar",
    "inviterbares": "inviterbar",
    "inviterbarheten": "inviterbarhet",
    "inviterbarhetens": "inviterbarhet",
    "inviterbarhets": "inviterbarhet",
    "inviterbars": "inviterbar",
    "inviterbart": "inviterbar",
    "inviterbarts": "inviterbar",
    "inviteringar": "invitering",
    "inviteringarna": "invitering",
    "inviteringarnas": "invitering",
    "inviteringars": "invitering",
    "inviteringen": "invitering",
    "inviteringens": "invitering",
    "inviterings": "invitering",
    "inviterna": "invit",
    "inviternas": "invit",
    "inviters": "invit",
    "invits": "invit",
    "invokationen": "invokation",
    "invokationens": "invokation",
    "invokationer": "invokation",
    "invokationerna": "invokation",
    "invokationernas": "invokation",
    "invokationers": "invokation",
    "invokations": "invokation",
    "involverad": "involvera",
    "involverade": "involvera",
    "involverades": "involvera",
    "involverads": "involvera",
    "involverande": "involvera",
    "involveranden": "involverande",
    "involverandena": "involverande",
    "involverandenas": "involverande",
    "involverandens": "involverande",
    "involverandes": "involverande",
    "involverandet": "involverande",
    "involverandets": "involverande",
    "involverar": "involvera",
    "involveras": "involvera",
    "involverat": "involvera",
    "involverats": "involvera",
    "involverbara": "involverbar",
    "involverbarare": "involverbar",
    "involverbarares": "involverbar",
    "involverbaras": "involverbar",
    "involverbarast": "involverbar",
    "involverbaraste": "involverbar",
    "involverbarastes": "involverbar",
    "involverbarasts": "involverbar",
    "involverbare": "involverbar",
    "involverbares": "involverbar",
    "involverbarheten": "involverbarhet",
    "involverbarhetens": "involverbarhet",
    "involverbarhets": "involverbarhet",
    "involverbars": "involverbar",
    "involverbart": "involverbar",
    "involverbarts": "involverbar",
    "involveringar": "involvering",
    "involveringarna": "involvering",
    "involveringarnas": "involvering",
    "involveringars": "involvering",
    "involveringen": "involvering",
    "involveringens": "involvering",
    "involverings": "involvering",
    "invägningar": "invägning",
    "invägningarna": "invägning",
    "invägningarnas": "invägning",
    "invägningars": "invägning",
    "invägningen": "invägning",
    "invägningens": "invägning",
    "invägnings": "invägning",
    "invälj": "invälja",
    "inväljande": "invälja",
    "inväljanden": "inväljande",
    "inväljandena": "inväljande",
    "inväljandenas": "inväljande",
    "inväljandens": "inväljande",
    "inväljandes": "inväljande",
    "inväljandet": "inväljande",
    "inväljandets": "inväljande",
    "inväljas": "invälja",
    "inväljer": "invälja",
    "inväljes": "invälja",
    "inväljs": "invälja",
    "invänd": "invända",
    "invändande": "invända",
    "invändanden": "invändande",
    "invändandena": "invändande",
    "invändandenas": "invändande",
    "invändandens": "invändande",
    "invändandes": "invändande",
    "invändandet": "invändande",
    "invändandets": "invändande",
    "invändas": "invända",
    "invände": "invända",
    "invänder": "invända",
    "invändes": "invända",
    "invändiga": "invändig",
    "invändigare": "invändig",
    "invändigares": "invändig",
    "invändigas": "invändig",
    "invändigast": "invändig",
    "invändigaste": "invändig",
    "invändigastes": "invändig",
    "invändigasts": "invändig",
    "invändige": "invändig",
    "invändiges": "invändig",
    "invändigs": "invändig",
    "invändigt": "invändig",
    "invändigts": "invändig",
    "invändningar": "invändning",
    "invändningarna": "invändning",
    "invändningarnas": "invändning",
    "invändningars": "invändning",
    "invändningen": "invändning",
    "invändningens": "invändning",
    "invändnings": "invändning",
    "invändningsfria": "invändningsfri",
    "invändningsfriare": "invändningsfri",
    "invändningsfriares": "invändningsfri",
    "invändningsfrias": "invändningsfri",
    "invändningsfriast": "invändningsfri",
    "invändningsfriaste": "invändningsfri",
    "invändningsfriastes": "invändningsfri",
    "invändningsfriasts": "invändningsfri",
    "invändningsfrie": "invändningsfri",
    "invändningsfries": "invändningsfri",
    "invändningsfris": "invändningsfri",
    "invändningsfritt": "invändningsfri",
    "invändningsfritts": "invändningsfri",
    "invänds": "invända",
    "invänt": "invänta",
    "inväntad": "invänta",
    "inväntade": "invänta",
    "inväntades": "invänta",
    "inväntads": "invänta",
    "inväntande": "invänta",
    "inväntanden": "inväntande",
    "inväntandena": "inväntande",
    "inväntandenas": "inväntande",
    "inväntandens": "inväntande",
    "inväntandes": "inväntande",
    "inväntandet": "inväntande",
    "inväntandets": "inväntande",
    "inväntar": "invänta",
    "inväntas": "invänta",
    "inväntat": "invänta",
    "inväntats": "invänta",
    "invänts": "invända",
    "inväv": "inväva",
    "invävande": "inväva",
    "invävanden": "invävande",
    "invävandena": "invävande",
    "invävandenas": "invävande",
    "invävandens": "invävande",
    "invävandes": "invävande",
    "invävandet": "invävande",
    "invävandets": "invävande",
    "invävas": "inväva",
    "invävd": "inväva",
    "invävda": "inväva",
    "invävdas": "inväva",
    "invävde": "inväva",
    "invävdes": "inväva",
    "invävds": "inväva",
    "inväver": "inväva",
    "inväves": "inväva",
    "invävs": "inväva",
    "invävt": "inväva",
    "invävts": "inväva",
    "invånar": "invånare",
    "invånaren": "invånare",
    "invånarens": "invånare",
    "invånares": "invånare",
    "invånarna": "invånare",
    "invånarnas": "invånare",
    "inympad": "inympa",
    "inympade": "inympa",
    "inympades": "inympa",
    "inympads": "inympa",
    "inympande": "inympa",
    "inympanden": "inympande",
    "inympandena": "inympande",
    "inympandenas": "inympande",
    "inympandens": "inympande",
    "inympandes": "inympande",
    "inympandet": "inympande",
    "inympandets": "inympande",
    "inympar": "inympa",
    "inympas": "inympa",
    "inympat": "inympa",
    "inympats": "inympa",
    "inägan": "inäga",
    "inägans": "inäga",
    "inägas": "inäga",
    "inäge": "inäga",
    "inägo": "inäga",
    "inägor": "inäga",
    "inägorna": "inäga",
    "inägornas": "inäga",
    "inägors": "inäga",
    "inälvorna": "inälvor",
    "inälvornas": "inälvor",
    "inälvors": "inälvor",
    "inälvs": "inälvor",
    "inälvsmaskar": "inälvsmask",
    "inälvsmaskarna": "inälvsmask",
    "inälvsmaskarnas": "inälvsmask",
    "inälvsmaskars": "inälvsmask",
    "inälvsmasken": "inälvsmask",
    "inälvsmaskens": "inälvsmask",
    "inälvsmasks": "inälvsmask",
    "inåtböjde": "inåtböjd",
    "inåtböjdes": "inåtböjd",
    "inåtböjds": "inåtböjd",
    "inåtböjt": "inåtböjd",
    "inåtböjts": "inåtböjd",
    "inåtvända": "inåtvänd",
    "inåtvändare": "inåtvänd",
    "inåtvändares": "inåtvänd",
    "inåtvändas": "inåtvänd",
    "inåtvändast": "inåtvänd",
    "inåtvändaste": "inåtvänd",
    "inåtvändastes": "inåtvänd",
    "inåtvändasts": "inåtvänd",
    "inåtvände": "inåtvänd",
    "inåtvändes": "inåtvänd",
    "inåtvändheten": "inåtvändhet",
    "inåtvändhetens": "inåtvändhet",
    "inåtvändhets": "inåtvändhet",
    "inåtvänds": "inåtvänd",
    "inåtvänt": "inåtvänd",
    "inåtvänts": "inåtvänd",
    "inöv": "inöva",
    "inövad": "inöva",
    "inövade": "inöva",
    "inövades": "inöva",
    "inövads": "inöva",
    "inövande": "inöva",
    "inövanden": "inövande",
    "inövandena": "inövande",
    "inövandenas": "inövande",
    "inövandens": "inövande",
    "inövandes": "inövande",
    "inövandet": "inövande",
    "inövandets": "inövande",
    "inövar": "inöva",
    "inövas": "inöva",
    "inövat": "inöva",
    "inövats": "inöva",
    "iordningställ": "iordningställa",
    "iordningställande": "iordningställa",
    "iordningställanden": "iordningställande",
    "iordningställandena": "iordningställande",
    "iordningställandenas": "iordningställande",
    "iordningställandens": "iordningställande",
    "iordningställandes": "iordningställande",
    "iordningställandet": "iordningställande",
    "iordningställandets": "iordningställande",
    "iordningställas": "iordningställa",
    "iordningställd": "iordningställa",
    "iordningställda": "iordningställa",
    "iordningställdas": "iordningställa",
    "iordningställde": "iordningställa",
    "iordningställdes": "iordningställa",
    "iordningställds": "iordningställa",
    "iordningställer": "iordningställa",
    "iordningställes": "iordningställa",
    "iordningställs": "iordningställa",
    "iordningställt": "iordningställa",
    "iordningställts": "iordningställa",
    "iotan": "iota",
    "iotana": "iota",
    "iotanas": "iota",
    "iotans": "iota",
    "iotas": "iota",
    "iotat": "iota",
    "iotats": "iota",
    "ip-nummers": "ip-nummer",
    "ip-numrens": "ip-nummer",
    "ip-numrets": "ip-nummer",
    "irakiern": "irakier",
    "irakierna": "irakier",
    "irakiernas": "irakier",
    "irakierns": "irakier",
    "irakiers": "irakier",
    "irakiska": "irakisk",
    "irakiskan": "irakiska",
    "irakiskans": "irakiska",
    "irakiskare": "irakisk",
    "irakiskares": "irakisk",
    "irakiskas": "irakiska",
    "irakiskast": "irakisk",
    "irakiskaste": "irakisk",
    "irakiskastes": "irakisk",
    "irakiskasts": "irakisk",
    "irakiske": "irakiska",
    "irakiskes": "irakisk",
    "irakiskor": "irakiska",
    "irakiskorna": "irakiska",
    "irakiskornas": "irakiska",
    "irakiskors": "irakiska",
    "irakisks": "irakisk",
    "irakiskt": "irakisk",
    "irakiskts": "irakisk",
    "iraniern": "iranier",
    "iranierna": "iranier",
    "iraniernas": "iranier",
    "iranierns": "iranier",
    "iraniers": "iranier",
    "iransk": "iranska",
    "iranska": "iransk",
    "iranskan": "iranska",
    "iranskans": "iranska",
    "iranskare": "iransk",
    "iranskares": "iransk",
    "iranskas": "iranska",
    "iranskast": "iransk",
    "iranskaste": "iransk",
    "iranskastes": "iransk",
    "iranskasts": "iransk",
    "iranske": "iranska",
    "iranskes": "iransk",
    "iranskor": "iranska",
    "iranskorna": "iranska",
    "iranskornas": "iranska",
    "iranskors": "iranska",
    "iransks": "iransk",
    "iranskt": "iransk",
    "iranskts": "iransk",
    "irern": "irer",
    "irerna": "irer",
    "irernas": "irer",
    "irerns": "irer",
    "irers": "irer",
    "iridiet": "iridium",
    "iridiets": "iridium",
    "iridiumet": "iridium",
    "iridiumets": "iridium",
    "iridiumlagerna": "iridiumlager",
    "iridiumlagernas": "iridiumlager",
    "iridiumlagers": "iridiumlager",
    "iridiumlagren": "iridiumlager",
    "iridiumlagrens": "iridiumlager",
    "iridiumlagret": "iridiumlager",
    "iridiumlagrets": "iridiumlager",
    "iridiums": "iridium",
    "irisar": "iris",
    "irisarna": "iris",
    "irisarnas": "iris",
    "irisars": "iris",
    "irisbländar": "irisbländare",
    "irisbländaren": "irisbländare",
    "irisbländarens": "irisbländare",
    "irisbländares": "irisbländare",
    "irisbländarna": "irisbländare",
    "irisbländarnas": "irisbländare",
    "irisen": "iris",
    "irisens": "iris",
    "iriserade": "irisera",
    "iriserades": "irisera",
    "iriserande": "irisera",
    "iriseranden": "iriserande",
    "iriserandena": "iriserande",
    "iriserandenas": "iriserande",
    "iriserandens": "iriserande",
    "iriserandes": "iriserande",
    "iriserandet": "iriserande",
    "iriserandets": "iriserande",
    "iriserar": "irisera",
    "iriseras": "irisera",
    "iriserat": "irisera",
    "iriserats": "irisera",
    "iriseringar": "irisering",
    "iriseringarna": "irisering",
    "iriseringarnas": "irisering",
    "iriseringars": "irisering",
    "iriseringen": "irisering",
    "iriseringens": "irisering",
    "iriserings": "irisering",
    "irisk": "iriska",
    "iriska": "irisk",
    "iriskan": "iriska",
    "iriskans": "iriska",
    "iriskare": "irisk",
    "iriskares": "irisk",
    "iriskas": "iriska",
    "iriskast": "irisk",
    "iriskaste": "irisk",
    "iriskastes": "irisk",
    "iriskasts": "irisk",
    "iriske": "iriska",
    "iriskes": "irisk",
    "iriskor": "iriska",
    "iriskorna": "iriska",
    "iriskornas": "iriska",
    "iriskors": "iriska",
    "irisks": "irisk",
    "iriskt": "irisk",
    "iriskts": "irisk",
    "irländar": "irländare",
    "irländaren": "irländare",
    "irländarens": "irländare",
    "irländares": "irländare",
    "irländarna": "irländare",
    "irländarnas": "irländare",
    "irländsk": "irländska",
    "irländska": "irländsk",
    "irländskan": "irländska",
    "irländskans": "irländska",
    "irländskare": "irländsk",
    "irländskares": "irländsk",
    "irländskas": "irländska",
    "irländskast": "irländsk",
    "irländskaste": "irländsk",
    "irländskastes": "irländsk",
    "irländskasts": "irländsk",
    "irländske": "irländska",
    "irländskes": "irländsk",
    "irländskor": "irländska",
    "irländskorna": "irländska",
    "irländskornas": "irländska",
    "irländskors": "irländska",
    "irländsks": "irländsk",
    "irländskt": "irländsk",
    "irländskts": "irländsk",
    "ironien": "ironi",
    "ironiens": "ironi",
    "ironier": "ironi",
    "ironierna": "ironi",
    "ironiernas": "ironi",
    "ironiers": "ironi",
    "ironikern": "ironiker",
    "ironikerna": "ironiker",
    "ironikernas": "ironiker",
    "ironikerns": "ironiker",
    "ironikers": "ironiker",
    "ironin": "ironi",
    "ironins": "ironi",
    "ironis": "ironi",
    "ironiserade": "ironisera",
    "ironiserades": "ironisera",
    "ironiserande": "ironisera",
    "ironiseranden": "ironiserande",
    "ironiserandena": "ironiserande",
    "ironiserandenas": "ironiserande",
    "ironiserandens": "ironiserande",
    "ironiserandes": "ironiserande",
    "ironiserandet": "ironiserande",
    "ironiserandets": "ironiserande",
    "ironiserar": "ironisera",
    "ironiseras": "ironisera",
    "ironiserat": "ironisera",
    "ironiserats": "ironisera",
    "ironiseringar": "ironisering",
    "ironiseringarna": "ironisering",
    "ironiseringarnas": "ironisering",
    "ironiseringars": "ironisering",
    "ironiseringen": "ironisering",
    "ironiseringens": "ironisering",
    "ironiserings": "ironisering",
    "ironiska": "ironisk",
    "ironiskare": "ironisk",
    "ironiskares": "ironisk",
    "ironiskas": "ironisk",
    "ironiskast": "ironisk",
    "ironiskaste": "ironisk",
    "ironiskastes": "ironisk",
    "ironiskasts": "ironisk",
    "ironiske": "ironisk",
    "ironiskes": "ironisk",
    "ironisks": "ironisk",
    "ironiskt": "ironisk",
    "ironiskts": "ironisk",
    "irr": "irra",
    "irrade": "irra",
    "irrades": "irra",
    "irrande": "irra",
    "irranden": "irrande",
    "irrandena": "irrande",
    "irrandenas": "irrande",
    "irrandens": "irrande",
    "irrandes": "irrande",
    "irrandet": "irrande",
    "irrandets": "irrande",
    "irrar": "irra",
    "irras": "irra",
    "irrat": "irra",
    "irrationella": "irrationell",
    "irrationellare": "irrationell",
    "irrationellares": "irrationell",
    "irrationellas": "irrationell",
    "irrationellast": "irrationell",
    "irrationellaste": "irrationell",
    "irrationellastes": "irrationell",
    "irrationellasts": "irrationell",
    "irrationelle": "irrationell",
    "irrationelles": "irrationell",
    "irrationells": "irrationell",
    "irrationellt": "irrationell",
    "irrationellts": "irrationell",
    "irrats": "irra",
    "irrblossen": "irrbloss",
    "irrblossens": "irrbloss",
    "irrblosset": "irrbloss",
    "irrblossets": "irrbloss",
    "irreala": "irreal",
    "irrealare": "irreal",
    "irrealares": "irreal",
    "irrealas": "irreal",
    "irrealast": "irreal",
    "irrealaste": "irreal",
    "irrealastes": "irreal",
    "irrealasts": "irreal",
    "irreale": "irreal",
    "irreales": "irreal",
    "irreals": "irreal",
    "irrealt": "irreal",
    "irrealts": "irreal",
    "irredentismen": "irredentism",
    "irredentismens": "irredentism",
    "irredentismer": "irredentism",
    "irredentismerna": "irredentism",
    "irredentismernas": "irredentism",
    "irredentismers": "irredentism",
    "irredentisms": "irredentism",
    "irreella": "irreell",
    "irreellare": "irreell",
    "irreellares": "irreell",
    "irreellas": "irreell",
    "irreellast": "irreell",
    "irreellaste": "irreell",
    "irreellastes": "irreell",
    "irreellasts": "irreell",
    "irreelle": "irreell",
    "irreelles": "irreell",
    "irreells": "irreell",
    "irreellt": "irreell",
    "irreellts": "irreell",
    "irreguljära": "irreguljär",
    "irreguljärare": "irreguljär",
    "irreguljärares": "irreguljär",
    "irreguljäras": "irreguljär",
    "irreguljärast": "irreguljär",
    "irreguljäraste": "irreguljär",
    "irreguljärastes": "irreguljär",
    "irreguljärasts": "irreguljär",
    "irreguljäre": "irreguljär",
    "irreguljäres": "irreguljär",
    "irreguljärs": "irreguljär",
    "irreguljärt": "irreguljär",
    "irreguljärts": "irreguljär",
    "irrelevanta": "irrelevant",
    "irrelevantare": "irrelevant",
    "irrelevantares": "irrelevant",
    "irrelevantas": "irrelevant",
    "irrelevantast": "irrelevant",
    "irrelevantaste": "irrelevant",
    "irrelevantastes": "irrelevant",
    "irrelevantasts": "irrelevant",
    "irrelevante": "irrelevant",
    "irrelevantes": "irrelevant",
    "irrelevants": "irrelevant",
    "irreparabels": "irreparabel",
    "irreparabelt": "irreparabel",
    "irreparabelts": "irreparabel",
    "irreparabla": "irreparabel",
    "irreparablare": "irreparabel",
    "irreparablares": "irreparabel",
    "irreparablas": "irreparabel",
    "irreparablast": "irreparabel",
    "irreparablaste": "irreparabel",
    "irreparablastes": "irreparabel",
    "irreparablasts": "irreparabel",
    "irreparable": "irreparabel",
    "irreparables": "irreparabel",
    "irreversibels": "irreversibel",
    "irreversibelt": "irreversibel",
    "irreversibelts": "irreversibel",
    "irreversibla": "irreversibel",
    "irreversiblare": "irreversibel",
    "irreversiblares": "irreversibel",
    "irreversiblas": "irreversibel",
    "irreversiblast": "irreversibel",
    "irreversiblaste": "irreversibel",
    "irreversiblastes": "irreversibel",
    "irreversiblasts": "irreversibel",
    "irreversible": "irreversibel",
    "irreversibles": "irreversibel",
    "irrfärden": "irrfärd",
    "irrfärdens": "irrfärd",
    "irrfärder": "irrfärd",
    "irrfärderna": "irrfärd",
    "irrfärdernas": "irrfärd",
    "irrfärders": "irrfärd",
    "irrfärds": "irrfärd",
    "irrgångar": "irrgång",
    "irrgångarna": "irrgång",
    "irrgångarnas": "irrgång",
    "irrgångars": "irrgång",
    "irrgången": "irrgång",
    "irrgångens": "irrgång",
    "irrgångs": "irrgång",
    "irrigationen": "irrigation",
    "irrigationens": "irrigation",
    "irrigationer": "irrigation",
    "irrigationerna": "irrigation",
    "irrigationernas": "irrigation",
    "irrigationers": "irrigation",
    "irrigations": "irrigation",
    "irritabels": "irritabel",
    "irritabelt": "irritabel",
    "irritabelts": "irritabel",
    "irritabla": "irritabel",
    "irritablare": "irritabel",
    "irritablares": "irritabel",
    "irritablas": "irritabel",
    "irritablast": "irritabel",
    "irritablaste": "irritabel",
    "irritablastes": "irritabel",
    "irritablasts": "irritabel",
    "irritable": "irritabel",
    "irritables": "irritabel",
    "irritamenten": "irritament",
    "irritamentens": "irritament",
    "irritamentet": "irritament",
    "irritamentets": "irritament",
    "irritaments": "irritament",
    "irritationen": "irritation",
    "irritationens": "irritation",
    "irritationer": "irritation",
    "irritationerna": "irritation",
    "irritationernas": "irritation",
    "irritationers": "irritation",
    "irritations": "irritation",
    "irritationsmomenten": "irritationsmoment",
    "irritationsmomentens": "irritationsmoment",
    "irritationsmomentet": "irritationsmoment",
    "irritationsmomentets": "irritationsmoment",
    "irritationsmoments": "irritationsmoment",
    "irriterad": "irritera",
    "irriterade": "irritera",
    "irriterades": "irritera",
    "irriterads": "irritera",
    "irriterande": "irritera",
    "irriteranden": "irriterande",
    "irriterandena": "irriterande",
    "irriterandenas": "irriterande",
    "irriterandens": "irriterande",
    "irriterandes": "irriterande",
    "irriterandet": "irriterande",
    "irriterandets": "irriterande",
    "irriterar": "irritera",
    "irriteras": "irritera",
    "irriterat": "irritera",
    "irriterats": "irritera",
    "irriterbara": "irriterbar",
    "irriterbarare": "irriterbar",
    "irriterbarares": "irriterbar",
    "irriterbaras": "irriterbar",
    "irriterbarast": "irriterbar",
    "irriterbaraste": "irriterbar",
    "irriterbarastes": "irriterbar",
    "irriterbarasts": "irriterbar",
    "irriterbare": "irriterbar",
    "irriterbares": "irriterbar",
    "irriterbarheten": "irriterbarhet",
    "irriterbarhetens": "irriterbarhet",
    "irriterbarhets": "irriterbarhet",
    "irriterbars": "irriterbar",
    "irriterbart": "irriterbar",
    "irriterbarts": "irriterbar",
    "irriteringar": "irritering",
    "irriteringarna": "irritering",
    "irriteringarnas": "irritering",
    "irriteringars": "irritering",
    "irriteringen": "irritering",
    "irriteringens": "irritering",
    "irriterings": "irritering",
    "irrläran": "irrlära",
    "irrlärans": "irrlära",
    "irrläras": "irrlära",
    "irrläre": "irrlära",
    "irrläriga": "irrlärig",
    "irrlärigare": "irrlärig",
    "irrlärigares": "irrlärig",
    "irrlärigas": "irrlärig",
    "irrlärigast": "irrlärig",
    "irrlärigaste": "irrlärig",
    "irrlärigastes": "irrlärig",
    "irrlärigasts": "irrlärig",
    "irrlärige": "irrlärig",
    "irrläriges": "irrlärig",
    "irrlärigheten": "irrlärighet",
    "irrlärighetens": "irrlärighet",
    "irrlärighets": "irrlärighet",
    "irrlärigs": "irrlärig",
    "irrlärigt": "irrlärig",
    "irrlärigts": "irrlärig",
    "irrläro": "irrlära",
    "irrläror": "irrlära",
    "irrlärorna": "irrlära",
    "irrlärornas": "irrlära",
    "irrlärors": "irrlära",
    "isabellafärgen": "isabellafärg",
    "isabellafärgens": "isabellafärg",
    "isabellafärgs": "isabellafärg",
    "isade": "isa",
    "isades": "isa",
    "isagogiken": "isagogik",
    "isagogikens": "isagogik",
    "isagogiks": "isagogik",
    "isagogiska": "isagogisk",
    "isagogiskare": "isagogisk",
    "isagogiskares": "isagogisk",
    "isagogiskas": "isagogisk",
    "isagogiskast": "isagogisk",
    "isagogiskaste": "isagogisk",
    "isagogiskastes": "isagogisk",
    "isagogiskasts": "isagogisk",
    "isagogiske": "isagogisk",
    "isagogiskes": "isagogisk",
    "isagogisks": "isagogisk",
    "isagogiskt": "isagogisk",
    "isagogiskts": "isagogisk",
    "isande": "isa",
    "isanden": "isande",
    "isandena": "isande",
    "isandenas": "isande",
    "isandens": "isande",
    "isandes": "isande",
    "isandet": "isande",
    "isandets": "isande",
    "isar": "isa",
    "isarna": "is",
    "isarnas": "is",
    "isars": "is",
    "isas": "isa",
    "isat": "isa",
    "isats": "isa",
    "isbanan": "isbana",
    "isbanans": "isbana",
    "isbanas": "isbana",
    "isbane": "isbana",
    "isbanor": "isbana",
    "isbanorna": "isbana",
    "isbanornas": "isbana",
    "isbanors": "isbana",
    "isbarken": "isbark",
    "isbarkens": "isbark",
    "isbarks": "isbark",
    "isbergen": "isberg",
    "isbergens": "isberg",
    "isberget": "isberg",
    "isbergets": "isberg",
    "isbergs": "isberg",
    "isbergssalladen": "isbergssallad",
    "isbergssalladens": "isbergssallad",
    "isbergssallads": "isbergssallad",
    "isbildningar": "isbildning",
    "isbildningarna": "isbildning",
    "isbildningarnas": "isbildning",
    "isbildningars": "isbildning",
    "isbildningen": "isbildning",
    "isbildningens": "isbildning",
    "isbildnings": "isbildning",
    "isbillar": "isbill",
    "isbillarna": "isbill",
    "isbillarnas": "isbill",
    "isbillars": "isbill",
    "isbillen": "isbill",
    "isbillens": "isbill",
    "isbills": "isbill",
    "isbitar": "isbit",
    "isbitarna": "isbit",
    "isbitarnas": "isbit",
    "isbitars": "isbit",
    "isbiten": "isbit",
    "isbitens": "isbit",
    "isbits": "isbit",
    "isbjörnar": "isbjörn",
    "isbjörnarna": "isbjörn",
    "isbjörnarnas": "isbjörn",
    "isbjörnars": "isbjörn",
    "isbjörnen": "isbjörn",
    "isbjörnens": "isbjörn",
    "isbjörns": "isbjörn",
    "isblandade": "isblandad",
    "isblandades": "isblandad",
    "isblandads": "isblandad",
    "isblandat": "isblandad",
    "isblandats": "isblandad",
    "isblocken": "isblock",
    "isblockens": "isblock",
    "isblocket": "isblock",
    "isblockets": "isblock",
    "isblocks": "isblock",
    "isblom": "isblomma",
    "isblomman": "isblomma",
    "isblommans": "isblomma",
    "isblommas": "isblomma",
    "isblomme": "isblomma",
    "isblommor": "isblomma",
    "isblommorna": "isblomma",
    "isblommornas": "isblomma",
    "isblommors": "isblomma",
    "isbloms": "isblomma",
    "isblåa": "isblå",
    "isblåare": "isblå",
    "isblåares": "isblå",
    "isblåas": "isblå",
    "isblåast": "isblå",
    "isblåaste": "isblå",
    "isblåastes": "isblå",
    "isblåasts": "isblå",
    "isblåe": "isblå",
    "isblåes": "isblå",
    "isblås": "isblåsa",
    "isblåsan": "isblåsa",
    "isblåsans": "isblåsa",
    "isblåsas": "isblåsa",
    "isblåse": "isblåsa",
    "isblåsor": "isblåsa",
    "isblåsorna": "isblåsa",
    "isblåsornas": "isblåsa",
    "isblåsors": "isblåsa",
    "isblått": "isblå",
    "isblåtts": "isblå",
    "isbojar": "isboj",
    "isbojarna": "isboj",
    "isbojarnas": "isboj",
    "isbojars": "isboj",
    "isbojen": "isboj",
    "isbojens": "isboj",
    "isbojs": "isboj",
    "isborttagar": "isborttagare",
    "isborttagaren": "isborttagare",
    "isborttagarens": "isborttagare",
    "isborttagares": "isborttagare",
    "isborttagarna": "isborttagare",
    "isborttagarnas": "isborttagare",
    "isbroddar": "isbrodd",
    "isbroddarna": "isbrodd",
    "isbroddarnas": "isbrodd",
    "isbroddars": "isbrodd",
    "isbrodden": "isbrodd",
    "isbroddens": "isbrodd",
    "isbrodds": "isbrodd",
    "isbrytar": "isbrytare",
    "isbrytaregenskapen": "isbrytaregenskap",
    "isbrytaregenskapens": "isbrytaregenskap",
    "isbrytaregenskaper": "isbrytaregenskap",
    "isbrytaregenskaperna": "isbrytaregenskap",
    "isbrytaregenskapernas": "isbrytaregenskap",
    "isbrytaregenskapers": "isbrytaregenskap",
    "isbrytaregenskaps": "isbrytaregenskap",
    "isbrytaren": "isbrytare",
    "isbrytarens": "isbrytare",
    "isbrytares": "isbrytare",
    "isbrytarna": "isbrytare",
    "isbrytarnas": "isbrytare",
    "isbrytningar": "isbrytning",
    "isbrytningarna": "isbrytning",
    "isbrytningarnas": "isbrytning",
    "isbrytningars": "isbrytning",
    "isbrytningen": "isbrytning",
    "isbrytningens": "isbrytning",
    "isbrytnings": "isbrytning",
    "isbrännan": "isbränna",
    "isbrännans": "isbränna",
    "isbrännas": "isbränna",
    "isbälten": "isbälte",
    "isbältena": "isbälte",
    "isbältenas": "isbälte",
    "isbältens": "isbälte",
    "isbältes": "isbälte",
    "isbältet": "isbälte",
    "isbältets": "isbälte",
    "iscensatt": "iscensätta",
    "iscensatta": "iscensätta",
    "iscensattas": "iscensätta",
    "iscensatte": "iscensätta",
    "iscensattes": "iscensätta",
    "iscensatts": "iscensätta",
    "iscensätt": "iscensätta",
    "iscensättande": "iscensätta",
    "iscensättanden": "iscensättande",
    "iscensättandena": "iscensättande",
    "iscensättandenas": "iscensättande",
    "iscensättandens": "iscensättande",
    "iscensättandes": "iscensättande",
    "iscensättandet": "iscensättande",
    "iscensättandets": "iscensättande",
    "iscensättas": "iscensätta",
    "iscensätter": "iscensätta",
    "iscensättes": "iscensätta",
    "iscensättningar": "iscensättning",
    "iscensättningarna": "iscensättning",
    "iscensättningarnas": "iscensättning",
    "iscensättningars": "iscensättning",
    "iscensättningen": "iscensättning",
    "iscensättningens": "iscensättning",
    "iscensättnings": "iscensättning",
    "iscensätts": "iscensätta",
    "ischiasen": "ischias",
    "ischiasens": "ischias",
    "ischiasnerven": "ischiasnerv",
    "ischiasnervens": "ischiasnerv",
    "ischiasnerver": "ischiasnerv",
    "ischiasnerverna": "ischiasnerv",
    "ischiasnervernas": "ischiasnerv",
    "ischiasnervers": "ischiasnerv",
    "ischiasnervs": "ischiasnerv",
    "ischokladen": "ischoklad",
    "ischokladens": "ischoklad",
    "ischoklads": "ischoklad",
    "ischurien": "ischuri",
    "ischuriens": "ischuri",
    "ischurier": "ischuri",
    "ischurierna": "ischuri",
    "ischuriernas": "ischuri",
    "ischuriers": "ischuri",
    "ischurin": "ischuri",
    "ischurins": "ischuri",
    "ischuris": "ischuri",
    "isdansen": "isdans",
    "isdansens": "isdans",
    "isdrabbade": "isdrabbad",
    "isdrabbades": "isdrabbad",
    "isdrabbads": "isdrabbad",
    "isdrabbat": "isdrabbad",
    "isdrabbats": "isdrabbad",
    "isdubbar": "isdubb",
    "isdubbarna": "isdubb",
    "isdubbarnas": "isdubb",
    "isdubbars": "isdubb",
    "isdubben": "isdubb",
    "isdubbens": "isdubb",
    "isdubbs": "isdubb",
    "isen": "is",
    "isens": "is",
    "isflaken": "isflak",
    "isflakens": "isflak",
    "isflaket": "isflak",
    "isflakets": "isflak",
    "isflaks": "isflak",
    "isfria": "isfri",
    "isfriare": "isfri",
    "isfriares": "isfri",
    "isfrias": "isfri",
    "isfriast": "isfri",
    "isfriaste": "isfri",
    "isfriastes": "isfri",
    "isfriasts": "isfri",
    "isfrie": "isfri",
    "isfries": "isfri",
    "isfris": "isfri",
    "isfritt": "isfri",
    "isfritts": "isfri",
    "isfronten": "isfront",
    "isfrontens": "isfront",
    "isfronter": "isfront",
    "isfronterna": "isfront",
    "isfronternas": "isfront",
    "isfronters": "isfront",
    "isfronts": "isfront",
    "isfågeln": "isfågel",
    "isfågelns": "isfågel",
    "isfågels": "isfågel",
    "isfåglar": "isfågel",
    "isfåglarna": "isfågel",
    "isfåglarnas": "isfågel",
    "isfåglars": "isfågel",
    "isförhållanden": "isförhållande",
    "isförhållandena": "isförhållande",
    "isförhållandenas": "isförhållande",
    "isförhållandens": "isförhållande",
    "isförhållandes": "isförhållande",
    "isförhållandet": "isförhållande",
    "isförhållandets": "isförhållande",
    "isglassar": "isglass",
    "isglassarna": "isglass",
    "isglassarnas": "isglass",
    "isglassars": "isglass",
    "isglassen": "isglass",
    "isglassens": "isglass",
    "ishala": "ishal",
    "ishalare": "ishal",
    "ishalares": "ishal",
    "ishalas": "ishal",
    "ishalast": "ishal",
    "ishalaste": "ishal",
    "ishalastes": "ishal",
    "ishalasts": "ishal",
    "ishale": "ishal",
    "ishales": "ishal",
    "ishalkan": "ishalka",
    "ishalkans": "ishalka",
    "ishalkas": "ishalka",
    "ishallar": "ishall",
    "ishallarna": "ishall",
    "ishallarnas": "ishall",
    "ishallars": "ishall",
    "ishallen": "ishall",
    "ishallens": "ishall",
    "ishalls": "ishall",
    "ishals": "ishal",
    "ishalt": "ishal",
    "ishalts": "ishal",
    "ishaven": "ishav",
    "ishavens": "ishav",
    "ishavet": "ishav",
    "ishavets": "ishav",
    "ishavs": "ishav",
    "ishavsdim": "ishavsdimma",
    "ishavsdimman": "ishavsdimma",
    "ishavsdimmans": "ishavsdimma",
    "ishavsdimmas": "ishavsdimma",
    "ishavsdimme": "ishavsdimma",
    "ishavsdimmor": "ishavsdimma",
    "ishavsdimmorna": "ishavsdimma",
    "ishavsdimmornas": "ishavsdimma",
    "ishavsdimmors": "ishavsdimma",
    "ishavsdims": "ishavsdimma",
    "ishockeyklubb": "ishockeyklubba",
    "ishockeyklubban": "ishockeyklubba",
    "ishockeyklubbans": "ishockeyklubba",
    "ishockeyklubbas": "ishockeyklubba",
    "ishockeyklubbe": "ishockeyklubba",
    "ishockeyklubbor": "ishockeyklubba",
    "ishockeyklubborna": "ishockeyklubba",
    "ishockeyklubbornas": "ishockeyklubba",
    "ishockeyklubbors": "ishockeyklubba",
    "ishockeyklubbs": "ishockeyklubba",
    "ishockeymässiga": "ishockeymässig",
    "ishockeymässigare": "ishockeymässig",
    "ishockeymässigares": "ishockeymässig",
    "ishockeymässigas": "ishockeymässig",
    "ishockeymässigast": "ishockeymässig",
    "ishockeymässigaste": "ishockeymässig",
    "ishockeymässigastes": "ishockeymässig",
    "ishockeymässigasts": "ishockeymässig",
    "ishockeymässige": "ishockeymässig",
    "ishockeymässiges": "ishockeymässig",
    "ishockeymässigs": "ishockeymässig",
    "ishockeymässigt": "ishockeymässig",
    "ishockeymässigts": "ishockeymässig",
    "ishockeyn": "ishockey",
    "ishockeyns": "ishockey",
    "ishockeyrören": "ishockeyrör",
    "ishockeyrörens": "ishockeyrör",
    "ishockeyröret": "ishockeyrör",
    "ishockeyrörets": "ishockeyrör",
    "ishockeyrörs": "ishockeyrör",
    "ishockeys": "ishockey",
    "ishockeyspelar": "ishockeyspelare",
    "ishockeyspelaren": "ishockeyspelare",
    "ishockeyspelarens": "ishockeyspelare",
    "ishockeyspelares": "ishockeyspelare",
    "ishockeyspelarna": "ishockeyspelare",
    "ishockeyspelarnas": "ishockeyspelare",
    "isiga": "isig",
    "isigare": "isig",
    "isigares": "isig",
    "isigas": "isig",
    "isigast": "isig",
    "isigaste": "isig",
    "isigastes": "isig",
    "isigasts": "isig",
    "isige": "isig",
    "isiges": "isig",
    "isigs": "isig",
    "isigt": "isig",
    "isigts": "isig",
    "isjakten": "isjakt",
    "isjaktens": "isjakt",
    "isjakter": "isjakt",
    "isjakterna": "isjakt",
    "isjakternas": "isjakt",
    "isjakters": "isjakt",
    "isjakts": "isjakt",
    "iskalla": "iskall",
    "iskallare": "iskall",
    "iskallares": "iskall",
    "iskallas": "iskall",
    "iskallast": "iskall",
    "iskallaste": "iskall",
    "iskallastes": "iskall",
    "iskallasts": "iskall",
    "iskalle": "iskall",
    "iskalles": "iskall",
    "iskalls": "iskall",
    "iskallt": "iskall",
    "iskallts": "iskall",
    "iskanten": "iskant",
    "iskantens": "iskant",
    "iskanter": "iskant",
    "iskanterna": "iskant",
    "iskanternas": "iskant",
    "iskanters": "iskant",
    "iskants": "iskant",
    "isklumpar": "isklump",
    "isklumparna": "isklump",
    "isklumparnas": "isklump",
    "isklumpars": "isklump",
    "isklumpen": "isklump",
    "isklumpens": "isklump",
    "isklumps": "isklump",
    "iskonvaljen": "iskonvalje",
    "iskonvaljens": "iskonvalje",
    "iskonvaljer": "iskonvalje",
    "iskonvaljerna": "iskonvalje",
    "iskonvaljernas": "iskonvalje",
    "iskonvaljers": "iskonvalje",
    "iskonvaljes": "iskonvalje",
    "iskonvaljs": "iskonvalj",
    "iskornen": "iskorn",
    "iskornens": "iskorn",
    "iskornet": "iskorn",
    "iskornets": "iskorn",
    "iskorns": "iskorn",
    "iskravningar": "iskravning",
    "iskravningarna": "iskravning",
    "iskravningarnas": "iskravning",
    "iskravningars": "iskravning",
    "iskravningen": "iskravning",
    "iskravningens": "iskravning",
    "iskravnings": "iskravning",
    "iskristallen": "iskristall",
    "iskristallens": "iskristall",
    "iskristaller": "iskristall",
    "iskristallerna": "iskristall",
    "iskristallernas": "iskristall",
    "iskristallers": "iskristall",
    "iskristalls": "iskristall",
    "iskylan": "iskyla",
    "iskylans": "iskyla",
    "iskylas": "iskyla",
    "islamiserad": "islamisera",
    "islamiserade": "islamisera",
    "islamiserades": "islamisera",
    "islamiserads": "islamisera",
    "islamiserande": "islamisera",
    "islamiseranden": "islamiserande",
    "islamiserandena": "islamiserande",
    "islamiserandenas": "islamiserande",
    "islamiserandens": "islamiserande",
    "islamiserandes": "islamiserande",
    "islamiserandet": "islamiserande",
    "islamiserandets": "islamiserande",
    "islamiserar": "islamisera",
    "islamiseras": "islamisera",
    "islamiserat": "islamisera",
    "islamiserats": "islamisera",
    "islamiserbara": "islamiserbar",
    "islamiserbarare": "islamiserbar",
    "islamiserbarares": "islamiserbar",
    "islamiserbaras": "islamiserbar",
    "islamiserbarast": "islamiserbar",
    "islamiserbaraste": "islamiserbar",
    "islamiserbarastes": "islamiserbar",
    "islamiserbarasts": "islamiserbar",
    "islamiserbare": "islamiserbar",
    "islamiserbares": "islamiserbar",
    "islamiserbarheten": "islamiserbarhet",
    "islamiserbarhetens": "islamiserbarhet",
    "islamiserbarhets": "islamiserbarhet",
    "islamiserbars": "islamiserbar",
    "islamiserbart": "islamiserbar",
    "islamiserbarts": "islamiserbar",
    "islamiseringen": "islamisering",
    "islamiseringens": "islamisering",
    "islamiserings": "islamisering",
    "islamiska": "islamisk",
    "islamiskare": "islamisk",
    "islamiskares": "islamisk",
    "islamiskas": "islamisk",
    "islamiskast": "islamisk",
    "islamiskaste": "islamisk",
    "islamiskastes": "islamisk",
    "islamiskasts": "islamisk",
    "islamiske": "islamisk",
    "islamiskes": "islamisk",
    "islamisks": "islamisk",
    "islamiskt": "islamisk",
    "islamiskts": "islamisk",
    "islamismen": "islamism",
    "islamismens": "islamism",
    "islamismer": "islamism",
    "islamismerna": "islamism",
    "islamismernas": "islamism",
    "islamismers": "islamism",
    "islamisms": "islamism",
    "islamisten": "islamist",
    "islamistens": "islamist",
    "islamister": "islamist",
    "islamisterna": "islamist",
    "islamisternas": "islamist",
    "islamisters": "islamist",
    "islamistiska": "islamistisk",
    "islamistiskare": "islamistisk",
    "islamistiskares": "islamistisk",
    "islamistiskas": "islamistisk",
    "islamistiskast": "islamistisk",
    "islamistiskaste": "islamistisk",
    "islamistiskastes": "islamistisk",
    "islamistiskasts": "islamistisk",
    "islamistiske": "islamistisk",
    "islamistiskes": "islamistisk",
    "islamistisks": "islamistisk",
    "islamistiskt": "islamistisk",
    "islamistiskts": "islamistisk",
    "islamists": "islamist",
    "islamofobien": "islamofobi",
    "islamofobiens": "islamofobi",
    "islamofobier": "islamofobi",
    "islamofobierna": "islamofobi",
    "islamofobiernas": "islamofobi",
    "islamofobiers": "islamofobi",
    "islamofobin": "islamofobi",
    "islamofobins": "islamofobi",
    "islamofobis": "islamofobi",
    "islams": "islam",
    "islamska": "islamsk",
    "islamskare": "islamsk",
    "islamskares": "islamsk",
    "islamskas": "islamsk",
    "islamskast": "islamsk",
    "islamskaste": "islamsk",
    "islamskastes": "islamsk",
    "islamskasts": "islamsk",
    "islamske": "islamsk",
    "islamskes": "islamsk",
    "islamsks": "islamsk",
    "islamskt": "islamsk",
    "islamskts": "islamsk",
    "islamtalen": "islamtal",
    "islamtalens": "islamtal",
    "islamtalet": "islamtal",
    "islamtalets": "islamtal",
    "islamtals": "islamtal",
    "islandslavar": "islandslav",
    "islandslavarna": "islandslav",
    "islandslavarnas": "islandslav",
    "islandslavars": "islandslav",
    "islandslaven": "islandslav",
    "islandslavens": "islandslav",
    "islandslavs": "islandslav",
    "islandssillar": "islandssill",
    "islandssillarna": "islandssill",
    "islandssillarnas": "islandssill",
    "islandssillars": "islandssill",
    "islandssillen": "islandssill",
    "islandssillens": "islandssill",
    "islandssills": "islandssill",
    "islandströj": "islandströja",
    "islandströjan": "islandströja",
    "islandströjans": "islandströja",
    "islandströjas": "islandströja",
    "islandströje": "islandströja",
    "islandströjor": "islandströja",
    "islandströjorna": "islandströja",
    "islandströjornas": "islandströja",
    "islandströjors": "islandströja",
    "islandströjs": "islandströja",
    "islossningar": "islossning",
    "islossningarna": "islossning",
    "islossningarnas": "islossning",
    "islossningars": "islossning",
    "islossningen": "islossning",
    "islossningens": "islossning",
    "islossnings": "islossning",
    "isländar": "isländare",
    "isländaren": "isländare",
    "isländarens": "isländare",
    "isländares": "isländare",
    "isländarna": "isländare",
    "isländarnas": "isländare",
    "isländsk": "isländska",
    "isländska": "isländsk",
    "isländskan": "isländska",
    "isländskans": "isländska",
    "isländskare": "isländsk",
    "isländskares": "isländsk",
    "isländskas": "isländska",
    "isländskast": "isländsk",
    "isländskaste": "isländsk",
    "isländskastes": "isländsk",
    "isländskasts": "isländsk",
    "isländske": "isländska",
    "isländskes": "isländsk",
    "isländskor": "isländska",
    "isländskorna": "isländska",
    "isländskornas": "isländska",
    "isländskors": "isländska",
    "isländsks": "isländsk",
    "isländskt": "isländsk",
    "isländskts": "isländsk",
    "islänningar": "islänning",
    "islänningarna": "islänning",
    "islänningarnas": "islänning",
    "islänningars": "islänning",
    "islänningen": "islänning",
    "islänningens": "islänning",
    "islännings": "islänning",
    "ismassan": "ismassa",
    "ismassans": "ismassa",
    "ismassas": "ismassa",
    "ismasse": "ismassa",
    "ismassor": "ismassa",
    "ismassorna": "ismassa",
    "ismassornas": "ismassa",
    "ismassors": "ismassa",
    "ismen": "ism",
    "ismens": "ism",
    "ismer": "ism",
    "ismerna": "ism",
    "ismernas": "ism",
    "ismers": "ism",
    "isms": "ism",
    "isobaren": "isobar",
    "isobarens": "isobar",
    "isobarer": "isobar",
    "isobarerna": "isobar",
    "isobarernas": "isobar",
    "isobarers": "isobar",
    "isobars": "isobar",
    "isoglossen": "isogloss",
    "isoglossens": "isogloss",
    "isoglosser": "isogloss",
    "isoglosserna": "isogloss",
    "isoglossernas": "isogloss",
    "isoglossers": "isogloss",
    "isogonen": "isogon",
    "isogonens": "isogon",
    "isogoner": "isogon",
    "isogonerna": "isogon",
    "isogonernas": "isogon",
    "isogoners": "isogon",
    "isogons": "isogon",
    "isolaten": "isolat",
    "isolatens": "isolat",
    "isolatet": "isolat",
    "isolatets": "isolat",
    "isolationismen": "isolationism",
    "isolationismens": "isolationism",
    "isolationismer": "isolationism",
    "isolationismerna": "isolationism",
    "isolationismernas": "isolationism",
    "isolationismers": "isolationism",
    "isolationisms": "isolationism",
    "isolationistiska": "isolationistisk",
    "isolationistiskare": "isolationistisk",
    "isolationistiskares": "isolationistisk",
    "isolationistiskas": "isolationistisk",
    "isolationistiskast": "isolationistisk",
    "isolationistiskaste": "isolationistisk",
    "isolationistiskastes": "isolationistisk",
    "isolationistiskasts": "isolationistisk",
    "isolationistiske": "isolationistisk",
    "isolationistiskes": "isolationistisk",
    "isolationistisks": "isolationistisk",
    "isolationistiskt": "isolationistisk",
    "isolationistiskts": "isolationistisk",
    "isolatorer": "isolator",
    "isolatorerna": "isolator",
    "isolatorernas": "isolator",
    "isolatorers": "isolator",
    "isolatorn": "isolator",
    "isolatorns": "isolator",
    "isolators": "isolator",
    "isolats": "isolat",
    "isolerad": "isolera",
    "isolerade": "isolerad",
    "isolerades": "isolerad",
    "isolerads": "isolerad",
    "isolerande": "isolera",
    "isoleranden": "isolerande",
    "isolerandena": "isolerande",
    "isolerandenas": "isolerande",
    "isolerandens": "isolerande",
    "isolerandes": "isolerande",
    "isolerandet": "isolerande",
    "isolerandets": "isolerande",
    "isolerar": "isolera",
    "isoleras": "isolera",
    "isolerat": "isolerad",
    "isolerats": "isolerad",
    "isolerbanden": "isolerband",
    "isolerbandens": "isolerband",
    "isolerbandet": "isolerband",
    "isolerbandets": "isolerband",
    "isolerbands": "isolerband",
    "isolerbara": "isolerbar",
    "isolerbarare": "isolerbar",
    "isolerbarares": "isolerbar",
    "isolerbaras": "isolerbar",
    "isolerbarast": "isolerbar",
    "isolerbaraste": "isolerbar",
    "isolerbarastes": "isolerbar",
    "isolerbarasts": "isolerbar",
    "isolerbare": "isolerbar",
    "isolerbares": "isolerbar",
    "isolerbarheten": "isolerbarhet",
    "isolerbarhetens": "isolerbarhet",
    "isolerbarhets": "isolerbarhet",
    "isolerbars": "isolerbar",
    "isolerbart": "isolerbar",
    "isolerbarts": "isolerbar",
    "isolerglasen": "isolerglas",
    "isolerglasens": "isolerglas",
    "isolerglaset": "isolerglas",
    "isolerglasets": "isolerglas",
    "isoleringar": "isolering",
    "isoleringarna": "isolering",
    "isoleringarnas": "isolering",
    "isoleringars": "isolering",
    "isoleringen": "isolering",
    "isoleringens": "isolering",
    "isolerings": "isolering",
    "isoleringsavdelningar": "isoleringsavdelning",
    "isoleringsavdelningarna": "isoleringsavdelning",
    "isoleringsavdelningarnas": "isoleringsavdelning",
    "isoleringsavdelningars": "isoleringsavdelning",
    "isoleringsavdelningen": "isoleringsavdelning",
    "isoleringsavdelningens": "isoleringsavdelning",
    "isoleringsavdelnings": "isoleringsavdelning",
    "isoleringsbanden": "isoleringsband",
    "isoleringsbandens": "isoleringsband",
    "isoleringsbandet": "isoleringsband",
    "isoleringsbandets": "isoleringsband",
    "isoleringsbands": "isoleringsband",
    "isoleringscellen": "isoleringscell",
    "isoleringscellens": "isoleringscell",
    "isoleringsceller": "isoleringscell",
    "isoleringscellerna": "isoleringscell",
    "isoleringscellernas": "isoleringscell",
    "isoleringscellers": "isoleringscell",
    "isoleringscells": "isoleringscell",
    "isoleringsklassen": "isoleringsklass",
    "isoleringsklassens": "isoleringsklass",
    "isoleringsklasser": "isoleringsklass",
    "isoleringsklasserna": "isoleringsklass",
    "isoleringsklassernas": "isoleringsklass",
    "isoleringsklassers": "isoleringsklass",
    "isoleringsmaterialen": "isoleringsmaterial",
    "isoleringsmaterialens": "isoleringsmaterial",
    "isoleringsmaterialet": "isoleringsmaterial",
    "isoleringsmaterialets": "isoleringsmaterial",
    "isoleringsmaterials": "isoleringsmaterial",
    "isoleringsrutan": "isoleringsruta",
    "isoleringsrutans": "isoleringsruta",
    "isoleringsrutas": "isoleringsruta",
    "isoleringsrute": "isoleringsruta",
    "isoleringsrutor": "isoleringsruta",
    "isoleringsrutorna": "isoleringsruta",
    "isoleringsrutornas": "isoleringsruta",
    "isoleringsrutors": "isoleringsruta",
    "isomera": "isomer",
    "isomerare": "isomer",
    "isomerares": "isomer",
    "isomeras": "isomer",
    "isomerast": "isomer",
    "isomeraste": "isomer",
    "isomerastes": "isomer",
    "isomerasts": "isomer",
    "isomere": "isomer",
    "isomeren": "isomer",
    "isomerens": "isomer",
    "isomerer": "isomer",
    "isomererna": "isomer",
    "isomerernas": "isomer",
    "isomerers": "isomer",
    "isomeres": "isomer",
    "isomerien": "isomeri",
    "isomeriens": "isomeri",
    "isomerier": "isomeri",
    "isomerierna": "isomeri",
    "isomeriernas": "isomeri",
    "isomeriers": "isomeri",
    "isomerin": "isomeri",
    "isomerins": "isomeri",
    "isomeris": "isomeri",
    "isomers": "isomer",
    "isomert": "isomer",
    "isomerts": "isomer",
    "isomorfa": "isomorf",
    "isomorfare": "isomorf",
    "isomorfares": "isomorf",
    "isomorfas": "isomorf",
    "isomorfast": "isomorf",
    "isomorfaste": "isomorf",
    "isomorfastes": "isomorf",
    "isomorfasts": "isomorf",
    "isomorfe": "isomorf",
    "isomorfes": "isomorf",
    "isomorfien": "isomorfi",
    "isomorfiens": "isomorfi",
    "isomorfier": "isomorfi",
    "isomorfierna": "isomorfi",
    "isomorfiernas": "isomorfi",
    "isomorfiers": "isomorfi",
    "isomorfin": "isomorfi",
    "isomorfins": "isomorfi",
    "isomorfis": "isomorfi",
    "isomorfs": "isomorf",
    "isomorft": "isomorf",
    "isomorfts": "isomorf",
    "isooktanen": "isooktan",
    "isooktanens": "isooktan",
    "isooktaner": "isooktan",
    "isooktanerna": "isooktan",
    "isooktanernas": "isooktan",
    "isooktaners": "isooktan",
    "isooktanet": "isooktan",
    "isooktanets": "isooktan",
    "isooktans": "isooktan",
    "isopen": "isop",
    "isopens": "isop",
    "isops": "isop",
    "isotermen": "isoterm",
    "isotermens": "isoterm",
    "isotermer": "isoterm",
    "isotermerna": "isoterm",
    "isotermernas": "isoterm",
    "isotermers": "isoterm",
    "isoterms": "isoterm",
    "isotopen": "isotop",
    "isotopens": "isotop",
    "isotoper": "isotop",
    "isotoperna": "isotop",
    "isotopernas": "isotop",
    "isotopers": "isotop",
    "isotopmätningar": "isotopmätning",
    "isotopmätningarna": "isotopmätning",
    "isotopmätningarnas": "isotopmätning",
    "isotopmätningars": "isotopmätning",
    "isotopmätningen": "isotopmätning",
    "isotopmätningens": "isotopmätning",
    "isotopmätnings": "isotopmätning",
    "isotops": "isotop",
    "isperioden": "isperiod",
    "isperiodens": "isperiod",
    "isperioder": "isperiod",
    "isperioderna": "isperiod",
    "isperiodernas": "isperiod",
    "isperioders": "isperiod",
    "isperiods": "isperiod",
    "ispiggar": "ispigg",
    "ispiggarna": "ispigg",
    "ispiggarnas": "ispigg",
    "ispiggars": "ispigg",
    "ispiggen": "ispigg",
    "ispiggens": "ispigg",
    "ispiggs": "ispigg",
    "ispikar": "ispik",
    "ispikarna": "ispik",
    "ispikarnas": "ispik",
    "ispikars": "ispik",
    "ispiken": "ispik",
    "ispikens": "ispik",
    "ispiks": "ispik",
    "isprinsess": "isprinsessa",
    "isprinsessan": "isprinsessa",
    "isprinsessans": "isprinsessa",
    "isprinsessas": "isprinsessa",
    "isprinsesse": "isprinsessa",
    "isprinsessor": "isprinsessa",
    "isprinsessorna": "isprinsessa",
    "isprinsessornas": "isprinsessa",
    "isprinsessors": "isprinsessa",
    "isproppar": "ispropp",
    "ispropparna": "ispropp",
    "ispropparnas": "ispropp",
    "isproppars": "ispropp",
    "isproppen": "ispropp",
    "isproppens": "ispropp",
    "ispropps": "ispropp",
    "isracingen": "isracing",
    "isracingens": "isracing",
    "isracings": "isracing",
    "israelen": "israel",
    "israelens": "israel",
    "israeler": "israel",
    "israelerna": "israel",
    "israelernas": "israel",
    "israelers": "israel",
    "israeliska": "israelisk",
    "israeliskan": "israeliska",
    "israeliskans": "israeliska",
    "israeliskare": "israelisk",
    "israeliskares": "israelisk",
    "israeliskas": "israeliska",
    "israeliskast": "israelisk",
    "israeliskaste": "israelisk",
    "israeliskastes": "israelisk",
    "israeliskasts": "israelisk",
    "israeliske": "israeliska",
    "israeliskes": "israelisk",
    "israeliskor": "israeliska",
    "israeliskorna": "israeliska",
    "israeliskornas": "israeliska",
    "israeliskors": "israeliska",
    "israelisks": "israelisk",
    "israeliskt": "israelisk",
    "israeliskts": "israelisk",
    "israeliten": "israelit",
    "israelitens": "israelit",
    "israeliter": "israelit",
    "israeliterna": "israelit",
    "israeliternas": "israelit",
    "israeliters": "israelit",
    "israelitiska": "israelitisk",
    "israelitiskare": "israelitisk",
    "israelitiskares": "israelitisk",
    "israelitiskas": "israelitisk",
    "israelitiskast": "israelitisk",
    "israelitiskaste": "israelitisk",
    "israelitiskastes": "israelitisk",
    "israelitiskasts": "israelitisk",
    "israelitiske": "israelitisk",
    "israelitiskes": "israelitisk",
    "israelitisks": "israelitisk",
    "israelitiskt": "israelitisk",
    "israelitiskts": "israelitisk",
    "israelits": "israelit",
    "israels": "israel",
    "isranden": "isrand",
    "israndens": "isrand",
    "isrands": "isrand",
    "isranunkeln": "isranunkel",
    "isranunkelns": "isranunkel",
    "isranunkels": "isranunkel",
    "isranunklar": "isranunkel",
    "isranunklarna": "isranunkel",
    "isranunklarnas": "isranunkel",
    "isranunklars": "isranunkel",
    "isranunkler": "isranunkel",
    "isranunklerna": "isranunkel",
    "isranunklernas": "isranunkel",
    "isranunklers": "isranunkel",
    "israpporten": "israpport",
    "israpportens": "israpport",
    "israpporter": "israpport",
    "israpporterna": "israpport",
    "israpporternas": "israpport",
    "israpporters": "israpport",
    "israpports": "israpport",
    "isrevyer": "isrevy",
    "isrevyerna": "isrevy",
    "isrevyernas": "isrevy",
    "isrevyers": "isrevy",
    "isrevyn": "isrevy",
    "isrevyns": "isrevy",
    "isrevys": "isrevy",
    "isräffel": "isräffla",
    "isräfflan": "isräffla",
    "isräfflans": "isräffla",
    "isräfflas": "isräffla",
    "isräffle": "isräffla",
    "isräfflor": "isräffla",
    "isräfflorna": "isräffla",
    "isräfflornas": "isräffla",
    "isräfflors": "isräffla",
    "isränder": "isrand",
    "isränderna": "isrand",
    "isrändernas": "isrand",
    "isränders": "isrand",
    "isränn": "isränna",
    "isrännan": "isränna",
    "isrännans": "isränna",
    "isrännas": "isränna",
    "isränne": "isränna",
    "isrännor": "isränna",
    "isrännorna": "isränna",
    "isrännornas": "isränna",
    "isrännors": "isränna",
    "isränns": "isränna",
    "issjöar": "issjö",
    "issjöarna": "issjö",
    "issjöarnas": "issjö",
    "issjöars": "issjö",
    "issjön": "issjö",
    "issjöns": "issjö",
    "issjös": "issjö",
    "isskrapan": "isskrapa",
    "isskrapans": "isskrapa",
    "isskrapas": "isskrapa",
    "isskrape": "isskrapa",
    "isskrapor": "isskrapa",
    "isskraporna": "isskrapa",
    "isskrapornas": "isskrapa",
    "isskrapors": "isskrapa",
    "isskruvningar": "isskruvning",
    "isskruvningarna": "isskruvning",
    "isskruvningarnas": "isskruvning",
    "isskruvningars": "isskruvning",
    "isskruvningen": "isskruvning",
    "isskruvningens": "isskruvning",
    "isskruvnings": "isskruvning",
    "issmältningar": "issmältning",
    "issmältningarna": "issmältning",
    "issmältningarnas": "issmältning",
    "issmältningars": "issmältning",
    "issmältningen": "issmältning",
    "issmältningens": "issmältning",
    "issmältnings": "issmältning",
    "issörjan": "issörja",
    "issörjans": "issörja",
    "issörjas": "issörja",
    "istadarätten": "istadarätt",
    "istadarättens": "istadarätt",
    "istadarätts": "istadarätt",
    "istadiga": "istadig",
    "istadigare": "istadig",
    "istadigares": "istadig",
    "istadigas": "istadig",
    "istadigast": "istadig",
    "istadigaste": "istadig",
    "istadigastes": "istadig",
    "istadigasts": "istadig",
    "istadige": "istadig",
    "istadiges": "istadig",
    "istadigheten": "istadighet",
    "istadighetens": "istadighet",
    "istadighets": "istadighet",
    "istadigs": "istadig",
    "istadigt": "istadig",
    "istadigts": "istadig",
    "istappar": "istapp",
    "istapparna": "istapp",
    "istapparnas": "istapp",
    "istappars": "istapp",
    "istappen": "istapp",
    "istappens": "istapp",
    "istapps": "istapp",
    "isterbanden": "isterband",
    "isterbandens": "isterband",
    "isterbandet": "isterband",
    "isterbandets": "isterband",
    "isterbands": "isterband",
    "isterbukar": "isterbuk",
    "isterbukarna": "isterbuk",
    "isterbukarnas": "isterbuk",
    "isterbukars": "isterbuk",
    "isterbuken": "isterbuk",
    "isterbukens": "isterbuk",
    "isterbuks": "isterbuk",
    "isterflottet": "isterflott",
    "isterflottets": "isterflott",
    "isterflotts": "isterflott",
    "isterhak": "isterhaka",
    "isterhakan": "isterhaka",
    "isterhakans": "isterhaka",
    "isterhakas": "isterhaka",
    "isterhake": "isterhaka",
    "isterhakor": "isterhaka",
    "isterhakorna": "isterhaka",
    "isterhakornas": "isterhaka",
    "isterhakors": "isterhaka",
    "isterhaks": "isterhaka",
    "isters": "ister",
    "istiden": "istid",
    "istidens": "istid",
    "istider": "istid",
    "istiderna": "istid",
    "istidernas": "istid",
    "istiders": "istid",
    "istids": "istid",
    "istidsforskar": "istidsforskare",
    "istidsforskaren": "istidsforskare",
    "istidsforskarens": "istidsforskare",
    "istidsforskares": "istidsforskare",
    "istidsforskarna": "istidsforskare",
    "istidsforskarnas": "istidsforskare",
    "istret": "ister",
    "istrets": "ister",
    "istrycken": "istryck",
    "istryckens": "istryck",
    "istrycket": "istryck",
    "istryckets": "istryck",
    "istrycks": "istryck",
    "istäcken": "istäcke",
    "istäckena": "istäcke",
    "istäckenas": "istäcke",
    "istäckens": "istäcke",
    "istäckes": "istäcke",
    "istäcket": "istäcke",
    "istäckets": "istäcke",
    "istäckta": "istäckt",
    "istäcktare": "istäckt",
    "istäcktares": "istäckt",
    "istäcktas": "istäckt",
    "istäcktast": "istäckt",
    "istäcktaste": "istäckt",
    "istäcktastes": "istäckt",
    "istäcktasts": "istäckt",
    "istäckte": "istäckt",
    "istäcktes": "istäckt",
    "istäckts": "istäckt",
    "iståndsatt": "iståndsätta",
    "iståndsatta": "iståndsätta",
    "iståndsattas": "iståndsätta",
    "iståndsatte": "iståndsätta",
    "iståndsattes": "iståndsätta",
    "iståndsatts": "iståndsätta",
    "iståndsätt": "iståndsätta",
    "iståndsättande": "iståndsätta",
    "iståndsättanden": "iståndsättande",
    "iståndsättandena": "iståndsättande",
    "iståndsättandenas": "iståndsättande",
    "iståndsättandens": "iståndsättande",
    "iståndsättandes": "iståndsättande",
    "iståndsättandet": "iståndsättande",
    "iståndsättandets": "iståndsättande",
    "iståndsättas": "iståndsätta",
    "iståndsätter": "iståndsätta",
    "iståndsättes": "iståndsätta",
    "iståndsätts": "iståndsätta",
    "isvakar": "isvak",
    "isvakarna": "isvak",
    "isvakarnas": "isvak",
    "isvakars": "isvak",
    "isvaken": "isvak",
    "isvakens": "isvak",
    "isvaks": "isvak",
    "isvarningar": "isvarning",
    "isvarningarna": "isvarning",
    "isvarningarnas": "isvarning",
    "isvarningars": "isvarning",
    "isvarningen": "isvarning",
    "isvarningens": "isvarning",
    "isvarnings": "isvarning",
    "isyx": "isyxa",
    "isyxan": "isyxa",
    "isyxans": "isyxa",
    "isyxas": "isyxa",
    "isyxe": "isyxa",
    "isyxor": "isyxa",
    "isyxorna": "isyxa",
    "isyxornas": "isyxa",
    "isyxors": "isyxa",
    "isälvar": "isälv",
    "isälvarna": "isälv",
    "isälvarnas": "isälv",
    "isälvars": "isälv",
    "isälven": "isälv",
    "isälvens": "isälv",
    "isälvs": "isälv",
    "isättningar": "isättning",
    "isättningarna": "isättning",
    "isättningarnas": "isättning",
    "isättningars": "isättning",
    "isättningen": "isättning",
    "isättningens": "isättning",
    "isättnings": "isättning",
    "it": "i",
    "it-företagen": "it-företag",
    "it-företagets": "it-företag",
    "it-jättar": "it-jätte",
    "it-jättarnas": "it-jätte",
    "it-jätten": "it-jätte",
    "it-jättes": "it-jätte",
    "italern": "italer",
    "italerna": "italer",
    "italernas": "italer",
    "italerns": "italer",
    "italers": "italer",
    "italienar": "italienare",
    "italienaren": "italienare",
    "italienarens": "italienare",
    "italienares": "italienare",
    "italienarna": "italienare",
    "italienarnas": "italienare",
    "italiensk": "italienska",
    "italienska": "italiensk",
    "italienskan": "italienska",
    "italienskans": "italienska",
    "italienskare": "italiensk",
    "italienskares": "italiensk",
    "italienskas": "italienska",
    "italienskast": "italiensk",
    "italienskaste": "italiensk",
    "italienskastes": "italiensk",
    "italienskasts": "italiensk",
    "italienske": "italienska",
    "italienskes": "italiensk",
    "italienskor": "italienska",
    "italienskorna": "italienska",
    "italienskornas": "italienska",
    "italienskors": "italienska",
    "italiensks": "italiensk",
    "italienskt": "italiensk",
    "italienskts": "italiensk",
    "italikern": "italiker",
    "italikerna": "italiker",
    "italikernas": "italiker",
    "italikerns": "italiker",
    "italikers": "italiker",
    "italiska": "italisk",
    "italiskare": "italisk",
    "italiskares": "italisk",
    "italiskas": "italisk",
    "italiskast": "italisk",
    "italiskaste": "italisk",
    "italiskastes": "italisk",
    "italiskasts": "italisk",
    "italiske": "italisk",
    "italiskes": "italisk",
    "italisks": "italisk",
    "italiskt": "italisk",
    "italiskts": "italisk",
    "items": "item",
    "iterationen": "iteration",
    "iterationens": "iteration",
    "iterationer": "iteration",
    "iterationerna": "iteration",
    "iterationernas": "iteration",
    "iterationers": "iteration",
    "iterations": "iteration",
    "iterativa": "iterativ",
    "iterativare": "iterativ",
    "iterativares": "iterativ",
    "iterativas": "iterativ",
    "iterativast": "iterativ",
    "iterativaste": "iterativ",
    "iterativastes": "iterativ",
    "iterativasts": "iterativ",
    "iterative": "iterativ",
    "iteratives": "iterativ",
    "iterativs": "iterativ",
    "iterativt": "iterativ",
    "iterativts": "iterativ",
    "itererad": "iterera",
    "itererade": "iterera",
    "itererades": "iterera",
    "itererads": "iterera",
    "itererande": "iterera",
    "itereranden": "itererande",
    "itererandena": "itererande",
    "itererandenas": "itererande",
    "itererandens": "itererande",
    "itererandes": "itererande",
    "itererandet": "itererande",
    "itererandets": "itererande",
    "itererar": "iterera",
    "itereras": "iterera",
    "itererat": "iterera",
    "itererats": "iterera",
    "itererbara": "itererbar",
    "itererbarare": "itererbar",
    "itererbarares": "itererbar",
    "itererbaras": "itererbar",
    "itererbarast": "itererbar",
    "itererbaraste": "itererbar",
    "itererbarastes": "itererbar",
    "itererbarasts": "itererbar",
    "itererbare": "itererbar",
    "itererbares": "itererbar",
    "itererbarheten": "itererbarhet",
    "itererbarhetens": "itererbarhet",
    "itererbarhets": "itererbarhet",
    "itererbars": "itererbar",
    "itererbart": "itererbar",
    "itererbarts": "itererbar",
    "itereringar": "iterering",
    "itereringarna": "iterering",
    "itereringarnas": "iterering",
    "itereringars": "iterering",
    "itereringen": "iterering",
    "itereringens": "iterering",
    "itererings": "iterering",
    "its": "i",
    "itts": "idas",
    "itudelade": "itudelad",
    "itudelades": "itudelad",
    "itudelads": "itudelad",
    "itudelat": "itudelad",
    "itudelats": "itudelad",
    "itut": "ituta",
    "itutad": "ituta",
    "itutade": "ituta",
    "itutades": "ituta",
    "itutads": "ituta",
    "itutande": "ituta",
    "itutanden": "itutande",
    "itutandena": "itutande",
    "itutandenas": "itutande",
    "itutandens": "itutande",
    "itutandes": "itutande",
    "itutandet": "itutande",
    "itutandets": "itutande",
    "itutar": "ituta",
    "itutas": "ituta",
    "itutat": "ituta",
    "itutats": "ituta",
    "ivern": "iver",
    "iverns": "iver",
    "ivers": "iver",
    "ivorianen": "ivorian",
    "ivorianens": "ivorian",
    "ivorianer": "ivorian",
    "ivorianerna": "ivorian",
    "ivorianernas": "ivorian",
    "ivorianers": "ivorian",
    "ivorians": "ivorian",
    "ivorianska": "ivoriansk",
    "ivorianskan": "ivorianska",
    "ivorianskans": "ivorianska",
    "ivorianskare": "ivoriansk",
    "ivorianskares": "ivoriansk",
    "ivorianskas": "ivorianska",
    "ivorianskast": "ivoriansk",
    "ivorianskaste": "ivoriansk",
    "ivorianskastes": "ivoriansk",
    "ivorianskasts": "ivoriansk",
    "ivorianske": "ivorianska",
    "ivorianskes": "ivoriansk",
    "ivorianskor": "ivorianska",
    "ivorianskorna": "ivorianska",
    "ivorianskornas": "ivorianska",
    "ivorianskors": "ivorianska",
    "ivoriansks": "ivoriansk",
    "ivorianskt": "ivoriansk",
    "ivorianskts": "ivoriansk",
    "ivrade": "ivra",
    "ivrades": "ivra",
    "ivrande": "ivra",
    "ivranden": "ivrande",
    "ivrandena": "ivrande",
    "ivrandenas": "ivrande",
    "ivrandens": "ivrande",
    "ivrandes": "ivrande",
    "ivrandet": "ivrande",
    "ivrandets": "ivrande",
    "ivrans": "ivran",
    "ivrar": "ivrare",
    "ivraren": "ivrare",
    "ivrarens": "ivrare",
    "ivrares": "ivrare",
    "ivrarna": "ivrare",
    "ivrarnas": "ivrare",
    "ivras": "ivra",
    "ivrat": "ivra",
    "ivrats": "ivra",
    "ivriga": "ivrig",
    "ivrigare": "ivrig",
    "ivrigares": "ivrig",
    "ivrigas": "ivrig",
    "ivrigast": "ivrig",
    "ivrigaste": "ivrig",
    "ivrigastes": "ivrig",
    "ivrigasts": "ivrig",
    "ivrige": "ivrig",
    "ivriges": "ivrig",
    "ivrigheten": "ivrighet",
    "ivrighetens": "ivrighet",
    "ivrighets": "ivrighet",
    "ivrigs": "ivrig",
    "ivrigt": "ivrig",
    "ivrigts": "ivrig",
    "ivägskick": "ivägskicka",
    "ivägskickad": "ivägskicka",
    "ivägskickade": "ivägskicka",
    "ivägskickades": "ivägskicka",
    "ivägskickads": "ivägskicka",
    "ivägskickande": "ivägskicka",
    "ivägskickanden": "ivägskickande",
    "ivägskickandena": "ivägskickande",
    "ivägskickandenas": "ivägskickande",
    "ivägskickandens": "ivägskickande",
    "ivägskickandes": "ivägskickande",
    "ivägskickandet": "ivägskickande",
    "ivägskickandets": "ivägskickande",
    "ivägskickar": "ivägskicka",
    "ivägskickas": "ivägskicka",
    "ivägskickat": "ivägskicka",
    "ivägskickats": "ivägskicka",
    "j-et": "j",
    "j-ets": "j",
    "j-n": "j",
    "j-na": "j",
    "j-nas": "j",
    "j-ns": "j",
    "j-s": "j",
    "j-t": "j",
    "j-ts": "j",
    "j:et": "j",
    "j:ets": "j",
    "j:n": "j",
    "j:na": "j",
    "j:nas": "j",
    "j:ns": "j",
    "j:s": "j",
    "j:t": "j",
    "j:ts": "j",
    "jabar": "jab",
    "jabarna": "jab",
    "jabarnas": "jab",
    "jabars": "jab",
    "jabb": "jabba",
    "jabbad": "jabba",
    "jabbade": "jabba",
    "jabbades": "jabba",
    "jabbads": "jabba",
    "jabbande": "jabba",
    "jabbanden": "jabbande",
    "jabbandena": "jabbande",
    "jabbandenas": "jabbande",
    "jabbandens": "jabbande",
    "jabbandes": "jabbande",
    "jabbandet": "jabbande",
    "jabbandets": "jabbande",
    "jabbar": "jabba",
    "jabbarna": "jabb",
    "jabbarnas": "jabb",
    "jabbars": "jabb",
    "jabbas": "jabba",
    "jabbat": "jabba",
    "jabbats": "jabba",
    "jabben": "jabb",
    "jabbens": "jabb",
    "jabbs": "jabb",
    "jaben": "jab",
    "jabens": "jab",
    "jabirustorkar": "jabirustork",
    "jabirustorkarna": "jabirustork",
    "jabirustorkarnas": "jabirustork",
    "jabirustorkars": "jabirustork",
    "jabirustorken": "jabirustork",
    "jabirustorkens": "jabirustork",
    "jabirustorks": "jabirustork",
    "jaboten": "jabot",
    "jabotens": "jabot",
    "jaboter": "jabot",
    "jaboterna": "jabot",
    "jaboternas": "jabot",
    "jaboters": "jabot",
    "jabots": "jabot",
    "jabs": "jab",
    "jack": "jacka",
    "jackan": "jacka",
    "jackans": "jacka",
    "jackar": "jack",
    "jackarna": "jack",
    "jackarnas": "jack",
    "jackars": "jack",
    "jackas": "jacka",
    "jacke": "jacka",
    "jacken": "jack",
    "jackens": "jack",
    "jacket": "jack",
    "jacketkron": "jacketkrona",
    "jacketkronan": "jacketkrona",
    "jacketkronans": "jacketkrona",
    "jacketkronas": "jacketkrona",
    "jacketkrone": "jacketkrona",
    "jacketkronor": "jacketkrona",
    "jacketkronorna": "jacketkrona",
    "jacketkronornas": "jacketkrona",
    "jacketkronors": "jacketkrona",
    "jacketkrons": "jacketkrona",
    "jackets": "jack",
    "jackettbyx": "jackettbyxa",
    "jackettbyxan": "jackettbyxa",
    "jackettbyxans": "jackettbyxa",
    "jackettbyxas": "jackettbyxa",
    "jackettbyxe": "jackettbyxa",
    "jackettbyxor": "jackettbyxa",
    "jackettbyxorna": "jackettbyxa",
    "jackettbyxornas": "jackettbyxa",
    "jackettbyxors": "jackettbyxa",
    "jacketten": "jackett",
    "jackettens": "jackett",
    "jacketter": "jackett",
    "jacketterna": "jackett",
    "jacketternas": "jackett",
    "jacketters": "jackett",
    "jacketts": "jackett",
    "jackfick": "jackficka",
    "jackfickan": "jackficka",
    "jackfickans": "jackficka",
    "jackfickas": "jackficka",
    "jackficke": "jackficka",
    "jackfickor": "jackficka",
    "jackfickorna": "jackficka",
    "jackfickornas": "jackficka",
    "jackfickors": "jackficka",
    "jackficks": "jackficka",
    "jackiga": "jackig",
    "jackigare": "jackig",
    "jackigares": "jackig",
    "jackigas": "jackig",
    "jackigast": "jackig",
    "jackigaste": "jackig",
    "jackigastes": "jackig",
    "jackigasts": "jackig",
    "jackige": "jackig",
    "jackiges": "jackig",
    "jackigheten": "jackighet",
    "jackighetens": "jackighet",
    "jackighets": "jackighet",
    "jackigs": "jackig",
    "jackigt": "jackig",
    "jackigts": "jackig",
    "jackor": "jacka",
    "jackorna": "jacka",
    "jackornas": "jacka",
    "jackors": "jacka",
    "jackpotar": "jackpot",
    "jackpotarna": "jackpot",
    "jackpotarnas": "jackpot",
    "jackpotars": "jackpot",
    "jackpoten": "jackpot",
    "jackpotens": "jackpot",
    "jackpoter": "jackpot",
    "jackpoterna": "jackpot",
    "jackpoternas": "jackpot",
    "jackpoters": "jackpot",
    "jackpots": "jackpot",
    "jackproppar": "jackpropp",
    "jackpropparna": "jackpropp",
    "jackpropparnas": "jackpropp",
    "jackproppars": "jackpropp",
    "jackproppen": "jackpropp",
    "jackproppens": "jackpropp",
    "jackpropps": "jackpropp",
    "jacks": "jacka",
    "jackuttagen": "jackuttag",
    "jackuttagens": "jackuttag",
    "jackuttaget": "jackuttag",
    "jackuttagets": "jackuttag",
    "jackuttags": "jackuttag",
    "jacquarden": "jacquard",
    "jacquardens": "jacquard",
    "jacquards": "jacquard",
    "jacuzzin": "jacuzzi",
    "jacuzzins": "jacuzzi",
    "jacuzzis": "jacuzzi",
    "jacuzzisarna": "jacuzzi",
    "jacuzzisarnas": "jacuzzi",
    "jacuzzisen": "jacuzzi",
    "jacuzzisens": "jacuzzi",
    "jadegröna": "jadegrön",
    "jadegrönare": "jadegrön",
    "jadegrönares": "jadegrön",
    "jadegrönas": "jadegrön",
    "jadegrönast": "jadegrön",
    "jadegrönaste": "jadegrön",
    "jadegrönastes": "jadegrön",
    "jadegrönasts": "jadegrön",
    "jadegröne": "jadegrön",
    "jadegrönes": "jadegrön",
    "jadegröns": "jadegrön",
    "jadegrönt": "jadegrön",
    "jadegrönts": "jadegrön",
    "jadeiten": "jadeit",
    "jadeitens": "jadeit",
    "jadeits": "jadeit",
    "jaden": "jade",
    "jadens": "jade",
    "jades": "jade",
    "jaet": "ja",
    "jaets": "ja",
    "jag": "jaga",
    "jagad": "jaga",
    "jagade": "jaga",
    "jagades": "jaga",
    "jagads": "jaga",
    "jagande": "jaga",
    "jaganden": "jagande",
    "jagandena": "jagande",
    "jagandenas": "jagande",
    "jagandens": "jagande",
    "jagandes": "jagande",
    "jagandet": "jagande",
    "jagandets": "jagande",
    "jagar": "jagare",
    "jagaren": "jagare",
    "jagarens": "jagare",
    "jagares": "jagare",
    "jagarna": "jagare",
    "jagarnas": "jagare",
    "jagas": "jaga",
    "jagat": "jaga",
    "jagats": "jaga",
    "jagdriften": "jagdrift",
    "jagdriftens": "jagdrift",
    "jagdrifts": "jagdrift",
    "jagen": "jag",
    "jagens": "jag",
    "jaget": "jag",
    "jagets": "jag",
    "jagformen": "jagform",
    "jagformens": "jagform",
    "jagforms": "jagform",
    "jagföreställningar": "jagföreställning",
    "jagföreställningarna": "jagföreställning",
    "jagföreställningarnas": "jagföreställning",
    "jagföreställningars": "jagföreställning",
    "jagföreställningen": "jagföreställning",
    "jagföreställningens": "jagföreställning",
    "jagföreställnings": "jagföreställning",
    "jaggernautar": "jaggernaut",
    "jaggernautarna": "jaggernaut",
    "jaggernautarnas": "jaggernaut",
    "jaggernautars": "jaggernaut",
    "jaggernauten": "jaggernaut",
    "jaggernautens": "jaggernaut",
    "jaggernauts": "jaggernaut",
    "jagiska": "jagisk",
    "jagiskare": "jagisk",
    "jagiskares": "jagisk",
    "jagiskas": "jagisk",
    "jagiskast": "jagisk",
    "jagiskaste": "jagisk",
    "jagiskastes": "jagisk",
    "jagiskasts": "jagisk",
    "jagiske": "jagisk",
    "jagiskes": "jagisk",
    "jagisks": "jagisk",
    "jagiskt": "jagisk",
    "jagiskts": "jagisk",
    "jagkänslan": "jagkänsla",
    "jagkänslans": "jagkänsla",
    "jagkänslas": "jagkänsla",
    "jagkänsle": "jagkänsla",
    "jagkänslo": "jagkänsla",
    "jaglin": "jaglina",
    "jaglinan": "jaglina",
    "jaglinans": "jaglina",
    "jaglinas": "jaglina",
    "jagline": "jaglina",
    "jaglinor": "jaglina",
    "jaglinorna": "jaglina",
    "jaglinornas": "jaglina",
    "jaglinors": "jaglina",
    "jaglins": "jaglina",
    "jagmodellen": "jagmodell",
    "jagmodellens": "jagmodell",
    "jagmodeller": "jagmodell",
    "jagmodellerna": "jagmodell",
    "jagmodellernas": "jagmodell",
    "jagmodellers": "jagmodell",
    "jagmodells": "jagmodell",
    "jags": "jag",
    "jagsvagheten": "jagsvaghet",
    "jagsvaghetens": "jagsvaghet",
    "jagsvagheter": "jagsvaghet",
    "jagsvagheterna": "jagsvaghet",
    "jagsvagheternas": "jagsvaghet",
    "jagsvagheters": "jagsvaghet",
    "jagsvaghets": "jagsvaghet",
    "jaguaren": "jaguar",
    "jaguarens": "jaguar",
    "jaguarer": "jaguar",
    "jaguarerna": "jaguar",
    "jaguarernas": "jaguar",
    "jaguarers": "jaguar",
    "jaguars": "jaguar",
    "jagupplevelsen": "jagupplevelse",
    "jagupplevelsens": "jagupplevelse",
    "jagupplevelser": "jagupplevelse",
    "jagupplevelserna": "jagupplevelse",
    "jagupplevelsernas": "jagupplevelse",
    "jagupplevelsers": "jagupplevelse",
    "jagupplevelses": "jagupplevelse",
    "jaha-upplevelsen": "jaha-upplevelse",
    "jaha-upplevelsens": "jaha-upplevelse",
    "jaha-upplevelser": "jaha-upplevelse",
    "jaha-upplevelserna": "jaha-upplevelse",
    "jaha-upplevelsernas": "jaha-upplevelse",
    "jaha-upplevelsers": "jaha-upplevelse",
    "jaha-upplevelses": "jaha-upplevelse",
    "jahaupplevelsen": "jahaupplevelse",
    "jahaupplevelsens": "jahaupplevelse",
    "jahaupplevelser": "jahaupplevelse",
    "jahaupplevelserna": "jahaupplevelse",
    "jahaupplevelsernas": "jahaupplevelse",
    "jahaupplevelsers": "jahaupplevelse",
    "jahaupplevelses": "jahaupplevelse",
    "jainismen": "jainism",
    "jainismens": "jainism",
    "jainismer": "jainism",
    "jainismerna": "jainism",
    "jainismernas": "jainism",
    "jainismers": "jainism",
    "jainisms": "jainism",
    "jainistiska": "jainistisk",
    "jainistiskas": "jainistisk",
    "jainistiske": "jainistisk",
    "jainistiskes": "jainistisk",
    "jainistisks": "jainistisk",
    "jainistiskt": "jainistisk",
    "jainistiskts": "jainistisk",
    "jak": "jaka",
    "jakad": "jaka",
    "jakade": "jaka",
    "jakades": "jaka",
    "jakads": "jaka",
    "jakande": "jaka",
    "jakanden": "jakande",
    "jakandena": "jakande",
    "jakandenas": "jakande",
    "jakandens": "jakande",
    "jakandes": "jakande",
    "jakandet": "jakande",
    "jakandets": "jakande",
    "jakar": "jaka",
    "jakarandan": "jakaranda",
    "jakarandans": "jakaranda",
    "jakarandas": "jakaranda",
    "jakarna": "jak",
    "jakarnas": "jak",
    "jakars": "jak",
    "jakas": "jaka",
    "jakat": "jaka",
    "jakats": "jaka",
    "jaken": "jak",
    "jakens": "jak",
    "jakobinen": "jakobin",
    "jakobinens": "jakobin",
    "jakobiner": "jakobin",
    "jakobinerna": "jakobin",
    "jakobinernas": "jakobin",
    "jakobiners": "jakobin",
    "jakobinmöss": "jakobinmössa",
    "jakobinmössan": "jakobinmössa",
    "jakobinmössans": "jakobinmössa",
    "jakobinmössas": "jakobinmössa",
    "jakobinmösse": "jakobinmössa",
    "jakobinmössor": "jakobinmössa",
    "jakobinmössorna": "jakobinmössa",
    "jakobinmössornas": "jakobinmössa",
    "jakobinmössors": "jakobinmössa",
    "jakobins": "jakobin",
    "jakobskampen": "jakobskamp",
    "jakobskampens": "jakobskamp",
    "jakobskamper": "jakobskamp",
    "jakobskamperna": "jakobskamp",
    "jakobskampernas": "jakobskamp",
    "jakobskampers": "jakobskamp",
    "jakobskamps": "jakobskamp",
    "jakobssteg": "jakobsstege",
    "jakobsstegar": "jakobsstege",
    "jakobsstegarna": "jakobsstege",
    "jakobsstegarnas": "jakobsstege",
    "jakobsstegars": "jakobsstege",
    "jakobsstegen": "jakobsstege",
    "jakobsstegens": "jakobsstege",
    "jakobssteges": "jakobsstege",
    "jakobsstegs": "jakobsstege",
    "jaks": "jak",
    "jaktavgiften": "jaktavgift",
    "jaktavgiftens": "jaktavgift",
    "jaktavgifter": "jaktavgift",
    "jaktavgifterna": "jaktavgift",
    "jaktavgifternas": "jaktavgift",
    "jaktavgifters": "jaktavgift",
    "jaktavgifts": "jaktavgift",
    "jaktbara": "jaktbar",
    "jaktbarare": "jaktbar",
    "jaktbarares": "jaktbar",
    "jaktbaras": "jaktbar",
    "jaktbarast": "jaktbar",
    "jaktbaraste": "jaktbar",
    "jaktbarastes": "jaktbar",
    "jaktbarasts": "jaktbar",
    "jaktbare": "jaktbar",
    "jaktbares": "jaktbar",
    "jaktbarheten": "jaktbarhet",
    "jaktbarhetens": "jaktbarhet",
    "jaktbarhets": "jaktbarhet",
    "jaktbars": "jaktbar",
    "jaktbart": "jaktbar",
    "jaktbarts": "jaktbar",
    "jaktbrotten": "jaktbrott",
    "jaktbrottens": "jaktbrott",
    "jaktbrottet": "jaktbrott",
    "jaktbrottets": "jaktbrott",
    "jaktbrotts": "jaktbrott",
    "jaktbyten": "jaktbyte",
    "jaktbytena": "jaktbyte",
    "jaktbytenas": "jaktbyte",
    "jaktbytens": "jaktbyte",
    "jaktbytes": "jaktbyte",
    "jaktbytet": "jaktbyte",
    "jaktbytets": "jaktbyte",
    "jakten": "jakt",
    "jaktens": "jakt",
    "jakter": "jakt",
    "jakterna": "jakt",
    "jakternas": "jakt",
    "jakters": "jakt",
    "jaktexpeditionen": "jaktexpedition",
    "jaktexpeditionens": "jaktexpedition",
    "jaktexpeditioner": "jaktexpedition",
    "jaktexpeditionerna": "jaktexpedition",
    "jaktexpeditionernas": "jaktexpedition",
    "jaktexpeditioners": "jaktexpedition",
    "jaktexpeditions": "jaktexpedition",
    "jaktfalkar": "jaktfalk",
    "jaktfalkarna": "jaktfalk",
    "jaktfalkarnas": "jaktfalk",
    "jaktfalkars": "jaktfalk",
    "jaktfalken": "jaktfalk",
    "jaktfalkens": "jaktfalk",
    "jaktfalks": "jaktfalk",
    "jaktflyget": "jaktflyg",
    "jaktflygets": "jaktflyg",
    "jaktflygs": "jaktflyg",
    "jaktförordningar": "jaktförordning",
    "jaktförordningarna": "jaktförordning",
    "jaktförordningarnas": "jaktförordning",
    "jaktförordningars": "jaktförordning",
    "jaktförordningen": "jaktförordning",
    "jaktförordningens": "jaktförordning",
    "jaktförordnings": "jaktförordning",
    "jaktgevären": "jaktgevär",
    "jaktgevärens": "jaktgevär",
    "jaktgeväret": "jaktgevär",
    "jaktgevärets": "jaktgevär",
    "jaktgevärs": "jaktgevär",
    "jakthistorian": "jakthistoria",
    "jakthistorians": "jakthistoria",
    "jakthistorias": "jakthistoria",
    "jakthistorien": "jakthistoria",
    "jakthistoriens": "jakthistoria",
    "jakthistorier": "jakthistoria",
    "jakthistorierna": "jakthistoria",
    "jakthistoriernas": "jakthistoria",
    "jakthistoriers": "jakthistoria",
    "jakthornen": "jakthorn",
    "jakthornens": "jakthorn",
    "jakthornet": "jakthorn",
    "jakthornets": "jakthorn",
    "jakthorns": "jakthorn",
    "jakthundar": "jakthund",
    "jakthundarna": "jakthund",
    "jakthundarnas": "jakthund",
    "jakthundars": "jakthund",
    "jakthunden": "jakthund",
    "jakthundens": "jakthund",
    "jakthunds": "jakthund",
    "jaktkorten": "jaktkort",
    "jaktkortens": "jaktkort",
    "jaktkortet": "jaktkort",
    "jaktkortets": "jaktkort",
    "jaktkorts": "jaktkort",
    "jaktlagen": "jaktlag",
    "jaktlagens": "jaktlag",
    "jaktlaget": "jaktlag",
    "jaktlagets": "jaktlag",
    "jaktlags": "jaktlag",
    "jaktleoparden": "jaktleopard",
    "jaktleopardens": "jaktleopard",
    "jaktleoparder": "jaktleopard",
    "jaktleoparderna": "jaktleopard",
    "jaktleopardernas": "jaktleopard",
    "jaktleoparders": "jaktleopard",
    "jaktleopards": "jaktleopard",
    "jaktliga": "jaktlig",
    "jaktligare": "jaktlig",
    "jaktligares": "jaktlig",
    "jaktligas": "jaktlig",
    "jaktligast": "jaktlig",
    "jaktligaste": "jaktlig",
    "jaktligastes": "jaktlig",
    "jaktligasts": "jaktlig",
    "jaktlige": "jaktlig",
    "jaktliges": "jaktlig",
    "jaktligs": "jaktlig",
    "jaktligt": "jaktlig",
    "jaktligts": "jaktlig",
    "jaktloppen": "jaktlopp",
    "jaktloppens": "jaktlopp",
    "jaktloppet": "jaktlopp",
    "jaktloppets": "jaktlopp",
    "jaktlopps": "jaktlopp",
    "jaktlyckan": "jaktlycka",
    "jaktlyckans": "jaktlycka",
    "jaktlyckas": "jaktlycka",
    "jaktmarken": "jaktmark",
    "jaktmarkens": "jaktmark",
    "jaktmarker": "jaktmark",
    "jaktmarkerna": "jaktmark",
    "jaktmarkernas": "jaktmark",
    "jaktmarkers": "jaktmark",
    "jaktmarks": "jaktmark",
    "jaktplanen": "jaktplan",
    "jaktplanens": "jaktplan",
    "jaktplanet": "jaktplan",
    "jaktplanets": "jaktplan",
    "jaktplans": "jaktplan",
    "jaktproven": "jaktprov",
    "jaktprovens": "jaktprov",
    "jaktprovet": "jaktprov",
    "jaktprovets": "jaktprov",
    "jaktprovs": "jaktprov",
    "jaktresan": "jaktresa",
    "jaktresans": "jaktresa",
    "jaktresas": "jaktresa",
    "jaktrese": "jaktresa",
    "jaktresor": "jaktresa",
    "jaktresorna": "jaktresa",
    "jaktresornas": "jaktresa",
    "jaktresors": "jaktresa",
    "jaktridningar": "jaktridning",
    "jaktridningarna": "jaktridning",
    "jaktridningarnas": "jaktridning",
    "jaktridningars": "jaktridning",
    "jaktridningen": "jaktridning",
    "jaktridningens": "jaktridning",
    "jaktridnings": "jaktridning",
    "jaktrobotar": "jaktrobot",
    "jaktrobotarna": "jaktrobot",
    "jaktrobotarnas": "jaktrobot",
    "jaktrobotars": "jaktrobot",
    "jaktroboten": "jaktrobot",
    "jaktrobotens": "jaktrobot",
    "jaktrobots": "jaktrobot",
    "jakträtten": "jakträtt",
    "jakträttens": "jakträtt",
    "jakträtts": "jakträtt",
    "jakträttsinnehavar": "jakträttsinnehavare",
    "jakträttsinnehavaren": "jakträttsinnehavare",
    "jakträttsinnehavarens": "jakträttsinnehavare",
    "jakträttsinnehavares": "jakträttsinnehavare",
    "jakträttsinnehavarna": "jakträttsinnehavare",
    "jakträttsinnehavarnas": "jakträttsinnehavare",
    "jakts": "jakt",
    "jaktsignalen": "jaktsignal",
    "jaktsignalens": "jaktsignal",
    "jaktsignaler": "jaktsignal",
    "jaktsignalerna": "jaktsignal",
    "jaktsignalernas": "jaktsignal",
    "jaktsignalers": "jaktsignal",
    "jaktsignals": "jaktsignal",
    "jaktskyttes": "jaktskytte",
    "jaktskyttet": "jaktskytte",
    "jaktskyttets": "jaktskytte",
    "jaktslotten": "jaktslott",
    "jaktslottens": "jaktslott",
    "jaktslottet": "jaktslott",
    "jaktslottets": "jaktslott",
    "jaktslotts": "jaktslott",
    "jaktspindeln": "jaktspindel",
    "jaktspindelns": "jaktspindel",
    "jaktspindels": "jaktspindel",
    "jaktspindlar": "jaktspindel",
    "jaktspindlarna": "jaktspindel",
    "jaktspindlarnas": "jaktspindel",
    "jaktspindlars": "jaktspindel",
    "jaktspåren": "jaktspår",
    "jaktspårens": "jaktspår",
    "jaktspåret": "jaktspår",
    "jaktspårets": "jaktspår",
    "jaktspårs": "jaktspår",
    "jakttabellen": "jakttabell",
    "jakttabellens": "jakttabell",
    "jakttabeller": "jakttabell",
    "jakttabellerna": "jakttabell",
    "jakttabellernas": "jakttabell",
    "jakttabellers": "jakttabell",
    "jakttabells": "jakttabell",
    "jakttiden": "jakttid",
    "jakttidens": "jakttid",
    "jakttider": "jakttid",
    "jakttiderna": "jakttid",
    "jakttidernas": "jakttid",
    "jakttiders": "jakttid",
    "jakttids": "jakttid",
    "jakttillfällen": "jakttillfälle",
    "jakttillfällena": "jakttillfälle",
    "jakttillfällenas": "jakttillfälle",
    "jakttillfällens": "jakttillfälle",
    "jakttillfälles": "jakttillfälle",
    "jakttillfället": "jakttillfälle",
    "jakttillfällets": "jakttillfälle",
    "jakttroféer": "jakttrofé",
    "jakttroféerna": "jakttrofé",
    "jakttroféernas": "jakttrofé",
    "jakttroféers": "jakttrofé",
    "jakttrofén": "jakttrofé",
    "jakttroféns": "jakttrofé",
    "jakttrofés": "jakttrofé",
    "jaktvapens": "jaktvapen",
    "jaktvapnen": "jaktvapen",
    "jaktvapnens": "jaktvapen",
    "jaktvapnet": "jaktvapen",
    "jaktvapnets": "jaktvapen",
    "jaktväsk": "jaktväska",
    "jaktväskan": "jaktväska",
    "jaktväskans": "jaktväska",
    "jaktväskas": "jaktväska",
    "jaktväske": "jaktväska",
    "jaktväskor": "jaktväska",
    "jaktväskorna": "jaktväska",
    "jaktväskornas": "jaktväska",
    "jaktväskors": "jaktväska",
    "jaktvården": "jaktvård",
    "jaktvårdens": "jaktvård",
    "jaktvårds": "jaktvård",
    "jalusien": "jalusi",
    "jalusiens": "jalusi",
    "jalusier": "jalusi",
    "jalusierna": "jalusi",
    "jalusiernas": "jalusi",
    "jalusiers": "jalusi",
    "jalusin": "jalusi",
    "jalusins": "jalusi",
    "jalusis": "jalusi",
    "jam": "jama",
    "jamade": "jama",
    "jamades": "jama",
    "jamaicanen": "jamaican",
    "jamaicanens": "jamaican",
    "jamaicaner": "jamaican",
    "jamaicanerna": "jamaican",
    "jamaicanernas": "jamaican",
    "jamaicaners": "jamaican",
    "jamaicans": "jamaican",
    "jamaicanska": "jamaicansk",
    "jamaicanskan": "jamaicanska",
    "jamaicanskans": "jamaicanska",
    "jamaicanskare": "jamaicansk",
    "jamaicanskares": "jamaicansk",
    "jamaicanskas": "jamaicanska",
    "jamaicanskast": "jamaicansk",
    "jamaicanskaste": "jamaicansk",
    "jamaicanskastes": "jamaicansk",
    "jamaicanskasts": "jamaicansk",
    "jamaicanske": "jamaicanska",
    "jamaicanskes": "jamaicansk",
    "jamaicanskor": "jamaicanska",
    "jamaicanskorna": "jamaicanska",
    "jamaicanskornas": "jamaicanska",
    "jamaicanskors": "jamaicanska",
    "jamaicansks": "jamaicansk",
    "jamaicanskt": "jamaicansk",
    "jamaicanskts": "jamaicansk",
    "jamaikanen": "jamaikan",
    "jamaikanens": "jamaikan",
    "jamaikaner": "jamaikan",
    "jamaikanerna": "jamaikan",
    "jamaikanernas": "jamaikan",
    "jamaikaners": "jamaikan",
    "jamaikans": "jamaikan",
    "jamaikanska": "jamaikansk",
    "jamaikanskare": "jamaikansk",
    "jamaikanskares": "jamaikansk",
    "jamaikanskas": "jamaikansk",
    "jamaikanskast": "jamaikansk",
    "jamaikanskaste": "jamaikansk",
    "jamaikanskastes": "jamaikansk",
    "jamaikanskasts": "jamaikansk",
    "jamaikanske": "jamaikansk",
    "jamaikanskes": "jamaikansk",
    "jamaikansks": "jamaikansk",
    "jamaikanskt": "jamaikansk",
    "jamaikanskts": "jamaikansk",
    "jamande": "jama",
    "jamanden": "jamande",
    "jamandena": "jamande",
    "jamandenas": "jamande",
    "jamandens": "jamande",
    "jamandes": "jamande",
    "jamandet": "jamande",
    "jamandets": "jamande",
    "jamar": "jamare",
    "jamaren": "jamare",
    "jamarens": "jamare",
    "jamares": "jamare",
    "jamarna": "jamare",
    "jamarnas": "jamare",
    "jamas": "jama",
    "jamat": "jama",
    "jamats": "jama",
    "jamben": "jamb",
    "jambens": "jamb",
    "jamber": "jamb",
    "jamberna": "jamb",
    "jambernas": "jamb",
    "jambers": "jamb",
    "jambiska": "jambisk",
    "jambiskare": "jambisk",
    "jambiskares": "jambisk",
    "jambiskas": "jambisk",
    "jambiskast": "jambisk",
    "jambiskaste": "jambisk",
    "jambiskastes": "jambisk",
    "jambiskasts": "jambisk",
    "jambiske": "jambisk",
    "jambiskes": "jambisk",
    "jambisks": "jambisk",
    "jambiskt": "jambisk",
    "jambiskts": "jambisk",
    "jamboreen": "jamboree",
    "jamboreens": "jamboree",
    "jamboreer": "jamboree",
    "jamboreerna": "jamboree",
    "jamboreernas": "jamboree",
    "jamboreers": "jamboree",
    "jamborees": "jamboree",
    "jambs": "jamb",
    "jamet": "jam",
    "jamets": "jam",
    "jammade": "jamma",
    "jammades": "jamma",
    "jammande": "jamma",
    "jammanden": "jammande",
    "jammandena": "jammande",
    "jammandenas": "jammande",
    "jammandens": "jammande",
    "jammandes": "jammande",
    "jammandet": "jammande",
    "jammandets": "jammande",
    "jammar": "jamma",
    "jammas": "jamma",
    "jammat": "jamma",
    "jammats": "jamma",
    "jammet": "jam",
    "jammets": "jam",
    "jams": "jamsa",
    "jamsade": "jamsa",
    "jamsades": "jamsa",
    "jamsande": "jamsa",
    "jamsanden": "jamsande",
    "jamsandena": "jamsande",
    "jamsandenas": "jamsande",
    "jamsandens": "jamsande",
    "jamsandes": "jamsande",
    "jamsandet": "jamsande",
    "jamsandets": "jamsande",
    "jamsar": "jamsa",
    "jamsas": "jamsa",
    "jamsat": "jamsa",
    "jamsats": "jamsa",
    "jamsen": "jams",
    "jamsens": "jams",
    "jamsroten": "jamsrot",
    "jamsrotens": "jamsrot",
    "jamsrots": "jamsrot",
    "jan": "ja",
    "jana": "ja",
    "janarna": "jan",
    "janars": "jan",
    "janas": "ja",
    "janen": "jan",
    "janens": "jan",
    "janitsjaren": "janitsjar",
    "janitsjarens": "janitsjar",
    "janitsjarer": "janitsjar",
    "janitsjarerna": "janitsjar",
    "janitsjarernas": "janitsjar",
    "janitsjarers": "janitsjar",
    "janitsjarmusiken": "janitsjarmusik",
    "janitsjarmusikens": "janitsjarmusik",
    "janitsjarmusiks": "janitsjarmusik",
    "janitsjars": "janitsjar",
    "jans": "ja",
    "jansenismen": "jansenism",
    "jansenismens": "jansenism",
    "jansenismer": "jansenism",
    "jansenismerna": "jansenism",
    "jansenismernas": "jansenism",
    "jansenismers": "jansenism",
    "jansenisms": "jansenism",
    "jansenistiska": "jansenistisk",
    "jansenistiskas": "jansenistisk",
    "jansenistiske": "jansenistisk",
    "jansenistiskes": "jansenistisk",
    "jansenistisks": "jansenistisk",
    "jansenistiskt": "jansenistisk",
    "jansenistiskts": "jansenistisk",
    "jantelagarna": "jantelag",
    "jantelagars": "jantelag",
    "jantelagens": "jantelag",
    "januarikylan": "januarikyla",
    "januarikylans": "januarikyla",
    "januarikylas": "januarikyla",
    "januarikyle": "januarikyla",
    "januaris": "januari",
    "janusanleten": "janusanlete",
    "janusanletena": "janusanlete",
    "janusanletenas": "janusanlete",
    "janusanletens": "janusanlete",
    "janusanletes": "janusanlete",
    "janusanletet": "janusanlete",
    "janusanletets": "janusanlete",
    "janusanlets": "janusanlete",
    "janusansikten": "janusansikte",
    "janusansiktena": "janusansikte",
    "janusansiktenas": "janusansikte",
    "janusansiktens": "janusansikte",
    "janusansiktes": "janusansikte",
    "janusansiktet": "janusansikte",
    "janusansiktets": "janusansikte",
    "janusansikts": "janusansikte",
    "japanen": "japan",
    "japanens": "japan",
    "japaner": "japan",
    "japanerna": "japan",
    "japanernas": "japan",
    "japaners": "japan",
    "japanesen": "japanes",
    "japanesens": "japanes",
    "japaneser": "japanes",
    "japaneserna": "japanes",
    "japanesernas": "japanes",
    "japanesers": "japanes",
    "japans": "japan",
    "japansk": "japanska",
    "japanska": "japansk",
    "japanskan": "japanska",
    "japanskans": "japanska",
    "japanskare": "japansk",
    "japanskares": "japansk",
    "japanskas": "japanska",
    "japanskast": "japansk",
    "japanskaste": "japansk",
    "japanskastes": "japansk",
    "japanskasts": "japansk",
    "japanske": "japanska",
    "japanskes": "japansk",
    "japanskor": "japanska",
    "japanskorna": "japanska",
    "japanskornas": "japanska",
    "japanskors": "japanska",
    "japansks": "japansk",
    "japanskt": "japansk",
    "japanskts": "japansk",
    "japropositionen": "japroposition",
    "japropositionens": "japroposition",
    "japropositioner": "japroposition",
    "japropositionerna": "japroposition",
    "japropositionernas": "japroposition",
    "japropositioners": "japroposition",
    "japropositions": "japroposition",
    "jardinjären": "jardinjär",
    "jardinjärens": "jardinjär",
    "jardinjärer": "jardinjär",
    "jardinjärerna": "jardinjär",
    "jardinjärernas": "jardinjär",
    "jardinjärers": "jardinjär",
    "jardinjärs": "jardinjär",
    "jargongen": "jargong",
    "jargongens": "jargong",
    "jargonger": "jargong",
    "jargongerna": "jargong",
    "jargongernas": "jargong",
    "jargongers": "jargong",
    "jargongmässiga": "jargongmässig",
    "jargongmässigare": "jargongmässig",
    "jargongmässigares": "jargongmässig",
    "jargongmässigas": "jargongmässig",
    "jargongmässigast": "jargongmässig",
    "jargongmässigaste": "jargongmässig",
    "jargongmässigastes": "jargongmässig",
    "jargongmässigasts": "jargongmässig",
    "jargongmässige": "jargongmässig",
    "jargongmässiges": "jargongmässig",
    "jargongmässigs": "jargongmässig",
    "jargongmässigt": "jargongmässig",
    "jargongmässigts": "jargongmässig",
    "jargongs": "jargong",
    "jarlar": "jarl",
    "jarlarna": "jarl",
    "jarlarnas": "jarl",
    "jarlars": "jarl",
    "jarlen": "jarl",
    "jarlens": "jarl",
    "jarls": "jarl",
    "jaropen": "jarop",
    "jaropens": "jarop",
    "jaropet": "jarop",
    "jaropets": "jarop",
    "jarops": "jarop",
    "jarösten": "jaröst",
    "jaröstens": "jaröst",
    "jaröster": "jaröst",
    "jarösterna": "jaröst",
    "jarösternas": "jaröst",
    "jarösters": "jaröst",
    "jarösts": "jaröst",
    "jas": "ja",
    "jasminen": "jasmin",
    "jasminens": "jasmin",
    "jasminer": "jasmin",
    "jasminerna": "jasmin",
    "jasminernas": "jasmin",
    "jasminers": "jasmin",
    "jasmins": "jasmin",
    "jaspisar": "jaspis",
    "jaspisarna": "jaspis",
    "jaspisarnas": "jaspis",
    "jaspisars": "jaspis",
    "jaspisen": "jaspis",
    "jaspisens": "jaspis",
    "jass": "jassa",
    "jassade": "jassa",
    "jassades": "jassa",
    "jassande": "jassa",
    "jassanden": "jassande",
    "jassandena": "jassande",
    "jassandenas": "jassande",
    "jassandens": "jassande",
    "jassandes": "jassande",
    "jassandet": "jassande",
    "jassandets": "jassande",
    "jassar": "jassa",
    "jassas": "jassa",
    "jassat": "jassa",
    "jassats": "jassa",
    "jassen": "jass",
    "jassens": "jass",
    "jasägar": "jasägare",
    "jasägaren": "jasägare",
    "jasägarens": "jasägare",
    "jasägares": "jasägare",
    "jasägarna": "jasägare",
    "jasägarnas": "jasägare",
    "jat": "ja",
    "jats": "ja",
    "javan": "java",
    "javanen": "javan",
    "javanens": "javan",
    "javaner": "javan",
    "javanerna": "javan",
    "javanernas": "javan",
    "javaners": "javan",
    "javanesen": "javanes",
    "javanesens": "javanes",
    "javaneser": "javanes",
    "javaneserna": "javanes",
    "javanesernas": "javanes",
    "javanesers": "javanes",
    "javanesiska": "javanesisk",
    "javanesiskare": "javanesisk",
    "javanesiskares": "javanesisk",
    "javanesiskas": "javanesisk",
    "javanesiskast": "javanesisk",
    "javanesiskaste": "javanesisk",
    "javanesiskastes": "javanesisk",
    "javanesiskasts": "javanesisk",
    "javanesiske": "javanesisk",
    "javanesiskes": "javanesisk",
    "javanesisks": "javanesisk",
    "javanesiskt": "javanesisk",
    "javanesiskts": "javanesisk",
    "javans": "javan",
    "javanska": "javansk",
    "javanskare": "javansk",
    "javanskares": "javansk",
    "javanskas": "javansk",
    "javanskast": "javansk",
    "javanskaste": "javansk",
    "javanskastes": "javansk",
    "javanskasts": "javansk",
    "javanske": "javansk",
    "javanskes": "javansk",
    "javansks": "javansk",
    "javanskt": "javansk",
    "javanskts": "javansk",
    "jazz": "jazza",
    "jazzade": "jazza",
    "jazzades": "jazza",
    "jazzande": "jazza",
    "jazzanden": "jazzande",
    "jazzandena": "jazzande",
    "jazzandenas": "jazzande",
    "jazzandens": "jazzande",
    "jazzandes": "jazzande",
    "jazzandet": "jazzande",
    "jazzandets": "jazzande",
    "jazzar": "jazza",
    "jazzas": "jazza",
    "jazzat": "jazza",
    "jazzats": "jazza",
    "jazzbaletten": "jazzbalett",
    "jazzbalettens": "jazzbalett",
    "jazzbaletter": "jazzbalett",
    "jazzbaletterna": "jazzbalett",
    "jazzbaletternas": "jazzbalett",
    "jazzbaletters": "jazzbalett",
    "jazzbaletts": "jazzbalett",
    "jazzen": "jazz",
    "jazzens": "jazz",
    "jazzifierad": "jazzifiera",
    "jazzifierade": "jazzifiera",
    "jazzifierades": "jazzifiera",
    "jazzifierads": "jazzifiera",
    "jazzifierande": "jazzifiera",
    "jazzifieranden": "jazzifierande",
    "jazzifierandena": "jazzifierande",
    "jazzifierandenas": "jazzifierande",
    "jazzifierandens": "jazzifierande",
    "jazzifierandes": "jazzifierande",
    "jazzifierandet": "jazzifierande",
    "jazzifierandets": "jazzifierande",
    "jazzifierar": "jazzifiera",
    "jazzifieras": "jazzifiera",
    "jazzifierat": "jazzifiera",
    "jazzifierats": "jazzifiera",
    "jazzifierbara": "jazzifierbar",
    "jazzifierbarare": "jazzifierbar",
    "jazzifierbarares": "jazzifierbar",
    "jazzifierbaras": "jazzifierbar",
    "jazzifierbarast": "jazzifierbar",
    "jazzifierbaraste": "jazzifierbar",
    "jazzifierbarastes": "jazzifierbar",
    "jazzifierbarasts": "jazzifierbar",
    "jazzifierbare": "jazzifierbar",
    "jazzifierbares": "jazzifierbar",
    "jazzifierbarheten": "jazzifierbarhet",
    "jazzifierbarhetens": "jazzifierbarhet",
    "jazzifierbarhets": "jazzifierbarhet",
    "jazzifierbars": "jazzifierbar",
    "jazzifierbart": "jazzifierbar",
    "jazzifierbarts": "jazzifierbar",
    "jazzifieringar": "jazzifiering",
    "jazzifieringarna": "jazzifiering",
    "jazzifieringarnas": "jazzifiering",
    "jazzifieringars": "jazzifiering",
    "jazzifieringen": "jazzifiering",
    "jazzifieringens": "jazzifiering",
    "jazzifierings": "jazzifiering",
    "jazziga": "jazzig",
    "jazzigare": "jazzig",
    "jazzigares": "jazzig",
    "jazzigas": "jazzig",
    "jazzigast": "jazzig",
    "jazzigaste": "jazzig",
    "jazzigastes": "jazzig",
    "jazzigasts": "jazzig",
    "jazzige": "jazzig",
    "jazziges": "jazzig",
    "jazzigheten": "jazzighet",
    "jazzighetens": "jazzighet",
    "jazzighets": "jazzighet",
    "jazzigs": "jazzig",
    "jazzigt": "jazzig",
    "jazzigts": "jazzig",
    "jazzintresserade": "jazzintresserad",
    "jazzintresserades": "jazzintresserad",
    "jazzintresserads": "jazzintresserad",
    "jazzintresserat": "jazzintresserad",
    "jazzintresserats": "jazzintresserad",
    "jazzkonserten": "jazzkonsert",
    "jazzkonsertens": "jazzkonsert",
    "jazzkonserter": "jazzkonsert",
    "jazzkonserterna": "jazzkonsert",
    "jazzkonserternas": "jazzkonsert",
    "jazzkonserters": "jazzkonsert",
    "jazzkonserts": "jazzkonsert",
    "jazzlåtar": "jazzlåt",
    "jazzlåtarna": "jazzlåt",
    "jazzlåtarnas": "jazzlåt",
    "jazzlåtars": "jazzlåt",
    "jazzlåten": "jazzlåt",
    "jazzlåtens": "jazzlåt",
    "jazzlåts": "jazzlåt",
    "jazzmusikern": "jazzmusiker",
    "jazzmusikerna": "jazzmusiker",
    "jazzmusikernas": "jazzmusiker",
    "jazzmusikerns": "jazzmusiker",
    "jazzmusikers": "jazzmusiker",
    "jazzmässiga": "jazzmässig",
    "jazzmässigare": "jazzmässig",
    "jazzmässigares": "jazzmässig",
    "jazzmässigas": "jazzmässig",
    "jazzmässigast": "jazzmässig",
    "jazzmässigaste": "jazzmässig",
    "jazzmässigastes": "jazzmässig",
    "jazzmässigasts": "jazzmässig",
    "jazzmässige": "jazzmässig",
    "jazzmässiges": "jazzmässig",
    "jazzmässigs": "jazzmässig",
    "jazzmässigt": "jazzmässig",
    "jazzmässigts": "jazzmässig",
    "jazzorkestern": "jazzorkester",
    "jazzorkesterns": "jazzorkester",
    "jazzorkesters": "jazzorkester",
    "jazzorkestrar": "jazzorkester",
    "jazzorkestrarna": "jazzorkester",
    "jazzorkestrarnas": "jazzorkester",
    "jazzorkestrars": "jazzorkester",
    "jeansen": "jeans",
    "jeansens": "jeans",
    "jeansfick": "jeansficka",
    "jeansfickan": "jeansficka",
    "jeansfickans": "jeansficka",
    "jeansfickas": "jeansficka",
    "jeansficke": "jeansficka",
    "jeansfickor": "jeansficka",
    "jeansfickorna": "jeansficka",
    "jeansfickornas": "jeansficka",
    "jeansfickors": "jeansficka",
    "jeansficks": "jeansficka",
    "jeepar": "jeep",
    "jeeparna": "jeep",
    "jeeparnas": "jeep",
    "jeepars": "jeep",
    "jeepen": "jeep",
    "jeepens": "jeep",
    "jeeps": "jeep",
    "jemeniten": "jemenit",
    "jemenitens": "jemenit",
    "jemeniter": "jemenit",
    "jemeniterna": "jemenit",
    "jemeniternas": "jemenit",
    "jemeniters": "jemenit",
    "jemenitiska": "jemenitisk",
    "jemenitiskan": "jemenitiska",
    "jemenitiskans": "jemenitiska",
    "jemenitiskare": "jemenitisk",
    "jemenitiskares": "jemenitisk",
    "jemenitiskas": "jemenitiska",
    "jemenitiskast": "jemenitisk",
    "jemenitiskaste": "jemenitisk",
    "jemenitiskastes": "jemenitisk",
    "jemenitiskasts": "jemenitisk",
    "jemenitiske": "jemenitiska",
    "jemenitiskes": "jemenitisk",
    "jemenitiskor": "jemenitiska",
    "jemenitiskorna": "jemenitiska",
    "jemenitiskornas": "jemenitiska",
    "jemenitiskors": "jemenitiska",
    "jemenitisks": "jemenitisk",
    "jemenitiskt": "jemenitisk",
    "jemenitiskts": "jemenitisk",
    "jemenits": "jemenit",
    "jenk": "jenka",
    "jenkan": "jenka",
    "jenkans": "jenka",
    "jenkas": "jenka",
    "jenke": "jenka",
    "jenkor": "jenka",
    "jenkorna": "jenka",
    "jenkornas": "jenka",
    "jenkors": "jenka",
    "jenks": "jenka",
    "jepp": "jeppe",
    "jeppar": "jeppe",
    "jepparna": "jeppe",
    "jepparnas": "jeppe",
    "jeppars": "jeppe",
    "jeppen": "jeppe",
    "jeppens": "jeppe",
    "jeppes": "jeppe",
    "jepps": "jeppe",
    "jeremiaden": "jeremiad",
    "jeremiadens": "jeremiad",
    "jeremiader": "jeremiad",
    "jeremiaderna": "jeremiad",
    "jeremiadernas": "jeremiad",
    "jeremiaders": "jeremiad",
    "jeremiads": "jeremiad",
    "jerikorosen": "jerikoros",
    "jerikorosens": "jerikoros",
    "jerseykon": "jerseyko",
    "jerseykons": "jerseyko",
    "jerseykor": "jerseyko",
    "jerseykorna": "jerseyko",
    "jerseykornas": "jerseyko",
    "jerseykors": "jerseyko",
    "jerseykos": "jerseyko",
    "jerseyn": "jersey",
    "jerseyns": "jersey",
    "jerseys": "jersey",
    "jesuiten": "jesuit",
    "jesuitens": "jesuit",
    "jesuiter": "jesuit",
    "jesuiterna": "jesuit",
    "jesuiternas": "jesuit",
    "jesuiters": "jesuit",
    "jesuitgeneralen": "jesuitgeneral",
    "jesuitgeneralens": "jesuitgeneral",
    "jesuitgeneraler": "jesuitgeneral",
    "jesuitgeneralerna": "jesuitgeneral",
    "jesuitgeneralernas": "jesuitgeneral",
    "jesuitgeneralers": "jesuitgeneral",
    "jesuitgenerals": "jesuitgeneral",
    "jesuitiska": "jesuitisk",
    "jesuitiskare": "jesuitisk",
    "jesuitiskares": "jesuitisk",
    "jesuitiskas": "jesuitisk",
    "jesuitiskast": "jesuitisk",
    "jesuitiskaste": "jesuitisk",
    "jesuitiskastes": "jesuitisk",
    "jesuitiskasts": "jesuitisk",
    "jesuitiske": "jesuitisk",
    "jesuitiskes": "jesuitisk",
    "jesuitisks": "jesuitisk",
    "jesuitiskt": "jesuitisk",
    "jesuitiskts": "jesuitisk",
    "jesuitordens": "jesuitorden",
    "jesuitordnar": "jesuitorden",
    "jesuitordnarna": "jesuitorden",
    "jesuitordnarnas": "jesuitorden",
    "jesuitordnars": "jesuitorden",
    "jesuitordnen": "jesuitorden",
    "jesuitordnens": "jesuitorden",
    "jesuits": "jesuit",
    "jesusbarnen": "jesusbarn",
    "jesusbarnens": "jesusbarn",
    "jesusbarnet": "jesusbarn",
    "jesusbarnets": "jesusbarn",
    "jesusbarns": "jesusbarn",
    "jet-lagen": "jet-lag",
    "jet-lagens": "jet-lag",
    "jet-laget": "jet-lag",
    "jet-lagets": "jet-lag",
    "jet-laggen": "jet-lagg",
    "jet-laggens": "jet-lagg",
    "jet-lagget": "jet-lagg",
    "jet-laggets": "jet-lagg",
    "jet-laggs": "jet-lagg",
    "jet-lags": "jet-lag",
    "jetdriften": "jetdrift",
    "jetdriftens": "jetdrift",
    "jetdrifts": "jetdrift",
    "jeten": "jet",
    "jetens": "jet",
    "jetflygplanen": "jetflygplan",
    "jetflygplanens": "jetflygplan",
    "jetflygplanet": "jetflygplan",
    "jetflygplanets": "jetflygplan",
    "jetflygplans": "jetflygplan",
    "jethjälmar": "jethjälm",
    "jethjälmarna": "jethjälm",
    "jethjälmarnas": "jethjälm",
    "jethjälmars": "jethjälm",
    "jethjälmen": "jethjälm",
    "jethjälmens": "jethjälm",
    "jethjälms": "jethjälm",
    "jetlagen": "jetlag",
    "jetlagens": "jetlag",
    "jetlaget": "jetlag",
    "jetlagets": "jetlag",
    "jetlaggade": "jetlaggad",
    "jetlaggades": "jetlaggad",
    "jetlaggads": "jetlaggad",
    "jetlaggat": "jetlaggad",
    "jetlaggats": "jetlaggad",
    "jetlaggen": "jetlagg",
    "jetlaggens": "jetlagg",
    "jetlagget": "jetlagg",
    "jetlaggets": "jetlagg",
    "jetlaggs": "jetlagg",
    "jetlags": "jetlag",
    "jetmotorer": "jetmotor",
    "jetmotorerna": "jetmotor",
    "jetmotorernas": "jetmotor",
    "jetmotorers": "jetmotor",
    "jetmotorn": "jetmotor",
    "jetmotorns": "jetmotor",
    "jetmotors": "jetmotor",
    "jetongen": "jetong",
    "jetongens": "jetong",
    "jetonger": "jetong",
    "jetongerna": "jetong",
    "jetongernas": "jetong",
    "jetongers": "jetong",
    "jetongs": "jetong",
    "jetplanen": "jetplan",
    "jetplanens": "jetplan",
    "jetplanet": "jetplan",
    "jetplanets": "jetplan",
    "jetplans": "jetplan",
    "jets": "jet",
    "jetseten": "jetset",
    "jetsetens": "jetset",
    "jetsetet": "jetset",
    "jetsetets": "jetset",
    "jetsets": "jetset",
    "jetsettar": "jetsettare",
    "jetsettaren": "jetsettare",
    "jetsettarens": "jetsettare",
    "jetsettares": "jetsettare",
    "jetsettarna": "jetsettare",
    "jetsettarnas": "jetsettare",
    "jetströmmar": "jetström",
    "jetströmmarna": "jetström",
    "jetströmmarnas": "jetström",
    "jetströmmars": "jetström",
    "jetströmmen": "jetström",
    "jetströmmens": "jetström",
    "jetströms": "jetström",
    "jetåldern": "jetålder",
    "jetålderns": "jetålder",
    "jetålders": "jetålder",
    "jidders": "jidder",
    "jiddischen": "jiddisch",
    "jiddischens": "jiddisch",
    "jiddischs": "jiddisch",
    "jiddrade": "jiddra",
    "jiddrades": "jiddra",
    "jiddrande": "jiddra",
    "jiddrandes": "jiddra",
    "jiddrar": "jiddra",
    "jiddras": "jiddra",
    "jiddrat": "jiddra",
    "jiddrats": "jiddra",
    "jiddret": "jidder",
    "jiddrets": "jidder",
    "jigar": "jig",
    "jigarna": "jig",
    "jigarnas": "jig",
    "jigars": "jig",
    "jigen": "jig",
    "jigens": "jig",
    "jiggar": "jigg",
    "jiggarna": "jigg",
    "jiggarnas": "jigg",
    "jiggars": "jigg",
    "jiggen": "jigg",
    "jiggens": "jigg",
    "jiggs": "jigg",
    "jigs": "jig",
    "jingoismen": "jingoism",
    "jingoismens": "jingoism",
    "jingoismer": "jingoism",
    "jingoismerna": "jingoism",
    "jingoismernas": "jingoism",
    "jingoismers": "jingoism",
    "jingoisms": "jingoism",
    "jippon": "jippo",
    "jippona": "jippo",
    "jipponas": "jippo",
    "jippons": "jippo",
    "jippos": "jippo",
    "jippot": "jippo",
    "jippots": "jippo",
    "jitterbuggen": "jitterbug",
    "jitterbuggens": "jitterbug",
    "jitterbugs": "jitterbug",
    "jiujitsun": "jiujitsu",
    "jiujitsuns": "jiujitsu",
    "jiujitsus": "jiujitsu",
    "jobbade": "jobba",
    "jobbades": "jobba",
    "jobbande": "jobba",
    "jobbanden": "jobbande",
    "jobbandena": "jobbande",
    "jobbandenas": "jobbande",
    "jobbandens": "jobbande",
    "jobbandes": "jobbande",
    "jobbandet": "jobbande",
    "jobbandets": "jobbande",
    "jobbar": "jobbare",
    "jobbaren": "jobbare",
    "jobbarens": "jobbare",
    "jobbares": "jobbare",
    "jobbarkompisar": "jobbarkompis",
    "jobbarkompisarna": "jobbarkompis",
    "jobbarkompisarnas": "jobbarkompis",
    "jobbarkompisars": "jobbarkompis",
    "jobbarkompisen": "jobbarkompis",
    "jobbarkompisens": "jobbarkompis",
    "jobbarna": "jobbare",
    "jobbarnas": "jobbare",
    "jobbas": "jobba",
    "jobbat": "jobba",
    "jobbats": "jobba",
    "jobbcoachar": "jobbcoach",
    "jobbcoacharna": "jobbcoach",
    "jobbcoacharnas": "jobbcoach",
    "jobbcoachars": "jobbcoach",
    "jobbcoachen": "jobbcoach",
    "jobbcoachens": "jobbcoach",
    "jobbcoacher": "jobbcoach",
    "jobbcoacherna": "jobbcoach",
    "jobbcoachernas": "jobbcoach",
    "jobbcoachers": "jobbcoach",
    "jobbcoachningen": "jobbcoachning",
    "jobbcoachningens": "jobbcoachning",
    "jobbcoachnings": "jobbcoachning",
    "jobbcoachningsföretagen": "jobbcoachningsföretag",
    "jobbcoachningsföretagens": "jobbcoachningsföretag",
    "jobbcoachningsföretaget": "jobbcoachningsföretag",
    "jobbcoachningsföretagets": "jobbcoachningsföretag",
    "jobbcoachningsföretags": "jobbcoachningsföretag",
    "jobbcoachs": "jobbcoach",
    "jobben": "jobb",
    "jobbens": "jobb",
    "jobberier": "jobberi",
    "jobberierna": "jobberi",
    "jobberiernas": "jobberi",
    "jobberiers": "jobberi",
    "jobberiet": "jobberi",
    "jobberiets": "jobberi",
    "jobberis": "jobberi",
    "jobberit": "jobberi",
    "jobberits": "jobberi",
    "jobbet": "jobb",
    "jobbets": "jobb",
    "jobbiga": "jobbig",
    "jobbigare": "jobbig",
    "jobbigares": "jobbig",
    "jobbigas": "jobbig",
    "jobbigast": "jobbig",
    "jobbigaste": "jobbig",
    "jobbigastes": "jobbig",
    "jobbigasts": "jobbig",
    "jobbige": "jobbig",
    "jobbiges": "jobbig",
    "jobbigheten": "jobbighet",
    "jobbighetens": "jobbighet",
    "jobbigheter": "jobbighet",
    "jobbigheterna": "jobbighet",
    "jobbigheternas": "jobbighet",
    "jobbigheters": "jobbighet",
    "jobbighets": "jobbighet",
    "jobbigs": "jobbig",
    "jobbigt": "jobbig",
    "jobbigts": "jobbig",
    "jobbintervjuer": "jobbintervju",
    "jobbintervjuerna": "jobbintervju",
    "jobbintervjuernas": "jobbintervju",
    "jobbintervjuers": "jobbintervju",
    "jobbintervjun": "jobbintervju",
    "jobbintervjuns": "jobbintervju",
    "jobbintervjus": "jobbintervju",
    "jobbköken": "jobbkök",
    "jobbkökens": "jobbkök",
    "jobbköket": "jobbkök",
    "jobbkökets": "jobbkök",
    "jobbköks": "jobbkök",
    "jobbrasen": "jobbras",
    "jobbrasens": "jobbras",
    "jobbraser": "jobbras",
    "jobbraserna": "jobbras",
    "jobbrasernas": "jobbras",
    "jobbrasers": "jobbras",
    "jobbrelaterade": "jobbrelaterad",
    "jobbrelaterades": "jobbrelaterad",
    "jobbrelaterads": "jobbrelaterad",
    "jobbrelaterat": "jobbrelaterad",
    "jobbrelaterats": "jobbrelaterad",
    "jobbs": "jobb",
    "jobbskatteavdragen": "jobbskatteavdrag",
    "jobbskatteavdragens": "jobbskatteavdrag",
    "jobbskatteavdraget": "jobbskatteavdrag",
    "jobbskatteavdragets": "jobbskatteavdrag",
    "jobbskatteavdrags": "jobbskatteavdrag",
    "jobbskattesänkningar": "jobbskattesänkning",
    "jobbskattesänkningarna": "jobbskattesänkning",
    "jobbskattesänkningarnas": "jobbskattesänkning",
    "jobbskattesänkningars": "jobbskattesänkning",
    "jobbskattesänkningen": "jobbskattesänkning",
    "jobbskattesänkningens": "jobbskattesänkning",
    "jobbskattesänknings": "jobbskattesänkning",
    "jobbsökanden": "jobbsökande",
    "jobbsökandena": "jobbsökande",
    "jobbsökandenas": "jobbsökande",
    "jobbsökandens": "jobbsökande",
    "jobbsökandes": "jobbsökande",
    "jobbsökar": "jobbsökare",
    "jobbsökaraktiviteten": "jobbsökaraktivitet",
    "jobbsökaraktivitetens": "jobbsökaraktivitet",
    "jobbsökaraktiviteter": "jobbsökaraktivitet",
    "jobbsökaraktiviteterna": "jobbsökaraktivitet",
    "jobbsökaraktiviteternas": "jobbsökaraktivitet",
    "jobbsökaraktiviteters": "jobbsökaraktivitet",
    "jobbsökaraktivitets": "jobbsökaraktivitet",
    "jobbsökaren": "jobbsökare",
    "jobbsökarens": "jobbsökare",
    "jobbsökares": "jobbsökare",
    "jobbsökarna": "jobbsökare",
    "jobbsökarnas": "jobbsökare",
    "jobsposten": "jobspost",
    "jobspostens": "jobspost",
    "jobsposter": "jobspost",
    "jobsposterna": "jobspost",
    "jobsposternas": "jobspost",
    "jobsposters": "jobspost",
    "jobsposts": "jobspost",
    "jockejen": "jockej",
    "jockejens": "jockej",
    "jockejer": "jockej",
    "jockejerna": "jockej",
    "jockejernas": "jockej",
    "jockejers": "jockej",
    "jockejs": "jockej",
    "jockeyar": "jockey",
    "jockeyarna": "jockey",
    "jockeyarnas": "jockey",
    "jockeyars": "jockey",
    "jockeyen": "jockey",
    "jockeyens": "jockey",
    "jockeyer": "jockey",
    "jockeyerna": "jockey",
    "jockeyernas": "jockey",
    "jockeyers": "jockey",
    "jockeymöss": "jockeymössa",
    "jockeymössan": "jockeymössa",
    "jockeymössans": "jockeymössa",
    "jockeymössas": "jockeymössa",
    "jockeymösse": "jockeymössa",
    "jockeymössor": "jockeymössa",
    "jockeymössorna": "jockeymössa",
    "jockeymössornas": "jockeymössa",
    "jockeymössors": "jockeymössa",
    "jockeyn": "jockey",
    "jockeyns": "jockey",
    "jockeys": "jockey",
    "jockeysar": "jockey",
    "jockeysarna": "jockey",
    "jockeysarnas": "jockey",
    "jockeysars": "jockey",
    "jod-131-s": "jod-131",
    "jod-131:s": "jod-131",
    "joddel": "joddla",
    "joddels": "joddel",
    "joddlad": "joddla",
    "joddlade": "joddla",
    "joddlades": "joddla",
    "joddlads": "joddla",
    "joddlande": "joddla",
    "joddlanden": "joddlande",
    "joddlandena": "joddlande",
    "joddlandenas": "joddlande",
    "joddlandens": "joddlande",
    "joddlandes": "joddlande",
    "joddlandet": "joddlande",
    "joddlandets": "joddlande",
    "joddlar": "joddla",
    "joddlas": "joddla",
    "joddlat": "joddla",
    "joddlats": "joddla",
    "joddlet": "joddel",
    "joddlets": "joddel",
    "joden": "jod",
    "jodens": "jod",
    "joderad": "jodera",
    "joderade": "jodera",
    "joderades": "jodera",
    "joderads": "jodera",
    "joderande": "jodera",
    "joderanden": "joderande",
    "joderandena": "joderande",
    "joderandenas": "joderande",
    "joderandens": "joderande",
    "joderandes": "joderande",
    "joderandet": "joderande",
    "joderandets": "joderande",
    "joderar": "jodera",
    "joderas": "jodera",
    "joderat": "jodera",
    "joderats": "jodera",
    "joderbara": "joderbar",
    "joderbarare": "joderbar",
    "joderbarares": "joderbar",
    "joderbaras": "joderbar",
    "joderbarast": "joderbar",
    "joderbaraste": "joderbar",
    "joderbarastes": "joderbar",
    "joderbarasts": "joderbar",
    "joderbare": "joderbar",
    "joderbares": "joderbar",
    "joderbarheten": "joderbarhet",
    "joderbarhetens": "joderbarhet",
    "joderbarhets": "joderbarhet",
    "joderbars": "joderbar",
    "joderbart": "joderbar",
    "joderbarts": "joderbar",
    "joderingar": "jodering",
    "joderingarna": "jodering",
    "joderingarnas": "jodering",
    "joderingars": "jodering",
    "joderingen": "jodering",
    "joderingens": "jodering",
    "joderings": "jodering",
    "jodhpursen": "jodhpurs",
    "jodhpursens": "jodhpurs",
    "jodoformen": "jodoform",
    "jodoformens": "jodoform",
    "jodoforms": "jodoform",
    "jods": "jod",
    "jodspriten": "jodsprit",
    "jodspritens": "jodsprit",
    "jodsprits": "jodsprit",
    "jodtabletten": "jodtablett",
    "jodtablettens": "jodtablett",
    "jodtabletter": "jodtablett",
    "jodtabletterna": "jodtablett",
    "jodtabletternas": "jodtablett",
    "jodtabletters": "jodtablett",
    "jodtabletts": "jodtablett",
    "jogg": "jogga",
    "joggad": "jogga",
    "joggade": "jogga",
    "joggades": "jogga",
    "joggads": "jogga",
    "joggande": "jogga",
    "jogganden": "joggande",
    "joggandena": "joggande",
    "joggandenas": "joggande",
    "joggandens": "joggande",
    "joggandes": "joggande",
    "joggandet": "joggande",
    "joggandets": "joggande",
    "joggar": "jogga",
    "joggas": "jogga",
    "joggat": "jogga",
    "joggats": "jogga",
    "joggingskon": "joggingsko",
    "joggingskons": "joggingsko",
    "joggingskor": "joggingsko",
    "joggingskorna": "joggingsko",
    "joggingskornas": "joggingsko",
    "joggingskors": "joggingsko",
    "joggingskos": "joggingsko",
    "joggingturen": "joggingtur",
    "joggingturens": "joggingtur",
    "joggingturer": "joggingtur",
    "joggingturerna": "joggingtur",
    "joggingturernas": "joggingtur",
    "joggingturers": "joggingtur",
    "joggingturs": "joggingtur",
    "jogglingar": "joggling",
    "jogglingarna": "joggling",
    "jogglingarnas": "joggling",
    "jogglingars": "joggling",
    "jogglingen": "joggling",
    "jogglingens": "joggling",
    "jogglings": "joggling",
    "johannesbrödet": "johannesbröd",
    "johannesbrödets": "johannesbröd",
    "johannesbröds": "johannesbröd",
    "johannesnyckel": "johannesnycklar",
    "johannesnyckels": "johannesnycklar",
    "johannesnycklarna": "johannesnycklar",
    "johannesnycklarnas": "johannesnycklar",
    "johannesnycklars": "johannesnycklar",
    "johannesörten": "johannesört",
    "johannesörtens": "johannesört",
    "johannesörter": "johannesört",
    "johannesörterna": "johannesört",
    "johannesörternas": "johannesört",
    "johannesörters": "johannesört",
    "johannesörts": "johannesört",
    "johanniten": "johannit",
    "johannitens": "johannit",
    "johanniter": "johannit",
    "johanniterkorsen": "johanniterkors",
    "johanniterkorsens": "johanniterkors",
    "johanniterkorset": "johanniterkors",
    "johanniterkorsets": "johanniterkors",
    "johanniterna": "johannit",
    "johanniternas": "johannit",
    "johanniterordens": "johanniterorden",
    "johanniterordnar": "johanniterorden",
    "johanniterordnarna": "johanniterorden",
    "johanniterordnarnas": "johanniterorden",
    "johanniterordnars": "johanniterorden",
    "johanniterordnen": "johanniterorden",
    "johanniterordnens": "johanniterorden",
    "johanniters": "johannit",
    "johannitkorsen": "johannitkors",
    "johannitkorsens": "johannitkors",
    "johannitkorset": "johannitkors",
    "johannitkorsets": "johannitkors",
    "johannitordens": "johannitorden",
    "johannitordnar": "johannitorden",
    "johannitordnarna": "johannitorden",
    "johannitordnarnas": "johannitorden",
    "johannitordnars": "johannitorden",
    "johannitordnen": "johannitorden",
    "johannitordnens": "johannitorden",
    "johannits": "johannit",
    "jointen": "joint",
    "jointens": "joint",
    "jointer": "joint",
    "jointerna": "joint",
    "jointernas": "joint",
    "jointers": "joint",
    "joints": "joint",
    "jojk": "jojka",
    "jojkad": "jojka",
    "jojkade": "jojka",
    "jojkades": "jojka",
    "jojkads": "jojka",
    "jojkande": "jojka",
    "jojkanden": "jojkande",
    "jojkandena": "jojkande",
    "jojkandenas": "jojkande",
    "jojkandens": "jojkande",
    "jojkandes": "jojkande",
    "jojkandet": "jojkande",
    "jojkandets": "jojkande",
    "jojkar": "jojka",
    "jojkarna": "jojk",
    "jojkarnas": "jojk",
    "jojkars": "jojk",
    "jojkas": "jojka",
    "jojkat": "jojka",
    "jojkats": "jojka",
    "jojken": "jojk",
    "jojkens": "jojk",
    "jojks": "jojk",
    "jojoar": "jojo",
    "jojoarna": "jojo",
    "jojoarnas": "jojo",
    "jojoars": "jojo",
    "jojon": "jojo",
    "jojons": "jojo",
    "jojor": "jojo",
    "jojorna": "jojo",
    "jojornas": "jojo",
    "jojors": "jojo",
    "jojos": "jojo",
    "jojoväderna": "jojoväder",
    "jojovädernas": "jojoväder",
    "jojoväders": "jojoväder",
    "jojovädren": "jojoväder",
    "jojovädrens": "jojoväder",
    "jojovädret": "jojoväder",
    "jojovädrets": "jojoväder",
    "jokern": "joker",
    "jokerns": "joker",
    "jokers": "joker",
    "jokkar": "jokk",
    "jokkarna": "jokk",
    "jokkarnas": "jokk",
    "jokkars": "jokk",
    "jokken": "jokk",
    "jokkens": "jokk",
    "jokks": "jokk",
    "jokrar": "joker",
    "jokrarna": "joker",
    "jokrarnas": "joker",
    "jokrars": "joker",
    "joll": "jolle",
    "jollar": "jolle",
    "jollarna": "jolle",
    "jollarnas": "jolle",
    "jollars": "jolle",
    "jollen": "jolle",
    "jollens": "jolle",
    "joller": "jollra",
    "jollers": "joller",
    "jolles": "jolle",
    "jollrad": "jollra",
    "jollrade": "jollra",
    "jollrades": "jollra",
    "jollrads": "jollra",
    "jollrande": "jollra",
    "jollranden": "jollrande",
    "jollrandena": "jollrande",
    "jollrandenas": "jollrande",
    "jollrandens": "jollrande",
    "jollrandes": "jollrande",
    "jollrandet": "jollrande",
    "jollrandets": "jollrande",
    "jollrar": "jollra",
    "jollras": "jollra",
    "jollrat": "jollra",
    "jollrats": "jollra",
    "jollret": "joller",
    "jollrets": "joller",
    "jolls": "jolle",
    "jolmiga": "jolmig",
    "jolmigare": "jolmig",
    "jolmigares": "jolmig",
    "jolmigas": "jolmig",
    "jolmigast": "jolmig",
    "jolmigaste": "jolmig",
    "jolmigastes": "jolmig",
    "jolmigasts": "jolmig",
    "jolmige": "jolmig",
    "jolmiges": "jolmig",
    "jolmigheten": "jolmighet",
    "jolmighetens": "jolmighet",
    "jolmighets": "jolmighet",
    "jolmigs": "jolmig",
    "jolmigt": "jolmig",
    "jolmigts": "jolmig",
    "jolstern": "jolster",
    "jolsterns": "jolster",
    "jolsters": "jolster",
    "jolstrar": "jolster",
    "jolstrarna": "jolster",
    "jolstrarnas": "jolster",
    "jolstrars": "jolster",
    "jolt": "jolta",
    "joltade": "jolta",
    "joltades": "jolta",
    "joltande": "jolta",
    "joltanden": "joltande",
    "joltandena": "joltande",
    "joltandenas": "joltande",
    "joltandens": "joltande",
    "joltandes": "joltande",
    "joltandet": "joltande",
    "joltandets": "joltande",
    "joltar": "jolta",
    "joltas": "jolta",
    "joltat": "jolta",
    "joltats": "jolta",
    "jonbildningar": "jonbildning",
    "jonbildningarna": "jonbildning",
    "jonbildningarnas": "jonbildning",
    "jonbildningars": "jonbildning",
    "jonbildningen": "jonbildning",
    "jonbildningens": "jonbildning",
    "jonbildnings": "jonbildning",
    "jonbindningar": "jonbindning",
    "jonbindningarna": "jonbindning",
    "jonbindningarnas": "jonbindning",
    "jonbindningars": "jonbindning",
    "jonbindningen": "jonbindning",
    "jonbindningens": "jonbindning",
    "jonbindnings": "jonbindning",
    "jonbytar": "jonbytare",
    "jonbytaren": "jonbytare",
    "jonbytarens": "jonbytare",
    "jonbytares": "jonbytare",
    "jonbytarna": "jonbytare",
    "jonbytarnas": "jonbytare",
    "jonen": "jon",
    "jonens": "jon",
    "joner": "jon",
    "jonern": "joner",
    "jonerna": "joner",
    "jonernas": "joner",
    "jonerns": "joner",
    "joners": "joner",
    "jonfläckar": "jonfläck",
    "jonfläckarna": "jonfläck",
    "jonfläckarnas": "jonfläck",
    "jonfläckars": "jonfläck",
    "jonfläcken": "jonfläck",
    "jonfläckens": "jonfläck",
    "jonfläcks": "jonfläck",
    "jonfäll": "jonfälla",
    "jonfällan": "jonfälla",
    "jonfällans": "jonfälla",
    "jonfällas": "jonfälla",
    "jonfälle": "jonfälla",
    "jonfällor": "jonfälla",
    "jonfällorna": "jonfälla",
    "jonfällornas": "jonfälla",
    "jonfällors": "jonfälla",
    "jonfälls": "jonfälla",
    "jonföreningar": "jonförening",
    "jonföreningarna": "jonförening",
    "jonföreningarnas": "jonförening",
    "jonföreningars": "jonförening",
    "jonföreningen": "jonförening",
    "jonföreningens": "jonförening",
    "jonförenings": "jonförening",
    "jongitterna": "jongitter",
    "jongitternas": "jongitter",
    "jongitters": "jongitter",
    "jongittren": "jongitter",
    "jongittrens": "jongitter",
    "jongittret": "jongitter",
    "jongittrets": "jongitter",
    "jonglerad": "jonglera",
    "jonglerade": "jonglera",
    "jonglerades": "jonglera",
    "jonglerads": "jonglera",
    "jonglerande": "jonglera",
    "jongleranden": "jonglerande",
    "jonglerandena": "jonglerande",
    "jonglerandenas": "jonglerande",
    "jonglerandens": "jonglerande",
    "jonglerandes": "jonglerande",
    "jonglerandet": "jonglerande",
    "jonglerandets": "jonglerande",
    "jonglerar": "jonglera",
    "jongleras": "jonglera",
    "jonglerat": "jonglera",
    "jonglerats": "jonglera",
    "jonglerbara": "jonglerbar",
    "jonglerbarare": "jonglerbar",
    "jonglerbarares": "jonglerbar",
    "jonglerbaras": "jonglerbar",
    "jonglerbarast": "jonglerbar",
    "jonglerbaraste": "jonglerbar",
    "jonglerbarastes": "jonglerbar",
    "jonglerbarasts": "jonglerbar",
    "jonglerbare": "jonglerbar",
    "jonglerbares": "jonglerbar",
    "jonglerbarheten": "jonglerbarhet",
    "jonglerbarhetens": "jonglerbarhet",
    "jonglerbarhets": "jonglerbarhet",
    "jonglerbars": "jonglerbar",
    "jonglerbart": "jonglerbar",
    "jonglerbarts": "jonglerbar",
    "jongleringar": "jonglering",
    "jongleringarna": "jonglering",
    "jongleringarnas": "jonglering",
    "jongleringars": "jonglering",
    "jongleringen": "jonglering",
    "jongleringens": "jonglering",
    "jonglerings": "jonglering",
    "jonglören": "jonglör",
    "jonglörens": "jonglör",
    "jonglörer": "jonglör",
    "jonglörerna": "jonglör",
    "jonglörernas": "jonglör",
    "jonglörers": "jonglör",
    "jonglörs": "jonglör",
    "joniern": "jonier",
    "jonierna": "jonier",
    "joniernas": "jonier",
    "jonierns": "jonier",
    "joniers": "jonier",
    "jonisationen": "jonisation",
    "jonisationens": "jonisation",
    "jonisationer": "jonisation",
    "jonisationerna": "jonisation",
    "jonisationernas": "jonisation",
    "jonisationers": "jonisation",
    "jonisations": "jonisation",
    "joniserad": "jonisera",
    "joniserade": "jonisera",
    "joniserades": "jonisera",
    "joniserads": "jonisera",
    "joniserande": "jonisera",
    "joniseranden": "joniserande",
    "joniserandena": "joniserande",
    "joniserandenas": "joniserande",
    "joniserandens": "joniserande",
    "joniserandes": "joniserande",
    "joniserandet": "joniserande",
    "joniserandets": "joniserande",
    "joniserar": "jonisera",
    "joniseras": "jonisera",
    "joniserat": "jonisera",
    "joniserats": "jonisera",
    "joniserbara": "joniserbar",
    "joniserbarare": "joniserbar",
    "joniserbarares": "joniserbar",
    "joniserbaras": "joniserbar",
    "joniserbarast": "joniserbar",
    "joniserbaraste": "joniserbar",
    "joniserbarastes": "joniserbar",
    "joniserbarasts": "joniserbar",
    "joniserbare": "joniserbar",
    "joniserbares": "joniserbar",
    "joniserbarheten": "joniserbarhet",
    "joniserbarhetens": "joniserbarhet",
    "joniserbarhets": "joniserbarhet",
    "joniserbars": "joniserbar",
    "joniserbart": "joniserbar",
    "joniserbarts": "joniserbar",
    "joniseringar": "jonisering",
    "joniseringarna": "jonisering",
    "joniseringarnas": "jonisering",
    "joniseringars": "jonisering",
    "joniseringen": "jonisering",
    "joniseringens": "jonisering",
    "joniserings": "jonisering",
    "joniseringsenergien": "joniseringsenergi",
    "joniseringsenergiens": "joniseringsenergi",
    "joniseringsenergier": "joniseringsenergi",
    "joniseringsenergierna": "joniseringsenergi",
    "joniseringsenergiernas": "joniseringsenergi",
    "joniseringsenergiers": "joniseringsenergi",
    "joniseringsenergin": "joniseringsenergi",
    "joniseringsenergins": "joniseringsenergi",
    "joniseringsenergis": "joniseringsenergi",
    "joniseringstendensen": "joniseringstendens",
    "joniseringstendensens": "joniseringstendens",
    "joniseringstendenser": "joniseringstendens",
    "joniseringstendenserna": "joniseringstendens",
    "joniseringstendensernas": "joniseringstendens",
    "joniseringstendensers": "joniseringstendens",
    "joniska": "jonisk",
    "joniskare": "jonisk",
    "joniskares": "jonisk",
    "joniskas": "jonisk",
    "joniskast": "jonisk",
    "joniskaste": "jonisk",
    "joniskastes": "jonisk",
    "joniskasts": "jonisk",
    "joniske": "jonisk",
    "joniskes": "jonisk",
    "jonisks": "jonisk",
    "joniskt": "jonisk",
    "joniskts": "jonisk",
    "jonkillen": "jonkill",
    "jonkillens": "jonkill",
    "jonkiller": "jonkill",
    "jonkillerna": "jonkill",
    "jonkillernas": "jonkill",
    "jonkillers": "jonkill",
    "jonkills": "jonkill",
    "jonkvillen": "jonkvill",
    "jonkvillens": "jonkvill",
    "jonkviller": "jonkvill",
    "jonkvillerna": "jonkvill",
    "jonkvillernas": "jonkvill",
    "jonkvillers": "jonkvill",
    "jonkvills": "jonkvill",
    "jonkäll": "jonkälla",
    "jonkällan": "jonkälla",
    "jonkällans": "jonkälla",
    "jonkällas": "jonkälla",
    "jonkälle": "jonkälla",
    "jonkällor": "jonkälla",
    "jonkällorna": "jonkälla",
    "jonkällornas": "jonkälla",
    "jonkällors": "jonkälla",
    "jonkälls": "jonkälla",
    "jonosfären": "jonosfär",
    "jonosfärens": "jonosfär",
    "jonosfärs": "jonosfär",
    "jons": "jon",
    "jonstrål": "jonstråle",
    "jonstrålar": "jonstråle",
    "jonstrålarna": "jonstråle",
    "jonstrålarnas": "jonstråle",
    "jonstrålars": "jonstråle",
    "jonstrålen": "jonstråle",
    "jonstrålens": "jonstråle",
    "jonstråles": "jonstråle",
    "jonstråls": "jonstråle",
    "jord": "jorda",
    "jordabalkar": "jordabalk",
    "jordabalkarna": "jordabalk",
    "jordabalkarnas": "jordabalk",
    "jordabalkars": "jordabalk",
    "jordabalken": "jordabalk",
    "jordabalkens": "jordabalk",
    "jordabalks": "jordabalk",
    "jordad": "jorda",
    "jordade": "jorda",
    "jordades": "jorda",
    "jordads": "jorda",
    "jordafärden": "jordafärd",
    "jordafärdens": "jordafärd",
    "jordafärder": "jordafärd",
    "jordafärderna": "jordafärd",
    "jordafärdernas": "jordafärd",
    "jordafärders": "jordafärd",
    "jordafärds": "jordafärd",
    "jordagodsen": "jordagods",
    "jordagodsens": "jordagods",
    "jordagodset": "jordagods",
    "jordagodsets": "jordagods",
    "jordanalysen": "jordanalys",
    "jordanalysens": "jordanalys",
    "jordanalyser": "jordanalys",
    "jordanalyserna": "jordanalys",
    "jordanalysernas": "jordanalys",
    "jordanalysers": "jordanalys",
    "jordandar": "jordande",
    "jordandarna": "jordande",
    "jordandarnas": "jordande",
    "jordandars": "jordande",
    "jordande": "jorda",
    "jordanden": "jordande",
    "jordandena": "jordande",
    "jordandenas": "jordande",
    "jordandens": "jordande",
    "jordandes": "jordande",
    "jordandet": "jordande",
    "jordandets": "jordande",
    "jordaniern": "jordanier",
    "jordanierna": "jordanier",
    "jordaniernas": "jordanier",
    "jordanierns": "jordanier",
    "jordaniers": "jordanier",
    "jordanska": "jordansk",
    "jordanskan": "jordanska",
    "jordanskans": "jordanska",
    "jordanskare": "jordansk",
    "jordanskares": "jordansk",
    "jordanskas": "jordanska",
    "jordanskast": "jordansk",
    "jordanskaste": "jordansk",
    "jordanskastes": "jordansk",
    "jordanskasts": "jordansk",
    "jordanske": "jordanska",
    "jordanskes": "jordansk",
    "jordanskor": "jordanska",
    "jordanskorna": "jordanska",
    "jordanskornas": "jordanska",
    "jordanskors": "jordanska",
    "jordansks": "jordansk",
    "jordanskt": "jordansk",
    "jordanskts": "jordansk",
    "jordar": "jorda",
    "jordarna": "jord",
    "jordarnas": "jord",
    "jordars": "jord",
    "jordarten": "jordart",
    "jordartens": "jordart",
    "jordarter": "jordart",
    "jordarterna": "jordart",
    "jordarternas": "jordart",
    "jordarters": "jordart",
    "jordarts": "jordart",
    "jordartsmetallen": "jordartsmetall",
    "jordartsmetallens": "jordartsmetall",
    "jordartsmetaller": "jordartsmetall",
    "jordartsmetallerna": "jordartsmetall",
    "jordartsmetallernas": "jordartsmetall",
    "jordartsmetallers": "jordartsmetall",
    "jordartsmetalls": "jordartsmetall",
    "jordas": "jorda",
    "jordat": "jorda",
    "jordatmosfären": "jordatmosfär",
    "jordatmosfärens": "jordatmosfär",
    "jordatmosfärer": "jordatmosfär",
    "jordatmosfärerna": "jordatmosfär",
    "jordatmosfärernas": "jordatmosfär",
    "jordatmosfärers": "jordatmosfär",
    "jordatmosfärs": "jordatmosfär",
    "jordats": "jorda",
    "jordavsöndringar": "jordavsöndring",
    "jordavsöndringarna": "jordavsöndring",
    "jordavsöndringarnas": "jordavsöndring",
    "jordavsöndringars": "jordavsöndring",
    "jordavsöndringen": "jordavsöndring",
    "jordavsöndringens": "jordavsöndring",
    "jordavsöndrings": "jordavsöndring",
    "jordaxeln": "jordaxel",
    "jordaxelns": "jordaxel",
    "jordaxels": "jordaxel",
    "jordbanan": "jordbana",
    "jordbanans": "jordbana",
    "jordbanas": "jordbana",
    "jordbane": "jordbana",
    "jordbanor": "jordbana",
    "jordbanorna": "jordbana",
    "jordbanornas": "jordbana",
    "jordbanors": "jordbana",
    "jordbecket": "jordbeck",
    "jordbeckets": "jordbeck",
    "jordbecks": "jordbeck",
    "jordbegravningar": "jordbegravning",
    "jordbegravningarna": "jordbegravning",
    "jordbegravningarnas": "jordbegravning",
    "jordbegravningars": "jordbegravning",
    "jordbegravningen": "jordbegravning",
    "jordbegravningens": "jordbegravning",
    "jordbegravnings": "jordbegravning",
    "jordbien": "jordbi",
    "jordbiens": "jordbi",
    "jordbiet": "jordbi",
    "jordbiets": "jordbi",
    "jordbin": "jordbi",
    "jordbina": "jordbi",
    "jordbinas": "jordbi",
    "jordbins": "jordbi",
    "jordbis": "jordbi",
    "jordbit": "jordbi",
    "jordbits": "jordbi",
    "jordbladen": "jordblad",
    "jordbladens": "jordblad",
    "jordbladet": "jordblad",
    "jordbladets": "jordblad",
    "jordblads": "jordblad",
    "jordborrar": "jordborr",
    "jordborrarna": "jordborr",
    "jordborrarnas": "jordborr",
    "jordborrars": "jordborr",
    "jordborren": "jordborr",
    "jordborrens": "jordborr",
    "jordborrs": "jordborr",
    "jordbrukar": "jordbrukare",
    "jordbrukaren": "jordbrukare",
    "jordbrukarens": "jordbrukare",
    "jordbrukares": "jordbrukare",
    "jordbrukarna": "jordbrukare",
    "jordbrukarnas": "jordbrukare",
    "jordbruken": "jordbruk",
    "jordbrukens": "jordbruk",
    "jordbruket": "jordbruk",
    "jordbrukets": "jordbruk",
    "jordbruks": "jordbruk",
    "jordbruksbebyggelsen": "jordbruksbebyggelse",
    "jordbruksbebyggelsens": "jordbruksbebyggelse",
    "jordbruksbebyggelser": "jordbruksbebyggelse",
    "jordbruksbebyggelserna": "jordbruksbebyggelse",
    "jordbruksbebyggelsernas": "jordbruksbebyggelse",
    "jordbruksbebyggelsers": "jordbruksbebyggelse",
    "jordbruksbebyggelses": "jordbruksbebyggelse",
    "jordbruksbefolkningar": "jordbruksbefolkning",
    "jordbruksbefolkningarna": "jordbruksbefolkning",
    "jordbruksbefolkningarnas": "jordbruksbefolkning",
    "jordbruksbefolkningars": "jordbruksbefolkning",
    "jordbruksbefolkningen": "jordbruksbefolkning",
    "jordbruksbefolkningens": "jordbruksbefolkning",
    "jordbruksbefolknings": "jordbruksbefolkning",
    "jordbruksbygden": "jordbruksbygd",
    "jordbruksbygdens": "jordbruksbygd",
    "jordbruksbygder": "jordbruksbygd",
    "jordbruksbygderna": "jordbruksbygd",
    "jordbruksbygdernas": "jordbruksbygd",
    "jordbruksbygders": "jordbruksbygd",
    "jordbruksbygds": "jordbruksbygd",
    "jordbruksdepartementen": "jordbruksdepartement",
    "jordbruksdepartementens": "jordbruksdepartement",
    "jordbruksdepartementet": "jordbruksdepartement",
    "jordbruksdepartementets": "jordbruksdepartement",
    "jordbruksdepartements": "jordbruksdepartement",
    "jordbrukslandskapen": "jordbrukslandskap",
    "jordbrukslandskapens": "jordbrukslandskap",
    "jordbrukslandskapet": "jordbrukslandskap",
    "jordbrukslandskapets": "jordbrukslandskap",
    "jordbrukslandskaps": "jordbrukslandskap",
    "jordbruksmarken": "jordbruksmark",
    "jordbruksmarkens": "jordbruksmark",
    "jordbruksmarker": "jordbruksmark",
    "jordbruksmarkerna": "jordbruksmark",
    "jordbruksmarkernas": "jordbruksmark",
    "jordbruksmarkers": "jordbruksmark",
    "jordbruksmarks": "jordbruksmark",
    "jordbruksmaskinen": "jordbruksmaskin",
    "jordbruksmaskinens": "jordbruksmaskin",
    "jordbruksmaskiner": "jordbruksmaskin",
    "jordbruksmaskinerna": "jordbruksmaskin",
    "jordbruksmaskinernas": "jordbruksmaskin",
    "jordbruksmaskiners": "jordbruksmaskin",
    "jordbruksmaskins": "jordbruksmaskin",
    "jordbruksministern": "jordbruksminister",
    "jordbruksministerns": "jordbruksminister",
    "jordbruksministers": "jordbruksminister",
    "jordbruksministrar": "jordbruksminister",
    "jordbruksministrarna": "jordbruksminister",
    "jordbruksministrarnas": "jordbruksminister",
    "jordbruksministrars": "jordbruksminister",
    "jordbruksmässiga": "jordbruksmässig",
    "jordbruksmässigare": "jordbruksmässig",
    "jordbruksmässigares": "jordbruksmässig",
    "jordbruksmässigas": "jordbruksmässig",
    "jordbruksmässigast": "jordbruksmässig",
    "jordbruksmässigaste": "jordbruksmässig",
    "jordbruksmässigastes": "jordbruksmässig",
    "jordbruksmässigasts": "jordbruksmässig",
    "jordbruksmässige": "jordbruksmässig",
    "jordbruksmässiges": "jordbruksmässig",
    "jordbruksmässigs": "jordbruksmässig",
    "jordbruksmässigt": "jordbruksmässig",
    "jordbruksmässigts": "jordbruksmässig",
    "jordbrukspolitiken": "jordbrukspolitik",
    "jordbrukspolitikens": "jordbrukspolitik",
    "jordbrukspolitiks": "jordbrukspolitik",
    "jordbrukspolitiska": "jordbrukspolitisk",
    "jordbrukspolitiskas": "jordbrukspolitisk",
    "jordbrukspolitiske": "jordbrukspolitisk",
    "jordbrukspolitiskes": "jordbrukspolitisk",
    "jordbrukspolitisks": "jordbrukspolitisk",
    "jordbrukspolitiskt": "jordbrukspolitisk",
    "jordbrukspolitiskts": "jordbrukspolitisk",
    "jordbruksprodukten": "jordbruksprodukt",
    "jordbruksproduktens": "jordbruksprodukt",
    "jordbruksprodukter": "jordbruksprodukt",
    "jordbruksprodukterna": "jordbruksprodukt",
    "jordbruksprodukternas": "jordbruksprodukt",
    "jordbruksprodukters": "jordbruksprodukt",
    "jordbruksprodukts": "jordbruksprodukt",
    "jordbruksredskapen": "jordbruksredskap",
    "jordbruksredskapens": "jordbruksredskap",
    "jordbruksredskapet": "jordbruksredskap",
    "jordbruksredskapets": "jordbruksredskap",
    "jordbruksredskaps": "jordbruksredskap",
    "jordbruksreformen": "jordbruksreform",
    "jordbruksreformens": "jordbruksreform",
    "jordbruksreformer": "jordbruksreform",
    "jordbruksreformerna": "jordbruksreform",
    "jordbruksreformernas": "jordbruksreform",
    "jordbruksreformers": "jordbruksreform",
    "jordbruksreforms": "jordbruksreform",
    "jordbundenheten": "jordbundenhet",
    "jordbundenhetens": "jordbundenhet",
    "jordbundenhets": "jordbundenhet",
    "jordbundens": "jordbunden",
    "jordbundet": "jordbunden",
    "jordbundets": "jordbunden",
    "jordbundna": "jordbunden",
    "jordbundnare": "jordbunden",
    "jordbundnares": "jordbunden",
    "jordbundnas": "jordbunden",
    "jordbundnast": "jordbunden",
    "jordbundnaste": "jordbunden",
    "jordbundnastes": "jordbunden",
    "jordbundnasts": "jordbunden",
    "jordbundne": "jordbunden",
    "jordbundnes": "jordbunden",
    "jordbävningar": "jordbävning",
    "jordbävningarna": "jordbävning",
    "jordbävningarnas": "jordbävning",
    "jordbävningars": "jordbävning",
    "jordbävningen": "jordbävning",
    "jordbävningens": "jordbävning",
    "jordbävnings": "jordbävning",
    "jordbävningsdrabbade": "jordbävningsdrabbad",
    "jordbävningsdrabbades": "jordbävningsdrabbad",
    "jordbävningsdrabbads": "jordbävningsdrabbad",
    "jordbävningsdrabbat": "jordbävningsdrabbad",
    "jordbävningsdrabbats": "jordbävningsdrabbad",
    "jordbävningssäkerheten": "jordbävningssäkerhet",
    "jordbävningssäkerhetens": "jordbävningssäkerhet",
    "jordbävningssäkerhets": "jordbävningssäkerhet",
    "jordbävningssäkers": "jordbävningssäker",
    "jordbävningssäkert": "jordbävningssäker",
    "jordbävningssäkerts": "jordbävningssäker",
    "jordbävningssäkra": "jordbävningssäker",
    "jordbävningssäkrare": "jordbävningssäker",
    "jordbävningssäkrares": "jordbävningssäker",
    "jordbävningssäkras": "jordbävningssäker",
    "jordbävningssäkrast": "jordbävningssäker",
    "jordbävningssäkraste": "jordbävningssäker",
    "jordbävningssäkrastes": "jordbävningssäker",
    "jordbävningssäkrasts": "jordbävningssäker",
    "jordbävningssäkre": "jordbävningssäker",
    "jordbävningssäkres": "jordbävningssäker",
    "jorddelningar": "jorddelning",
    "jorddelningarna": "jorddelning",
    "jorddelningarnas": "jorddelning",
    "jorddelningars": "jorddelning",
    "jorddelningen": "jorddelning",
    "jorddelningens": "jorddelning",
    "jorddelnings": "jorddelning",
    "jorddrottar": "jorddrott",
    "jorddrottarna": "jorddrott",
    "jorddrottarnas": "jorddrott",
    "jorddrottars": "jorddrott",
    "jorddrotten": "jorddrott",
    "jorddrottens": "jorddrott",
    "jorddrotts": "jorddrott",
    "jordeboken": "jordebok",
    "jordebokens": "jordebok",
    "jordeboks": "jordebok",
    "jordeböcker": "jordebok",
    "jordeböckerna": "jordebok",
    "jordeböckernas": "jordebok",
    "jordeböckers": "jordebok",
    "jordegendomar": "jordegendom",
    "jordegendomarna": "jordegendom",
    "jordegendomarnas": "jordegendom",
    "jordegendomars": "jordegendom",
    "jordegendomen": "jordegendom",
    "jordegendomens": "jordegendom",
    "jordegendoms": "jordegendom",
    "jordekorr": "jordekorre",
    "jordekorrar": "jordekorre",
    "jordekorrarna": "jordekorre",
    "jordekorrarnas": "jordekorre",
    "jordekorrars": "jordekorre",
    "jordekorren": "jordekorre",
    "jordekorrens": "jordekorre",
    "jordekorres": "jordekorre",
    "jordekorrs": "jordekorre",
    "jordelivet": "jordeliv",
    "jordelivets": "jordeliv",
    "jordelivs": "jordeliv",
    "jordemodern": "jordemoder",
    "jordemoderns": "jordemoder",
    "jordemoders": "jordemoder",
    "jorden": "jord",
    "jorden-runt-seglar": "jorden-runt-seglare",
    "jorden-runt-seglaren": "jorden-runt-seglare",
    "jorden-runt-seglarens": "jorden-runt-seglare",
    "jorden-runt-seglares": "jorden-runt-seglare",
    "jorden-runt-seglarna": "jorden-runt-seglare",
    "jorden-runt-seglarnas": "jorden-runt-seglare",
    "jordens": "jord",
    "jordfasta": "jordfast",
    "jordfastare": "jordfast",
    "jordfastares": "jordfast",
    "jordfastas": "jordfast",
    "jordfastast": "jordfast",
    "jordfastaste": "jordfast",
    "jordfastastes": "jordfast",
    "jordfastasts": "jordfast",
    "jordfaste": "jordfast",
    "jordfastes": "jordfast",
    "jordfasts": "jordfast",
    "jordflyen": "jordfly",
    "jordflyens": "jordfly",
    "jordflyet": "jordfly",
    "jordflyets": "jordfly",
    "jordflyn": "jordfly",
    "jordflyna": "jordfly",
    "jordflynas": "jordfly",
    "jordflyns": "jordfly",
    "jordflys": "jordfly",
    "jordflyt": "jordfly",
    "jordflytningar": "jordflytning",
    "jordflytningarna": "jordflytning",
    "jordflytningarnas": "jordflytning",
    "jordflytningars": "jordflytning",
    "jordflytningen": "jordflytning",
    "jordflytningens": "jordflytning",
    "jordflytnings": "jordflytning",
    "jordflyts": "jordfly",
    "jordfräsar": "jordfräs",
    "jordfräsarna": "jordfräs",
    "jordfräsarnas": "jordfräs",
    "jordfräsars": "jordfräs",
    "jordfräsen": "jordfräs",
    "jordfräsens": "jordfräs",
    "jordfärgade": "jordfärgad",
    "jordfärgades": "jordfärgad",
    "jordfärgads": "jordfärgad",
    "jordfärgat": "jordfärgad",
    "jordfärgats": "jordfärgad",
    "jordfärgen": "jordfärg",
    "jordfärgens": "jordfärg",
    "jordfärger": "jordfärg",
    "jordfärgerna": "jordfärg",
    "jordfärgernas": "jordfärg",
    "jordfärgers": "jordfärg",
    "jordfärgs": "jordfärg",
    "jordfärgämnen": "jordfärgämne",
    "jordfärgämnena": "jordfärgämne",
    "jordfärgämnenas": "jordfärgämne",
    "jordfärgämnens": "jordfärgämne",
    "jordfärgämnes": "jordfärgämne",
    "jordfärgämnet": "jordfärgämne",
    "jordfärgämnets": "jordfärgämne",
    "jordfäst": "jordfästa",
    "jordfästande": "jordfästa",
    "jordfästanden": "jordfästande",
    "jordfästandena": "jordfästande",
    "jordfästandenas": "jordfästande",
    "jordfästandens": "jordfästande",
    "jordfästandes": "jordfästande",
    "jordfästandet": "jordfästande",
    "jordfästandets": "jordfästande",
    "jordfästas": "jordfästa",
    "jordfäste": "jordfästa",
    "jordfäster": "jordfästa",
    "jordfästes": "jordfästa",
    "jordfästningar": "jordfästning",
    "jordfästningarna": "jordfästning",
    "jordfästningarnas": "jordfästning",
    "jordfästningars": "jordfästning",
    "jordfästningen": "jordfästning",
    "jordfästningens": "jordfästning",
    "jordfästnings": "jordfästning",
    "jordfästs": "jordfästa",
    "jordförbättringar": "jordförbättring",
    "jordförbättringarna": "jordförbättring",
    "jordförbättringarnas": "jordförbättring",
    "jordförbättringars": "jordförbättring",
    "jordförbättringen": "jordförbättring",
    "jordförbättringens": "jordförbättring",
    "jordförbättrings": "jordförbättring",
    "jordförstöringar": "jordförstöring",
    "jordförstöringarna": "jordförstöring",
    "jordförstöringarnas": "jordförstöring",
    "jordförstöringars": "jordförstöring",
    "jordförstöringen": "jordförstöring",
    "jordförstöringens": "jordförstöring",
    "jordförstörings": "jordförstöring",
    "jordgetingar": "jordgeting",
    "jordgetingarna": "jordgeting",
    "jordgetingarnas": "jordgeting",
    "jordgetingars": "jordgeting",
    "jordgetingen": "jordgeting",
    "jordgetingens": "jordgeting",
    "jordgetings": "jordgeting",
    "jordgloben": "jordglob",
    "jordglobens": "jordglob",
    "jordglober": "jordglob",
    "jordgloberna": "jordglob",
    "jordglobernas": "jordglob",
    "jordglobers": "jordglob",
    "jordglobs": "jordglob",
    "jordgolven": "jordgolv",
    "jordgolvens": "jordgolv",
    "jordgolvet": "jordgolv",
    "jordgolvets": "jordgolv",
    "jordgolvs": "jordgolv",
    "jordgubb": "jordgubbe",
    "jordgubbar": "jordgubbe",
    "jordgubbarna": "jordgubbe",
    "jordgubbarnas": "jordgubbe",
    "jordgubbars": "jordgubbe",
    "jordgubben": "jordgubbe",
    "jordgubbens": "jordgubbe",
    "jordgubbes": "jordgubbe",
    "jordgubbs": "jordgubbe",
    "jordgubbssaften": "jordgubbssaft",
    "jordgubbssaftens": "jordgubbssaft",
    "jordgubbssafts": "jordgubbssaft",
    "jordgubbssmaken": "jordgubbssmak",
    "jordgubbssmakens": "jordgubbssmak",
    "jordgubbssmaks": "jordgubbssmak",
    "jordgubbssylten": "jordgubbssylt",
    "jordgubbssyltens": "jordgubbssylt",
    "jordgubbssylts": "jordgubbssylt",
    "jordhack": "jordhacka",
    "jordhackan": "jordhacka",
    "jordhackans": "jordhacka",
    "jordhackas": "jordhacka",
    "jordhacke": "jordhacka",
    "jordhackor": "jordhacka",
    "jordhackorna": "jordhacka",
    "jordhackornas": "jordhacka",
    "jordhackors": "jordhacka",
    "jordhacks": "jordhacka",
    "jordhål": "jordhåla",
    "jordhålan": "jordhåla",
    "jordhålans": "jordhåla",
    "jordhålas": "jordhåla",
    "jordhåle": "jordhåla",
    "jordhålor": "jordhåla",
    "jordhålorna": "jordhåla",
    "jordhålornas": "jordhåla",
    "jordhålors": "jordhåla",
    "jordhåls": "jordhåla",
    "jordiga": "jordig",
    "jordigare": "jordig",
    "jordigares": "jordig",
    "jordigas": "jordig",
    "jordigast": "jordig",
    "jordigaste": "jordig",
    "jordigastes": "jordig",
    "jordigasts": "jordig",
    "jordige": "jordig",
    "jordiges": "jordig",
    "jordigheten": "jordighet",
    "jordighetens": "jordighet",
    "jordighets": "jordighet",
    "jordigs": "jordig",
    "jordigt": "jordig",
    "jordigts": "jordig",
    "jordiska": "jordisk",
    "jordiskare": "jordisk",
    "jordiskares": "jordisk",
    "jordiskas": "jordisk",
    "jordiskast": "jordisk",
    "jordiskaste": "jordisk",
    "jordiskastes": "jordisk",
    "jordiskasts": "jordisk",
    "jordiske": "jordisk",
    "jordiskes": "jordisk",
    "jordisks": "jordisk",
    "jordiskt": "jordisk",
    "jordiskts": "jordisk",
    "jordkabeln": "jordkabel",
    "jordkabelns": "jordkabel",
    "jordkabels": "jordkabel",
    "jordkablar": "jordkabel",
    "jordkablarna": "jordkabel",
    "jordkablarnas": "jordkabel",
    "jordkablars": "jordkabel",
    "jordklotet": "jordklot",
    "jordklotets": "jordklot",
    "jordklots": "jordklot",
    "jordkul": "jordkula",
    "jordkulan": "jordkula",
    "jordkulans": "jordkula",
    "jordkulas": "jordkula",
    "jordkule": "jordkula",
    "jordkulor": "jordkula",
    "jordkulorna": "jordkula",
    "jordkulornas": "jordkula",
    "jordkulors": "jordkula",
    "jordkuls": "jordkula",
    "jordkällar": "jordkällare",
    "jordkällaren": "jordkällare",
    "jordkällarens": "jordkällare",
    "jordkällares": "jordkällare",
    "jordkällarna": "jordkällare",
    "jordkällarnas": "jordkällare",
    "jordkärn": "jordkärna",
    "jordkärnan": "jordkärna",
    "jordkärnans": "jordkärna",
    "jordkärnas": "jordkärna",
    "jordkärne": "jordkärna",
    "jordkärnor": "jordkärna",
    "jordkärnorna": "jordkärna",
    "jordkärnornas": "jordkärna",
    "jordkärnors": "jordkärna",
    "jordkärns": "jordkärna",
    "jordlagerna": "jordlager",
    "jordlagernas": "jordlager",
    "jordlagers": "jordlager",
    "jordlagren": "jordlager",
    "jordlagrens": "jordlager",
    "jordlagret": "jordlager",
    "jordlagrets": "jordlager",
    "jordledningar": "jordledning",
    "jordledningarna": "jordledning",
    "jordledningarnas": "jordledning",
    "jordledningars": "jordledning",
    "jordledningen": "jordledning",
    "jordledningens": "jordledning",
    "jordlednings": "jordledning",
    "jordleg": "jordlega",
    "jordlegan": "jordlega",
    "jordlegans": "jordlega",
    "jordlegas": "jordlega",
    "jordlege": "jordlega",
    "jordlegor": "jordlega",
    "jordlegorna": "jordlega",
    "jordlegornas": "jordlega",
    "jordlegors": "jordlega",
    "jordlegs": "jordlega",
    "jordlika": "jordlik",
    "jordlikare": "jordlik",
    "jordlikares": "jordlik",
    "jordlikas": "jordlik",
    "jordlikast": "jordlik",
    "jordlikaste": "jordlik",
    "jordlikastes": "jordlik",
    "jordlikasts": "jordlik",
    "jordlike": "jordlik",
    "jordlikes": "jordlik",
    "jordlikheten": "jordlikhet",
    "jordlikhetens": "jordlikhet",
    "jordlikhets": "jordlikhet",
    "jordliks": "jordlik",
    "jordlikt": "jordlik",
    "jordlikts": "jordlik",
    "jordlopp": "jordloppa",
    "jordloppan": "jordloppa",
    "jordloppans": "jordloppa",
    "jordloppas": "jordloppa",
    "jordloppe": "jordloppa",
    "jordloppor": "jordloppa",
    "jordlopporna": "jordloppa",
    "jordloppornas": "jordloppa",
    "jordloppors": "jordloppa",
    "jordlopps": "jordloppa",
    "jordlotten": "jordlott",
    "jordlottens": "jordlott",
    "jordlotter": "jordlott",
    "jordlotterna": "jordlott",
    "jordlotternas": "jordlott",
    "jordlotters": "jordlott",
    "jordlotts": "jordlott",
    "jordlöpar": "jordlöpare",
    "jordlöparen": "jordlöpare",
    "jordlöparens": "jordlöpare",
    "jordlöpares": "jordlöpare",
    "jordlöparna": "jordlöpare",
    "jordlöparnas": "jordlöpare",
    "jordmagnetismen": "jordmagnetism",
    "jordmagnetismens": "jordmagnetism",
    "jordmagnetismer": "jordmagnetism",
    "jordmagnetismerna": "jordmagnetism",
    "jordmagnetismernas": "jordmagnetism",
    "jordmagnetismers": "jordmagnetism",
    "jordmagnetisms": "jordmagnetism",
    "jordmanteln": "jordmantel",
    "jordmantelns": "jordmantel",
    "jordmantels": "jordmantel",
    "jordmaterialen": "jordmaterial",
    "jordmaterialens": "jordmaterial",
    "jordmaterialet": "jordmaterial",
    "jordmaterialets": "jordmaterial",
    "jordmaterials": "jordmaterial",
    "jordmaterian": "jordmateria",
    "jordmaterians": "jordmateria",
    "jordmaterias": "jordmateria",
    "jordmaterier": "jordmateria",
    "jordmaterierna": "jordmateria",
    "jordmateriernas": "jordmateria",
    "jordmateriers": "jordmateria",
    "jordmetallen": "jordmetall",
    "jordmetallens": "jordmetall",
    "jordmetaller": "jordmetall",
    "jordmetallerna": "jordmetall",
    "jordmetallernas": "jordmetall",
    "jordmetallers": "jordmetall",
    "jordmetalls": "jordmetall",
    "jordmånen": "jordmån",
    "jordmånens": "jordmån",
    "jordmåns": "jordmån",
    "jordnöten": "jordnöt",
    "jordnötens": "jordnöt",
    "jordnöts": "jordnöt",
    "jordnötssmöret": "jordnötssmör",
    "jordnötssmörets": "jordnötssmör",
    "jordnötssmörs": "jordnötssmör",
    "jordnötter": "jordnöt",
    "jordnötterna": "jordnöt",
    "jordnötternas": "jordnöt",
    "jordnötters": "jordnöt",
    "jordområden": "jordområde",
    "jordområdena": "jordområde",
    "jordområdenas": "jordområde",
    "jordområdens": "jordområde",
    "jordområdes": "jordområde",
    "jordområdet": "jordområde",
    "jordområdets": "jordområde",
    "jordpartikeln": "jordpartikel",
    "jordpartikelns": "jordpartikel",
    "jordpartikels": "jordpartikel",
    "jordpartiklar": "jordpartikel",
    "jordpartiklarna": "jordpartikel",
    "jordpartiklarnas": "jordpartikel",
    "jordpartiklars": "jordpartikel",
    "jordpås": "jordpåse",
    "jordpåsar": "jordpåse",
    "jordpåsarna": "jordpåse",
    "jordpåsarnas": "jordpåse",
    "jordpåsars": "jordpåse",
    "jordpåsen": "jordpåse",
    "jordpåsens": "jordpåse",
    "jordpåses": "jordpåse",
    "jordreformen": "jordreform",
    "jordreformens": "jordreform",
    "jordreformer": "jordreform",
    "jordreformerna": "jordreform",
    "jordreformernas": "jordreform",
    "jordreformers": "jordreform",
    "jordreforms": "jordreform",
    "jordregisterna": "jordregister",
    "jordregisternas": "jordregister",
    "jordregisters": "jordregister",
    "jordregistren": "jordregister",
    "jordregistrens": "jordregister",
    "jordregistret": "jordregister",
    "jordregistrets": "jordregister",
    "jordrems": "jordremsa",
    "jordremsan": "jordremsa",
    "jordremsans": "jordremsa",
    "jordremsas": "jordremsa",
    "jordremse": "jordremsa",
    "jordremsor": "jordremsa",
    "jordremsorna": "jordremsa",
    "jordremsornas": "jordremsa",
    "jordremsors": "jordremsa",
    "jordrotationen": "jordrotation",
    "jordrotationens": "jordrotation",
    "jordrotationer": "jordrotation",
    "jordrotationerna": "jordrotation",
    "jordrotationernas": "jordrotation",
    "jordrotationers": "jordrotation",
    "jordrotations": "jordrotation",
    "jordräntan": "jordränta",
    "jordräntans": "jordränta",
    "jordräntas": "jordränta",
    "jordränte": "jordränta",
    "jordräntor": "jordränta",
    "jordräntorna": "jordränta",
    "jordräntornas": "jordränta",
    "jordräntors": "jordränta",
    "jordröken": "jordrök",
    "jordrökens": "jordrök",
    "jordröks": "jordrök",
    "jords": "jord",
    "jordskalven": "jordskalv",
    "jordskalvens": "jordskalv",
    "jordskalvet": "jordskalv",
    "jordskalvets": "jordskalv",
    "jordskalvs": "jordskalv",
    "jordskalvsaktivisten": "jordskalvsaktivist",
    "jordskalvsaktivistens": "jordskalvsaktivist",
    "jordskalvsaktivister": "jordskalvsaktivist",
    "jordskalvsaktivisterna": "jordskalvsaktivist",
    "jordskalvsaktivisternas": "jordskalvsaktivist",
    "jordskalvsaktivisters": "jordskalvsaktivist",
    "jordskalvsaktivists": "jordskalvsaktivist",
    "jordskenet": "jordsken",
    "jordskenets": "jordsken",
    "jordskens": "jordsken",
    "jordskorpan": "jordskorpa",
    "jordskorpans": "jordskorpa",
    "jordskorpas": "jordskorpa",
    "jordskotten": "jordskott",
    "jordskottens": "jordskott",
    "jordskottet": "jordskott",
    "jordskottets": "jordskott",
    "jordskotts": "jordskott",
    "jordskreden": "jordskred",
    "jordskredens": "jordskred",
    "jordskredet": "jordskred",
    "jordskredets": "jordskred",
    "jordskreds": "jordskred",
    "jordskredssegern": "jordskredsseger",
    "jordskredssegerns": "jordskredsseger",
    "jordskredssegers": "jordskredsseger",
    "jordskredssegrar": "jordskredsseger",
    "jordskredssegrarna": "jordskredsseger",
    "jordskredssegrarnas": "jordskredsseger",
    "jordskredssegrars": "jordskredsseger",
    "jordskuggan": "jordskugga",
    "jordskuggans": "jordskugga",
    "jordskuggas": "jordskugga",
    "jordskylden": "jordskyld",
    "jordskyldens": "jordskyld",
    "jordskylder": "jordskyld",
    "jordskylderna": "jordskyld",
    "jordskyldernas": "jordskyld",
    "jordskylders": "jordskyld",
    "jordskylds": "jordskyld",
    "jordslagen": "jordslå",
    "jordslagens": "jordslå",
    "jordslaget": "jordslag",
    "jordslagets": "jordslag",
    "jordslagit": "jordslå",
    "jordslagits": "jordslå",
    "jordslagna": "jordslå",
    "jordslagnas": "jordslå",
    "jordslagne": "jordslå",
    "jordslagnes": "jordslå",
    "jordslags": "jordslag",
    "jordslog": "jordslå",
    "jordsloge": "jordslå",
    "jordsloges": "jordslå",
    "jordslogs": "jordslå",
    "jordslående": "jordslå",
    "jordslåenden": "jordslående",
    "jordslåendena": "jordslående",
    "jordslåendenas": "jordslående",
    "jordslåendens": "jordslående",
    "jordslåendes": "jordslående",
    "jordslåendet": "jordslående",
    "jordslåendets": "jordslående",
    "jordslår": "jordslå",
    "jordslås": "jordslå",
    "jordspjuten": "jordspjut",
    "jordspjutens": "jordspjut",
    "jordspjutet": "jordspjut",
    "jordspjutets": "jordspjut",
    "jordspjuts": "jordspjut",
    "jordstammar": "jordstam",
    "jordstammarna": "jordstam",
    "jordstammarnas": "jordstam",
    "jordstammars": "jordstam",
    "jordstammen": "jordstam",
    "jordstammens": "jordstam",
    "jordstams": "jordstam",
    "jordstjärnan": "jordstjärna",
    "jordstjärnans": "jordstjärna",
    "jordstjärnas": "jordstjärna",
    "jordstjärne": "jordstjärna",
    "jordstjärnor": "jordstjärna",
    "jordstjärnorna": "jordstjärna",
    "jordstjärnornas": "jordstjärna",
    "jordstjärnors": "jordstjärna",
    "jordströmmar": "jordström",
    "jordströmmarna": "jordström",
    "jordströmmarnas": "jordström",
    "jordströmmars": "jordström",
    "jordströmmen": "jordström",
    "jordströmmens": "jordström",
    "jordströms": "jordström",
    "jordstötar": "jordstöt",
    "jordstötarna": "jordstöt",
    "jordstötarnas": "jordstöt",
    "jordstötars": "jordstöt",
    "jordstöten": "jordstöt",
    "jordstötens": "jordstöt",
    "jordstöts": "jordstöt",
    "jordsvinen": "jordsvin",
    "jordsvinens": "jordsvin",
    "jordsvinet": "jordsvin",
    "jordsvinets": "jordsvin",
    "jordsvins": "jordsvin",
    "jordtagen": "jordtag",
    "jordtagens": "jordtag",
    "jordtaget": "jordtag",
    "jordtagets": "jordtag",
    "jordtags": "jordtag",
    "jordtröttheten": "jordtrötthet",
    "jordtrötthetens": "jordtrötthet",
    "jordtröttheter": "jordtrötthet",
    "jordtröttheterna": "jordtrötthet",
    "jordtröttheternas": "jordtrötthet",
    "jordtröttheters": "jordtrötthet",
    "jordtrötthets": "jordtrötthet",
    "jordtäkten": "jordtäkt",
    "jordtäktens": "jordtäkt",
    "jordtäkter": "jordtäkt",
    "jordtäkterna": "jordtäkt",
    "jordtäkternas": "jordtäkt",
    "jordtäkters": "jordtäkt",
    "jordtäkts": "jordtäkt",
    "jordugglan": "jorduggla",
    "jordugglans": "jorduggla",
    "jordugglas": "jorduggla",
    "jorduggle": "jorduggla",
    "jordugglor": "jorduggla",
    "jordugglorna": "jorduggla",
    "jordugglornas": "jorduggla",
    "jordugglors": "jorduggla",
    "jordutdelningar": "jordutdelning",
    "jordutdelningarna": "jordutdelning",
    "jordutdelningarnas": "jordutdelning",
    "jordutdelningars": "jordutdelning",
    "jordutdelningen": "jordutdelning",
    "jordutdelningens": "jordutdelning",
    "jordutdelnings": "jordutdelning",
    "jordvallar": "jordvall",
    "jordvallarna": "jordvall",
    "jordvallarnas": "jordvall",
    "jordvallars": "jordvall",
    "jordvallen": "jordvall",
    "jordvallens": "jordvall",
    "jordvalls": "jordvall",
    "jordvaxet": "jordvax",
    "jordvaxets": "jordvax",
    "jordvärden": "jordvärde",
    "jordvärdena": "jordvärde",
    "jordvärdenas": "jordvärde",
    "jordvärdens": "jordvärde",
    "jordvärdes": "jordvärde",
    "jordvärdestegringar": "jordvärdestegring",
    "jordvärdestegringarna": "jordvärdestegring",
    "jordvärdestegringarnas": "jordvärdestegring",
    "jordvärdestegringars": "jordvärdestegring",
    "jordvärdestegringen": "jordvärdestegring",
    "jordvärdestegringens": "jordvärdestegring",
    "jordvärdestegrings": "jordvärdestegring",
    "jordvärdet": "jordvärde",
    "jordvärdets": "jordvärde",
    "jordvärmen": "jordvärme",
    "jordvärmens": "jordvärme",
    "jordvärmes": "jordvärme",
    "jordytan": "jordyta",
    "jordytans": "jordyta",
    "jordytas": "jordyta",
    "jordyte": "jordyta",
    "jordytor": "jordyta",
    "jordytorna": "jordyta",
    "jordytornas": "jordyta",
    "jordytors": "jordyta",
    "jordägar": "jordägare",
    "jordägaren": "jordägare",
    "jordägarens": "jordägare",
    "jordägares": "jordägare",
    "jordägarna": "jordägare",
    "jordägarnas": "jordägare",
    "jordärtskock": "jordärtskocka",
    "jordärtskockan": "jordärtskocka",
    "jordärtskockans": "jordärtskocka",
    "jordärtskockas": "jordärtskocka",
    "jordärtskocke": "jordärtskocka",
    "jordärtskockor": "jordärtskocka",
    "jordärtskockorna": "jordärtskocka",
    "jordärtskockornas": "jordärtskocka",
    "jordärtskockors": "jordärtskocka",
    "jordärtskocks": "jordärtskocka",
    "jorsskalvsaktivisten": "jorsskalvsaktivist",
    "jorsskalvsaktivistens": "jorsskalvsaktivist",
    "jorsskalvsaktivister": "jorsskalvsaktivist",
    "jorsskalvsaktivisterna": "jorsskalvsaktivist",
    "jorsskalvsaktivisternas": "jorsskalvsaktivist",
    "jorsskalvsaktivisters": "jorsskalvsaktivist",
    "jorsskalvsaktivists": "jorsskalvsaktivist",
    "josen": "jos",
    "josens": "jos",
    "joser": "jos",
    "joserna": "jos",
    "josernas": "jos",
    "josers": "jos",
    "jotan": "jota",
    "jotana": "jota",
    "jotanas": "jota",
    "jotans": "jota",
    "jotas": "jota",
    "jotat": "jota",
    "jotats": "jota",
    "joulen": "joule",
    "joulena": "joule",
    "joulenas": "joule",
    "joulens": "joule",
    "joules": "joule",
    "jourbutiken": "jourbutik",
    "jourbutikens": "jourbutik",
    "jourbutiker": "jourbutik",
    "jourbutikerna": "jourbutik",
    "jourbutikernas": "jourbutik",
    "jourbutikers": "jourbutik",
    "jourbutiks": "jourbutik",
    "jouren": "jour",
    "jourens": "jour",
    "jourer": "jour",
    "jourerna": "jour",
    "jourernas": "jour",
    "jourers": "jour",
    "jourhavanden": "jourhavande",
    "jourhavandena": "jourhavande",
    "jourhavandenas": "jourhavande",
    "jourhavandens": "jourhavande",
    "jourhavandes": "jourhavande",
    "journalen": "journal",
    "journalens": "journal",
    "journaler": "journal",
    "journalerna": "journal",
    "journalernas": "journal",
    "journalers": "journal",
    "journalfilmen": "journalfilm",
    "journalfilmens": "journalfilm",
    "journalfilmer": "journalfilm",
    "journalfilmerna": "journalfilm",
    "journalfilmernas": "journalfilm",
    "journalfilmers": "journalfilm",
    "journalfilms": "journalfilm",
    "journalisten": "journalist",
    "journalistens": "journalist",
    "journalister": "journalist",
    "journalisterna": "journalist",
    "journalisternas": "journalist",
    "journalisters": "journalist",
    "journalistiken": "journalistik",
    "journalistikens": "journalistik",
    "journalistiks": "journalistik",
    "journalistiska": "journalistisk",
    "journalistiskare": "journalistisk",
    "journalistiskares": "journalistisk",
    "journalistiskas": "journalistisk",
    "journalistiskast": "journalistisk",
    "journalistiskaste": "journalistisk",
    "journalistiskastes": "journalistisk",
    "journalistiskasts": "journalistisk",
    "journalistiske": "journalistisk",
    "journalistiskes": "journalistisk",
    "journalistisks": "journalistisk",
    "journalistiskt": "journalistisk",
    "journalistiskts": "journalistisk",
    "journalists": "journalist",
    "journals": "journal",
    "jours": "jour",
    "jourtjänsten": "jourtjänst",
    "jourtjänstens": "jourtjänst",
    "jourtjänsts": "jourtjänst",
    "joviala": "jovial",
    "jovialare": "jovial",
    "jovialares": "jovial",
    "jovialas": "jovial",
    "jovialast": "jovial",
    "jovialaste": "jovial",
    "jovialastes": "jovial",
    "jovialasts": "jovial",
    "joviale": "jovial",
    "joviales": "jovial",
    "jovialiska": "jovialisk",
    "jovialiskare": "jovialisk",
    "jovialiskares": "jovialisk",
    "jovialiskas": "jovialisk",
    "jovialiskast": "jovialisk",
    "jovialiskaste": "jovialisk",
    "jovialiskastes": "jovialisk",
    "jovialiskasts": "jovialisk",
    "jovialiske": "jovialisk",
    "jovialiskes": "jovialisk",
    "jovialisks": "jovialisk",
    "jovialiskt": "jovialisk",
    "jovialiskts": "jovialisk",
    "jovialiteten": "jovialitet",
    "jovialitetens": "jovialitet",
    "jovialiteter": "jovialitet",
    "jovialiteterna": "jovialitet",
    "jovialiteternas": "jovialitet",
    "jovialiteters": "jovialitet",
    "jovialitets": "jovialitet",
    "jovials": "jovial",
    "jovialt": "jovial",
    "jovialts": "jovial",
    "jox": "joxa",
    "joxade": "joxa",
    "joxades": "joxa",
    "joxande": "joxa",
    "joxanden": "joxande",
    "joxandena": "joxande",
    "joxandenas": "joxande",
    "joxandens": "joxande",
    "joxandes": "joxande",
    "joxandet": "joxande",
    "joxandets": "joxande",
    "joxar": "joxa",
    "joxas": "joxa",
    "joxat": "joxa",
    "joxats": "joxa",
    "joxet": "jox",
    "joxets": "jox",
    "joxiga": "joxig",
    "joxigare": "joxig",
    "joxigares": "joxig",
    "joxigas": "joxig",
    "joxigast": "joxig",
    "joxigaste": "joxig",
    "joxigastes": "joxig",
    "joxigasts": "joxig",
    "joxige": "joxig",
    "joxiges": "joxig",
    "joxigs": "joxig",
    "joxigt": "joxig",
    "joxigts": "joxig",
    "jubel": "jubla",
    "jubeldagar": "jubeldag",
    "jubeldagarna": "jubeldag",
    "jubeldagarnas": "jubeldag",
    "jubeldagars": "jubeldag",
    "jubeldagen": "jubeldag",
    "jubeldagens": "jubeldag",
    "jubeldags": "jubeldag",
    "jubeldoktorer": "jubeldoktor",
    "jubeldoktorerna": "jubeldoktor",
    "jubeldoktorernas": "jubeldoktor",
    "jubeldoktorers": "jubeldoktor",
    "jubeldoktorn": "jubeldoktor",
    "jubeldoktorns": "jubeldoktor",
    "jubeldoktors": "jubeldoktor",
    "jubelidioten": "jubelidiot",
    "jubelidiotens": "jubelidiot",
    "jubelidioter": "jubelidiot",
    "jubelidioterna": "jubelidiot",
    "jubelidioternas": "jubelidiot",
    "jubelidioters": "jubelidiot",
    "jubelidiots": "jubelidiot",
    "jubels": "jubel",
    "jubelåren": "jubelår",
    "jubelårens": "jubelår",
    "jubelåret": "jubelår",
    "jubelårets": "jubelår",
    "jubelårs": "jubelår",
    "jubelåsnan": "jubelåsna",
    "jubelåsnans": "jubelåsna",
    "jubelåsnas": "jubelåsna",
    "jubelåsne": "jubelåsna",
    "jubelåsnor": "jubelåsna",
    "jubelåsnorna": "jubelåsna",
    "jubelåsnornas": "jubelåsna",
    "jubelåsnors": "jubelåsna",
    "jubilaren": "jubilar",
    "jubilarens": "jubilar",
    "jubilarer": "jubilar",
    "jubilarerna": "jubilar",
    "jubilarernas": "jubilar",
    "jubilarers": "jubilar",
    "jubilars": "jubilar",
    "jubileer": "jubileum",
    "jubileerna": "jubileum",
    "jubileernas": "jubileum",
    "jubileers": "jubileum",
    "jubileet": "jubileum",
    "jubileets": "jubileum",
    "jubilei": "jubileum",
    "jubilerade": "jubilera",
    "jubilerades": "jubilera",
    "jubilerande": "jubilera",
    "jubileranden": "jubilerande",
    "jubilerandena": "jubilerande",
    "jubilerandenas": "jubilerande",
    "jubilerandens": "jubilerande",
    "jubilerandes": "jubilerande",
    "jubilerandet": "jubilerande",
    "jubilerandets": "jubilerande",
    "jubilerar": "jubilera",
    "jubileras": "jubilera",
    "jubilerat": "jubilera",
    "jubilerats": "jubilera",
    "jubileringar": "jubilering",
    "jubileringarna": "jubilering",
    "jubileringarnas": "jubilering",
    "jubileringars": "jubilering",
    "jubileringen": "jubilering",
    "jubileringens": "jubilering",
    "jubilerings": "jubilering",
    "jubileums": "jubileum",
    "jubileumsmynten": "jubileumsmynt",
    "jubileumsmyntens": "jubileumsmynt",
    "jubileumsmyntet": "jubileumsmynt",
    "jubileumsmyntets": "jubileumsmynt",
    "jubileumsmynts": "jubileumsmynt",
    "jubileumsåren": "jubileumsår",
    "jubileumsårens": "jubileumsår",
    "jubileumsåret": "jubileumsår",
    "jubileumsårets": "jubileumsår",
    "jubileumsårs": "jubileumsår",
    "jublade": "jubla",
    "jublades": "jubla",
    "jublande": "jubla",
    "jublanden": "jublande",
    "jublandena": "jublande",
    "jublandenas": "jublande",
    "jublandens": "jublande",
    "jublandes": "jublande",
    "jublandet": "jublande",
    "jublandets": "jublande",
    "jublar": "jubla",
    "jublas": "jubla",
    "jublat": "jubla",
    "jublats": "jubla",
    "jublet": "jubel",
    "jublets": "jubel",
    "juck": "jucka",
    "juckade": "jucka",
    "juckades": "jucka",
    "juckande": "jucka",
    "juckanden": "juckande",
    "juckandena": "juckande",
    "juckandenas": "juckande",
    "juckandens": "juckande",
    "juckandes": "juckande",
    "juckandet": "juckande",
    "juckandets": "juckande",
    "juckar": "jucka",
    "juckas": "jucka",
    "juckat": "jucka",
    "juckats": "jucka",
    "judafolket": "judafolk",
    "judafolkets": "judafolk",
    "judafolks": "judafolk",
    "judar": "jude",
    "judarna": "jude",
    "judarnas": "jude",
    "judars": "jude",
    "judasgärningar": "judasgärning",
    "judasgärningarna": "judasgärning",
    "judasgärningarnas": "judasgärning",
    "judasgärningars": "judasgärning",
    "judasgärningen": "judasgärning",
    "judasgärningens": "judasgärning",
    "judasgärnings": "judasgärning",
    "judaskyssar": "judaskyss",
    "judaskyssarna": "judaskyss",
    "judaskyssarnas": "judaskyss",
    "judaskyssars": "judaskyss",
    "judaskyssen": "judaskyss",
    "judaskyssens": "judaskyss",
    "judaspengar": "judaspeng",
    "judaspengarna": "judaspeng",
    "judaspengarnas": "judaspeng",
    "judaspengars": "judaspeng",
    "judaspengen": "judaspeng",
    "judaspengens": "judaspeng",
    "judaspengs": "judaspeng",
    "judebröden": "judebröd",
    "judebrödens": "judebröd",
    "judebrödet": "judebröd",
    "judebrödets": "judebröd",
    "judebröds": "judebröd",
    "judeförföljelsen": "judeförföljelse",
    "judeförföljelsens": "judeförföljelse",
    "judeförföljelser": "judeförföljelse",
    "judeförföljelserna": "judeförföljelse",
    "judeförföljelsernas": "judeförföljelse",
    "judeförföljelsers": "judeförföljelse",
    "judeförföljelses": "judeförföljelse",
    "judekristenheten": "judekristenhet",
    "judekristenhetens": "judekristenhet",
    "judekristenhets": "judekristenhet",
    "judekristens": "judekristen",
    "judekristet": "judekristen",
    "judekristets": "judekristen",
    "judekristna": "judekristen",
    "judekristnare": "judekristen",
    "judekristnares": "judekristen",
    "judekristnas": "judekristen",
    "judekristnast": "judekristen",
    "judekristnaste": "judekristen",
    "judekristnastes": "judekristen",
    "judekristnasts": "judekristen",
    "judekristne": "judekristen",
    "judekristnes": "judekristen",
    "juden": "jude",
    "judendomar": "judendom",
    "judendomarna": "judendom",
    "judendomarnas": "judendom",
    "judendomars": "judendom",
    "judendomen": "judendom",
    "judendomens": "judendom",
    "judendoms": "judendom",
    "judenheten": "judenhet",
    "judenhetens": "judenhet",
    "judenheter": "judenhet",
    "judenheterna": "judenhet",
    "judenheternas": "judenhet",
    "judenheters": "judenhet",
    "judenhets": "judenhet",
    "judens": "jude",
    "judes": "jude",
    "judetysk": "judetyska",
    "judetyskan": "judetyska",
    "judetyskans": "judetyska",
    "judetyskas": "judetyska",
    "judiciella": "judiciell",
    "judiciellare": "judiciell",
    "judiciellares": "judiciell",
    "judiciellas": "judiciell",
    "judiciellast": "judiciell",
    "judiciellaste": "judiciell",
    "judiciellastes": "judiciell",
    "judiciellasts": "judiciell",
    "judicielle": "judiciell",
    "judicielles": "judiciell",
    "judiciells": "judiciell",
    "judiciellt": "judiciell",
    "judiciellts": "judiciell",
    "judinnan": "judinna",
    "judinnans": "judinna",
    "judinnas": "judinna",
    "judinne": "judinna",
    "judinnor": "judinna",
    "judinnorna": "judinna",
    "judinnornas": "judinna",
    "judinnors": "judinna",
    "judiska": "judisk",
    "judiskare": "judisk",
    "judiskares": "judisk",
    "judiskas": "judisk",
    "judiskast": "judisk",
    "judiskaste": "judisk",
    "judiskastes": "judisk",
    "judiskasts": "judisk",
    "judiske": "judisk",
    "judiskes": "judisk",
    "judisks": "judisk",
    "judiskt": "judisk",
    "judiskts": "judisk",
    "judon": "judo",
    "judons": "judo",
    "judos": "judo",
    "juften": "juft",
    "juftens": "juft",
    "juftet": "juft",
    "juftets": "juft",
    "jufts": "juft",
    "jugendbanden": "jugendband",
    "jugendbandens": "jugendband",
    "jugendbandet": "jugendband",
    "jugendbandets": "jugendband",
    "jugendbands": "jugendband",
    "jugends": "jugend",
    "jugendstilen": "jugendstil",
    "jugendstilens": "jugendstil",
    "jugendstils": "jugendstil",
    "juggemaffian": "juggemaffia",
    "juggemaffians": "juggemaffia",
    "juggemaffias": "juggemaffia",
    "juggemaffior": "juggemaffia",
    "juggemaffiorna": "juggemaffia",
    "juggemaffiornas": "juggemaffia",
    "juggemaffiors": "juggemaffia",
    "jugoslaven": "jugoslav",
    "jugoslavens": "jugoslav",
    "jugoslaver": "jugoslav",
    "jugoslaverna": "jugoslav",
    "jugoslavernas": "jugoslav",
    "jugoslavers": "jugoslav",
    "jugoslaviska": "jugoslavisk",
    "jugoslaviskan": "jugoslaviska",
    "jugoslaviskans": "jugoslaviska",
    "jugoslaviskare": "jugoslavisk",
    "jugoslaviskares": "jugoslavisk",
    "jugoslaviskas": "jugoslaviska",
    "jugoslaviskast": "jugoslavisk",
    "jugoslaviskaste": "jugoslavisk",
    "jugoslaviskastes": "jugoslavisk",
    "jugoslaviskasts": "jugoslavisk",
    "jugoslaviske": "jugoslaviska",
    "jugoslaviskes": "jugoslavisk",
    "jugoslaviskor": "jugoslaviska",
    "jugoslaviskorna": "jugoslaviska",
    "jugoslaviskornas": "jugoslaviska",
    "jugoslaviskors": "jugoslaviska",
    "jugoslavisks": "jugoslavisk",
    "jugoslaviskt": "jugoslavisk",
    "jugoslaviskts": "jugoslavisk",
    "jugoslavs": "jugoslav",
    "juicen": "juice",
    "juicens": "juice",
    "juicer": "juice",
    "juicerna": "juice",
    "juicernas": "juice",
    "juicers": "juice",
    "juices": "juice",
    "jukeboxar": "jukebox",
    "jukeboxarna": "jukebox",
    "jukeboxarnas": "jukebox",
    "jukeboxars": "jukebox",
    "jukeboxen": "jukebox",
    "jukeboxens": "jukebox",
    "julade": "jula",
    "julades": "jula",
    "julaftnar": "julafton",
    "julaftnarna": "julafton",
    "julaftnarnas": "julafton",
    "julaftnars": "julafton",
    "julaftonen": "julafton",
    "julaftonens": "julafton",
    "julaftons": "julafton",
    "julande": "jula",
    "julanden": "julande",
    "julandena": "julande",
    "julandenas": "julande",
    "julandens": "julande",
    "julandes": "julande",
    "julandet": "julande",
    "julandets": "julande",
    "jular": "jula",
    "jularna": "jul",
    "jularnas": "jul",
    "julars": "jul",
    "julas": "jula",
    "julat": "jula",
    "julats": "jula",
    "julbelysningar": "julbelysning",
    "julbelysningarna": "julbelysning",
    "julbelysningarnas": "julbelysning",
    "julbelysningars": "julbelysning",
    "julbelysningen": "julbelysning",
    "julbelysningens": "julbelysning",
    "julbelysnings": "julbelysning",
    "julbockar": "julbock",
    "julbockarna": "julbock",
    "julbockarnas": "julbock",
    "julbockars": "julbock",
    "julbocken": "julbock",
    "julbockens": "julbock",
    "julbocks": "julbock",
    "julborden": "julbord",
    "julbordens": "julbord",
    "julbordet": "julbord",
    "julbordets": "julbord",
    "julbords": "julbord",
    "julbönen": "julbön",
    "julbönens": "julbön",
    "julböner": "julbön",
    "julbönerna": "julbön",
    "julbönernas": "julbön",
    "julböners": "julbön",
    "julböns": "julbön",
    "juldagar": "juldag",
    "juldagarna": "juldag",
    "juldagarnas": "juldag",
    "juldagars": "juldag",
    "juldagen": "juldag",
    "juldagens": "juldag",
    "juldags": "juldag",
    "juldagsmorgnar": "juldagsmorgon",
    "juldagsmorgnarna": "juldagsmorgon",
    "juldagsmorgnarnas": "juldagsmorgon",
    "juldagsmorgnars": "juldagsmorgon",
    "juldagsmorgonen": "juldagsmorgon",
    "juldagsmorgonens": "juldagsmorgon",
    "juldagsmorgons": "juldagsmorgon",
    "juldagsmornar": "juldagsmorgon",
    "juldagsmornarna": "juldagsmorgon",
    "juldagsmornarnas": "juldagsmorgon",
    "juldagsmornars": "juldagsmorgon",
    "juldekorationen": "juldekoration",
    "juldekorationens": "juldekoration",
    "juldekorationer": "juldekoration",
    "juldekorationerna": "juldekoration",
    "juldekorationernas": "juldekoration",
    "juldekorationers": "juldekoration",
    "juldekorations": "juldekoration",
    "juleljusen": "juleljus",
    "juleljusens": "juleljus",
    "juleljuset": "juleljus",
    "juleljusets": "juleljus",
    "julen": "jul",
    "julens": "jul",
    "julevangelie": "julevangelium",
    "julevangelier": "julevangelium",
    "julevangelierna": "julevangelium",
    "julevangeliernas": "julevangelium",
    "julevangeliers": "julevangelium",
    "julevangeliet": "julevangelium",
    "julevangeliets": "julevangelium",
    "julevangeliums": "julevangelium",
    "julfem": "julfemma",
    "julfemman": "julfemma",
    "julfemmans": "julfemma",
    "julfemmas": "julfemma",
    "julfemme": "julfemma",
    "julfemmor": "julfemma",
    "julfemmorna": "julfemma",
    "julfemmornas": "julfemma",
    "julfemmors": "julfemma",
    "julfems": "julfemma",
    "julfesten": "julfest",
    "julfestens": "julfest",
    "julfester": "julfest",
    "julfesterna": "julfest",
    "julfesternas": "julfest",
    "julfesters": "julfest",
    "julfests": "julfest",
    "julfilmen": "julfilm",
    "julfilmens": "julfilm",
    "julfilmer": "julfilm",
    "julfilmerna": "julfilm",
    "julfilmernas": "julfilm",
    "julfilmers": "julfilm",
    "julfilms": "julfilm",
    "julförsäljningen": "julförsäljning",
    "julförsäljningens": "julförsäljning",
    "julförsäljnings": "julförsäljning",
    "julgranar": "julgran",
    "julgranarna": "julgran",
    "julgranarnas": "julgran",
    "julgranars": "julgran",
    "julgranen": "julgran",
    "julgranens": "julgran",
    "julgrans": "julgran",
    "julgransbelysningar": "julgransbelysning",
    "julgransbelysningarna": "julgransbelysning",
    "julgransbelysningarnas": "julgransbelysning",
    "julgransbelysningars": "julgransbelysning",
    "julgransbelysningen": "julgransbelysning",
    "julgransbelysningens": "julgransbelysning",
    "julgransbelysnings": "julgransbelysning",
    "julgransfoten": "julgransfot",
    "julgransfotens": "julgransfot",
    "julgransfots": "julgransfot",
    "julgransfötter": "julgransfot",
    "julgransfötterna": "julgransfot",
    "julgransfötternas": "julgransfot",
    "julgransfötters": "julgransfot",
    "julgranskaramellen": "julgranskaramell",
    "julgranskaramellens": "julgranskaramell",
    "julgranskarameller": "julgranskaramell",
    "julgranskaramellerna": "julgranskaramell",
    "julgranskaramellernas": "julgranskaramell",
    "julgranskaramellers": "julgranskaramell",
    "julgranskaramells": "julgranskaramell",
    "julgranskul": "julgranskula",
    "julgranskulan": "julgranskula",
    "julgranskulans": "julgranskula",
    "julgranskulas": "julgranskula",
    "julgranskule": "julgranskula",
    "julgranskulor": "julgranskula",
    "julgranskulorna": "julgranskula",
    "julgranskulornas": "julgranskula",
    "julgranskulors": "julgranskula",
    "julgranskuls": "julgranskula",
    "julgransljusen": "julgransljus",
    "julgransljusens": "julgransljus",
    "julgransljuset": "julgransljus",
    "julgransljusets": "julgransljus",
    "julgransmatt": "julgransmatta",
    "julgransmattan": "julgransmatta",
    "julgransmattans": "julgransmatta",
    "julgransmattas": "julgransmatta",
    "julgransmatte": "julgransmatta",
    "julgransmattor": "julgransmatta",
    "julgransmattorna": "julgransmatta",
    "julgransmattornas": "julgransmatta",
    "julgransmattors": "julgransmatta",
    "julgransmatts": "julgransmatta",
    "julgransplundringar": "julgransplundring",
    "julgransplundringarna": "julgransplundring",
    "julgransplundringarnas": "julgransplundring",
    "julgransplundringars": "julgransplundring",
    "julgransplundringen": "julgransplundring",
    "julgransplundringens": "julgransplundring",
    "julgransplundrings": "julgransplundring",
    "julgransprydnaden": "julgransprydnad",
    "julgransprydnadens": "julgransprydnad",
    "julgransprydnader": "julgransprydnad",
    "julgransprydnaderna": "julgransprydnad",
    "julgransprydnadernas": "julgransprydnad",
    "julgransprydnaders": "julgransprydnad",
    "julgransprydnads": "julgransprydnad",
    "julgrisar": "julgris",
    "julgrisarna": "julgris",
    "julgrisarnas": "julgris",
    "julgrisars": "julgris",
    "julgrisen": "julgris",
    "julgrisens": "julgris",
    "julgruppen": "julgrupp",
    "julgruppens": "julgrupp",
    "julgrupper": "julgrupp",
    "julgrupperna": "julgrupp",
    "julgruppernas": "julgrupp",
    "julgruppers": "julgrupp",
    "julgrupps": "julgrupp",
    "julhandeln": "julhandel",
    "julhandelns": "julhandel",
    "julhandels": "julhandel",
    "julhelgen": "julhelg",
    "julhelgens": "julhelg",
    "julhelger": "julhelg",
    "julhelgerna": "julhelg",
    "julhelgernas": "julhelg",
    "julhelgers": "julhelg",
    "julhelgs": "julhelg",
    "julhysterier": "julhysteri",
    "julhysterierna": "julhysteri",
    "julhysteriernas": "julhysteri",
    "julhysteriers": "julhysteri",
    "julhysteriet": "julhysteri",
    "julhysteriets": "julhysteri",
    "julhysteris": "julhysteri",
    "julhysterit": "julhysteri",
    "julhysterits": "julhysteri",
    "julianska": "juliansk",
    "julianskare": "juliansk",
    "julianskares": "juliansk",
    "julianskas": "juliansk",
    "julianskast": "juliansk",
    "julianskaste": "juliansk",
    "julianskastes": "juliansk",
    "julianskasts": "juliansk",
    "julianske": "juliansk",
    "julianskes": "juliansk",
    "juliansks": "juliansk",
    "julianskt": "juliansk",
    "julianskts": "juliansk",
    "julis": "juli",
    "julkaktusar": "julkaktus",
    "julkaktusarna": "julkaktus",
    "julkaktusarnas": "julkaktus",
    "julkaktusars": "julkaktus",
    "julkaktusen": "julkaktus",
    "julkaktusens": "julkaktus",
    "julkalendern": "julkalender",
    "julkalenderns": "julkalender",
    "julkalenders": "julkalender",
    "julkalendrar": "julkalender",
    "julkalendrarna": "julkalender",
    "julkalendrarnas": "julkalender",
    "julkalendrars": "julkalender",
    "julkass": "julkasse",
    "julkassar": "julkasse",
    "julkassarna": "julkasse",
    "julkassarnas": "julkasse",
    "julkassars": "julkasse",
    "julkassen": "julkasse",
    "julkassens": "julkasse",
    "julkasses": "julkasse",
    "julklappar": "julklapp",
    "julklapparna": "julklapp",
    "julklapparnas": "julklapp",
    "julklappars": "julklapp",
    "julklappen": "julklapp",
    "julklappens": "julklapp",
    "julklapps": "julklapp",
    "julklappstipsen": "julklappstips",
    "julklappstipsens": "julklappstips",
    "julklappstipset": "julklappstips",
    "julklappstipsets": "julklappstips",
    "julkorten": "julkort",
    "julkortens": "julkort",
    "julkortet": "julkort",
    "julkortets": "julkort",
    "julkorts": "julkort",
    "julkrubb": "julkrubba",
    "julkrubban": "julkrubba",
    "julkrubbans": "julkrubba",
    "julkrubbas": "julkrubba",
    "julkrubbe": "julkrubba",
    "julkrubbor": "julkrubba",
    "julkrubborna": "julkrubba",
    "julkrubbornas": "julkrubba",
    "julkrubbors": "julkrubba",
    "julkrubbs": "julkrubba",
    "julkärv": "julkärve",
    "julkärvar": "julkärve",
    "julkärvarna": "julkärve",
    "julkärvarnas": "julkärve",
    "julkärvars": "julkärve",
    "julkärven": "julkärve",
    "julkärvens": "julkärve",
    "julkärves": "julkärve",
    "julkärvs": "julkärve",
    "jull": "julle",
    "jullar": "julle",
    "jullarna": "julle",
    "jullarnas": "julle",
    "jullars": "julle",
    "jullediga": "julledig",
    "julledigare": "julledig",
    "julledigares": "julledig",
    "julledigas": "julledig",
    "julledigast": "julledig",
    "julledigaste": "julledig",
    "julledigastes": "julledig",
    "julledigasts": "julledig",
    "julledige": "julledig",
    "jullediges": "julledig",
    "julledigheten": "julledighet",
    "julledighetens": "julledighet",
    "julledighets": "julledighet",
    "julledigs": "julledig",
    "julledigt": "julledig",
    "julledigts": "julledig",
    "jullen": "julle",
    "jullens": "julle",
    "julles": "julle",
    "julljusen": "julljus",
    "julljusens": "julljus",
    "julljuset": "julljus",
    "julljusets": "julljus",
    "julloven": "jullov",
    "jullovens": "jullov",
    "jullovet": "jullov",
    "jullovets": "jullov",
    "jullovs": "jullov",
    "julls": "julle",
    "jullåtar": "jullåt",
    "jullåtarna": "jullåt",
    "jullåtarnas": "jullåt",
    "jullåtars": "jullåt",
    "jullåten": "jullåt",
    "jullåtens": "jullåt",
    "jullåts": "jullåt",
    "julmotiven": "julmotiv",
    "julmotivens": "julmotiv",
    "julmotivet": "julmotiv",
    "julmotivets": "julmotiv",
    "julmotivs": "julmotiv",
    "julmusten": "julmust",
    "julmustens": "julmust",
    "julmusts": "julmust",
    "julmysen": "julmys",
    "julmysens": "julmys",
    "julmyset": "julmys",
    "julmysets": "julmys",
    "julott": "julotta",
    "julottan": "julotta",
    "julottans": "julotta",
    "julottas": "julotta",
    "julotte": "julotta",
    "julottor": "julotta",
    "julottorna": "julotta",
    "julottornas": "julotta",
    "julottors": "julotta",
    "julotts": "julotta",
    "julpar": "julp",
    "julparna": "julp",
    "julparnas": "julp",
    "julpars": "julp",
    "julpen": "julp",
    "julpens": "julp",
    "julps": "julp",
    "julpynten": "julpynt",
    "julpyntens": "julpynt",
    "julpyntet": "julpynt",
    "julpyntets": "julpynt",
    "julpynts": "julpynt",
    "julrecepten": "julrecept",
    "julreceptens": "julrecept",
    "julreceptet": "julrecept",
    "julreceptets": "julrecept",
    "julrecepts": "julrecept",
    "julrosen": "julros",
    "julrosens": "julros",
    "julrosor": "julros",
    "julrosorna": "julros",
    "julrosornas": "julros",
    "julrosors": "julros",
    "juls": "jul",
    "julshowen": "julshow",
    "julshowens": "julshow",
    "julshower": "julshow",
    "julshowerna": "julshow",
    "julshowernas": "julshow",
    "julshowers": "julshow",
    "julshows": "julshow",
    "julskink": "julskinka",
    "julskinkan": "julskinka",
    "julskinkans": "julskinka",
    "julskinkas": "julskinka",
    "julskinke": "julskinka",
    "julskinkor": "julskinka",
    "julskinkorna": "julskinka",
    "julskinkornas": "julskinka",
    "julskinkors": "julskinka",
    "julskinks": "julskinka",
    "julskyltningar": "julskyltning",
    "julskyltningarna": "julskyltning",
    "julskyltningarnas": "julskyltning",
    "julskyltningars": "julskyltning",
    "julskyltningen": "julskyltning",
    "julskyltningens": "julskyltning",
    "julskyltnings": "julskyltning",
    "julstjärnan": "julstjärna",
    "julstjärnans": "julstjärna",
    "julstjärnas": "julstjärna",
    "julstjärne": "julstjärna",
    "julstjärnor": "julstjärna",
    "julstjärnorna": "julstjärna",
    "julstjärnornas": "julstjärna",
    "julstjärnors": "julstjärna",
    "julstrump": "julstrumpa",
    "julstrumpan": "julstrumpa",
    "julstrumpans": "julstrumpa",
    "julstrumpas": "julstrumpa",
    "julstrumpe": "julstrumpa",
    "julstrumpor": "julstrumpa",
    "julstrumporna": "julstrumpa",
    "julstrumpornas": "julstrumpa",
    "julstrumpors": "julstrumpa",
    "julstrumps": "julstrumpa",
    "julstämningen": "julstämning",
    "julstämningens": "julstämning",
    "julstämnings": "julstämning",
    "julsången": "julsång",
    "julsångens": "julsång",
    "julsånger": "julsång",
    "julsångerna": "julsång",
    "julsångernas": "julsång",
    "julsångers": "julsång",
    "julsångs": "julsång",
    "jultallrikar": "jultallrik",
    "jultallrikarna": "jultallrik",
    "jultallrikarnas": "jultallrik",
    "jultallrikars": "jultallrik",
    "jultallriken": "jultallrik",
    "jultallrikens": "jultallrik",
    "jultallriks": "jultallrik",
    "jultidningar": "jultidning",
    "jultidningarna": "jultidning",
    "jultidningarnas": "jultidning",
    "jultidningars": "jultidning",
    "jultidningen": "jultidning",
    "jultidningens": "jultidning",
    "jultidnings": "jultidning",
    "jultomtar": "jultomte",
    "jultomtarna": "jultomte",
    "jultomtarnas": "jultomte",
    "jultomtars": "jultomte",
    "jultomten": "jultomte",
    "jultomtens": "jultomte",
    "jultomtes": "jultomte",
    "julölet": "julöl",
    "julölets": "julöl",
    "julöls": "julöl",
    "jumbojetar": "jumbojet",
    "jumbojetarna": "jumbojet",
    "jumbojetarnas": "jumbojet",
    "jumbojetars": "jumbojet",
    "jumbojeten": "jumbojet",
    "jumbojetens": "jumbojet",
    "jumbojets": "jumbojet",
    "jumbon": "jumbo",
    "jumbons": "jumbo",
    "jumbor": "jumbo",
    "jumborna": "jumbo",
    "jumbornas": "jumbo",
    "jumbors": "jumbo",
    "jumbos": "jumbo",
    "jump": "jumpa",
    "jumpade": "jumpa",
    "jumpades": "jumpa",
    "jumpan": "jumpa",
    "jumpande": "jumpa",
    "jumpanden": "jumpande",
    "jumpandena": "jumpande",
    "jumpandenas": "jumpande",
    "jumpandens": "jumpande",
    "jumpandes": "jumpande",
    "jumpandet": "jumpande",
    "jumpandets": "jumpande",
    "jumpans": "jumpa",
    "jumpar": "jumpa",
    "jumpas": "jumpa",
    "jumpat": "jumpa",
    "jumpats": "jumpa",
    "jumpern": "jumper",
    "jumperns": "jumper",
    "jumpers": "jumper",
    "jumprar": "jumper",
    "jumprarna": "jumper",
    "jumprarnas": "jumper",
    "jumprars": "jumper",
    "jungfrualstringar": "jungfrualstring",
    "jungfrualstringarna": "jungfrualstring",
    "jungfrualstringarnas": "jungfrualstring",
    "jungfrualstringars": "jungfrualstring",
    "jungfrualstringen": "jungfrualstring",
    "jungfrualstringens": "jungfrualstring",
    "jungfrualstrings": "jungfrualstring",
    "jungfrubenen": "jungfruben",
    "jungfrubenens": "jungfruben",
    "jungfrubenet": "jungfruben",
    "jungfrubenets": "jungfruben",
    "jungfrubens": "jungfruben",
    "jungfrubrösten": "jungfrubröst",
    "jungfrubröstens": "jungfrubröst",
    "jungfrubröstet": "jungfrubröst",
    "jungfrubröstets": "jungfrubröst",
    "jungfrubrösts": "jungfrubröst",
    "jungfruburar": "jungfrubur",
    "jungfruburarna": "jungfrubur",
    "jungfruburarnas": "jungfrubur",
    "jungfruburars": "jungfrubur",
    "jungfruburen": "jungfrubur",
    "jungfruburens": "jungfrubur",
    "jungfruburs": "jungfrubur",
    "jungfrubörden": "jungfrubörd",
    "jungfrubördens": "jungfrubörd",
    "jungfrubörder": "jungfrubörd",
    "jungfrubörderna": "jungfrubörd",
    "jungfrubördernas": "jungfrubörd",
    "jungfrubörders": "jungfrubörd",
    "jungfrubörds": "jungfrubörd",
    "jungfrudomar": "jungfrudom",
    "jungfrudomarna": "jungfrudom",
    "jungfrudomarnas": "jungfrudom",
    "jungfrudomars": "jungfrudom",
    "jungfrudomen": "jungfrudom",
    "jungfrudomens": "jungfrudom",
    "jungfrudoms": "jungfrudom",
    "jungfrufödseln": "jungfrufödsel",
    "jungfrufödselns": "jungfrufödsel",
    "jungfrufödsels": "jungfrufödsel",
    "jungfrufödslar": "jungfrufödsel",
    "jungfrufödslarna": "jungfrufödsel",
    "jungfrufödslarnas": "jungfrufödsel",
    "jungfrufödslars": "jungfrufödsel",
    "jungfrukammar": "jungfrukammare",
    "jungfrukammaren": "jungfrukammare",
    "jungfrukammarens": "jungfrukammare",
    "jungfrukammares": "jungfrukammare",
    "jungfrukamrar": "jungfrukammare",
    "jungfrukamrarna": "jungfrukammare",
    "jungfrukamrarnas": "jungfrukammare",
    "jungfrukamrars": "jungfrukammare",
    "jungfruliga": "jungfrulig",
    "jungfruligare": "jungfrulig",
    "jungfruligares": "jungfrulig",
    "jungfruligas": "jungfrulig",
    "jungfruligast": "jungfrulig",
    "jungfruligaste": "jungfrulig",
    "jungfruligastes": "jungfrulig",
    "jungfruligasts": "jungfrulig",
    "jungfrulige": "jungfrulig",
    "jungfruliges": "jungfrulig",
    "jungfruligheten": "jungfrulighet",
    "jungfrulighetens": "jungfrulighet",
    "jungfrulighets": "jungfrulighet",
    "jungfruligs": "jungfrulig",
    "jungfruligt": "jungfrulig",
    "jungfruligts": "jungfrulig",
    "jungfrulinet": "jungfrulin",
    "jungfrulinets": "jungfrulin",
    "jungfrulins": "jungfrulin",
    "jungfrun": "jungfru",
    "jungfruns": "jungfru",
    "jungfrur": "jungfru",
    "jungfruresan": "jungfruresa",
    "jungfruresans": "jungfruresa",
    "jungfruresas": "jungfruresa",
    "jungfrurese": "jungfruresa",
    "jungfruresor": "jungfruresa",
    "jungfruresorna": "jungfruresa",
    "jungfruresornas": "jungfruresa",
    "jungfruresors": "jungfruresa",
    "jungfrurna": "jungfru",
    "jungfrurnas": "jungfru",
    "jungfrurs": "jungfru",
    "jungfrus": "jungfru",
    "jungfrusländ": "jungfruslända",
    "jungfrusländan": "jungfruslända",
    "jungfrusländans": "jungfruslända",
    "jungfrusländas": "jungfruslända",
    "jungfruslände": "jungfruslända",
    "jungfrusländor": "jungfruslända",
    "jungfrusländorna": "jungfruslända",
    "jungfrusländornas": "jungfruslända",
    "jungfrusländors": "jungfruslända",
    "jungfrusländs": "jungfruslända",
    "jungfrustiften": "jungfrustift",
    "jungfrustiftens": "jungfrustift",
    "jungfrustiftet": "jungfrustift",
    "jungfrustiftets": "jungfrustift",
    "jungfrustifts": "jungfrustift",
    "jungfruståndet": "jungfrustånd",
    "jungfruståndets": "jungfrustånd",
    "jungfrustånds": "jungfrustånd",
    "jungfrusvärmar": "jungfrusvärm",
    "jungfrusvärmarna": "jungfrusvärm",
    "jungfrusvärmarnas": "jungfrusvärm",
    "jungfrusvärmars": "jungfrusvärm",
    "jungfrusvärmen": "jungfrusvärm",
    "jungfrusvärmens": "jungfrusvärm",
    "jungfrusvärms": "jungfrusvärm",
    "jungfrutalen": "jungfrutal",
    "jungfrutalens": "jungfrutal",
    "jungfrutalet": "jungfrutal",
    "jungfrutalets": "jungfrutal",
    "jungfrutals": "jungfrutal",
    "jungfruvaxet": "jungfruvax",
    "jungfruvaxets": "jungfruvax",
    "jungmannen": "jungman",
    "jungmannens": "jungman",
    "jungmans": "jungman",
    "jungmän": "jungman",
    "jungmännen": "jungman",
    "jungmännens": "jungman",
    "jungmäns": "jungman",
    "juniora": "junior",
    "juniorare": "junior",
    "juniorares": "junior",
    "junioras": "junior",
    "juniorast": "junior",
    "junioraste": "junior",
    "juniorastes": "junior",
    "juniorasts": "junior",
    "juniore": "junior",
    "junioren": "junior",
    "juniorens": "junior",
    "juniorer": "junior",
    "juniorerna": "junior",
    "juniorernas": "junior",
    "juniorers": "junior",
    "juniores": "junior",
    "juniormässiga": "juniormässig",
    "juniormässigare": "juniormässig",
    "juniormässigares": "juniormässig",
    "juniormässigas": "juniormässig",
    "juniormässigast": "juniormässig",
    "juniormässigaste": "juniormässig",
    "juniormässigastes": "juniormässig",
    "juniormässigasts": "juniormässig",
    "juniormässige": "juniormässig",
    "juniormässiges": "juniormässig",
    "juniormässigs": "juniormässig",
    "juniormässigt": "juniormässig",
    "juniormässigts": "juniormässig",
    "juniors": "junior",
    "juniort": "junior",
    "juniorts": "junior",
    "junis": "juni",
    "junkern": "junker",
    "junkerns": "junker",
    "junkers": "junker",
    "junkrar": "junker",
    "junkrarna": "junker",
    "junkrarnas": "junker",
    "junkrars": "junker",
    "junoniska": "junonisk",
    "junoniskare": "junonisk",
    "junoniskares": "junonisk",
    "junoniskas": "junonisk",
    "junoniskast": "junonisk",
    "junoniskaste": "junonisk",
    "junoniskastes": "junonisk",
    "junoniskasts": "junonisk",
    "junoniske": "junonisk",
    "junoniskes": "junonisk",
    "junonisks": "junonisk",
    "junoniskt": "junonisk",
    "junoniskts": "junonisk",
    "junt": "junta",
    "juntan": "junta",
    "juntans": "junta",
    "juntas": "junta",
    "junte": "junta",
    "juntor": "junta",
    "juntorna": "junta",
    "juntornas": "junta",
    "juntors": "junta",
    "junts": "junta",
    "juran": "jura",
    "jurans": "jura",
    "juras": "jura",
    "juridiken": "juridik",
    "juridikens": "juridik",
    "juridiks": "juridik",
    "juridiska": "juridisk",
    "juridiskare": "juridisk",
    "juridiskares": "juridisk",
    "juridiskas": "juridisk",
    "juridiskast": "juridisk",
    "juridiskaste": "juridisk",
    "juridiskastes": "juridisk",
    "juridiskasts": "juridisk",
    "juridiske": "juridisk",
    "juridiskes": "juridisk",
    "juridisks": "juridisk",
    "juridiskt": "juridisk",
    "juridiskts": "juridisk",
    "jurisdiktionen": "jurisdiktion",
    "jurisdiktionens": "jurisdiktion",
    "jurisdiktioner": "jurisdiktion",
    "jurisdiktionerna": "jurisdiktion",
    "jurisdiktionernas": "jurisdiktion",
    "jurisdiktioners": "jurisdiktion",
    "jurisdiktions": "jurisdiktion",
    "jurisprudensen": "jurisprudens",
    "jurisprudensens": "jurisprudens",
    "juristen": "jurist",
    "juristens": "jurist",
    "jurister": "jurist",
    "juristerna": "jurist",
    "juristernas": "jurist",
    "juristers": "jurist",
    "jurists": "jurist",
    "jurt": "jurta",
    "jurtan": "jurta",
    "jurtans": "jurta",
    "jurtas": "jurta",
    "jurte": "jurta",
    "jurten": "jurt",
    "jurtens": "jurt",
    "jurtet": "jurt",
    "jurtets": "jurt",
    "jurtor": "jurta",
    "jurtorna": "jurta",
    "jurtornas": "jurta",
    "jurtors": "jurta",
    "jurts": "jurta",
    "juryer": "jury",
    "juryerna": "jury",
    "juryernas": "jury",
    "juryers": "jury",
    "juryn": "jury",
    "juryns": "jury",
    "jurys": "jury",
    "jusen": "jus",
    "jusens": "jus",
    "juser": "jus",
    "juserna": "jus",
    "jusernas": "jus",
    "jusers": "jus",
    "justa": "just",
    "justare": "just",
    "justares": "just",
    "justas": "just",
    "justast": "just",
    "justaste": "just",
    "justastes": "just",
    "justasts": "just",
    "juste": "just",
    "justeheten": "justehet",
    "justehetens": "justehet",
    "justehets": "justehet",
    "justerad": "justera",
    "justerade": "justera",
    "justerades": "justera",
    "justerads": "justera",
    "justerande": "justera",
    "justeranden": "justerande",
    "justerandena": "justerande",
    "justerandenas": "justerande",
    "justerandens": "justerande",
    "justerandes": "justerande",
    "justerandet": "justerande",
    "justerandets": "justerande",
    "justerar": "justerare",
    "justeraren": "justerare",
    "justerarens": "justerare",
    "justerares": "justerare",
    "justerarmar": "justerarm",
    "justerarmarna": "justerarm",
    "justerarmarnas": "justerarm",
    "justerarmars": "justerarm",
    "justerarmen": "justerarm",
    "justerarmens": "justerarm",
    "justerarms": "justerarm",
    "justerarna": "justerare",
    "justerarnas": "justerare",
    "justeras": "justera",
    "justerat": "justera",
    "justerats": "justera",
    "justerbara": "justerbar",
    "justerbaras": "justerbar",
    "justerbare": "justerbar",
    "justerbares": "justerbar",
    "justerbars": "justerbar",
    "justerbart": "justerbar",
    "justerbarts": "justerbar",
    "justeringar": "justering",
    "justeringarna": "justering",
    "justeringarnas": "justering",
    "justeringars": "justering",
    "justeringen": "justering",
    "justeringens": "justering",
    "justerings": "justering",
    "justeringsmannen": "justeringsman",
    "justeringsmannens": "justeringsman",
    "justeringsmans": "justeringsman",
    "justeringsmän": "justeringsman",
    "justeringsmännen": "justeringsman",
    "justeringsmännens": "justeringsman",
    "justeringsmäns": "justeringsman",
    "justeringsmöjligheten": "justeringsmöjlighet",
    "justeringsmöjlighetens": "justeringsmöjlighet",
    "justeringsmöjligheter": "justeringsmöjlighet",
    "justeringsmöjligheterna": "justeringsmöjlighet",
    "justeringsmöjligheternas": "justeringsmöjlighet",
    "justeringsmöjligheters": "justeringsmöjlighet",
    "justeringsmöjlighets": "justeringsmöjlighet",
    "justes": "just",
    "justessen": "justess",
    "justessens": "justess",
    "justheten": "justhet",
    "justhetens": "justhet",
    "justhets": "justhet",
    "justisen": "justis",
    "justisens": "justis",
    "justitiedepartementen": "justitiedepartement",
    "justitiedepartementens": "justitiedepartement",
    "justitiedepartementet": "justitiedepartement",
    "justitiedepartementets": "justitiedepartement",
    "justitiedepartements": "justitiedepartement",
    "justitiekanslern": "justitiekansler",
    "justitiekanslerns": "justitiekansler",
    "justitiekanslers": "justitiekansler",
    "justitieministern": "justitieminister",
    "justitieministerns": "justitieminister",
    "justitieministers": "justitieminister",
    "justitieministrar": "justitieminister",
    "justitieministrarna": "justitieminister",
    "justitieministrarnas": "justitieminister",
    "justitieministrars": "justitieminister",
    "justitiemorden": "justitiemord",
    "justitiemordens": "justitiemord",
    "justitiemordet": "justitiemord",
    "justitiemordets": "justitiemord",
    "justitiemords": "justitiemord",
    "justitieombudsmannen": "justitieombudsman",
    "justitieombudsmannens": "justitieombudsman",
    "justitieombudsmans": "justitieombudsman",
    "justitieombudsmän": "justitieombudsman",
    "justitieombudsmännen": "justitieombudsman",
    "justitieombudsmännens": "justitieombudsman",
    "justitieombudsmäns": "justitieombudsman",
    "justitieråden": "justitieråd",
    "justitierådens": "justitieråd",
    "justitierådet": "justitieråd",
    "justitierådets": "justitieråd",
    "justitieråds": "justitieråd",
    "justitieutskotten": "justitieutskott",
    "justitieutskottens": "justitieutskott",
    "justitieutskottet": "justitieutskott",
    "justitieutskottets": "justitieutskott",
    "justitieutskotts": "justitieutskott",
    "justs": "just",
    "jut": "jute",
    "jutar": "jute",
    "jutarna": "jute",
    "jutarnas": "jute",
    "jutars": "jute",
    "juten": "jute",
    "jutens": "jute",
    "jutes": "jute",
    "jutet": "jute",
    "jutets": "jute",
    "jutländska": "jutländsk",
    "jutländskare": "jutländsk",
    "jutländskares": "jutländsk",
    "jutländskas": "jutländsk",
    "jutländskast": "jutländsk",
    "jutländskaste": "jutländsk",
    "jutländskastes": "jutländsk",
    "jutländskasts": "jutländsk",
    "jutländske": "jutländsk",
    "jutländskes": "jutländsk",
    "jutländsks": "jutländsk",
    "jutländskt": "jutländsk",
    "jutländskts": "jutländsk",
    "juts": "jute",
    "jutska": "jutsk",
    "jutskare": "jutsk",
    "jutskares": "jutsk",
    "jutskas": "jutsk",
    "jutskast": "jutsk",
    "jutskaste": "jutsk",
    "jutskastes": "jutsk",
    "jutskasts": "jutsk",
    "jutske": "jutsk",
    "jutskes": "jutsk",
    "jutskheten": "jutskhet",
    "jutskhetens": "jutskhet",
    "jutskhets": "jutskhet",
    "jutsks": "jutsk",
    "jutskt": "jutsk",
    "jutskts": "jutsk",
    "juvelen": "juvel",
    "juvelens": "juvel",
    "juveler": "juvel",
    "juvelerar": "juvelerare",
    "juveleraraffären": "juveleraraffär",
    "juveleraraffärens": "juveleraraffär",
    "juveleraraffärer": "juveleraraffär",
    "juveleraraffärerna": "juveleraraffär",
    "juveleraraffärernas": "juveleraraffär",
    "juveleraraffärers": "juveleraraffär",
    "juveleraraffärs": "juveleraraffär",
    "juvelerarbutiken": "juvelerarbutik",
    "juvelerarbutikens": "juvelerarbutik",
    "juvelerarbutiker": "juvelerarbutik",
    "juvelerarbutikerna": "juvelerarbutik",
    "juvelerarbutikernas": "juvelerarbutik",
    "juvelerarbutikers": "juvelerarbutik",
    "juvelerarbutiks": "juvelerarbutik",
    "juveleraren": "juvelerare",
    "juvelerarens": "juvelerare",
    "juvelerares": "juvelerare",
    "juvelerarfönsterna": "juvelerarfönster",
    "juvelerarfönsternas": "juvelerarfönster",
    "juvelerarfönsters": "juvelerarfönster",
    "juvelerarfönstren": "juvelerarfönster",
    "juvelerarfönstrens": "juvelerarfönster",
    "juvelerarfönstret": "juvelerarfönster",
    "juvelerarfönstrets": "juvelerarfönster",
    "juvelerarna": "juvelerare",
    "juvelerarnas": "juvelerare",
    "juvelerna": "juvel",
    "juvelernas": "juvel",
    "juvelers": "juvel",
    "juvelornamentiken": "juvelornamentik",
    "juvelornamentikens": "juvelornamentik",
    "juvelornamentiks": "juvelornamentik",
    "juvels": "juvel",
    "juvenila": "juvenil",
    "juvenilare": "juvenil",
    "juvenilares": "juvenil",
    "juvenilas": "juvenil",
    "juvenilast": "juvenil",
    "juvenilaste": "juvenil",
    "juvenilastes": "juvenil",
    "juvenilasts": "juvenil",
    "juvenile": "juvenil",
    "juveniles": "juvenil",
    "juvenils": "juvenil",
    "juvenilt": "juvenil",
    "juvenilts": "juvenil",
    "juverinflammationen": "juverinflammation",
    "juverinflammationens": "juverinflammation",
    "juverinflammationer": "juverinflammation",
    "juverinflammationerna": "juverinflammation",
    "juverinflammationernas": "juverinflammation",
    "juverinflammationers": "juverinflammation",
    "juverinflammations": "juverinflammation",
    "juvermassagen": "juvermassage",
    "juvermassagens": "juvermassage",
    "juvermassages": "juvermassage",
    "juverna": "juver",
    "juvernas": "juver",
    "juvers": "juver",
    "juvervävnaden": "juvervävnad",
    "juvervävnadens": "juvervävnad",
    "juvervävnader": "juvervävnad",
    "juvervävnaderna": "juvervävnad",
    "juvervävnadernas": "juvervävnad",
    "juvervävnaders": "juvervävnad",
    "juvervävnads": "juvervävnad",
    "juvren": "juver",
    "juvrens": "juver",
    "juvret": "juver",
    "juvrets": "juver",
    "juxtapositionen": "juxtaposition",
    "juxtapositionens": "juxtaposition",
    "juxtapositioner": "juxtaposition",
    "juxtapositionerna": "juxtaposition",
    "juxtapositionernas": "juxtaposition",
    "juxtapositioners": "juxtaposition",
    "juxtapositions": "juxtaposition",
    "jyck": "jycke",
    "jyckar": "jycke",
    "jyckarna": "jycke",
    "jyckarnas": "jycke",
    "jyckars": "jycke",
    "jycken": "jycke",
    "jyckens": "jycke",
    "jyckes": "jycke",
    "jycks": "jycke",
    "jylländsk": "jylländska",
    "jylländska": "jylländsk",
    "jylländskan": "jylländska",
    "jylländskans": "jylländska",
    "jylländskare": "jylländsk",
    "jylländskares": "jylländsk",
    "jylländskas": "jylländska",
    "jylländskast": "jylländsk",
    "jylländskaste": "jylländsk",
    "jylländskastes": "jylländsk",
    "jylländskasts": "jylländsk",
    "jylländske": "jylländska",
    "jylländskes": "jylländsk",
    "jylländskor": "jylländska",
    "jylländskorna": "jylländska",
    "jylländskornas": "jylländska",
    "jylländskors": "jylländska",
    "jylländsks": "jylländsk",
    "jylländskt": "jylländsk",
    "jylländskts": "jylländsk",
    "jyllänningar": "jyllänning",
    "jyllänningarna": "jyllänning",
    "jyllänningarnas": "jyllänning",
    "jyllänningars": "jyllänning",
    "jyllänningen": "jyllänning",
    "jyllänningens": "jyllänning",
    "jyllännings": "jyllänning",
    "jympade": "jympa",
    "jympades": "jympa",
    "jympan": "jympa",
    "jympande": "jympa",
    "jympanden": "jympande",
    "jympandena": "jympande",
    "jympandenas": "jympande",
    "jympandens": "jympande",
    "jympandes": "jympande",
    "jympandet": "jympande",
    "jympandets": "jympande",
    "jympans": "jympa",
    "jympar": "jympa",
    "jympas": "jympa",
    "jympat": "jympa",
    "jympats": "jympa",
    "jympingen": "jymping",
    "jympingens": "jymping",
    "jympings": "jymping",
    "jägar": "jägare",
    "jägarbefolkningar": "jägarbefolkning",
    "jägarbefolkningarna": "jägarbefolkning",
    "jägarbefolkningarnas": "jägarbefolkning",
    "jägarbefolkningars": "jägarbefolkning",
    "jägarbefolkningen": "jägarbefolkning",
    "jägarbefolkningens": "jägarbefolkning",
    "jägarbefolknings": "jägarbefolkning",
    "jägarbiffar": "jägarbiff",
    "jägarbiffarna": "jägarbiff",
    "jägarbiffarnas": "jägarbiff",
    "jägarbiffars": "jägarbiff",
    "jägarbiffen": "jägarbiff",
    "jägarbiffens": "jägarbiff",
    "jägarbiffs": "jägarbiff",
    "jägaren": "jägare",
    "jägarens": "jägare",
    "jägares": "jägare",
    "jägarfolken": "jägarfolk",
    "jägarfolkens": "jägarfolk",
    "jägarfolket": "jägarfolk",
    "jägarfolkets": "jägarfolk",
    "jägarfolks": "jägarfolk",
    "jägarförbanden": "jägarförband",
    "jägarförbandens": "jägarförband",
    "jägarförbandet": "jägarförband",
    "jägarförbandets": "jägarförband",
    "jägarförbands": "jägarförband",
    "jägarhattar": "jägarhatt",
    "jägarhattarna": "jägarhatt",
    "jägarhattarnas": "jägarhatt",
    "jägarhattars": "jägarhatt",
    "jägarhatten": "jägarhatt",
    "jägarhattens": "jägarhatt",
    "jägarhatts": "jägarhatt",
    "jägarhornen": "jägarhorn",
    "jägarhornens": "jägarhorn",
    "jägarhornet": "jägarhorn",
    "jägarhornets": "jägarhorn",
    "jägarhorns": "jägarhorn",
    "jägarna": "jägare",
    "jägarnas": "jägare",
    "jägarstenåldern": "jägarstenålder",
    "jägarstenålderns": "jägarstenålder",
    "jägarstenålders": "jägarstenålder",
    "jägmästar": "jägmästare",
    "jägmästaren": "jägmästare",
    "jägmästarens": "jägmästare",
    "jägmästares": "jägmästare",
    "jägmästarna": "jägmästare",
    "jägmästarnas": "jägmästare",
    "jäkeln": "jäkel",
    "jäkelns": "jäkel",
    "jäkels": "jäkel",
    "jäkelskapen": "jäkelskap",
    "jäkelskapens": "jäkelskap",
    "jäkelskaper": "jäkelskap",
    "jäkelskaperna": "jäkelskap",
    "jäkelskapernas": "jäkelskap",
    "jäkelskapers": "jäkelskap",
    "jäkelskapet": "jäkelskap",
    "jäkelskapets": "jäkelskap",
    "jäkelskaps": "jäkelskap",
    "jäklades": "jäklas",
    "jäklar": "jäkel",
    "jäklarna": "jäkel",
    "jäklarnas": "jäkel",
    "jäklars": "jäkel",
    "jäklats": "jäklas",
    "jäkliga": "jäklig",
    "jäkligare": "jäklig",
    "jäkligares": "jäklig",
    "jäkligas": "jäklig",
    "jäkligast": "jäklig",
    "jäkligaste": "jäklig",
    "jäkligastes": "jäklig",
    "jäkligasts": "jäklig",
    "jäklige": "jäklig",
    "jäkliges": "jäklig",
    "jäkligheten": "jäklighet",
    "jäklighetens": "jäklighet",
    "jäkligheter": "jäklighet",
    "jäkligheterna": "jäklighet",
    "jäkligheternas": "jäklighet",
    "jäkligheters": "jäklighet",
    "jäklighets": "jäklighet",
    "jäkligs": "jäklig",
    "jäkligt": "jäklig",
    "jäkligts": "jäklig",
    "jäkt": "jäkta",
    "jäktad": "jäkta",
    "jäktade": "jäktad",
    "jäktades": "jäktad",
    "jäktads": "jäktad",
    "jäktande": "jäkta",
    "jäktanden": "jäktande",
    "jäktandena": "jäktande",
    "jäktandenas": "jäktande",
    "jäktandens": "jäktande",
    "jäktandes": "jäktande",
    "jäktandet": "jäktande",
    "jäktandets": "jäktande",
    "jäktar": "jäkta",
    "jäktas": "jäkta",
    "jäktat": "jäktad",
    "jäktats": "jäktad",
    "jäktet": "jäkt",
    "jäktets": "jäkt",
    "jäktiga": "jäktig",
    "jäktigare": "jäktig",
    "jäktigares": "jäktig",
    "jäktigas": "jäktig",
    "jäktigast": "jäktig",
    "jäktigaste": "jäktig",
    "jäktigastes": "jäktig",
    "jäktigasts": "jäktig",
    "jäktige": "jäktig",
    "jäktiges": "jäktig",
    "jäktigheten": "jäktighet",
    "jäktighetens": "jäktighet",
    "jäktighets": "jäktighet",
    "jäktigs": "jäktig",
    "jäktigt": "jäktig",
    "jäktigts": "jäktig",
    "jäkts": "jäkt",
    "jämbördiga": "jämbördig",
    "jämbördigare": "jämbördig",
    "jämbördigares": "jämbördig",
    "jämbördigas": "jämbördig",
    "jämbördigast": "jämbördig",
    "jämbördigaste": "jämbördig",
    "jämbördigastes": "jämbördig",
    "jämbördigasts": "jämbördig",
    "jämbördige": "jämbördig",
    "jämbördiges": "jämbördig",
    "jämbördigheten": "jämbördighet",
    "jämbördighetens": "jämbördighet",
    "jämbördighets": "jämbördighet",
    "jämbördigs": "jämbördig",
    "jämbördigt": "jämbördig",
    "jämbördigts": "jämbördig",
    "jämför": "jämföra",
    "jämförande": "jämföra",
    "jämföranden": "jämförande",
    "jämförandena": "jämförande",
    "jämförandenas": "jämförande",
    "jämförandens": "jämförande",
    "jämförandes": "jämförande",
    "jämförandet": "jämförande",
    "jämförandets": "jämförande",
    "jämföras": "jämföra",
    "jämförbara": "jämförbar",
    "jämförbarare": "jämförbar",
    "jämförbarares": "jämförbar",
    "jämförbaras": "jämförbar",
    "jämförbarast": "jämförbar",
    "jämförbaraste": "jämförbar",
    "jämförbarastes": "jämförbar",
    "jämförbarasts": "jämförbar",
    "jämförbare": "jämförbar",
    "jämförbares": "jämförbar",
    "jämförbarheten": "jämförbarhet",
    "jämförbarhetens": "jämförbarhet",
    "jämförbarhets": "jämförbarhet",
    "jämförbars": "jämförbar",
    "jämförbart": "jämförbar",
    "jämförbarts": "jämförbar",
    "jämförd": "jämföra",
    "jämförda": "jämföra",
    "jämfördas": "jämföra",
    "jämförde": "jämföra",
    "jämfördes": "jämföra",
    "jämförds": "jämföra",
    "jämförelsen": "jämförelse",
    "jämförelsens": "jämförelse",
    "jämförelser": "jämförelse",
    "jämförelserna": "jämförelse",
    "jämförelsernas": "jämförelse",
    "jämförelsers": "jämförelse",
    "jämförelses": "jämförelse",
    "jämförelsetalen": "jämförelsetal",
    "jämförelsetalens": "jämförelsetal",
    "jämförelsetalet": "jämförelsetal",
    "jämförelsetalets": "jämförelsetal",
    "jämförelsetals": "jämförelsetal",
    "jämförelsetjänsten": "jämförelsetjänst",
    "jämförelsetjänstens": "jämförelsetjänst",
    "jämförelsetjänster": "jämförelsetjänst",
    "jämförelsetjänsterna": "jämförelsetjänst",
    "jämförelsetjänsternas": "jämförelsetjänst",
    "jämförelsetjänsters": "jämförelsetjänst",
    "jämförelsetjänsts": "jämförelsetjänst",
    "jämföres": "jämföra",
    "jämförliga": "jämförlig",
    "jämförligare": "jämförlig",
    "jämförligares": "jämförlig",
    "jämförligas": "jämförlig",
    "jämförligast": "jämförlig",
    "jämförligaste": "jämförlig",
    "jämförligastes": "jämförlig",
    "jämförligasts": "jämförlig",
    "jämförlige": "jämförlig",
    "jämförliges": "jämförlig",
    "jämförligheten": "jämförlighet",
    "jämförlighetens": "jämförlighet",
    "jämförlighets": "jämförlighet",
    "jämförligs": "jämförlig",
    "jämförligt": "jämförlig",
    "jämförligts": "jämförlig",
    "jämförprisen": "jämförpris",
    "jämförprisens": "jämförpris",
    "jämförpriser": "jämförpris",
    "jämförpriserna": "jämförpris",
    "jämförprisernas": "jämförpris",
    "jämförprisers": "jämförpris",
    "jämförpriset": "jämförpris",
    "jämförprisets": "jämförpris",
    "jämförs": "jämföra",
    "jämfört": "jämföra",
    "jämförts": "jämföra",
    "jämgamla": "jämgammal",
    "jämgamlas": "jämgammal",
    "jämgamle": "jämgammal",
    "jämgamles": "jämgammal",
    "jämgammals": "jämgammal",
    "jämgammalt": "jämgammal",
    "jämgammalts": "jämgammal",
    "jämgoda": "jämgod",
    "jämgodare": "jämgod",
    "jämgodares": "jämgod",
    "jämgodas": "jämgod",
    "jämgodast": "jämgod",
    "jämgodaste": "jämgod",
    "jämgodastes": "jämgod",
    "jämgodasts": "jämgod",
    "jämgode": "jämgod",
    "jämgodes": "jämgod",
    "jämgodheten": "jämgodhet",
    "jämgodhetens": "jämgodhet",
    "jämgodhets": "jämgodhet",
    "jämgods": "jämgod",
    "jämgott": "jämgod",
    "jämgotts": "jämgod",
    "jämk": "jämka",
    "jämkad": "jämka",
    "jämkade": "jämka",
    "jämkades": "jämka",
    "jämkads": "jämka",
    "jämkande": "jämka",
    "jämkanden": "jämkande",
    "jämkandena": "jämkande",
    "jämkandenas": "jämkande",
    "jämkandens": "jämkande",
    "jämkandes": "jämkande",
    "jämkandet": "jämkande",
    "jämkandets": "jämkande",
    "jämkar": "jämka",
    "jämkas": "jämka",
    "jämkat": "jämka",
    "jämkats": "jämka",
    "jämkningar": "jämkning",
    "jämkningarna": "jämkning",
    "jämkningarnas": "jämkning",
    "jämkningars": "jämkning",
    "jämkningen": "jämkning",
    "jämkningens": "jämkning",
    "jämknings": "jämkning",
    "jämlik": "jämlike",
    "jämlika": "jämlik",
    "jämlikar": "jämlike",
    "jämlikare": "jämlik",
    "jämlikares": "jämlik",
    "jämlikarna": "jämlike",
    "jämlikarnas": "jämlike",
    "jämlikars": "jämlike",
    "jämlikas": "jämlik",
    "jämlikast": "jämlik",
    "jämlikaste": "jämlik",
    "jämlikastes": "jämlik",
    "jämlikasts": "jämlik",
    "jämlike": "jämlik",
    "jämliken": "jämlike",
    "jämlikens": "jämlike",
    "jämlikes": "jämlike",
    "jämlikheten": "jämlikhet",
    "jämlikhetens": "jämlikhet",
    "jämlikheter": "jämlikhet",
    "jämlikheterna": "jämlikhet",
    "jämlikheternas": "jämlikhet",
    "jämlikheters": "jämlikhet",
    "jämlikhets": "jämlikhet",
    "jämliks": "jämlike",
    "jämlikt": "jämlik",
    "jämlikts": "jämlik",
    "jämmerdalar": "jämmerdal",
    "jämmerdalarna": "jämmerdal",
    "jämmerdalarnas": "jämmerdal",
    "jämmerdalars": "jämmerdal",
    "jämmerdalen": "jämmerdal",
    "jämmerdalens": "jämmerdal",
    "jämmerdals": "jämmerdal",
    "jämmerliga": "jämmerlig",
    "jämmerligare": "jämmerlig",
    "jämmerligares": "jämmerlig",
    "jämmerligas": "jämmerlig",
    "jämmerligast": "jämmerlig",
    "jämmerligaste": "jämmerlig",
    "jämmerligastes": "jämmerlig",
    "jämmerligasts": "jämmerlig",
    "jämmerlige": "jämmerlig",
    "jämmerliges": "jämmerlig",
    "jämmerligheten": "jämmerlighet",
    "jämmerlighetens": "jämmerlighet",
    "jämmerligheter": "jämmerlighet",
    "jämmerligheterna": "jämmerlighet",
    "jämmerligheternas": "jämmerlighet",
    "jämmerligheters": "jämmerlighet",
    "jämmerlighets": "jämmerlighet",
    "jämmerligs": "jämmerlig",
    "jämmerligt": "jämmerlig",
    "jämmerligts": "jämmerlig",
    "jämmerlåten": "jämmerlåt",
    "jämmerlåtens": "jämmerlåt",
    "jämmerlåts": "jämmerlåt",
    "jämmern": "jämmer",
    "jämmerns": "jämmer",
    "jämmers": "jämmer",
    "jämna": "jämn",
    "jämnad": "jämna",
    "jämnade": "jämna",
    "jämnades": "jämna",
    "jämnads": "jämna",
    "jämnande": "jämna",
    "jämnanden": "jämnande",
    "jämnandena": "jämnande",
    "jämnandenas": "jämnande",
    "jämnandens": "jämnande",
    "jämnandes": "jämnande",
    "jämnandet": "jämnande",
    "jämnandets": "jämnande",
    "jämnar": "jämna",
    "jämnare": "jämn",
    "jämnares": "jämn",
    "jämnas": "jämna",
    "jämnast": "jämn",
    "jämnaste": "jämn",
    "jämnastes": "jämn",
    "jämnasts": "jämn",
    "jämnat": "jämna",
    "jämnats": "jämna",
    "jämnbördiga": "jämnbördig",
    "jämnbördigare": "jämnbördig",
    "jämnbördigares": "jämnbördig",
    "jämnbördigas": "jämnbördig",
    "jämnbördigast": "jämnbördig",
    "jämnbördigaste": "jämnbördig",
    "jämnbördigastes": "jämnbördig",
    "jämnbördigasts": "jämnbördig",
    "jämnbördige": "jämnbördig",
    "jämnbördiges": "jämnbördig",
    "jämnbördigs": "jämnbördig",
    "jämnbördigt": "jämnbördig",
    "jämnbördigts": "jämnbördig",
    "jämne": "jämn",
    "jämnes": "jämn",
    "jämngamla": "jämngammal",
    "jämngamlas": "jämngammal",
    "jämngamle": "jämngammal",
    "jämngamles": "jämngammal",
    "jämngammals": "jämngammal",
    "jämngammalt": "jämngammal",
    "jämngammalts": "jämngammal",
    "jämngoda": "jämngod",
    "jämngodare": "jämngod",
    "jämngodares": "jämngod",
    "jämngodas": "jämngod",
    "jämngodast": "jämngod",
    "jämngodaste": "jämngod",
    "jämngodastes": "jämngod",
    "jämngodasts": "jämngod",
    "jämngode": "jämngod",
    "jämngodes": "jämngod",
    "jämngodheten": "jämngodhet",
    "jämngodhetens": "jämngodhet",
    "jämngodhets": "jämngodhet",
    "jämngods": "jämngod",
    "jämngott": "jämngod",
    "jämngotts": "jämngod",
    "jämnheten": "jämnhet",
    "jämnhetens": "jämnhet",
    "jämnhets": "jämnhet",
    "jämnmodet": "jämnmod",
    "jämnmodets": "jämnmod",
    "jämnmods": "jämnmod",
    "jämns": "jämn",
    "jämnslipade": "jämnslipad",
    "jämnslipades": "jämnslipad",
    "jämnslipads": "jämnslipad",
    "jämnslipat": "jämnslipad",
    "jämnslipats": "jämnslipad",
    "jämnstarka": "jämnstark",
    "jämnstarkare": "jämnstark",
    "jämnstarkares": "jämnstark",
    "jämnstarkas": "jämnstark",
    "jämnstarkast": "jämnstark",
    "jämnstarkaste": "jämnstark",
    "jämnstarkastes": "jämnstark",
    "jämnstarkasts": "jämnstark",
    "jämnstarke": "jämnstark",
    "jämnstarkes": "jämnstark",
    "jämnstarkheten": "jämnstarkhet",
    "jämnstarkhetens": "jämnstarkhet",
    "jämnstarkhets": "jämnstarkhet",
    "jämnstarks": "jämnstark",
    "jämnstarkt": "jämnstark",
    "jämnstarkts": "jämnstark",
    "jämnstora": "jämnstor",
    "jämnstorare": "jämnstor",
    "jämnstorares": "jämnstor",
    "jämnstoras": "jämnstor",
    "jämnstorast": "jämnstor",
    "jämnstoraste": "jämnstor",
    "jämnstorastes": "jämnstor",
    "jämnstorasts": "jämnstor",
    "jämnstore": "jämnstor",
    "jämnstores": "jämnstor",
    "jämnstorheten": "jämnstorhet",
    "jämnstorhetens": "jämnstorhet",
    "jämnstorhets": "jämnstorhet",
    "jämnstors": "jämnstor",
    "jämnstort": "jämnstor",
    "jämnstorts": "jämnstor",
    "jämnt": "jämn",
    "jämntjocka": "jämntjock",
    "jämntjockare": "jämntjock",
    "jämntjockares": "jämntjock",
    "jämntjockas": "jämntjock",
    "jämntjockast": "jämntjock",
    "jämntjockaste": "jämntjock",
    "jämntjockastes": "jämntjock",
    "jämntjockasts": "jämntjock",
    "jämntjocke": "jämntjock",
    "jämntjockes": "jämntjock",
    "jämntjockheten": "jämntjockhet",
    "jämntjockhetens": "jämntjockhet",
    "jämntjockhets": "jämntjockhet",
    "jämntjocks": "jämntjock",
    "jämntjockt": "jämntjock",
    "jämntjockts": "jämntjock",
    "jämnts": "jämn",
    "jämnvarma": "jämnvarm",
    "jämnvarmare": "jämnvarm",
    "jämnvarmares": "jämnvarm",
    "jämnvarmas": "jämnvarm",
    "jämnvarmast": "jämnvarm",
    "jämnvarmaste": "jämnvarm",
    "jämnvarmastes": "jämnvarm",
    "jämnvarmasts": "jämnvarm",
    "jämnvarme": "jämnvarm",
    "jämnvarmes": "jämnvarm",
    "jämnvarmheten": "jämnvarmhet",
    "jämnvarmhetens": "jämnvarmhet",
    "jämnvarmhets": "jämnvarmhet",
    "jämnvarms": "jämnvarm",
    "jämnvarmt": "jämnvarm",
    "jämnvarmts": "jämnvarm",
    "jämnåriga": "jämnårig",
    "jämnårigas": "jämnårig",
    "jämnårige": "jämnårig",
    "jämnåriges": "jämnårig",
    "jämnårigheten": "jämnårighet",
    "jämnårighetens": "jämnårighet",
    "jämnårighets": "jämnårighet",
    "jämnårigs": "jämnårig",
    "jämnårigt": "jämnårig",
    "jämnårigts": "jämnårig",
    "jämspelta": "jämspelt",
    "jämspeltare": "jämspelt",
    "jämspeltares": "jämspelt",
    "jämspeltas": "jämspelt",
    "jämspeltast": "jämspelt",
    "jämspeltaste": "jämspelt",
    "jämspeltastes": "jämspelt",
    "jämspeltasts": "jämspelt",
    "jämspelte": "jämspelt",
    "jämspeltes": "jämspelt",
    "jämspeltheten": "jämspelthet",
    "jämspelthetens": "jämspelthet",
    "jämspelthets": "jämspelthet",
    "jämspelts": "jämspelt",
    "jämstarka": "jämstark",
    "jämstarkare": "jämstark",
    "jämstarkares": "jämstark",
    "jämstarkas": "jämstark",
    "jämstarkast": "jämstark",
    "jämstarkaste": "jämstark",
    "jämstarkastes": "jämstark",
    "jämstarkasts": "jämstark",
    "jämstarke": "jämstark",
    "jämstarkes": "jämstark",
    "jämstarkheten": "jämstarkhet",
    "jämstarkhetens": "jämstarkhet",
    "jämstarkhets": "jämstarkhet",
    "jämstarks": "jämstark",
    "jämstarkt": "jämstark",
    "jämstarkts": "jämstark",
    "jämstora": "jämstor",
    "jämstoras": "jämstor",
    "jämstore": "jämstor",
    "jämstores": "jämstor",
    "jämstorheten": "jämstorhet",
    "jämstorhetens": "jämstorhet",
    "jämstorhets": "jämstorhet",
    "jämstors": "jämstor",
    "jämstort": "jämstor",
    "jämstorts": "jämstor",
    "jämställ": "jämställa",
    "jämställande": "jämställa",
    "jämställanden": "jämställande",
    "jämställandena": "jämställande",
    "jämställandenas": "jämställande",
    "jämställandens": "jämställande",
    "jämställandes": "jämställande",
    "jämställandet": "jämställande",
    "jämställandets": "jämställande",
    "jämställas": "jämställa",
    "jämställd": "jämställa",
    "jämställda": "jämställd",
    "jämställdare": "jämställd",
    "jämställdares": "jämställd",
    "jämställdas": "jämställd",
    "jämställdast": "jämställd",
    "jämställdaste": "jämställd",
    "jämställdastes": "jämställd",
    "jämställdasts": "jämställd",
    "jämställde": "jämställd",
    "jämställdes": "jämställd",
    "jämställdheten": "jämställdhet",
    "jämställdhetens": "jämställdhet",
    "jämställdheter": "jämställdhet",
    "jämställdheterna": "jämställdhet",
    "jämställdheternas": "jämställdhet",
    "jämställdheters": "jämställdhet",
    "jämställdhets": "jämställdhet",
    "jämställdhetspolitiken": "jämställdhetspolitik",
    "jämställdhetspolitikens": "jämställdhetspolitik",
    "jämställdhetspolitiks": "jämställdhetspolitik",
    "jämställdhetspolitiska": "jämställdhetspolitisk",
    "jämställdhetspolitiskas": "jämställdhetspolitisk",
    "jämställdhetspolitiske": "jämställdhetspolitisk",
    "jämställdhetspolitiskes": "jämställdhetspolitisk",
    "jämställdhetspolitisks": "jämställdhetspolitisk",
    "jämställdhetspolitiskt": "jämställdhetspolitisk",
    "jämställdhetspolitiskts": "jämställdhetspolitisk",
    "jämställdhetsskilsmässan": "jämställdhetsskilsmässa",
    "jämställdhetsskilsmässans": "jämställdhetsskilsmässa",
    "jämställdhetsskilsmässas": "jämställdhetsskilsmässa",
    "jämställdhetsskilsmässo": "jämställdhetsskilsmässa",
    "jämställdhetsskilsmässor": "jämställdhetsskilsmässa",
    "jämställdhetsskilsmässorna": "jämställdhetsskilsmässa",
    "jämställdhetsskilsmässornas": "jämställdhetsskilsmässa",
    "jämställdhetsskilsmässors": "jämställdhetsskilsmässa",
    "jämställds": "jämställd",
    "jämställer": "jämställa",
    "jämställes": "jämställa",
    "jämställs": "jämställa",
    "jämställt": "jämställd",
    "jämställts": "jämställd",
    "jämt": "jämte",
    "jämtar": "jämte",
    "jämtarna": "jämte",
    "jämtarnas": "jämte",
    "jämtars": "jämte",
    "jämten": "jämte",
    "jämtens": "jämte",
    "jämtes": "jämte",
    "jämthundar": "jämthund",
    "jämthundarna": "jämthund",
    "jämthundarnas": "jämthund",
    "jämthundars": "jämthund",
    "jämthunden": "jämthund",
    "jämthundens": "jämthund",
    "jämthunds": "jämthund",
    "jämtjocka": "jämtjock",
    "jämtjockare": "jämtjock",
    "jämtjockares": "jämtjock",
    "jämtjockas": "jämtjock",
    "jämtjockast": "jämtjock",
    "jämtjockaste": "jämtjock",
    "jämtjockastes": "jämtjock",
    "jämtjockasts": "jämtjock",
    "jämtjocke": "jämtjock",
    "jämtjockes": "jämtjock",
    "jämtjockheten": "jämtjockhet",
    "jämtjockhetens": "jämtjockhet",
    "jämtjockhets": "jämtjockhet",
    "jämtjocks": "jämtjock",
    "jämtjockt": "jämtjock",
    "jämtjockts": "jämtjock",
    "jämtländsk": "jämtländska",
    "jämtländska": "jämtländsk",
    "jämtländskan": "jämtländska",
    "jämtländskans": "jämtländska",
    "jämtländskare": "jämtländsk",
    "jämtländskares": "jämtländsk",
    "jämtländskas": "jämtländska",
    "jämtländskast": "jämtländsk",
    "jämtländskaste": "jämtländsk",
    "jämtländskastes": "jämtländsk",
    "jämtländskasts": "jämtländsk",
    "jämtländske": "jämtländska",
    "jämtländskes": "jämtländsk",
    "jämtländskor": "jämtländska",
    "jämtländskorna": "jämtländska",
    "jämtländskornas": "jämtländska",
    "jämtländskors": "jämtländska",
    "jämtländsks": "jämtländsk",
    "jämtländskt": "jämtländsk",
    "jämtländskts": "jämtländsk",
    "jämtlänningar": "jämtlänning",
    "jämtlänningarna": "jämtlänning",
    "jämtlänningarnas": "jämtlänning",
    "jämtlänningars": "jämtlänning",
    "jämtlänningen": "jämtlänning",
    "jämtlänningens": "jämtlänning",
    "jämtlännings": "jämtlänning",
    "jämts": "jämte",
    "jämtsk": "jämtska",
    "jämtska": "jämtsk",
    "jämtskan": "jämtska",
    "jämtskans": "jämtska",
    "jämtskare": "jämtsk",
    "jämtskares": "jämtsk",
    "jämtskas": "jämtska",
    "jämtskast": "jämtsk",
    "jämtskaste": "jämtsk",
    "jämtskastes": "jämtsk",
    "jämtskasts": "jämtsk",
    "jämtske": "jämtska",
    "jämtskes": "jämtsk",
    "jämtskheten": "jämtskhet",
    "jämtskhetens": "jämtskhet",
    "jämtskhets": "jämtskhet",
    "jämtskor": "jämtska",
    "jämtskorna": "jämtska",
    "jämtskornas": "jämtska",
    "jämtskors": "jämtska",
    "jämtsks": "jämtsk",
    "jämtskt": "jämtsk",
    "jämtskts": "jämtsk",
    "jämvikten": "jämvikt",
    "jämviktens": "jämvikt",
    "jämvikts": "jämvikt",
    "jämviktslägen": "jämviktsläge",
    "jämviktslägena": "jämviktsläge",
    "jämviktslägenas": "jämviktsläge",
    "jämviktslägens": "jämviktsläge",
    "jämviktsläges": "jämviktsläge",
    "jämviktsläget": "jämviktsläge",
    "jämviktslägets": "jämviktsläge",
    "jämviktsorganen": "jämviktsorgan",
    "jämviktsorganens": "jämviktsorgan",
    "jämviktsorganet": "jämviktsorgan",
    "jämviktsorganets": "jämviktsorgan",
    "jämviktsorgans": "jämviktsorgan",
    "jänkar": "jänkare",
    "jänkaren": "jänkare",
    "jänkarens": "jänkare",
    "jänkares": "jänkare",
    "jänkarna": "jänkare",
    "jänkarnas": "jänkare",
    "jänt": "jänta",
    "jäntan": "jänta",
    "jäntans": "jänta",
    "jäntas": "jänta",
    "jänte": "jänta",
    "jäntor": "jänta",
    "jäntorna": "jänta",
    "jäntornas": "jänta",
    "jäntors": "jänta",
    "jänts": "jänta",
    "järnaffären": "järnaffär",
    "järnaffärens": "järnaffär",
    "järnaffärer": "järnaffär",
    "järnaffärerna": "järnaffär",
    "järnaffärernas": "järnaffär",
    "järnaffärers": "järnaffär",
    "järnaffärs": "järnaffär",
    "järnbakterien": "järnbakterie",
    "järnbakteriens": "järnbakterie",
    "järnbakterier": "järnbakterie",
    "järnbakterierna": "järnbakterie",
    "järnbakteriernas": "järnbakterie",
    "järnbakteriers": "järnbakterie",
    "järnbakteries": "järnbakterie",
    "järnbalkar": "järnbalk",
    "järnbalkarna": "järnbalk",
    "järnbalkarnas": "järnbalk",
    "järnbalkars": "järnbalk",
    "järnbalken": "järnbalk",
    "järnbalkens": "järnbalk",
    "järnbalks": "järnbalk",
    "järnbanan": "järnbana",
    "järnbanans": "järnbana",
    "järnbanas": "järnbana",
    "järnbane": "järnbana",
    "järnbanor": "järnbana",
    "järnbanorna": "järnbana",
    "järnbanornas": "järnbana",
    "järnbanors": "järnbana",
    "järnbeslagen": "järnbeslag",
    "järnbeslagens": "järnbeslag",
    "järnbeslaget": "järnbeslag",
    "järnbeslagets": "järnbeslag",
    "järnbeslags": "järnbeslag",
    "järnbetongen": "järnbetong",
    "järnbetongens": "järnbetong",
    "järnbetongs": "järnbetong",
    "järnbladen": "järnblad",
    "järnbladens": "järnblad",
    "järnbladet": "järnblad",
    "järnbladets": "järnblad",
    "järnblads": "järnblad",
    "järnbristen": "järnbrist",
    "järnbristens": "järnbrist",
    "järnbrists": "järnbrist",
    "järnbruken": "järnbruk",
    "järnbrukens": "järnbruk",
    "järnbruket": "järnbruk",
    "järnbrukets": "järnbruk",
    "järnbruks": "järnbruk",
    "järnbröllopen": "järnbröllop",
    "järnbröllopens": "järnbröllop",
    "järnbröllopet": "järnbröllop",
    "järnbröllopets": "järnbröllop",
    "järnbröllops": "järnbröllop",
    "järnbörden": "järnbörd",
    "järnbördens": "järnbörd",
    "järnbörds": "järnbörd",
    "järndörrar": "järndörr",
    "järndörrarna": "järndörr",
    "järndörrarnas": "järndörr",
    "järndörrars": "järndörr",
    "järndörren": "järndörr",
    "järndörrens": "järndörr",
    "järndörrs": "järndörr",
    "järnekar": "järnek",
    "järnekarna": "järnek",
    "järnekarnas": "järnek",
    "järnekars": "järnek",
    "järneken": "järnek",
    "järnekens": "järnek",
    "järnekkransar": "järnekkrans",
    "järnekkransarna": "järnekkrans",
    "järnekkransarnas": "järnekkrans",
    "järnekkransars": "järnekkrans",
    "järnekkransen": "järnekkrans",
    "järnekkransens": "järnekkrans",
    "järneks": "järnek",
    "järnen": "järn",
    "järnens": "järn",
    "järnet": "järn",
    "järnets": "järn",
    "järnframställningar": "järnframställning",
    "järnframställningarna": "järnframställning",
    "järnframställningarnas": "järnframställning",
    "järnframställningars": "järnframställning",
    "järnframställningen": "järnframställning",
    "järnframställningens": "järnframställning",
    "järnframställnings": "järnframställning",
    "järnfysiken": "järnfysik",
    "järnfysikens": "järnfysik",
    "järnfysiks": "järnfysik",
    "järnföremålen": "järnföremål",
    "järnföremålens": "järnföremål",
    "järnföremålet": "järnföremål",
    "järnföremålets": "järnföremål",
    "järnföremåls": "järnföremål",
    "järnglansen": "järnglans",
    "järnglansens": "järnglans",
    "järnglimmern": "järnglimmer",
    "järnglimmerns": "järnglimmer",
    "järnglimmers": "järnglimmer",
    "järngreppen": "järngrepp",
    "järngreppens": "järngrepp",
    "järngreppet": "järngrepp",
    "järngreppets": "järngrepp",
    "järngrepps": "järngrepp",
    "järnhakar": "järnhake",
    "järnhakarna": "järnhake",
    "järnhakarnas": "järnhake",
    "järnhakars": "järnhake",
    "järnhaken": "järnhake",
    "järnhakens": "järnhake",
    "järnhakes": "järnhake",
    "järnhandeln": "järnhandel",
    "järnhandelns": "järnhandel",
    "järnhandels": "järnhandel",
    "järnhanden": "järnhand",
    "järnhandens": "järnhand",
    "järnhandlar": "järnhandel",
    "järnhandlarna": "järnhandel",
    "järnhandlarnas": "järnhandel",
    "järnhandlars": "järnhandel",
    "järnhands": "järnhand",
    "järnhanteringar": "järnhantering",
    "järnhanteringarna": "järnhantering",
    "järnhanteringarnas": "järnhantering",
    "järnhanteringars": "järnhantering",
    "järnhanteringen": "järnhantering",
    "järnhanteringens": "järnhantering",
    "järnhanterings": "järnhantering",
    "järnhällar": "järnhäll",
    "järnhällarna": "järnhäll",
    "järnhällarnas": "järnhäll",
    "järnhällars": "järnhäll",
    "järnhällen": "järnhäll",
    "järnhällens": "järnhäll",
    "järnhälls": "järnhäll",
    "järnhälsan": "järnhälsa",
    "järnhälsans": "järnhälsa",
    "järnhälsas": "järnhälsa",
    "järnhälse": "järnhälsa",
    "järnhälso": "järnhälsa",
    "järnhänder": "järnhand",
    "järnhänderna": "järnhand",
    "järnhändernas": "järnhand",
    "järnhänders": "järnhand",
    "järnhårda": "järnhård",
    "järnhårdare": "järnhård",
    "järnhårdares": "järnhård",
    "järnhårdas": "järnhård",
    "järnhårdast": "järnhård",
    "järnhårdaste": "järnhård",
    "järnhårdastes": "järnhård",
    "järnhårdasts": "järnhård",
    "järnhårde": "järnhård",
    "järnhårdes": "järnhård",
    "järnhårdheten": "järnhårdhet",
    "järnhårdhetens": "järnhårdhet",
    "järnhårdhets": "järnhårdhet",
    "järnhårds": "järnhård",
    "järnhårt": "järnhård",
    "järnhårts": "järnhård",
    "järnindustrien": "järnindustri",
    "järnindustriens": "järnindustri",
    "järnindustrier": "järnindustri",
    "järnindustrierna": "järnindustri",
    "järnindustriernas": "järnindustri",
    "järnindustriers": "järnindustri",
    "järnindustrin": "järnindustri",
    "järnindustrins": "järnindustri",
    "järnindustris": "järnindustri",
    "järnjungfrun": "järnjungfru",
    "järnjungfruns": "järnjungfru",
    "järnjungfrur": "järnjungfru",
    "järnjungfrurna": "järnjungfru",
    "järnjungfrurnas": "järnjungfru",
    "järnjungfrurs": "järnjungfru",
    "järnjungfrus": "järnjungfru",
    "järnkatastrofen": "järnkatastrof",
    "järnkatastrofens": "järnkatastrof",
    "järnkatastrofer": "järnkatastrof",
    "järnkatastroferna": "järnkatastrof",
    "järnkatastrofernas": "järnkatastrof",
    "järnkatastrofers": "järnkatastrof",
    "järnkatastrofs": "järnkatastrof",
    "järnkittet": "järnkitt",
    "järnkittets": "järnkitt",
    "järnkitts": "järnkitt",
    "järnklumpar": "järnklump",
    "järnklumparna": "järnklump",
    "järnklumparnas": "järnklump",
    "järnklumpars": "järnklump",
    "järnklumpen": "järnklump",
    "järnklumpens": "järnklump",
    "järnklumps": "järnklump",
    "järnkollen": "järnkoll",
    "järnkollens": "järnkoll",
    "järnkolls": "järnkoll",
    "järnkorsen": "järnkors",
    "järnkorsens": "järnkors",
    "järnkorset": "järnkors",
    "järnkorsets": "järnkors",
    "järnkärn": "järnkärna",
    "järnkärnan": "järnkärna",
    "järnkärnans": "järnkärna",
    "järnkärnas": "järnkärna",
    "järnkärne": "järnkärna",
    "järnkärnor": "järnkärna",
    "järnkärnorna": "järnkärna",
    "järnkärnornas": "järnkärna",
    "järnkärnors": "järnkärna",
    "järnkärns": "järnkärna",
    "järnlegeringar": "järnlegering",
    "järnlegeringarna": "järnlegering",
    "järnlegeringarnas": "järnlegering",
    "järnlegeringars": "järnlegering",
    "järnlegeringen": "järnlegering",
    "järnlegeringens": "järnlegering",
    "järnlegerings": "järnlegering",
    "järnlung": "järnlunga",
    "järnlungan": "järnlunga",
    "järnlungans": "järnlunga",
    "järnlungas": "järnlunga",
    "järnlunge": "järnlunga",
    "järnlungor": "järnlunga",
    "järnlungorna": "järnlunga",
    "järnlungornas": "järnlunga",
    "järnlungors": "järnlunga",
    "järnlungs": "järnlunga",
    "järnmalmen": "järnmalm",
    "järnmalmens": "järnmalm",
    "järnmalmer": "järnmalm",
    "järnmalmerna": "järnmalm",
    "järnmalmernas": "järnmalm",
    "järnmalmers": "järnmalm",
    "järnmalms": "järnmalm",
    "järnmanufakturen": "järnmanufaktur",
    "järnmanufakturens": "järnmanufaktur",
    "järnmanufakturer": "järnmanufaktur",
    "järnmanufakturerna": "järnmanufaktur",
    "järnmanufakturernas": "järnmanufaktur",
    "järnmanufakturers": "järnmanufaktur",
    "järnmanufakturs": "järnmanufaktur",
    "järnmetallurgien": "järnmetallurgi",
    "järnmetallurgiens": "järnmetallurgi",
    "järnmetallurgin": "järnmetallurgi",
    "järnmetallurgins": "järnmetallurgi",
    "järnmetallurgis": "järnmetallurgi",
    "järnnatn": "järnnatt",
    "järnnatns": "järnnatt",
    "järnnatten": "järnnatt",
    "järnnattens": "järnnatt",
    "järnnatts": "järnnatt",
    "järnnätter": "järnnatt",
    "järnnätterna": "järnnatt",
    "järnnätternas": "järnnatt",
    "järnnätters": "järnnatt",
    "järnockran": "järnockra",
    "järnockrans": "järnockra",
    "järnockras": "järnockra",
    "järnoxiden": "järnoxid",
    "järnoxidens": "järnoxid",
    "järnoxider": "järnoxid",
    "järnoxiderna": "järnoxid",
    "järnoxidernas": "järnoxid",
    "järnoxiders": "järnoxid",
    "järnoxids": "järnoxid",
    "järnpinn": "järnpinne",
    "järnpinnar": "järnpinne",
    "järnpinnarna": "järnpinne",
    "järnpinnarnas": "järnpinne",
    "järnpinnars": "järnpinne",
    "järnpinnen": "järnpinne",
    "järnpinnens": "järnpinne",
    "järnpinnes": "järnpinne",
    "järnpinns": "järnpinne",
    "järnplåtar": "järnplåt",
    "järnplåtarna": "järnplåt",
    "järnplåtarnas": "järnplåt",
    "järnplåtars": "järnplåt",
    "järnplåten": "järnplåt",
    "järnplåtens": "järnplåt",
    "järnplåts": "järnplåt",
    "järnproduktionen": "järnproduktion",
    "järnproduktionens": "järnproduktion",
    "järnproduktioner": "järnproduktion",
    "järnproduktionerna": "järnproduktion",
    "järnproduktionernas": "järnproduktion",
    "järnproduktioners": "järnproduktion",
    "järnproduktions": "järnproduktion",
    "järnpulvers": "järnpulver",
    "järnpulvret": "järnpulver",
    "järnpulvrets": "järnpulver",
    "järnredskapen": "järnredskap",
    "järnredskapens": "järnredskap",
    "järnredskapet": "järnredskap",
    "järnredskapets": "järnredskap",
    "järnredskaps": "järnredskap",
    "järnridåer": "järnridå",
    "järnridåerna": "järnridå",
    "järnridåernas": "järnridå",
    "järnridåers": "järnridå",
    "järnridån": "järnridå",
    "järnridåns": "järnridå",
    "järnridås": "järnridå",
    "järnrika": "järnrik",
    "järnrikare": "järnrik",
    "järnrikares": "järnrik",
    "järnrikas": "järnrik",
    "järnrikast": "järnrik",
    "järnrikaste": "järnrik",
    "järnrikastes": "järnrik",
    "järnrikasts": "järnrik",
    "järnrike": "järnrik",
    "järnrikes": "järnrik",
    "järnrikheten": "järnrikhet",
    "järnrikhetens": "järnrikhet",
    "järnrikhets": "järnrikhet",
    "järnriks": "järnrik",
    "järnrikt": "järnrik",
    "järnrikts": "järnrik",
    "järnringar": "järnring",
    "järnringarna": "järnring",
    "järnringarnas": "järnring",
    "järnringars": "järnring",
    "järnringen": "järnring",
    "järnringens": "järnring",
    "järnrings": "järnring",
    "järnräcken": "järnräcke",
    "järnräckena": "järnräcke",
    "järnräckenas": "järnräcke",
    "järnräckens": "järnräcke",
    "järnräckes": "järnräcke",
    "järnräcket": "järnräcke",
    "järnräckets": "järnräcke",
    "järnrören": "järnrör",
    "järnrörens": "järnrör",
    "järnröret": "järnrör",
    "järnrörets": "järnrör",
    "järnrörs": "järnrör",
    "järns": "järn",
    "järnsalter": "järnsalt",
    "järnsalterna": "järnsalt",
    "järnsalternas": "järnsalt",
    "järnsalters": "järnsalt",
    "järnsaltet": "järnsalt",
    "järnsaltets": "järnsalt",
    "järnsalts": "järnsalt",
    "järnskodd": "järnsko",
    "järnskodda": "järnsko",
    "järnskoddas": "järnsko",
    "järnskodde": "järnsko",
    "järnskoddes": "järnsko",
    "järnskodds": "järnsko",
    "järnskoende": "järnsko",
    "järnskoenden": "järnskoende",
    "järnskoendena": "järnskoende",
    "järnskoendenas": "järnskoende",
    "järnskoendens": "järnskoende",
    "järnskoendes": "järnskoende",
    "järnskoendet": "järnskoende",
    "järnskoendets": "järnskoende",
    "järnskor": "järnsko",
    "järnskos": "järnsko",
    "järnskott": "järnsko",
    "järnskotts": "järnsko",
    "järnskrotet": "järnskrot",
    "järnskrotets": "järnskrot",
    "järnskrots": "järnskrot",
    "järnsmält": "järnsmälta",
    "järnsmältan": "järnsmälta",
    "järnsmältans": "järnsmälta",
    "järnsmältas": "järnsmälta",
    "järnsmälte": "järnsmälta",
    "järnsmältor": "järnsmälta",
    "järnsmältorna": "järnsmälta",
    "järnsmältornas": "järnsmälta",
    "järnsmältors": "järnsmälta",
    "järnsmälts": "järnsmälta",
    "järnsparvar": "järnsparv",
    "järnsparvarna": "järnsparv",
    "järnsparvarnas": "järnsparv",
    "järnsparvars": "järnsparv",
    "järnsparven": "järnsparv",
    "järnsparvens": "järnsparv",
    "järnsparvs": "järnsparv",
    "järnspaten": "järnspat",
    "järnspatens": "järnspat",
    "järnspats": "järnspat",
    "järnspisar": "järnspis",
    "järnspisarna": "järnspis",
    "järnspisarnas": "järnspis",
    "järnspisars": "järnspis",
    "järnspisen": "järnspis",
    "järnspisens": "järnspis",
    "järnstagen": "järnstag",
    "järnstagens": "järnstag",
    "järnstaget": "järnstag",
    "järnstagets": "järnstag",
    "järnstags": "järnstag",
    "järnstaketen": "järnstaket",
    "järnstaketens": "järnstaket",
    "järnstaketet": "järnstaket",
    "järnstaketets": "järnstaket",
    "järnstakets": "järnstaket",
    "järnstycken": "järnstycke",
    "järnstyckena": "järnstycke",
    "järnstyckenas": "järnstycke",
    "järnstyckens": "järnstycke",
    "järnstyckes": "järnstycke",
    "järnstycket": "järnstycke",
    "järnstyckets": "järnstycke",
    "järnstycks": "järnstycke",
    "järnstänger": "järnstång",
    "järnstängerna": "järnstång",
    "järnstängernas": "järnstång",
    "järnstängers": "järnstång",
    "järnstången": "järnstång",
    "järnstångens": "järnstång",
    "järnstångs": "järnstång",
    "järnsulfiden": "järnsulfid",
    "järnsulfidens": "järnsulfid",
    "järnsulfider": "järnsulfid",
    "järnsulfiderna": "järnsulfid",
    "järnsulfidernas": "järnsulfid",
    "järnsulfiders": "järnsulfid",
    "järnsulfids": "järnsulfid",
    "järnsvampen": "järnsvamp",
    "järnsvampens": "järnsvamp",
    "järnsvamps": "järnsvamp",
    "järntillverkningar": "järntillverkning",
    "järntillverkningarna": "järntillverkning",
    "järntillverkningarnas": "järntillverkning",
    "järntillverkningars": "järntillverkning",
    "järntillverkningen": "järntillverkning",
    "järntillverkningens": "järntillverkning",
    "järntillverknings": "järntillverkning",
    "järntrådar": "järntråd",
    "järntrådarna": "järntråd",
    "järntrådarnas": "järntråd",
    "järntrådars": "järntråd",
    "järntråden": "järntråd",
    "järntrådens": "järntråd",
    "järntråds": "järntråd",
    "järnvapens": "järnvapen",
    "järnvapnen": "järnvapen",
    "järnvapnens": "järnvapen",
    "järnvapnet": "järnvapen",
    "järnvapnets": "järnvapen",
    "järnvar": "järnvara",
    "järnvaran": "järnvara",
    "järnvarans": "järnvara",
    "järnvaras": "järnvara",
    "järnvaror": "järnvara",
    "järnvarorna": "järnvara",
    "järnvarornas": "järnvara",
    "järnvarors": "järnvara",
    "järnvaru": "järnvara",
    "järnvaruaffären": "järnvaruaffär",
    "järnvaruaffärens": "järnvaruaffär",
    "järnvaruaffärer": "järnvaruaffär",
    "järnvaruaffärerna": "järnvaruaffär",
    "järnvaruaffärernas": "järnvaruaffär",
    "järnvaruaffärers": "järnvaruaffär",
    "järnvaruaffärs": "järnvaruaffär",
    "järnverken": "järnverk",
    "järnverkens": "järnverk",
    "järnverket": "järnverk",
    "järnverkets": "järnverk",
    "järnverks": "järnverk",
    "järnvitriolen": "järnvitriol",
    "järnvitriolens": "järnvitriol",
    "järnvitriols": "järnvitriol",
    "järnvägar": "järnvägare",
    "järnvägaren": "järnvägare",
    "järnvägarens": "järnvägare",
    "järnvägares": "järnvägare",
    "järnvägarna": "järnvägare",
    "järnvägarnas": "järnvägare",
    "järnvägars": "järnväg",
    "järnvägen": "järnväg",
    "järnvägens": "järnväg",
    "järnvägs": "järnväg",
    "järnvägsbiljetten": "järnvägsbiljett",
    "järnvägsbiljettens": "järnvägsbiljett",
    "järnvägsbiljetter": "järnvägsbiljett",
    "järnvägsbiljetterna": "järnvägsbiljett",
    "järnvägsbiljetternas": "järnvägsbiljett",
    "järnvägsbiljetters": "järnvägsbiljett",
    "järnvägsbiljetts": "järnvägsbiljett",
    "järnvägsbroar": "järnvägsbro",
    "järnvägsbroarna": "järnvägsbro",
    "järnvägsbroarnas": "järnvägsbro",
    "järnvägsbroars": "järnvägsbro",
    "järnvägsbron": "järnvägsbro",
    "järnvägsbrons": "järnvägsbro",
    "järnvägsbros": "järnvägsbro",
    "järnvägsbyggen": "järnvägsbygge",
    "järnvägsbyggena": "järnvägsbygge",
    "järnvägsbyggenas": "järnvägsbygge",
    "järnvägsbyggens": "järnvägsbygge",
    "järnvägsbygges": "järnvägsbygge",
    "järnvägsbygget": "järnvägsbygge",
    "järnvägsbyggets": "järnvägsbygge",
    "järnvägsknutar": "järnvägsknut",
    "järnvägsknutarna": "järnvägsknut",
    "järnvägsknutarnas": "järnvägsknut",
    "järnvägsknutars": "järnvägsknut",
    "järnvägsknuten": "järnvägsknut",
    "järnvägsknutens": "järnvägsknut",
    "järnvägsknuts": "järnvägsknut",
    "järnvägskorsningar": "järnvägskorsning",
    "järnvägskorsningarna": "järnvägskorsning",
    "järnvägskorsningarnas": "järnvägskorsning",
    "järnvägskorsningars": "järnvägskorsning",
    "järnvägskorsningen": "järnvägskorsning",
    "järnvägskorsningens": "järnvägskorsning",
    "järnvägskorsnings": "järnvägskorsning",
    "järnvägslinjen": "järnvägslinje",
    "järnvägslinjens": "järnvägslinje",
    "järnvägslinjer": "järnvägslinje",
    "järnvägslinjerna": "järnvägslinje",
    "järnvägslinjernas": "järnvägslinje",
    "järnvägslinjers": "järnvägslinje",
    "järnvägslinjes": "järnvägslinje",
    "järnvägsrälsar": "järnvägsräls",
    "järnvägsrälsarna": "järnvägsräls",
    "järnvägsrälsarnas": "järnvägsräls",
    "järnvägsrälsars": "järnvägsräls",
    "järnvägsrälsen": "järnvägsräls",
    "järnvägsrälsens": "järnvägsräls",
    "järnvägssignalen": "järnvägssignal",
    "järnvägssignalens": "järnvägssignal",
    "järnvägssignaler": "järnvägssignal",
    "järnvägssignalerna": "järnvägssignal",
    "järnvägssignalernas": "järnvägssignal",
    "järnvägssignalers": "järnvägssignal",
    "järnvägssignals": "järnvägssignal",
    "järnvägsspåren": "järnvägsspår",
    "järnvägsspårens": "järnvägsspår",
    "järnvägsspåret": "järnvägsspår",
    "järnvägsspårets": "järnvägsspår",
    "järnvägsspårs": "järnvägsspår",
    "järnvägsstationen": "järnvägsstation",
    "järnvägsstationens": "järnvägsstation",
    "järnvägsstationer": "järnvägsstation",
    "järnvägsstationerna": "järnvägsstation",
    "järnvägsstationernas": "järnvägsstation",
    "järnvägsstationers": "järnvägsstation",
    "järnvägsstations": "järnvägsstation",
    "järnvägsstrejken": "järnvägsstrejk",
    "järnvägsstrejkens": "järnvägsstrejk",
    "järnvägsstrejker": "järnvägsstrejk",
    "järnvägsstrejkerna": "järnvägsstrejk",
    "järnvägsstrejkernas": "järnvägsstrejk",
    "järnvägsstrejkers": "järnvägsstrejk",
    "järnvägsstrejks": "järnvägsstrejk",
    "järnvägsstängsels": "järnvägsstängsel",
    "järnvägsstängslen": "järnvägsstängsel",
    "järnvägsstängslens": "järnvägsstängsel",
    "järnvägsstängslet": "järnvägsstängsel",
    "järnvägsstängslets": "järnvägsstängsel",
    "järnvägstjänstemannen": "järnvägstjänsteman",
    "järnvägstjänstemannens": "järnvägstjänsteman",
    "järnvägstjänstemans": "järnvägstjänsteman",
    "järnvägstjänstemän": "järnvägstjänsteman",
    "järnvägstjänstemännen": "järnvägstjänsteman",
    "järnvägstjänstemännens": "järnvägstjänsteman",
    "järnvägstjänstemäns": "järnvägstjänsteman",
    "järnvägstrafiken": "järnvägstrafik",
    "järnvägstrafikens": "järnvägstrafik",
    "järnvägstrafiks": "järnvägstrafik",
    "järnvägsvagnar": "järnvägsvagn",
    "järnvägsvagnarna": "järnvägsvagn",
    "järnvägsvagnarnas": "järnvägsvagn",
    "järnvägsvagnars": "järnvägsvagn",
    "järnvägsvagnen": "järnvägsvagn",
    "järnvägsvagnens": "järnvägsvagn",
    "järnvägsvagns": "järnvägsvagn",
    "järnvägsövergångar": "järnvägsövergång",
    "järnvägsövergångarna": "järnvägsövergång",
    "järnvägsövergångarnas": "järnvägsövergång",
    "järnvägsövergångars": "järnvägsövergång",
    "järnvägsövergången": "järnvägsövergång",
    "järnvägsövergångens": "järnvägsövergång",
    "järnvägsövergångs": "järnvägsövergång",
    "järnyx": "järnyxa",
    "järnyxan": "järnyxa",
    "järnyxans": "järnyxa",
    "järnyxas": "järnyxa",
    "järnyxe": "järnyxa",
    "järnyxor": "järnyxa",
    "järnyxorna": "järnyxa",
    "järnyxornas": "järnyxa",
    "järnyxors": "järnyxa",
    "järnåldern": "järnålder",
    "järnålderns": "järnålder",
    "järnålders": "järnålder",
    "järnåldersbond": "järnåldersbonde",
    "järnåldersbonden": "järnåldersbonde",
    "järnåldersbondens": "järnåldersbonde",
    "järnåldersbondes": "järnåldersbonde",
    "järnåldersbonds": "järnåldersbonde",
    "järnåldersbygden": "järnåldersbygd",
    "järnåldersbygdens": "järnåldersbygd",
    "järnåldersbygder": "järnåldersbygd",
    "järnåldersbygderna": "järnåldersbygd",
    "järnåldersbygdernas": "järnåldersbygd",
    "järnåldersbygders": "järnåldersbygd",
    "järnåldersbygds": "järnåldersbygd",
    "järnåldersbönder": "järnåldersbonde",
    "järnåldersbönderna": "järnåldersbonde",
    "järnåldersböndernas": "järnåldersbonde",
    "järnåldersbönders": "järnåldersbonde",
    "järnåldersfiskar": "järnåldersfiskare",
    "järnåldersfiskaren": "järnåldersfiskare",
    "järnåldersfiskarens": "järnåldersfiskare",
    "järnåldersfiskares": "järnåldersfiskare",
    "järnåldersfiskarna": "järnåldersfiskare",
    "järnåldersfiskarnas": "järnåldersfiskare",
    "järnåren": "järnår",
    "järnårens": "järnår",
    "järnåret": "järnår",
    "järnårets": "järnår",
    "järnårs": "järnår",
    "järnörten": "järnört",
    "järnörtens": "järnört",
    "järnörter": "järnört",
    "järnörterna": "järnört",
    "järnörternas": "järnört",
    "järnörters": "järnört",
    "järnörts": "järnört",
    "järp": "järpe",
    "järpar": "järpe",
    "järparna": "järpe",
    "järparnas": "järpe",
    "järpars": "järpe",
    "järpen": "järpe",
    "järpens": "järpe",
    "järpes": "järpe",
    "järps": "järpe",
    "järteckens": "järtecken",
    "järtecknen": "järtecken",
    "järtecknens": "järtecken",
    "järtecknet": "järtecken",
    "järtecknets": "järtecken",
    "järvar": "järv",
    "järvarna": "järv",
    "järvarnas": "järv",
    "järvars": "järv",
    "järven": "järv",
    "järvens": "järv",
    "järvs": "järv",
    "jäs": "jäsa",
    "jäsande": "jäsa",
    "jäsanden": "jäsande",
    "jäsandena": "jäsande",
    "jäsandenas": "jäsande",
    "jäsandens": "jäsande",
    "jäsandes": "jäsande",
    "jäsandet": "jäsande",
    "jäsandets": "jäsande",
    "jäsas": "jäsa",
    "jäser": "jäsa",
    "jäses": "jäsa",
    "jäsfoders": "jäsfoder",
    "jäsfodret": "jäsfoder",
    "jäsfodrets": "jäsfoder",
    "jäsiga": "jäsig",
    "jäsigare": "jäsig",
    "jäsigares": "jäsig",
    "jäsigas": "jäsig",
    "jäsigast": "jäsig",
    "jäsigaste": "jäsig",
    "jäsigastes": "jäsig",
    "jäsigasts": "jäsig",
    "jäsige": "jäsig",
    "jäsiges": "jäsig",
    "jäsigs": "jäsig",
    "jäsigt": "jäsig",
    "jäsigts": "jäsig",
    "jäsningar": "jäsning",
    "jäsningarna": "jäsning",
    "jäsningarnas": "jäsning",
    "jäsningars": "jäsning",
    "jäsningen": "jäsning",
    "jäsningens": "jäsning",
    "jäsnings": "jäsning",
    "jäst": "jäsa",
    "jästa": "jäsa",
    "jästas": "jäsa",
    "jäste": "jäsa",
    "jästen": "jäst",
    "jästens": "jäst",
    "jästes": "jäsa",
    "jästgrumset": "jästgrums",
    "jästgrumsets": "jästgrums",
    "jästs": "jäst",
    "jästsvampar": "jästsvamp",
    "jästsvamparna": "jästsvamp",
    "jästsvamparnas": "jästsvamp",
    "jästsvampars": "jästsvamp",
    "jästsvampen": "jästsvamp",
    "jästsvampens": "jästsvamp",
    "jästsvamps": "jästsvamp",
    "jättar": "jätte",
    "jättarna": "jätte",
    "jättarnas": "jätte",
    "jättars": "jätte",
    "jätteavtalen": "jätteavtal",
    "jätteavtalens": "jätteavtal",
    "jätteavtalet": "jätteavtal",
    "jätteavtalets": "jätteavtal",
    "jätteavtals": "jätteavtal",
    "jättebubbel": "jättebubbla",
    "jättebubblan": "jättebubbla",
    "jättebubblans": "jättebubbla",
    "jättebubblas": "jättebubbla",
    "jättebubble": "jättebubbla",
    "jättebubblor": "jättebubbla",
    "jättebubblorna": "jättebubbla",
    "jättebubblornas": "jättebubbla",
    "jättebubblors": "jättebubbla",
    "jättedumheten": "jättedumhet",
    "jättedumhetens": "jättedumhet",
    "jättedumhets": "jättedumhet",
    "jättedumma": "jättedum",
    "jättedummare": "jättedum",
    "jättedummares": "jättedum",
    "jättedummas": "jättedum",
    "jättedummast": "jättedum",
    "jättedummaste": "jättedum",
    "jättedummastes": "jättedum",
    "jättedummasts": "jättedum",
    "jättedumme": "jättedum",
    "jättedummes": "jättedum",
    "jättedums": "jättedum",
    "jättedumt": "jättedum",
    "jättedumts": "jättedum",
    "jätteexperimenten": "jätteexperiment",
    "jätteexperimentens": "jätteexperiment",
    "jätteexperimentet": "jätteexperiment",
    "jätteexperimentets": "jätteexperiment",
    "jätteexperiments": "jätteexperiment",
    "jättefiaskon": "jättefiasko",
    "jättefiaskona": "jättefiasko",
    "jättefiaskonas": "jättefiasko",
    "jättefiaskons": "jättefiasko",
    "jättefiaskos": "jättefiasko",
    "jättefiaskot": "jättefiasko",
    "jättefiaskots": "jättefiasko",
    "jättefina": "jättefin",
    "jättefinas": "jättefin",
    "jättefine": "jättefin",
    "jättefines": "jättefin",
    "jättefins": "jättefin",
    "jättefint": "jättefin",
    "jättefints": "jättefin",
    "jättefloppar": "jätteflopp",
    "jätteflopparna": "jätteflopp",
    "jätteflopparnas": "jätteflopp",
    "jättefloppars": "jätteflopp",
    "jättefloppen": "jätteflopp",
    "jättefloppens": "jätteflopp",
    "jätteflopps": "jätteflopp",
    "jättegaltar": "jättegalt",
    "jättegaltarna": "jättegalt",
    "jättegaltarnas": "jättegalt",
    "jättegaltars": "jättegalt",
    "jättegalten": "jättegalt",
    "jättegaltens": "jättegalt",
    "jättegalts": "jättegalt",
    "jätteglada": "jätteglad",
    "jättegladare": "jätteglad",
    "jättegladares": "jätteglad",
    "jättegladas": "jätteglad",
    "jättegladast": "jätteglad",
    "jättegladaste": "jätteglad",
    "jättegladastes": "jätteglad",
    "jättegladasts": "jätteglad",
    "jätteglade": "jätteglad",
    "jätteglades": "jätteglad",
    "jätteglads": "jätteglad",
    "jätteglatt": "jätteglad",
    "jätteglatts": "jätteglad",
    "jättegrytan": "jättegryta",
    "jättegrytans": "jättegryta",
    "jättegrytas": "jättegryta",
    "jättegryte": "jättegryta",
    "jättegrytor": "jättegryta",
    "jättegrytorna": "jättegryta",
    "jättegrytornas": "jättegryta",
    "jättegrytors": "jättegryta",
    "jättekasten": "jättekast",
    "jättekastens": "jättekast",
    "jättekastet": "jättekast",
    "jättekastets": "jättekast",
    "jättekasts": "jättekast",
    "jättekliven": "jättekliv",
    "jätteklivens": "jättekliv",
    "jätteklivet": "jättekliv",
    "jätteklivets": "jättekliv",
    "jätteklivs": "jättekliv",
    "jättekloten": "jätteklot",
    "jätteklotens": "jätteklot",
    "jätteklotet": "jätteklot",
    "jätteklotets": "jätteklot",
    "jätteklots": "jätteklot",
    "jättelika": "jättelik",
    "jättelikare": "jättelik",
    "jättelikares": "jättelik",
    "jättelikas": "jättelik",
    "jättelikast": "jättelik",
    "jättelikaste": "jättelik",
    "jättelikastes": "jättelik",
    "jättelikasts": "jättelik",
    "jättelike": "jättelik",
    "jättelikes": "jättelik",
    "jätteliks": "jättelik",
    "jättelikt": "jättelik",
    "jättelikts": "jättelik",
    "jättemolnen": "jättemoln",
    "jättemolnens": "jättemoln",
    "jättemolnet": "jättemoln",
    "jättemolnets": "jättemoln",
    "jättemolns": "jättemoln",
    "jätten": "jätte",
    "jättens": "jätte",
    "jättenöjda": "jättenöjd",
    "jättenöjdare": "jättenöjd",
    "jättenöjdares": "jättenöjd",
    "jättenöjdas": "jättenöjd",
    "jättenöjdast": "jättenöjd",
    "jättenöjdaste": "jättenöjd",
    "jättenöjdastes": "jättenöjd",
    "jättenöjdasts": "jättenöjd",
    "jättenöjde": "jättenöjd",
    "jättenöjdes": "jättenöjd",
    "jättenöjds": "jättenöjd",
    "jättenöjt": "jättenöjd",
    "jättenöjts": "jättenöjd",
    "jätteormar": "jätteorm",
    "jätteormarna": "jätteorm",
    "jätteormarnas": "jätteorm",
    "jätteormars": "jätteorm",
    "jätteormen": "jätteorm",
    "jätteormens": "jätteorm",
    "jätteorms": "jätteorm",
    "jätteplasken": "jätteplask",
    "jätteplaskens": "jätteplask",
    "jätteplasket": "jätteplask",
    "jätteplaskets": "jätteplask",
    "jätteplasks": "jätteplask",
    "jätteroliga": "jätterolig",
    "jätteroligas": "jätterolig",
    "jätterolige": "jätterolig",
    "jätteroliges": "jätterolig",
    "jätteroligs": "jätterolig",
    "jätteroligt": "jätterolig",
    "jätteroligts": "jätterolig",
    "jätterädda": "jätterädd",
    "jätteräddare": "jätterädd",
    "jätteräddares": "jätterädd",
    "jätteräddas": "jätterädd",
    "jätteräddast": "jätterädd",
    "jätteräddaste": "jätterädd",
    "jätteräddastes": "jätterädd",
    "jätteräddasts": "jätterädd",
    "jätterädde": "jätterädd",
    "jätteräddes": "jätterädd",
    "jätterädds": "jätterädd",
    "jätteräden": "jätteräd",
    "jätterädens": "jätteräd",
    "jätteräder": "jätteräd",
    "jätteräderna": "jätteräd",
    "jätterädernas": "jätteräd",
    "jätteräders": "jätteräd",
    "jätteräds": "jätteräd",
    "jättes": "jätte",
    "jätteskrällar": "jätteskräll",
    "jätteskrällarna": "jätteskräll",
    "jätteskrällarnas": "jätteskräll",
    "jätteskrällars": "jätteskräll",
    "jätteskrällen": "jätteskräll",
    "jätteskrällens": "jätteskräll",
    "jätteskrälls": "jätteskräll",
    "jättesnygga": "jättesnygg",
    "jättesnyggare": "jättesnygg",
    "jättesnyggares": "jättesnygg",
    "jättesnyggas": "jättesnygg",
    "jättesnyggast": "jättesnygg",
    "jättesnyggaste": "jättesnygg",
    "jättesnyggastes": "jättesnygg",
    "jättesnyggasts": "jättesnygg",
    "jättesnygge": "jättesnygg",
    "jättesnygges": "jättesnygg",
    "jättesnyggheten": "jättesnygghet",
    "jättesnygghetens": "jättesnygghet",
    "jättesnygghets": "jättesnygghet",
    "jättesnyggs": "jättesnygg",
    "jättesnyggt": "jättesnygg",
    "jättesnyggts": "jättesnygg",
    "jättesnälla": "jättesnäll",
    "jättesnällare": "jättesnäll",
    "jättesnällares": "jättesnäll",
    "jättesnällas": "jättesnäll",
    "jättesnällast": "jättesnäll",
    "jättesnällaste": "jättesnäll",
    "jättesnällastes": "jättesnäll",
    "jättesnällasts": "jättesnäll",
    "jättesnälle": "jättesnäll",
    "jättesnälles": "jättesnäll",
    "jättesnällheten": "jättesnällhet",
    "jättesnällhetens": "jättesnällhet",
    "jättesnällhets": "jättesnällhet",
    "jättesnälls": "jättesnäll",
    "jättesnällt": "jättesnäll",
    "jättesnällts": "jättesnäll",
    "jättespindeln": "jättespindel",
    "jättespindelns": "jättespindel",
    "jättespindels": "jättespindel",
    "jättespindlar": "jättespindel",
    "jättespindlarna": "jättespindel",
    "jättespindlarnas": "jättespindel",
    "jättespindlars": "jättespindel",
    "jättestjärnan": "jättestjärna",
    "jättestjärnans": "jättestjärna",
    "jättestjärnas": "jättestjärna",
    "jättestjärne": "jättestjärna",
    "jättestjärnor": "jättestjärna",
    "jättestjärnorna": "jättestjärna",
    "jättestjärnornas": "jättestjärna",
    "jättestjärnors": "jättestjärna",
    "jättestora": "jättestor",
    "jättestoras": "jättestor",
    "jättestore": "jättestor",
    "jättestores": "jättestor",
    "jättestorheten": "jättestorhet",
    "jättestorhetens": "jättestorhet",
    "jättestorhets": "jättestorhet",
    "jättestors": "jättestor",
    "jättestort": "jättestor",
    "jättestorts": "jättestor",
    "jättesvåra": "jättesvår",
    "jättesvåras": "jättesvår",
    "jättesvåre": "jättesvår",
    "jättesvåres": "jättesvår",
    "jättesvårs": "jättesvår",
    "jättesvårt": "jättesvår",
    "jättesvårts": "jättesvår",
    "jättevalar": "jätteval",
    "jättevalarna": "jätteval",
    "jättevalarnas": "jätteval",
    "jättevalars": "jätteval",
    "jättevalen": "jätteval",
    "jättevalens": "jätteval",
    "jättevals": "jätteval",
    "jätteviktiga": "jätteviktig",
    "jätteviktigas": "jätteviktig",
    "jätteviktige": "jätteviktig",
    "jätteviktiges": "jätteviktig",
    "jätteviktigs": "jätteviktig",
    "jätteviktigt": "jätteviktig",
    "jätteviktigts": "jätteviktig",
    "jätteväxten": "jätteväxt",
    "jätteväxtens": "jätteväxt",
    "jätteväxts": "jätteväxt",
    "jätteödlan": "jätteödla",
    "jätteödlans": "jätteödla",
    "jätteödlas": "jätteödla",
    "jätteödle": "jätteödla",
    "jätteödlor": "jätteödla",
    "jätteödlorna": "jätteödla",
    "jätteödlornas": "jätteödla",
    "jätteödlors": "jätteödla",
    "jättinnan": "jättinna",
    "jättinnans": "jättinna",
    "jättinnas": "jättinna",
    "jättinne": "jättinna",
    "jättinnor": "jättinna",
    "jättinnorna": "jättinna",
    "jättinnornas": "jättinna",
    "jättinnors": "jättinna",
    "jäv": "jäva",
    "jävad": "jäva",
    "jävade": "jäva",
    "jävades": "jäva",
    "jävads": "jäva",
    "jävande": "jäva",
    "jävanden": "jävande",
    "jävandena": "jävande",
    "jävandenas": "jävande",
    "jävandens": "jävande",
    "jävandes": "jävande",
    "jävandet": "jävande",
    "jävandets": "jävande",
    "jävar": "jäva",
    "jävas": "jäva",
    "jävat": "jäva",
    "jävats": "jäva",
    "jäveln": "jävel",
    "jävelns": "jävel",
    "jävels": "jävel",
    "jävelska": "jävelsk",
    "jävelskapen": "jävelskap",
    "jävelskapens": "jävelskap",
    "jävelskaper": "jävelskap",
    "jävelskaperna": "jävelskap",
    "jävelskapernas": "jävelskap",
    "jävelskapers": "jävelskap",
    "jävelskapet": "jävelskap",
    "jävelskapets": "jävelskap",
    "jävelskaps": "jävelskap",
    "jävelskare": "jävelsk",
    "jävelskares": "jävelsk",
    "jävelskas": "jävelsk",
    "jävelskast": "jävelsk",
    "jävelskaste": "jävelsk",
    "jävelskastes": "jävelsk",
    "jävelskasts": "jävelsk",
    "jävelske": "jävelsk",
    "jävelskes": "jävelsk",
    "jävelsks": "jävelsk",
    "jävelskt": "jävelsk",
    "jävelskts": "jävelsk",
    "jävelstygen": "jävelstyg",
    "jävelstygens": "jävelstyg",
    "jävelstyget": "jävelstyg",
    "jävelstygets": "jävelstyg",
    "jävelstygs": "jävelstyg",
    "jäven": "jäv",
    "jävens": "jäv",
    "jävet": "jäv",
    "jävets": "jäv",
    "jäviga": "jävig",
    "jävigare": "jävig",
    "jävigares": "jävig",
    "jävigas": "jävig",
    "jävigast": "jävig",
    "jävigaste": "jävig",
    "jävigastes": "jävig",
    "jävigasts": "jävig",
    "jävige": "jävig",
    "jäviges": "jävig",
    "jävigs": "jävig",
    "jävigt": "jävig",
    "jävigts": "jävig",
    "jävlades": "jävlas",
    "jävlar": "jävel",
    "jävlarna": "jävel",
    "jävlarnas": "jävel",
    "jävlars": "jävel",
    "jävlats": "jävlas",
    "jävliga": "jävlig",
    "jävligare": "jävlig",
    "jävligares": "jävlig",
    "jävligas": "jävlig",
    "jävligast": "jävlig",
    "jävligaste": "jävlig",
    "jävligastes": "jävlig",
    "jävligasts": "jävlig",
    "jävlige": "jävlig",
    "jävliges": "jävlig",
    "jävligheten": "jävlighet",
    "jävlighetens": "jävlighet",
    "jävligheter": "jävlighet",
    "jävligheterna": "jävlighet",
    "jävligheternas": "jävlighet",
    "jävligheters": "jävlighet",
    "jävlighets": "jävlighet",
    "jävligs": "jävlig",
    "jävligt": "jävlig",
    "jävligts": "jävlig",
    "jävs": "jäv",
    "jävulska": "jävulsk",
    "jävulskapen": "jävulskap",
    "jävulskapens": "jävulskap",
    "jävulskaper": "jävulskap",
    "jävulskaperna": "jävulskap",
    "jävulskapernas": "jävulskap",
    "jävulskapers": "jävulskap",
    "jävulskapet": "jävulskap",
    "jävulskapets": "jävulskap",
    "jävulskaps": "jävulskap",
    "jävulskare": "jävulsk",
    "jävulskares": "jävulsk",
    "jävulskas": "jävulsk",
    "jävulskast": "jävulsk",
    "jävulskaste": "jävulsk",
    "jävulskastes": "jävulsk",
    "jävulskasts": "jävulsk",
    "jävulske": "jävulsk",
    "jävulskes": "jävulsk",
    "jävulsks": "jävulsk",
    "jävulskt": "jävulsk",
    "jävulskts": "jävulsk",
    "jävulstygen": "jävulstyg",
    "jävulstygens": "jävulstyg",
    "jävulstyget": "jävulstyg",
    "jävulstygets": "jävulstyg",
    "jävulstygs": "jävulstyg",
    "jåkkar": "jåkk",
    "jåkkarna": "jåkk",
    "jåkkarnas": "jåkk",
    "jåkkars": "jåkk",
    "jåkken": "jåkk",
    "jåkkens": "jåkk",
    "jåkks": "jåkk",
    "jökeln": "jökel",
    "jökelns": "jökel",
    "jökelportar": "jökelport",
    "jökelportarna": "jökelport",
    "jökelportarnas": "jökelport",
    "jökelportars": "jökelport",
    "jökelporten": "jökelport",
    "jökelportens": "jökelport",
    "jökelports": "jökelport",
    "jökels": "jökel",
    "jöklar": "jökel",
    "jöklarna": "jökel",
    "jöklarnas": "jökel",
    "jöklars": "jökel",
    "jönsar": "jöns",
    "jönsarna": "jöns",
    "jönsarnas": "jöns",
    "jönsars": "jöns",
    "jönsen": "jöns",
    "jönsens": "jöns",
    "jönsiga": "jönsig",
    "jönsigare": "jönsig",
    "jönsigares": "jönsig",
    "jönsigas": "jönsig",
    "jönsigast": "jönsig",
    "jönsigaste": "jönsig",
    "jönsigastes": "jönsig",
    "jönsigasts": "jönsig",
    "jönsige": "jönsig",
    "jönsiges": "jönsig",
    "jönsigheten": "jönsighet",
    "jönsighetens": "jönsighet",
    "jönsighets": "jönsighet",
    "jönsigs": "jönsig",
    "jönsigt": "jönsig",
    "jönsigts": "jönsig",
    "jöss": "jösse",
    "jössar": "jösse",
    "jössarna": "jösse",
    "jössarnas": "jösse",
    "jössars": "jösse",
    "jössen": "jösse",
    "jössens": "jösse",
    "jösses": "jösse",
    "k-et": "k",
    "k-ets": "k",
    "k-märkandena": "k-märkande",
    "k-märkandens": "k-märkande",
    "k-märkandes": "k-märkande",
    "k-märkandets": "k-märkande",
    "k-märker": "k-märka",
    "k-märks": "k-märka",
    "k-märkta": "k-märka",
    "k-märkte": "k-märka",
    "k-märkts": "k-märka",
    "k-n": "k",
    "k-na": "k",
    "k-nas": "k",
    "k-ns": "k",
    "k-pistar": "k-pist",
    "k-pistarna": "k-pist",
    "k-pistarnas": "k-pist",
    "k-pistars": "k-pist",
    "k-pisten": "k-pist",
    "k-pistens": "k-pist",
    "k-pists": "k-pist",
    "k-t": "k",
    "k-ts": "k",
    "k:et": "k",
    "k:ets": "k",
    "k:n": "k",
    "k:na": "k",
    "k:nas": "k",
    "k:ns": "k",
    "k:s": "k",
    "k:t": "k",
    "k:ts": "k",
    "kabalen": "kabal",
    "kabalens": "kabal",
    "kabaler": "kabal",
    "kabalerna": "kabal",
    "kabalernas": "kabal",
    "kabalers": "kabal",
    "kabals": "kabal",
    "kabaréer": "kabaré",
    "kabaréerna": "kabaré",
    "kabaréernas": "kabaré",
    "kabaréers": "kabaré",
    "kabarén": "kabaré",
    "kabaréns": "kabaré",
    "kabaréorkestern": "kabaréorkester",
    "kabaréorkesterns": "kabaréorkester",
    "kabaréorkesters": "kabaréorkester",
    "kabaréorkestrar": "kabaréorkester",
    "kabaréorkestrarna": "kabaréorkester",
    "kabaréorkestrarnas": "kabaréorkester",
    "kabaréorkestrars": "kabaréorkester",
    "kabarés": "kabaré",
    "kabbalan": "kabbala",
    "kabbalans": "kabbala",
    "kabbalas": "kabbala",
    "kabbalismen": "kabbalism",
    "kabbalismens": "kabbalism",
    "kabbalismer": "kabbalism",
    "kabbalismerna": "kabbalism",
    "kabbalismernas": "kabbalism",
    "kabbalismers": "kabbalism",
    "kabbalisms": "kabbalism",
    "kabbalisten": "kabbalist",
    "kabbalistens": "kabbalist",
    "kabbalister": "kabbalist",
    "kabbalisterna": "kabbalist",
    "kabbalisternas": "kabbalist",
    "kabbalisters": "kabbalist",
    "kabbalistiska": "kabbalistisk",
    "kabbalistiskas": "kabbalistisk",
    "kabbalistiske": "kabbalistisk",
    "kabbalistiskes": "kabbalistisk",
    "kabbalistisks": "kabbalistisk",
    "kabbalistiskt": "kabbalistisk",
    "kabbalistiskts": "kabbalistisk",
    "kabbalists": "kabbalist",
    "kabbelekan": "kabbeleka",
    "kabbelekans": "kabbeleka",
    "kabbelekas": "kabbeleka",
    "kabbeleke": "kabbeleka",
    "kabbelekor": "kabbeleka",
    "kabbelekorna": "kabbeleka",
    "kabbelekornas": "kabbeleka",
    "kabbelekors": "kabbeleka",
    "kabblekan": "kabbleka",
    "kabblekans": "kabbleka",
    "kabblekas": "kabbleka",
    "kabbleke": "kabbleka",
    "kabblekor": "kabbleka",
    "kabblekorna": "kabbleka",
    "kabblekornas": "kabbleka",
    "kabblekors": "kabbleka",
    "kabel": "kabla",
    "kabel-TVs": "kabel-TV",
    "kabel-teves": "kabel-teve",
    "kabel-tv-s": "kabel-tv",
    "kabel-tv:s": "kabel-tv",
    "kabelbroar": "kabelbro",
    "kabelbroarna": "kabelbro",
    "kabelbroarnas": "kabelbro",
    "kabelbroars": "kabelbro",
    "kabelbron": "kabelbro",
    "kabelbrons": "kabelbro",
    "kabelbros": "kabelbro",
    "kabelbrunnar": "kabelbrunn",
    "kabelbrunnarna": "kabelbrunn",
    "kabelbrunnarnas": "kabelbrunn",
    "kabelbrunnars": "kabelbrunn",
    "kabelbrunnen": "kabelbrunn",
    "kabelbrunnens": "kabelbrunn",
    "kabelbrunns": "kabelbrunn",
    "kabelfäst": "kabelfäste",
    "kabelfästen": "kabelfäste",
    "kabelfästena": "kabelfäste",
    "kabelfästenas": "kabelfäste",
    "kabelfästens": "kabelfäste",
    "kabelfästes": "kabelfäste",
    "kabelfästet": "kabelfäste",
    "kabelfästets": "kabelfäste",
    "kabelgatten": "kabelgatt",
    "kabelgattens": "kabelgatt",
    "kabelgattet": "kabelgatt",
    "kabelgattets": "kabelgatt",
    "kabelgatts": "kabelgatt",
    "kabelgenomföringar": "kabelgenomföring",
    "kabelgenomföringarna": "kabelgenomföring",
    "kabelgenomföringarnas": "kabelgenomföring",
    "kabelgenomföringars": "kabelgenomföring",
    "kabelgenomföringen": "kabelgenomföring",
    "kabelgenomföringens": "kabelgenomföring",
    "kabelgenomförings": "kabelgenomföring",
    "kabelhöljen": "kabelhölje",
    "kabelhöljena": "kabelhölje",
    "kabelhöljenas": "kabelhölje",
    "kabelhöljens": "kabelhölje",
    "kabelhöljes": "kabelhölje",
    "kabelhöljet": "kabelhölje",
    "kabelhöljets": "kabelhölje",
    "kabelhöljs": "kabelhölje",
    "kabeljon": "kabeljo",
    "kabeljons": "kabeljo",
    "kabeljos": "kabeljo",
    "kabellängden": "kabellängd",
    "kabellängdens": "kabellängd",
    "kabellängder": "kabellängd",
    "kabellängderna": "kabellängd",
    "kabellängdernas": "kabellängd",
    "kabellängders": "kabellängd",
    "kabellängds": "kabellängd",
    "kabeln": "kabel",
    "kabelns": "kabel",
    "kabels": "kabel",
    "kabelskon": "kabelsko",
    "kabelskons": "kabelsko",
    "kabelskor": "kabelsko",
    "kabelskorna": "kabelsko",
    "kabelskornas": "kabelsko",
    "kabelskors": "kabelsko",
    "kabelskos": "kabelsko",
    "kabelskotänger": "kabelskotång",
    "kabelskotängerna": "kabelskotång",
    "kabelskotängernas": "kabelskotång",
    "kabelskotängers": "kabelskotång",
    "kabelskotången": "kabelskotång",
    "kabelskotångens": "kabelskotång",
    "kabelskotångs": "kabelskotång",
    "kabelskåpen": "kabelskåp",
    "kabelskåpens": "kabelskåp",
    "kabelskåpet": "kabelskåp",
    "kabelskåpets": "kabelskåp",
    "kabelskåps": "kabelskåp",
    "kabelslagens": "kabelslagen",
    "kabelslaget": "kabelslagen",
    "kabelslagets": "kabelslagen",
    "kabelslagna": "kabelslagen",
    "kabelslagnare": "kabelslagen",
    "kabelslagnares": "kabelslagen",
    "kabelslagnas": "kabelslagen",
    "kabelslagnast": "kabelslagen",
    "kabelslagnaste": "kabelslagen",
    "kabelslagnastes": "kabelslagen",
    "kabelslagnasts": "kabelslagen",
    "kabelslagne": "kabelslagen",
    "kabelslagnes": "kabelslagen",
    "kabelteves": "kabelteve",
    "kabelvind": "kabelvinda",
    "kabelvindan": "kabelvinda",
    "kabelvindans": "kabelvinda",
    "kabelvindas": "kabelvinda",
    "kabelvinde": "kabelvinda",
    "kabelvindor": "kabelvinda",
    "kabelvindorna": "kabelvinda",
    "kabelvindornas": "kabelvinda",
    "kabelvindors": "kabelvinda",
    "kabelvinds": "kabelvinda",
    "kabinbåtar": "kabinbåt",
    "kabinbåtarna": "kabinbåt",
    "kabinbåtarnas": "kabinbåt",
    "kabinbåtars": "kabinbåt",
    "kabinbåten": "kabinbåt",
    "kabinbåtens": "kabinbåt",
    "kabinbåts": "kabinbåt",
    "kabinen": "kabin",
    "kabinens": "kabin",
    "kabiner": "kabin",
    "kabinerna": "kabin",
    "kabinernas": "kabin",
    "kabiners": "kabin",
    "kabinetten": "kabinett",
    "kabinettens": "kabinett",
    "kabinettet": "kabinett",
    "kabinettets": "kabinett",
    "kabinetts": "kabinett",
    "kabinettsformaten": "kabinettsformat",
    "kabinettsformatens": "kabinettsformat",
    "kabinettsformatet": "kabinettsformat",
    "kabinettsformatets": "kabinettsformat",
    "kabinettsformats": "kabinettsformat",
    "kabinettsfrågan": "kabinettsfråga",
    "kabinettsfrågans": "kabinettsfråga",
    "kabinettsfrågas": "kabinettsfråga",
    "kabinettsfråge": "kabinettsfråga",
    "kabinettsfrågor": "kabinettsfråga",
    "kabinettsfrågorna": "kabinettsfråga",
    "kabinettsfrågornas": "kabinettsfråga",
    "kabinettsfrågors": "kabinettsfråga",
    "kabinettskorten": "kabinettskort",
    "kabinettskortens": "kabinettskort",
    "kabinettskortet": "kabinettskort",
    "kabinettskortets": "kabinettskort",
    "kabinettskorts": "kabinettskort",
    "kabinettsordern": "kabinettsorder",
    "kabinettsorderna": "kabinettsorder",
    "kabinettsordernas": "kabinettsorder",
    "kabinettsorderns": "kabinettsorder",
    "kabinettsorders": "kabinettsorder",
    "kabinettsordrar": "kabinettsorder",
    "kabinettsordrarna": "kabinettsorder",
    "kabinettsordrarnas": "kabinettsorder",
    "kabinettsordrars": "kabinettsorder",
    "kabinettspassen": "kabinettspass",
    "kabinettspassens": "kabinettspass",
    "kabinettspasset": "kabinettspass",
    "kabinettspassets": "kabinettspass",
    "kabinettspolitiken": "kabinettspolitik",
    "kabinettspolitikens": "kabinettspolitik",
    "kabinettspolitiks": "kabinettspolitik",
    "kabinettssekreterar": "kabinettssekreterare",
    "kabinettssekreteraren": "kabinettssekreterare",
    "kabinettssekreterarens": "kabinettssekreterare",
    "kabinettssekreterares": "kabinettssekreterare",
    "kabinettssekreterarna": "kabinettssekreterare",
    "kabinettssekreterarnas": "kabinettssekreterare",
    "kabinpersonalen": "kabinpersonal",
    "kabinpersonalens": "kabinpersonal",
    "kabinpersonals": "kabinpersonal",
    "kabins": "kabin",
    "kabintrycket": "kabintryck",
    "kabintryckets": "kabintryck",
    "kabintrycks": "kabintryck",
    "kabinväsk": "kabinväska",
    "kabinväskan": "kabinväska",
    "kabinväskans": "kabinväska",
    "kabinväskas": "kabinväska",
    "kabinväske": "kabinväska",
    "kabinväskor": "kabinväska",
    "kabinväskorna": "kabinväska",
    "kabinväskornas": "kabinväska",
    "kabinväskors": "kabinväska",
    "kablad": "kabla",
    "kablade": "kabla",
    "kablades": "kabla",
    "kablads": "kabla",
    "kablande": "kabla",
    "kablanden": "kablande",
    "kablandena": "kablande",
    "kablandenas": "kablande",
    "kablandens": "kablande",
    "kablandes": "kablande",
    "kablandet": "kablande",
    "kablandets": "kablande",
    "kablar": "kabla",
    "kablarna": "kabel",
    "kablarnas": "kabel",
    "kablars": "kabel",
    "kablas": "kabla",
    "kablat": "kabla",
    "kablats": "kabla",
    "kabylen": "kabyl",
    "kabylens": "kabyl",
    "kabyler": "kabyl",
    "kabylerna": "kabyl",
    "kabylernas": "kabyl",
    "kabylers": "kabyl",
    "kabyliska": "kabylisk",
    "kabyliskare": "kabylisk",
    "kabyliskares": "kabylisk",
    "kabyliskas": "kabylisk",
    "kabyliskast": "kabylisk",
    "kabyliskaste": "kabylisk",
    "kabyliskastes": "kabylisk",
    "kabyliskasts": "kabylisk",
    "kabyliske": "kabylisk",
    "kabyliskes": "kabylisk",
    "kabylisks": "kabylisk",
    "kabyliskt": "kabylisk",
    "kabyliskts": "kabylisk",
    "kabyls": "kabyl",
    "kabyssen": "kabyss",
    "kabyssens": "kabyss",
    "kabysser": "kabyss",
    "kabysserna": "kabyss",
    "kabyssernas": "kabyss",
    "kabyssers": "kabyss",
    "kack": "kacka",
    "kackade": "kacka",
    "kackades": "kacka",
    "kackalorumet": "kackalorum",
    "kackalorumets": "kackalorum",
    "kackalorums": "kackalorum",
    "kackande": "kacka",
    "kackanden": "kackande",
    "kackandena": "kackande",
    "kackandenas": "kackande",
    "kackandens": "kackande",
    "kackandes": "kackande",
    "kackandet": "kackande",
    "kackandets": "kackande",
    "kackar": "kacka",
    "kackas": "kacka",
    "kackat": "kacka",
    "kackats": "kacka",
    "kackel": "kackla",
    "kackels": "kackel",
    "kackerlack": "kackerlacka",
    "kackerlackan": "kackerlacka",
    "kackerlackans": "kackerlacka",
    "kackerlackas": "kackerlacka",
    "kackerlacke": "kackerlacka",
    "kackerlackor": "kackerlacka",
    "kackerlackorna": "kackerlacka",
    "kackerlackornas": "kackerlacka",
    "kackerlackors": "kackerlacka",
    "kackerlacks": "kackerlacka",
    "kacklade": "kackla",
    "kacklades": "kackla",
    "kacklande": "kackla",
    "kacklanden": "kacklande",
    "kacklandena": "kacklande",
    "kacklandenas": "kacklande",
    "kacklandens": "kacklande",
    "kacklandes": "kacklande",
    "kacklandet": "kacklande",
    "kacklandets": "kacklande",
    "kacklar": "kackla",
    "kacklas": "kackla",
    "kacklat": "kackla",
    "kacklats": "kackla",
    "kacklet": "kackel",
    "kacklets": "kackel",
    "kadaverdisciplinen": "kadaverdisciplin",
    "kadaverdisciplinens": "kadaverdisciplin",
    "kadaverdisciplins": "kadaverdisciplin",
    "kadaverlydnaden": "kadaverlydnad",
    "kadaverlydnadens": "kadaverlydnad",
    "kadaverlydnader": "kadaverlydnad",
    "kadaverlydnaderna": "kadaverlydnad",
    "kadaverlydnadernas": "kadaverlydnad",
    "kadaverlydnaders": "kadaverlydnad",
    "kadaverlydnads": "kadaverlydnad",
    "kadaverna": "kadaver",
    "kadavernas": "kadaver",
    "kadavers": "kadaver",
    "kadavren": "kadaver",
    "kadavrens": "kadaver",
    "kadavret": "kadaver",
    "kadavrets": "kadaver",
    "kadensen": "kadens",
    "kadensens": "kadens",
    "kadenser": "kadens",
    "kadenserna": "kadens",
    "kadensernas": "kadens",
    "kadensers": "kadens",
    "kadern": "kader",
    "kaderns": "kader",
    "kaders": "kader",
    "kadersystemen": "kadersystem",
    "kadersystemens": "kadersystem",
    "kadersystemet": "kadersystem",
    "kadersystemets": "kadersystem",
    "kadersystems": "kadersystem",
    "kaderövningar": "kaderövning",
    "kaderövningarna": "kaderövning",
    "kaderövningarnas": "kaderövning",
    "kaderövningars": "kaderövning",
    "kaderövningen": "kaderövning",
    "kaderövningens": "kaderövning",
    "kaderövnings": "kaderövning",
    "kadetten": "kadett",
    "kadettens": "kadett",
    "kadetter": "kadett",
    "kadetterna": "kadett",
    "kadetternas": "kadett",
    "kadetters": "kadett",
    "kadettfartygen": "kadettfartyg",
    "kadettfartygens": "kadettfartyg",
    "kadettfartyget": "kadettfartyg",
    "kadettfartygets": "kadettfartyg",
    "kadettfartygs": "kadettfartyg",
    "kadettkåren": "kadettkår",
    "kadettkårens": "kadettkår",
    "kadettkårer": "kadettkår",
    "kadettkårerna": "kadettkår",
    "kadettkårernas": "kadettkår",
    "kadettkårers": "kadettkår",
    "kadettkårs": "kadettkår",
    "kadetts": "kadett",
    "kadettyget": "kadettyg",
    "kadettygets": "kadettyg",
    "kadettygs": "kadettyg",
    "kadier": "kadi",
    "kadierna": "kadi",
    "kadiernas": "kadi",
    "kadiers": "kadi",
    "kadin": "kadi",
    "kadins": "kadi",
    "kadis": "kadi",
    "kadmiet": "kadmium",
    "kadmiets": "kadmium",
    "kadmiumet": "kadmium",
    "kadmiumets": "kadmium",
    "kadmiumgula": "kadmiumgul",
    "kadmiumgulare": "kadmiumgul",
    "kadmiumgulares": "kadmiumgul",
    "kadmiumgulas": "kadmiumgul",
    "kadmiumgulast": "kadmiumgul",
    "kadmiumgulaste": "kadmiumgul",
    "kadmiumgulastes": "kadmiumgul",
    "kadmiumgulasts": "kadmiumgul",
    "kadmiumgule": "kadmiumgul",
    "kadmiumgules": "kadmiumgul",
    "kadmiumguls": "kadmiumgul",
    "kadmiumgult": "kadmiumgul",
    "kadmiumgults": "kadmiumgult",
    "kadmiumjonen": "kadmiumjon",
    "kadmiumjonens": "kadmiumjon",
    "kadmiumjoner": "kadmiumjon",
    "kadmiumjonerna": "kadmiumjon",
    "kadmiumjonernas": "kadmiumjon",
    "kadmiumjoners": "kadmiumjon",
    "kadmiumjons": "kadmiumjon",
    "kadmiumrötts": "kadmiumrött",
    "kadmiums": "kadmium",
    "kadrar": "kader",
    "kadrarna": "kader",
    "kadrarnas": "kader",
    "kadrars": "kader",
    "kadrer": "kader",
    "kadrerna": "kader",
    "kadrernas": "kader",
    "kadrers": "kader",
    "kadriljen": "kadrilj",
    "kadriljens": "kadrilj",
    "kadriljer": "kadrilj",
    "kadriljerna": "kadrilj",
    "kadriljernas": "kadrilj",
    "kadriljers": "kadrilj",
    "kadriljs": "kadrilj",
    "kafeer": "kafe",
    "kafeerna": "kafe",
    "kafeernas": "kafe",
    "kafeers": "kafe",
    "kafeet": "kafe",
    "kafeets": "kafe",
    "kafes": "kafe",
    "kafet": "kafe",
    "kafeteri": "kafeteria",
    "kafeterian": "kafeteria",
    "kafeterians": "kafeteria",
    "kafeterias": "kafeteria",
    "kafeterie": "kafeteria",
    "kafeterior": "kafeteria",
    "kafeteriorna": "kafeteria",
    "kafeteriornas": "kafeteria",
    "kafeteriors": "kafeteria",
    "kafeteris": "kafeteria",
    "kafets": "kafe",
    "kaffeautomaten": "kaffeautomat",
    "kaffeautomatens": "kaffeautomat",
    "kaffeautomater": "kaffeautomat",
    "kaffeautomaterna": "kaffeautomat",
    "kaffeautomaternas": "kaffeautomat",
    "kaffeautomaters": "kaffeautomat",
    "kaffeautomats": "kaffeautomat",
    "kaffebalar": "kaffebal",
    "kaffebalarna": "kaffebal",
    "kaffebalarnas": "kaffebal",
    "kaffebalars": "kaffebal",
    "kaffebalen": "kaffebal",
    "kaffebalens": "kaffebal",
    "kaffebals": "kaffebal",
    "kaffeborden": "kaffebord",
    "kaffebordens": "kaffebord",
    "kaffebordet": "kaffebord",
    "kaffebordets": "kaffebord",
    "kaffebords": "kaffebord",
    "kaffebrick": "kaffebricka",
    "kaffebrickan": "kaffebricka",
    "kaffebrickans": "kaffebricka",
    "kaffebrickas": "kaffebricka",
    "kaffebricke": "kaffebricka",
    "kaffebrickor": "kaffebricka",
    "kaffebrickorna": "kaffebricka",
    "kaffebrickornas": "kaffebricka",
    "kaffebrickors": "kaffebricka",
    "kaffebricks": "kaffebricka",
    "kaffebruna": "kaffebrun",
    "kaffebrunare": "kaffebrun",
    "kaffebrunares": "kaffebrun",
    "kaffebrunas": "kaffebrun",
    "kaffebrunast": "kaffebrun",
    "kaffebrunaste": "kaffebrun",
    "kaffebrunastes": "kaffebrun",
    "kaffebrunasts": "kaffebrun",
    "kaffebrune": "kaffebrun",
    "kaffebrunes": "kaffebrun",
    "kaffebruns": "kaffebrun",
    "kaffebrunt": "kaffebrun",
    "kaffebrunts": "kaffebrun",
    "kaffebryggar": "kaffebryggare",
    "kaffebryggaren": "kaffebryggare",
    "kaffebryggarens": "kaffebryggare",
    "kaffebryggares": "kaffebryggare",
    "kaffebryggarna": "kaffebryggare",
    "kaffebryggarnas": "kaffebryggare",
    "kaffebrödet": "kaffebröd",
    "kaffebrödets": "kaffebröd",
    "kaffebröds": "kaffebröd",
    "kaffebusk": "kaffebuske",
    "kaffebuskar": "kaffebuske",
    "kaffebuskarna": "kaffebuske",
    "kaffebuskarnas": "kaffebuske",
    "kaffebuskars": "kaffebuske",
    "kaffebusken": "kaffebuske",
    "kaffebuskens": "kaffebuske",
    "kaffebuskes": "kaffebuske",
    "kaffebön": "kaffeböna",
    "kaffebönan": "kaffeböna",
    "kaffebönans": "kaffeböna",
    "kaffebönas": "kaffeböna",
    "kaffeböne": "kaffeböna",
    "kaffebönor": "kaffeböna",
    "kaffebönorna": "kaffeböna",
    "kaffebönornas": "kaffeböna",
    "kaffebönors": "kaffeböna",
    "kaffeböns": "kaffeböna",
    "kaffedoppet": "kaffedopp",
    "kaffedoppets": "kaffedopp",
    "kaffedopps": "kaffedopp",
    "kaffedrickanden": "kaffedrickande",
    "kaffedrickandena": "kaffedrickande",
    "kaffedrickandenas": "kaffedrickande",
    "kaffedrickandens": "kaffedrickande",
    "kaffedrickandes": "kaffedrickande",
    "kaffedrickandet": "kaffedrickande",
    "kaffedrickandets": "kaffedrickande",
    "kaffedukar": "kaffeduk",
    "kaffedukarna": "kaffeduk",
    "kaffedukarnas": "kaffeduk",
    "kaffedukars": "kaffeduk",
    "kaffeduken": "kaffeduk",
    "kaffedukens": "kaffeduk",
    "kaffeduks": "kaffeduk",
    "kaffeersättningar": "kaffeersättning",
    "kaffeersättningarna": "kaffeersättning",
    "kaffeersättningarnas": "kaffeersättning",
    "kaffeersättningars": "kaffeersättning",
    "kaffeersättningen": "kaffeersättning",
    "kaffeersättningens": "kaffeersättning",
    "kaffeersättnings": "kaffeersättning",
    "kaffefaten": "kaffefat",
    "kaffefatens": "kaffefat",
    "kaffefatet": "kaffefat",
    "kaffefatets": "kaffefat",
    "kaffefats": "kaffefat",
    "kaffefilterna": "kaffefilter",
    "kaffefilternas": "kaffefilter",
    "kaffefilters": "kaffefilter",
    "kaffefiltren": "kaffefilter",
    "kaffefiltrens": "kaffefilter",
    "kaffefiltret": "kaffefilter",
    "kaffefiltrets": "kaffefilter",
    "kaffefläckar": "kaffefläck",
    "kaffefläckarna": "kaffefläck",
    "kaffefläckarnas": "kaffefläck",
    "kaffefläckars": "kaffefläck",
    "kaffefläcken": "kaffefläck",
    "kaffefläckens": "kaffefläck",
    "kaffefläcks": "kaffefläck",
    "kaffegrädden": "kaffegrädde",
    "kaffegräddens": "kaffegrädde",
    "kaffegräddes": "kaffegrädde",
    "kaffegökar": "kaffegök",
    "kaffegökarna": "kaffegök",
    "kaffegökarnas": "kaffegök",
    "kaffegökars": "kaffegök",
    "kaffegöken": "kaffegök",
    "kaffegökens": "kaffegök",
    "kaffegöks": "kaffegök",
    "kaffehalv": "kaffehalva",
    "kaffehalvan": "kaffehalva",
    "kaffehalvans": "kaffehalva",
    "kaffehalvas": "kaffehalva",
    "kaffehalve": "kaffehalva",
    "kaffehalvor": "kaffehalva",
    "kaffehalvorna": "kaffehalva",
    "kaffehalvornas": "kaffehalva",
    "kaffehalvors": "kaffehalva",
    "kaffehalvs": "kaffehalva",
    "kaffehurr": "kaffehurra",
    "kaffehurran": "kaffehurra",
    "kaffehurrans": "kaffehurra",
    "kaffehurras": "kaffehurra",
    "kaffehurre": "kaffehurra",
    "kaffehurror": "kaffehurra",
    "kaffehurrorna": "kaffehurra",
    "kaffehurrornas": "kaffehurra",
    "kaffehurrors": "kaffehurra",
    "kaffehurrs": "kaffehurra",
    "kaffekannan": "kaffekanna",
    "kaffekannans": "kaffekanna",
    "kaffekannas": "kaffekanna",
    "kaffekanne": "kaffekanna",
    "kaffekannor": "kaffekanna",
    "kaffekannorna": "kaffekanna",
    "kaffekannornas": "kaffekanna",
    "kaffekannors": "kaffekanna",
    "kaffekaskar": "kaffekask",
    "kaffekaskarna": "kaffekask",
    "kaffekaskarnas": "kaffekask",
    "kaffekaskars": "kaffekask",
    "kaffekasken": "kaffekask",
    "kaffekaskens": "kaffekask",
    "kaffekasks": "kaffekask",
    "kaffekitteln": "kaffekittel",
    "kaffekittelns": "kaffekittel",
    "kaffekittels": "kaffekittel",
    "kaffekittlar": "kaffekittel",
    "kaffekittlarna": "kaffekittel",
    "kaffekittlarnas": "kaffekittel",
    "kaffekittlars": "kaffekittel",
    "kaffekokar": "kaffekokare",
    "kaffekokaren": "kaffekokare",
    "kaffekokarens": "kaffekokare",
    "kaffekokares": "kaffekokare",
    "kaffekokarna": "kaffekokare",
    "kaffekokarnas": "kaffekokare",
    "kaffekokningar": "kaffekokning",
    "kaffekokningarna": "kaffekokning",
    "kaffekokningarnas": "kaffekokning",
    "kaffekokningars": "kaffekokning",
    "kaffekokningen": "kaffekokning",
    "kaffekokningens": "kaffekokning",
    "kaffekoknings": "kaffekokning",
    "kaffekoppar": "kaffekopp",
    "kaffekopparna": "kaffekopp",
    "kaffekopparnas": "kaffekopp",
    "kaffekoppars": "kaffekopp",
    "kaffekoppen": "kaffekopp",
    "kaffekoppens": "kaffekopp",
    "kaffekopps": "kaffekopp",
    "kaffekvarnar": "kaffekvarn",
    "kaffekvarnarna": "kaffekvarn",
    "kaffekvarnarnas": "kaffekvarn",
    "kaffekvarnars": "kaffekvarn",
    "kaffekvarnen": "kaffekvarn",
    "kaffekvarnens": "kaffekvarn",
    "kaffekvarns": "kaffekvarn",
    "kaffemostern": "kaffemoster",
    "kaffemosterns": "kaffemoster",
    "kaffemosters": "kaffemoster",
    "kaffemostrar": "kaffemoster",
    "kaffemostrarna": "kaffemoster",
    "kaffemostrarnas": "kaffemoster",
    "kaffemostrars": "kaffemoster",
    "kaffen": "kaffe",
    "kaffena": "kaffe",
    "kaffenas": "kaffe",
    "kaffens": "kaffe",
    "kaffepann": "kaffepanna",
    "kaffepannan": "kaffepanna",
    "kaffepannans": "kaffepanna",
    "kaffepannas": "kaffepanna",
    "kaffepanne": "kaffepanna",
    "kaffepannor": "kaffepanna",
    "kaffepannorna": "kaffepanna",
    "kaffepannornas": "kaffepanna",
    "kaffepannors": "kaffepanna",
    "kaffepanns": "kaffepanna",
    "kaffepettern": "kaffepetter",
    "kaffepetterns": "kaffepetter",
    "kaffepetters": "kaffepetter",
    "kaffepettrar": "kaffepetter",
    "kaffepettrarna": "kaffepetter",
    "kaffepettrarnas": "kaffepetter",
    "kaffepettrars": "kaffepetter",
    "kaffepulverna": "kaffepulver",
    "kaffepulvernas": "kaffepulver",
    "kaffepulvers": "kaffepulver",
    "kaffepulvren": "kaffepulver",
    "kaffepulvrens": "kaffepulver",
    "kaffepulvret": "kaffepulver",
    "kaffepulvrets": "kaffepulver",
    "kafferasten": "kafferast",
    "kafferastens": "kafferast",
    "kafferaster": "kafferast",
    "kafferasterna": "kafferast",
    "kafferasternas": "kafferast",
    "kafferasters": "kafferast",
    "kafferasts": "kafferast",
    "kafferastämnen": "kafferastämne",
    "kafferastämnena": "kafferastämne",
    "kafferastämnenas": "kafferastämne",
    "kafferastämnens": "kafferastämne",
    "kafferastämnes": "kafferastämne",
    "kafferastämnet": "kafferastämne",
    "kafferastämnets": "kafferastämne",
    "kafferbuffeln": "kafferbuffel",
    "kafferbuffelns": "kafferbuffel",
    "kafferbuffels": "kafferbuffel",
    "kafferbufflar": "kafferbuffel",
    "kafferbufflarna": "kafferbuffel",
    "kafferbufflarnas": "kafferbuffel",
    "kafferbufflars": "kafferbuffel",
    "kafferepen": "kafferep",
    "kafferepens": "kafferep",
    "kafferepet": "kafferep",
    "kafferepets": "kafferep",
    "kaffereps": "kafferep",
    "kafferkornet": "kafferkorn",
    "kafferkornets": "kafferkorn",
    "kafferkorns": "kafferkorn",
    "kaffern": "kaffer",
    "kafferns": "kaffer",
    "kafferosterier": "kafferosteri",
    "kafferosterierna": "kafferosteri",
    "kafferosteriernas": "kafferosteri",
    "kafferosteriers": "kafferosteri",
    "kafferosteriet": "kafferosteri",
    "kafferosteriets": "kafferosteri",
    "kafferosteris": "kafferosteri",
    "kafferosterit": "kafferosteri",
    "kafferosterits": "kafferosteri",
    "kaffers": "kaffer",
    "kafferspjuten": "kafferspjut",
    "kafferspjutens": "kafferspjut",
    "kafferspjutet": "kafferspjut",
    "kafferspjutets": "kafferspjut",
    "kafferspjuts": "kafferspjut",
    "kafferspråken": "kafferspråk",
    "kafferspråkens": "kafferspråk",
    "kafferspråket": "kafferspråk",
    "kafferspråkets": "kafferspråk",
    "kafferspråks": "kafferspråk",
    "kaffes": "kaffe",
    "kaffeserveringar": "kaffeservering",
    "kaffeserveringarna": "kaffeservering",
    "kaffeserveringarnas": "kaffeservering",
    "kaffeserveringars": "kaffeservering",
    "kaffeserveringen": "kaffeservering",
    "kaffeserveringens": "kaffeservering",
    "kaffeserverings": "kaffeservering",
    "kaffeskedar": "kaffesked",
    "kaffeskedarna": "kaffesked",
    "kaffeskedarnas": "kaffesked",
    "kaffeskedars": "kaffesked",
    "kaffeskeden": "kaffesked",
    "kaffeskedens": "kaffesked",
    "kaffeskeds": "kaffesked",
    "kaffesugenheten": "kaffesugenhet",
    "kaffesugenhetens": "kaffesugenhet",
    "kaffesugenhets": "kaffesugenhet",
    "kaffesugens": "kaffesugen",
    "kaffesuget": "kaffesugen",
    "kaffesugets": "kaffesugen",
    "kaffesugna": "kaffesugen",
    "kaffesugnare": "kaffesugen",
    "kaffesugnares": "kaffesugen",
    "kaffesugnas": "kaffesugen",
    "kaffesugnast": "kaffesugen",
    "kaffesugnaste": "kaffesugen",
    "kaffesugnastes": "kaffesugen",
    "kaffesugnasts": "kaffesugen",
    "kaffesugne": "kaffesugen",
    "kaffesugnes": "kaffesugen",
    "kaffesumpen": "kaffesump",
    "kaffesumpens": "kaffesump",
    "kaffesumps": "kaffesump",
    "kaffet": "kaffe",
    "kaffetanten": "kaffetant",
    "kaffetantens": "kaffetant",
    "kaffetanter": "kaffetant",
    "kaffetanterna": "kaffetant",
    "kaffetanternas": "kaffetant",
    "kaffetanters": "kaffetant",
    "kaffetants": "kaffetant",
    "kaffeträden": "kaffeträd",
    "kaffeträdens": "kaffeträd",
    "kaffeträdet": "kaffeträd",
    "kaffeträdets": "kaffeträd",
    "kaffeträds": "kaffeträd",
    "kaffets": "kaffe",
    "kaffetårar": "kaffetår",
    "kaffetårarna": "kaffetår",
    "kaffetårarnas": "kaffetår",
    "kaffetårars": "kaffetår",
    "kaffetåren": "kaffetår",
    "kaffetårens": "kaffetår",
    "kaffetårs": "kaffetår",
    "kaffeveden": "kaffeved",
    "kaffevedens": "kaffeved",
    "kaffeveds": "kaffeved",
    "kaffrer": "kaffer",
    "kaffrerna": "kaffer",
    "kaffrernas": "kaffer",
    "kaffrers": "kaffer",
    "kafkaartade": "kafkaartad",
    "kafkaartades": "kafkaartad",
    "kafkaartat": "kafkaartad",
    "kafkaeska": "kafkaesk",
    "kafkaeskares": "kafkaesk",
    "kafkaeskast": "kafkaesk",
    "kafkaeskastes": "kafkaesk",
    "kafkaeske": "kafkaesk",
    "kafkaeskt": "kafkaesk",
    "kafkalika": "kafkalik",
    "kafkalikares": "kafkalik",
    "kafkalikas": "kafkalik",
    "kafkalikast": "kafkalik",
    "kafkalikastes": "kafkalik",
    "kafkalike": "kafkalik",
    "kafkaliks": "kafkalik",
    "kafkalikts": "kafkalik",
    "kafkastämningarna": "kafkastämning",
    "kafkastämningars": "kafkastämning",
    "kafkastämningen": "kafkastämning",
    "kafkastämnings": "kafkastämning",
    "kaftanen": "kaftan",
    "kaftanens": "kaftan",
    "kaftaner": "kaftan",
    "kaftanerna": "kaftan",
    "kaftanernas": "kaftan",
    "kaftaners": "kaftan",
    "kaftans": "kaftan",
    "kaféborden": "kafébord",
    "kafébordens": "kafébord",
    "kafébordet": "kafébord",
    "kafébordets": "kafébord",
    "kafébords": "kafébord",
    "kaféer": "kafé",
    "kaféerna": "kafé",
    "kaféernas": "kafé",
    "kaféers": "kafé",
    "kaféet": "kafé",
    "kaféets": "kafé",
    "kaférörelsen": "kaférörelse",
    "kaférörelsens": "kaférörelse",
    "kaférörelser": "kaférörelse",
    "kaférörelserna": "kaférörelse",
    "kaférörelsernas": "kaférörelse",
    "kaférörelsers": "kaférörelse",
    "kaférörelses": "kaférörelse",
    "kafés": "kafé",
    "kafét": "kafé",
    "kaféts": "kafé",
    "kafévagnar": "kafévagn",
    "kafévagnarna": "kafévagn",
    "kafévagnarnas": "kafévagn",
    "kafévagnars": "kafévagn",
    "kafévagnen": "kafévagn",
    "kafévagnens": "kafévagn",
    "kafévagns": "kafévagn",
    "kagg": "kagge",
    "kaggar": "kagge",
    "kaggarna": "kagge",
    "kaggarnas": "kagge",
    "kaggars": "kagge",
    "kaggen": "kagge",
    "kaggens": "kagge",
    "kagges": "kagge",
    "kaggs": "kagge",
    "kainsmärkes": "kainsmärke",
    "kainsmärket": "kainsmärke",
    "kainsmärkets": "kainsmärke",
    "kairotalen": "kairotal",
    "kairotalens": "kairotal",
    "kairotalet": "kairotal",
    "kairotalets": "kairotal",
    "kairotals": "kairotal",
    "kaj": "kaja",
    "kajaken": "kajak",
    "kajakens": "kajak",
    "kajaker": "kajak",
    "kajakerna": "kajak",
    "kajakernas": "kajak",
    "kajakers": "kajak",
    "kajaks": "kajak",
    "kajalen": "kajal",
    "kajalens": "kajal",
    "kajaler": "kajal",
    "kajalerna": "kajal",
    "kajalernas": "kajal",
    "kajalers": "kajal",
    "kajalet": "kajal",
    "kajalets": "kajal",
    "kajalpenn": "kajalpenna",
    "kajalpennan": "kajalpenna",
    "kajalpennans": "kajalpenna",
    "kajalpennas": "kajalpenna",
    "kajalpenne": "kajalpenna",
    "kajalpennor": "kajalpenna",
    "kajalpennorna": "kajalpenna",
    "kajalpennornas": "kajalpenna",
    "kajalpennors": "kajalpenna",
    "kajalpenns": "kajalpenna",
    "kajals": "kajal",
    "kajan": "kaja",
    "kajans": "kaja",
    "kajas": "kaja",
    "kajavgiften": "kajavgift",
    "kajavgiftens": "kajavgift",
    "kajavgifter": "kajavgift",
    "kajavgifterna": "kajavgift",
    "kajavgifternas": "kajavgift",
    "kajavgifters": "kajavgift",
    "kajavgifts": "kajavgift",
    "kajdjupen": "kajdjup",
    "kajdjupens": "kajdjup",
    "kajdjupet": "kajdjup",
    "kajdjupets": "kajdjup",
    "kajdjups": "kajdjup",
    "kaje": "kaja",
    "kajen": "kaj",
    "kajennpepparn": "kajennpeppar",
    "kajennpepparns": "kajennpeppar",
    "kajennpeppars": "kajennpeppar",
    "kajens": "kaj",
    "kajer": "kaj",
    "kajerna": "kaj",
    "kajernas": "kaj",
    "kajers": "kaj",
    "kajk": "kajka",
    "kajkade": "kajka",
    "kajkades": "kajka",
    "kajkande": "kajka",
    "kajkanden": "kajkande",
    "kajkandena": "kajkande",
    "kajkandenas": "kajkande",
    "kajkandens": "kajkande",
    "kajkandes": "kajkande",
    "kajkandet": "kajkande",
    "kajkandets": "kajkande",
    "kajkar": "kajka",
    "kajkas": "kajka",
    "kajkat": "kajka",
    "kajkats": "kajka",
    "kajmanen": "kajman",
    "kajmanens": "kajman",
    "kajmaner": "kajman",
    "kajmanerna": "kajman",
    "kajmanernas": "kajman",
    "kajmaners": "kajman",
    "kajmans": "kajman",
    "kajor": "kaja",
    "kajorna": "kaja",
    "kajornas": "kaja",
    "kajors": "kaja",
    "kajplatsen": "kajplats",
    "kajplatsens": "kajplats",
    "kajplatser": "kajplats",
    "kajplatserna": "kajplats",
    "kajplatsernas": "kajplats",
    "kajplatsers": "kajplats",
    "kajs": "kaja",
    "kajskoningar": "kajskoning",
    "kajskoningarna": "kajskoning",
    "kajskoningarnas": "kajskoning",
    "kajskoningars": "kajskoning",
    "kajskoningen": "kajskoning",
    "kajskoningens": "kajskoning",
    "kajskonings": "kajskoning",
    "kajsvärmar": "kajsvärm",
    "kajsvärmarna": "kajsvärm",
    "kajsvärmarnas": "kajsvärm",
    "kajsvärmars": "kajsvärm",
    "kajsvärmen": "kajsvärm",
    "kajsvärmens": "kajsvärm",
    "kajsvärms": "kajsvärm",
    "kajut": "kajuta",
    "kajutan": "kajuta",
    "kajutans": "kajuta",
    "kajutas": "kajuta",
    "kajutdäcken": "kajutdäck",
    "kajutdäckens": "kajutdäck",
    "kajutdäcket": "kajutdäck",
    "kajutdäckets": "kajutdäck",
    "kajutdäcks": "kajutdäck",
    "kajute": "kajuta",
    "kajutor": "kajuta",
    "kajutorna": "kajuta",
    "kajutornas": "kajuta",
    "kajutors": "kajuta",
    "kajutposten": "kajutpost",
    "kajutpostens": "kajutpost",
    "kajutposter": "kajutpost",
    "kajutposterna": "kajutpost",
    "kajutposternas": "kajutpost",
    "kajutposters": "kajutpost",
    "kajutposts": "kajutpost",
    "kajuts": "kajuta",
    "kak": "kaka",
    "kakadu": "kakadua",
    "kakaduan": "kakadua",
    "kakaduans": "kakadua",
    "kakaduas": "kakadua",
    "kakadue": "kakadua",
    "kakaduor": "kakadua",
    "kakaduorna": "kakadua",
    "kakaduornas": "kakadua",
    "kakaduors": "kakadua",
    "kakadus": "kakadua",
    "kakafonien": "kakafoni",
    "kakafoniens": "kakafoni",
    "kakafonier": "kakafoni",
    "kakafonierna": "kakafoni",
    "kakafoniernas": "kakafoni",
    "kakafoniers": "kakafoni",
    "kakafonin": "kakafoni",
    "kakafonins": "kakafoni",
    "kakafonis": "kakafoni",
    "kakan": "kaka",
    "kakans": "kaka",
    "kakaobön": "kakaoböna",
    "kakaobönan": "kakaoböna",
    "kakaobönans": "kakaoböna",
    "kakaobönas": "kakaoböna",
    "kakaoböne": "kakaoböna",
    "kakaobönor": "kakaoböna",
    "kakaobönorna": "kakaoböna",
    "kakaobönornas": "kakaoböna",
    "kakaobönors": "kakaoböna",
    "kakaoböns": "kakaoböna",
    "kakaofettet": "kakaofett",
    "kakaofettets": "kakaofett",
    "kakaofetts": "kakaofett",
    "kakaolikören": "kakaolikör",
    "kakaolikörens": "kakaolikör",
    "kakaolikörer": "kakaolikör",
    "kakaolikörerna": "kakaolikör",
    "kakaolikörernas": "kakaolikör",
    "kakaolikörers": "kakaolikör",
    "kakaolikörs": "kakaolikör",
    "kakaon": "kakao",
    "kakaons": "kakao",
    "kakaopulvers": "kakaopulver",
    "kakaopulvret": "kakaopulver",
    "kakaopulvrets": "kakaopulver",
    "kakaos": "kakao",
    "kakaot": "kakao",
    "kakaoträden": "kakaoträd",
    "kakaoträdens": "kakaoträd",
    "kakaoträdet": "kakaoträd",
    "kakaoträdets": "kakaoträd",
    "kakaoträds": "kakaoträd",
    "kakaots": "kakao",
    "kakas": "kaka",
    "kakbaken": "kakbak",
    "kakbakens": "kakbak",
    "kakbaket": "kakbak",
    "kakbakets": "kakbak",
    "kakbaks": "kakbak",
    "kakburkar": "kakburk",
    "kakburkarna": "kakburk",
    "kakburkarnas": "kakburk",
    "kakburkars": "kakburk",
    "kakburken": "kakburk",
    "kakburkens": "kakburk",
    "kakburks": "kakburk",
    "kakdoppanden": "kakdoppande",
    "kakdoppandena": "kakdoppande",
    "kakdoppandenas": "kakdoppande",
    "kakdoppandens": "kakdoppande",
    "kakdoppandes": "kakdoppande",
    "kakdoppandet": "kakdoppande",
    "kakdoppandets": "kakdoppande",
    "kake": "kaka",
    "kakelmaskinen": "kakelmaskin",
    "kakelmaskinens": "kakelmaskin",
    "kakelmaskiner": "kakelmaskin",
    "kakelmaskinerna": "kakelmaskin",
    "kakelmaskinernas": "kakelmaskin",
    "kakelmaskiners": "kakelmaskin",
    "kakelmaskins": "kakelmaskin",
    "kakelplatt": "kakelplatta",
    "kakelplattan": "kakelplatta",
    "kakelplattans": "kakelplatta",
    "kakelplattas": "kakelplatta",
    "kakelplatte": "kakelplatta",
    "kakelplattor": "kakelplatta",
    "kakelplattorna": "kakelplatta",
    "kakelplattornas": "kakelplatta",
    "kakelplattors": "kakelplatta",
    "kakelplatts": "kakelplatta",
    "kakels": "kakel",
    "kakelskärar": "kakelskärare",
    "kakelskäraren": "kakelskärare",
    "kakelskärarens": "kakelskärare",
    "kakelskärares": "kakelskärare",
    "kakelskärarna": "kakelskärare",
    "kakelskärarnas": "kakelskärare",
    "kakelugnar": "kakelugn",
    "kakelugnarna": "kakelugn",
    "kakelugnarnas": "kakelugn",
    "kakelugnars": "kakelugn",
    "kakelugnen": "kakelugn",
    "kakelugnens": "kakelugn",
    "kakelugns": "kakelugn",
    "kakelugnsluck": "kakelugnslucka",
    "kakelugnsluckan": "kakelugnslucka",
    "kakelugnsluckans": "kakelugnslucka",
    "kakelugnsluckas": "kakelugnslucka",
    "kakelugnslucke": "kakelugnslucka",
    "kakelugnsluckor": "kakelugnslucka",
    "kakelugnsluckorna": "kakelugnslucka",
    "kakelugnsluckornas": "kakelugnslucka",
    "kakelugnsluckors": "kakelugnslucka",
    "kakelugnslucks": "kakelugnslucka",
    "kakelugnsmakar": "kakelugnsmakare",
    "kakelugnsmakaren": "kakelugnsmakare",
    "kakelugnsmakarens": "kakelugnsmakare",
    "kakelugnsmakares": "kakelugnsmakare",
    "kakelugnsmakarna": "kakelugnsmakare",
    "kakelugnsmakarnas": "kakelugnsmakare",
    "kakelugnsnischen": "kakelugnsnisch",
    "kakelugnsnischens": "kakelugnsnisch",
    "kakelugnsnischer": "kakelugnsnisch",
    "kakelugnsnischerna": "kakelugnsnisch",
    "kakelugnsnischernas": "kakelugnsnisch",
    "kakelugnsnischers": "kakelugnsnisch",
    "kakelugnsnischs": "kakelugnsnisch",
    "kakelugnssättar": "kakelugnssättare",
    "kakelugnssättaren": "kakelugnssättare",
    "kakelugnssättarens": "kakelugnssättare",
    "kakelugnssättares": "kakelugnssättare",
    "kakelugnssättarna": "kakelugnssättare",
    "kakelugnssättarnas": "kakelugnssättare",
    "kakelugnsventilen": "kakelugnsventil",
    "kakelugnsventilens": "kakelugnsventil",
    "kakelugnsventiler": "kakelugnsventil",
    "kakelugnsventilerna": "kakelugnsventil",
    "kakelugnsventilernas": "kakelugnsventil",
    "kakelugnsventilers": "kakelugnsventil",
    "kakelugnsventils": "kakelugnsventil",
    "kakelverktygen": "kakelverktyg",
    "kakelverktygens": "kakelverktyg",
    "kakelverktyget": "kakelverktyg",
    "kakelverktygets": "kakelverktyg",
    "kakelverktygs": "kakelverktyg",
    "kakfaten": "kakfat",
    "kakfatens": "kakfat",
    "kakfatet": "kakfat",
    "kakfatets": "kakfat",
    "kakfats": "kakfat",
    "kakformar": "kakform",
    "kakformarna": "kakform",
    "kakformarnas": "kakform",
    "kakformars": "kakform",
    "kakformen": "kakform",
    "kakformens": "kakform",
    "kakforms": "kakform",
    "kakifärgade": "kakifärgad",
    "kakifärgades": "kakifärgad",
    "kakifärgads": "kakifärgad",
    "kakifärgat": "kakifärgad",
    "kakifärgats": "kakifärgad",
    "kakin": "kaki",
    "kakins": "kaki",
    "kakis": "kaki",
    "kakiuniformen": "kakiuniform",
    "kakiuniformens": "kakiuniform",
    "kakiuniformer": "kakiuniform",
    "kakiuniformerna": "kakiuniform",
    "kakiuniformernas": "kakiuniform",
    "kakiuniformers": "kakiuniform",
    "kakiuniforms": "kakiuniform",
    "kaklad": "kakla",
    "kaklade": "kakla",
    "kaklades": "kakla",
    "kaklads": "kakla",
    "kaklande": "kakla",
    "kaklanden": "kaklande",
    "kaklandena": "kaklande",
    "kaklandenas": "kaklande",
    "kaklandens": "kaklande",
    "kaklandes": "kaklande",
    "kaklandet": "kaklande",
    "kaklandets": "kaklande",
    "kaklar": "kakla",
    "kaklas": "kakla",
    "kaklat": "kakla",
    "kaklats": "kakla",
    "kaklen": "kakel",
    "kaklens": "kakel",
    "kaklet": "kakel",
    "kaklets": "kakel",
    "kakmixar": "kakmix",
    "kakmixarna": "kakmix",
    "kakmixarnas": "kakmix",
    "kakmixars": "kakmix",
    "kakmixen": "kakmix",
    "kakmixens": "kakmix",
    "kakmixer": "kakmix",
    "kakmixerna": "kakmix",
    "kakmixernas": "kakmix",
    "kakmixers": "kakmix",
    "kakmåtten": "kakmått",
    "kakmåttens": "kakmått",
    "kakmåttet": "kakmått",
    "kakmåttets": "kakmått",
    "kakmåtts": "kakmått",
    "kakofonien": "kakofoni",
    "kakofoniens": "kakofoni",
    "kakofonier": "kakofoni",
    "kakofonierna": "kakofoni",
    "kakofoniernas": "kakofoni",
    "kakofoniers": "kakofoni",
    "kakofonin": "kakofoni",
    "kakofonins": "kakofoni",
    "kakofonis": "kakofoni",
    "kakor": "kaka",
    "kakorna": "kaka",
    "kakornas": "kaka",
    "kakors": "kaka",
    "kaks": "kaka",
    "kaksmeten": "kaksmet",
    "kaksmetens": "kaksmet",
    "kaksmeter": "kaksmet",
    "kaksmeterna": "kaksmet",
    "kaksmeternas": "kaksmet",
    "kaksmeters": "kaksmet",
    "kaksmets": "kaksmet",
    "kaktusar": "kaktus",
    "kaktusarna": "kaktus",
    "kaktusarnas": "kaktus",
    "kaktusars": "kaktus",
    "kaktusen": "kaktus",
    "kaktusens": "kaktus",
    "kaktusfikonen": "kaktusfikon",
    "kaktusfikonens": "kaktusfikon",
    "kaktusfikonet": "kaktusfikon",
    "kaktusfikonets": "kaktusfikon",
    "kaktusfikons": "kaktusfikon",
    "kaktänger": "kaktång",
    "kaktängerna": "kaktång",
    "kaktängernas": "kaktång",
    "kaktängers": "kaktång",
    "kaktången": "kaktång",
    "kaktångens": "kaktång",
    "kaktångs": "kaktång",
    "kaktéer": "kakté",
    "kaktéerna": "kakté",
    "kaktéernas": "kakté",
    "kaktéers": "kakté",
    "kaktén": "kakté",
    "kakténs": "kakté",
    "kaktés": "kakté",
    "kakuminala": "kakuminal",
    "kakuminalare": "kakuminal",
    "kakuminalares": "kakuminal",
    "kakuminalas": "kakuminal",
    "kakuminalast": "kakuminal",
    "kakuminalaste": "kakuminal",
    "kakuminalastes": "kakuminal",
    "kakuminalasts": "kakuminal",
    "kakuminale": "kakuminal",
    "kakuminalen": "kakuminal",
    "kakuminalens": "kakuminal",
    "kakuminaler": "kakuminal",
    "kakuminalerna": "kakuminal",
    "kakuminalernas": "kakuminal",
    "kakuminalers": "kakuminal",
    "kakuminales": "kakuminal",
    "kakuminals": "kakuminal",
    "kakuminalt": "kakuminal",
    "kakuminalts": "kakuminal",
    "kala": "kal",
    "kalabaliken": "kalabalik",
    "kalabalikens": "kalabalik",
    "kalabaliker": "kalabalik",
    "kalabalikerna": "kalabalik",
    "kalabalikernas": "kalabalik",
    "kalabalikers": "kalabalik",
    "kalabaliks": "kalabalik",
    "kalabassen": "kalabass",
    "kalabassens": "kalabass",
    "kalabasser": "kalabass",
    "kalabasserna": "kalabass",
    "kalabassernas": "kalabass",
    "kalabassers": "kalabass",
    "kalabasspump": "kalabasspumpa",
    "kalabasspumpan": "kalabasspumpa",
    "kalabasspumpans": "kalabasspumpa",
    "kalabasspumpas": "kalabasspumpa",
    "kalabasspumpe": "kalabasspumpa",
    "kalabasspumpor": "kalabasspumpa",
    "kalabasspumporna": "kalabasspumpa",
    "kalabasspumpornas": "kalabasspumpa",
    "kalabasspumpors": "kalabasspumpa",
    "kalabasspumps": "kalabasspumpa",
    "kalamiteten": "kalamitet",
    "kalamitetens": "kalamitet",
    "kalamiteter": "kalamitet",
    "kalamiteterna": "kalamitet",
    "kalamiteternas": "kalamitet",
    "kalamiteters": "kalamitet",
    "kalamitets": "kalamitet",
    "kalandern": "kalander",
    "kalanderns": "kalander",
    "kalanders": "kalander",
    "kalandrar": "kalander",
    "kalandrarna": "kalander",
    "kalandrarnas": "kalander",
    "kalandrars": "kalander",
    "kalandrerad": "kalandrera",
    "kalandrerade": "kalandrera",
    "kalandrerades": "kalandrera",
    "kalandrerads": "kalandrera",
    "kalandrerande": "kalandrera",
    "kalandreranden": "kalandrerande",
    "kalandrerandena": "kalandrerande",
    "kalandrerandenas": "kalandrerande",
    "kalandrerandens": "kalandrerande",
    "kalandrerandes": "kalandrerande",
    "kalandrerandet": "kalandrerande",
    "kalandrerandets": "kalandrerande",
    "kalandrerar": "kalandrera",
    "kalandreras": "kalandrera",
    "kalandrerat": "kalandrera",
    "kalandrerats": "kalandrera",
    "kalandrerbara": "kalandrerbar",
    "kalandrerbarare": "kalandrerbar",
    "kalandrerbarares": "kalandrerbar",
    "kalandrerbaras": "kalandrerbar",
    "kalandrerbarast": "kalandrerbar",
    "kalandrerbaraste": "kalandrerbar",
    "kalandrerbarastes": "kalandrerbar",
    "kalandrerbarasts": "kalandrerbar",
    "kalandrerbare": "kalandrerbar",
    "kalandrerbares": "kalandrerbar",
    "kalandrerbarheten": "kalandrerbarhet",
    "kalandrerbarhetens": "kalandrerbarhet",
    "kalandrerbarhets": "kalandrerbarhet",
    "kalandrerbars": "kalandrerbar",
    "kalandrerbart": "kalandrerbar",
    "kalandrerbarts": "kalandrerbar",
    "kalandreringar": "kalandrering",
    "kalandreringarna": "kalandrering",
    "kalandreringarnas": "kalandrering",
    "kalandreringars": "kalandrering",
    "kalandreringen": "kalandrering",
    "kalandreringens": "kalandrering",
    "kalandrerings": "kalandrering",
    "kalare": "kal",
    "kalares": "kal",
    "kalas": "kal",
    "kalasade": "kalasa",
    "kalasades": "kalasa",
    "kalasande": "kalasa",
    "kalasanden": "kalasande",
    "kalasandena": "kalasande",
    "kalasandenas": "kalasande",
    "kalasandens": "kalasande",
    "kalasandes": "kalasande",
    "kalasandet": "kalasande",
    "kalasandets": "kalasande",
    "kalasar": "kalasa",
    "kalasas": "kalasa",
    "kalasat": "kalasa",
    "kalasats": "kalasa",
    "kalasbyx": "kalasbyxa",
    "kalasbyxan": "kalasbyxa",
    "kalasbyxans": "kalasbyxa",
    "kalasbyxas": "kalasbyxa",
    "kalasbyxe": "kalasbyxa",
    "kalasbyxor": "kalasbyxa",
    "kalasbyxorna": "kalasbyxa",
    "kalasbyxornas": "kalasbyxa",
    "kalasbyxors": "kalasbyxa",
    "kalasen": "kalas",
    "kalasens": "kalas",
    "kalaset": "kalas",
    "kalasets": "kalas",
    "kalaskul": "kalaskula",
    "kalaskulan": "kalaskula",
    "kalaskulans": "kalaskula",
    "kalaskulas": "kalaskula",
    "kalaskule": "kalaskula",
    "kalaskulor": "kalaskula",
    "kalaskulorna": "kalaskula",
    "kalaskulornas": "kalaskula",
    "kalaskulors": "kalaskula",
    "kalaskuls": "kalaskula",
    "kalasmaten": "kalasmat",
    "kalasmatens": "kalasmat",
    "kalasmats": "kalasmat",
    "kalaspingel": "kalaspingla",
    "kalaspinglan": "kalaspingla",
    "kalaspinglans": "kalaspingla",
    "kalaspinglas": "kalaspingla",
    "kalaspingle": "kalaspingla",
    "kalaspinglor": "kalaspingla",
    "kalaspinglorna": "kalaspingla",
    "kalaspinglornas": "kalaspingla",
    "kalaspinglors": "kalaspingla",
    "kalast": "kal",
    "kalaste": "kal",
    "kalastes": "kal",
    "kalasts": "kal",
    "kalavverk": "kalavverka",
    "kalavverkad": "kalavverka",
    "kalavverkade": "kalavverka",
    "kalavverkades": "kalavverka",
    "kalavverkads": "kalavverka",
    "kalavverkande": "kalavverka",
    "kalavverkanden": "kalavverkande",
    "kalavverkandena": "kalavverkande",
    "kalavverkandenas": "kalavverkande",
    "kalavverkandens": "kalavverkande",
    "kalavverkandes": "kalavverkande",
    "kalavverkandet": "kalavverkande",
    "kalavverkandets": "kalavverkande",
    "kalavverkar": "kalavverka",
    "kalavverkas": "kalavverka",
    "kalavverkat": "kalavverka",
    "kalavverkats": "kalavverka",
    "kalcedonen": "kalcedon",
    "kalcedonens": "kalcedon",
    "kalcedoner": "kalcedon",
    "kalcedonerna": "kalcedon",
    "kalcedonernas": "kalcedon",
    "kalcedoners": "kalcedon",
    "kalcedons": "kalcedon",
    "kalciet": "kalcium",
    "kalciets": "kalcium",
    "kalcinerad": "kalcinera",
    "kalcinerade": "kalcinera",
    "kalcinerades": "kalcinera",
    "kalcinerads": "kalcinera",
    "kalcinerande": "kalcinera",
    "kalcineranden": "kalcinerande",
    "kalcinerandena": "kalcinerande",
    "kalcinerandenas": "kalcinerande",
    "kalcinerandens": "kalcinerande",
    "kalcinerandes": "kalcinerande",
    "kalcinerandet": "kalcinerande",
    "kalcinerandets": "kalcinerande",
    "kalcinerar": "kalcinera",
    "kalcineras": "kalcinera",
    "kalcinerat": "kalcinera",
    "kalcinerats": "kalcinera",
    "kalcinerbara": "kalcinerbar",
    "kalcinerbarare": "kalcinerbar",
    "kalcinerbarares": "kalcinerbar",
    "kalcinerbaras": "kalcinerbar",
    "kalcinerbarast": "kalcinerbar",
    "kalcinerbaraste": "kalcinerbar",
    "kalcinerbarastes": "kalcinerbar",
    "kalcinerbarasts": "kalcinerbar",
    "kalcinerbare": "kalcinerbar",
    "kalcinerbares": "kalcinerbar",
    "kalcinerbarheten": "kalcinerbarhet",
    "kalcinerbarhetens": "kalcinerbarhet",
    "kalcinerbarhets": "kalcinerbarhet",
    "kalcinerbars": "kalcinerbar",
    "kalcinerbart": "kalcinerbar",
    "kalcinerbarts": "kalcinerbar",
    "kalcineringar": "kalcinering",
    "kalcineringarna": "kalcinering",
    "kalcineringarnas": "kalcinering",
    "kalcineringars": "kalcinering",
    "kalcineringen": "kalcinering",
    "kalcineringens": "kalcinering",
    "kalcinerings": "kalcinering",
    "kalciumet": "kalcium",
    "kalciumets": "kalcium",
    "kalciumfosfatet": "kalciumfosfat",
    "kalciumfosfatets": "kalciumfosfat",
    "kalciumfosfats": "kalciumfosfat",
    "kalciumhydroxiden": "kalciumhydroxid",
    "kalciumhydroxidens": "kalciumhydroxid",
    "kalciumhydroxider": "kalciumhydroxid",
    "kalciumhydroxiderna": "kalciumhydroxid",
    "kalciumhydroxidernas": "kalciumhydroxid",
    "kalciumhydroxiders": "kalciumhydroxid",
    "kalciumhydroxids": "kalciumhydroxid",
    "kalciumkarbonatet": "kalciumkarbonat",
    "kalciumkarbonatets": "kalciumkarbonat",
    "kalciumkarbonats": "kalciumkarbonat",
    "kalciumkloriden": "kalciumklorid",
    "kalciumkloridens": "kalciumklorid",
    "kalciumklorids": "kalciumklorid",
    "kalciumoxiden": "kalciumoxid",
    "kalciumoxidens": "kalciumoxid",
    "kalciumoxider": "kalciumoxid",
    "kalciumoxiderna": "kalciumoxid",
    "kalciumoxidernas": "kalciumoxid",
    "kalciumoxiders": "kalciumoxid",
    "kalciumoxids": "kalciumoxid",
    "kalciums": "kalcium",
    "kalciumsilikaten": "kalciumsilikat",
    "kalciumsilikatens": "kalciumsilikat",
    "kalciumsilikater": "kalciumsilikat",
    "kalciumsilikaterna": "kalciumsilikat",
    "kalciumsilikaternas": "kalciumsilikat",
    "kalciumsilikaters": "kalciumsilikat",
    "kalciumsilikatet": "kalciumsilikat",
    "kalciumsilikatets": "kalciumsilikat",
    "kalciumsilikats": "kalciumsilikat",
    "kalciumsulfaten": "kalciumsulfat",
    "kalciumsulfatens": "kalciumsulfat",
    "kalciumsulfatet": "kalciumsulfat",
    "kalciumsulfatets": "kalciumsulfat",
    "kalciumsulfats": "kalciumsulfat",
    "kaldéen": "kaldé",
    "kaldéens": "kaldé",
    "kaldéer": "kaldé",
    "kaldéerna": "kaldé",
    "kaldéernas": "kaldé",
    "kaldéers": "kaldé",
    "kaldén": "kaldé",
    "kaldéns": "kaldé",
    "kaldés": "kaldé",
    "kale": "kal",
    "kalebassen": "kalebass",
    "kalebassens": "kalebass",
    "kalebasser": "kalebass",
    "kalebasserna": "kalebass",
    "kalebassernas": "kalebass",
    "kalebassers": "kalebass",
    "kalebasspump": "kalebasspumpa",
    "kalebasspumpan": "kalebasspumpa",
    "kalebasspumpans": "kalebasspumpa",
    "kalebasspumpas": "kalebasspumpa",
    "kalebasspumpe": "kalebasspumpa",
    "kalebasspumpor": "kalebasspumpa",
    "kalebasspumporna": "kalebasspumpa",
    "kalebasspumpornas": "kalebasspumpa",
    "kalebasspumpors": "kalebasspumpa",
    "kalebasspumps": "kalebasspumpa",
    "kaledoniska": "kaledonisk",
    "kaledoniskare": "kaledonisk",
    "kaledoniskares": "kaledonisk",
    "kaledoniskas": "kaledonisk",
    "kaledoniskast": "kaledonisk",
    "kaledoniskaste": "kaledonisk",
    "kaledoniskastes": "kaledonisk",
    "kaledoniskasts": "kaledonisk",
    "kaledoniske": "kaledonisk",
    "kaledoniskes": "kaledonisk",
    "kaledonisks": "kaledonisk",
    "kaledoniskt": "kaledonisk",
    "kaledoniskts": "kaledonisk",
    "kalejdoskopen": "kalejdoskop",
    "kalejdoskopens": "kalejdoskop",
    "kalejdoskopet": "kalejdoskop",
    "kalejdoskopets": "kalejdoskop",
    "kalejdoskopiska": "kalejdoskopisk",
    "kalejdoskopiskare": "kalejdoskopisk",
    "kalejdoskopiskares": "kalejdoskopisk",
    "kalejdoskopiskas": "kalejdoskopisk",
    "kalejdoskopiskast": "kalejdoskopisk",
    "kalejdoskopiskaste": "kalejdoskopisk",
    "kalejdoskopiskastes": "kalejdoskopisk",
    "kalejdoskopiskasts": "kalejdoskopisk",
    "kalejdoskopiske": "kalejdoskopisk",
    "kalejdoskopiskes": "kalejdoskopisk",
    "kalejdoskopisks": "kalejdoskopisk",
    "kalejdoskopiskt": "kalejdoskopisk",
    "kalejdoskopiskts": "kalejdoskopisk",
    "kalejdoskops": "kalejdoskop",
    "kalendarie": "kalendarium",
    "kalendarier": "kalendarium",
    "kalendarierna": "kalendarium",
    "kalendariernas": "kalendarium",
    "kalendariers": "kalendarium",
    "kalendariet": "kalendarium",
    "kalendariets": "kalendarium",
    "kalendariska": "kalendarisk",
    "kalendariskare": "kalendarisk",
    "kalendariskares": "kalendarisk",
    "kalendariskas": "kalendarisk",
    "kalendariskast": "kalendarisk",
    "kalendariskaste": "kalendarisk",
    "kalendariskastes": "kalendarisk",
    "kalendariskasts": "kalendarisk",
    "kalendariske": "kalendarisk",
    "kalendariskes": "kalendarisk",
    "kalendarisks": "kalendarisk",
    "kalendariskt": "kalendarisk",
    "kalendariskts": "kalendarisk",
    "kalendariums": "kalendarium",
    "kalenderbitar": "kalenderbitare",
    "kalenderbitaren": "kalenderbitare",
    "kalenderbitarens": "kalenderbitare",
    "kalenderbitares": "kalenderbitare",
    "kalenderbitarna": "kalenderbitare",
    "kalenderbitarnas": "kalenderbitare",
    "kalenderbiterier": "kalenderbiteri",
    "kalenderbiterierna": "kalenderbiteri",
    "kalenderbiteriernas": "kalenderbiteri",
    "kalenderbiteriers": "kalenderbiteri",
    "kalenderbiteriet": "kalenderbiteri",
    "kalenderbiteriets": "kalenderbiteri",
    "kalenderbiteris": "kalenderbiteri",
    "kalenderbiterit": "kalenderbiteri",
    "kalenderbiterits": "kalenderbiteri",
    "kalenderdygnen": "kalenderdygn",
    "kalenderdygnens": "kalenderdygn",
    "kalenderdygnet": "kalenderdygn",
    "kalenderdygnets": "kalenderdygn",
    "kalenderdygns": "kalenderdygn",
    "kalenderfotograferingar": "kalenderfotografering",
    "kalenderfotograferingarna": "kalenderfotografering",
    "kalenderfotograferingarnas": "kalenderfotografering",
    "kalenderfotograferingars": "kalenderfotografering",
    "kalenderfotograferingen": "kalenderfotografering",
    "kalenderfotograferingens": "kalenderfotografering",
    "kalenderfotograferings": "kalenderfotografering",
    "kalendermånaden": "kalendermånad",
    "kalendermånadens": "kalendermånad",
    "kalendermånader": "kalendermånad",
    "kalendermånaderna": "kalendermånad",
    "kalendermånadernas": "kalendermånad",
    "kalendermånaders": "kalendermånad",
    "kalendermånads": "kalendermånad",
    "kalendern": "kalender",
    "kalenderns": "kalender",
    "kalenders": "kalender",
    "kalenderstavar": "kalenderstav",
    "kalenderstavarna": "kalenderstav",
    "kalenderstavarnas": "kalenderstav",
    "kalenderstavars": "kalenderstav",
    "kalenderstaven": "kalenderstav",
    "kalenderstavens": "kalenderstav",
    "kalenderstavs": "kalenderstav",
    "kalenderveck": "kalendervecka",
    "kalenderveckan": "kalendervecka",
    "kalenderveckans": "kalendervecka",
    "kalenderveckas": "kalendervecka",
    "kalendervecke": "kalendervecka",
    "kalendervecko": "kalendervecka",
    "kalenderveckor": "kalendervecka",
    "kalenderveckorna": "kalendervecka",
    "kalenderveckornas": "kalendervecka",
    "kalenderveckors": "kalendervecka",
    "kalendervecks": "kalendervecka",
    "kalenderåren": "kalenderår",
    "kalenderårens": "kalenderår",
    "kalenderåret": "kalenderår",
    "kalenderårets": "kalenderår",
    "kalenderårs": "kalenderår",
    "kalendrar": "kalender",
    "kalendrarna": "kalender",
    "kalendrarnas": "kalender",
    "kalendrars": "kalender",
    "kales": "kal",
    "kaleschen": "kalesch",
    "kaleschens": "kalesch",
    "kalescher": "kalesch",
    "kalescherna": "kalesch",
    "kaleschernas": "kalesch",
    "kaleschers": "kalesch",
    "kaleschs": "kalesch",
    "kalfaktorer": "kalfaktor",
    "kalfaktorerna": "kalfaktor",
    "kalfaktorernas": "kalfaktor",
    "kalfaktorers": "kalfaktor",
    "kalfaktorn": "kalfaktor",
    "kalfaktorns": "kalfaktor",
    "kalfaktors": "kalfaktor",
    "kalfatrad": "kalfatra",
    "kalfatrade": "kalfatra",
    "kalfatrades": "kalfatra",
    "kalfatrads": "kalfatra",
    "kalfatrande": "kalfatra",
    "kalfatranden": "kalfatrande",
    "kalfatrandena": "kalfatrande",
    "kalfatrandenas": "kalfatrande",
    "kalfatrandens": "kalfatrande",
    "kalfatrandes": "kalfatrande",
    "kalfatrandet": "kalfatrande",
    "kalfatrandets": "kalfatrande",
    "kalfatrar": "kalfatra",
    "kalfatras": "kalfatra",
    "kalfatrat": "kalfatra",
    "kalfatrats": "kalfatra",
    "kalfjällen": "kalfjäll",
    "kalfjällens": "kalfjäll",
    "kalfjället": "kalfjäll",
    "kalfjällets": "kalfjäll",
    "kalfjälls": "kalfjäll",
    "kalheten": "kalhet",
    "kalhetens": "kalhet",
    "kalhets": "kalhet",
    "kalhugg": "kalhugga",
    "kalhuggande": "kalhugga",
    "kalhugganden": "kalhuggande",
    "kalhuggandena": "kalhuggande",
    "kalhuggandenas": "kalhuggande",
    "kalhuggandens": "kalhuggande",
    "kalhuggandes": "kalhuggande",
    "kalhuggandet": "kalhuggande",
    "kalhuggandets": "kalhuggande",
    "kalhuggas": "kalhugga",
    "kalhugge": "kalhugga",
    "kalhuggen": "kalhugga",
    "kalhuggens": "kalhugga",
    "kalhugger": "kalhugga",
    "kalhugges": "kalhugga",
    "kalhugget": "kalhugga",
    "kalhuggets": "kalhugga",
    "kalhuggit": "kalhugga",
    "kalhuggits": "kalhugga",
    "kalhuggna": "kalhugga",
    "kalhuggnas": "kalhugga",
    "kalhuggne": "kalhugga",
    "kalhuggnes": "kalhugga",
    "kalhuggs": "kalhugga",
    "kalhyggen": "kalhygge",
    "kalhyggena": "kalhygge",
    "kalhyggenas": "kalhygge",
    "kalhyggens": "kalhygge",
    "kalhygges": "kalhygge",
    "kalhygget": "kalhygge",
    "kalhyggets": "kalhygge",
    "kalhögg": "kalhugga",
    "kalhögge": "kalhugga",
    "kalhögges": "kalhugga",
    "kalhöggs": "kalhugga",
    "kaliberborrar": "kaliberborr",
    "kaliberborrarna": "kaliberborr",
    "kaliberborrarnas": "kaliberborr",
    "kaliberborrars": "kaliberborr",
    "kaliberborren": "kaliberborr",
    "kaliberborrens": "kaliberborr",
    "kaliberborret": "kaliberborr",
    "kaliberborrets": "kaliberborr",
    "kaliberborrs": "kaliberborr",
    "kalibern": "kaliber",
    "kaliberns": "kaliber",
    "kalibers": "kaliber",
    "kalibertolkar": "kalibertolk",
    "kalibertolkarna": "kalibertolk",
    "kalibertolkarnas": "kalibertolk",
    "kalibertolkars": "kalibertolk",
    "kalibertolken": "kalibertolk",
    "kalibertolkens": "kalibertolk",
    "kalibertolks": "kalibertolk",
    "kalibrar": "kaliber",
    "kalibrarna": "kaliber",
    "kalibrarnas": "kaliber",
    "kalibrars": "kaliber",
    "kalibrer": "kaliber",
    "kalibrerad": "kalibrera",
    "kalibrerade": "kalibrera",
    "kalibrerades": "kalibrera",
    "kalibrerads": "kalibrera",
    "kalibrerande": "kalibrera",
    "kalibreranden": "kalibrerande",
    "kalibrerandena": "kalibrerande",
    "kalibrerandenas": "kalibrerande",
    "kalibrerandens": "kalibrerande",
    "kalibrerandes": "kalibrerande",
    "kalibrerandet": "kalibrerande",
    "kalibrerandets": "kalibrerande",
    "kalibrerar": "kalibrera",
    "kalibreras": "kalibrera",
    "kalibrerat": "kalibrera",
    "kalibrerats": "kalibrera",
    "kalibrerbara": "kalibrerbar",
    "kalibrerbarare": "kalibrerbar",
    "kalibrerbarares": "kalibrerbar",
    "kalibrerbaras": "kalibrerbar",
    "kalibrerbarast": "kalibrerbar",
    "kalibrerbaraste": "kalibrerbar",
    "kalibrerbarastes": "kalibrerbar",
    "kalibrerbarasts": "kalibrerbar",
    "kalibrerbare": "kalibrerbar",
    "kalibrerbares": "kalibrerbar",
    "kalibrerbarheten": "kalibrerbarhet",
    "kalibrerbarhetens": "kalibrerbarhet",
    "kalibrerbarhets": "kalibrerbarhet",
    "kalibrerbars": "kalibrerbar",
    "kalibrerbart": "kalibrerbar",
    "kalibrerbarts": "kalibrerbar",
    "kalibreringar": "kalibrering",
    "kalibreringarna": "kalibrering",
    "kalibreringarnas": "kalibrering",
    "kalibreringars": "kalibrering",
    "kalibreringen": "kalibrering",
    "kalibreringens": "kalibrering",
    "kalibrerings": "kalibrering",
    "kalibreringsknappar": "kalibreringsknapp",
    "kalibreringsknapparna": "kalibreringsknapp",
    "kalibreringsknapparnas": "kalibreringsknapp",
    "kalibreringsknappars": "kalibreringsknapp",
    "kalibreringsknappen": "kalibreringsknapp",
    "kalibreringsknappens": "kalibreringsknapp",
    "kalibreringsknapps": "kalibreringsknapp",
    "kalibrerna": "kaliber",
    "kalibrernas": "kaliber",
    "kalibrers": "kaliber",
    "kaliet": "kalium",
    "kaliets": "kalium",
    "kalifaten": "kalifat",
    "kalifatens": "kalifat",
    "kalifatet": "kalifat",
    "kalifatets": "kalifat",
    "kalifats": "kalifat",
    "kalifen": "kalif",
    "kalifens": "kalif",
    "kalifer": "kalif",
    "kaliferna": "kalif",
    "kalifernas": "kalif",
    "kalifers": "kalif",
    "kalifs": "kalif",
    "kalihungern": "kalihunger",
    "kalihungerns": "kalihunger",
    "kalihungers": "kalihunger",
    "kalikån": "kalikå",
    "kalikåns": "kalikå",
    "kalikås": "kalikå",
    "kaliluten": "kalilut",
    "kalilutens": "kalilut",
    "kaliluts": "kalilut",
    "kalis": "kali",
    "kalisalpetern": "kalisalpeter",
    "kalisalpeterns": "kalisalpeter",
    "kalisalpeters": "kalisalpeter",
    "kalisalter": "kalisalt",
    "kalisalterna": "kalisalt",
    "kalisalternas": "kalisalt",
    "kalisalters": "kalisalt",
    "kalisaltet": "kalisalt",
    "kalisaltets": "kalisalt",
    "kalisalts": "kalisalt",
    "kalit": "kali",
    "kalits": "kali",
    "kaliumet": "kalium",
    "kaliumets": "kalium",
    "kaliumhydroxiden": "kaliumhydroxid",
    "kaliumhydroxidens": "kaliumhydroxid",
    "kaliumhydroxider": "kaliumhydroxid",
    "kaliumhydroxiderna": "kaliumhydroxid",
    "kaliumhydroxidernas": "kaliumhydroxid",
    "kaliumhydroxiders": "kaliumhydroxid",
    "kaliumhydroxids": "kaliumhydroxid",
    "kaliumjonen": "kaliumjon",
    "kaliumjonens": "kaliumjon",
    "kaliumjoner": "kaliumjon",
    "kaliumjonerna": "kaliumjon",
    "kaliumjonernas": "kaliumjon",
    "kaliumjoners": "kaliumjon",
    "kaliumjons": "kaliumjon",
    "kaliumkarbonatet": "kaliumkarbonat",
    "kaliumkarbonatets": "kaliumkarbonat",
    "kaliumkarbonats": "kaliumkarbonat",
    "kaliumkloriden": "kaliumklorid",
    "kaliumkloridens": "kaliumklorid",
    "kaliumklorids": "kaliumklorid",
    "kaliumnitratet": "kaliumnitrat",
    "kaliumnitratets": "kaliumnitrat",
    "kaliumnitrats": "kaliumnitrat",
    "kaliumpermanganatet": "kaliumpermanganat",
    "kaliumpermanganatets": "kaliumpermanganat",
    "kaliumpermanganats": "kaliumpermanganat",
    "kaliums": "kalium",
    "kaliumsulfaten": "kaliumsulfat",
    "kaliumsulfatens": "kaliumsulfat",
    "kaliumsulfatet": "kaliumsulfat",
    "kaliumsulfatets": "kaliumsulfat",
    "kaliumsulfats": "kaliumsulfat",
    "kalk": "kalka",
    "kalkad": "kalka",
    "kalkade": "kalkad",
    "kalkades": "kalkad",
    "kalkads": "kalkad",
    "kalkalgen": "kalkalg",
    "kalkalgens": "kalkalg",
    "kalkalger": "kalkalg",
    "kalkalgerna": "kalkalg",
    "kalkalgernas": "kalkalg",
    "kalkalgers": "kalkalg",
    "kalkalgs": "kalkalg",
    "kalkande": "kalka",
    "kalkanden": "kalkande",
    "kalkandena": "kalkande",
    "kalkandenas": "kalkande",
    "kalkandens": "kalkande",
    "kalkandes": "kalkande",
    "kalkandet": "kalkande",
    "kalkandets": "kalkande",
    "kalkanhopningar": "kalkanhopning",
    "kalkanhopningarna": "kalkanhopning",
    "kalkanhopningarnas": "kalkanhopning",
    "kalkanhopningars": "kalkanhopning",
    "kalkanhopningen": "kalkanhopning",
    "kalkanhopningens": "kalkanhopning",
    "kalkanhopnings": "kalkanhopning",
    "kalkar": "kalka",
    "kalkarna": "kalk",
    "kalkarnas": "kalk",
    "kalkars": "kalk",
    "kalkas": "kalka",
    "kalkat": "kalkad",
    "kalkats": "kalkad",
    "kalkbrotten": "kalkbrott",
    "kalkbrottens": "kalkbrott",
    "kalkbrottet": "kalkbrott",
    "kalkbrottets": "kalkbrott",
    "kalkbrotts": "kalkbrott",
    "kalkbruken": "kalkbruk",
    "kalkbrukens": "kalkbruk",
    "kalkbruket": "kalkbruk",
    "kalkbrukets": "kalkbruk",
    "kalkbruks": "kalkbruk",
    "kalkbrännerier": "kalkbränneri",
    "kalkbrännerierna": "kalkbränneri",
    "kalkbränneriernas": "kalkbränneri",
    "kalkbränneriers": "kalkbränneri",
    "kalkbränneriet": "kalkbränneri",
    "kalkbränneriets": "kalkbränneri",
    "kalkbränneris": "kalkbränneri",
    "kalkbrännerit": "kalkbränneri",
    "kalkbrännerits": "kalkbränneri",
    "kalken": "kalk",
    "kalkens": "kalk",
    "kalker": "kalk",
    "kalkerad": "kalkera",
    "kalkerade": "kalkera",
    "kalkerades": "kalkera",
    "kalkerads": "kalkera",
    "kalkerande": "kalkera",
    "kalkeranden": "kalkerande",
    "kalkerandena": "kalkerande",
    "kalkerandenas": "kalkerande",
    "kalkerandens": "kalkerande",
    "kalkerandes": "kalkerande",
    "kalkerandet": "kalkerande",
    "kalkerandets": "kalkerande",
    "kalkerar": "kalkera",
    "kalkeras": "kalkera",
    "kalkerat": "kalkera",
    "kalkerats": "kalkera",
    "kalkerbara": "kalkerbar",
    "kalkerbarare": "kalkerbar",
    "kalkerbarares": "kalkerbar",
    "kalkerbaras": "kalkerbar",
    "kalkerbarast": "kalkerbar",
    "kalkerbaraste": "kalkerbar",
    "kalkerbarastes": "kalkerbar",
    "kalkerbarasts": "kalkerbar",
    "kalkerbare": "kalkerbar",
    "kalkerbares": "kalkerbar",
    "kalkerbarheten": "kalkerbarhet",
    "kalkerbarhetens": "kalkerbarhet",
    "kalkerbarhets": "kalkerbarhet",
    "kalkerbars": "kalkerbar",
    "kalkerbart": "kalkerbar",
    "kalkerbarts": "kalkerbar",
    "kalkeringar": "kalkering",
    "kalkeringarna": "kalkering",
    "kalkeringarnas": "kalkering",
    "kalkeringars": "kalkering",
    "kalkeringen": "kalkering",
    "kalkeringens": "kalkering",
    "kalkerings": "kalkering",
    "kalkerlärften": "kalkerlärft",
    "kalkerlärftens": "kalkerlärft",
    "kalkerlärftet": "kalkerlärft",
    "kalkerlärftets": "kalkerlärft",
    "kalkerlärfts": "kalkerlärft",
    "kalkerna": "kalk",
    "kalkernas": "kalk",
    "kalkerpapperen": "kalkerpapper",
    "kalkerpapperens": "kalkerpapper",
    "kalkerpapperet": "kalkerpapper",
    "kalkerpapperets": "kalkerpapper",
    "kalkerpapperna": "kalkerpapper",
    "kalkerpappernas": "kalkerpapper",
    "kalkerpappers": "kalkerpapper",
    "kalkerpappren": "kalkerpapper",
    "kalkerpapprens": "kalkerpapper",
    "kalkerpappret": "kalkerpapper",
    "kalkerpapprets": "kalkerpapper",
    "kalkers": "kalk",
    "kalkfattiga": "kalkfattig",
    "kalkfattigare": "kalkfattig",
    "kalkfattigares": "kalkfattig",
    "kalkfattigas": "kalkfattig",
    "kalkfattigast": "kalkfattig",
    "kalkfattigaste": "kalkfattig",
    "kalkfattigastes": "kalkfattig",
    "kalkfattigasts": "kalkfattig",
    "kalkfattige": "kalkfattig",
    "kalkfattiges": "kalkfattig",
    "kalkfattigheten": "kalkfattighet",
    "kalkfattighetens": "kalkfattighet",
    "kalkfattighets": "kalkfattighet",
    "kalkfattigs": "kalkfattig",
    "kalkfattigt": "kalkfattig",
    "kalkfattigts": "kalkfattig",
    "kalkformationen": "kalkformation",
    "kalkformationens": "kalkformation",
    "kalkformationer": "kalkformation",
    "kalkformationerna": "kalkformation",
    "kalkformationernas": "kalkformation",
    "kalkformationers": "kalkformation",
    "kalkformations": "kalkformation",
    "kalkfärgen": "kalkfärg",
    "kalkfärgens": "kalkfärg",
    "kalkfärger": "kalkfärg",
    "kalkfärgerna": "kalkfärg",
    "kalkfärgernas": "kalkfärg",
    "kalkfärgers": "kalkfärg",
    "kalkfärgs": "kalkfärg",
    "kalkgrunden": "kalkgrund",
    "kalkgrundens": "kalkgrund",
    "kalkgrunder": "kalkgrund",
    "kalkgrunderna": "kalkgrund",
    "kalkgrundernas": "kalkgrund",
    "kalkgrunders": "kalkgrund",
    "kalkgrunds": "kalkgrund",
    "kalkhalten": "kalkhalt",
    "kalkhaltens": "kalkhalt",
    "kalkhalter": "kalkhalt",
    "kalkhalterna": "kalkhalt",
    "kalkhalternas": "kalkhalt",
    "kalkhalters": "kalkhalt",
    "kalkhaltiga": "kalkhaltig",
    "kalkhaltigare": "kalkhaltig",
    "kalkhaltigares": "kalkhaltig",
    "kalkhaltigas": "kalkhaltig",
    "kalkhaltigast": "kalkhaltig",
    "kalkhaltigaste": "kalkhaltig",
    "kalkhaltigastes": "kalkhaltig",
    "kalkhaltigasts": "kalkhaltig",
    "kalkhaltige": "kalkhaltig",
    "kalkhaltiges": "kalkhaltig",
    "kalkhaltigs": "kalkhaltig",
    "kalkhaltigt": "kalkhaltig",
    "kalkhaltigts": "kalkhaltig",
    "kalkhalts": "kalkhalt",
    "kalkjonen": "kalkjon",
    "kalkjonens": "kalkjon",
    "kalkjoner": "kalkjon",
    "kalkjonerna": "kalkjon",
    "kalkjonernas": "kalkjon",
    "kalkjoners": "kalkjon",
    "kalkjons": "kalkjon",
    "kalkkväves": "kalkkväve",
    "kalkkvävet": "kalkkväve",
    "kalkkvävets": "kalkkväve",
    "kalkljuset": "kalkljus",
    "kalkljusets": "kalkljus",
    "kalkmjölet": "kalkmjöl",
    "kalkmjölets": "kalkmjöl",
    "kalkmjölken": "kalkmjölk",
    "kalkmjölkens": "kalkmjölk",
    "kalkmjölks": "kalkmjölk",
    "kalkmjöls": "kalkmjöl",
    "kalkmålningar": "kalkmålning",
    "kalkmålningarna": "kalkmålning",
    "kalkmålningarnas": "kalkmålning",
    "kalkmålningars": "kalkmålning",
    "kalkmålningen": "kalkmålning",
    "kalkmålningens": "kalkmålning",
    "kalkmålnings": "kalkmålning",
    "kalkomanien": "kalkomani",
    "kalkomaniens": "kalkomani",
    "kalkomanier": "kalkomani",
    "kalkomanierna": "kalkomani",
    "kalkomaniernas": "kalkomani",
    "kalkomaniers": "kalkomani",
    "kalkomanin": "kalkomani",
    "kalkomanins": "kalkomani",
    "kalkomanis": "kalkomani",
    "kalkonen": "kalkon",
    "kalkonens": "kalkon",
    "kalkoner": "kalkon",
    "kalkonerna": "kalkon",
    "kalkonernas": "kalkon",
    "kalkoners": "kalkon",
    "kalkonköttet": "kalkonkött",
    "kalkonköttets": "kalkonkött",
    "kalkonkötts": "kalkonkött",
    "kalkonmässiga": "kalkonmässig",
    "kalkonmässigare": "kalkonmässig",
    "kalkonmässigares": "kalkonmässig",
    "kalkonmässigas": "kalkonmässig",
    "kalkonmässigast": "kalkonmässig",
    "kalkonmässigaste": "kalkonmässig",
    "kalkonmässigastes": "kalkonmässig",
    "kalkonmässigasts": "kalkonmässig",
    "kalkonmässige": "kalkonmässig",
    "kalkonmässiges": "kalkonmässig",
    "kalkonmässigs": "kalkonmässig",
    "kalkonmässigt": "kalkonmässig",
    "kalkonmässigts": "kalkonmässig",
    "kalkonrull": "kalkonrulle",
    "kalkonrullar": "kalkonrulle",
    "kalkonrullarna": "kalkonrulle",
    "kalkonrullarnas": "kalkonrulle",
    "kalkonrullars": "kalkonrulle",
    "kalkonrullen": "kalkonrulle",
    "kalkonrullens": "kalkonrulle",
    "kalkonrulles": "kalkonrulle",
    "kalkonrulls": "kalkonrulle",
    "kalkons": "kalkon",
    "kalkonsmörgåsar": "kalkonsmörgås",
    "kalkonsmörgåsarna": "kalkonsmörgås",
    "kalkonsmörgåsarnas": "kalkonsmörgås",
    "kalkonsmörgåsars": "kalkonsmörgås",
    "kalkonsmörgåsen": "kalkonsmörgås",
    "kalkonsmörgåsens": "kalkonsmörgås",
    "kalkputsen": "kalkputs",
    "kalkputsens": "kalkputs",
    "kalkresten": "kalkrest",
    "kalkrestens": "kalkrest",
    "kalkrester": "kalkrest",
    "kalkresterna": "kalkrest",
    "kalkresternas": "kalkrest",
    "kalkresters": "kalkrest",
    "kalkrests": "kalkrest",
    "kalkrika": "kalkrik",
    "kalkrikare": "kalkrik",
    "kalkrikares": "kalkrik",
    "kalkrikas": "kalkrik",
    "kalkrikast": "kalkrik",
    "kalkrikaste": "kalkrik",
    "kalkrikastes": "kalkrik",
    "kalkrikasts": "kalkrik",
    "kalkrike": "kalkrik",
    "kalkrikes": "kalkrik",
    "kalkrikheten": "kalkrikhet",
    "kalkrikhetens": "kalkrikhet",
    "kalkrikhets": "kalkrikhet",
    "kalkriks": "kalkrik",
    "kalkrikt": "kalkrik",
    "kalkrikts": "kalkrik",
    "kalks": "kalk",
    "kalksedimenten": "kalksediment",
    "kalksedimentens": "kalksediment",
    "kalksedimentet": "kalksediment",
    "kalksedimentets": "kalksediment",
    "kalksediments": "kalksediment",
    "kalkskalen": "kalkskal",
    "kalkskalens": "kalkskal",
    "kalkskalet": "kalkskal",
    "kalkskalets": "kalkskal",
    "kalkskals": "kalkskal",
    "kalkslagen": "kalkslå",
    "kalkslagens": "kalkslå",
    "kalkslaget": "kalkslå",
    "kalkslagets": "kalkslå",
    "kalkslagit": "kalkslå",
    "kalkslagits": "kalkslå",
    "kalkslagna": "kalkslå",
    "kalkslagnas": "kalkslå",
    "kalkslagne": "kalkslå",
    "kalkslagnes": "kalkslå",
    "kalkslog": "kalkslå",
    "kalksloge": "kalkslå",
    "kalksloges": "kalkslå",
    "kalkslogs": "kalkslå",
    "kalkslående": "kalkslå",
    "kalkslåenden": "kalkslående",
    "kalkslåendena": "kalkslående",
    "kalkslåendenas": "kalkslående",
    "kalkslåendens": "kalkslående",
    "kalkslåendes": "kalkslående",
    "kalkslåendet": "kalkslående",
    "kalkslåendets": "kalkslående",
    "kalkslår": "kalkslå",
    "kalkslås": "kalkslå",
    "kalkspaten": "kalkspat",
    "kalkspatens": "kalkspat",
    "kalkspats": "kalkspat",
    "kalkstenen": "kalksten",
    "kalkstenens": "kalksten",
    "kalkstens": "kalksten",
    "kalkstenshällar": "kalkstenshäll",
    "kalkstenshällarna": "kalkstenshäll",
    "kalkstenshällarnas": "kalkstenshäll",
    "kalkstenshällars": "kalkstenshäll",
    "kalkstenshällen": "kalkstenshäll",
    "kalkstenshällens": "kalkstenshäll",
    "kalkstenshälls": "kalkstenshäll",
    "kalkstensplatt": "kalkstensplatta",
    "kalkstensplattan": "kalkstensplatta",
    "kalkstensplattans": "kalkstensplatta",
    "kalkstensplattas": "kalkstensplatta",
    "kalkstensplatte": "kalkstensplatta",
    "kalkstensplattor": "kalkstensplatta",
    "kalkstensplattorna": "kalkstensplatta",
    "kalkstensplattornas": "kalkstensplatta",
    "kalkstensplattors": "kalkstensplatta",
    "kalkstensplatts": "kalkstensplatta",
    "kalkstensväggar": "kalkstensvägg",
    "kalkstensväggarna": "kalkstensvägg",
    "kalkstensväggarnas": "kalkstensvägg",
    "kalkstensväggars": "kalkstensvägg",
    "kalkstensväggen": "kalkstensvägg",
    "kalkstensväggens": "kalkstensvägg",
    "kalkstensväggs": "kalkstensvägg",
    "kalkströet": "kalkströ",
    "kalkströets": "kalkströ",
    "kalkströs": "kalkströ",
    "kalkströt": "kalkströ",
    "kalkströts": "kalkströ",
    "kalktuffen": "kalktuff",
    "kalktuffens": "kalktuff",
    "kalktuffer": "kalktuff",
    "kalktufferna": "kalktuff",
    "kalktuffernas": "kalktuff",
    "kalktuffers": "kalktuff",
    "kalktuffs": "kalktuff",
    "kalkugnar": "kalkugn",
    "kalkugnarna": "kalkugn",
    "kalkugnarnas": "kalkugn",
    "kalkugnars": "kalkugn",
    "kalkugnen": "kalkugn",
    "kalkugnens": "kalkugn",
    "kalkugns": "kalkugn",
    "kalkvattenbeständiga": "kalkvattenbeständig",
    "kalkvattenbeständigare": "kalkvattenbeständig",
    "kalkvattenbeständigares": "kalkvattenbeständig",
    "kalkvattenbeständigas": "kalkvattenbeständig",
    "kalkvattenbeständigast": "kalkvattenbeständig",
    "kalkvattenbeständigaste": "kalkvattenbeständig",
    "kalkvattenbeständigastes": "kalkvattenbeständig",
    "kalkvattenbeständigasts": "kalkvattenbeständig",
    "kalkvattenbeständige": "kalkvattenbeständig",
    "kalkvattenbeständiges": "kalkvattenbeständig",
    "kalkvattenbeständigs": "kalkvattenbeständig",
    "kalkvattenbeständigt": "kalkvattenbeständig",
    "kalkvattenbeständigts": "kalkvattenbeständig",
    "kalkvattens": "kalkvatten",
    "kalkvattnet": "kalkvatten",
    "kalkvattnets": "kalkvatten",
    "kalkvita": "kalkvit",
    "kalkvitare": "kalkvit",
    "kalkvitares": "kalkvit",
    "kalkvitas": "kalkvit",
    "kalkvitast": "kalkvit",
    "kalkvitaste": "kalkvit",
    "kalkvitastes": "kalkvit",
    "kalkvitasts": "kalkvit",
    "kalkvite": "kalkvit",
    "kalkvites": "kalkvit",
    "kalkvits": "kalkvit",
    "kalkvitt": "kalkvit",
    "kalkvitts": "kalkvit",
    "kalkylarken": "kalkylark",
    "kalkylarkens": "kalkylark",
    "kalkylarket": "kalkylark",
    "kalkylarkets": "kalkylark",
    "kalkylarks": "kalkylark",
    "kalkylatorer": "kalkylator",
    "kalkylatorerna": "kalkylator",
    "kalkylatorernas": "kalkylator",
    "kalkylatorers": "kalkylator",
    "kalkylatorn": "kalkylator",
    "kalkylatorns": "kalkylator",
    "kalkylators": "kalkylator",
    "kalkylen": "kalkyl",
    "kalkylens": "kalkyl",
    "kalkyler": "kalkyl",
    "kalkylerad": "kalkylera",
    "kalkylerade": "kalkylera",
    "kalkylerades": "kalkylera",
    "kalkylerads": "kalkylera",
    "kalkylerande": "kalkylera",
    "kalkyleranden": "kalkylerande",
    "kalkylerandena": "kalkylerande",
    "kalkylerandenas": "kalkylerande",
    "kalkylerandens": "kalkylerande",
    "kalkylerandes": "kalkylerande",
    "kalkylerandet": "kalkylerande",
    "kalkylerandets": "kalkylerande",
    "kalkylerar": "kalkylera",
    "kalkyleras": "kalkylera",
    "kalkylerat": "kalkylera",
    "kalkylerats": "kalkylera",
    "kalkylerbara": "kalkylerbar",
    "kalkylerbarare": "kalkylerbar",
    "kalkylerbarares": "kalkylerbar",
    "kalkylerbaras": "kalkylerbar",
    "kalkylerbarast": "kalkylerbar",
    "kalkylerbaraste": "kalkylerbar",
    "kalkylerbarastes": "kalkylerbar",
    "kalkylerbarasts": "kalkylerbar",
    "kalkylerbare": "kalkylerbar",
    "kalkylerbares": "kalkylerbar",
    "kalkylerbarheten": "kalkylerbarhet",
    "kalkylerbarhetens": "kalkylerbarhet",
    "kalkylerbarhets": "kalkylerbarhet",
    "kalkylerbars": "kalkylerbar",
    "kalkylerbart": "kalkylerbar",
    "kalkylerbarts": "kalkylerbar",
    "kalkyleringar": "kalkylering",
    "kalkyleringarna": "kalkylering",
    "kalkyleringarnas": "kalkylering",
    "kalkyleringars": "kalkylering",
    "kalkyleringen": "kalkylering",
    "kalkyleringens": "kalkylering",
    "kalkylerings": "kalkylering",
    "kalkylerna": "kalkyl",
    "kalkylernas": "kalkyl",
    "kalkylers": "kalkyl",
    "kalkylmässiga": "kalkylmässig",
    "kalkylmässigare": "kalkylmässig",
    "kalkylmässigares": "kalkylmässig",
    "kalkylmässigas": "kalkylmässig",
    "kalkylmässigast": "kalkylmässig",
    "kalkylmässigaste": "kalkylmässig",
    "kalkylmässigastes": "kalkylmässig",
    "kalkylmässigasts": "kalkylmässig",
    "kalkylmässige": "kalkylmässig",
    "kalkylmässiges": "kalkylmässig",
    "kalkylmässigs": "kalkylmässig",
    "kalkylmässigt": "kalkylmässig",
    "kalkylmässigts": "kalkylmässig",
    "kalkyls": "kalkyl",
    "kall": "kalla",
    "kalla": "kall",
    "kallad": "kalla",
    "kallade": "kalla",
    "kallades": "kalla",
    "kallads": "kalla",
    "kallan": "kalla",
    "kallande": "kalla",
    "kallanden": "kallande",
    "kallandena": "kallande",
    "kallandenas": "kallande",
    "kallandens": "kallande",
    "kallandes": "kallande",
    "kallandet": "kallande",
    "kallandets": "kallande",
    "kallans": "kalla",
    "kallar": "kalla",
    "kallarbet": "kallarbeta",
    "kallarbetad": "kallarbeta",
    "kallarbetade": "kallarbeta",
    "kallarbetades": "kallarbeta",
    "kallarbetads": "kallarbeta",
    "kallarbetande": "kallarbeta",
    "kallarbetanden": "kallarbetande",
    "kallarbetandena": "kallarbetande",
    "kallarbetandenas": "kallarbetande",
    "kallarbetandens": "kallarbetande",
    "kallarbetandes": "kallarbetande",
    "kallarbetandet": "kallarbetande",
    "kallarbetandets": "kallarbetande",
    "kallarbetar": "kallarbeta",
    "kallarbetas": "kallarbeta",
    "kallarbetat": "kallarbeta",
    "kallarbetats": "kallarbeta",
    "kallare": "kall",
    "kallares": "kall",
    "kallas": "kalla",
    "kallast": "kall",
    "kallaste": "kall",
    "kallastes": "kall",
    "kallasts": "kall",
    "kallat": "kalla",
    "kallats": "kalla",
    "kallavfettningen": "kallavfettning",
    "kallavfettningens": "kallavfettning",
    "kallavfettnings": "kallavfettning",
    "kallbaden": "kallbad",
    "kallbadens": "kallbad",
    "kallbadet": "kallbad",
    "kallbadets": "kallbad",
    "kallbads": "kallbad",
    "kallbearbet": "kallbearbeta",
    "kallbearbetad": "kallbearbeta",
    "kallbearbetade": "kallbearbeta",
    "kallbearbetades": "kallbearbeta",
    "kallbearbetads": "kallbearbeta",
    "kallbearbetande": "kallbearbeta",
    "kallbearbetanden": "kallbearbetande",
    "kallbearbetandena": "kallbearbetande",
    "kallbearbetandenas": "kallbearbetande",
    "kallbearbetandens": "kallbearbetande",
    "kallbearbetandes": "kallbearbetande",
    "kallbearbetandet": "kallbearbetande",
    "kallbearbetandets": "kallbearbetande",
    "kallbearbetar": "kallbearbeta",
    "kallbearbetas": "kallbearbeta",
    "kallbearbetat": "kallbearbeta",
    "kallbearbetats": "kallbearbeta",
    "kallbloden": "kallblod",
    "kallblodens": "kallblod",
    "kallblodet": "kallblod",
    "kallblodets": "kallblod",
    "kallblodiga": "kallblodig",
    "kallblodigare": "kallblodig",
    "kallblodigares": "kallblodig",
    "kallblodigas": "kallblodig",
    "kallblodigast": "kallblodig",
    "kallblodigaste": "kallblodig",
    "kallblodigastes": "kallblodig",
    "kallblodigasts": "kallblodig",
    "kallblodige": "kallblodig",
    "kallblodiges": "kallblodig",
    "kallblodigheten": "kallblodighet",
    "kallblodighetens": "kallblodighet",
    "kallblodigheter": "kallblodighet",
    "kallblodigheterna": "kallblodighet",
    "kallblodigheternas": "kallblodighet",
    "kallblodigheters": "kallblodighet",
    "kallblodighets": "kallblodighet",
    "kallblodigs": "kallblodig",
    "kallblodigt": "kallblodig",
    "kallblodigts": "kallblodig",
    "kallblods": "kallblod",
    "kallbock": "kallbocka",
    "kallbockad": "kallbocka",
    "kallbockade": "kallbocka",
    "kallbockades": "kallbocka",
    "kallbockads": "kallbocka",
    "kallbockande": "kallbocka",
    "kallbockanden": "kallbockande",
    "kallbockandena": "kallbockande",
    "kallbockandenas": "kallbockande",
    "kallbockandens": "kallbockande",
    "kallbockandes": "kallbockande",
    "kallbockandet": "kallbockande",
    "kallbockandets": "kallbockande",
    "kallbockar": "kallbocka",
    "kallbockas": "kallbocka",
    "kallbockat": "kallbocka",
    "kallbockats": "kallbocka",
    "kallbranden": "kallbrand",
    "kallbrandens": "kallbrand",
    "kallbrands": "kallbrand",
    "kallbräckan": "kallbräcka",
    "kallbräckans": "kallbräcka",
    "kallbräckas": "kallbräcka",
    "kallbänkar": "kallbänk",
    "kallbänkarna": "kallbänk",
    "kallbänkarnas": "kallbänk",
    "kallbänkars": "kallbänk",
    "kallbänken": "kallbänk",
    "kallbänkens": "kallbänk",
    "kallbänks": "kallbänk",
    "kalldrag": "kalldra",
    "kalldraga": "kalldra",
    "kalldragande": "kalldra",
    "kalldraganden": "kalldragande",
    "kalldragandena": "kalldragande",
    "kalldragandenas": "kalldragande",
    "kalldragandens": "kalldragande",
    "kalldragandes": "kalldragande",
    "kalldragandet": "kalldragande",
    "kalldragandets": "kalldragande",
    "kalldragas": "kalldra",
    "kalldrage": "kalldra",
    "kalldragen": "kalldra",
    "kalldragens": "kalldra",
    "kalldrager": "kalldra",
    "kalldrages": "kalldra",
    "kalldraget": "kalldra",
    "kalldragets": "kalldra",
    "kalldragit": "kalldra",
    "kalldragits": "kalldra",
    "kalldragna": "kalldra",
    "kalldragnas": "kalldra",
    "kalldragne": "kalldra",
    "kalldragnes": "kalldra",
    "kalldrags": "kalldra",
    "kalldrar": "kalldra",
    "kalldras": "kalldra",
    "kalldrog": "kalldra",
    "kalldroge": "kalldra",
    "kalldroges": "kalldra",
    "kalldrogs": "kalldra",
    "kallduschar": "kalldusch",
    "kallduscharna": "kalldusch",
    "kallduscharnas": "kalldusch",
    "kallduschars": "kalldusch",
    "kallduschen": "kalldusch",
    "kallduschens": "kalldusch",
    "kallduschs": "kalldusch",
    "kalle": "kalla",
    "kallelsebesluten": "kallelsebeslut",
    "kallelsebeslutens": "kallelsebeslut",
    "kallelsebeslutet": "kallelsebeslut",
    "kallelsebeslutets": "kallelsebeslut",
    "kallelsebesluts": "kallelsebeslut",
    "kallelsebreven": "kallelsebrev",
    "kallelsebrevens": "kallelsebrev",
    "kallelsebrevet": "kallelsebrev",
    "kallelsebrevets": "kallelsebrev",
    "kallelsebrevs": "kallelsebrev",
    "kallelseförslagen": "kallelseförslag",
    "kallelseförslagens": "kallelseförslag",
    "kallelseförslaget": "kallelseförslag",
    "kallelseförslagets": "kallelseförslag",
    "kallelseförslags": "kallelseförslag",
    "kallelsegärningar": "kallelsegärning",
    "kallelsegärningarna": "kallelsegärning",
    "kallelsegärningarnas": "kallelsegärning",
    "kallelsegärningars": "kallelsegärning",
    "kallelsegärningen": "kallelsegärning",
    "kallelsegärningens": "kallelsegärning",
    "kallelsegärnings": "kallelsegärning",
    "kallelselistan": "kallelselista",
    "kallelselistans": "kallelselista",
    "kallelselistas": "kallelselista",
    "kallelseliste": "kallelselista",
    "kallelselistor": "kallelselista",
    "kallelselistorna": "kallelselista",
    "kallelselistornas": "kallelselista",
    "kallelselistors": "kallelselista",
    "kallelsen": "kallelse",
    "kallelsens": "kallelse",
    "kallelser": "kallelse",
    "kallelserna": "kallelse",
    "kallelsernas": "kallelse",
    "kallelsers": "kallelse",
    "kallelserätten": "kallelserätt",
    "kallelserättens": "kallelserätt",
    "kallelserätts": "kallelserätt",
    "kallelses": "kallelse",
    "kallelsetiden": "kallelsetid",
    "kallelsetidens": "kallelsetid",
    "kallelsetider": "kallelsetid",
    "kallelsetiderna": "kallelsetid",
    "kallelsetidernas": "kallelsetid",
    "kallelsetiders": "kallelsetid",
    "kallelsetids": "kallelsetid",
    "kallen": "kall",
    "kallens": "kall",
    "kalles": "kall",
    "kallet": "kall",
    "kallets": "kall",
    "kallfronten": "kallfront",
    "kallfrontens": "kallfront",
    "kallfronter": "kallfront",
    "kallfronterna": "kallfront",
    "kallfronternas": "kallfront",
    "kallfronters": "kallfront",
    "kallfronts": "kallfront",
    "kallgaragen": "kallgarage",
    "kallgaragens": "kallgarage",
    "kallgarages": "kallgarage",
    "kallgaraget": "kallgarage",
    "kallgaragets": "kallgarage",
    "kallgrinade": "kallgrina",
    "kallgrinades": "kallgrina",
    "kallgrinande": "kallgrina",
    "kallgrinanden": "kallgrinande",
    "kallgrinandena": "kallgrinande",
    "kallgrinandenas": "kallgrinande",
    "kallgrinandens": "kallgrinande",
    "kallgrinandes": "kallgrinande",
    "kallgrinandet": "kallgrinande",
    "kallgrinandets": "kallgrinande",
    "kallgrinar": "kallgrina",
    "kallgrinas": "kallgrina",
    "kallgrinat": "kallgrina",
    "kallgrinats": "kallgrina",
    "kallgrinen": "kallgrin",
    "kallgrinens": "kallgrin",
    "kallgrinet": "kallgrin",
    "kallgrinets": "kallgrin",
    "kallgrins": "kallgrin",
    "kallhamrad": "kallhamra",
    "kallhamrade": "kallhamrad",
    "kallhamrades": "kallhamrad",
    "kallhamrads": "kallhamrad",
    "kallhamrande": "kallhamra",
    "kallhamranden": "kallhamrande",
    "kallhamrandena": "kallhamrande",
    "kallhamrandenas": "kallhamrande",
    "kallhamrandens": "kallhamrande",
    "kallhamrandes": "kallhamrande",
    "kallhamrandet": "kallhamrande",
    "kallhamrandets": "kallhamrande",
    "kallhamrar": "kallhamra",
    "kallhamras": "kallhamra",
    "kallhamrat": "kallhamrad",
    "kallhamrats": "kallhamrad",
    "kallhusen": "kallhus",
    "kallhusens": "kallhus",
    "kallhuset": "kallhus",
    "kallhusets": "kallhus",
    "kallhyr": "kallhyra",
    "kallhyran": "kallhyra",
    "kallhyrans": "kallhyra",
    "kallhyras": "kallhyra",
    "kallhyre": "kallhyra",
    "kallhyror": "kallhyra",
    "kallhyrorna": "kallhyra",
    "kallhyrornas": "kallhyra",
    "kallhyrors": "kallhyra",
    "kallhyrs": "kallhyra",
    "kalligrafien": "kalligrafi",
    "kalligrafiens": "kalligrafi",
    "kalligrafin": "kalligrafi",
    "kalligrafins": "kalligrafi",
    "kalligrafis": "kalligrafi",
    "kallimmet": "kallim",
    "kallimmets": "kallim",
    "kallims": "kallim",
    "kallingar": "kalling",
    "kallingarna": "kalling",
    "kallingarnas": "kalling",
    "kallingars": "kalling",
    "kallingen": "kalling",
    "kallingens": "kalling",
    "kallings": "kalling",
    "kalljorden": "kalljord",
    "kalljordens": "kalljord",
    "kalljords": "kalljord",
    "kallkäll": "kallkälla",
    "kallkällan": "kallkälla",
    "kallkällans": "kallkälla",
    "kallkällas": "kallkälla",
    "kallkälle": "kallkälla",
    "kallkällor": "kallkälla",
    "kallkällorna": "kallkälla",
    "kallkällornas": "kallkälla",
    "kallkällors": "kallkälla",
    "kallkälls": "kallkälla",
    "kallmangel": "kallmangla",
    "kallmangeln": "kallmangel",
    "kallmangelns": "kallmangel",
    "kallmangels": "kallmangel",
    "kallmanglad": "kallmangla",
    "kallmanglade": "kallmangla",
    "kallmanglades": "kallmangla",
    "kallmanglads": "kallmangla",
    "kallmanglande": "kallmangla",
    "kallmanglanden": "kallmanglande",
    "kallmanglandena": "kallmanglande",
    "kallmanglandenas": "kallmanglande",
    "kallmanglandens": "kallmanglande",
    "kallmanglandes": "kallmanglande",
    "kallmanglandet": "kallmanglande",
    "kallmanglandets": "kallmanglande",
    "kallmanglar": "kallmangla",
    "kallmanglarna": "kallmangel",
    "kallmanglarnas": "kallmangel",
    "kallmanglars": "kallmangel",
    "kallmanglas": "kallmangla",
    "kallmanglat": "kallmangla",
    "kallmanglats": "kallmangla",
    "kallmurar": "kallmur",
    "kallmurarna": "kallmur",
    "kallmurarnas": "kallmur",
    "kallmurars": "kallmur",
    "kallmuren": "kallmur",
    "kallmurens": "kallmur",
    "kallmurs": "kallmur",
    "kalln": "kallna",
    "kallnad": "kallna",
    "kallnade": "kallna",
    "kallnades": "kallna",
    "kallnads": "kallna",
    "kallnande": "kallna",
    "kallnanden": "kallnande",
    "kallnandena": "kallnande",
    "kallnandenas": "kallnande",
    "kallnandens": "kallnande",
    "kallnandes": "kallnande",
    "kallnandet": "kallnande",
    "kallnandets": "kallnande",
    "kallnar": "kallna",
    "kallnas": "kallna",
    "kallnat": "kallna",
    "kallnats": "kallna",
    "kallnålar": "kallnål",
    "kallnålarna": "kallnål",
    "kallnålarnas": "kallnål",
    "kallnålars": "kallnål",
    "kallnålen": "kallnål",
    "kallnålens": "kallnål",
    "kallnåls": "kallnål",
    "kallor": "kalla",
    "kallorna": "kalla",
    "kallornas": "kalla",
    "kallors": "kalla",
    "kallortstilläggen": "kallortstillägg",
    "kallortstilläggens": "kallortstillägg",
    "kallortstillägget": "kallortstillägg",
    "kallortstilläggets": "kallortstillägg",
    "kallortstilläggs": "kallortstillägg",
    "kallpermanenten": "kallpermanent",
    "kallpermanentens": "kallpermanent",
    "kallpermanents": "kallpermanent",
    "kallpratade": "kallprata",
    "kallpratades": "kallprata",
    "kallpratande": "kallprata",
    "kallpratanden": "kallpratande",
    "kallpratandena": "kallpratande",
    "kallpratandenas": "kallpratande",
    "kallpratandens": "kallpratande",
    "kallpratandes": "kallpratande",
    "kallpratandet": "kallpratande",
    "kallpratandets": "kallpratande",
    "kallpratar": "kallprata",
    "kallpratas": "kallprata",
    "kallpratat": "kallprata",
    "kallpratats": "kallprata",
    "kallpratet": "kallprat",
    "kallpratets": "kallprat",
    "kallprats": "kallprat",
    "kallpress": "kallpressa",
    "kallpressad": "kallpressa",
    "kallpressade": "kallpressa",
    "kallpressades": "kallpressa",
    "kallpressads": "kallpressa",
    "kallpressande": "kallpressa",
    "kallpressanden": "kallpressande",
    "kallpressandena": "kallpressande",
    "kallpressandenas": "kallpressande",
    "kallpressandens": "kallpressande",
    "kallpressandes": "kallpressande",
    "kallpressandet": "kallpressande",
    "kallpressandets": "kallpressande",
    "kallpressar": "kallpressa",
    "kallpressas": "kallpressa",
    "kallpressat": "kallpressa",
    "kallpressats": "kallpressa",
    "kallpunkten": "kallpunkt",
    "kallpunktens": "kallpunkt",
    "kallpunkter": "kallpunkt",
    "kallpunkterna": "kallpunkt",
    "kallpunkternas": "kallpunkt",
    "kallpunkters": "kallpunkt",
    "kallpunkts": "kallpunkt",
    "kallrök": "kallröka",
    "kallrökande": "kallröka",
    "kallrökanden": "kallrökande",
    "kallrökandena": "kallrökande",
    "kallrökandenas": "kallrökande",
    "kallrökandens": "kallrökande",
    "kallrökandes": "kallrökande",
    "kallrökandet": "kallrökande",
    "kallrökandets": "kallrökande",
    "kallrökas": "kallröka",
    "kallröker": "kallröka",
    "kallrökes": "kallröka",
    "kallröks": "kallröka",
    "kallrökt": "kallröka",
    "kallrökta": "kallröka",
    "kallröktas": "kallröka",
    "kallrökte": "kallröka",
    "kallröktes": "kallröka",
    "kallrökts": "kallröka",
    "kallrör": "kallröra",
    "kallrörande": "kallröra",
    "kallröranden": "kallrörande",
    "kallrörandena": "kallrörande",
    "kallrörandenas": "kallrörande",
    "kallrörandens": "kallrörande",
    "kallrörandes": "kallrörande",
    "kallrörandet": "kallrörande",
    "kallrörandets": "kallrörande",
    "kallröras": "kallröra",
    "kallrörd": "kallröra",
    "kallrörda": "kallröra",
    "kallrördas": "kallröra",
    "kallrörde": "kallröra",
    "kallrördes": "kallröra",
    "kallrörds": "kallröra",
    "kallröres": "kallröra",
    "kallrörs": "kallröra",
    "kallrört": "kallröra",
    "kallrörts": "kallröra",
    "kalls": "kalla",
    "kallsinnes": "kallsinne",
    "kallsinnet": "kallsinne",
    "kallsinnets": "kallsinne",
    "kallsinniga": "kallsinnig",
    "kallsinnigare": "kallsinnig",
    "kallsinnigares": "kallsinnig",
    "kallsinnigas": "kallsinnig",
    "kallsinnigast": "kallsinnig",
    "kallsinnigaste": "kallsinnig",
    "kallsinnigastes": "kallsinnig",
    "kallsinnigasts": "kallsinnig",
    "kallsinnige": "kallsinnig",
    "kallsinniges": "kallsinnig",
    "kallsinnigheten": "kallsinnighet",
    "kallsinnighetens": "kallsinnighet",
    "kallsinnighets": "kallsinnighet",
    "kallsinnigs": "kallsinnig",
    "kallsinnigt": "kallsinnig",
    "kallsinnigts": "kallsinnig",
    "kallskurens": "kallskuren",
    "kallskuret": "kallskuren",
    "kallskurets": "kallskuret",
    "kallskurna": "kallskuren",
    "kallskurnare": "kallskuren",
    "kallskurnares": "kallskuren",
    "kallskurnas": "kallskuren",
    "kallskurnast": "kallskuren",
    "kallskurnaste": "kallskuren",
    "kallskurnastes": "kallskuren",
    "kallskurnasts": "kallskuren",
    "kallskurne": "kallskuren",
    "kallskurnes": "kallskuren",
    "kallskänk": "kallskänka",
    "kallskänkan": "kallskänka",
    "kallskänkans": "kallskänka",
    "kallskänkar": "kallskänk",
    "kallskänkarna": "kallskänk",
    "kallskänkarnas": "kallskänk",
    "kallskänkars": "kallskänk",
    "kallskänkas": "kallskänka",
    "kallskänke": "kallskänka",
    "kallskänken": "kallskänk",
    "kallskänkens": "kallskänk",
    "kallskänkor": "kallskänka",
    "kallskänkorna": "kallskänka",
    "kallskänkornas": "kallskänka",
    "kallskänkors": "kallskänka",
    "kallskänks": "kallskänka",
    "kallskålen": "kallskål",
    "kallskålens": "kallskål",
    "kallskåls": "kallskål",
    "kallsmid": "kallsmida",
    "kallsmidande": "kallsmida",
    "kallsmidanden": "kallsmidande",
    "kallsmidandena": "kallsmidande",
    "kallsmidandenas": "kallsmidande",
    "kallsmidandens": "kallsmidande",
    "kallsmidandes": "kallsmidande",
    "kallsmidandet": "kallsmidande",
    "kallsmidandets": "kallsmidande",
    "kallsmidas": "kallsmida",
    "kallsmidd": "kallsmida",
    "kallsmidda": "kallsmida",
    "kallsmiddas": "kallsmida",
    "kallsmidde": "kallsmida",
    "kallsmiddes": "kallsmida",
    "kallsmidds": "kallsmida",
    "kallsmider": "kallsmida",
    "kallsmides": "kallsmida",
    "kallsmids": "kallsmida",
    "kallsmitt": "kallsmida",
    "kallsmitts": "kallsmida",
    "kallstarten": "kallstart",
    "kallstartens": "kallstart",
    "kallstarter": "kallstart",
    "kallstarterna": "kallstart",
    "kallstarternas": "kallstart",
    "kallstarters": "kallstart",
    "kallstarts": "kallstart",
    "kallsupar": "kallsup",
    "kallsuparna": "kallsup",
    "kallsuparnas": "kallsup",
    "kallsupars": "kallsup",
    "kallsupen": "kallsup",
    "kallsupens": "kallsup",
    "kallsups": "kallsup",
    "kallsvettades": "kallsvettas",
    "kallsvettats": "kallsvettas",
    "kallsvetten": "kallsvett",
    "kallsvettens": "kallsvett",
    "kallsvetts": "kallsvett",
    "kallsågar": "kallsåg",
    "kallsågarna": "kallsåg",
    "kallsågarnas": "kallsåg",
    "kallsågars": "kallsåg",
    "kallsågen": "kallsåg",
    "kallsågens": "kallsåg",
    "kallsågs": "kallsåg",
    "kallt": "kall",
    "kallts": "kall",
    "kalluften": "kalluft",
    "kalluftens": "kalluft",
    "kallufts": "kalluft",
    "kalluftsfläktar": "kalluftsfläkt",
    "kalluftsfläktarna": "kalluftsfläkt",
    "kalluftsfläktarnas": "kalluftsfläkt",
    "kalluftsfläktars": "kalluftsfläkt",
    "kalluftsfläkten": "kalluftsfläkt",
    "kalluftsfläktens": "kalluftsfläkt",
    "kalluftsfläkts": "kalluftsfläkt",
    "kalluftslägen": "kalluftsläge",
    "kalluftslägena": "kalluftsläge",
    "kalluftslägenas": "kalluftsläge",
    "kalluftslägens": "kalluftsläge",
    "kalluftsläges": "kalluftsläge",
    "kalluftsläget": "kalluftsläge",
    "kalluftslägets": "kalluftsläge",
    "kallvals": "kallvalsa",
    "kallvalsad": "kallvalsa",
    "kallvalsade": "kallvalsa",
    "kallvalsades": "kallvalsa",
    "kallvalsads": "kallvalsa",
    "kallvalsande": "kallvalsa",
    "kallvalsanden": "kallvalsande",
    "kallvalsandena": "kallvalsande",
    "kallvalsandenas": "kallvalsande",
    "kallvalsandens": "kallvalsande",
    "kallvalsandes": "kallvalsande",
    "kallvalsandet": "kallvalsande",
    "kallvalsandets": "kallvalsande",
    "kallvalsar": "kallvalsa",
    "kallvalsas": "kallvalsa",
    "kallvalsat": "kallvalsa",
    "kallvalsats": "kallvalsa",
    "kallvattens": "kallvatten",
    "kallvattnen": "kallvatten",
    "kallvattnens": "kallvatten",
    "kallvattnet": "kallvatten",
    "kallvattnets": "kallvatten",
    "kalmarken": "kalmark",
    "kalmarkens": "kalmark",
    "kalmarker": "kalmark",
    "kalmarkerna": "kalmark",
    "kalmarkernas": "kalmark",
    "kalmarkers": "kalmark",
    "kalmarks": "kalmark",
    "kalmerad": "kalmera",
    "kalmerade": "kalmera",
    "kalmerades": "kalmera",
    "kalmerads": "kalmera",
    "kalmerande": "kalmera",
    "kalmeranden": "kalmerande",
    "kalmerandena": "kalmerande",
    "kalmerandenas": "kalmerande",
    "kalmerandens": "kalmerande",
    "kalmerandes": "kalmerande",
    "kalmerandet": "kalmerande",
    "kalmerandets": "kalmerande",
    "kalmerar": "kalmera",
    "kalmeras": "kalmera",
    "kalmerat": "kalmera",
    "kalmerats": "kalmera",
    "kalmerbara": "kalmerbar",
    "kalmerbarare": "kalmerbar",
    "kalmerbarares": "kalmerbar",
    "kalmerbaras": "kalmerbar",
    "kalmerbarast": "kalmerbar",
    "kalmerbaraste": "kalmerbar",
    "kalmerbarastes": "kalmerbar",
    "kalmerbarasts": "kalmerbar",
    "kalmerbare": "kalmerbar",
    "kalmerbares": "kalmerbar",
    "kalmerbarheten": "kalmerbarhet",
    "kalmerbarhetens": "kalmerbarhet",
    "kalmerbarhets": "kalmerbarhet",
    "kalmerbars": "kalmerbar",
    "kalmerbart": "kalmerbar",
    "kalmerbarts": "kalmerbar",
    "kalmeringar": "kalmering",
    "kalmeringarna": "kalmering",
    "kalmeringarnas": "kalmering",
    "kalmeringars": "kalmering",
    "kalmeringen": "kalmering",
    "kalmeringens": "kalmering",
    "kalmerings": "kalmering",
    "kalmucken": "kalmuck",
    "kalmuckens": "kalmuck",
    "kalmucker": "kalmuck",
    "kalmuckerna": "kalmuck",
    "kalmuckernas": "kalmuck",
    "kalmuckers": "kalmuck",
    "kalmucks": "kalmuck",
    "kalmusen": "kalmus",
    "kalmusens": "kalmus",
    "kalnade": "kalna",
    "kalnades": "kalna",
    "kalnande": "kalna",
    "kalnanden": "kalnande",
    "kalnandena": "kalnande",
    "kalnandenas": "kalnande",
    "kalnandens": "kalnande",
    "kalnandes": "kalnande",
    "kalnandet": "kalnande",
    "kalnandets": "kalnande",
    "kalnar": "kalna",
    "kalnas": "kalna",
    "kalnat": "kalna",
    "kalnats": "kalna",
    "kalomelen": "kalomel",
    "kalomelens": "kalomel",
    "kalomels": "kalomel",
    "kalopsen": "kalops",
    "kalopsens": "kalops",
    "kaloribehoven": "kaloribehov",
    "kaloribehovens": "kaloribehov",
    "kaloribehovet": "kaloribehov",
    "kaloribehovets": "kaloribehov",
    "kaloribehovs": "kaloribehov",
    "kaloribomben": "kaloribomb",
    "kaloribombens": "kaloribomb",
    "kaloribomber": "kaloribomb",
    "kaloribomberna": "kaloribomb",
    "kaloribombernas": "kaloribomb",
    "kaloribombers": "kaloribomb",
    "kaloribombs": "kaloribomb",
    "kalorien": "kalori",
    "kaloriens": "kalori",
    "kalorier": "kalori",
    "kalorierna": "kalori",
    "kaloriernas": "kalori",
    "kaloriers": "kalori",
    "kalorifattiga": "kalorifattig",
    "kalorifattigare": "kalorifattig",
    "kalorifattigares": "kalorifattig",
    "kalorifattigas": "kalorifattig",
    "kalorifattigast": "kalorifattig",
    "kalorifattigaste": "kalorifattig",
    "kalorifattigastes": "kalorifattig",
    "kalorifattigasts": "kalorifattig",
    "kalorifattige": "kalorifattig",
    "kalorifattiges": "kalorifattig",
    "kalorifattigheten": "kalorifattighet",
    "kalorifattighetens": "kalorifattighet",
    "kalorifattighets": "kalorifattighet",
    "kalorifattigs": "kalorifattig",
    "kalorifattigt": "kalorifattig",
    "kalorifattigts": "kalorifattig",
    "kaloriintagen": "kaloriintag",
    "kaloriintagens": "kaloriintag",
    "kaloriintaget": "kaloriintag",
    "kaloriintagets": "kaloriintag",
    "kaloriintags": "kaloriintag",
    "kalorijakten": "kalorijakt",
    "kalorijaktens": "kalorijakt",
    "kalorijakter": "kalorijakt",
    "kalorijakterna": "kalorijakt",
    "kalorijakternas": "kalorijakt",
    "kalorijakters": "kalorijakt",
    "kalorijakts": "kalorijakt",
    "kalorimetern": "kalorimeter",
    "kalorimeterns": "kalorimeter",
    "kalorimeters": "kalorimeter",
    "kalorimetrar": "kalorimeter",
    "kalorimetrarna": "kalorimeter",
    "kalorimetrarnas": "kalorimeter",
    "kalorimetrars": "kalorimeter",
    "kalorin": "kalori",
    "kalorins": "kalori",
    "kaloririka": "kaloririk",
    "kaloririkare": "kaloririk",
    "kaloririkares": "kaloririk",
    "kaloririkas": "kaloririk",
    "kaloririkast": "kaloririk",
    "kaloririkaste": "kaloririk",
    "kaloririkastes": "kaloririk",
    "kaloririkasts": "kaloririk",
    "kaloririke": "kaloririk",
    "kaloririkes": "kaloririk",
    "kaloririkheten": "kaloririkhet",
    "kaloririkhetens": "kaloririkhet",
    "kaloririkhets": "kaloririkhet",
    "kaloririks": "kaloririk",
    "kaloririkt": "kaloririk",
    "kaloririkts": "kaloririk",
    "kaloris": "kalori",
    "kaloritabellen": "kaloritabell",
    "kaloritabellens": "kaloritabell",
    "kaloritabeller": "kaloritabell",
    "kaloritabellerna": "kaloritabell",
    "kaloritabellernas": "kaloritabell",
    "kaloritabellers": "kaloritabell",
    "kaloritabells": "kaloritabell",
    "kalorivärden": "kalorivärde",
    "kalorivärdena": "kalorivärde",
    "kalorivärdenas": "kalorivärde",
    "kalorivärdens": "kalorivärde",
    "kalorivärdes": "kalorivärde",
    "kalorivärdet": "kalorivärde",
    "kalorivärdets": "kalorivärde",
    "kalotten": "kalott",
    "kalottens": "kalott",
    "kalotter": "kalott",
    "kalotterna": "kalott",
    "kalotternas": "kalott",
    "kalotters": "kalott",
    "kalotts": "kalott",
    "kalresten": "kalrest",
    "kalrestens": "kalrest",
    "kalrester": "kalrest",
    "kalresterna": "kalrest",
    "kalresternas": "kalrest",
    "kalresters": "kalrest",
    "kalrests": "kalrest",
    "kals": "kal",
    "kalsing": "kalsingar",
    "kalsingarna": "kalsingar",
    "kalsingarnas": "kalsingar",
    "kalsingars": "kalsingar",
    "kalsings": "kalsingar",
    "kalsong": "kalsonger",
    "kalsongerna": "kalsonger",
    "kalsongernas": "kalsonger",
    "kalsongers": "kalsonger",
    "kalsongs": "kalsonger",
    "kalspolade": "kalspolad",
    "kalspolades": "kalspolad",
    "kalspolads": "kalspolad",
    "kalspolat": "kalspolad",
    "kalspolats": "kalspolad",
    "kalstammiga": "kalstammig",
    "kalstammigare": "kalstammig",
    "kalstammigares": "kalstammig",
    "kalstammigas": "kalstammig",
    "kalstammigast": "kalstammig",
    "kalstammigaste": "kalstammig",
    "kalstammigastes": "kalstammig",
    "kalstammigasts": "kalstammig",
    "kalstammige": "kalstammig",
    "kalstammiges": "kalstammig",
    "kalstammigs": "kalstammig",
    "kalstammigt": "kalstammig",
    "kalstammigts": "kalstammig",
    "kalt": "kal",
    "kalts": "kal",
    "kalufsen": "kalufs",
    "kalufsens": "kalufs",
    "kalufser": "kalufs",
    "kalufserna": "kalufs",
    "kalufsernas": "kalufs",
    "kalufsers": "kalufs",
    "kaluven": "kaluv",
    "kaluvens": "kaluv",
    "kaluvs": "kaluv",
    "kalvade": "kalva",
    "kalvades": "kalva",
    "kalvande": "kalva",
    "kalvanden": "kalvande",
    "kalvandena": "kalvande",
    "kalvandenas": "kalvande",
    "kalvandens": "kalvande",
    "kalvandes": "kalvande",
    "kalvandet": "kalvande",
    "kalvandets": "kalvande",
    "kalvar": "kalva",
    "kalvarna": "kalv",
    "kalvarnas": "kalv",
    "kalvars": "kalv",
    "kalvas": "kalva",
    "kalvat": "kalva",
    "kalvats": "kalva",
    "kalvbrässen": "kalvbräss",
    "kalvbrässens": "kalvbräss",
    "kalvdansen": "kalvdans",
    "kalvdansens": "kalvdans",
    "kalven": "kalv",
    "kalvens": "kalv",
    "kalvfrikasséer": "kalvfrikassé",
    "kalvfrikasséerna": "kalvfrikassé",
    "kalvfrikasséernas": "kalvfrikassé",
    "kalvfrikasséers": "kalvfrikassé",
    "kalvfrikassén": "kalvfrikassé",
    "kalvfrikasséns": "kalvfrikassé",
    "kalvfrikassés": "kalvfrikassé",
    "kalvfärdiga": "kalvfärdig",
    "kalvfärdigare": "kalvfärdig",
    "kalvfärdigares": "kalvfärdig",
    "kalvfärdigas": "kalvfärdig",
    "kalvfärdigast": "kalvfärdig",
    "kalvfärdigaste": "kalvfärdig",
    "kalvfärdigastes": "kalvfärdig",
    "kalvfärdigasts": "kalvfärdig",
    "kalvfärdige": "kalvfärdig",
    "kalvfärdiges": "kalvfärdig",
    "kalvfärdigs": "kalvfärdig",
    "kalvfärdigt": "kalvfärdig",
    "kalvfärdigts": "kalvfärdig",
    "kalvillen": "kalvill",
    "kalvillens": "kalvill",
    "kalviller": "kalvill",
    "kalvillerna": "kalvill",
    "kalvillernas": "kalvill",
    "kalvillers": "kalvill",
    "kalvills": "kalvill",
    "kalvinismen": "kalvinism",
    "kalvinismens": "kalvinism",
    "kalvinismer": "kalvinism",
    "kalvinismerna": "kalvinism",
    "kalvinismernas": "kalvinism",
    "kalvinismers": "kalvinism",
    "kalvinisms": "kalvinism",
    "kalvinisten": "kalvinist",
    "kalvinistens": "kalvinist",
    "kalvinister": "kalvinist",
    "kalvinisterna": "kalvinist",
    "kalvinisternas": "kalvinist",
    "kalvinisters": "kalvinist",
    "kalvinistiska": "kalvinistisk",
    "kalvinistiskare": "kalvinistisk",
    "kalvinistiskares": "kalvinistisk",
    "kalvinistiskas": "kalvinistisk",
    "kalvinistiskast": "kalvinistisk",
    "kalvinistiskaste": "kalvinistisk",
    "kalvinistiskastes": "kalvinistisk",
    "kalvinistiskasts": "kalvinistisk",
    "kalvinistiske": "kalvinistisk",
    "kalvinistiskes": "kalvinistisk",
    "kalvinistisks": "kalvinistisk",
    "kalvinistiskt": "kalvinistisk",
    "kalvinistiskts": "kalvinistisk",
    "kalvinists": "kalvinist",
    "kalvinska": "kalvinsk",
    "kalvinskare": "kalvinsk",
    "kalvinskares": "kalvinsk",
    "kalvinskas": "kalvinsk",
    "kalvinskast": "kalvinsk",
    "kalvinskaste": "kalvinsk",
    "kalvinskastes": "kalvinsk",
    "kalvinskasts": "kalvinsk",
    "kalvinske": "kalvinsk",
    "kalvinskes": "kalvinsk",
    "kalvinsks": "kalvinsk",
    "kalvinskt": "kalvinsk",
    "kalvinskts": "kalvinsk",
    "kalvjärp": "kalvjärpe",
    "kalvjärpar": "kalvjärpe",
    "kalvjärparna": "kalvjärpe",
    "kalvjärparnas": "kalvjärpe",
    "kalvjärpars": "kalvjärpe",
    "kalvjärpen": "kalvjärpe",
    "kalvjärpens": "kalvjärpe",
    "kalvjärpes": "kalvjärpe",
    "kalvjärps": "kalvjärpe",
    "kalvkon": "kalvko",
    "kalvkons": "kalvko",
    "kalvkor": "kalvko",
    "kalvkorna": "kalvko",
    "kalvkornas": "kalvko",
    "kalvkors": "kalvko",
    "kalvkos": "kalvko",
    "kalvkycklingar": "kalvkyckling",
    "kalvkycklingarna": "kalvkyckling",
    "kalvkycklingarnas": "kalvkyckling",
    "kalvkycklingars": "kalvkyckling",
    "kalvkycklingen": "kalvkyckling",
    "kalvkycklingens": "kalvkyckling",
    "kalvkycklings": "kalvkyckling",
    "kalvkylen": "kalvkyl",
    "kalvkylens": "kalvkyl",
    "kalvkyls": "kalvkyl",
    "kalvköttet": "kalvkött",
    "kalvköttets": "kalvkött",
    "kalvkötts": "kalvkött",
    "kalvläggen": "kalvlägg",
    "kalvläggens": "kalvlägg",
    "kalvlägget": "kalvlägg",
    "kalvläggets": "kalvlägg",
    "kalvläggs": "kalvlägg",
    "kalvläggsgrytaen": "kalvläggsgryta",
    "kalvläggsgrytaens": "kalvläggsgryta",
    "kalvläggsgrytaet": "kalvläggsgryta",
    "kalvläggsgrytaets": "kalvläggsgryta",
    "kalvläggsgrytas": "kalvläggsgryta",
    "kalvningsfebern": "kalvningsfeber",
    "kalvningsfeberns": "kalvningsfeber",
    "kalvningsfebers": "kalvningsfeber",
    "kalvosten": "kalvost",
    "kalvostens": "kalvost",
    "kalvosts": "kalvost",
    "kalvruladen": "kalvrulad",
    "kalvruladens": "kalvrulad",
    "kalvrulader": "kalvrulad",
    "kalvruladerna": "kalvrulad",
    "kalvruladernas": "kalvrulad",
    "kalvruladers": "kalvrulad",
    "kalvrulads": "kalvrulad",
    "kalvrulladen": "kalvrullad",
    "kalvrulladens": "kalvrullad",
    "kalvrullader": "kalvrullad",
    "kalvrulladerna": "kalvrullad",
    "kalvrulladernas": "kalvrullad",
    "kalvrulladers": "kalvrullad",
    "kalvrullads": "kalvrullad",
    "kalvs": "kalv",
    "kalvskinnen": "kalvskinn",
    "kalvskinnens": "kalvskinn",
    "kalvskinnet": "kalvskinn",
    "kalvskinnets": "kalvskinn",
    "kalvskinns": "kalvskinn",
    "kalvskinnsbanden": "kalvskinnsband",
    "kalvskinnsbandens": "kalvskinnsband",
    "kalvskinnsbandet": "kalvskinnsband",
    "kalvskinnsbandets": "kalvskinnsband",
    "kalvskinnsbands": "kalvskinnsband",
    "kalvstekar": "kalvstek",
    "kalvstekarna": "kalvstek",
    "kalvstekarnas": "kalvstek",
    "kalvstekars": "kalvstek",
    "kalvsteken": "kalvstek",
    "kalvstekens": "kalvstek",
    "kalvsteks": "kalvstek",
    "kalvställningar": "kalvställning",
    "kalvställningarna": "kalvställning",
    "kalvställningarnas": "kalvställning",
    "kalvställningars": "kalvställning",
    "kalvställningen": "kalvställning",
    "kalvställningens": "kalvställning",
    "kalvställnings": "kalvställning",
    "kalvsylt": "kalvsylta",
    "kalvsyltan": "kalvsylta",
    "kalvsyltans": "kalvsylta",
    "kalvsyltas": "kalvsylta",
    "kalvsylte": "kalvsylta",
    "kalvsyltor": "kalvsylta",
    "kalvsyltorna": "kalvsylta",
    "kalvsyltornas": "kalvsylta",
    "kalvsyltors": "kalvsylta",
    "kalvsylts": "kalvsylta",
    "kalät": "kaläta",
    "kalätande": "kaläta",
    "kalätanden": "kalätande",
    "kalätandena": "kalätande",
    "kalätandenas": "kalätande",
    "kalätandens": "kalätande",
    "kalätandes": "kalätande",
    "kalätandet": "kalätande",
    "kalätandets": "kalätande",
    "kalätas": "kaläta",
    "kaläte": "kaläta",
    "kaläten": "kaläta",
    "kalätens": "kaläta",
    "kaläter": "kaläta",
    "kalätes": "kaläta",
    "kalätet": "kaläta",
    "kalätets": "kaläta",
    "kalätit": "kaläta",
    "kalätits": "kaläta",
    "kalätna": "kaläta",
    "kalätnas": "kaläta",
    "kalätne": "kaläta",
    "kalätnes": "kaläta",
    "kaläts": "kaläta",
    "kalåt": "kaläta",
    "kalåte": "kaläta",
    "kalåtes": "kaläta",
    "kalåts": "kaläta",
    "kamaraderiet": "kamaraderi",
    "kamaraderiets": "kamaraderi",
    "kamaraderis": "kamaraderi",
    "kamaraderit": "kamaraderi",
    "kamaraderits": "kamaraderi",
    "kamarill": "kamarilla",
    "kamarillan": "kamarilla",
    "kamarillans": "kamarilla",
    "kamarillas": "kamarilla",
    "kamarille": "kamarilla",
    "kamarillor": "kamarilla",
    "kamarillorna": "kamarilla",
    "kamarillornas": "kamarilla",
    "kamarillors": "kamarilla",
    "kamarills": "kamarilla",
    "kamaxeln": "kamaxel",
    "kamaxelns": "kamaxel",
    "kamaxels": "kamaxel",
    "kamaxlar": "kamaxel",
    "kamaxlarna": "kamaxel",
    "kamaxlarnas": "kamaxel",
    "kamaxlars": "kamaxel",
    "kambodjanen": "kambodjan",
    "kambodjanens": "kambodjan",
    "kambodjaner": "kambodjan",
    "kambodjanerna": "kambodjan",
    "kambodjanernas": "kambodjan",
    "kambodjaners": "kambodjan",
    "kambodjans": "kambodjan",
    "kambodjanskan": "kambodjanska",
    "kambodjanskans": "kambodjanska",
    "kambodjanskas": "kambodjanska",
    "kambodjanske": "kambodjanska",
    "kambodjanskor": "kambodjanska",
    "kambodjanskorna": "kambodjanska",
    "kambodjanskornas": "kambodjanska",
    "kambodjanskors": "kambodjanska",
    "kambriken": "kambrik",
    "kambrikens": "kambrik",
    "kambriks": "kambrik",
    "kambriska": "kambrisk",
    "kambriskare": "kambrisk",
    "kambriskares": "kambrisk",
    "kambriskas": "kambrisk",
    "kambriskast": "kambrisk",
    "kambriskaste": "kambrisk",
    "kambriskastes": "kambrisk",
    "kambriskasts": "kambrisk",
    "kambriske": "kambrisk",
    "kambriskes": "kambrisk",
    "kambrisks": "kambrisk",
    "kambriskt": "kambrisk",
    "kambriskts": "kambrisk",
    "kambriums": "kambrium",
    "kambrosiluren": "kambrosilur",
    "kambrosilurens": "kambrosilur",
    "kambrosilurs": "kambrosilur",
    "kameldjuren": "kameldjur",
    "kameldjurens": "kameldjur",
    "kameldjuret": "kameldjur",
    "kameldjurets": "kameldjur",
    "kameldjurs": "kameldjur",
    "kamelen": "kamel",
    "kamelens": "kamel",
    "kameleonten": "kameleont",
    "kameleontens": "kameleont",
    "kameleonter": "kameleont",
    "kameleonterna": "kameleont",
    "kameleonternas": "kameleont",
    "kameleonters": "kameleont",
    "kameleonts": "kameleont",
    "kameler": "kamel",
    "kamelerna": "kamel",
    "kamelernas": "kamel",
    "kamelers": "kamel",
    "kamelforskar": "kamelforskare",
    "kamelforskaren": "kamelforskare",
    "kamelforskarens": "kamelforskare",
    "kamelforskares": "kamelforskare",
    "kamelforskarna": "kamelforskare",
    "kamelforskarnas": "kamelforskare",
    "kamelforskningar": "kamelforskning",
    "kamelforskningarna": "kamelforskning",
    "kamelforskningarnas": "kamelforskning",
    "kamelforskningars": "kamelforskning",
    "kamelforskningen": "kamelforskning",
    "kamelforskningens": "kamelforskning",
    "kamelforsknings": "kamelforskning",
    "kamelforskningsprojekten": "kamelforskningsprojekt",
    "kamelforskningsprojektens": "kamelforskningsprojekt",
    "kamelforskningsprojektet": "kamelforskningsprojekt",
    "kamelforskningsprojektets": "kamelforskningsprojekt",
    "kamelforskningsprojekts": "kamelforskningsprojekt",
    "kamelgarnet": "kamelgarn",
    "kamelgarnets": "kamelgarn",
    "kamelgarns": "kamelgarn",
    "kamelherda": "kamelherde",
    "kamelherdar": "kamelherde",
    "kamelherdarna": "kamelherde",
    "kamelherdarnas": "kamelherde",
    "kamelherdars": "kamelherde",
    "kamelherden": "kamelherde",
    "kamelherdens": "kamelherde",
    "kamelherdes": "kamelherde",
    "kamelhjordar": "kamelhjord",
    "kamelhjordarna": "kamelhjord",
    "kamelhjordarnas": "kamelhjord",
    "kamelhjordars": "kamelhjord",
    "kamelhjorden": "kamelhjord",
    "kamelhjordens": "kamelhjord",
    "kamelhjords": "kamelhjord",
    "kamelhåret": "kamelhår",
    "kamelhårets": "kamelhår",
    "kamelhårs": "kamelhår",
    "kamelhårsfärgade": "kamelhårsfärgad",
    "kamelhårsfärgades": "kamelhårsfärgad",
    "kamelhårsfärgads": "kamelhårsfärgad",
    "kamelhårsfärgat": "kamelhårsfärgad",
    "kamelhårsfärgats": "kamelhårsfärgad",
    "kameli": "kamelia",
    "kamelian": "kamelia",
    "kamelians": "kamelia",
    "kamelias": "kamelia",
    "kamelie": "kamelia",
    "kamelior": "kamelia",
    "kameliorna": "kamelia",
    "kameliornas": "kamelia",
    "kameliors": "kamelia",
    "kamelis": "kamelia",
    "kamelklock": "kamelklocka",
    "kamelklockan": "kamelklocka",
    "kamelklockans": "kamelklocka",
    "kamelklockas": "kamelklocka",
    "kamelklocke": "kamelklocka",
    "kamelklockor": "kamelklocka",
    "kamelklockorna": "kamelklocka",
    "kamelklockornas": "kamelklocka",
    "kamelklockors": "kamelklocka",
    "kamelklocks": "kamelklocka",
    "kamelmedicinen": "kamelmedicin",
    "kamelmedicinens": "kamelmedicin",
    "kamelmediciner": "kamelmedicin",
    "kamelmedicinerna": "kamelmedicin",
    "kamelmedicinernas": "kamelmedicin",
    "kamelmediciners": "kamelmedicin",
    "kamelmedicins": "kamelmedicin",
    "kamelmjölken": "kamelmjölk",
    "kamelmjölkens": "kamelmjölk",
    "kamelmjölks": "kamelmjölk",
    "kameloparden": "kamelopard",
    "kamelopardens": "kamelopard",
    "kameloparder": "kamelopard",
    "kameloparderna": "kamelopard",
    "kamelopardernas": "kamelopard",
    "kameloparders": "kamelopard",
    "kamelopards": "kamelopard",
    "kamelpoesien": "kamelpoesi",
    "kamelpoesiens": "kamelpoesi",
    "kamelpoesier": "kamelpoesi",
    "kamelpoesierna": "kamelpoesi",
    "kamelpoesiernas": "kamelpoesi",
    "kamelpoesiers": "kamelpoesi",
    "kamelpoesin": "kamelpoesi",
    "kamelpoesins": "kamelpoesi",
    "kamelpoesis": "kamelpoesi",
    "kamels": "kamel",
    "kamelsadeln": "kamelsadel",
    "kamelsadelns": "kamelsadel",
    "kamelsadels": "kamelsadel",
    "kamelsadlar": "kamelsadel",
    "kamelsadlarna": "kamelsadel",
    "kamelsadlarnas": "kamelsadel",
    "kamelsadlars": "kamelsadel",
    "kamelskötseln": "kamelskötsel",
    "kamelskötselns": "kamelskötsel",
    "kamelskötsels": "kamelskötsel",
    "kamelsäckar": "kamelsäck",
    "kamelsäckarna": "kamelsäck",
    "kamelsäckarnas": "kamelsäck",
    "kamelsäckars": "kamelsäck",
    "kamelsäcken": "kamelsäck",
    "kamelsäckens": "kamelsäck",
    "kamelsäcks": "kamelsäck",
    "kamelullen": "kamelull",
    "kamelullens": "kamelull",
    "kamelulls": "kamelull",
    "kamerajakten": "kamerajakt",
    "kamerajaktens": "kamerajakt",
    "kamerajakter": "kamerajakt",
    "kamerajakterna": "kamerajakt",
    "kamerajakternas": "kamerajakt",
    "kamerajakters": "kamerajakt",
    "kamerajakts": "kamerajakt",
    "kamerala": "kameral",
    "kameralare": "kameral",
    "kameralares": "kameral",
    "kameralas": "kameral",
    "kameralast": "kameral",
    "kameralaste": "kameral",
    "kameralastes": "kameral",
    "kameralasts": "kameral",
    "kamerale": "kameral",
    "kamerales": "kameral",
    "kamerals": "kameral",
    "kameralt": "kameral",
    "kameralts": "kameral",
    "kameramannen": "kameraman",
    "kameramannens": "kameraman",
    "kameramans": "kameraman",
    "kameramän": "kameraman",
    "kameramännen": "kameraman",
    "kameramännens": "kameraman",
    "kameramäns": "kameraman",
    "kameran": "kamera",
    "kamerans": "kamera",
    "kameraobjektiven": "kameraobjektiv",
    "kameraobjektivens": "kameraobjektiv",
    "kameraobjektivet": "kameraobjektiv",
    "kameraobjektivets": "kameraobjektiv",
    "kameraobjektivs": "kameraobjektiv",
    "kameras": "kamera",
    "kamerastativen": "kamerastativ",
    "kamerastativens": "kamerastativ",
    "kamerastativet": "kamerastativ",
    "kamerastativets": "kamerastativ",
    "kamerastativs": "kamerastativ",
    "kameravinkeln": "kameravinkel",
    "kameravinkelns": "kameravinkel",
    "kameravinkels": "kameravinkel",
    "kameravinklar": "kameravinkel",
    "kameravinklarna": "kameravinkel",
    "kameravinklarnas": "kameravinkel",
    "kameravinklars": "kameravinkel",
    "kameror": "kamera",
    "kamerorna": "kamera",
    "kamerornas": "kamera",
    "kamerors": "kamera",
    "kamerunar": "kamerunare",
    "kamerunaren": "kamerunare",
    "kamerunarens": "kamerunare",
    "kamerunares": "kamerunare",
    "kamerunarna": "kamerunare",
    "kamerunarnas": "kamerunare",
    "kamerunska": "kamerunsk",
    "kamerunskan": "kamerunska",
    "kamerunskans": "kamerunska",
    "kamerunskare": "kamerunsk",
    "kamerunskares": "kamerunsk",
    "kamerunskas": "kamerunska",
    "kamerunskast": "kamerunsk",
    "kamerunskaste": "kamerunsk",
    "kamerunskastes": "kamerunsk",
    "kamerunskasts": "kamerunsk",
    "kamerunske": "kamerunska",
    "kamerunskes": "kamerunsk",
    "kamerunskor": "kamerunska",
    "kamerunskorna": "kamerunska",
    "kamerunskornas": "kamerunska",
    "kamerunskors": "kamerunska",
    "kamerunsks": "kamerunsk",
    "kamerunskt": "kamerunsk",
    "kamerunskts": "kamerunsk",
    "kamferdropparna": "kamferdroppar",
    "kamferdropparnas": "kamferdroppar",
    "kamferdroppars": "kamferdroppar",
    "kamferdropps": "kamferdroppar",
    "kamferlinimentet": "kamferliniment",
    "kamferlinimentets": "kamferliniment",
    "kamferliniments": "kamferliniment",
    "kamfern": "kamfer",
    "kamferns": "kamfer",
    "kamfers": "kamfer",
    "kamgarnet": "kamgarn",
    "kamgarnets": "kamgarn",
    "kamgarns": "kamgarn",
    "kamikazeuppdragen": "kamikazeuppdrag",
    "kamikazeuppdragens": "kamikazeuppdrag",
    "kamikazeuppdraget": "kamikazeuppdrag",
    "kamikazeuppdragets": "kamikazeuppdrag",
    "kamikazeuppdrags": "kamikazeuppdrag",
    "kaminen": "kamin",
    "kaminens": "kamin",
    "kaminer": "kamin",
    "kaminerna": "kamin",
    "kaminernas": "kamin",
    "kaminers": "kamin",
    "kamins": "kamin",
    "kamkoft": "kamkofta",
    "kamkoftan": "kamkofta",
    "kamkoftans": "kamkofta",
    "kamkoftas": "kamkofta",
    "kamkofte": "kamkofta",
    "kamkoftor": "kamkofta",
    "kamkoftorna": "kamkofta",
    "kamkoftornas": "kamkofta",
    "kamkoftors": "kamkofta",
    "kamkofts": "kamkofta",
    "kamlotten": "kamlott",
    "kamlottens": "kamlott",
    "kamlotts": "kamlott",
    "kammad": "kamma",
    "kammade": "kamma",
    "kammades": "kamma",
    "kammads": "kamma",
    "kammande": "kamma",
    "kammanden": "kammande",
    "kammandena": "kammande",
    "kammandenas": "kammande",
    "kammandens": "kammande",
    "kammandes": "kammande",
    "kammandet": "kammande",
    "kammandets": "kammande",
    "kammaneten": "kammanet",
    "kammanetens": "kammanet",
    "kammaneter": "kammanet",
    "kammaneterna": "kammanet",
    "kammaneternas": "kammanet",
    "kammaneters": "kammanet",
    "kammanets": "kammanet",
    "kammar": "kammare",
    "kammarammunitionen": "kammarammunition",
    "kammarammunitionens": "kammarammunition",
    "kammarammunitioner": "kammarammunition",
    "kammarammunitionerna": "kammarammunition",
    "kammarammunitionernas": "kammarammunition",
    "kammarammunitioners": "kammarammunition",
    "kammarammunitions": "kammarammunition",
    "kammardressyren": "kammardressyr",
    "kammardressyrens": "kammardressyr",
    "kammardressyrer": "kammardressyr",
    "kammardressyrerna": "kammardressyr",
    "kammardressyrernas": "kammardressyr",
    "kammardressyrers": "kammardressyr",
    "kammardressyrs": "kammardressyr",
    "kammarduken": "kammarduk",
    "kammardukens": "kammarduk",
    "kammarduks": "kammarduk",
    "kammaren": "kammare",
    "kammarens": "kammare",
    "kammares": "kammare",
    "kammarherrar": "kammarherre",
    "kammarherrarna": "kammarherre",
    "kammarherrarnas": "kammarherre",
    "kammarherrars": "kammarherre",
    "kammarherren": "kammarherre",
    "kammarherrens": "kammarherre",
    "kammarherres": "kammarherre",
    "kammarjungfrun": "kammarjungfru",
    "kammarjungfruns": "kammarjungfru",
    "kammarjungfrur": "kammarjungfru",
    "kammarjungfrurna": "kammarjungfru",
    "kammarjungfrurnas": "kammarjungfru",
    "kammarjungfrurs": "kammarjungfru",
    "kammarjungfrus": "kammarjungfru",
    "kammarjunkar": "kammarjunkare",
    "kammarjunkaren": "kammarjunkare",
    "kammarjunkarens": "kammarjunkare",
    "kammarjunkares": "kammarjunkare",
    "kammarjunkarna": "kammarjunkare",
    "kammarjunkarnas": "kammarjunkare",
    "kammarkollegiet": "kammarkollegium",
    "kammarkollegiets": "kammarkollegium",
    "kammarkollegiums": "kammarkollegium",
    "kammarlärda": "kammarlärd",
    "kammarlärdare": "kammarlärd",
    "kammarlärdares": "kammarlärd",
    "kammarlärdas": "kammarlärd",
    "kammarlärdast": "kammarlärd",
    "kammarlärdaste": "kammarlärd",
    "kammarlärdastes": "kammarlärd",
    "kammarlärdasts": "kammarlärd",
    "kammarlärde": "kammarlärd",
    "kammarlärdes": "kammarlärd",
    "kammarlärds": "kammarlärd",
    "kammarlärt": "kammarlärd",
    "kammarlärts": "kammarlärd",
    "kammarmusiken": "kammarmusik",
    "kammarmusikens": "kammarmusik",
    "kammarmusikern": "kammarmusiker",
    "kammarmusikerna": "kammarmusiker",
    "kammarmusikernas": "kammarmusiker",
    "kammarmusikerns": "kammarmusiker",
    "kammarmusikers": "kammarmusiker",
    "kammarmusiks": "kammarmusik",
    "kammarna": "kam",
    "kammarnas": "kam",
    "kammarorkestern": "kammarorkester",
    "kammarorkesterns": "kammarorkester",
    "kammarorkesters": "kammarorkester",
    "kammarorkestrar": "kammarorkester",
    "kammarorkestrarna": "kammarorkester",
    "kammarorkestrarnas": "kammarorkester",
    "kammarorkestrars": "kammarorkester",
    "kammarpianon": "kammarpiano",
    "kammarpianona": "kammarpiano",
    "kammarpianonas": "kammarpiano",
    "kammarpianons": "kammarpiano",
    "kammarpianos": "kammarpiano",
    "kammarpianot": "kammarpiano",
    "kammarpianots": "kammarpiano",
    "kammarrätten": "kammarrätt",
    "kammarrättens": "kammarrätt",
    "kammarrätter": "kammarrätt",
    "kammarrätterna": "kammarrätt",
    "kammarrätternas": "kammarrätt",
    "kammarrätters": "kammarrätt",
    "kammarrätts": "kammarrätt",
    "kammars": "kam",
    "kammarskjutningar": "kammarskjutning",
    "kammarskjutningarna": "kammarskjutning",
    "kammarskjutningarnas": "kammarskjutning",
    "kammarskjutningars": "kammarskjutning",
    "kammarskjutningen": "kammarskjutning",
    "kammarskjutningens": "kammarskjutning",
    "kammarskjutnings": "kammarskjutning",
    "kammarskrivar": "kammarskrivare",
    "kammarskrivaren": "kammarskrivare",
    "kammarskrivarens": "kammarskrivare",
    "kammarskrivares": "kammarskrivare",
    "kammarskrivarna": "kammarskrivare",
    "kammarskrivarnas": "kammarskrivare",
    "kammarskruvar": "kammarskruv",
    "kammarskruvarna": "kammarskruv",
    "kammarskruvarnas": "kammarskruv",
    "kammarskruvars": "kammarskruv",
    "kammarskruven": "kammarskruv",
    "kammarskruvens": "kammarskruv",
    "kammarskruvs": "kammarskruv",
    "kammarspelen": "kammarspel",
    "kammarspelens": "kammarspel",
    "kammarspelet": "kammarspel",
    "kammarspelets": "kammarspel",
    "kammarspels": "kammarspel",
    "kammaråklagar": "kammaråklagare",
    "kammaråklagaren": "kammaråklagare",
    "kammaråklagarens": "kammaråklagare",
    "kammaråklagares": "kammaråklagare",
    "kammaråklagarna": "kammaråklagare",
    "kammaråklagarnas": "kammaråklagare",
    "kammas": "kamma",
    "kammat": "kamma",
    "kammats": "kamma",
    "kammen": "kam",
    "kammens": "kam",
    "kammussel": "kammussla",
    "kammusslan": "kammussla",
    "kammusslans": "kammussla",
    "kammusslas": "kammussla",
    "kammussle": "kammussla",
    "kammusslor": "kammussla",
    "kammusslorna": "kammussla",
    "kammusslornas": "kammussla",
    "kammusslors": "kammussla",
    "kamomillen": "kamomill",
    "kamomillens": "kamomill",
    "kamomiller": "kamomill",
    "kamomillerna": "kamomill",
    "kamomillernas": "kamomill",
    "kamomillers": "kamomill",
    "kamomills": "kamomill",
    "kamouflagefärgade": "kamouflagefärgad",
    "kamouflagefärgades": "kamouflagefärgad",
    "kamouflagefärgads": "kamouflagefärgad",
    "kamouflagefärgat": "kamouflagefärgad",
    "kamouflagefärgats": "kamouflagefärgad",
    "kamouflagegråa": "kamouflagegrå",
    "kamouflagegråare": "kamouflagegrå",
    "kamouflagegråares": "kamouflagegrå",
    "kamouflagegråas": "kamouflagegrå",
    "kamouflagegråast": "kamouflagegrå",
    "kamouflagegråaste": "kamouflagegrå",
    "kamouflagegråastes": "kamouflagegrå",
    "kamouflagegråasts": "kamouflagegrå",
    "kamouflagegråe": "kamouflagegrå",
    "kamouflagegråes": "kamouflagegrå",
    "kamouflagegrås": "kamouflagegrå",
    "kamouflagegrått": "kamouflagegrå",
    "kamouflagegråtts": "kamouflagegrå",
    "kamouflageinläggen": "kamouflageinlägg",
    "kamouflageinläggens": "kamouflageinlägg",
    "kamouflageinlägget": "kamouflageinlägg",
    "kamouflageinläggets": "kamouflageinlägg",
    "kamouflageinläggs": "kamouflageinlägg",
    "kamouflages": "kamouflage",
    "kamouflaget": "kamouflage",
    "kamouflagets": "kamouflage",
    "kamouflerad": "kamouflera",
    "kamouflerade": "kamouflera",
    "kamouflerades": "kamouflera",
    "kamouflerads": "kamouflera",
    "kamouflerande": "kamouflera",
    "kamoufleranden": "kamouflerande",
    "kamouflerandena": "kamouflerande",
    "kamouflerandenas": "kamouflerande",
    "kamouflerandens": "kamouflerande",
    "kamouflerandes": "kamouflerande",
    "kamouflerandet": "kamouflerande",
    "kamouflerandets": "kamouflerande",
    "kamouflerar": "kamouflera",
    "kamoufleras": "kamouflera",
    "kamouflerat": "kamouflera",
    "kamouflerats": "kamouflera",
    "kamouflerbara": "kamouflerbar",
    "kamouflerbarare": "kamouflerbar",
    "kamouflerbarares": "kamouflerbar",
    "kamouflerbaras": "kamouflerbar",
    "kamouflerbarast": "kamouflerbar",
    "kamouflerbaraste": "kamouflerbar",
    "kamouflerbarastes": "kamouflerbar",
    "kamouflerbarasts": "kamouflerbar",
    "kamouflerbare": "kamouflerbar",
    "kamouflerbares": "kamouflerbar",
    "kamouflerbarheten": "kamouflerbarhet",
    "kamouflerbarhetens": "kamouflerbarhet",
    "kamouflerbarhets": "kamouflerbarhet",
    "kamouflerbars": "kamouflerbar",
    "kamouflerbart": "kamouflerbar",
    "kamouflerbarts": "kamouflerbar",
    "kamoufleringar": "kamouflering",
    "kamoufleringarna": "kamouflering",
    "kamoufleringarnas": "kamouflering",
    "kamoufleringars": "kamouflering",
    "kamoufleringen": "kamouflering",
    "kamoufleringens": "kamouflering",
    "kamouflerings": "kamouflering",
    "kampade": "kampa",
    "kampades": "kampa",
    "kampande": "kampa",
    "kampanden": "kampande",
    "kampandena": "kampande",
    "kampandenas": "kampande",
    "kampandens": "kampande",
    "kampandes": "kampande",
    "kampandet": "kampande",
    "kampandets": "kampande",
    "kampanilen": "kampanil",
    "kampanilens": "kampanil",
    "kampaniler": "kampanil",
    "kampanilerna": "kampanil",
    "kampanilernas": "kampanil",
    "kampanilers": "kampanil",
    "kampanils": "kampanil",
    "kampanjen": "kampanj",
    "kampanjens": "kampanj",
    "kampanjer": "kampanj",
    "kampanjerna": "kampanj",
    "kampanjernas": "kampanj",
    "kampanjers": "kampanj",
    "kampanjräkningar": "kampanjräkning",
    "kampanjräkningarna": "kampanjräkning",
    "kampanjräkningarnas": "kampanjräkning",
    "kampanjräkningars": "kampanjräkning",
    "kampanjräkningen": "kampanjräkning",
    "kampanjräkningens": "kampanjräkning",
    "kampanjräknings": "kampanjräkning",
    "kampanjrådgivar": "kampanjrådgivare",
    "kampanjrådgivaren": "kampanjrådgivare",
    "kampanjrådgivarens": "kampanjrådgivare",
    "kampanjrådgivares": "kampanjrådgivare",
    "kampanjrådgivarna": "kampanjrådgivare",
    "kampanjrådgivarnas": "kampanjrådgivare",
    "kampanjs": "kampanj",
    "kampanjstaben": "kampanjstab",
    "kampanjstabens": "kampanjstab",
    "kampanjstaber": "kampanjstab",
    "kampanjstaberna": "kampanjstab",
    "kampanjstabernas": "kampanjstab",
    "kampanjstabers": "kampanjstab",
    "kampanjstabs": "kampanjstab",
    "kampanjvinnar": "kampanjvinnare",
    "kampanjvinnaren": "kampanjvinnare",
    "kampanjvinnarens": "kampanjvinnare",
    "kampanjvinnares": "kampanjvinnare",
    "kampanjvinnarna": "kampanjvinnare",
    "kampanjvinnarnas": "kampanjvinnare",
    "kampar": "kampare",
    "kamparen": "kampare",
    "kamparens": "kampare",
    "kampares": "kampare",
    "kamparna": "kampare",
    "kamparnas": "kampare",
    "kampars": "kamp",
    "kampas": "kampa",
    "kampat": "kampa",
    "kampats": "kampa",
    "kampegräsen": "kampegräs",
    "kampegräsens": "kampegräs",
    "kampegräset": "kampegräs",
    "kampegräsets": "kampegräs",
    "kampen": "kamp",
    "kampens": "kamp",
    "kamper": "kamp",
    "kamperade": "kampera",
    "kamperades": "kampera",
    "kamperande": "kampera",
    "kamperanden": "kamperande",
    "kamperandena": "kamperande",
    "kamperandenas": "kamperande",
    "kamperandens": "kamperande",
    "kamperandes": "kamperande",
    "kamperandet": "kamperande",
    "kamperandets": "kamperande",
    "kamperar": "kampera",
    "kamperas": "kampera",
    "kamperat": "kampera",
    "kamperats": "kampera",
    "kamperingar": "kampering",
    "kamperingarna": "kampering",
    "kamperingarnas": "kampering",
    "kamperingars": "kampering",
    "kamperingen": "kampering",
    "kamperingens": "kampering",
    "kamperings": "kampering",
    "kamperna": "kamp",
    "kampernas": "kamp",
    "kampers": "kamp",
    "kampeschen": "kampesch",
    "kampeschens": "kampesch",
    "kampeschs": "kampesch",
    "kampeschträden": "kampeschträd",
    "kampeschträdens": "kampeschträd",
    "kampeschträdet": "kampeschträd",
    "kampeschträdets": "kampeschträd",
    "kampeschträds": "kampeschträd",
    "kampeschträn": "kampeschträd",
    "kampeschträna": "kampeschträd",
    "kampeschtränas": "kampeschträd",
    "kampeschträns": "kampeschträd",
    "kampintresserade": "kampintresserad",
    "kampintresserades": "kampintresserad",
    "kampintresserads": "kampintresserad",
    "kampintresserat": "kampintresserad",
    "kampintresserats": "kampintresserad",
    "kampkonsten": "kampkonst",
    "kampkonstens": "kampkonst",
    "kampkonster": "kampkonst",
    "kampkonsterna": "kampkonst",
    "kampkonsternas": "kampkonst",
    "kampkonsters": "kampkonst",
    "kampkonstkretsar": "kampkonstkrets",
    "kampkonstkretsarna": "kampkonstkrets",
    "kampkonstkretsarnas": "kampkonstkrets",
    "kampkonstkretsars": "kampkonstkrets",
    "kampkonstkretsen": "kampkonstkrets",
    "kampkonstkretsens": "kampkonstkrets",
    "kampkonsts": "kampkonst",
    "kamporganisationen": "kamporganisation",
    "kamporganisationens": "kamporganisation",
    "kamporganisationer": "kamporganisation",
    "kamporganisationerna": "kamporganisation",
    "kamporganisationernas": "kamporganisation",
    "kamporganisationers": "kamporganisation",
    "kamporganisations": "kamporganisation",
    "kamps": "kamp",
    "kampsporten": "kampsport",
    "kampsportens": "kampsport",
    "kampsporter": "kampsport",
    "kampsporterna": "kampsport",
    "kampsporternas": "kampsport",
    "kampsporters": "kampsport",
    "kampsports": "kampsport",
    "kampsången": "kampsång",
    "kampsångens": "kampsång",
    "kampsånger": "kampsång",
    "kampsångerna": "kampsång",
    "kampsångernas": "kampsång",
    "kampsångers": "kampsång",
    "kampsångs": "kampsång",
    "kampucheanen": "kampuchean",
    "kampucheanens": "kampuchean",
    "kampucheaner": "kampuchean",
    "kampucheanerna": "kampuchean",
    "kampucheanernas": "kampuchean",
    "kampucheaners": "kampuchean",
    "kampucheans": "kampuchean",
    "kampucheanska": "kampucheansk",
    "kampucheanskare": "kampucheansk",
    "kampucheanskares": "kampucheansk",
    "kampucheanskas": "kampucheansk",
    "kampucheanskast": "kampucheansk",
    "kampucheanskaste": "kampucheansk",
    "kampucheanskastes": "kampucheansk",
    "kampucheanskasts": "kampucheansk",
    "kampucheanske": "kampucheansk",
    "kampucheanskes": "kampucheansk",
    "kampucheansks": "kampucheansk",
    "kampucheanskt": "kampucheansk",
    "kampucheanskts": "kampucheansk",
    "kampviljan": "kampvilja",
    "kampviljans": "kampvilja",
    "kampviljas": "kampvilja",
    "kampvilje": "kampvilja",
    "kampviljor": "kampvilja",
    "kampviljorna": "kampvilja",
    "kampviljornas": "kampvilja",
    "kampviljors": "kampvilja",
    "kamrar": "kammare",
    "kamrarna": "kammare",
    "kamrarnas": "kammare",
    "kamrars": "kammare",
    "kamratandan": "kamratanda",
    "kamratandans": "kamratanda",
    "kamratandas": "kamratanda",
    "kamraten": "kamrat",
    "kamratens": "kamrat",
    "kamrater": "kamrat",
    "kamraterna": "kamrat",
    "kamraternas": "kamrat",
    "kamraters": "kamrat",
    "kamratkänslan": "kamratkänsla",
    "kamratkänslans": "kamratkänsla",
    "kamratkänslas": "kamratkänsla",
    "kamratkänsle": "kamratkänsla",
    "kamratkänslo": "kamratkänsla",
    "kamratliga": "kamratlig",
    "kamratligare": "kamratlig",
    "kamratligares": "kamratlig",
    "kamratligas": "kamratlig",
    "kamratligast": "kamratlig",
    "kamratligaste": "kamratlig",
    "kamratligastes": "kamratlig",
    "kamratligasts": "kamratlig",
    "kamratlige": "kamratlig",
    "kamratliges": "kamratlig",
    "kamratligheten": "kamratlighet",
    "kamratlighetens": "kamratlighet",
    "kamratligheter": "kamratlighet",
    "kamratligheterna": "kamratlighet",
    "kamratligheternas": "kamratlighet",
    "kamratligheters": "kamratlighet",
    "kamratlighets": "kamratlighet",
    "kamratligs": "kamratlig",
    "kamratligt": "kamratlig",
    "kamratligts": "kamratlig",
    "kamratpåverkans": "kamratpåverkan",
    "kamratpåverkningar": "kamratpåverkning",
    "kamratpåverkningarna": "kamratpåverkning",
    "kamratpåverkningarnas": "kamratpåverkning",
    "kamratpåverkningars": "kamratpåverkning",
    "kamratpåverkningen": "kamratpåverkning",
    "kamratpåverkningens": "kamratpåverkning",
    "kamratpåverknings": "kamratpåverkning",
    "kamrats": "kamrat",
    "kamratskapet": "kamratskap",
    "kamratskapets": "kamratskap",
    "kamratskaps": "kamratskap",
    "kamrerar": "kamrerare",
    "kamreraren": "kamrerare",
    "kamrerarens": "kamrerare",
    "kamrerares": "kamrerare",
    "kamrerarna": "kamrerare",
    "kamrerarnas": "kamrerare",
    "kamreren": "kamrer",
    "kamrerens": "kamrer",
    "kamrerer": "kamrer",
    "kamrererna": "kamrer",
    "kamrerernas": "kamrer",
    "kamrerers": "kamrer",
    "kamrermässiga": "kamrermässig",
    "kamrermässigare": "kamrermässig",
    "kamrermässigares": "kamrermässig",
    "kamrermässigas": "kamrermässig",
    "kamrermässigast": "kamrermässig",
    "kamrermässigaste": "kamrermässig",
    "kamrermässigastes": "kamrermässig",
    "kamrermässigasts": "kamrermässig",
    "kamrermässige": "kamrermässig",
    "kamrermässiges": "kamrermässig",
    "kamrermässigs": "kamrermässig",
    "kamrermässigt": "kamrermässig",
    "kamrermässigts": "kamrermässig",
    "kamrern": "kamrer",
    "kamrerns": "kamrer",
    "kamrers": "kamrer",
    "kams": "kam",
    "kamsar": "kams",
    "kamsarna": "kams",
    "kamsarnas": "kams",
    "kamsars": "kams",
    "kamsen": "kams",
    "kamsens": "kams",
    "kamtsjadalen": "kamtsjadal",
    "kamtsjadalens": "kamtsjadal",
    "kamtsjadaler": "kamtsjadal",
    "kamtsjadalerna": "kamtsjadal",
    "kamtsjadalernas": "kamtsjadal",
    "kamtsjadalers": "kamtsjadal",
    "kamtsjadals": "kamtsjadal",
    "kaméer": "kamé",
    "kaméerna": "kamé",
    "kaméernas": "kamé",
    "kaméers": "kamé",
    "kamén": "kamé",
    "kaméns": "kamé",
    "kamés": "kamé",
    "kan": "kunna",
    "kanadagäss": "kanadagås",
    "kanadagässen": "kanadagås",
    "kanadagässens": "kanadagås",
    "kanadagåsen": "kanadagås",
    "kanadagåsens": "kanadagås",
    "kanade": "kana",
    "kanadensar": "kanadensare",
    "kanadensaren": "kanadensare",
    "kanadensarens": "kanadensare",
    "kanadensares": "kanadensare",
    "kanadensarna": "kanadensare",
    "kanadensarnas": "kanadensare",
    "kanadensiska": "kanadensisk",
    "kanadensiskan": "kanadensiska",
    "kanadensiskans": "kanadensiska",
    "kanadensiskare": "kanadensisk",
    "kanadensiskares": "kanadensisk",
    "kanadensiskas": "kanadensiska",
    "kanadensiskast": "kanadensisk",
    "kanadensiskaste": "kanadensisk",
    "kanadensiskastes": "kanadensisk",
    "kanadensiskasts": "kanadensisk",
    "kanadensiske": "kanadensiska",
    "kanadensiskes": "kanadensisk",
    "kanadensiskor": "kanadensiska",
    "kanadensiskorna": "kanadensiska",
    "kanadensiskornas": "kanadensiska",
    "kanadensiskors": "kanadensiska",
    "kanadensisks": "kanadensisk",
    "kanadensiskt": "kanadensisk",
    "kanadensiskts": "kanadensisk",
    "kanades": "kana",
    "kanadicken": "kanadick",
    "kanadickens": "kanadick",
    "kanadicker": "kanadick",
    "kanadickerna": "kanadick",
    "kanadickernas": "kanadick",
    "kanadickers": "kanadick",
    "kanadicks": "kanadick",
    "kanaken": "kanak",
    "kanakens": "kanak",
    "kanaker": "kanak",
    "kanakerna": "kanak",
    "kanakernas": "kanak",
    "kanakers": "kanak",
    "kanaks": "kanak",
    "kanalbyggen": "kanalbygge",
    "kanalbyggena": "kanalbygge",
    "kanalbyggenas": "kanalbygge",
    "kanalbyggens": "kanalbygge",
    "kanalbygges": "kanalbygge",
    "kanalbygget": "kanalbygge",
    "kanalbyggets": "kanalbygge",
    "kanalchefen": "kanalchef",
    "kanalchefens": "kanalchef",
    "kanalchefer": "kanalchef",
    "kanalcheferna": "kanalchef",
    "kanalchefernas": "kanalchef",
    "kanalchefers": "kanalchef",
    "kanalchefs": "kanalchef",
    "kanalen": "kanal",
    "kanalens": "kanal",
    "kanaler": "kanal",
    "kanalerna": "kanal",
    "kanalernas": "kanal",
    "kanalers": "kanal",
    "kanaliserad": "kanalisera",
    "kanaliserade": "kanalisera",
    "kanaliserades": "kanalisera",
    "kanaliserads": "kanalisera",
    "kanaliserande": "kanalisera",
    "kanaliseranden": "kanaliserande",
    "kanaliserandena": "kanaliserande",
    "kanaliserandenas": "kanaliserande",
    "kanaliserandens": "kanaliserande",
    "kanaliserandes": "kanaliserande",
    "kanaliserandet": "kanaliserande",
    "kanaliserandets": "kanaliserande",
    "kanaliserar": "kanalisera",
    "kanaliseras": "kanalisera",
    "kanaliserat": "kanalisera",
    "kanaliserats": "kanalisera",
    "kanaliserbara": "kanaliserbar",
    "kanaliserbarare": "kanaliserbar",
    "kanaliserbarares": "kanaliserbar",
    "kanaliserbaras": "kanaliserbar",
    "kanaliserbarast": "kanaliserbar",
    "kanaliserbaraste": "kanaliserbar",
    "kanaliserbarastes": "kanaliserbar",
    "kanaliserbarasts": "kanaliserbar",
    "kanaliserbare": "kanaliserbar",
    "kanaliserbares": "kanaliserbar",
    "kanaliserbarheten": "kanaliserbarhet",
    "kanaliserbarhetens": "kanaliserbarhet",
    "kanaliserbarhets": "kanaliserbarhet",
    "kanaliserbars": "kanaliserbar",
    "kanaliserbart": "kanaliserbar",
    "kanaliserbarts": "kanaliserbar",
    "kanaliseringar": "kanalisering",
    "kanaliseringarna": "kanalisering",
    "kanaliseringarnas": "kanalisering",
    "kanaliseringars": "kanalisering",
    "kanaliseringen": "kanalisering",
    "kanaliseringens": "kanalisering",
    "kanaliserings": "kanalisering",
    "kanaljen": "kanalje",
    "kanaljens": "kanalje",
    "kanaljer": "kanalje",
    "kanaljerna": "kanalje",
    "kanaljernas": "kanalje",
    "kanaljers": "kanalje",
    "kanaljes": "kanalje",
    "kanalkrockar": "kanalkrock",
    "kanalkrockarna": "kanalkrock",
    "kanalkrockarnas": "kanalkrock",
    "kanalkrockars": "kanalkrock",
    "kanalkrocken": "kanalkrock",
    "kanalkrockens": "kanalkrock",
    "kanalkrocks": "kanalkrock",
    "kanalljusen": "kanalljus",
    "kanalljusens": "kanalljus",
    "kanalljuset": "kanalljus",
    "kanalljusets": "kanalljus",
    "kanals": "kanal",
    "kanalsystemen": "kanalsystem",
    "kanalsystemens": "kanalsystem",
    "kanalsystemet": "kanalsystem",
    "kanalsystemets": "kanalsystem",
    "kanalsystems": "kanalsystem",
    "kanalutbuden": "kanalutbud",
    "kanalutbudens": "kanalutbud",
    "kanalutbudet": "kanalutbud",
    "kanalutbudets": "kanalutbud",
    "kanalutbuds": "kanalutbud",
    "kanalväljar": "kanalväljare",
    "kanalväljaren": "kanalväljare",
    "kanalväljarens": "kanalväljare",
    "kanalväljares": "kanalväljare",
    "kanalväljarna": "kanalväljare",
    "kanalväljarnas": "kanalväljare",
    "kanalångar": "kanalångare",
    "kanalångaren": "kanalångare",
    "kanalångarens": "kanalångare",
    "kanalångares": "kanalångare",
    "kanalångarna": "kanalångare",
    "kanalångarnas": "kanalångare",
    "kanan": "kana",
    "kanande": "kana",
    "kananden": "kanande",
    "kanandena": "kanande",
    "kanandenas": "kanande",
    "kanandens": "kanande",
    "kanandes": "kanande",
    "kanandet": "kanande",
    "kanandets": "kanande",
    "kanans": "kana",
    "kananéen": "kanané",
    "kananéens": "kanané",
    "kananéer": "kanané",
    "kananéerna": "kanané",
    "kananéernas": "kanané",
    "kananéers": "kanané",
    "kananén": "kanané",
    "kananéns": "kanané",
    "kananés": "kanané",
    "kanapéer": "kanapé",
    "kanapéerna": "kanapé",
    "kanapéernas": "kanapé",
    "kanapéers": "kanapé",
    "kanapén": "kanapé",
    "kanapéns": "kanapé",
    "kanapés": "kanapé",
    "kanar": "kana",
    "kanariefröen": "kanariefrö",
    "kanariefröens": "kanariefrö",
    "kanariefröet": "kanariefrö",
    "kanariefröets": "kanariefrö",
    "kanariefrön": "kanariefrö",
    "kanariefröna": "kanariefrö",
    "kanariefrönas": "kanariefrö",
    "kanariefröns": "kanariefrö",
    "kanariefrös": "kanariefrö",
    "kanariefröt": "kanariefrö",
    "kanariefröts": "kanariefrö",
    "kanariefågeln": "kanariefågel",
    "kanariefågelns": "kanariefågel",
    "kanariefågels": "kanariefågel",
    "kanariefåglar": "kanariefågel",
    "kanariefåglarna": "kanariefågel",
    "kanariefåglarnas": "kanariefågel",
    "kanariefåglars": "kanariefågel",
    "kanariegräset": "kanariegräs",
    "kanariegräsets": "kanariegräs",
    "kanariegula": "kanariegul",
    "kanariegulare": "kanariegul",
    "kanariegulares": "kanariegul",
    "kanariegulas": "kanariegul",
    "kanariegulast": "kanariegul",
    "kanariegulaste": "kanariegul",
    "kanariegulastes": "kanariegul",
    "kanariegulasts": "kanariegul",
    "kanariegule": "kanariegul",
    "kanariegules": "kanariegul",
    "kanarieguls": "kanariegul",
    "kanariegult": "kanariegul",
    "kanariegults": "kanariegul",
    "kanas": "kana",
    "kanat": "kana",
    "kanats": "kana",
    "kandaren": "kandar",
    "kandarens": "kandar",
    "kandaret": "kandar",
    "kandarets": "kandar",
    "kandars": "kandar",
    "kandelabern": "kandelaber",
    "kandelaberns": "kandelaber",
    "kandelabers": "kandelaber",
    "kandelabrar": "kandelaber",
    "kandelabrarna": "kandelaber",
    "kandelabrarnas": "kandelaber",
    "kandelabrars": "kandelaber",
    "kanderad": "kandera",
    "kanderade": "kandera",
    "kanderades": "kandera",
    "kanderads": "kandera",
    "kanderande": "kandera",
    "kanderanden": "kanderande",
    "kanderandena": "kanderande",
    "kanderandenas": "kanderande",
    "kanderandens": "kanderande",
    "kanderandes": "kanderande",
    "kanderandet": "kanderande",
    "kanderandets": "kanderande",
    "kanderar": "kandera",
    "kanderas": "kandera",
    "kanderat": "kandera",
    "kanderats": "kandera",
    "kanderbara": "kanderbar",
    "kanderbarare": "kanderbar",
    "kanderbarares": "kanderbar",
    "kanderbaras": "kanderbar",
    "kanderbarast": "kanderbar",
    "kanderbaraste": "kanderbar",
    "kanderbarastes": "kanderbar",
    "kanderbarasts": "kanderbar",
    "kanderbare": "kanderbar",
    "kanderbares": "kanderbar",
    "kanderbarheten": "kanderbarhet",
    "kanderbarhetens": "kanderbarhet",
    "kanderbarhets": "kanderbarhet",
    "kanderbars": "kanderbar",
    "kanderbart": "kanderbar",
    "kanderbarts": "kanderbar",
    "kanderingar": "kandering",
    "kanderingarna": "kandering",
    "kanderingarnas": "kandering",
    "kanderingars": "kandering",
    "kanderingen": "kandering",
    "kanderingens": "kandering",
    "kanderings": "kandering",
    "kandidaten": "kandidat",
    "kandidatens": "kandidat",
    "kandidater": "kandidat",
    "kandidaterna": "kandidat",
    "kandidaternas": "kandidat",
    "kandidaters": "kandidat",
    "kandidatlistan": "kandidatlista",
    "kandidatlistans": "kandidatlista",
    "kandidatlistas": "kandidatlista",
    "kandidatliste": "kandidatlista",
    "kandidatlistor": "kandidatlista",
    "kandidatlistorna": "kandidatlista",
    "kandidatlistornas": "kandidatlista",
    "kandidatlistors": "kandidatlista",
    "kandidats": "kandidat",
    "kandidaturen": "kandidatur",
    "kandidaturens": "kandidatur",
    "kandidaturer": "kandidatur",
    "kandidaturerna": "kandidatur",
    "kandidaturernas": "kandidatur",
    "kandidaturers": "kandidatur",
    "kandidaturs": "kandidatur",
    "kandiderade": "kandidera",
    "kandiderades": "kandidera",
    "kandiderande": "kandidera",
    "kandideranden": "kandiderande",
    "kandiderandena": "kandiderande",
    "kandiderandenas": "kandiderande",
    "kandiderandens": "kandiderande",
    "kandiderandes": "kandiderande",
    "kandiderandet": "kandiderande",
    "kandiderandets": "kandiderande",
    "kandiderar": "kandidera",
    "kandideras": "kandidera",
    "kandiderat": "kandidera",
    "kandiderats": "kandidera",
    "kandiderbara": "kandiderbar",
    "kandiderbarare": "kandiderbar",
    "kandiderbarares": "kandiderbar",
    "kandiderbaras": "kandiderbar",
    "kandiderbarast": "kandiderbar",
    "kandiderbaraste": "kandiderbar",
    "kandiderbarastes": "kandiderbar",
    "kandiderbarasts": "kandiderbar",
    "kandiderbare": "kandiderbar",
    "kandiderbares": "kandiderbar",
    "kandiderbarheten": "kandiderbarhet",
    "kandiderbarhetens": "kandiderbarhet",
    "kandiderbarhets": "kandiderbarhet",
    "kandiderbars": "kandiderbar",
    "kandiderbart": "kandiderbar",
    "kandiderbarts": "kandiderbar",
    "kandideringar": "kandidering",
    "kandideringarna": "kandidering",
    "kandideringarnas": "kandidering",
    "kandideringars": "kandidering",
    "kandideringen": "kandidering",
    "kandideringens": "kandidering",
    "kandiderings": "kandidering",
    "kandis": "kandi",
    "kandisockers": "kandisocker",
    "kandisockret": "kandisocker",
    "kandisockrets": "kandisocker",
    "kandit": "kandi",
    "kandits": "kandi",
    "kane": "kana",
    "kanelbruna": "kanelbrun",
    "kanelbrunare": "kanelbrun",
    "kanelbrunares": "kanelbrun",
    "kanelbrunas": "kanelbrun",
    "kanelbrunast": "kanelbrun",
    "kanelbrunaste": "kanelbrun",
    "kanelbrunastes": "kanelbrun",
    "kanelbrunasts": "kanelbrun",
    "kanelbrune": "kanelbrun",
    "kanelbrunes": "kanelbrun",
    "kanelbruns": "kanelbrun",
    "kanelbrunt": "kanelbrun",
    "kanelbrunts": "kanelbrun",
    "kanelbull": "kanelbulle",
    "kanelbullan": "kanelbulla",
    "kanelbullans": "kanelbulla",
    "kanelbullar": "kanelbulle",
    "kanelbullarna": "kanelbulle",
    "kanelbullarnas": "kanelbulle",
    "kanelbullars": "kanelbulle",
    "kanelbullas": "kanelbulla",
    "kanelbulle": "kanelbulla",
    "kanelbullen": "kanelbulle",
    "kanelbullens": "kanelbulle",
    "kanelbulles": "kanelbulle",
    "kanelbullor": "kanelbulla",
    "kanelbullorna": "kanelbulla",
    "kanelbullornas": "kanelbulla",
    "kanelbullors": "kanelbulla",
    "kanelbulls": "kanelbulle",
    "kanelen": "kanel",
    "kanelens": "kanel",
    "kanels": "kanel",
    "kanelstänger": "kanelstång",
    "kanelstängerna": "kanelstång",
    "kanelstängernas": "kanelstång",
    "kanelstängers": "kanelstång",
    "kanelstången": "kanelstång",
    "kanelstångens": "kanelstång",
    "kanelstångs": "kanelstång",
    "kanen": "kan",
    "kanens": "kan",
    "kaner": "kan",
    "kanerna": "kan",
    "kanernas": "kan",
    "kaners": "kan",
    "kanfasen": "kanfas",
    "kanfasens": "kanfas",
    "kanfaser": "kanfas",
    "kanfaserna": "kanfas",
    "kanfasernas": "kanfas",
    "kanfasers": "kanfas",
    "kaniken": "kanik",
    "kanikens": "kanik",
    "kaniker": "kanik",
    "kanikerna": "kanik",
    "kanikernas": "kanik",
    "kanikers": "kanik",
    "kaniks": "kanik",
    "kaninen": "kanin",
    "kaninens": "kanin",
    "kaniner": "kanin",
    "kaninerna": "kanin",
    "kaninernas": "kanin",
    "kaniners": "kanin",
    "kaninhål": "kaninhåla",
    "kaninhålan": "kaninhåla",
    "kaninhålans": "kaninhåla",
    "kaninhålas": "kaninhåla",
    "kaninhåle": "kaninhåla",
    "kaninhålen": "kaninhål",
    "kaninhålens": "kaninhål",
    "kaninhålet": "kaninhål",
    "kaninhålets": "kaninhål",
    "kaninhålor": "kaninhåla",
    "kaninhålorna": "kaninhåla",
    "kaninhålornas": "kaninhåla",
    "kaninhålors": "kaninhåla",
    "kaninhåls": "kaninhåla",
    "kaninpulsen": "kaninpuls",
    "kaninpulsens": "kaninpuls",
    "kanins": "kanin",
    "kaninstora": "kaninstor",
    "kaninstoras": "kaninstor",
    "kaninstore": "kaninstor",
    "kaninstores": "kaninstor",
    "kaninstors": "kaninstor",
    "kaninstort": "kaninstor",
    "kaninstorts": "kaninstor",
    "kanistern": "kanister",
    "kanisterns": "kanister",
    "kanisters": "kanister",
    "kanistrar": "kanister",
    "kanistrarna": "kanister",
    "kanistrarnas": "kanister",
    "kanistrars": "kanister",
    "kanjonen": "kanjon",
    "kanjonens": "kanjon",
    "kanjoner": "kanjon",
    "kanjonerna": "kanjon",
    "kanjonernas": "kanjon",
    "kanjoners": "kanjon",
    "kanjons": "kanjon",
    "kann": "kanna",
    "kannan": "kanna",
    "kannans": "kanna",
    "kannas": "kanna",
    "kannbrosken": "kannbrosk",
    "kannbroskens": "kannbrosk",
    "kannbrosket": "kannbrosk",
    "kannbroskets": "kannbrosk",
    "kannbrosks": "kannbrosk",
    "kanne": "kanna",
    "kannelerad": "kannelera",
    "kannelerade": "kannelera",
    "kannelerades": "kannelera",
    "kannelerads": "kannelera",
    "kannelerande": "kannelera",
    "kanneleranden": "kannelerande",
    "kannelerandena": "kannelerande",
    "kannelerandenas": "kannelerande",
    "kannelerandens": "kannelerande",
    "kannelerandes": "kannelerande",
    "kannelerandet": "kannelerande",
    "kannelerandets": "kannelerande",
    "kannelerar": "kannelera",
    "kanneleras": "kannelera",
    "kannelerat": "kannelera",
    "kannelerats": "kannelera",
    "kannelerbara": "kannelerbar",
    "kannelerbarare": "kannelerbar",
    "kannelerbarares": "kannelerbar",
    "kannelerbaras": "kannelerbar",
    "kannelerbarast": "kannelerbar",
    "kannelerbaraste": "kannelerbar",
    "kannelerbarastes": "kannelerbar",
    "kannelerbarasts": "kannelerbar",
    "kannelerbare": "kannelerbar",
    "kannelerbares": "kannelerbar",
    "kannelerbarheten": "kannelerbarhet",
    "kannelerbarhetens": "kannelerbarhet",
    "kannelerbarhets": "kannelerbarhet",
    "kannelerbars": "kannelerbar",
    "kannelerbart": "kannelerbar",
    "kannelerbarts": "kannelerbar",
    "kanneleringar": "kannelering",
    "kanneleringarna": "kannelering",
    "kanneleringarnas": "kannelering",
    "kanneleringars": "kannelering",
    "kanneleringen": "kannelering",
    "kanneleringens": "kannelering",
    "kannelerings": "kannelering",
    "kannelyren": "kannelyr",
    "kannelyrens": "kannelyr",
    "kannelyrer": "kannelyr",
    "kannelyrerna": "kannelyr",
    "kannelyrernas": "kannelyr",
    "kannelyrers": "kannelyr",
    "kannelyrs": "kannelyr",
    "kannibalen": "kannibal",
    "kannibalens": "kannibal",
    "kannibaler": "kannibal",
    "kannibalerna": "kannibal",
    "kannibalernas": "kannibal",
    "kannibalers": "kannibal",
    "kannibalgryt": "kannibalgryta",
    "kannibalgrytan": "kannibalgryta",
    "kannibalgrytans": "kannibalgryta",
    "kannibalgrytas": "kannibalgryta",
    "kannibalgryte": "kannibalgryta",
    "kannibalgrytor": "kannibalgryta",
    "kannibalgrytorna": "kannibalgryta",
    "kannibalgrytornas": "kannibalgryta",
    "kannibalgrytors": "kannibalgryta",
    "kannibalgryts": "kannibalgryta",
    "kannibaliska": "kannibalisk",
    "kannibaliskare": "kannibalisk",
    "kannibaliskares": "kannibalisk",
    "kannibaliskas": "kannibalisk",
    "kannibaliskast": "kannibalisk",
    "kannibaliskaste": "kannibalisk",
    "kannibaliskastes": "kannibalisk",
    "kannibaliskasts": "kannibalisk",
    "kannibaliske": "kannibalisk",
    "kannibaliskes": "kannibalisk",
    "kannibalisks": "kannibalisk",
    "kannibaliskt": "kannibalisk",
    "kannibaliskts": "kannibalisk",
    "kannibalismen": "kannibalism",
    "kannibalismens": "kannibalism",
    "kannibalismer": "kannibalism",
    "kannibalismerna": "kannibalism",
    "kannibalismernas": "kannibalism",
    "kannibalismers": "kannibalism",
    "kannibalisms": "kannibalism",
    "kannibalistiska": "kannibalistisk",
    "kannibalistiskas": "kannibalistisk",
    "kannibalistiske": "kannibalistisk",
    "kannibalistiskes": "kannibalistisk",
    "kannibalistisks": "kannibalistisk",
    "kannibalistiskt": "kannibalistisk",
    "kannibalistiskts": "kannibalistisk",
    "kannibals": "kannibal",
    "kannor": "kanna",
    "kannorna": "kanna",
    "kannornas": "kanna",
    "kannors": "kanna",
    "kanns": "kanna",
    "kannstöpar": "kannstöpare",
    "kannstöparen": "kannstöpare",
    "kannstöparens": "kannstöpare",
    "kannstöpares": "kannstöpare",
    "kannstöparna": "kannstöpare",
    "kannstöparnas": "kannstöpare",
    "kannstöperier": "kannstöperi",
    "kannstöperierna": "kannstöperi",
    "kannstöperiernas": "kannstöperi",
    "kannstöperiers": "kannstöperi",
    "kannstöperiet": "kannstöperi",
    "kannstöperiets": "kannstöperi",
    "kannstöperis": "kannstöperi",
    "kannstöperit": "kannstöperi",
    "kannstöperits": "kannstöperi",
    "kanonaden": "kanonad",
    "kanonadens": "kanonad",
    "kanonader": "kanonad",
    "kanonaderna": "kanonad",
    "kanonadernas": "kanonad",
    "kanonaders": "kanonad",
    "kanonads": "kanonad",
    "kanonaffären": "kanonaffär",
    "kanonaffärens": "kanonaffär",
    "kanonaffärer": "kanonaffär",
    "kanonaffärerna": "kanonaffär",
    "kanonaffärernas": "kanonaffär",
    "kanonaffärers": "kanonaffär",
    "kanonaffärs": "kanonaffär",
    "kanonbåtar": "kanonbåt",
    "kanonbåtarna": "kanonbåt",
    "kanonbåtarnas": "kanonbåt",
    "kanonbåtars": "kanonbåt",
    "kanonbåten": "kanonbåt",
    "kanonbåtens": "kanonbåt",
    "kanonbåts": "kanonbåt",
    "kanonbåtsdiplomatien": "kanonbåtsdiplomati",
    "kanonbåtsdiplomatiens": "kanonbåtsdiplomati",
    "kanonbåtsdiplomatin": "kanonbåtsdiplomati",
    "kanonbåtsdiplomatins": "kanonbåtsdiplomati",
    "kanonbåtsdiplomatis": "kanonbåtsdiplomati",
    "kanonelden": "kanoneld",
    "kanoneldens": "kanoneld",
    "kanonelds": "kanoneld",
    "kanonen": "kanon",
    "kanonens": "kanon",
    "kanoner": "kanon",
    "kanonerbjudanden": "kanonerbjudande",
    "kanonerbjudandena": "kanonerbjudande",
    "kanonerbjudandenas": "kanonerbjudande",
    "kanonerbjudandens": "kanonerbjudande",
    "kanonerbjudandes": "kanonerbjudande",
    "kanonerbjudandet": "kanonerbjudande",
    "kanonerbjudandets": "kanonerbjudande",
    "kanonerna": "kanon",
    "kanonernas": "kanon",
    "kanoners": "kanon",
    "kanonfotografen": "kanonfotograf",
    "kanonfotografens": "kanonfotograf",
    "kanonfotografer": "kanonfotograf",
    "kanonfotograferna": "kanonfotograf",
    "kanonfotografernas": "kanonfotograf",
    "kanonfotografers": "kanonfotograf",
    "kanonfotografs": "kanonfotograf",
    "kanonfödan": "kanonföda",
    "kanonfödans": "kanonföda",
    "kanonfödas": "kanonföda",
    "kanongjuterier": "kanongjuteri",
    "kanongjuterierna": "kanongjuteri",
    "kanongjuteriernas": "kanongjuteri",
    "kanongjuteriers": "kanongjuteri",
    "kanongjuteriet": "kanongjuteri",
    "kanongjuteriets": "kanongjuteri",
    "kanongjuteris": "kanongjuteri",
    "kanongjuterit": "kanongjuteri",
    "kanongjuterits": "kanongjuteri",
    "kanonisationen": "kanonisation",
    "kanonisationens": "kanonisation",
    "kanonisationer": "kanonisation",
    "kanonisationerna": "kanonisation",
    "kanonisationernas": "kanonisation",
    "kanonisationers": "kanonisation",
    "kanonisations": "kanonisation",
    "kanoniserad": "kanonisera",
    "kanoniserade": "kanonisera",
    "kanoniserades": "kanonisera",
    "kanoniserads": "kanonisera",
    "kanoniserande": "kanonisera",
    "kanoniseranden": "kanoniserande",
    "kanoniserandena": "kanoniserande",
    "kanoniserandenas": "kanoniserande",
    "kanoniserandens": "kanoniserande",
    "kanoniserandes": "kanoniserande",
    "kanoniserandet": "kanoniserande",
    "kanoniserandets": "kanoniserande",
    "kanoniserar": "kanonisera",
    "kanoniseras": "kanonisera",
    "kanoniserat": "kanonisera",
    "kanoniserats": "kanonisera",
    "kanoniserbara": "kanoniserbar",
    "kanoniserbarare": "kanoniserbar",
    "kanoniserbarares": "kanoniserbar",
    "kanoniserbaras": "kanoniserbar",
    "kanoniserbarast": "kanoniserbar",
    "kanoniserbaraste": "kanoniserbar",
    "kanoniserbarastes": "kanoniserbar",
    "kanoniserbarasts": "kanoniserbar",
    "kanoniserbare": "kanoniserbar",
    "kanoniserbares": "kanoniserbar",
    "kanoniserbarheten": "kanoniserbarhet",
    "kanoniserbarhetens": "kanoniserbarhet",
    "kanoniserbarhets": "kanoniserbarhet",
    "kanoniserbars": "kanoniserbar",
    "kanoniserbart": "kanoniserbar",
    "kanoniserbarts": "kanoniserbar",
    "kanoniseringar": "kanonisering",
    "kanoniseringarna": "kanonisering",
    "kanoniseringarnas": "kanonisering",
    "kanoniseringars": "kanonisering",
    "kanoniseringen": "kanonisering",
    "kanoniseringens": "kanonisering",
    "kanoniserings": "kanonisering",
    "kanoniska": "kanonisk",
    "kanoniskare": "kanonisk",
    "kanoniskares": "kanonisk",
    "kanoniskas": "kanonisk",
    "kanoniskast": "kanonisk",
    "kanoniskaste": "kanonisk",
    "kanoniskastes": "kanonisk",
    "kanoniskasts": "kanonisk",
    "kanoniske": "kanonisk",
    "kanoniskes": "kanonisk",
    "kanonisks": "kanonisk",
    "kanoniskt": "kanonisk",
    "kanoniskts": "kanonisk",
    "kanoniären": "kanoniär",
    "kanoniärens": "kanoniär",
    "kanoniärer": "kanoniär",
    "kanoniärerna": "kanoniär",
    "kanoniärernas": "kanoniär",
    "kanoniärers": "kanoniär",
    "kanoniärs": "kanoniär",
    "kanonjären": "kanonjär",
    "kanonjärens": "kanonjär",
    "kanonjärer": "kanonjär",
    "kanonjärerna": "kanonjär",
    "kanonjärernas": "kanonjär",
    "kanonjärers": "kanonjär",
    "kanonjärs": "kanonjär",
    "kanonkul": "kanonkula",
    "kanonkulan": "kanonkula",
    "kanonkulans": "kanonkula",
    "kanonkulas": "kanonkula",
    "kanonkule": "kanonkula",
    "kanonkulor": "kanonkula",
    "kanonkulorna": "kanonkula",
    "kanonkulornas": "kanonkula",
    "kanonkulors": "kanonkula",
    "kanonkuls": "kanonkula",
    "kanonköpen": "kanonköp",
    "kanonköpens": "kanonköp",
    "kanonköpet": "kanonköp",
    "kanonköpets": "kanonköp",
    "kanonköps": "kanonköp",
    "kanonlockar": "kanonlock",
    "kanonlockarna": "kanonlock",
    "kanonlockarnas": "kanonlock",
    "kanonlockars": "kanonlock",
    "kanonlocken": "kanonlock",
    "kanonlockens": "kanonlock",
    "kanonlocks": "kanonlock",
    "kanonloppen": "kanonlopp",
    "kanonloppens": "kanonlopp",
    "kanonloppet": "kanonlopp",
    "kanonloppets": "kanonlopp",
    "kanonlopps": "kanonlopp",
    "kanonmaten": "kanonmat",
    "kanonmatens": "kanonmat",
    "kanonmats": "kanonmat",
    "kanonportar": "kanonport",
    "kanonportarna": "kanonport",
    "kanonportarnas": "kanonport",
    "kanonportars": "kanonport",
    "kanonporten": "kanonport",
    "kanonportens": "kanonport",
    "kanonports": "kanonport",
    "kanons": "kanon",
    "kanonseten": "kanonset",
    "kanonsetens": "kanonset",
    "kanonsetet": "kanonset",
    "kanonsetets": "kanonset",
    "kanonsets": "kanonset",
    "kanontornen": "kanontorn",
    "kanontornens": "kanontorn",
    "kanontornet": "kanontorn",
    "kanontornets": "kanontorn",
    "kanontorns": "kanontorn",
    "kanonväderna": "kanonväder",
    "kanonvädernas": "kanonväder",
    "kanonväders": "kanonväder",
    "kanonvädren": "kanonväder",
    "kanonvädrens": "kanonväder",
    "kanonvädret": "kanonväder",
    "kanonvädrets": "kanonväder",
    "kanor": "kana",
    "kanorna": "kana",
    "kanornas": "kana",
    "kanors": "kana",
    "kanotade": "kanota",
    "kanotades": "kanota",
    "kanotande": "kanota",
    "kanotanden": "kanotande",
    "kanotandena": "kanotande",
    "kanotandenas": "kanotande",
    "kanotandens": "kanotande",
    "kanotandes": "kanotande",
    "kanotandet": "kanotande",
    "kanotandets": "kanotande",
    "kanotar": "kanota",
    "kanotas": "kanota",
    "kanotat": "kanota",
    "kanotats": "kanota",
    "kanoten": "kanot",
    "kanotens": "kanot",
    "kanoter": "kanot",
    "kanoterna": "kanot",
    "kanoternas": "kanot",
    "kanoters": "kanot",
    "kanotisten": "kanotist",
    "kanotistens": "kanotist",
    "kanotister": "kanotist",
    "kanotisterna": "kanotist",
    "kanotisternas": "kanotist",
    "kanotisters": "kanotist",
    "kanotists": "kanotist",
    "kanotresan": "kanotresa",
    "kanotresans": "kanotresa",
    "kanotresas": "kanotresa",
    "kanotrese": "kanotresa",
    "kanotresor": "kanotresa",
    "kanotresorna": "kanotresa",
    "kanotresornas": "kanotresa",
    "kanotresors": "kanotresa",
    "kanots": "kanot",
    "kans": "kana",
    "kansleren": "kansler",
    "kanslerens": "kansler",
    "kanslerer": "kansler",
    "kanslererna": "kansler",
    "kanslerernas": "kansler",
    "kanslerers": "kansler",
    "kanslern": "kansler",
    "kanslerns": "kansler",
    "kanslers": "kansler",
    "kanslier": "kansli",
    "kanslierna": "kansli",
    "kansliernas": "kansli",
    "kansliers": "kansli",
    "kansliet": "kansli",
    "kansliets": "kansli",
    "kanslihuset": "kanslihus",
    "kanslihusets": "kanslihus",
    "kanslimässiga": "kanslimässig",
    "kanslimässigare": "kanslimässig",
    "kanslimässigares": "kanslimässig",
    "kanslimässigas": "kanslimässig",
    "kanslimässigast": "kanslimässig",
    "kanslimässigaste": "kanslimässig",
    "kanslimässigastes": "kanslimässig",
    "kanslimässigasts": "kanslimässig",
    "kanslimässige": "kanslimässig",
    "kanslimässiges": "kanslimässig",
    "kanslimässigs": "kanslimässig",
    "kanslimässigt": "kanslimässig",
    "kanslimässigts": "kanslimässig",
    "kansliråden": "kansliråd",
    "kanslirådens": "kansliråd",
    "kanslirådet": "kansliråd",
    "kanslirådets": "kansliråd",
    "kansliråds": "kansliråd",
    "kanslis": "kansli",
    "kanslisekreterar": "kanslisekreterare",
    "kanslisekreteraren": "kanslisekreterare",
    "kanslisekreterarens": "kanslisekreterare",
    "kanslisekreterares": "kanslisekreterare",
    "kanslisekreterarna": "kanslisekreterare",
    "kanslisekreterarnas": "kanslisekreterare",
    "kanslispråket": "kanslispråk",
    "kanslispråkets": "kanslispråk",
    "kanslispråks": "kanslispråk",
    "kanslisten": "kanslist",
    "kanslistens": "kanslist",
    "kanslister": "kanslist",
    "kanslisterna": "kanslist",
    "kanslisternas": "kanslist",
    "kanslisters": "kanslist",
    "kanslistilen": "kanslistil",
    "kanslistilens": "kanslistil",
    "kanslistils": "kanslistil",
    "kanslists": "kanslist",
    "kanslisvensk": "kanslisvenska",
    "kanslisvenskan": "kanslisvenska",
    "kanslisvenskans": "kanslisvenska",
    "kanslisvenskas": "kanslisvenska",
    "kanslit": "kansli",
    "kanslits": "kansli",
    "kantabels": "kantabel",
    "kantabelt": "kantabel",
    "kantabelts": "kantabel",
    "kantabla": "kantabel",
    "kantablare": "kantabel",
    "kantablares": "kantabel",
    "kantablas": "kantabel",
    "kantablast": "kantabel",
    "kantablaste": "kantabel",
    "kantablastes": "kantabel",
    "kantablasts": "kantabel",
    "kantable": "kantabel",
    "kantables": "kantabel",
    "kantad": "kanta",
    "kantade": "kanta",
    "kantades": "kanta",
    "kantads": "kanta",
    "kantande": "kanta",
    "kantanden": "kantande",
    "kantandena": "kantande",
    "kantandenas": "kantande",
    "kantandens": "kantande",
    "kantandes": "kantande",
    "kantandet": "kantande",
    "kantandets": "kantande",
    "kantar": "kanta",
    "kantarellen": "kantarell",
    "kantarellens": "kantarell",
    "kantareller": "kantarell",
    "kantarellerna": "kantarell",
    "kantarellernas": "kantarell",
    "kantarellers": "kantarell",
    "kantarells": "kantarell",
    "kantas": "kanta",
    "kantat": "kanta",
    "kantaten": "kantat",
    "kantatens": "kantat",
    "kantater": "kantat",
    "kantaterna": "kantat",
    "kantaternas": "kantat",
    "kantaters": "kantat",
    "kantats": "kantat",
    "kantbanden": "kantband",
    "kantbandens": "kantband",
    "kantbandet": "kantband",
    "kantbandets": "kantband",
    "kantbands": "kantband",
    "kantbeslagen": "kantbeslag",
    "kantbeslagens": "kantbeslag",
    "kantbeslaget": "kantbeslag",
    "kantbeslagets": "kantbeslag",
    "kantbeslags": "kantbeslag",
    "kantblom": "kantblomma",
    "kantblomman": "kantblomma",
    "kantblommans": "kantblomma",
    "kantblommas": "kantblomma",
    "kantblomme": "kantblomma",
    "kantblommor": "kantblomma",
    "kantblommorna": "kantblomma",
    "kantblommornas": "kantblomma",
    "kantblommors": "kantblomma",
    "kantbloms": "kantblomma",
    "kantelen": "kantele",
    "kantelens": "kantele",
    "kanteler": "kantele",
    "kantelerna": "kantele",
    "kantelernas": "kantele",
    "kantelers": "kantele",
    "kanteles": "kantele",
    "kanten": "kant",
    "kantens": "kant",
    "kanter": "kant",
    "kanterna": "kant",
    "kanternas": "kant",
    "kanters": "kant",
    "kanthugg": "kanthugga",
    "kanthuggande": "kanthugga",
    "kanthugganden": "kanthuggande",
    "kanthuggandena": "kanthuggande",
    "kanthuggandenas": "kanthuggande",
    "kanthuggandens": "kanthuggande",
    "kanthuggandes": "kanthuggande",
    "kanthuggandet": "kanthuggande",
    "kanthuggandets": "kanthuggande",
    "kanthuggas": "kanthugga",
    "kanthugge": "kanthugga",
    "kanthuggen": "kanthugga",
    "kanthuggens": "kanthugga",
    "kanthugger": "kanthugga",
    "kanthugges": "kanthugga",
    "kanthugget": "kanthugga",
    "kanthuggets": "kanthugga",
    "kanthuggit": "kanthugga",
    "kanthuggits": "kanthugga",
    "kanthuggna": "kanthugga",
    "kanthuggnas": "kanthugga",
    "kanthuggne": "kanthugga",
    "kanthuggnes": "kanthugga",
    "kanthuggs": "kanthugga",
    "kanthyveln": "kanthyvel",
    "kanthyvelns": "kanthyvel",
    "kanthyvels": "kanthyvel",
    "kanthyvlar": "kanthyvel",
    "kanthyvlarna": "kanthyvel",
    "kanthyvlarnas": "kanthyvel",
    "kanthyvlars": "kanthyvel",
    "kanthögg": "kanthugga",
    "kanthögge": "kanthugga",
    "kanthögges": "kanthugga",
    "kanthöggs": "kanthugga",
    "kantiga": "kantig",
    "kantigare": "kantig",
    "kantigares": "kantig",
    "kantigas": "kantig",
    "kantigast": "kantig",
    "kantigaste": "kantig",
    "kantigastes": "kantig",
    "kantigasts": "kantig",
    "kantige": "kantig",
    "kantiges": "kantig",
    "kantigheten": "kantighet",
    "kantighetens": "kantighet",
    "kantigheter": "kantighet",
    "kantigheterna": "kantighet",
    "kantigheternas": "kantighet",
    "kantigheters": "kantighet",
    "kantighets": "kantighet",
    "kantigs": "kantig",
    "kantigt": "kantig",
    "kantigts": "kantig",
    "kantilen": "kantilena",
    "kantilenan": "kantilena",
    "kantilenans": "kantilena",
    "kantilenas": "kantilena",
    "kantilene": "kantilena",
    "kantilenor": "kantilena",
    "kantilenorna": "kantilena",
    "kantilenornas": "kantilena",
    "kantilenors": "kantilena",
    "kantilens": "kantilena",
    "kantinen": "kantin",
    "kantinens": "kantin",
    "kantiner": "kantin",
    "kantinerna": "kantin",
    "kantinernas": "kantin",
    "kantiners": "kantin",
    "kantins": "kantin",
    "kantklipp": "kantklippa",
    "kantklippande": "kantklippa",
    "kantklippanden": "kantklippande",
    "kantklippandena": "kantklippande",
    "kantklippandenas": "kantklippande",
    "kantklippandens": "kantklippande",
    "kantklippandes": "kantklippande",
    "kantklippandet": "kantklippande",
    "kantklippandets": "kantklippande",
    "kantklippas": "kantklippa",
    "kantklipper": "kantklippa",
    "kantklippes": "kantklippa",
    "kantklippningar": "kantklippning",
    "kantklippningarna": "kantklippning",
    "kantklippningarnas": "kantklippning",
    "kantklippningars": "kantklippning",
    "kantklippningen": "kantklippning",
    "kantklippningens": "kantklippning",
    "kantklippnings": "kantklippning",
    "kantklipps": "kantklippa",
    "kantklippt": "kantklippa",
    "kantklippta": "kantklippa",
    "kantklipptas": "kantklippa",
    "kantklippte": "kantklippa",
    "kantklipptes": "kantklippa",
    "kantklippts": "kantklippa",
    "kantnålar": "kantnål",
    "kantnålarna": "kantnål",
    "kantnålarnas": "kantnål",
    "kantnålars": "kantnål",
    "kantnålen": "kantnål",
    "kantnålens": "kantnål",
    "kantnåls": "kantnål",
    "kantonen": "kanton",
    "kantonens": "kanton",
    "kantoner": "kanton",
    "kantonerna": "kanton",
    "kantonernas": "kanton",
    "kantoners": "kanton",
    "kantons": "kanton",
    "kantorer": "kantor",
    "kantorerna": "kantor",
    "kantorernas": "kantor",
    "kantorers": "kantor",
    "kantorn": "kantor",
    "kantorns": "kantor",
    "kantors": "kantor",
    "kantrad": "kantra",
    "kantrade": "kantra",
    "kantrades": "kantra",
    "kantrads": "kantra",
    "kantrande": "kantra",
    "kantranden": "kantrande",
    "kantrandena": "kantrande",
    "kantrandenas": "kantrande",
    "kantrandens": "kantrande",
    "kantrandes": "kantrande",
    "kantrandet": "kantrande",
    "kantrandets": "kantrande",
    "kantrar": "kantra",
    "kantras": "kantra",
    "kantrat": "kantra",
    "kantrats": "kantra",
    "kantrepen": "kantrep",
    "kantrepens": "kantrep",
    "kantrepet": "kantrep",
    "kantrepets": "kantrep",
    "kantreps": "kantrep",
    "kantstenar": "kantsten",
    "kantstenarna": "kantsten",
    "kantstenarnas": "kantsten",
    "kantstenars": "kantsten",
    "kantstenen": "kantsten",
    "kantstenens": "kantsten",
    "kantstens": "kantsten",
    "kantstötta": "kantstött",
    "kantstöttare": "kantstött",
    "kantstöttares": "kantstött",
    "kantstöttas": "kantstött",
    "kantstöttast": "kantstött",
    "kantstöttaste": "kantstött",
    "kantstöttastes": "kantstött",
    "kantstöttasts": "kantstött",
    "kantstötte": "kantstött",
    "kantstöttes": "kantstött",
    "kantstöttheten": "kantstötthet",
    "kantstötthetens": "kantstötthet",
    "kantstötthets": "kantstötthet",
    "kantstötts": "kantstött",
    "kantsömmar": "kantsöm",
    "kantsömmarna": "kantsöm",
    "kantsömmarnas": "kantsöm",
    "kantsömmars": "kantsöm",
    "kantsömmen": "kantsöm",
    "kantsömmens": "kantsöm",
    "kantsöms": "kantsöm",
    "kantväxten": "kantväxt",
    "kantväxtens": "kantväxt",
    "kantväxter": "kantväxt",
    "kantväxterna": "kantväxt",
    "kantväxternas": "kantväxt",
    "kantväxters": "kantväxt",
    "kantväxts": "kantväxt",
    "kanvasbanden": "kanvasband",
    "kanvasbandens": "kanvasband",
    "kanvasbandet": "kanvasband",
    "kanvasbandets": "kanvasband",
    "kanvasbands": "kanvasband",
    "kanvasdukar": "kanvasduk",
    "kanvasdukarna": "kanvasduk",
    "kanvasdukarnas": "kanvasduk",
    "kanvasdukars": "kanvasduk",
    "kanvasduken": "kanvasduk",
    "kanvasdukens": "kanvasduk",
    "kanvasduks": "kanvasduk",
    "kanvasen": "kanvas",
    "kanvasens": "kanvas",
    "kanylen": "kanyl",
    "kanylens": "kanyl",
    "kanyler": "kanyl",
    "kanylerna": "kanyl",
    "kanylernas": "kanyl",
    "kanylers": "kanyl",
    "kanyls": "kanyl",
    "kaolinen": "kaolin",
    "kaolinens": "kaolin",
    "kaolinet": "kaolin",
    "kaolinets": "kaolin",
    "kaolins": "kaolin",
    "kaoset": "kaos",
    "kaosets": "kaos",
    "kaosteorien": "kaosteori",
    "kaosteoriens": "kaosteori",
    "kaosteorin": "kaosteori",
    "kaosteorins": "kaosteori",
    "kaosteoris": "kaosteori",
    "kaotiska": "kaotisk",
    "kaotiskare": "kaotisk",
    "kaotiskares": "kaotisk",
    "kaotiskas": "kaotisk",
    "kaotiskast": "kaotisk",
    "kaotiskaste": "kaotisk",
    "kaotiskastes": "kaotisk",
    "kaotiskasts": "kaotisk",
    "kaotiske": "kaotisk",
    "kaotiskes": "kaotisk",
    "kaotisks": "kaotisk",
    "kaotiskt": "kaotisk",
    "kaotiskts": "kaotisk",
    "kap": "kapa",
    "kapabels": "kapabel",
    "kapabelt": "kapabel",
    "kapabelts": "kapabel",
    "kapabla": "kapabel",
    "kapablare": "kapabel",
    "kapablares": "kapabel",
    "kapablas": "kapabel",
    "kapablast": "kapabel",
    "kapablaste": "kapabel",
    "kapablastes": "kapabel",
    "kapablasts": "kapabel",
    "kapable": "kapabel",
    "kapables": "kapabel",
    "kapacitansen": "kapacitans",
    "kapacitansens": "kapacitans",
    "kapaciteten": "kapacitet",
    "kapacitetens": "kapacitet",
    "kapaciteter": "kapacitet",
    "kapaciteterna": "kapacitet",
    "kapaciteternas": "kapacitet",
    "kapaciteters": "kapacitet",
    "kapacitets": "kapacitet",
    "kapacitetsökningar": "kapacitetsökning",
    "kapacitetsökningarna": "kapacitetsökning",
    "kapacitetsökningarnas": "kapacitetsökning",
    "kapacitetsökningars": "kapacitetsökning",
    "kapacitetsökningen": "kapacitetsökning",
    "kapacitetsökningens": "kapacitetsökning",
    "kapacitetsöknings": "kapacitetsökning",
    "kapad": "kapa",
    "kapade": "kapa",
    "kapades": "kapa",
    "kapads": "kapa",
    "kapande": "kapa",
    "kapanden": "kapande",
    "kapandena": "kapande",
    "kapandenas": "kapande",
    "kapandens": "kapande",
    "kapandes": "kapande",
    "kapandet": "kapande",
    "kapandets": "kapande",
    "kapar": "kapare",
    "kaparen": "kapare",
    "kaparens": "kapare",
    "kapares": "kapare",
    "kaparna": "kapare",
    "kaparnas": "kapare",
    "kapas": "kapa",
    "kapat": "kapa",
    "kapats": "kapa",
    "kapduv": "kapduva",
    "kapduvan": "kapduva",
    "kapduvans": "kapduva",
    "kapduvas": "kapduva",
    "kapduve": "kapduva",
    "kapduvor": "kapduva",
    "kapduvorna": "kapduva",
    "kapduvornas": "kapduva",
    "kapduvors": "kapduva",
    "kapduvs": "kapduva",
    "kapellen": "kapell",
    "kapellens": "kapell",
    "kapellet": "kapell",
    "kapellets": "kapell",
    "kapellmästar": "kapellmästare",
    "kapellmästaren": "kapellmästare",
    "kapellmästarens": "kapellmästare",
    "kapellmästares": "kapellmästare",
    "kapellmästarna": "kapellmästare",
    "kapellmästarnas": "kapellmästare",
    "kapells": "kapell",
    "kapen": "kap",
    "kapens": "kap",
    "kaperier": "kaperi",
    "kaperierna": "kaperi",
    "kaperiernas": "kaperi",
    "kaperiers": "kaperi",
    "kaperiet": "kaperi",
    "kaperiets": "kaperi",
    "kaperis": "kaperi",
    "kaperit": "kaperi",
    "kaperits": "kaperi",
    "kapet": "kap",
    "kapets": "kap",
    "kapfåren": "kapfår",
    "kapfårens": "kapfår",
    "kapfåret": "kapfår",
    "kapfårets": "kapfår",
    "kapfårs": "kapfår",
    "kapillariteten": "kapillaritet",
    "kapillaritetens": "kapillaritet",
    "kapillariteter": "kapillaritet",
    "kapillariteterna": "kapillaritet",
    "kapillariteternas": "kapillaritet",
    "kapillariteters": "kapillaritet",
    "kapillaritets": "kapillaritet",
    "kapillära": "kapillär",
    "kapillärare": "kapillär",
    "kapillärares": "kapillär",
    "kapilläras": "kapillär",
    "kapillärast": "kapillär",
    "kapilläraste": "kapillär",
    "kapillärastes": "kapillär",
    "kapillärasts": "kapillär",
    "kapilläre": "kapillär",
    "kapillären": "kapillär",
    "kapillärens": "kapillär",
    "kapillärer": "kapillär",
    "kapillärerna": "kapillär",
    "kapillärernas": "kapillär",
    "kapillärers": "kapillär",
    "kapilläres": "kapillär",
    "kapillärkraften": "kapillärkraft",
    "kapillärkraftens": "kapillärkraft",
    "kapillärkrafts": "kapillärkraft",
    "kapillärrören": "kapillärrör",
    "kapillärrörens": "kapillärrör",
    "kapillärröret": "kapillärrör",
    "kapillärrörets": "kapillärrör",
    "kapillärrörs": "kapillärrör",
    "kapillärs": "kapillär",
    "kapillärt": "kapillär",
    "kapillärts": "kapillär",
    "kapitala": "kapital",
    "kapitalare": "kapital",
    "kapitalares": "kapital",
    "kapitalas": "kapital",
    "kapitalast": "kapital",
    "kapitalaste": "kapital",
    "kapitalastes": "kapital",
    "kapitalasts": "kapital",
    "kapitalavkastningar": "kapitalavkastning",
    "kapitalavkastningarna": "kapitalavkastning",
    "kapitalavkastningarnas": "kapitalavkastning",
    "kapitalavkastningars": "kapitalavkastning",
    "kapitalavkastningen": "kapitalavkastning",
    "kapitalavkastningens": "kapitalavkastning",
    "kapitalavkastnings": "kapitalavkastning",
    "kapitalbeskattningar": "kapitalbeskattning",
    "kapitalbeskattningarna": "kapitalbeskattning",
    "kapitalbeskattningarnas": "kapitalbeskattning",
    "kapitalbeskattningars": "kapitalbeskattning",
    "kapitalbeskattningen": "kapitalbeskattning",
    "kapitalbeskattningens": "kapitalbeskattning",
    "kapitalbeskattnings": "kapitalbeskattning",
    "kapitalbildningar": "kapitalbildning",
    "kapitalbildningarna": "kapitalbildning",
    "kapitalbildningarnas": "kapitalbildning",
    "kapitalbildningars": "kapitalbildning",
    "kapitalbildningen": "kapitalbildning",
    "kapitalbildningens": "kapitalbildning",
    "kapitalbildnings": "kapitalbildning",
    "kapitalbudgetar": "kapitalbudget",
    "kapitalbudgetarna": "kapitalbudget",
    "kapitalbudgetarnas": "kapitalbudget",
    "kapitalbudgetars": "kapitalbudget",
    "kapitalbudgeten": "kapitalbudget",
    "kapitalbudgetens": "kapitalbudget",
    "kapitalbudgeter": "kapitalbudget",
    "kapitalbudgeterna": "kapitalbudget",
    "kapitalbudgeternas": "kapitalbudget",
    "kapitalbudgeters": "kapitalbudget",
    "kapitalbudgets": "kapitalbudget",
    "kapitale": "kapital",
    "kapitalen": "kapital",
    "kapitalens": "kapital",
    "kapitales": "kapital",
    "kapitalet": "kapital",
    "kapitalets": "kapital",
    "kapitalexporten": "kapitalexport",
    "kapitalexportens": "kapitalexport",
    "kapitalexports": "kapitalexport",
    "kapitalflykten": "kapitalflykt",
    "kapitalflyktens": "kapitalflykt",
    "kapitalflykts": "kapitalflykt",
    "kapitalförlusten": "kapitalförlust",
    "kapitalförlustens": "kapitalförlust",
    "kapitalförluster": "kapitalförlust",
    "kapitalförlusterna": "kapitalförlust",
    "kapitalförlusternas": "kapitalförlust",
    "kapitalförlusters": "kapitalförlust",
    "kapitalförlusts": "kapitalförlust",
    "kapitalförstöringar": "kapitalförstöring",
    "kapitalförstöringarna": "kapitalförstöring",
    "kapitalförstöringarnas": "kapitalförstöring",
    "kapitalförstöringars": "kapitalförstöring",
    "kapitalförstöringen": "kapitalförstöring",
    "kapitalförstöringens": "kapitalförstöring",
    "kapitalförstörings": "kapitalförstöring",
    "kapitalförsäkringar": "kapitalförsäkring",
    "kapitalförsäkringarna": "kapitalförsäkring",
    "kapitalförsäkringarnas": "kapitalförsäkring",
    "kapitalförsäkringars": "kapitalförsäkring",
    "kapitalförsäkringen": "kapitalförsäkring",
    "kapitalförsäkringens": "kapitalförsäkring",
    "kapitalförsäkrings": "kapitalförsäkring",
    "kapitalinkomstbeskattningar": "kapitalinkomstbeskattning",
    "kapitalinkomstbeskattningarna": "kapitalinkomstbeskattning",
    "kapitalinkomstbeskattningarnas": "kapitalinkomstbeskattning",
    "kapitalinkomstbeskattningars": "kapitalinkomstbeskattning",
    "kapitalinkomstbeskattningen": "kapitalinkomstbeskattning",
    "kapitalinkomstbeskattningens": "kapitalinkomstbeskattning",
    "kapitalinkomstbeskattnings": "kapitalinkomstbeskattning",
    "kapitalinkomsten": "kapitalinkomst",
    "kapitalinkomstens": "kapitalinkomst",
    "kapitalinkomster": "kapitalinkomst",
    "kapitalinkomsterna": "kapitalinkomst",
    "kapitalinkomsternas": "kapitalinkomst",
    "kapitalinkomsters": "kapitalinkomst",
    "kapitalinkomsts": "kapitalinkomst",
    "kapitalintensiva": "kapitalintensiv",
    "kapitalintensivare": "kapitalintensiv",
    "kapitalintensivares": "kapitalintensiv",
    "kapitalintensivas": "kapitalintensiv",
    "kapitalintensivast": "kapitalintensiv",
    "kapitalintensivaste": "kapitalintensiv",
    "kapitalintensivastes": "kapitalintensiv",
    "kapitalintensivasts": "kapitalintensiv",
    "kapitalintensive": "kapitalintensiv",
    "kapitalintensives": "kapitalintensiv",
    "kapitalintensivs": "kapitalintensiv",
    "kapitalintensivt": "kapitalintensiv",
    "kapitalintensivts": "kapitalintensiv",
    "kapitaliserad": "kapitalisera",
    "kapitaliserade": "kapitalisera",
    "kapitaliserades": "kapitalisera",
    "kapitaliserads": "kapitalisera",
    "kapitaliserande": "kapitalisera",
    "kapitaliseranden": "kapitaliserande",
    "kapitaliserandena": "kapitaliserande",
    "kapitaliserandenas": "kapitaliserande",
    "kapitaliserandens": "kapitaliserande",
    "kapitaliserandes": "kapitaliserande",
    "kapitaliserandet": "kapitaliserande",
    "kapitaliserandets": "kapitaliserande",
    "kapitaliserar": "kapitalisera",
    "kapitaliseras": "kapitalisera",
    "kapitaliserat": "kapitalisera",
    "kapitaliserats": "kapitalisera",
    "kapitaliserbara": "kapitaliserbar",
    "kapitaliserbarare": "kapitaliserbar",
    "kapitaliserbarares": "kapitaliserbar",
    "kapitaliserbaras": "kapitaliserbar",
    "kapitaliserbarast": "kapitaliserbar",
    "kapitaliserbaraste": "kapitaliserbar",
    "kapitaliserbarastes": "kapitaliserbar",
    "kapitaliserbarasts": "kapitaliserbar",
    "kapitaliserbare": "kapitaliserbar",
    "kapitaliserbares": "kapitaliserbar",
    "kapitaliserbarheten": "kapitaliserbarhet",
    "kapitaliserbarhetens": "kapitaliserbarhet",
    "kapitaliserbarhets": "kapitaliserbarhet",
    "kapitaliserbars": "kapitaliserbar",
    "kapitaliserbart": "kapitaliserbar",
    "kapitaliserbarts": "kapitaliserbar",
    "kapitaliseringar": "kapitalisering",
    "kapitaliseringarna": "kapitalisering",
    "kapitaliseringarnas": "kapitalisering",
    "kapitaliseringars": "kapitalisering",
    "kapitaliseringen": "kapitalisering",
    "kapitaliseringens": "kapitalisering",
    "kapitaliserings": "kapitalisering",
    "kapitalismen": "kapitalism",
    "kapitalismens": "kapitalism",
    "kapitalismer": "kapitalism",
    "kapitalismerna": "kapitalism",
    "kapitalismernas": "kapitalism",
    "kapitalismers": "kapitalism",
    "kapitalisms": "kapitalism",
    "kapitalisten": "kapitalist",
    "kapitalistens": "kapitalist",
    "kapitalister": "kapitalist",
    "kapitalisterna": "kapitalist",
    "kapitalisternas": "kapitalist",
    "kapitalisters": "kapitalist",
    "kapitalistiska": "kapitalistisk",
    "kapitalistiskare": "kapitalistisk",
    "kapitalistiskares": "kapitalistisk",
    "kapitalistiskas": "kapitalistisk",
    "kapitalistiskast": "kapitalistisk",
    "kapitalistiskaste": "kapitalistisk",
    "kapitalistiskastes": "kapitalistisk",
    "kapitalistiskasts": "kapitalistisk",
    "kapitalistiske": "kapitalistisk",
    "kapitalistiskes": "kapitalistisk",
    "kapitalistisks": "kapitalistisk",
    "kapitalistiskt": "kapitalistisk",
    "kapitalistiskts": "kapitalistisk",
    "kapitalists": "kapitalist",
    "kapitaliststaten": "kapitaliststat",
    "kapitaliststatens": "kapitaliststat",
    "kapitaliststater": "kapitaliststat",
    "kapitaliststaterna": "kapitaliststat",
    "kapitaliststaternas": "kapitaliststat",
    "kapitaliststaters": "kapitaliststat",
    "kapitaliststats": "kapitaliststat",
    "kapitalkonton": "kapitalkonto",
    "kapitalkontona": "kapitalkonto",
    "kapitalkontonas": "kapitalkonto",
    "kapitalkontons": "kapitalkonto",
    "kapitalkontos": "kapitalkonto",
    "kapitalkontot": "kapitalkonto",
    "kapitalkontots": "kapitalkonto",
    "kapitalmarknaden": "kapitalmarknad",
    "kapitalmarknadens": "kapitalmarknad",
    "kapitalmarknader": "kapitalmarknad",
    "kapitalmarknaderna": "kapitalmarknad",
    "kapitalmarknadernas": "kapitalmarknad",
    "kapitalmarknaders": "kapitalmarknad",
    "kapitalmarknads": "kapitalmarknad",
    "kapitalmässiga": "kapitalmässig",
    "kapitalmässigare": "kapitalmässig",
    "kapitalmässigares": "kapitalmässig",
    "kapitalmässigas": "kapitalmässig",
    "kapitalmässigast": "kapitalmässig",
    "kapitalmässigaste": "kapitalmässig",
    "kapitalmässigastes": "kapitalmässig",
    "kapitalmässigasts": "kapitalmässig",
    "kapitalmässige": "kapitalmässig",
    "kapitalmässiges": "kapitalmässig",
    "kapitalmässigs": "kapitalmässig",
    "kapitalmässigt": "kapitalmässig",
    "kapitalmässigts": "kapitalmässig",
    "kapitals": "kapital",
    "kapitalstinna": "kapitalstinn",
    "kapitalstinnare": "kapitalstinn",
    "kapitalstinnares": "kapitalstinn",
    "kapitalstinnas": "kapitalstinn",
    "kapitalstinnast": "kapitalstinn",
    "kapitalstinnaste": "kapitalstinn",
    "kapitalstinnastes": "kapitalstinn",
    "kapitalstinnasts": "kapitalstinn",
    "kapitalstinne": "kapitalstinn",
    "kapitalstinnes": "kapitalstinn",
    "kapitalstinnheten": "kapitalstinnhet",
    "kapitalstinnhetens": "kapitalstinnhet",
    "kapitalstinnhets": "kapitalstinnhet",
    "kapitalstinns": "kapitalstinn",
    "kapitalstint": "kapitalstinn",
    "kapitalstints": "kapitalstinn",
    "kapitalt": "kapital",
    "kapitalts": "kapital",
    "kapitalvar": "kapitalvara",
    "kapitalvaran": "kapitalvara",
    "kapitalvarans": "kapitalvara",
    "kapitalvaras": "kapitalvara",
    "kapitalvare": "kapitalvara",
    "kapitalvaror": "kapitalvara",
    "kapitalvarorna": "kapitalvara",
    "kapitalvarornas": "kapitalvara",
    "kapitalvarors": "kapitalvara",
    "kapitalvars": "kapitalvara",
    "kapitalvinsten": "kapitalvinst",
    "kapitalvinstens": "kapitalvinst",
    "kapitalvinster": "kapitalvinst",
    "kapitalvinsterna": "kapitalvinst",
    "kapitalvinsternas": "kapitalvinst",
    "kapitalvinsters": "kapitalvinst",
    "kapitalvinsts": "kapitalvinst",
    "kapitalvärden": "kapitalvärde",
    "kapitalvärdena": "kapitalvärde",
    "kapitalvärdenas": "kapitalvärde",
    "kapitalvärdens": "kapitalvärde",
    "kapitalvärdes": "kapitalvärde",
    "kapitalvärdet": "kapitalvärde",
    "kapitalvärdets": "kapitalvärde",
    "kapitels": "kapitel",
    "kapitelsalar": "kapitelsal",
    "kapitelsalarna": "kapitelsal",
    "kapitelsalarnas": "kapitelsal",
    "kapitelsalars": "kapitelsal",
    "kapitelsalen": "kapitelsal",
    "kapitelsalens": "kapitelsal",
    "kapitelsals": "kapitelsal",
    "kapitlen": "kapitel",
    "kapitlens": "kapitel",
    "kapitlet": "kapitel",
    "kapitlets": "kapitel",
    "kapitulationen": "kapitulation",
    "kapitulationens": "kapitulation",
    "kapitulationer": "kapitulation",
    "kapitulationerna": "kapitulation",
    "kapitulationernas": "kapitulation",
    "kapitulationers": "kapitulation",
    "kapitulations": "kapitulation",
    "kapitulerade": "kapitulera",
    "kapitulerades": "kapitulera",
    "kapitulerande": "kapitulera",
    "kapituleranden": "kapitulerande",
    "kapitulerandena": "kapitulerande",
    "kapitulerandenas": "kapitulerande",
    "kapitulerandens": "kapitulerande",
    "kapitulerandes": "kapitulerande",
    "kapitulerandet": "kapitulerande",
    "kapitulerandets": "kapitulerande",
    "kapitulerar": "kapitulera",
    "kapituleras": "kapitulera",
    "kapitulerat": "kapitulera",
    "kapitulerats": "kapitulera",
    "kapituleringar": "kapitulering",
    "kapituleringarna": "kapitulering",
    "kapituleringarnas": "kapitulering",
    "kapituleringars": "kapitulering",
    "kapituleringen": "kapitulering",
    "kapituleringens": "kapitulering",
    "kapitulerings": "kapitulering",
    "kapitälen": "kapitäl",
    "kapitälens": "kapitäl",
    "kapitäler": "kapitäl",
    "kapitälerna": "kapitäl",
    "kapitälernas": "kapitäl",
    "kapitälers": "kapitäl",
    "kapitälet": "kapitäl",
    "kapitälets": "kapitäl",
    "kapitäls": "kapitäl",
    "kapkrusbären": "kapkrusbär",
    "kapkrusbärens": "kapkrusbär",
    "kapkrusbäret": "kapkrusbär",
    "kapkrusbärets": "kapkrusbär",
    "kapkrusbärs": "kapkrusbär",
    "kaplanen": "kaplan",
    "kaplanens": "kaplan",
    "kaplaner": "kaplan",
    "kaplanerna": "kaplan",
    "kaplanernas": "kaplan",
    "kaplaners": "kaplan",
    "kaplans": "kaplan",
    "kapmaskinen": "kapmaskin",
    "kapmaskinens": "kapmaskin",
    "kapmaskiner": "kapmaskin",
    "kapmaskinerna": "kapmaskin",
    "kapmaskinernas": "kapmaskin",
    "kapmaskiners": "kapmaskin",
    "kapmaskins": "kapmaskin",
    "kapningar": "kapning",
    "kapningarna": "kapning",
    "kapningarnas": "kapning",
    "kapningars": "kapning",
    "kapningen": "kapning",
    "kapningens": "kapning",
    "kapnings": "kapning",
    "kapningsförsöken": "kapningsförsök",
    "kapningsförsökens": "kapningsförsök",
    "kapningsförsöket": "kapningsförsök",
    "kapningsförsökets": "kapningsförsök",
    "kapningsförsöks": "kapningsförsök",
    "kapocken": "kapock",
    "kapockens": "kapock",
    "kapocks": "kapock",
    "kapotten": "kapott",
    "kapottens": "kapott",
    "kapotter": "kapott",
    "kapotterna": "kapott",
    "kapotternas": "kapott",
    "kapotters": "kapott",
    "kapotts": "kapott",
    "kapp": "kappe",
    "kappades": "kappas",
    "kappan": "kappa",
    "kappana": "kappa",
    "kappanas": "kappa",
    "kappans": "kappa",
    "kappar": "kappe",
    "kapparna": "kappe",
    "kapparnas": "kappe",
    "kappars": "kappe",
    "kappas": "kappa",
    "kappat": "kappa",
    "kappats": "kappas",
    "kappe": "kappa",
    "kappen": "kappe",
    "kappens": "kappe",
    "kappes": "kappe",
    "kapphyll": "kapphylla",
    "kapphyllan": "kapphylla",
    "kapphyllans": "kapphylla",
    "kapphyllas": "kapphylla",
    "kapphylle": "kapphylla",
    "kapphyllor": "kapphylla",
    "kapphyllorna": "kapphylla",
    "kapphyllornas": "kapphylla",
    "kapphyllors": "kapphylla",
    "kapphylls": "kapphylla",
    "kappkörningar": "kappkörning",
    "kappkörningarna": "kappkörning",
    "kappkörningarnas": "kappkörning",
    "kappkörningars": "kappkörning",
    "kappkörningen": "kappkörning",
    "kappkörningens": "kappkörning",
    "kappkörnings": "kappkörning",
    "kapplöpningar": "kapplöpning",
    "kapplöpningarna": "kapplöpning",
    "kapplöpningarnas": "kapplöpning",
    "kapplöpningars": "kapplöpning",
    "kapplöpningen": "kapplöpning",
    "kapplöpningens": "kapplöpning",
    "kapplöpnings": "kapplöpning",
    "kappor": "kappa",
    "kapporna": "kappa",
    "kappornas": "kappa",
    "kappors": "kappa",
    "kappraka": "kapprak",
    "kapprakare": "kapprak",
    "kapprakares": "kapprak",
    "kapprakas": "kapprak",
    "kapprakast": "kapprak",
    "kapprakaste": "kapprak",
    "kapprakastes": "kapprak",
    "kapprakasts": "kapprak",
    "kapprake": "kapprak",
    "kapprakes": "kapprak",
    "kapprakheten": "kapprakhet",
    "kapprakhetens": "kapprakhet",
    "kapprakhets": "kapprakhet",
    "kappraks": "kapprak",
    "kapprakt": "kapprak",
    "kapprakts": "kapprak",
    "kapprockar": "kapprock",
    "kapprockarna": "kapprock",
    "kapprockarnas": "kapprock",
    "kapprockars": "kapprock",
    "kapprocken": "kapprock",
    "kapprockens": "kapprock",
    "kapprocks": "kapprock",
    "kapprummen": "kapprum",
    "kapprummens": "kapprum",
    "kapprummet": "kapprum",
    "kapprummets": "kapprum",
    "kapprums": "kapprum",
    "kapprustade": "kapprusta",
    "kapprustades": "kapprusta",
    "kapprustande": "kapprusta",
    "kapprustanden": "kapprustande",
    "kapprustandena": "kapprustande",
    "kapprustandenas": "kapprustande",
    "kapprustandens": "kapprustande",
    "kapprustandes": "kapprustande",
    "kapprustandet": "kapprustande",
    "kapprustandets": "kapprustande",
    "kapprustar": "kapprusta",
    "kapprustas": "kapprusta",
    "kapprustat": "kapprusta",
    "kapprustats": "kapprusta",
    "kapprustningar": "kapprustning",
    "kapprustningarna": "kapprustning",
    "kapprustningarnas": "kapprustning",
    "kapprustningars": "kapprustning",
    "kapprustningen": "kapprustning",
    "kapprustningens": "kapprustning",
    "kapprustnings": "kapprustning",
    "kapps": "kappe",
    "kappseglade": "kappsegla",
    "kappseglades": "kappsegla",
    "kappseglande": "kappsegla",
    "kappseglanden": "kappseglande",
    "kappseglandena": "kappseglande",
    "kappseglandenas": "kappseglande",
    "kappseglandens": "kappseglande",
    "kappseglandes": "kappseglande",
    "kappseglandet": "kappseglande",
    "kappseglandets": "kappseglande",
    "kappseglar": "kappseglare",
    "kappseglaren": "kappseglare",
    "kappseglarens": "kappseglare",
    "kappseglares": "kappseglare",
    "kappseglarna": "kappseglare",
    "kappseglarnas": "kappseglare",
    "kappseglas": "kappsegla",
    "kappseglat": "kappsegla",
    "kappseglats": "kappsegla",
    "kappseglingar": "kappsegling",
    "kappseglingarna": "kappsegling",
    "kappseglingarnas": "kappsegling",
    "kappseglingars": "kappsegling",
    "kappseglingen": "kappsegling",
    "kappseglingens": "kappsegling",
    "kappseglings": "kappsegling",
    "kappseglingsbåtar": "kappseglingsbåt",
    "kappseglingsbåtarna": "kappseglingsbåt",
    "kappseglingsbåtarnas": "kappseglingsbåt",
    "kappseglingsbåtars": "kappseglingsbåt",
    "kappseglingsbåten": "kappseglingsbåt",
    "kappseglingsbåtens": "kappseglingsbåt",
    "kappseglingsbåts": "kappseglingsbåt",
    "kappsimningar": "kappsimning",
    "kappsimningarna": "kappsimning",
    "kappsimningarnas": "kappsimning",
    "kappsimningars": "kappsimning",
    "kappsimningen": "kappsimning",
    "kappsimningens": "kappsimning",
    "kappsimnings": "kappsimning",
    "kappsäckar": "kappsäck",
    "kappsäckarna": "kappsäck",
    "kappsäckarnas": "kappsäck",
    "kappsäckars": "kappsäck",
    "kappsäcken": "kappsäck",
    "kappsäckens": "kappsäck",
    "kappsäcks": "kappsäck",
    "kapriciösa": "kapriciös",
    "kapriciösare": "kapriciös",
    "kapriciösares": "kapriciös",
    "kapriciösas": "kapriciös",
    "kapriciösast": "kapriciös",
    "kapriciösaste": "kapriciös",
    "kapriciösastes": "kapriciös",
    "kapriciösasts": "kapriciös",
    "kapriciöse": "kapriciös",
    "kapriciöses": "kapriciös",
    "kapriciöst": "kapriciös",
    "kapriciösts": "kapriciös",
    "kaprifolen": "kaprifol",
    "kaprifolens": "kaprifol",
    "kaprifoler": "kaprifol",
    "kaprifolerna": "kaprifol",
    "kaprifolernas": "kaprifol",
    "kaprifolers": "kaprifol",
    "kaprifolien": "kaprifolium",
    "kaprifoliens": "kaprifolium",
    "kaprifolier": "kaprifolium",
    "kaprifolierna": "kaprifolium",
    "kaprifoliernas": "kaprifolium",
    "kaprifoliers": "kaprifolium",
    "kaprifoliums": "kaprifolium",
    "kaprifols": "kaprifol",
    "kapriolen": "kapriol",
    "kapriolens": "kapriol",
    "kaprioler": "kapriol",
    "kapriolerna": "kapriol",
    "kapriolernas": "kapriol",
    "kapriolers": "kapriol",
    "kapriols": "kapriol",
    "kaprisen": "kapris",
    "kaprisens": "kapris",
    "kapriser": "kapris",
    "kapriserna": "kapris",
    "kaprisernas": "kapris",
    "kaprisers": "kapris",
    "kaps": "kap",
    "kapsejs": "kapsejsa",
    "kapsejsad": "kapsejsa",
    "kapsejsade": "kapsejsa",
    "kapsejsades": "kapsejsa",
    "kapsejsads": "kapsejsa",
    "kapsejsande": "kapsejsa",
    "kapsejsanden": "kapsejsande",
    "kapsejsandena": "kapsejsande",
    "kapsejsandenas": "kapsejsande",
    "kapsejsandens": "kapsejsande",
    "kapsejsandes": "kapsejsande",
    "kapsejsandet": "kapsejsande",
    "kapsejsandets": "kapsejsande",
    "kapsejsar": "kapsejsa",
    "kapsejsas": "kapsejsa",
    "kapsejsat": "kapsejsa",
    "kapsejsats": "kapsejsa",
    "kapsel": "kapsla",
    "kapseln": "kapsel",
    "kapselns": "kapsel",
    "kapsels": "kapsel",
    "kapskivan": "kapskiva",
    "kapskivans": "kapskiva",
    "kapskivas": "kapskiva",
    "kapskive": "kapskiva",
    "kapskivor": "kapskiva",
    "kapskivorna": "kapskiva",
    "kapskivornas": "kapskiva",
    "kapskivors": "kapskiva",
    "kapslad": "kapsla",
    "kapslade": "kapsla",
    "kapslades": "kapsla",
    "kapslads": "kapsla",
    "kapslande": "kapsla",
    "kapslanden": "kapslande",
    "kapslandena": "kapslande",
    "kapslandenas": "kapslande",
    "kapslandens": "kapslande",
    "kapslandes": "kapslande",
    "kapslandet": "kapslande",
    "kapslandets": "kapslande",
    "kapslar": "kapsla",
    "kapslarna": "kapsel",
    "kapslarnas": "kapsel",
    "kapslars": "kapsel",
    "kapslas": "kapsla",
    "kapslat": "kapsla",
    "kapslats": "kapsla",
    "kapslingar": "kapsling",
    "kapslingarna": "kapsling",
    "kapslingarnas": "kapsling",
    "kapslingars": "kapsling",
    "kapslingen": "kapsling",
    "kapslingens": "kapsling",
    "kapslings": "kapsling",
    "kapsonen": "kapson",
    "kapsonens": "kapson",
    "kapsoner": "kapson",
    "kapsonerna": "kapson",
    "kapsonernas": "kapson",
    "kapsoners": "kapson",
    "kapsons": "kapson",
    "kapsylen": "kapsyl",
    "kapsylens": "kapsyl",
    "kapsyler": "kapsyl",
    "kapsylerna": "kapsyl",
    "kapsylernas": "kapsyl",
    "kapsylers": "kapsyl",
    "kapsyls": "kapsyl",
    "kapsylöppnar": "kapsylöppnare",
    "kapsylöppnaren": "kapsylöppnare",
    "kapsylöppnarens": "kapsylöppnare",
    "kapsylöppnares": "kapsylöppnare",
    "kapsylöppnarna": "kapsylöppnare",
    "kapsylöppnarnas": "kapsylöppnare",
    "kapsågar": "kapsåg",
    "kapsågarna": "kapsåg",
    "kapsågarnas": "kapsåg",
    "kapsågars": "kapsåg",
    "kapsågen": "kapsåg",
    "kapsågens": "kapsåg",
    "kapsågs": "kapsåg",
    "kaptenen": "kapten",
    "kaptenens": "kapten",
    "kaptener": "kapten",
    "kaptenerna": "kapten",
    "kaptenernas": "kapten",
    "kapteners": "kapten",
    "kaptenlöjtnanten": "kaptenlöjtnant",
    "kaptenlöjtnantens": "kaptenlöjtnant",
    "kaptenlöjtnants": "kaptenlöjtnant",
    "kaptens": "kapten",
    "kapucinap": "kapucinapa",
    "kapucinapan": "kapucinapa",
    "kapucinapans": "kapucinapa",
    "kapucinapas": "kapucinapa",
    "kapucinape": "kapucinapa",
    "kapucinapor": "kapucinapa",
    "kapucinaporna": "kapucinapa",
    "kapucinapornas": "kapucinapa",
    "kapucinapors": "kapucinapa",
    "kapucinaps": "kapucinapa",
    "kapucinen": "kapucin",
    "kapucinens": "kapucin",
    "kapuciner": "kapucin",
    "kapucinerna": "kapucin",
    "kapucinernas": "kapucin",
    "kapucinerordens": "kapucinerorden",
    "kapucinerordnar": "kapucinerorden",
    "kapucinerordnarna": "kapucinerorden",
    "kapucinerordnarnas": "kapucinerorden",
    "kapucinerordnars": "kapucinerorden",
    "kapucinerordnen": "kapucinerorden",
    "kapucinerordnens": "kapucinerorden",
    "kapuciners": "kapucin",
    "kapucinordens": "kapucinorden",
    "kapucinordnar": "kapucinorden",
    "kapucinordnarna": "kapucinorden",
    "kapucinordnarnas": "kapucinorden",
    "kapucinordnars": "kapucinorden",
    "kapucinordnen": "kapucinorden",
    "kapucinordnens": "kapucinorden",
    "kapucins": "kapucin",
    "kapunen": "kapun",
    "kapunens": "kapun",
    "kapuner": "kapun",
    "kapunerna": "kapun",
    "kapunernas": "kapun",
    "kapuners": "kapun",
    "kapuns": "kapun",
    "kapuschongen": "kapuschong",
    "kapuschongens": "kapuschong",
    "kapuschonger": "kapuschong",
    "kapuschongerna": "kapuschong",
    "kapuschongernas": "kapuschong",
    "kapuschongers": "kapuschong",
    "kapuschongs": "kapuschong",
    "kapverdiern": "kapverdier",
    "kapverdierna": "kapverdier",
    "kapverdiernas": "kapverdier",
    "kapverdierns": "kapverdier",
    "kapverdiers": "kapverdier",
    "kapverdiska": "kapverdisk",
    "kapverdiskan": "kapverdiska",
    "kapverdiskans": "kapverdiska",
    "kapverdiskare": "kapverdisk",
    "kapverdiskares": "kapverdisk",
    "kapverdiskas": "kapverdiska",
    "kapverdiskast": "kapverdisk",
    "kapverdiskaste": "kapverdisk",
    "kapverdiskastes": "kapverdisk",
    "kapverdiskasts": "kapverdisk",
    "kapverdiske": "kapverdiska",
    "kapverdiskes": "kapverdisk",
    "kapverdiskor": "kapverdiska",
    "kapverdiskorna": "kapverdiska",
    "kapverdiskornas": "kapverdiska",
    "kapverdiskors": "kapverdiska",
    "kapverdisks": "kapverdisk",
    "kapverdiskt": "kapverdisk",
    "kapverdiskts": "kapverdisk",
    "kapybaran": "kapybara",
    "kapybarans": "kapybara",
    "kapybaras": "kapybara",
    "kapybaren": "kapybar",
    "kapybarens": "kapybar",
    "kapybarer": "kapybar",
    "kapybarerna": "kapybar",
    "kapybarernas": "kapybar",
    "kapybarers": "kapybar",
    "kapybaror": "kapybara",
    "kapybarorna": "kapybara",
    "kapybarornas": "kapybara",
    "kapybarors": "kapybara",
    "kapybars": "kapybar",
    "kar": "kara",
    "karabinjären": "karabinjär",
    "karabinjärens": "karabinjär",
    "karabinjärer": "karabinjär",
    "karabinjärerna": "karabinjär",
    "karabinjärernas": "karabinjär",
    "karabinjärers": "karabinjär",
    "karabinjärs": "karabinjär",
    "karad": "kara",
    "karade": "kara",
    "karades": "kara",
    "karads": "kara",
    "karaffen": "karaff",
    "karaffens": "karaff",
    "karaffer": "karaff",
    "karafferna": "karaff",
    "karaffernas": "karaff",
    "karaffers": "karaff",
    "karaffinen": "karaffin",
    "karaffinens": "karaffin",
    "karaffiner": "karaffin",
    "karaffinerna": "karaffin",
    "karaffinernas": "karaffin",
    "karaffiners": "karaffin",
    "karaffins": "karaffin",
    "karaffs": "karaff",
    "karakoleringar": "karakolering",
    "karakoleringarna": "karakolering",
    "karakoleringarnas": "karakolering",
    "karakoleringars": "karakolering",
    "karakoleringen": "karakolering",
    "karakoleringens": "karakolering",
    "karakolerings": "karakolering",
    "karakteriserad": "karakterisera",
    "karakteriserade": "karakterisera",
    "karakteriserades": "karakterisera",
    "karakteriserads": "karakterisera",
    "karakteriserande": "karakterisera",
    "karakteriseranden": "karakteriserande",
    "karakteriserandena": "karakteriserande",
    "karakteriserandenas": "karakteriserande",
    "karakteriserandens": "karakteriserande",
    "karakteriserandes": "karakteriserande",
    "karakteriserandet": "karakteriserande",
    "karakteriserandets": "karakteriserande",
    "karakteriserar": "karakterisera",
    "karakteriseras": "karakterisera",
    "karakteriserat": "karakterisera",
    "karakteriserats": "karakterisera",
    "karakteriserbara": "karakteriserbar",
    "karakteriserbarare": "karakteriserbar",
    "karakteriserbarares": "karakteriserbar",
    "karakteriserbaras": "karakteriserbar",
    "karakteriserbarast": "karakteriserbar",
    "karakteriserbaraste": "karakteriserbar",
    "karakteriserbarastes": "karakteriserbar",
    "karakteriserbarasts": "karakteriserbar",
    "karakteriserbare": "karakteriserbar",
    "karakteriserbares": "karakteriserbar",
    "karakteriserbarheten": "karakteriserbarhet",
    "karakteriserbarhetens": "karakteriserbarhet",
    "karakteriserbarhets": "karakteriserbarhet",
    "karakteriserbars": "karakteriserbar",
    "karakteriserbart": "karakteriserbar",
    "karakteriserbarts": "karakteriserbar",
    "karakteriseringar": "karakterisering",
    "karakteriseringarna": "karakterisering",
    "karakteriseringarnas": "karakterisering",
    "karakteriseringars": "karakterisering",
    "karakteriseringen": "karakterisering",
    "karakteriseringens": "karakterisering",
    "karakteriserings": "karakterisering",
    "karakteristik": "karakteristika",
    "karakteristikan": "karakteristika",
    "karakteristikana": "karakteristika",
    "karakteristikanas": "karakteristika",
    "karakteristikans": "karakteristika",
    "karakteristikas": "karakteristika",
    "karakteristikat": "karakteristika",
    "karakteristikats": "karakteristika",
    "karakteristike": "karakteristika",
    "karakteristiken": "karakteristik",
    "karakteristikens": "karakteristik",
    "karakteristiker": "karakteristik",
    "karakteristikerna": "karakteristik",
    "karakteristikernas": "karakteristik",
    "karakteristikers": "karakteristik",
    "karakteristikor": "karakteristika",
    "karakteristikorna": "karakteristika",
    "karakteristikornas": "karakteristika",
    "karakteristikors": "karakteristika",
    "karakteristiks": "karakteristika",
    "karakteristiska": "karakteristisk",
    "karakteristiskare": "karakteristisk",
    "karakteristiskares": "karakteristisk",
    "karakteristiskas": "karakteristisk",
    "karakteristiskast": "karakteristisk",
    "karakteristiskaste": "karakteristisk",
    "karakteristiskastes": "karakteristisk",
    "karakteristiskasts": "karakteristisk",
    "karakteristiske": "karakteristisk",
    "karakteristiskes": "karakteristisk",
    "karakteristisks": "karakteristisk",
    "karakteristiskt": "karakteristisk",
    "karakteristiskts": "karakteristisk",
    "karakterologien": "karakterologi",
    "karakterologiens": "karakterologi",
    "karakterologin": "karakterologi",
    "karakterologins": "karakterologi",
    "karakterologis": "karakterologi",
    "karaktären": "karaktär",
    "karaktärens": "karaktär",
    "karaktärer": "karaktär",
    "karaktärerna": "karaktär",
    "karaktärernas": "karaktär",
    "karaktärers": "karaktär",
    "karaktäriserad": "karaktärisera",
    "karaktäriserade": "karaktärisera",
    "karaktäriserades": "karaktärisera",
    "karaktäriserads": "karaktärisera",
    "karaktäriserande": "karaktärisera",
    "karaktäriseranden": "karaktäriserande",
    "karaktäriserandena": "karaktäriserande",
    "karaktäriserandenas": "karaktäriserande",
    "karaktäriserandens": "karaktäriserande",
    "karaktäriserandes": "karaktäriserande",
    "karaktäriserandet": "karaktäriserande",
    "karaktäriserandets": "karaktäriserande",
    "karaktäriserar": "karaktärisera",
    "karaktäriseras": "karaktärisera",
    "karaktäriserat": "karaktärisera",
    "karaktäriserats": "karaktärisera",
    "karaktäriserbara": "karaktäriserbar",
    "karaktäriserbarare": "karaktäriserbar",
    "karaktäriserbarares": "karaktäriserbar",
    "karaktäriserbaras": "karaktäriserbar",
    "karaktäriserbarast": "karaktäriserbar",
    "karaktäriserbaraste": "karaktäriserbar",
    "karaktäriserbarastes": "karaktäriserbar",
    "karaktäriserbarasts": "karaktäriserbar",
    "karaktäriserbare": "karaktäriserbar",
    "karaktäriserbares": "karaktäriserbar",
    "karaktäriserbarheten": "karaktäriserbarhet",
    "karaktäriserbarhetens": "karaktäriserbarhet",
    "karaktäriserbarhets": "karaktäriserbarhet",
    "karaktäriserbars": "karaktäriserbar",
    "karaktäriserbart": "karaktäriserbar",
    "karaktäriserbarts": "karaktäriserbar",
    "karaktäriseringar": "karaktärisering",
    "karaktäriseringarna": "karaktärisering",
    "karaktäriseringarnas": "karaktärisering",
    "karaktäriseringars": "karaktärisering",
    "karaktäriseringen": "karaktärisering",
    "karaktäriseringens": "karaktärisering",
    "karaktäriserings": "karaktärisering",
    "karaktäristik": "karaktäristika",
    "karaktäristikan": "karaktäristika",
    "karaktäristikana": "karaktäristika",
    "karaktäristikanas": "karaktäristika",
    "karaktäristikans": "karaktäristika",
    "karaktäristikas": "karaktäristika",
    "karaktäristikat": "karaktäristika",
    "karaktäristikats": "karaktäristika",
    "karaktäristike": "karaktäristika",
    "karaktäristiken": "karaktäristik",
    "karaktäristikens": "karaktäristik",
    "karaktäristiker": "karaktäristik",
    "karaktäristikerna": "karaktäristik",
    "karaktäristikernas": "karaktäristik",
    "karaktäristikers": "karaktäristik",
    "karaktäristikor": "karaktäristika",
    "karaktäristikorna": "karaktäristika",
    "karaktäristikornas": "karaktäristika",
    "karaktäristikors": "karaktäristika",
    "karaktäristiks": "karaktäristika",
    "karaktäristiska": "karaktäristisk",
    "karaktäristiskare": "karaktäristisk",
    "karaktäristiskares": "karaktäristisk",
    "karaktäristiskas": "karaktäristisk",
    "karaktäristiskast": "karaktäristisk",
    "karaktäristiskaste": "karaktäristisk",
    "karaktäristiskastes": "karaktäristisk",
    "karaktäristiskasts": "karaktäristisk",
    "karaktäristiske": "karaktäristisk",
    "karaktäristiskes": "karaktäristisk",
    "karaktäristisks": "karaktäristisk",
    "karaktäristiskt": "karaktäristisk",
    "karaktäristiskts": "karaktäristisk",
    "karaktärologien": "karaktärologi",
    "karaktärologiens": "karaktärologi",
    "karaktärologin": "karaktärologi",
    "karaktärologins": "karaktärologi",
    "karaktärologis": "karaktärologi",
    "karaktärs": "karaktär",
    "karaktärsarten": "karaktärsart",
    "karaktärsartens": "karaktärsart",
    "karaktärsarter": "karaktärsart",
    "karaktärsarterna": "karaktärsart",
    "karaktärsarternas": "karaktärsart",
    "karaktärsarters": "karaktärsart",
    "karaktärsarts": "karaktärsart",
    "karaktärsdragen": "karaktärsdrag",
    "karaktärsdragens": "karaktärsdrag",
    "karaktärsdraget": "karaktärsdrag",
    "karaktärsdragets": "karaktärsdrag",
    "karaktärsdrags": "karaktärsdrag",
    "karaktärsdraman": "karaktärsdrama",
    "karaktärsdramana": "karaktärsdrama",
    "karaktärsdramanas": "karaktärsdrama",
    "karaktärsdramans": "karaktärsdrama",
    "karaktärsdramas": "karaktärsdrama",
    "karaktärsdramat": "karaktärsdrama",
    "karaktärsdramats": "karaktärsdrama",
    "karaktärsdramer": "karaktärsdrama",
    "karaktärsdramerna": "karaktärsdrama",
    "karaktärsdramernas": "karaktärsdrama",
    "karaktärsdramers": "karaktärsdrama",
    "karaktärsfasta": "karaktärsfast",
    "karaktärsfastare": "karaktärsfast",
    "karaktärsfastares": "karaktärsfast",
    "karaktärsfastas": "karaktärsfast",
    "karaktärsfastast": "karaktärsfast",
    "karaktärsfastaste": "karaktärsfast",
    "karaktärsfastastes": "karaktärsfast",
    "karaktärsfastasts": "karaktärsfast",
    "karaktärsfaste": "karaktärsfast",
    "karaktärsfastes": "karaktärsfast",
    "karaktärsfastheten": "karaktärsfasthet",
    "karaktärsfasthetens": "karaktärsfasthet",
    "karaktärsfasthets": "karaktärsfasthet",
    "karaktärsfasts": "karaktärsfast",
    "karaktärsfelen": "karaktärsfel",
    "karaktärsfelens": "karaktärsfel",
    "karaktärsfelet": "karaktärsfel",
    "karaktärsfelets": "karaktärsfel",
    "karaktärsfels": "karaktärsfel",
    "karaktärsmorden": "karaktärsmord",
    "karaktärsmordens": "karaktärsmord",
    "karaktärsmordet": "karaktärsmord",
    "karaktärsmordets": "karaktärsmord",
    "karaktärsmords": "karaktärsmord",
    "karaktärsmässiga": "karaktärsmässig",
    "karaktärsmässigare": "karaktärsmässig",
    "karaktärsmässigares": "karaktärsmässig",
    "karaktärsmässigas": "karaktärsmässig",
    "karaktärsmässigast": "karaktärsmässig",
    "karaktärsmässigaste": "karaktärsmässig",
    "karaktärsmässigastes": "karaktärsmässig",
    "karaktärsmässigasts": "karaktärsmässig",
    "karaktärsmässige": "karaktärsmässig",
    "karaktärsmässiges": "karaktärsmässig",
    "karaktärsmässigs": "karaktärsmässig",
    "karaktärsmässigt": "karaktärsmässig",
    "karaktärsmässigts": "karaktärsmässig",
    "karaktärsrollen": "karaktärsroll",
    "karaktärsrollens": "karaktärsroll",
    "karaktärsroller": "karaktärsroll",
    "karaktärsrollerna": "karaktärsroll",
    "karaktärsrollernas": "karaktärsroll",
    "karaktärsrollers": "karaktärsroll",
    "karaktärsrolls": "karaktärsroll",
    "karaktärsskådespelar": "karaktärsskådespelare",
    "karaktärsskådespelaren": "karaktärsskådespelare",
    "karaktärsskådespelarens": "karaktärsskådespelare",
    "karaktärsskådespelares": "karaktärsskådespelare",
    "karaktärsskådespelarna": "karaktärsskådespelare",
    "karaktärsskådespelarnas": "karaktärsskådespelare",
    "karaktärstypen": "karaktärstyp",
    "karaktärstypens": "karaktärstyp",
    "karaktärstyper": "karaktärstyp",
    "karaktärstyperna": "karaktärstyp",
    "karaktärstypernas": "karaktärstyp",
    "karaktärstypers": "karaktärstyp",
    "karaktärstyps": "karaktärstyp",
    "karaktärsvittnen": "karaktärsvittne",
    "karaktärsvittnena": "karaktärsvittne",
    "karaktärsvittnenas": "karaktärsvittne",
    "karaktärsvittnens": "karaktärsvittne",
    "karaktärsvittnes": "karaktärsvittne",
    "karaktärsvittnet": "karaktärsvittne",
    "karaktärsvittnets": "karaktärsvittne",
    "karambolages": "karambolage",
    "karambolaget": "karambolage",
    "karambolagets": "karambolage",
    "karambolerad": "karambolera",
    "karambolerade": "karambolera",
    "karambolerades": "karambolera",
    "karambolerads": "karambolera",
    "karambolerande": "karambolera",
    "karamboleranden": "karambolerande",
    "karambolerandena": "karambolerande",
    "karambolerandenas": "karambolerande",
    "karambolerandens": "karambolerande",
    "karambolerandes": "karambolerande",
    "karambolerandet": "karambolerande",
    "karambolerandets": "karambolerande",
    "karambolerar": "karambolera",
    "karamboleras": "karambolera",
    "karambolerat": "karambolera",
    "karambolerats": "karambolera",
    "karambolerbara": "karambolerbar",
    "karambolerbarare": "karambolerbar",
    "karambolerbarares": "karambolerbar",
    "karambolerbaras": "karambolerbar",
    "karambolerbarast": "karambolerbar",
    "karambolerbaraste": "karambolerbar",
    "karambolerbarastes": "karambolerbar",
    "karambolerbarasts": "karambolerbar",
    "karambolerbare": "karambolerbar",
    "karambolerbares": "karambolerbar",
    "karambolerbarheten": "karambolerbarhet",
    "karambolerbarhetens": "karambolerbarhet",
    "karambolerbarhets": "karambolerbarhet",
    "karambolerbars": "karambolerbar",
    "karambolerbart": "karambolerbar",
    "karambolerbarts": "karambolerbar",
    "karamboleringar": "karambolering",
    "karamboleringarna": "karambolering",
    "karamboleringarnas": "karambolering",
    "karamboleringars": "karambolering",
    "karamboleringen": "karambolering",
    "karamboleringens": "karambolering",
    "karambolerings": "karambolering",
    "karambollen": "karamboll",
    "karambollens": "karamboll",
    "karambolls": "karamboll",
    "karamellen": "karamell",
    "karamellens": "karamell",
    "karameller": "karamell",
    "karamellerna": "karamell",
    "karamellernas": "karamell",
    "karamellers": "karamell",
    "karamellfabriken": "karamellfabrik",
    "karamellfabrikens": "karamellfabrik",
    "karamellfabriker": "karamellfabrik",
    "karamellfabrikerna": "karamellfabrik",
    "karamellfabrikernas": "karamellfabrik",
    "karamellfabrikers": "karamellfabrik",
    "karamellfabriks": "karamellfabrik",
    "karamellfärgade": "karamellfärgad",
    "karamellfärgades": "karamellfärgad",
    "karamellfärgads": "karamellfärgad",
    "karamellfärgat": "karamellfärgad",
    "karamellfärgats": "karamellfärgad",
    "karamellfärgen": "karamellfärg",
    "karamellfärgens": "karamellfärg",
    "karamellfärger": "karamellfärg",
    "karamellfärgerna": "karamellfärg",
    "karamellfärgernas": "karamellfärg",
    "karamellfärgers": "karamellfärg",
    "karamellfärgs": "karamellfärg",
    "karamellpapperen": "karamellpapper",
    "karamellpapperens": "karamellpapper",
    "karamellpapperet": "karamellpapper",
    "karamellpapperets": "karamellpapper",
    "karamellpapperna": "karamellpapper",
    "karamellpappernas": "karamellpapper",
    "karamellpappers": "karamellpapper",
    "karamellpappren": "karamellpapper",
    "karamellpapprens": "karamellpapper",
    "karamellpappret": "karamellpapper",
    "karamellpapprets": "karamellpapper",
    "karamellpuddingar": "karamellpudding",
    "karamellpuddingarna": "karamellpudding",
    "karamellpuddingarnas": "karamellpudding",
    "karamellpuddingars": "karamellpudding",
    "karamellpuddingen": "karamellpudding",
    "karamellpuddingens": "karamellpudding",
    "karamellpuddings": "karamellpudding",
    "karamells": "karamell",
    "karamellsåsen": "karamellsås",
    "karamellsåsens": "karamellsås",
    "karamellsåser": "karamellsås",
    "karamellsåserna": "karamellsås",
    "karamellsåsernas": "karamellsås",
    "karamellsåsers": "karamellsås",
    "karan": "kara",
    "karande": "kara",
    "karanden": "karande",
    "karandena": "karande",
    "karandenas": "karande",
    "karandens": "karande",
    "karandes": "karande",
    "karandet": "karande",
    "karandets": "karande",
    "karans": "kara",
    "karantänen": "karantän",
    "karantänens": "karantän",
    "karantäner": "karantän",
    "karantänerna": "karantän",
    "karantänernas": "karantän",
    "karantäners": "karantän",
    "karantäns": "karantän",
    "karantänsflaggen": "karantänsflagg",
    "karantänsflaggens": "karantänsflagg",
    "karantänsflaggs": "karantänsflagg",
    "karaoken": "karaoke",
    "karaokens": "karaoke",
    "karaokes": "karaoke",
    "karar": "kara",
    "karas": "kara",
    "karat": "kara",
    "karaten": "karate",
    "karatens": "karate",
    "karaterade": "karaterad",
    "karaterades": "karaterad",
    "karaterads": "karaterad",
    "karaterat": "karaterad",
    "karaterats": "karaterad",
    "karateringar": "karatering",
    "karateringarna": "karatering",
    "karateringarnas": "karatering",
    "karateringars": "karatering",
    "karateringen": "karatering",
    "karateringens": "karatering",
    "karaterings": "karatering",
    "karates": "karate",
    "karatesparkar": "karatespark",
    "karatesparkarna": "karatespark",
    "karatesparkarnas": "karatespark",
    "karatesparkars": "karatespark",
    "karatesparken": "karatespark",
    "karatesparkens": "karatespark",
    "karatesparks": "karatespark",
    "karatet": "karat",
    "karatetekniska": "karateteknisk",
    "karatetekniskas": "karateteknisk",
    "karatetekniske": "karateteknisk",
    "karatetekniskes": "karateteknisk",
    "karateteknisks": "karateteknisk",
    "karatetekniskt": "karateteknisk",
    "karatetekniskts": "karateteknisk",
    "karatets": "karat",
    "karats": "karat",
    "karatstämpeln": "karatstämpel",
    "karatstämpelns": "karatstämpel",
    "karatstämpels": "karatstämpel",
    "karatstämplar": "karatstämpel",
    "karatstämplarna": "karatstämpel",
    "karatstämplarnas": "karatstämpel",
    "karatstämplars": "karatstämpel",
    "karavanen": "karavan",
    "karavanens": "karavan",
    "karavaner": "karavan",
    "karavanerna": "karavan",
    "karavanernas": "karavan",
    "karavaners": "karavan",
    "karavans": "karavan",
    "karavanserajen": "karavanseraj",
    "karavanserajens": "karavanseraj",
    "karavanserajer": "karavanseraj",
    "karavanserajerna": "karavanseraj",
    "karavanserajernas": "karavanseraj",
    "karavanserajers": "karavanseraj",
    "karavanserajs": "karavanseraj",
    "karavellen": "karavell",
    "karavellens": "karavell",
    "karaveller": "karavell",
    "karavellerna": "karavell",
    "karavellernas": "karavell",
    "karavellers": "karavell",
    "karavells": "karavell",
    "karbaden": "karbad",
    "karbadens": "karbad",
    "karbadet": "karbad",
    "karbadets": "karbad",
    "karbads": "karbad",
    "karbamiden": "karbamid",
    "karbamidens": "karbamid",
    "karbamider": "karbamid",
    "karbamiderna": "karbamid",
    "karbamidernas": "karbamid",
    "karbamiders": "karbamid",
    "karbamids": "karbamid",
    "karbasen": "karbas",
    "karbasens": "karbas",
    "karbaser": "karbas",
    "karbaserna": "karbas",
    "karbasernas": "karbas",
    "karbasers": "karbas",
    "karbiden": "karbid",
    "karbidens": "karbid",
    "karbider": "karbid",
    "karbiderna": "karbid",
    "karbidernas": "karbid",
    "karbiders": "karbid",
    "karbidlamp": "karbidlampa",
    "karbidlampan": "karbidlampa",
    "karbidlampans": "karbidlampa",
    "karbidlampas": "karbidlampa",
    "karbidlampe": "karbidlampa",
    "karbidlampor": "karbidlampa",
    "karbidlamporna": "karbidlampa",
    "karbidlampornas": "karbidlampa",
    "karbidlampors": "karbidlampa",
    "karbidlamps": "karbidlampa",
    "karbids": "karbid",
    "karbinen": "karbin",
    "karbinens": "karbin",
    "karbiner": "karbin",
    "karbinerna": "karbin",
    "karbinernas": "karbin",
    "karbiners": "karbin",
    "karbinhakar": "karbinhake",
    "karbinhakarna": "karbinhake",
    "karbinhakarnas": "karbinhake",
    "karbinhakars": "karbinhake",
    "karbinhaken": "karbinhake",
    "karbinhakens": "karbinhake",
    "karbinhakes": "karbinhake",
    "karbins": "karbin",
    "karbolen": "karbol",
    "karbolens": "karbol",
    "karbols": "karbol",
    "karbolsyran": "karbolsyra",
    "karbolsyrans": "karbolsyra",
    "karbolsyras": "karbolsyra",
    "karbolsyre": "karbolsyra",
    "karbolsyror": "karbolsyra",
    "karbolsyrorna": "karbolsyra",
    "karbolsyrornas": "karbolsyra",
    "karbolsyrors": "karbolsyra",
    "karbonaten": "karbonat",
    "karbonatens": "karbonat",
    "karbonater": "karbonat",
    "karbonaterna": "karbonat",
    "karbonaternas": "karbonat",
    "karbonaters": "karbonat",
    "karbonatet": "karbonat",
    "karbonatets": "karbonat",
    "karbonatjonen": "karbonatjon",
    "karbonatjonens": "karbonatjon",
    "karbonatjoner": "karbonatjon",
    "karbonatjonerna": "karbonatjon",
    "karbonatjonernas": "karbonatjon",
    "karbonatjoners": "karbonatjon",
    "karbonatjons": "karbonatjon",
    "karbonats": "karbonat",
    "karbonatsmältecellen": "karbonatsmältecell",
    "karbonatsmältecellens": "karbonatsmältecell",
    "karbonatsmälteceller": "karbonatsmältecell",
    "karbonatsmältecellerna": "karbonatsmältecell",
    "karbonatsmältecellernas": "karbonatsmältecell",
    "karbonatsmältecellers": "karbonatsmältecell",
    "karbonatsmältecells": "karbonatsmältecell",
    "karbonen": "karbon",
    "karbonens": "karbon",
    "karboniserad": "karbonisera",
    "karboniserade": "karbonisera",
    "karboniserades": "karbonisera",
    "karboniserads": "karbonisera",
    "karboniserande": "karbonisera",
    "karboniseranden": "karboniserande",
    "karboniserandena": "karboniserande",
    "karboniserandenas": "karboniserande",
    "karboniserandens": "karboniserande",
    "karboniserandes": "karboniserande",
    "karboniserandet": "karboniserande",
    "karboniserandets": "karboniserande",
    "karboniserar": "karbonisera",
    "karboniseras": "karbonisera",
    "karboniserat": "karbonisera",
    "karboniserats": "karbonisera",
    "karboniserbara": "karboniserbar",
    "karboniserbarare": "karboniserbar",
    "karboniserbarares": "karboniserbar",
    "karboniserbaras": "karboniserbar",
    "karboniserbarast": "karboniserbar",
    "karboniserbaraste": "karboniserbar",
    "karboniserbarastes": "karboniserbar",
    "karboniserbarasts": "karboniserbar",
    "karboniserbare": "karboniserbar",
    "karboniserbares": "karboniserbar",
    "karboniserbarheten": "karboniserbarhet",
    "karboniserbarhetens": "karboniserbarhet",
    "karboniserbarhets": "karboniserbarhet",
    "karboniserbars": "karboniserbar",
    "karboniserbart": "karboniserbar",
    "karboniserbarts": "karboniserbar",
    "karboniseringen": "karbonisering",
    "karboniseringens": "karbonisering",
    "karboniserings": "karbonisering",
    "karbonkopian": "karbonkopia",
    "karbonkopians": "karbonkopia",
    "karbonkopias": "karbonkopia",
    "karbonkopie": "karbonkopia",
    "karbonkopior": "karbonkopia",
    "karbonkopiorna": "karbonkopia",
    "karbonkopiornas": "karbonkopia",
    "karbonkopiors": "karbonkopia",
    "karbonpapperen": "karbonpapper",
    "karbonpapperens": "karbonpapper",
    "karbonpapperet": "karbonpapper",
    "karbonpapperets": "karbonpapper",
    "karbonpapperna": "karbonpapper",
    "karbonpappernas": "karbonpapper",
    "karbonpappers": "karbonpapper",
    "karbonpappren": "karbonpapper",
    "karbonpapprens": "karbonpapper",
    "karbonpappret": "karbonpapper",
    "karbonpapprets": "karbonpapper",
    "karbons": "karbon",
    "karbonsyran": "karbonsyra",
    "karbonsyrans": "karbonsyra",
    "karbonsyras": "karbonsyra",
    "karbonsyre": "karbonsyra",
    "karbonsystemet": "karbonsystem",
    "karbonsystemets": "karbonsystem",
    "karbonsystems": "karbonsystem",
    "karborundumdukar": "karborundumduk",
    "karborundumdukarna": "karborundumduk",
    "karborundumdukarnas": "karborundumduk",
    "karborundumdukars": "karborundumduk",
    "karborundumduken": "karborundumduk",
    "karborundumdukens": "karborundumduk",
    "karborundumduks": "karborundumduk",
    "karborundumet": "karborundum",
    "karborundumets": "karborundum",
    "karborundums": "karborundum",
    "karboxylsyran": "karboxylsyra",
    "karboxylsyrans": "karboxylsyra",
    "karboxylsyras": "karboxylsyra",
    "karboxylsyre": "karboxylsyra",
    "karbunkeln": "karbunkel",
    "karbunkelns": "karbunkel",
    "karbunkels": "karbunkel",
    "karbunklar": "karbunkel",
    "karbunklarna": "karbunkel",
    "karbunklarnas": "karbunkel",
    "karbunklars": "karbunkel",
    "karburatorer": "karburator",
    "karburatorerna": "karburator",
    "karburatorernas": "karburator",
    "karburatorers": "karburator",
    "karburatorn": "karburator",
    "karburatorns": "karburator",
    "karburators": "karburator",
    "karburatorspriten": "karburatorsprit",
    "karburatorspritens": "karburatorsprit",
    "karburatorsprits": "karburatorsprit",
    "karcinogena": "karcinogen",
    "karcinogenare": "karcinogen",
    "karcinogenares": "karcinogen",
    "karcinogenas": "karcinogen",
    "karcinogenast": "karcinogen",
    "karcinogenaste": "karcinogen",
    "karcinogenastes": "karcinogen",
    "karcinogenasts": "karcinogen",
    "karcinogene": "karcinogen",
    "karcinogenes": "karcinogen",
    "karcinogens": "karcinogen",
    "karcinogent": "karcinogen",
    "karcinogents": "karcinogen",
    "karcinomen": "karcinom",
    "karcinomens": "karcinom",
    "karcinomet": "karcinom",
    "karcinomets": "karcinom",
    "karcinoms": "karcinom",
    "kard": "karda",
    "kardad": "karda",
    "kardade": "karda",
    "kardades": "karda",
    "kardads": "karda",
    "kardan": "karda",
    "kardanaxeln": "kardanaxel",
    "kardanaxelns": "kardanaxel",
    "kardanaxels": "kardanaxel",
    "kardanaxlar": "kardanaxel",
    "kardanaxlarna": "kardanaxel",
    "kardanaxlarnas": "kardanaxel",
    "kardanaxlars": "kardanaxel",
    "kardande": "karda",
    "kardanden": "kardande",
    "kardandena": "kardande",
    "kardandenas": "kardande",
    "kardandens": "kardande",
    "kardandes": "kardande",
    "kardandet": "kardande",
    "kardandets": "kardande",
    "kardanen": "kardan",
    "kardanens": "kardan",
    "kardaner": "kardan",
    "kardanerna": "kardan",
    "kardanernas": "kardan",
    "kardaners": "kardan",
    "kardanknutar": "kardanknut",
    "kardanknutarna": "kardanknut",
    "kardanknutarnas": "kardanknut",
    "kardanknutars": "kardanknut",
    "kardanknuten": "kardanknut",
    "kardanknutens": "kardanknut",
    "kardanknuts": "kardanknut",
    "kardans": "kardan",
    "kardanska": "kardansk",
    "kardanskare": "kardansk",
    "kardanskares": "kardansk",
    "kardanskas": "kardansk",
    "kardanskast": "kardansk",
    "kardanskaste": "kardansk",
    "kardanskastes": "kardansk",
    "kardanskasts": "kardansk",
    "kardanske": "kardansk",
    "kardanskes": "kardansk",
    "kardansks": "kardansk",
    "kardanskt": "kardansk",
    "kardanskts": "kardansk",
    "kardanupphängningar": "kardanupphängning",
    "kardanupphängningarna": "kardanupphängning",
    "kardanupphängningarnas": "kardanupphängning",
    "kardanupphängningars": "kardanupphängning",
    "kardanupphängningen": "kardanupphängning",
    "kardanupphängningens": "kardanupphängning",
    "kardanupphängnings": "kardanupphängning",
    "kardar": "karda",
    "kardas": "karda",
    "kardat": "karda",
    "kardats": "karda",
    "kardborr": "kardborre",
    "kardborrar": "kardborre",
    "kardborrarna": "kardborre",
    "kardborrarnas": "kardborre",
    "kardborrars": "kardborre",
    "kardborrbanden": "kardborrband",
    "kardborrbandens": "kardborrband",
    "kardborrbandet": "kardborrband",
    "kardborrbandets": "kardborrband",
    "kardborrbands": "kardborrband",
    "kardborrebanden": "kardborreband",
    "kardborrebandens": "kardborreband",
    "kardborrebandet": "kardborreband",
    "kardborrebandets": "kardborreband",
    "kardborrebands": "kardborreband",
    "kardborreknäppningar": "kardborreknäppning",
    "kardborreknäppningarna": "kardborreknäppning",
    "kardborreknäppningarnas": "kardborreknäppning",
    "kardborreknäppningars": "kardborreknäppning",
    "kardborreknäppningen": "kardborreknäppning",
    "kardborreknäppningens": "kardborreknäppning",
    "kardborreknäppnings": "kardborreknäppning",
    "kardborren": "kardborre",
    "kardborrens": "kardborre",
    "kardborres": "kardborre",
    "kardborrfäst": "kardborrfäste",
    "kardborrfästen": "kardborrfäste",
    "kardborrfästena": "kardborrfäste",
    "kardborrfästenas": "kardborrfäste",
    "kardborrfästens": "kardborrfäste",
    "kardborrfästes": "kardborrfäste",
    "kardborrfästet": "kardborrfäste",
    "kardborrfästets": "kardborrfäste",
    "kardborrs": "kardborre",
    "karde": "karda",
    "kardelen": "kardel",
    "kardelens": "kardel",
    "kardeler": "kardel",
    "kardelerna": "kardel",
    "kardelernas": "kardel",
    "kardelers": "kardel",
    "kardels": "kardel",
    "kardemumman": "kardemumma",
    "kardemummans": "kardemumma",
    "kardemummas": "kardemumma",
    "kardgarnet": "kardgarn",
    "kardgarnets": "kardgarn",
    "kardgarns": "kardgarn",
    "kardinalbiskopar": "kardinalbiskop",
    "kardinalbiskoparna": "kardinalbiskop",
    "kardinalbiskoparnas": "kardinalbiskop",
    "kardinalbiskopars": "kardinalbiskop",
    "kardinalbiskopen": "kardinalbiskop",
    "kardinalbiskopens": "kardinalbiskop",
    "kardinalbiskops": "kardinalbiskop",
    "kardinaldygden": "kardinaldygd",
    "kardinaldygdens": "kardinaldygd",
    "kardinaldygder": "kardinaldygd",
    "kardinaldygderna": "kardinaldygd",
    "kardinaldygdernas": "kardinaldygd",
    "kardinaldygders": "kardinaldygd",
    "kardinaldygds": "kardinaldygd",
    "kardinalen": "kardinal",
    "kardinalens": "kardinal",
    "kardinaler": "kardinal",
    "kardinalerna": "kardinal",
    "kardinalernas": "kardinal",
    "kardinalers": "kardinal",
    "kardinalfelen": "kardinalfel",
    "kardinalfelens": "kardinalfel",
    "kardinalfelet": "kardinalfel",
    "kardinalfelets": "kardinalfel",
    "kardinalfels": "kardinalfel",
    "kardinals": "kardinal",
    "kardinalstrecken": "kardinalstreck",
    "kardinalstreckens": "kardinalstreck",
    "kardinalstrecket": "kardinalstreck",
    "kardinalstreckets": "kardinalstreck",
    "kardinalstrecks": "kardinalstreck",
    "kardinalsynden": "kardinalsynd",
    "kardinalsyndens": "kardinalsynd",
    "kardinalsynder": "kardinalsynd",
    "kardinalsynderna": "kardinalsynd",
    "kardinalsyndernas": "kardinalsynd",
    "kardinalsynders": "kardinalsynd",
    "kardinalsynds": "kardinalsynd",
    "kardinaltalen": "kardinaltal",
    "kardinaltalens": "kardinaltal",
    "kardinaltalet": "kardinaltal",
    "kardinaltalets": "kardinaltal",
    "kardinaltals": "kardinaltal",
    "kardiografen": "kardiograf",
    "kardiografens": "kardiograf",
    "kardiografer": "kardiograf",
    "kardiograferna": "kardiograf",
    "kardiografernas": "kardiograf",
    "kardiografers": "kardiograf",
    "kardiografs": "kardiograf",
    "kardiogrammen": "kardiogram",
    "kardiogrammens": "kardiogram",
    "kardiogrammet": "kardiogram",
    "kardiogrammets": "kardiogram",
    "kardiograms": "kardiogram",
    "kardiologen": "kardiolog",
    "kardiologens": "kardiolog",
    "kardiologer": "kardiolog",
    "kardiologerna": "kardiolog",
    "kardiologernas": "kardiolog",
    "kardiologers": "kardiolog",
    "kardiologien": "kardiologi",
    "kardiologiens": "kardiologi",
    "kardiologin": "kardiologi",
    "kardiologins": "kardiologi",
    "kardiologis": "kardiologi",
    "kardiologs": "kardiolog",
    "kardnubbar": "kardnubb",
    "kardnubbarna": "kardnubb",
    "kardnubbarnas": "kardnubb",
    "kardnubbars": "kardnubb",
    "kardnubben": "kardnubb",
    "kardnubbens": "kardnubb",
    "kardnubbs": "kardnubb",
    "kardor": "karda",
    "kardorna": "karda",
    "kardornas": "karda",
    "kardors": "karda",
    "kards": "karda",
    "karduanen": "karduan",
    "karduanens": "karduan",
    "karduanet": "karduan",
    "karduanets": "karduan",
    "karduans": "karduan",
    "kardullen": "kardull",
    "kardullens": "kardull",
    "kardulls": "kardull",
    "kardusen": "kardus",
    "kardusens": "kardus",
    "karduser": "kardus",
    "karduserna": "kardus",
    "kardusernas": "kardus",
    "kardusers": "kardus",
    "kare": "kara",
    "karelar": "karelare",
    "karelaren": "karelare",
    "karelarens": "karelare",
    "karelares": "karelare",
    "karelarna": "karelare",
    "karelarnas": "karelare",
    "karelen": "karel",
    "karelens": "karel",
    "kareler": "karel",
    "karelerna": "karel",
    "karelernas": "karel",
    "karelers": "karel",
    "karels": "karel",
    "karelsk": "karelska",
    "karelska": "karelsk",
    "karelskan": "karelska",
    "karelskans": "karelska",
    "karelskare": "karelsk",
    "karelskares": "karelsk",
    "karelskas": "karelska",
    "karelskast": "karelsk",
    "karelskaste": "karelsk",
    "karelskastes": "karelsk",
    "karelskasts": "karelsk",
    "karelske": "karelska",
    "karelskes": "karelsk",
    "karelskor": "karelska",
    "karelskorna": "karelska",
    "karelskornas": "karelska",
    "karelskors": "karelska",
    "karelsks": "karelsk",
    "karelskt": "karelsk",
    "karelskts": "karelsk",
    "karen": "kar",
    "karens": "kar",
    "karensdagar": "karensdag",
    "karensdagarna": "karensdag",
    "karensdagarnas": "karensdag",
    "karensdagars": "karensdag",
    "karensdagen": "karensdag",
    "karensdagens": "karensdag",
    "karensdags": "karensdag",
    "karensen": "karens",
    "karensens": "karens",
    "karenstiden": "karenstid",
    "karenstidens": "karenstid",
    "karenstids": "karenstid",
    "karessen": "karess",
    "karessens": "karess",
    "karesser": "karess",
    "karesserna": "karess",
    "karessernas": "karess",
    "karessers": "karess",
    "karet": "kareta",
    "karetan": "kareta",
    "karetans": "kareta",
    "karetas": "kareta",
    "karete": "kareta",
    "kareten": "karet",
    "karetens": "karet",
    "kareter": "karet",
    "kareterna": "karet",
    "kareternas": "karet",
    "kareters": "karet",
    "karetor": "kareta",
    "karetorna": "kareta",
    "karetornas": "kareta",
    "karetors": "kareta",
    "karets": "kareta",
    "karga": "karg",
    "kargare": "karg",
    "kargares": "karg",
    "kargas": "karg",
    "kargast": "karg",
    "kargaste": "karg",
    "kargastes": "karg",
    "kargasts": "karg",
    "karge": "karg",
    "karges": "karg",
    "kargheten": "karghet",
    "karghetens": "karghet",
    "karghets": "karghet",
    "kargs": "karg",
    "kargt": "karg",
    "kargts": "karg",
    "kariesen": "karies",
    "kariesens": "karies",
    "karikatyren": "karikatyr",
    "karikatyrens": "karikatyr",
    "karikatyrer": "karikatyr",
    "karikatyrerna": "karikatyr",
    "karikatyrernas": "karikatyr",
    "karikatyrers": "karikatyr",
    "karikatyrmässiga": "karikatyrmässig",
    "karikatyrmässigare": "karikatyrmässig",
    "karikatyrmässigares": "karikatyrmässig",
    "karikatyrmässigas": "karikatyrmässig",
    "karikatyrmässigast": "karikatyrmässig",
    "karikatyrmässigaste": "karikatyrmässig",
    "karikatyrmässigastes": "karikatyrmässig",
    "karikatyrmässigasts": "karikatyrmässig",
    "karikatyrmässige": "karikatyrmässig",
    "karikatyrmässiges": "karikatyrmässig",
    "karikatyrmässigs": "karikatyrmässig",
    "karikatyrmässigt": "karikatyrmässig",
    "karikatyrmässigts": "karikatyrmässig",
    "karikatyrs": "karikatyr",
    "karikatyrtecknar": "karikatyrtecknare",
    "karikatyrtecknaren": "karikatyrtecknare",
    "karikatyrtecknarens": "karikatyrtecknare",
    "karikatyrtecknares": "karikatyrtecknare",
    "karikatyrtecknarna": "karikatyrtecknare",
    "karikatyrtecknarnas": "karikatyrtecknare",
    "karikerad": "karikera",
    "karikerade": "karikera",
    "karikerades": "karikera",
    "karikerads": "karikera",
    "karikerande": "karikera",
    "karikeranden": "karikerande",
    "karikerandena": "karikerande",
    "karikerandenas": "karikerande",
    "karikerandens": "karikerande",
    "karikerandes": "karikerande",
    "karikerandet": "karikerande",
    "karikerandets": "karikerande",
    "karikerar": "karikera",
    "karikeras": "karikera",
    "karikerat": "karikera",
    "karikerats": "karikera",
    "karikerbara": "karikerbar",
    "karikerbarare": "karikerbar",
    "karikerbarares": "karikerbar",
    "karikerbaras": "karikerbar",
    "karikerbarast": "karikerbar",
    "karikerbaraste": "karikerbar",
    "karikerbarastes": "karikerbar",
    "karikerbarasts": "karikerbar",
    "karikerbare": "karikerbar",
    "karikerbares": "karikerbar",
    "karikerbarheten": "karikerbarhet",
    "karikerbarhetens": "karikerbarhet",
    "karikerbarhets": "karikerbarhet",
    "karikerbars": "karikerbar",
    "karikerbart": "karikerbar",
    "karikerbarts": "karikerbar",
    "karikeringar": "karikering",
    "karikeringarna": "karikering",
    "karikeringarnas": "karikering",
    "karikeringars": "karikering",
    "karikeringen": "karikering",
    "karikeringens": "karikering",
    "karikerings": "karikering",
    "karisman": "karisma",
    "karismans": "karisma",
    "karismas": "karisma",
    "karismasignalen": "karismasignal",
    "karismasignalens": "karismasignal",
    "karismasignaler": "karismasignal",
    "karismasignalerna": "karismasignal",
    "karismasignalernas": "karismasignal",
    "karismasignalers": "karismasignal",
    "karismasignals": "karismasignal",
    "karismatiska": "karismatisk",
    "karismatiskare": "karismatisk",
    "karismatiskares": "karismatisk",
    "karismatiskas": "karismatisk",
    "karismatiskast": "karismatisk",
    "karismatiskaste": "karismatisk",
    "karismatiskastes": "karismatisk",
    "karismatiskasts": "karismatisk",
    "karismatiske": "karismatisk",
    "karismatiskes": "karismatisk",
    "karismatisks": "karismatisk",
    "karismatiskt": "karismatisk",
    "karismatiskts": "karismatisk",
    "karismer": "karisma",
    "karismerna": "karisma",
    "karismernas": "karisma",
    "karismers": "karisma",
    "karit": "kariter",
    "kariterna": "kariter",
    "kariternas": "kariter",
    "kariters": "kariter",
    "karits": "kariter",
    "karkasen": "karkas",
    "karkasens": "karkas",
    "karkaser": "karkas",
    "karkaserna": "karkas",
    "karkasernas": "karkas",
    "karkasers": "karkas",
    "karlakarlar": "karlakarl",
    "karlakarlarna": "karlakarl",
    "karlakarlarnas": "karlakarl",
    "karlakarlars": "karlakarl",
    "karlakarlen": "karlakarl",
    "karlakarlens": "karlakarl",
    "karlakarln": "karlakarl",
    "karlakarlns": "karlakarl",
    "karlakarls": "karlakarl",
    "karlaktiga": "karlaktig",
    "karlaktigare": "karlaktig",
    "karlaktigares": "karlaktig",
    "karlaktigas": "karlaktig",
    "karlaktigast": "karlaktig",
    "karlaktigaste": "karlaktig",
    "karlaktigastes": "karlaktig",
    "karlaktigasts": "karlaktig",
    "karlaktige": "karlaktig",
    "karlaktiges": "karlaktig",
    "karlaktigheten": "karlaktighet",
    "karlaktighetens": "karlaktighet",
    "karlaktighets": "karlaktighet",
    "karlaktigs": "karlaktig",
    "karlaktigt": "karlaktig",
    "karlaktigts": "karlaktig",
    "karlansikten": "karlansikte",
    "karlansiktena": "karlansikte",
    "karlansiktenas": "karlansikte",
    "karlansiktens": "karlansikte",
    "karlansiktes": "karlansikte",
    "karlansiktet": "karlansikte",
    "karlansiktets": "karlansikte",
    "karlansikts": "karlansikte",
    "karlar": "karl",
    "karlarnas": "karl",
    "karlatagen": "karlatag",
    "karlatagens": "karlatag",
    "karlataget": "karlatag",
    "karlatagets": "karlatag",
    "karlatags": "karlatag",
    "karlavulenheten": "karlavulenhet",
    "karlavulenhetens": "karlavulenhet",
    "karlavulenhets": "karlavulenhet",
    "karlavulens": "karlavulen",
    "karlavulet": "karlavulen",
    "karlavulets": "karlavulen",
    "karlavulna": "karlavulen",
    "karlavulnare": "karlavulen",
    "karlavulnares": "karlavulen",
    "karlavulnas": "karlavulen",
    "karlavulnast": "karlavulen",
    "karlavulnaste": "karlavulen",
    "karlavulnastes": "karlavulen",
    "karlavulnasts": "karlavulen",
    "karlavulne": "karlavulen",
    "karlavulnes": "karlavulen",
    "karldagsverken": "karldagsverke",
    "karldagsverkena": "karldagsverke",
    "karldagsverkenas": "karldagsverke",
    "karldagsverkens": "karldagsverke",
    "karldagsverkes": "karldagsverke",
    "karldagsverket": "karldagsverke",
    "karldagsverkets": "karldagsverke",
    "karleden": "karled",
    "karledens": "karled",
    "karleder": "karled",
    "karlederna": "karled",
    "karledernas": "karled",
    "karleders": "karled",
    "karleds": "karled",
    "karlen": "karl",
    "karlens": "karl",
    "karlgalenheten": "karlgalenhet",
    "karlgalenhetens": "karlgalenhet",
    "karlgalenhets": "karlgalenhet",
    "karlgalens": "karlgalen",
    "karlgalet": "karlgalen",
    "karlgalets": "karlgalen",
    "karlgalna": "karlgalen",
    "karlgalnare": "karlgalen",
    "karlgalnares": "karlgalen",
    "karlgalnas": "karlgalen",
    "karlgalnast": "karlgalen",
    "karlgalnaste": "karlgalen",
    "karlgalnastes": "karlgalen",
    "karlgalnasts": "karlgalen",
    "karlgalne": "karlgalen",
    "karlgalnes": "karlgalen",
    "karljohans": "karljohan",
    "karljohanssoff": "karljohanssoffa",
    "karljohanssoffan": "karljohanssoffa",
    "karljohanssoffans": "karljohanssoffa",
    "karljohanssoffas": "karljohanssoffa",
    "karljohanssoffe": "karljohanssoffa",
    "karljohanssoffor": "karljohanssoffa",
    "karljohanssofforna": "karljohanssoffa",
    "karljohanssoffornas": "karljohanssoffa",
    "karljohanssoffors": "karljohanssoffa",
    "karljohanssoffs": "karljohanssoffa",
    "karljohansstilen": "karljohansstil",
    "karljohansstilens": "karljohansstil",
    "karljohansstils": "karljohansstil",
    "karljohanssvampar": "karljohanssvamp",
    "karljohanssvamparna": "karljohanssvamp",
    "karljohanssvamparnas": "karljohanssvamp",
    "karljohanssvampars": "karljohanssvamp",
    "karljohanssvampen": "karljohanssvamp",
    "karljohanssvampens": "karljohanssvamp",
    "karljohanssvamps": "karljohanssvamp",
    "karln": "karl",
    "karlns": "karl",
    "karls": "karl",
    "karlsbaderbröden": "karlsbaderbröd",
    "karlsbaderbrödens": "karlsbaderbröd",
    "karlsbaderbrödet": "karlsbaderbröd",
    "karlsbaderbrödets": "karlsbaderbröd",
    "karlsbaderbröds": "karlsbaderbröd",
    "karlsbadersaltet": "karlsbadersalt",
    "karlsbadersaltets": "karlsbadersalt",
    "karlsbadersalts": "karlsbadersalt",
    "karlslokar": "karlslok",
    "karlslokarna": "karlslok",
    "karlslokarnas": "karlslok",
    "karlslokars": "karlslok",
    "karlsloken": "karlslok",
    "karlslokens": "karlslok",
    "karlsloks": "karlslok",
    "karltokiga": "karltokig",
    "karltokigare": "karltokig",
    "karltokigares": "karltokig",
    "karltokigas": "karltokig",
    "karltokigast": "karltokig",
    "karltokigaste": "karltokig",
    "karltokigastes": "karltokig",
    "karltokigasts": "karltokig",
    "karltokige": "karltokig",
    "karltokiges": "karltokig",
    "karltokigheten": "karltokighet",
    "karltokighetens": "karltokighet",
    "karltokighets": "karltokighet",
    "karltokigs": "karltokig",
    "karltokigt": "karltokig",
    "karltokigts": "karltokig",
    "karltorkan": "karltorka",
    "karltorkans": "karltorka",
    "karltorkas": "karltorka",
    "karltorke": "karltorka",
    "karmar": "karm",
    "karmarna": "karm",
    "karmarnas": "karm",
    "karmars": "karm",
    "karmeliten": "karmelit",
    "karmelitens": "karmelit",
    "karmeliter": "karmelit",
    "karmeliterna": "karmelit",
    "karmeliternas": "karmelit",
    "karmeliterordens": "karmeliterorden",
    "karmeliterordnar": "karmeliterorden",
    "karmeliterordnarna": "karmeliterorden",
    "karmeliterordnarnas": "karmeliterorden",
    "karmeliterordnars": "karmeliterorden",
    "karmeliterordnen": "karmeliterorden",
    "karmeliterordnens": "karmeliterorden",
    "karmeliters": "karmelit",
    "karmelitordens": "karmelitorden",
    "karmelitordnar": "karmelitorden",
    "karmelitordnarna": "karmelitorden",
    "karmelitordnarnas": "karmelitorden",
    "karmelitordnars": "karmelitorden",
    "karmelitordnen": "karmelitorden",
    "karmelitordnens": "karmelitorden",
    "karmelits": "karmelit",
    "karmen": "karm",
    "karmens": "karm",
    "karminen": "karmin",
    "karminens": "karmin",
    "karminet": "karmin",
    "karminets": "karmin",
    "karmins": "karmin",
    "karminsyran": "karminsyra",
    "karminsyrans": "karminsyra",
    "karminsyras": "karminsyra",
    "karminsyre": "karminsyra",
    "karmosinen": "karmosin",
    "karmosinens": "karmosin",
    "karmosinet": "karmosin",
    "karmosinets": "karmosin",
    "karmosins": "karmosin",
    "karms": "karm",
    "karmskruvar": "karmskruv",
    "karmskruvarna": "karmskruv",
    "karmskruvarnas": "karmskruv",
    "karmskruvars": "karmskruv",
    "karmskruven": "karmskruv",
    "karmskruvens": "karmskruv",
    "karmskruvs": "karmskruv",
    "karmstolar": "karmstol",
    "karmstolarna": "karmstol",
    "karmstolarnas": "karmstol",
    "karmstolars": "karmstol",
    "karmstolen": "karmstol",
    "karmstolens": "karmstol",
    "karmstols": "karmstol",
    "karnapen": "karnap",
    "karnapens": "karnap",
    "karnaper": "karnap",
    "karnaperna": "karnap",
    "karnapernas": "karnap",
    "karnapers": "karnap",
    "karnapet": "karnap",
    "karnapets": "karnap",
    "karnappen": "karnapp",
    "karnappens": "karnapp",
    "karnapper": "karnapp",
    "karnapperna": "karnapp",
    "karnappernas": "karnapp",
    "karnappers": "karnapp",
    "karnappet": "karnapp",
    "karnappets": "karnapp",
    "karnapps": "karnapp",
    "karnaps": "karnap",
    "karnationen": "karnation",
    "karnationens": "karnation",
    "karnationer": "karnation",
    "karnationerna": "karnation",
    "karnationernas": "karnation",
    "karnationers": "karnation",
    "karnations": "karnation",
    "karneolen": "karneol",
    "karneolens": "karneol",
    "karneoler": "karneol",
    "karneolerna": "karneol",
    "karneolernas": "karneol",
    "karneolers": "karneol",
    "karneols": "karneol",
    "karnevalen": "karneval",
    "karnevalens": "karneval",
    "karnevaler": "karneval",
    "karnevalerna": "karneval",
    "karnevalernas": "karneval",
    "karnevalers": "karneval",
    "karnevals": "karneval",
    "karnisen": "karnis",
    "karnisens": "karnis",
    "karniser": "karnis",
    "karniserna": "karnis",
    "karnisernas": "karnis",
    "karnisers": "karnis",
    "karnivoren": "karnivor",
    "karnivorens": "karnivor",
    "karnivorer": "karnivor",
    "karnivorerna": "karnivor",
    "karnivorernas": "karnivor",
    "karnivorers": "karnivor",
    "karnivors": "karnivor",
    "karolinen": "karolin",
    "karolinens": "karolin",
    "karoliner": "karolin",
    "karolinerna": "karolin",
    "karolinernas": "karolin",
    "karoliners": "karolin",
    "karolingen": "karoling",
    "karolingens": "karoling",
    "karolinger": "karoling",
    "karolingerna": "karoling",
    "karolingernas": "karoling",
    "karolingers": "karoling",
    "karolings": "karoling",
    "karolins": "karolin",
    "karolinska": "karolinsk",
    "karolinskare": "karolinsk",
    "karolinskares": "karolinsk",
    "karolinskas": "karolinsk",
    "karolinskast": "karolinsk",
    "karolinskaste": "karolinsk",
    "karolinskastes": "karolinsk",
    "karolinskasts": "karolinsk",
    "karolinske": "karolinsk",
    "karolinskes": "karolinsk",
    "karolinsks": "karolinsk",
    "karolinskt": "karolinsk",
    "karolinskts": "karolinsk",
    "karor": "kara",
    "karorna": "kara",
    "karornas": "kara",
    "karors": "kara",
    "karossen": "kaross",
    "karossens": "kaross",
    "karosser": "kaross",
    "karosserier": "karosseri",
    "karosserierna": "karosseri",
    "karosseriernas": "karosseri",
    "karosseriers": "karosseri",
    "karosseriet": "karosseri",
    "karosseriets": "karosseri",
    "karosseris": "karosseri",
    "karosserit": "karosseri",
    "karosserits": "karosseri",
    "karosserna": "kaross",
    "karossernas": "kaross",
    "karossers": "kaross",
    "karotiner": "karotin",
    "karotinerna": "karotin",
    "karotinernas": "karotin",
    "karotiners": "karotin",
    "karotinet": "karotin",
    "karotinets": "karotin",
    "karotins": "karotin",
    "karotten": "karott",
    "karottens": "karott",
    "karotter": "karott",
    "karotterna": "karott",
    "karotternas": "karott",
    "karotters": "karott",
    "karotts": "karott",
    "karottunderläggen": "karottunderlägg",
    "karottunderläggens": "karottunderlägg",
    "karottunderlägget": "karottunderlägg",
    "karottunderläggets": "karottunderlägg",
    "karottunderläggs": "karottunderlägg",
    "karpar": "karp",
    "karparna": "karp",
    "karparnas": "karp",
    "karpars": "karp",
    "karpen": "karp",
    "karpens": "karp",
    "karpfiskar": "karpfisk",
    "karpfiskarna": "karpfisk",
    "karpfiskarnas": "karpfisk",
    "karpfiskars": "karpfisk",
    "karpfisken": "karpfisk",
    "karpfiskens": "karpfisk",
    "karpfisks": "karpfisk",
    "karps": "karp",
    "karriärdiplomaten": "karriärdiplomat",
    "karriärdiplomatens": "karriärdiplomat",
    "karriärdiplomater": "karriärdiplomat",
    "karriärdiplomaterna": "karriärdiplomat",
    "karriärdiplomaternas": "karriärdiplomat",
    "karriärdiplomaters": "karriärdiplomat",
    "karriärdiplomats": "karriärdiplomat",
    "karriären": "karriär",
    "karriärens": "karriär",
    "karriärer": "karriär",
    "karriärerna": "karriär",
    "karriärernas": "karriär",
    "karriärers": "karriär",
    "karriärförsäkringar": "karriärförsäkring",
    "karriärförsäkringarna": "karriärförsäkring",
    "karriärförsäkringarnas": "karriärförsäkring",
    "karriärförsäkringars": "karriärförsäkring",
    "karriärförsäkringen": "karriärförsäkring",
    "karriärförsäkringens": "karriärförsäkring",
    "karriärförsäkrings": "karriärförsäkring",
    "karriärismen": "karriärism",
    "karriärismens": "karriärism",
    "karriärismer": "karriärism",
    "karriärismerna": "karriärism",
    "karriärismernas": "karriärism",
    "karriärismers": "karriärism",
    "karriärisms": "karriärism",
    "karriäristen": "karriärist",
    "karriäristens": "karriärist",
    "karriärister": "karriärist",
    "karriäristerna": "karriärist",
    "karriäristernas": "karriärist",
    "karriäristers": "karriärist",
    "karriäristiska": "karriäristisk",
    "karriäristiskas": "karriäristisk",
    "karriäristiske": "karriäristisk",
    "karriäristiskes": "karriäristisk",
    "karriäristisks": "karriäristisk",
    "karriäristiskt": "karriäristisk",
    "karriäristiskts": "karriäristisk",
    "karriärists": "karriärist",
    "karriärmässiga": "karriärmässig",
    "karriärmässigare": "karriärmässig",
    "karriärmässigares": "karriärmässig",
    "karriärmässigas": "karriärmässig",
    "karriärmässigast": "karriärmässig",
    "karriärmässigaste": "karriärmässig",
    "karriärmässigastes": "karriärmässig",
    "karriärmässigasts": "karriärmässig",
    "karriärmässige": "karriärmässig",
    "karriärmässiges": "karriärmässig",
    "karriärmässigs": "karriärmässig",
    "karriärmässigt": "karriärmässig",
    "karriärmässigts": "karriärmässig",
    "karriärs": "karriär",
    "karriärsteg": "karriärstege",
    "karriärstegar": "karriärstege",
    "karriärstegarna": "karriärstege",
    "karriärstegarnas": "karriärstege",
    "karriärstegars": "karriärstege",
    "karriärstegen": "karriärstege",
    "karriärstegens": "karriärstege",
    "karriärsteges": "karriärstege",
    "karriärstegs": "karriärstege",
    "karriärtipsen": "karriärtips",
    "karriärtipsens": "karriärtips",
    "karriärtipset": "karriärtips",
    "karriärtipsets": "karriärtips",
    "karronaden": "karronad",
    "karronadens": "karronad",
    "karronader": "karronad",
    "karronaderna": "karronad",
    "karronadernas": "karronad",
    "karronaders": "karronad",
    "karronads": "karronad",
    "karréer": "karré",
    "karréerna": "karré",
    "karréernas": "karré",
    "karréers": "karré",
    "karrén": "karré",
    "karréns": "karré",
    "karrés": "karré",
    "kars": "kara",
    "karska": "karsk",
    "karskare": "karsk",
    "karskares": "karsk",
    "karskas": "karsk",
    "karskast": "karsk",
    "karskaste": "karsk",
    "karskastes": "karsk",
    "karskasts": "karsk",
    "karske": "karsk",
    "karskes": "karsk",
    "karskheten": "karskhet",
    "karskhetens": "karskhet",
    "karskhets": "karskhet",
    "karsks": "karsk",
    "karskt": "karsk",
    "karskts": "karsk",
    "karstbildningar": "karstbildning",
    "karstbildningarna": "karstbildning",
    "karstbildningarnas": "karstbildning",
    "karstbildningars": "karstbildning",
    "karstbildningen": "karstbildning",
    "karstbildningens": "karstbildning",
    "karstbildnings": "karstbildning",
    "karsten": "karst",
    "karstens": "karst",
    "karster": "karst",
    "karsterna": "karst",
    "karsternas": "karst",
    "karsters": "karst",
    "karsts": "karst",
    "kart": "karta",
    "kartagiska": "kartagisk",
    "kartagiskare": "kartagisk",
    "kartagiskares": "kartagisk",
    "kartagiskas": "kartagisk",
    "kartagiskast": "kartagisk",
    "kartagiskaste": "kartagisk",
    "kartagiskastes": "kartagisk",
    "kartagiskasts": "kartagisk",
    "kartagiske": "kartagisk",
    "kartagiskes": "kartagisk",
    "kartagisks": "kartagisk",
    "kartagiskt": "kartagisk",
    "kartagiskts": "kartagisk",
    "kartan": "karta",
    "kartans": "karta",
    "kartanteckningar": "kartanteckning",
    "kartanteckningarna": "kartanteckning",
    "kartanteckningarnas": "kartanteckning",
    "kartanteckningars": "kartanteckning",
    "kartanteckningen": "kartanteckning",
    "kartanteckningens": "kartanteckning",
    "kartantecknings": "kartanteckning",
    "kartar": "kart",
    "kartarna": "kart",
    "kartarnas": "kart",
    "kartars": "kart",
    "kartas": "karta",
    "kartbilden": "kartbild",
    "kartbildens": "kartbild",
    "kartbilder": "kartbild",
    "kartbilderna": "kartbild",
    "kartbildernas": "kartbild",
    "kartbilders": "kartbild",
    "kartbilds": "kartbild",
    "kartboken": "kartbok",
    "kartbokens": "kartbok",
    "kartboks": "kartbok",
    "kartböcker": "kartbok",
    "kartböckerna": "kartbok",
    "kartböckernas": "kartbok",
    "kartböckers": "kartbok",
    "karte": "karta",
    "kartellen": "kartell",
    "kartellens": "kartell",
    "karteller": "kartell",
    "kartellerna": "kartell",
    "kartellernas": "kartell",
    "kartellers": "kartell",
    "kartellmässiga": "kartellmässig",
    "kartellmässigare": "kartellmässig",
    "kartellmässigares": "kartellmässig",
    "kartellmässigas": "kartellmässig",
    "kartellmässigast": "kartellmässig",
    "kartellmässigaste": "kartellmässig",
    "kartellmässigastes": "kartellmässig",
    "kartellmässigasts": "kartellmässig",
    "kartellmässige": "kartellmässig",
    "kartellmässiges": "kartellmässig",
    "kartellmässigs": "kartellmässig",
    "kartellmässigt": "kartellmässig",
    "kartellmässigts": "kartellmässig",
    "kartells": "kartell",
    "karten": "kart",
    "kartens": "kart",
    "karterad": "kartera",
    "karterade": "kartera",
    "karterades": "kartera",
    "karterads": "kartera",
    "karterande": "kartera",
    "karteranden": "karterande",
    "karterandena": "karterande",
    "karterandenas": "karterande",
    "karterandens": "karterande",
    "karterandes": "karterande",
    "karterandet": "karterande",
    "karterandets": "karterande",
    "karterar": "kartera",
    "karteras": "kartera",
    "karterat": "kartera",
    "karterats": "kartera",
    "karterbara": "karterbar",
    "karterbarare": "karterbar",
    "karterbarares": "karterbar",
    "karterbaras": "karterbar",
    "karterbarast": "karterbar",
    "karterbaraste": "karterbar",
    "karterbarastes": "karterbar",
    "karterbarasts": "karterbar",
    "karterbare": "karterbar",
    "karterbares": "karterbar",
    "karterbarheten": "karterbarhet",
    "karterbarhetens": "karterbarhet",
    "karterbarhets": "karterbarhet",
    "karterbars": "karterbar",
    "karterbart": "karterbar",
    "karterbarts": "karterbar",
    "karteringar": "kartering",
    "karteringarna": "kartering",
    "karteringarnas": "kartering",
    "karteringars": "kartering",
    "karteringen": "kartering",
    "karteringens": "kartering",
    "karterings": "kartering",
    "karteschen": "kartesch",
    "karteschens": "kartesch",
    "kartescher": "kartesch",
    "kartescherna": "kartesch",
    "karteschernas": "kartesch",
    "karteschers": "kartesch",
    "karteschkul": "karteschkula",
    "karteschkulan": "karteschkula",
    "karteschkulans": "karteschkula",
    "karteschkulas": "karteschkula",
    "karteschkule": "karteschkula",
    "karteschkulor": "karteschkula",
    "karteschkulorna": "karteschkula",
    "karteschkulornas": "karteschkula",
    "karteschkulors": "karteschkula",
    "karteschkuls": "karteschkula",
    "karteschs": "kartesch",
    "kartiga": "kartig",
    "kartigare": "kartig",
    "kartigares": "kartig",
    "kartigas": "kartig",
    "kartigast": "kartig",
    "kartigaste": "kartig",
    "kartigastes": "kartig",
    "kartigasts": "kartig",
    "kartige": "kartig",
    "kartiges": "kartig",
    "kartigheten": "kartighet",
    "kartighetens": "kartighet",
    "kartighets": "kartighet",
    "kartigs": "kartig",
    "kartigt": "kartig",
    "kartigts": "kartig",
    "kartla": "kartlägga",
    "kartlade": "kartlägga",
    "kartlades": "kartlägga",
    "kartlagd": "kartlägga",
    "kartlagda": "kartlägga",
    "kartlagdas": "kartlägga",
    "kartlagde": "kartlägga",
    "kartlagdes": "kartlägga",
    "kartlagds": "kartlägga",
    "kartlagt": "kartlägga",
    "kartlagts": "kartlägga",
    "kartlamp": "kartlampa",
    "kartlampan": "kartlampa",
    "kartlampans": "kartlampa",
    "kartlampas": "kartlampa",
    "kartlampe": "kartlampa",
    "kartlampor": "kartlampa",
    "kartlamporna": "kartlampa",
    "kartlampornas": "kartlampa",
    "kartlampors": "kartlampa",
    "kartlamps": "kartlampa",
    "kartlas": "kartlägga",
    "kartlägg": "kartlägga",
    "kartläggande": "kartlägga",
    "kartlägganden": "kartläggande",
    "kartläggandena": "kartläggande",
    "kartläggandenas": "kartläggande",
    "kartläggandens": "kartläggande",
    "kartläggandes": "kartläggande",
    "kartläggandet": "kartläggande",
    "kartläggandets": "kartläggande",
    "kartläggas": "kartlägga",
    "kartlägger": "kartlägga",
    "kartlägges": "kartlägga",
    "kartläggningar": "kartläggning",
    "kartläggningarna": "kartläggning",
    "kartläggningarnas": "kartläggning",
    "kartläggningars": "kartläggning",
    "kartläggningen": "kartläggning",
    "kartläggningens": "kartläggning",
    "kartläggnings": "kartläggning",
    "kartläggs": "kartlägga",
    "kartläsar": "kartläsare",
    "kartläsaren": "kartläsare",
    "kartläsarens": "kartläsare",
    "kartläsares": "kartläsare",
    "kartläsarlamp": "kartläsarlampa",
    "kartläsarlampan": "kartläsarlampa",
    "kartläsarlampans": "kartläsarlampa",
    "kartläsarlampas": "kartläsarlampa",
    "kartläsarlampe": "kartläsarlampa",
    "kartläsarlampor": "kartläsarlampa",
    "kartläsarlamporna": "kartläsarlampa",
    "kartläsarlampornas": "kartläsarlampa",
    "kartläsarlampors": "kartläsarlampa",
    "kartläsarlamps": "kartläsarlampa",
    "kartläsarna": "kartläsare",
    "kartläsarnas": "kartläsare",
    "kartläsningar": "kartläsning",
    "kartläsningarna": "kartläsning",
    "kartläsningarnas": "kartläsning",
    "kartläsningars": "kartläsning",
    "kartläsningen": "kartläsning",
    "kartläsningens": "kartläsning",
    "kartläsnings": "kartläsning",
    "kartmätar": "kartmätare",
    "kartmätaren": "kartmätare",
    "kartmätarens": "kartmätare",
    "kartmätares": "kartmätare",
    "kartmätarna": "kartmätare",
    "kartmätarnas": "kartmätare",
    "kartnageln": "kartnagel",
    "kartnagelns": "kartnagel",
    "kartnagels": "kartnagel",
    "kartnaglar": "kartnagel",
    "kartnaglarna": "kartnagel",
    "kartnaglarnas": "kartnagel",
    "kartnaglars": "kartnagel",
    "kartografien": "kartografi",
    "kartografiens": "kartografi",
    "kartografin": "kartografi",
    "kartografins": "kartografi",
    "kartografis": "kartografi",
    "kartongbruken": "kartongbruk",
    "kartongbrukens": "kartongbruk",
    "kartongbruket": "kartongbruk",
    "kartongbrukets": "kartongbruk",
    "kartongbruks": "kartongbruk",
    "kartongen": "kartong",
    "kartongens": "kartong",
    "kartonger": "kartong",
    "kartongerna": "kartong",
    "kartongernas": "kartong",
    "kartongers": "kartong",
    "kartongs": "kartong",
    "kartonisten": "kartonist",
    "kartonistens": "kartonist",
    "kartonister": "kartonist",
    "kartonisterna": "kartonist",
    "kartonisternas": "kartonist",
    "kartonisters": "kartonist",
    "kartonists": "kartonist",
    "kartonnerad": "kartonnera",
    "kartonnerade": "kartonnera",
    "kartonnerades": "kartonnera",
    "kartonnerads": "kartonnera",
    "kartonnerande": "kartonnera",
    "kartonneranden": "kartonnerande",
    "kartonnerandena": "kartonnerande",
    "kartonnerandenas": "kartonnerande",
    "kartonnerandens": "kartonnerande",
    "kartonnerandes": "kartonnerande",
    "kartonnerandet": "kartonnerande",
    "kartonnerandets": "kartonnerande",
    "kartonnerar": "kartonnera",
    "kartonneras": "kartonnera",
    "kartonnerat": "kartonnera",
    "kartonnerats": "kartonnera",
    "kartonnerbara": "kartonnerbar",
    "kartonnerbarare": "kartonnerbar",
    "kartonnerbarares": "kartonnerbar",
    "kartonnerbaras": "kartonnerbar",
    "kartonnerbarast": "kartonnerbar",
    "kartonnerbaraste": "kartonnerbar",
    "kartonnerbarastes": "kartonnerbar",
    "kartonnerbarasts": "kartonnerbar",
    "kartonnerbare": "kartonnerbar",
    "kartonnerbares": "kartonnerbar",
    "kartonnerbarheten": "kartonnerbarhet",
    "kartonnerbarhetens": "kartonnerbarhet",
    "kartonnerbarhets": "kartonnerbarhet",
    "kartonnerbars": "kartonnerbar",
    "kartonnerbart": "kartonnerbar",
    "kartonnerbarts": "kartonnerbar",
    "kartonneringar": "kartonnering",
    "kartonneringarna": "kartonnering",
    "kartonneringarnas": "kartonnering",
    "kartonneringars": "kartonnering",
    "kartonneringen": "kartonnering",
    "kartonneringens": "kartonnering",
    "kartonnerings": "kartonnering",
    "kartor": "karta",
    "kartorna": "karta",
    "kartornas": "karta",
    "kartors": "karta",
    "kartoteken": "kartotek",
    "kartotekens": "kartotek",
    "kartoteket": "kartotek",
    "kartotekets": "kartotek",
    "kartoteks": "kartotek",
    "kartotekslåd": "kartotekslåda",
    "kartotekslådan": "kartotekslåda",
    "kartotekslådans": "kartotekslåda",
    "kartotekslådas": "kartotekslåda",
    "kartotekslåde": "kartotekslåda",
    "kartotekslådor": "kartotekslåda",
    "kartotekslådorna": "kartotekslåda",
    "kartotekslådornas": "kartotekslåda",
    "kartotekslådors": "kartotekslåda",
    "kartotekslåds": "kartotekslåda",
    "kartprojektionen": "kartprojektion",
    "kartprojektionens": "kartprojektion",
    "kartprojektioner": "kartprojektion",
    "kartprojektionerna": "kartprojektion",
    "kartprojektionernas": "kartprojektion",
    "kartprojektioners": "kartprojektion",
    "kartprojektions": "kartprojektion",
    "kartritar": "kartritare",
    "kartritaren": "kartritare",
    "kartritarens": "kartritare",
    "kartritares": "kartritare",
    "kartritarna": "kartritare",
    "kartritarnas": "kartritare",
    "kartritartraditionen": "kartritartradition",
    "kartritartraditionens": "kartritartradition",
    "kartritartraditioner": "kartritartradition",
    "kartritartraditionerna": "kartritartradition",
    "kartritartraditionernas": "kartritartradition",
    "kartritartraditioners": "kartritartradition",
    "kartritartraditions": "kartritartradition",
    "karts": "karta",
    "kartspecialen": "kartspecial",
    "kartspecialens": "kartspecial",
    "kartspecialer": "kartspecial",
    "kartspecialerna": "kartspecial",
    "kartspecialernas": "kartspecial",
    "kartspecialers": "kartspecial",
    "kartspecials": "kartspecial",
    "kartteckens": "karttecken",
    "karttecknen": "karttecken",
    "karttecknens": "karttecken",
    "karttecknet": "karttecken",
    "karttecknets": "karttecken",
    "kartuschen": "kartusch",
    "kartuschens": "kartusch",
    "kartuscher": "kartusch",
    "kartuscherna": "kartusch",
    "kartuschernas": "kartusch",
    "kartuschers": "kartusch",
    "kartuschs": "kartusch",
    "kartusianen": "kartusian",
    "kartusianens": "kartusian",
    "kartusianer": "kartusian",
    "kartusianerna": "kartusian",
    "kartusianernas": "kartusian",
    "kartusianerordens": "kartusianerorden",
    "kartusianerordnar": "kartusianerorden",
    "kartusianerordnarna": "kartusianerorden",
    "kartusianerordnarnas": "kartusianerorden",
    "kartusianerordnars": "kartusianerorden",
    "kartusianerordnen": "kartusianerorden",
    "kartusianerordnens": "kartusianerorden",
    "kartusianers": "kartusian",
    "kartusianordens": "kartusianorden",
    "kartusianordnar": "kartusianorden",
    "kartusianordnarna": "kartusianorden",
    "kartusianordnarnas": "kartusianorden",
    "kartusianordnars": "kartusianorden",
    "kartusianordnen": "kartusianorden",
    "kartusianordnens": "kartusianorden",
    "kartusians": "kartusian",
    "karusellen": "karusell",
    "karusellens": "karusell",
    "karuseller": "karusell",
    "karusellerna": "karusell",
    "karusellernas": "karusell",
    "karusellers": "karusell",
    "karusellhästar": "karusellhäst",
    "karusellhästarna": "karusellhäst",
    "karusellhästarnas": "karusellhäst",
    "karusellhästars": "karusellhäst",
    "karusellhästen": "karusellhäst",
    "karusellhästens": "karusellhäst",
    "karusellhästs": "karusellhäst",
    "karusells": "karusell",
    "karv": "karva",
    "karvad": "karva",
    "karvade": "karva",
    "karvades": "karva",
    "karvads": "karva",
    "karvande": "karva",
    "karvanden": "karvande",
    "karvandena": "karvande",
    "karvandenas": "karvande",
    "karvandens": "karvande",
    "karvandes": "karvande",
    "karvandet": "karvande",
    "karvandets": "karvande",
    "karvar": "karva",
    "karvas": "karva",
    "karvat": "karva",
    "karvats": "karva",
    "karvsnitten": "karvsnitt",
    "karvsnittens": "karvsnitt",
    "karvsnittet": "karvsnitt",
    "karvsnittets": "karvsnitt",
    "karvsnitts": "karvsnitt",
    "karvstockar": "karvstock",
    "karvstockarna": "karvstock",
    "karvstockarnas": "karvstock",
    "karvstockars": "karvstock",
    "karvstocken": "karvstock",
    "karvstockens": "karvstock",
    "karvstocks": "karvstock",
    "karyatiden": "karyatid",
    "karyatidens": "karyatid",
    "karyatider": "karyatid",
    "karyatiderna": "karyatid",
    "karyatidernas": "karyatid",
    "karyatiders": "karyatid",
    "karyatids": "karyatid",
    "kas": "kase",
    "kasacken": "kasack",
    "kasackens": "kasack",
    "kasacker": "kasack",
    "kasackerna": "kasack",
    "kasackernas": "kasack",
    "kasackers": "kasack",
    "kasacks": "kasack",
    "kasade": "kasa",
    "kasades": "kasa",
    "kasande": "kasa",
    "kasanden": "kasande",
    "kasandena": "kasande",
    "kasandenas": "kasande",
    "kasandens": "kasande",
    "kasandes": "kasande",
    "kasandet": "kasande",
    "kasandets": "kasande",
    "kasar": "kase",
    "kasarna": "kase",
    "kasarnas": "kase",
    "kasars": "kase",
    "kasas": "kasa",
    "kasat": "kasa",
    "kasats": "kasa",
    "kaschmiren": "kaschmir",
    "kaschmirens": "kaschmir",
    "kaschmiret": "kaschmir",
    "kaschmirets": "kaschmir",
    "kaschmirs": "kaschmir",
    "kaschmirsjalar": "kaschmirsjal",
    "kaschmirsjalarna": "kaschmirsjal",
    "kaschmirsjalarnas": "kaschmirsjal",
    "kaschmirsjalars": "kaschmirsjal",
    "kaschmirsjalen": "kaschmirsjal",
    "kaschmirsjalens": "kaschmirsjal",
    "kaschmirsjals": "kaschmirsjal",
    "kaseinen": "kasein",
    "kaseinens": "kasein",
    "kaseiner": "kasein",
    "kaseinerna": "kasein",
    "kaseinernas": "kasein",
    "kaseiners": "kasein",
    "kaseinet": "kasein",
    "kaseinets": "kasein",
    "kaseins": "kasein",
    "kasematten": "kasematt",
    "kasemattens": "kasematt",
    "kasematter": "kasematt",
    "kasematterna": "kasematt",
    "kasematternas": "kasematt",
    "kasematters": "kasematt",
    "kasematts": "kasematt",
    "kasen": "kase",
    "kasens": "kase",
    "kasernen": "kasern",
    "kasernens": "kasern",
    "kaserner": "kasern",
    "kasernerna": "kasern",
    "kasernernas": "kasern",
    "kaserners": "kasern",
    "kasernförbuden": "kasernförbud",
    "kasernförbudens": "kasernförbud",
    "kasernförbudet": "kasernförbud",
    "kasernförbudets": "kasernförbud",
    "kasernförbuds": "kasernförbud",
    "kaserngårdar": "kaserngård",
    "kaserngårdarna": "kaserngård",
    "kaserngårdarnas": "kaserngård",
    "kaserngårdars": "kaserngård",
    "kaserngården": "kaserngård",
    "kaserngårdens": "kaserngård",
    "kaserngårds": "kaserngård",
    "kaserns": "kasern",
    "kases": "kase",
    "kashmiren": "kashmir",
    "kashmirens": "kashmir",
    "kashmirer": "kashmir",
    "kashmirerna": "kashmir",
    "kashmirernas": "kashmir",
    "kashmirers": "kashmir",
    "kashmirs": "kashmir",
    "kashmirsjalar": "kashmirsjal",
    "kashmirsjalarna": "kashmirsjal",
    "kashmirsjalarnas": "kashmirsjal",
    "kashmirsjalars": "kashmirsjal",
    "kashmirsjalen": "kashmirsjal",
    "kashmirsjalens": "kashmirsjal",
    "kashmirsjals": "kashmirsjal",
    "kasinon": "kasino",
    "kasinona": "kasino",
    "kasinonas": "kasino",
    "kasinons": "kasino",
    "kasinos": "kasino",
    "kasinot": "kasino",
    "kasinots": "kasino",
    "kasjunöten": "kasjunöt",
    "kasjunötens": "kasjunöt",
    "kasjunöts": "kasjunöt",
    "kasjunötter": "kasjunöt",
    "kasjunötterna": "kasjunöt",
    "kasjunötternas": "kasjunöt",
    "kasjunötters": "kasjunöt",
    "kaskaden": "kaskad",
    "kaskadens": "kaskad",
    "kaskader": "kaskad",
    "kaskaderna": "kaskad",
    "kaskadernas": "kaskad",
    "kaskaders": "kaskad",
    "kaskadkopplad": "kaskadkoppla",
    "kaskadkopplade": "kaskadkoppla",
    "kaskadkopplades": "kaskadkoppla",
    "kaskadkopplads": "kaskadkoppla",
    "kaskadkopplande": "kaskadkoppla",
    "kaskadkopplanden": "kaskadkopplande",
    "kaskadkopplandena": "kaskadkopplande",
    "kaskadkopplandenas": "kaskadkopplande",
    "kaskadkopplandens": "kaskadkopplande",
    "kaskadkopplandes": "kaskadkopplande",
    "kaskadkopplandet": "kaskadkopplande",
    "kaskadkopplandets": "kaskadkopplande",
    "kaskadkopplar": "kaskadkoppla",
    "kaskadkopplas": "kaskadkoppla",
    "kaskadkopplat": "kaskadkoppla",
    "kaskadkopplats": "kaskadkoppla",
    "kaskadkopplingar": "kaskadkoppling",
    "kaskadkopplingarna": "kaskadkoppling",
    "kaskadkopplingarnas": "kaskadkoppling",
    "kaskadkopplingars": "kaskadkoppling",
    "kaskadkopplingen": "kaskadkoppling",
    "kaskadkopplingens": "kaskadkoppling",
    "kaskadkopplings": "kaskadkoppling",
    "kaskads": "kaskad",
    "kaskar": "kask",
    "kaskarna": "kask",
    "kaskarnas": "kask",
    "kaskars": "kask",
    "kaskeloten": "kaskelot",
    "kaskelotens": "kaskelot",
    "kaskeloter": "kaskelot",
    "kaskeloterna": "kaskelot",
    "kaskeloternas": "kaskelot",
    "kaskeloters": "kaskelot",
    "kaskelots": "kaskelot",
    "kaskelotten": "kaskelott",
    "kaskelottens": "kaskelott",
    "kaskelotter": "kaskelott",
    "kaskelotterna": "kaskelott",
    "kaskelotternas": "kaskelott",
    "kaskelotters": "kaskelott",
    "kaskelotts": "kaskelott",
    "kasken": "kask",
    "kaskens": "kask",
    "kasketten": "kaskett",
    "kaskettens": "kaskett",
    "kasketter": "kaskett",
    "kasketterna": "kaskett",
    "kasketternas": "kaskett",
    "kasketters": "kaskett",
    "kasketts": "kaskett",
    "kaskoförsäkringar": "kaskoförsäkring",
    "kaskoförsäkringarna": "kaskoförsäkring",
    "kaskoförsäkringarnas": "kaskoförsäkring",
    "kaskoförsäkringars": "kaskoförsäkring",
    "kaskoförsäkringen": "kaskoförsäkring",
    "kaskoförsäkringens": "kaskoförsäkring",
    "kaskoförsäkrings": "kaskoförsäkring",
    "kaskon": "kasko",
    "kaskona": "kasko",
    "kaskonas": "kasko",
    "kaskons": "kasko",
    "kaskos": "kasko",
    "kaskot": "kasko",
    "kaskots": "kasko",
    "kasks": "kask",
    "kasperdock": "kasperdocka",
    "kasperdockan": "kasperdocka",
    "kasperdockans": "kasperdocka",
    "kasperdockas": "kasperdocka",
    "kasperdocke": "kasperdocka",
    "kasperdockor": "kasperdocka",
    "kasperdockorna": "kasperdocka",
    "kasperdockornas": "kasperdocka",
    "kasperdockors": "kasperdocka",
    "kasperdocks": "kasperdocka",
    "kaspern": "kasper",
    "kasperns": "kasper",
    "kaspers": "kasper",
    "kasperteatern": "kasperteater",
    "kasperteaterns": "kasperteater",
    "kasperteaters": "kasperteater",
    "kasperteatrar": "kasperteater",
    "kasperteatrarna": "kasperteater",
    "kasperteatrarnas": "kasperteater",
    "kasperteatrars": "kasperteater",
    "kass": "kasse",
    "kassa": "kass",
    "kassaaffären": "kassaaffär",
    "kassaaffärens": "kassaaffär",
    "kassaaffärer": "kassaaffär",
    "kassaaffärerna": "kassaaffär",
    "kassaaffärernas": "kassaaffär",
    "kassaaffärers": "kassaaffär",
    "kassaaffärs": "kassaaffär",
    "kassaapparaten": "kassaapparat",
    "kassaapparatens": "kassaapparat",
    "kassaapparater": "kassaapparat",
    "kassaapparaterna": "kassaapparat",
    "kassaapparaternas": "kassaapparat",
    "kassaapparaters": "kassaapparat",
    "kassaapparats": "kassaapparat",
    "kassabels": "kassabel",
    "kassabelt": "kassabel",
    "kassabelts": "kassabel",
    "kassabla": "kassabel",
    "kassablare": "kassabel",
    "kassablares": "kassabel",
    "kassablas": "kassabel",
    "kassablast": "kassabel",
    "kassablaste": "kassabel",
    "kassablastes": "kassabel",
    "kassablasts": "kassabel",
    "kassable": "kassabel",
    "kassables": "kassabel",
    "kassaboken": "kassabok",
    "kassabokens": "kassabok",
    "kassaboks": "kassabok",
    "kassabristen": "kassabrist",
    "kassabristens": "kassabrist",
    "kassabrister": "kassabrist",
    "kassabristerna": "kassabrist",
    "kassabristernas": "kassabrist",
    "kassabristers": "kassabrist",
    "kassabrists": "kassabrist",
    "kassaböcker": "kassabok",
    "kassaböckerna": "kassabok",
    "kassaböckernas": "kassabok",
    "kassaböckers": "kassabok",
    "kassakist": "kassakista",
    "kassakistan": "kassakista",
    "kassakistans": "kassakista",
    "kassakistas": "kassakista",
    "kassakiste": "kassakista",
    "kassakistor": "kassakista",
    "kassakistorna": "kassakista",
    "kassakistornas": "kassakista",
    "kassakistors": "kassakista",
    "kassaklirret": "kassaklirr",
    "kassaklirrets": "kassaklirr",
    "kassaklirrs": "kassaklirr",
    "kassakon": "kassako",
    "kassakons": "kassako",
    "kassakontrollapparaten": "kassakontrollapparat",
    "kassakontrollapparatens": "kassakontrollapparat",
    "kassakontrollapparater": "kassakontrollapparat",
    "kassakontrollapparaterna": "kassakontrollapparat",
    "kassakontrollapparaternas": "kassakontrollapparat",
    "kassakontrollapparaters": "kassakontrollapparat",
    "kassakontrollapparats": "kassakontrollapparat",
    "kassakor": "kassako",
    "kassakorna": "kassako",
    "kassakornas": "kassako",
    "kassakors": "kassako",
    "kassakos": "kassako",
    "kassakreditiven": "kassakreditiv",
    "kassakreditivens": "kassakreditiv",
    "kassakreditivet": "kassakreditiv",
    "kassakreditivets": "kassakreditiv",
    "kassakreditivs": "kassakreditiv",
    "kassakvitton": "kassakvitto",
    "kassakvittona": "kassakvitto",
    "kassakvittonas": "kassakvitto",
    "kassakvittons": "kassakvitto",
    "kassakvittos": "kassakvitto",
    "kassakvittot": "kassakvitto",
    "kassakvittots": "kassakvitto",
    "kassaköer": "kassakö",
    "kassaköerna": "kassakö",
    "kassaköernas": "kassakö",
    "kassaköers": "kassakö",
    "kassakön": "kassakö",
    "kassaköns": "kassakö",
    "kassaköpen": "kassaköp",
    "kassaköpens": "kassaköp",
    "kassaköpet": "kassaköp",
    "kassaköpets": "kassaköp",
    "kassaköps": "kassaköp",
    "kassakös": "kassakö",
    "kassalåd": "kassalåda",
    "kassalådan": "kassalåda",
    "kassalådans": "kassalåda",
    "kassalådas": "kassalåda",
    "kassalåde": "kassalåda",
    "kassalådor": "kassalåda",
    "kassalådorna": "kassalåda",
    "kassalådornas": "kassalåda",
    "kassalådors": "kassalåda",
    "kassalåds": "kassalåda",
    "kassamässiga": "kassamässig",
    "kassamässigare": "kassamässig",
    "kassamässigares": "kassamässig",
    "kassamässigas": "kassamässig",
    "kassamässigast": "kassamässig",
    "kassamässigaste": "kassamässig",
    "kassamässigastes": "kassamässig",
    "kassamässigasts": "kassamässig",
    "kassamässige": "kassamässig",
    "kassamässiges": "kassamässig",
    "kassamässigs": "kassamässig",
    "kassamässigt": "kassamässig",
    "kassamässigts": "kassamässig",
    "kassan": "kassa",
    "kassans": "kassa",
    "kassapjäsen": "kassapjäs",
    "kassapjäsens": "kassapjäs",
    "kassapjäser": "kassapjäs",
    "kassapjäserna": "kassapjäs",
    "kassapjäsernas": "kassapjäs",
    "kassapjäsers": "kassapjäs",
    "kassar": "kasse",
    "kassarabatten": "kassarabatt",
    "kassarabattens": "kassarabatt",
    "kassarabatter": "kassarabatt",
    "kassarabatterna": "kassarabatt",
    "kassarabatternas": "kassarabatt",
    "kassarabatters": "kassarabatt",
    "kassarabatts": "kassarabatt",
    "kassare": "kass",
    "kassares": "kass",
    "kassareserven": "kassareserv",
    "kassareservens": "kassareserv",
    "kassareserver": "kassareserv",
    "kassareserverna": "kassareserv",
    "kassareservernas": "kassareserv",
    "kassareservers": "kassareserv",
    "kassareservs": "kassareserv",
    "kassarna": "kasse",
    "kassarnas": "kasse",
    "kassars": "kasse",
    "kassas": "kassa",
    "kassaskrinen": "kassaskrin",
    "kassaskrinens": "kassaskrin",
    "kassaskrinet": "kassaskrin",
    "kassaskrinets": "kassaskrin",
    "kassaskrins": "kassaskrin",
    "kassaskåpen": "kassaskåp",
    "kassaskåpens": "kassaskåp",
    "kassaskåpet": "kassaskåp",
    "kassaskåpets": "kassaskåp",
    "kassaskåps": "kassaskåp",
    "kassast": "kass",
    "kassaste": "kass",
    "kassastes": "kass",
    "kassasts": "kass",
    "kassationen": "kassation",
    "kassationens": "kassation",
    "kassationer": "kassation",
    "kassationerna": "kassation",
    "kassationernas": "kassation",
    "kassationers": "kassation",
    "kassations": "kassation",
    "kassationsdomstolar": "kassationsdomstol",
    "kassationsdomstolarna": "kassationsdomstol",
    "kassationsdomstolarnas": "kassationsdomstol",
    "kassationsdomstolars": "kassationsdomstol",
    "kassationsdomstolen": "kassationsdomstol",
    "kassationsdomstolens": "kassationsdomstol",
    "kassationsdomstols": "kassationsdomstol",
    "kassavalven": "kassavalv",
    "kassavalvens": "kassavalv",
    "kassavalvet": "kassavalv",
    "kassavalvets": "kassavalv",
    "kassavalvs": "kassavalv",
    "kassavan": "kassava",
    "kassavans": "kassava",
    "kassavas": "kassava",
    "kasse": "kassa",
    "kasselern": "kasseler",
    "kasselerns": "kasseler",
    "kasselers": "kasseler",
    "kassen": "kasse",
    "kassens": "kasse",
    "kasserad": "kassera",
    "kasserade": "kassera",
    "kasserades": "kassera",
    "kasserads": "kassera",
    "kasserande": "kassera",
    "kasseranden": "kasserande",
    "kasserandena": "kasserande",
    "kasserandenas": "kasserande",
    "kasserandens": "kasserande",
    "kasserandes": "kasserande",
    "kasserandet": "kasserande",
    "kasserandets": "kasserande",
    "kasserar": "kassera",
    "kasseras": "kassera",
    "kasserat": "kassera",
    "kasserats": "kassera",
    "kasserbara": "kasserbar",
    "kasserbarare": "kasserbar",
    "kasserbarares": "kasserbar",
    "kasserbaras": "kasserbar",
    "kasserbarast": "kasserbar",
    "kasserbaraste": "kasserbar",
    "kasserbarastes": "kasserbar",
    "kasserbarasts": "kasserbar",
    "kasserbare": "kasserbar",
    "kasserbares": "kasserbar",
    "kasserbarheten": "kasserbarhet",
    "kasserbarhetens": "kasserbarhet",
    "kasserbarhets": "kasserbarhet",
    "kasserbars": "kasserbar",
    "kasserbart": "kasserbar",
    "kasserbarts": "kasserbar",
    "kasseringar": "kassering",
    "kasseringarna": "kassering",
    "kasseringarnas": "kassering",
    "kasseringars": "kassering",
    "kasseringen": "kassering",
    "kasseringens": "kassering",
    "kasserings": "kassering",
    "kasses": "kasse",
    "kassettbanden": "kassettband",
    "kassettbandens": "kassettband",
    "kassettbandet": "kassettband",
    "kassettbandets": "kassettband",
    "kassettbands": "kassettband",
    "kassettbandspelar": "kassettbandspelare",
    "kassettbandspelaren": "kassettbandspelare",
    "kassettbandspelarens": "kassettbandspelare",
    "kassettbandspelares": "kassettbandspelare",
    "kassettbandspelarna": "kassettbandspelare",
    "kassettbandspelarnas": "kassettbandspelare",
    "kassettdäcken": "kassettdäck",
    "kassettdäckens": "kassettdäck",
    "kassettdäcket": "kassettdäck",
    "kassettdäckets": "kassettdäck",
    "kassettdäcks": "kassettdäck",
    "kassetten": "kassett",
    "kassettens": "kassett",
    "kassetter": "kassett",
    "kassetterna": "kassett",
    "kassetternas": "kassett",
    "kassetters": "kassett",
    "kassettradion": "kassettradio",
    "kassettradions": "kassettradio",
    "kassettradios": "kassettradio",
    "kassetts": "kassett",
    "kassheten": "kasshet",
    "kasshetens": "kasshet",
    "kasshets": "kasshet",
    "kasslern": "kassler",
    "kasslerns": "kassler",
    "kasslers": "kassler",
    "kassor": "kassa",
    "kassorna": "kassa",
    "kassornas": "kassa",
    "kassors": "kassa",
    "kasst": "kass",
    "kassts": "kass",
    "kassunen": "kassun",
    "kassunens": "kassun",
    "kassuner": "kassun",
    "kassunerna": "kassun",
    "kassunernas": "kassun",
    "kassuners": "kassun",
    "kassuns": "kassun",
    "kassunsjukan": "kassunsjuka",
    "kassunsjukans": "kassunsjuka",
    "kassunsjukas": "kassunsjuka",
    "kassunsjuke": "kassunsjuka",
    "kassunsjuks": "kassunsjuka",
    "kassören": "kassör",
    "kassörens": "kassör",
    "kassörer": "kassör",
    "kassörerna": "kassör",
    "kassörernas": "kassör",
    "kassörers": "kassör",
    "kassörn": "kassör",
    "kassörns": "kassör",
    "kassörs": "kassör",
    "kassörskan": "kassörska",
    "kassörskans": "kassörska",
    "kassörskas": "kassörska",
    "kassörske": "kassörska",
    "kassörskor": "kassörska",
    "kassörskorna": "kassörska",
    "kassörskornas": "kassörska",
    "kassörskors": "kassörska",
    "kast": "kasta",
    "kastad": "kasta",
    "kastade": "kasta",
    "kastades": "kasta",
    "kastads": "kasta",
    "kastalen": "kastal",
    "kastalens": "kastal",
    "kastaler": "kastal",
    "kastalerna": "kastal",
    "kastalernas": "kastal",
    "kastalers": "kastal",
    "kastals": "kastal",
    "kastande": "kasta",
    "kastanden": "kastande",
    "kastandena": "kastande",
    "kastandenas": "kastande",
    "kastandens": "kastande",
    "kastandes": "kastande",
    "kastandet": "kastande",
    "kastandets": "kastande",
    "kastanjbruna": "kastanjbrun",
    "kastanjbrunare": "kastanjbrun",
    "kastanjbrunares": "kastanjbrun",
    "kastanjbrunas": "kastanjbrun",
    "kastanjbrunast": "kastanjbrun",
    "kastanjbrunaste": "kastanjbrun",
    "kastanjbrunastes": "kastanjbrun",
    "kastanjbrunasts": "kastanjbrun",
    "kastanjbrune": "kastanjbrun",
    "kastanjbrunes": "kastanjbrun",
    "kastanjbruns": "kastanjbrun",
    "kastanjbrunt": "kastanjbrun",
    "kastanjbrunts": "kastanjbrun",
    "kastanjebruna": "kastanjebrun",
    "kastanjebrunare": "kastanjebrun",
    "kastanjebrunares": "kastanjebrun",
    "kastanjebrunas": "kastanjebrun",
    "kastanjebrunast": "kastanjebrun",
    "kastanjebrunaste": "kastanjebrun",
    "kastanjebrunastes": "kastanjebrun",
    "kastanjebrunasts": "kastanjebrun",
    "kastanjebrune": "kastanjebrun",
    "kastanjebrunes": "kastanjebrun",
    "kastanjebruns": "kastanjebrun",
    "kastanjebrunt": "kastanjebrun",
    "kastanjebrunts": "kastanjebrun",
    "kastanjen": "kastanje",
    "kastanjens": "kastanje",
    "kastanjer": "kastanje",
    "kastanjerna": "kastanje",
    "kastanjernas": "kastanje",
    "kastanjers": "kastanje",
    "kastanjes": "kastanje",
    "kastanjetten": "kastanjett",
    "kastanjettens": "kastanjett",
    "kastanjetter": "kastanjett",
    "kastanjetterna": "kastanjett",
    "kastanjetternas": "kastanjett",
    "kastanjetters": "kastanjett",
    "kastanjetts": "kastanjett",
    "kastanjs": "kastanj",
    "kastar": "kasta",
    "kastas": "kasta",
    "kastat": "kasta",
    "kastats": "kasta",
    "kastbanan": "kastbana",
    "kastbanans": "kastbana",
    "kastbanas": "kastbana",
    "kastbane": "kastbana",
    "kastbanor": "kastbana",
    "kastbanorna": "kastbana",
    "kastbanornas": "kastbana",
    "kastbanors": "kastbana",
    "kastblocken": "kastblock",
    "kastblockens": "kastblock",
    "kastblocket": "kastblock",
    "kastblockets": "kastblock",
    "kastblocks": "kastblock",
    "kastbyar": "kastby",
    "kastbyarna": "kastby",
    "kastbyarnas": "kastby",
    "kastbyars": "kastby",
    "kastbyn": "kastby",
    "kastbyns": "kastby",
    "kastbys": "kastby",
    "kastelden": "kasteld",
    "kasteldens": "kasteld",
    "kastelds": "kasteld",
    "kastellanen": "kastellan",
    "kastellanens": "kastellan",
    "kastellaner": "kastellan",
    "kastellanerna": "kastellan",
    "kastellanernas": "kastellan",
    "kastellaners": "kastellan",
    "kastellans": "kastellan",
    "kastellen": "kastell",
    "kastellens": "kastell",
    "kastellet": "kastell",
    "kastellets": "kastell",
    "kastells": "kastell",
    "kasten": "kast",
    "kastens": "kast",
    "kaster": "kast",
    "kasterna": "kast",
    "kasternas": "kast",
    "kasters": "kast",
    "kastet": "kast",
    "kastets": "kast",
    "kastilianar": "kastilianare",
    "kastilianaren": "kastilianare",
    "kastilianarens": "kastilianare",
    "kastilianares": "kastilianare",
    "kastilianarna": "kastilianare",
    "kastilianarnas": "kastilianare",
    "kastilianen": "kastilian",
    "kastilianens": "kastilian",
    "kastilianer": "kastilian",
    "kastilianerna": "kastilian",
    "kastilianernas": "kastilian",
    "kastilianers": "kastilian",
    "kastilians": "kastilian",
    "kastiliansk": "kastilianska",
    "kastilianska": "kastiliansk",
    "kastilianskan": "kastilianska",
    "kastilianskans": "kastilianska",
    "kastilianskare": "kastiliansk",
    "kastilianskares": "kastiliansk",
    "kastilianskas": "kastilianska",
    "kastilianskast": "kastiliansk",
    "kastilianskaste": "kastiliansk",
    "kastilianskastes": "kastiliansk",
    "kastilianskasts": "kastiliansk",
    "kastilianske": "kastilianska",
    "kastilianskes": "kastiliansk",
    "kastilianskor": "kastilianska",
    "kastilianskorna": "kastilianska",
    "kastilianskornas": "kastilianska",
    "kastilianskors": "kastilianska",
    "kastiliansks": "kastiliansk",
    "kastilianskt": "kastiliansk",
    "kastilianskts": "kastiliansk",
    "kastlösa": "kastlös",
    "kastlösare": "kastlös",
    "kastlösares": "kastlös",
    "kastlösas": "kastlös",
    "kastlösast": "kastlös",
    "kastlösaste": "kastlös",
    "kastlösastes": "kastlös",
    "kastlösasts": "kastlös",
    "kastlöse": "kastlös",
    "kastlöses": "kastlös",
    "kastlösheten": "kastlöshet",
    "kastlöshetens": "kastlöshet",
    "kastlöshets": "kastlöshet",
    "kastlöst": "kastlös",
    "kastlösts": "kastlös",
    "kastmaskinen": "kastmaskin",
    "kastmaskinens": "kastmaskin",
    "kastmaskiner": "kastmaskin",
    "kastmaskinerna": "kastmaskin",
    "kastmaskinernas": "kastmaskin",
    "kastmaskiners": "kastmaskin",
    "kastmaskins": "kastmaskin",
    "kastmärken": "kastmärke",
    "kastmärkena": "kastmärke",
    "kastmärkenas": "kastmärke",
    "kastmärkens": "kastmärke",
    "kastmärkes": "kastmärke",
    "kastmärket": "kastmärke",
    "kastmärkets": "kastmärke",
    "kastoren": "kastor",
    "kastorens": "kastor",
    "kastors": "kastor",
    "kastpjäsen": "kastpjäs",
    "kastpjäsens": "kastpjäs",
    "kastpjäser": "kastpjäs",
    "kastpjäserna": "kastpjäs",
    "kastpjäsernas": "kastpjäs",
    "kastpjäsers": "kastpjäs",
    "kastraten": "kastrat",
    "kastratens": "kastrat",
    "kastrater": "kastrat",
    "kastraterna": "kastrat",
    "kastraternas": "kastrat",
    "kastraters": "kastrat",
    "kastrats": "kastrat",
    "kastratsångar": "kastratsångare",
    "kastratsångaren": "kastratsångare",
    "kastratsångarens": "kastratsångare",
    "kastratsångares": "kastratsångare",
    "kastratsångarna": "kastratsångare",
    "kastratsångarnas": "kastratsångare",
    "kastrerad": "kastrera",
    "kastrerade": "kastrera",
    "kastrerades": "kastrera",
    "kastrerads": "kastrera",
    "kastrerande": "kastrera",
    "kastreranden": "kastrerande",
    "kastrerandena": "kastrerande",
    "kastrerandenas": "kastrerande",
    "kastrerandens": "kastrerande",
    "kastrerandes": "kastrerande",
    "kastrerandet": "kastrerande",
    "kastrerandets": "kastrerande",
    "kastrerar": "kastrera",
    "kastreras": "kastrera",
    "kastrerat": "kastrera",
    "kastrerats": "kastrera",
    "kastrerbara": "kastrerbar",
    "kastrerbarare": "kastrerbar",
    "kastrerbarares": "kastrerbar",
    "kastrerbaras": "kastrerbar",
    "kastrerbarast": "kastrerbar",
    "kastrerbaraste": "kastrerbar",
    "kastrerbarastes": "kastrerbar",
    "kastrerbarasts": "kastrerbar",
    "kastrerbare": "kastrerbar",
    "kastrerbares": "kastrerbar",
    "kastrerbarheten": "kastrerbarhet",
    "kastrerbarhetens": "kastrerbarhet",
    "kastrerbarhets": "kastrerbarhet",
    "kastrerbars": "kastrerbar",
    "kastrerbart": "kastrerbar",
    "kastrerbarts": "kastrerbar",
    "kastreringar": "kastrering",
    "kastreringarna": "kastrering",
    "kastreringarnas": "kastrering",
    "kastreringars": "kastrering",
    "kastreringen": "kastrering",
    "kastreringens": "kastrering",
    "kastrerings": "kastrering",
    "kastrullen": "kastrull",
    "kastrullens": "kastrull",
    "kastruller": "kastrull",
    "kastrullerna": "kastrull",
    "kastrullernas": "kastrull",
    "kastrullers": "kastrull",
    "kastrulls": "kastrull",
    "kasts": "kast",
    "kastsjukan": "kastsjuka",
    "kastsjukans": "kastsjuka",
    "kastsjukas": "kastsjuka",
    "kastsjuke": "kastsjuka",
    "kastsjuks": "kastsjuka",
    "kastskydden": "kastskydd",
    "kastskyddens": "kastskydd",
    "kastskyddet": "kastskydd",
    "kastskyddets": "kastskydd",
    "kastskydds": "kastskydd",
    "kastspjuten": "kastspjut",
    "kastspjutens": "kastspjut",
    "kastspjutet": "kastspjut",
    "kastspjutets": "kastspjut",
    "kastspjuts": "kastspjut",
    "kastspöet": "kastspö",
    "kastspöets": "kastspö",
    "kastspön": "kastspö",
    "kastspöna": "kastspö",
    "kastspönas": "kastspö",
    "kastspöns": "kastspö",
    "kastspös": "kastspö",
    "kastspöt": "kastspö",
    "kastspöts": "kastspö",
    "kaststygnen": "kaststygn",
    "kaststygnens": "kaststygn",
    "kaststygnet": "kaststygn",
    "kaststygnets": "kaststygn",
    "kaststygns": "kaststygn",
    "kastsömmar": "kastsöm",
    "kastsömmarna": "kastsöm",
    "kastsömmarnas": "kastsöm",
    "kastsömmars": "kastsöm",
    "kastsömmen": "kastsöm",
    "kastsömmens": "kastsöm",
    "kastsöms": "kastsöm",
    "kastträet": "kastträ",
    "kastträets": "kastträ",
    "kastträn": "kastträ",
    "kastträna": "kastträ",
    "kasttränas": "kastträ",
    "kastträns": "kastträ",
    "kastträs": "kastträ",
    "kastträt": "kastträ",
    "kastträts": "kastträ",
    "kastvapens": "kastvapen",
    "kastvapnen": "kastvapen",
    "kastvapnens": "kastvapen",
    "kastvapnet": "kastvapen",
    "kastvapnets": "kastvapen",
    "kastvindar": "kastvind",
    "kastvindarna": "kastvind",
    "kastvindarnas": "kastvind",
    "kastvindars": "kastvind",
    "kastvinden": "kastvind",
    "kastvindens": "kastvind",
    "kastvinds": "kastvind",
    "kasuaren": "kasuar",
    "kasuarens": "kasuar",
    "kasuarer": "kasuar",
    "kasuarerna": "kasuar",
    "kasuarernas": "kasuar",
    "kasuarers": "kasuar",
    "kasuars": "kasuar",
    "kasuella": "kasuell",
    "kasuellare": "kasuell",
    "kasuellares": "kasuell",
    "kasuellas": "kasuell",
    "kasuellast": "kasuell",
    "kasuellaste": "kasuell",
    "kasuellastes": "kasuell",
    "kasuellasts": "kasuell",
    "kasuelle": "kasuell",
    "kasuelles": "kasuell",
    "kasuells": "kasuell",
    "kasuellt": "kasuell",
    "kasuellts": "kasuell",
    "kasuistiken": "kasuistik",
    "kasuistikens": "kasuistik",
    "kasuistiks": "kasuistik",
    "kasunen": "kasun",
    "kasunens": "kasun",
    "kasuner": "kasun",
    "kasunerna": "kasun",
    "kasunernas": "kasun",
    "kasuners": "kasun",
    "kasuns": "kasun",
    "kasunsjukan": "kasunsjuka",
    "kasunsjukans": "kasunsjuka",
    "kasunsjukas": "kasunsjuka",
    "kasunsjuke": "kasunsjuka",
    "kasunsjuks": "kasunsjuka",
    "kasusanvändningar": "kasusanvändning",
    "kasusanvändningarna": "kasusanvändning",
    "kasusanvändningarnas": "kasusanvändning",
    "kasusanvändningars": "kasusanvändning",
    "kasusanvändningen": "kasusanvändning",
    "kasusanvändningens": "kasusanvändning",
    "kasusanvändnings": "kasusanvändning",
    "kasusen": "kasus",
    "kasusens": "kasus",
    "kasuset": "kasus",
    "kasusets": "kasus",
    "katabatiska": "katabatisk",
    "katabatiskare": "katabatisk",
    "katabatiskares": "katabatisk",
    "katabatiskas": "katabatisk",
    "katabatiskast": "katabatisk",
    "katabatiskaste": "katabatisk",
    "katabatiskastes": "katabatisk",
    "katabatiskasts": "katabatisk",
    "katabatiske": "katabatisk",
    "katabatiskes": "katabatisk",
    "katabatisks": "katabatisk",
    "katabatiskt": "katabatisk",
    "katabatiskts": "katabatisk",
    "katafalken": "katafalk",
    "katafalkens": "katafalk",
    "katafalker": "katafalk",
    "katafalkerna": "katafalk",
    "katafalkernas": "katafalk",
    "katafalkers": "katafalk",
    "katafalks": "katafalk",
    "kataforiska": "kataforisk",
    "kataforiskare": "kataforisk",
    "kataforiskares": "kataforisk",
    "kataforiskas": "kataforisk",
    "kataforiskast": "kataforisk",
    "kataforiskaste": "kataforisk",
    "kataforiskastes": "kataforisk",
    "kataforiskasts": "kataforisk",
    "kataforiske": "kataforisk",
    "kataforiskes": "kataforisk",
    "kataforisks": "kataforisk",
    "kataforiskt": "kataforisk",
    "kataforiskts": "kataforisk",
    "katakomben": "katakomb",
    "katakombens": "katakomb",
    "katakomber": "katakomb",
    "katakomberna": "katakomb",
    "katakombernas": "katakomb",
    "katakombers": "katakomb",
    "katakombs": "katakomb",
    "katakresen": "katakres",
    "katakresens": "katakres",
    "katakreser": "katakres",
    "katakreserna": "katakres",
    "katakresernas": "katakres",
    "katakresers": "katakres",
    "katalanen": "katalan",
    "katalanens": "katalan",
    "katalaner": "katalan",
    "katalanerna": "katalan",
    "katalanernas": "katalan",
    "katalaners": "katalan",
    "katalans": "katalan",
    "katalansk": "katalanska",
    "katalanska": "katalansk",
    "katalanskan": "katalanska",
    "katalanskans": "katalanska",
    "katalanskare": "katalansk",
    "katalanskares": "katalansk",
    "katalanskas": "katalanska",
    "katalanskast": "katalansk",
    "katalanskaste": "katalansk",
    "katalanskastes": "katalansk",
    "katalanskasts": "katalansk",
    "katalanske": "katalanska",
    "katalanskes": "katalansk",
    "katalanskor": "katalanska",
    "katalanskorna": "katalanska",
    "katalanskornas": "katalanska",
    "katalanskors": "katalanska",
    "katalansks": "katalansk",
    "katalanskt": "katalansk",
    "katalanskts": "katalansk",
    "katalektiska": "katalektisk",
    "katalektiskare": "katalektisk",
    "katalektiskares": "katalektisk",
    "katalektiskas": "katalektisk",
    "katalektiskast": "katalektisk",
    "katalektiskaste": "katalektisk",
    "katalektiskastes": "katalektisk",
    "katalektiskasts": "katalektisk",
    "katalektiske": "katalektisk",
    "katalektiskes": "katalektisk",
    "katalektisks": "katalektisk",
    "katalektiskt": "katalektisk",
    "katalektiskts": "katalektisk",
    "katalepsien": "katalepsi",
    "katalepsiens": "katalepsi",
    "katalepsier": "katalepsi",
    "katalepsierna": "katalepsi",
    "katalepsiernas": "katalepsi",
    "katalepsiers": "katalepsi",
    "katalepsin": "katalepsi",
    "katalepsins": "katalepsi",
    "katalepsis": "katalepsi",
    "katalogen": "katalog",
    "katalogens": "katalog",
    "kataloger": "katalog",
    "katalogerna": "katalog",
    "katalogernas": "katalog",
    "katalogers": "katalog",
    "katalogföretagen": "katalogföretag",
    "katalogföretagens": "katalogföretag",
    "katalogföretaget": "katalogföretag",
    "katalogföretagets": "katalogföretag",
    "katalogföretags": "katalogföretag",
    "katalogiserad": "katalogisera",
    "katalogiserade": "katalogisera",
    "katalogiserades": "katalogisera",
    "katalogiserads": "katalogisera",
    "katalogiserande": "katalogisera",
    "katalogiseranden": "katalogiserande",
    "katalogiserandena": "katalogiserande",
    "katalogiserandenas": "katalogiserande",
    "katalogiserandens": "katalogiserande",
    "katalogiserandes": "katalogiserande",
    "katalogiserandet": "katalogiserande",
    "katalogiserandets": "katalogiserande",
    "katalogiserar": "katalogisera",
    "katalogiseras": "katalogisera",
    "katalogiserat": "katalogisera",
    "katalogiserats": "katalogisera",
    "katalogiserbara": "katalogiserbar",
    "katalogiserbarare": "katalogiserbar",
    "katalogiserbarares": "katalogiserbar",
    "katalogiserbaras": "katalogiserbar",
    "katalogiserbarast": "katalogiserbar",
    "katalogiserbaraste": "katalogiserbar",
    "katalogiserbarastes": "katalogiserbar",
    "katalogiserbarasts": "katalogiserbar",
    "katalogiserbare": "katalogiserbar",
    "katalogiserbares": "katalogiserbar",
    "katalogiserbarheten": "katalogiserbarhet",
    "katalogiserbarhetens": "katalogiserbarhet",
    "katalogiserbarhets": "katalogiserbarhet",
    "katalogiserbars": "katalogiserbar",
    "katalogiserbart": "katalogiserbar",
    "katalogiserbarts": "katalogiserbar",
    "katalogiseringar": "katalogisering",
    "katalogiseringarna": "katalogisering",
    "katalogiseringarnas": "katalogisering",
    "katalogiseringars": "katalogisering",
    "katalogiseringen": "katalogisering",
    "katalogiseringens": "katalogisering",
    "katalogiserings": "katalogisering",
    "kataloglåd": "kataloglåda",
    "kataloglådan": "kataloglåda",
    "kataloglådans": "kataloglåda",
    "kataloglådas": "kataloglåda",
    "kataloglåde": "kataloglåda",
    "kataloglådor": "kataloglåda",
    "kataloglådorna": "kataloglåda",
    "kataloglådornas": "kataloglåda",
    "kataloglådors": "kataloglåda",
    "kataloglåds": "kataloglåda",
    "katalognummerna": "katalognummer",
    "katalognummernas": "katalognummer",
    "katalognummers": "katalognummer",
    "katalognumren": "katalognummer",
    "katalognumrens": "katalognummer",
    "katalognumret": "katalognummer",
    "katalognumrets": "katalognummer",
    "katalogprisen": "katalogpris",
    "katalogprisens": "katalogpris",
    "katalogpriser": "katalogpris",
    "katalogpriserna": "katalogpris",
    "katalogprisernas": "katalogpris",
    "katalogprisers": "katalogpris",
    "katalogpriset": "katalogpris",
    "katalogprisets": "katalogpris",
    "katalogs": "katalog",
    "katalysatorer": "katalysator",
    "katalysatorerna": "katalysator",
    "katalysatorernas": "katalysator",
    "katalysatorers": "katalysator",
    "katalysatorn": "katalysator",
    "katalysatorns": "katalysator",
    "katalysators": "katalysator",
    "katalysen": "katalys",
    "katalysens": "katalys",
    "katalyserad": "katalysera",
    "katalyserade": "katalysera",
    "katalyserades": "katalysera",
    "katalyserads": "katalysera",
    "katalyserande": "katalysera",
    "katalyseranden": "katalyserande",
    "katalyserandena": "katalyserande",
    "katalyserandenas": "katalyserande",
    "katalyserandens": "katalyserande",
    "katalyserandes": "katalyserande",
    "katalyserandet": "katalyserande",
    "katalyserandets": "katalyserande",
    "katalyserar": "katalysera",
    "katalyseras": "katalysera",
    "katalyserat": "katalysera",
    "katalyserats": "katalysera",
    "katalyserbara": "katalyserbar",
    "katalyserbarare": "katalyserbar",
    "katalyserbarares": "katalyserbar",
    "katalyserbaras": "katalyserbar",
    "katalyserbarast": "katalyserbar",
    "katalyserbaraste": "katalyserbar",
    "katalyserbarastes": "katalyserbar",
    "katalyserbarasts": "katalyserbar",
    "katalyserbare": "katalyserbar",
    "katalyserbares": "katalyserbar",
    "katalyserbarheten": "katalyserbarhet",
    "katalyserbarhetens": "katalyserbarhet",
    "katalyserbarhets": "katalyserbarhet",
    "katalyserbars": "katalyserbar",
    "katalyserbart": "katalyserbar",
    "katalyserbarts": "katalyserbar",
    "katalyseringar": "katalysering",
    "katalyseringarna": "katalysering",
    "katalyseringarnas": "katalysering",
    "katalyseringars": "katalysering",
    "katalyseringen": "katalysering",
    "katalyseringens": "katalysering",
    "katalyserings": "katalysering",
    "katalytiska": "katalytisk",
    "katalytiskare": "katalytisk",
    "katalytiskares": "katalytisk",
    "katalytiskas": "katalytisk",
    "katalytiskast": "katalytisk",
    "katalytiskaste": "katalytisk",
    "katalytiskastes": "katalytisk",
    "katalytiskasts": "katalytisk",
    "katalytiske": "katalytisk",
    "katalytiskes": "katalytisk",
    "katalytisks": "katalytisk",
    "katalytiskt": "katalytisk",
    "katalytiskts": "katalytisk",
    "katamaranen": "katamaran",
    "katamaranens": "katamaran",
    "katamaraner": "katamaran",
    "katamaranerna": "katamaran",
    "katamaranernas": "katamaran",
    "katamaraners": "katamaran",
    "katamarans": "katamaran",
    "katapulten": "katapult",
    "katapultens": "katapult",
    "katapulter": "katapult",
    "katapulterna": "katapult",
    "katapulternas": "katapult",
    "katapulters": "katapult",
    "katapults": "katapult",
    "katapultstolar": "katapultstol",
    "katapultstolarna": "katapultstol",
    "katapultstolarnas": "katapultstol",
    "katapultstolars": "katapultstol",
    "katapultstolen": "katapultstol",
    "katapultstolens": "katapultstol",
    "katapultstols": "katapultstol",
    "katarakten": "katarakt",
    "kataraktens": "katarakt",
    "katarakter": "katarakt",
    "katarakterna": "katarakt",
    "katarakternas": "katarakt",
    "katarakters": "katarakt",
    "katarakts": "katarakt",
    "katarren": "katarr",
    "katarrens": "katarr",
    "katarrer": "katarr",
    "katarrerna": "katarr",
    "katarrernas": "katarr",
    "katarrers": "katarr",
    "katarrs": "katarr",
    "katastrofala": "katastrofal",
    "katastrofalare": "katastrofal",
    "katastrofalares": "katastrofal",
    "katastrofalas": "katastrofal",
    "katastrofalast": "katastrofal",
    "katastrofalaste": "katastrofal",
    "katastrofalastes": "katastrofal",
    "katastrofalasts": "katastrofal",
    "katastrofale": "katastrofal",
    "katastrofales": "katastrofal",
    "katastrofals": "katastrofal",
    "katastrofalt": "katastrofal",
    "katastrofalts": "katastrofal",
    "katastrofdrabbade": "katastrofdrabbad",
    "katastrofdrabbades": "katastrofdrabbad",
    "katastrofdrabbads": "katastrofdrabbad",
    "katastrofdrabbat": "katastrofdrabbad",
    "katastrofdrabbats": "katastrofdrabbad",
    "katastrofen": "katastrof",
    "katastrofens": "katastrof",
    "katastrofer": "katastrof",
    "katastroferna": "katastrof",
    "katastrofernas": "katastrof",
    "katastrofers": "katastrof",
    "katastroffilmen": "katastroffilm",
    "katastroffilmens": "katastroffilm",
    "katastroffilmer": "katastroffilm",
    "katastroffilmerna": "katastroffilm",
    "katastroffilmernas": "katastroffilm",
    "katastroffilmers": "katastroffilm",
    "katastroffilms": "katastroffilm",
    "katastrofhanteringen": "katastrofhantering",
    "katastrofhanteringens": "katastrofhantering",
    "katastrofhanterings": "katastrofhantering",
    "katastrofhanteringsmyndigheten": "katastrofhanteringsmyndighet",
    "katastrofhanteringsmyndighetens": "katastrofhanteringsmyndighet",
    "katastrofhanteringsmyndigheter": "katastrofhanteringsmyndighet",
    "katastrofhanteringsmyndigheterna": "katastrofhanteringsmyndighet",
    "katastrofhanteringsmyndigheternas": "katastrofhanteringsmyndighet",
    "katastrofhanteringsmyndigheters": "katastrofhanteringsmyndighet",
    "katastrofhanteringsmyndighets": "katastrofhanteringsmyndighet",
    "katastroflarmen": "katastroflarm",
    "katastroflarmens": "katastroflarm",
    "katastroflarmet": "katastroflarm",
    "katastroflarmets": "katastroflarm",
    "katastroflarms": "katastroflarm",
    "katastroflägen": "katastrofläge",
    "katastroflägena": "katastrofläge",
    "katastroflägenas": "katastrofläge",
    "katastroflägens": "katastrofläge",
    "katastrofläges": "katastrofläge",
    "katastrofläget": "katastrofläge",
    "katastroflägets": "katastrofläge",
    "katastrofs": "katastrof",
    "katastrofscenerier": "katastrofsceneri",
    "katastrofscenerierna": "katastrofsceneri",
    "katastrofsceneriernas": "katastrofsceneri",
    "katastrofsceneriers": "katastrofsceneri",
    "katastrofsceneriet": "katastrofsceneri",
    "katastrofsceneriets": "katastrofsceneri",
    "katastrofsceneris": "katastrofsceneri",
    "katastrofscenerit": "katastrofsceneri",
    "katastrofscenerits": "katastrofsceneri",
    "katastrofsiffer": "katastrofsiffra",
    "katastrofsiffran": "katastrofsiffra",
    "katastrofsiffrans": "katastrofsiffra",
    "katastrofsiffras": "katastrofsiffra",
    "katastrofsiffre": "katastrofsiffra",
    "katastrofsiffror": "katastrofsiffra",
    "katastrofsiffrorna": "katastrofsiffra",
    "katastrofsiffrornas": "katastrofsiffra",
    "katastrofsiffrors": "katastrofsiffra",
    "katastrofsituationen": "katastrofsituation",
    "katastrofsituationens": "katastrofsituation",
    "katastrofsituationer": "katastrofsituation",
    "katastrofsituationerna": "katastrofsituation",
    "katastrofsituationernas": "katastrofsituation",
    "katastrofsituationers": "katastrofsituation",
    "katastrofsituations": "katastrofsituation",
    "katastrofteorien": "katastrofteori",
    "katastrofteoriens": "katastrofteori",
    "katastrofteorier": "katastrofteori",
    "katastrofteorierna": "katastrofteori",
    "katastrofteoriernas": "katastrofteori",
    "katastrofteoriers": "katastrofteori",
    "katastrofteorin": "katastrofteori",
    "katastrofteorins": "katastrofteori",
    "katastrofteoris": "katastrofteori",
    "katastrofvarningar": "katastrofvarning",
    "katastrofvarningarna": "katastrofvarning",
    "katastrofvarningarnas": "katastrofvarning",
    "katastrofvarningars": "katastrofvarning",
    "katastrofvarningen": "katastrofvarning",
    "katastrofvarningens": "katastrofvarning",
    "katastrofvarnings": "katastrofvarning",
    "katatonien": "katatoni",
    "katatoniens": "katatoni",
    "katatonin": "katatoni",
    "katatonins": "katatoni",
    "katatonis": "katatoni",
    "katedern": "kateder",
    "katederns": "kateder",
    "kateders": "kateder",
    "katedersocialismen": "katedersocialism",
    "katedersocialismens": "katedersocialism",
    "katedersocialismer": "katedersocialism",
    "katedersocialismerna": "katedersocialism",
    "katedersocialismernas": "katedersocialism",
    "katedersocialismers": "katedersocialism",
    "katedersocialisms": "katedersocialism",
    "katedersocialistiska": "katedersocialistisk",
    "katedersocialistiskas": "katedersocialistisk",
    "katedersocialistiske": "katedersocialistisk",
    "katedersocialistiskes": "katedersocialistisk",
    "katedersocialistisks": "katedersocialistisk",
    "katedersocialistiskt": "katedersocialistisk",
    "katedersocialistiskts": "katedersocialistisk",
    "katederundervisningar": "katederundervisning",
    "katederundervisningarna": "katederundervisning",
    "katederundervisningarnas": "katederundervisning",
    "katederundervisningars": "katederundervisning",
    "katederundervisningen": "katederundervisning",
    "katederundervisningens": "katederundervisning",
    "katederundervisnings": "katederundervisning",
    "katedralen": "katedral",
    "katedralens": "katedral",
    "katedraler": "katedral",
    "katedralerna": "katedral",
    "katedralernas": "katedral",
    "katedralers": "katedral",
    "katedrals": "katedral",
    "katedralsklock": "katedralsklocka",
    "katedralsklockan": "katedralsklocka",
    "katedralsklockans": "katedralsklocka",
    "katedralsklockas": "katedralsklocka",
    "katedralsklocke": "katedralsklocka",
    "katedralsklockor": "katedralsklocka",
    "katedralsklockorna": "katedralsklocka",
    "katedralsklockornas": "katedralsklocka",
    "katedralsklockors": "katedralsklocka",
    "katedralsklocks": "katedralsklocka",
    "katedralskolan": "katedralskola",
    "katedralskolans": "katedralskola",
    "katedralskolas": "katedralskola",
    "katedralskole": "katedralskola",
    "katedralskolor": "katedralskola",
    "katedralskolorna": "katedralskola",
    "katedralskolornas": "katedralskola",
    "katedralskolors": "katedralskola",
    "katedrar": "kateder",
    "katedrarna": "kateder",
    "katedrarnas": "kateder",
    "katedrars": "kateder",
    "kategorien": "kategori",
    "kategoriens": "kategori",
    "kategorier": "kategori",
    "kategorierna": "kategori",
    "kategoriernas": "kategori",
    "kategoriers": "kategori",
    "kategoriklyvningar": "kategoriklyvning",
    "kategoriklyvningarna": "kategoriklyvning",
    "kategoriklyvningarnas": "kategoriklyvning",
    "kategoriklyvningars": "kategoriklyvning",
    "kategoriklyvningen": "kategoriklyvning",
    "kategoriklyvningens": "kategoriklyvning",
    "kategoriklyvnings": "kategoriklyvning",
    "kategorin": "kategori",
    "kategorins": "kategori",
    "kategoris": "kategori",
    "kategoriserad": "kategorisera",
    "kategoriserade": "kategorisera",
    "kategoriserades": "kategorisera",
    "kategoriserads": "kategorisera",
    "kategoriserande": "kategorisera",
    "kategoriseranden": "kategoriserande",
    "kategoriserandena": "kategoriserande",
    "kategoriserandenas": "kategoriserande",
    "kategoriserandens": "kategoriserande",
    "kategoriserandes": "kategoriserande",
    "kategoriserandet": "kategoriserande",
    "kategoriserandets": "kategoriserande",
    "kategoriserar": "kategorisera",
    "kategoriseras": "kategorisera",
    "kategoriserat": "kategorisera",
    "kategoriserats": "kategorisera",
    "kategoriserbara": "kategoriserbar",
    "kategoriserbarare": "kategoriserbar",
    "kategoriserbarares": "kategoriserbar",
    "kategoriserbaras": "kategoriserbar",
    "kategoriserbarast": "kategoriserbar",
    "kategoriserbaraste": "kategoriserbar",
    "kategoriserbarastes": "kategoriserbar",
    "kategoriserbarasts": "kategoriserbar",
    "kategoriserbare": "kategoriserbar",
    "kategoriserbares": "kategoriserbar",
    "kategoriserbarheten": "kategoriserbarhet",
    "kategoriserbarhetens": "kategoriserbarhet",
    "kategoriserbarhets": "kategoriserbarhet",
    "kategoriserbars": "kategoriserbar",
    "kategoriserbart": "kategoriserbar",
    "kategoriserbarts": "kategoriserbar",
    "kategoriseringar": "kategorisering",
    "kategoriseringarna": "kategorisering",
    "kategoriseringarnas": "kategorisering",
    "kategoriseringars": "kategorisering",
    "kategoriseringen": "kategorisering",
    "kategoriseringens": "kategorisering",
    "kategoriserings": "kategorisering",
    "kategoriska": "kategorisk",
    "kategoriskare": "kategorisk",
    "kategoriskares": "kategorisk",
    "kategoriskas": "kategorisk",
    "kategoriskast": "kategorisk",
    "kategoriskaste": "kategorisk",
    "kategoriskastes": "kategorisk",
    "kategoriskasts": "kategorisk",
    "kategoriske": "kategorisk",
    "kategoriskes": "kategorisk",
    "kategorisks": "kategorisk",
    "kategoriskt": "kategorisk",
    "kategoriskts": "kategorisk",
    "katekesen": "katekes",
    "katekesens": "katekes",
    "katekeser": "katekes",
    "katekeserna": "katekes",
    "katekesernas": "katekes",
    "katekesers": "katekes",
    "katekesstycken": "katekesstycke",
    "katekesstyckena": "katekesstycke",
    "katekesstyckenas": "katekesstycke",
    "katekesstyckens": "katekesstycke",
    "katekesstyckes": "katekesstycke",
    "katekesstycket": "katekesstycke",
    "katekesstyckets": "katekesstycke",
    "katekesstycks": "katekesstycke",
    "kateketen": "kateket",
    "kateketens": "kateket",
    "kateketer": "kateket",
    "kateketerna": "kateket",
    "kateketernas": "kateket",
    "kateketers": "kateket",
    "kateketiska": "kateketisk",
    "kateketiskare": "kateketisk",
    "kateketiskares": "kateketisk",
    "kateketiskas": "kateketisk",
    "kateketiskast": "kateketisk",
    "kateketiskaste": "kateketisk",
    "kateketiskastes": "kateketisk",
    "kateketiskasts": "kateketisk",
    "kateketiske": "kateketisk",
    "kateketiskes": "kateketisk",
    "kateketisks": "kateketisk",
    "kateketiskt": "kateketisk",
    "kateketiskts": "kateketisk",
    "katekets": "kateket",
    "katen": "kat",
    "katens": "kat",
    "katet": "kat",
    "kateten": "katet",
    "katetens": "katet",
    "kateter": "katet",
    "kateteriserad": "kateterisera",
    "kateteriserade": "kateterisera",
    "kateteriserades": "kateterisera",
    "kateteriserads": "kateterisera",
    "kateteriserande": "kateterisera",
    "kateteriseranden": "kateteriserande",
    "kateteriserandena": "kateteriserande",
    "kateteriserandenas": "kateteriserande",
    "kateteriserandens": "kateteriserande",
    "kateteriserandes": "kateteriserande",
    "kateteriserandet": "kateteriserande",
    "kateteriserandets": "kateteriserande",
    "kateteriserar": "kateterisera",
    "kateteriseras": "kateterisera",
    "kateteriserat": "kateterisera",
    "kateteriserats": "kateterisera",
    "kateteriserbara": "kateteriserbar",
    "kateteriserbarare": "kateteriserbar",
    "kateteriserbarares": "kateteriserbar",
    "kateteriserbaras": "kateteriserbar",
    "kateteriserbarast": "kateteriserbar",
    "kateteriserbaraste": "kateteriserbar",
    "kateteriserbarastes": "kateteriserbar",
    "kateteriserbarasts": "kateteriserbar",
    "kateteriserbare": "kateteriserbar",
    "kateteriserbares": "kateteriserbar",
    "kateteriserbarheten": "kateteriserbarhet",
    "kateteriserbarhetens": "kateteriserbarhet",
    "kateteriserbarhets": "kateteriserbarhet",
    "kateteriserbars": "kateteriserbar",
    "kateteriserbart": "kateteriserbar",
    "kateteriserbarts": "kateteriserbar",
    "kateteriseringar": "kateterisering",
    "kateteriseringarna": "kateterisering",
    "kateteriseringarnas": "kateterisering",
    "kateteriseringars": "kateterisering",
    "kateteriseringen": "kateterisering",
    "kateteriseringens": "kateterisering",
    "kateteriserings": "kateterisering",
    "katetern": "kateter",
    "kateterna": "katet",
    "kateternas": "katet",
    "kateterns": "kateter",
    "kateters": "kateter",
    "katetrar": "kateter",
    "katetrarna": "kateter",
    "katetrarnas": "kateter",
    "katetrars": "kateter",
    "katetriserad": "katetrisera",
    "katetriserade": "katetrisera",
    "katetriserades": "katetrisera",
    "katetriserads": "katetrisera",
    "katetriserande": "katetrisera",
    "katetriseranden": "katetriserande",
    "katetriserandena": "katetriserande",
    "katetriserandenas": "katetriserande",
    "katetriserandens": "katetriserande",
    "katetriserandes": "katetriserande",
    "katetriserandet": "katetriserande",
    "katetriserandets": "katetriserande",
    "katetriserar": "katetrisera",
    "katetriseras": "katetrisera",
    "katetriserat": "katetrisera",
    "katetriserats": "katetrisera",
    "katetriserbara": "katetriserbar",
    "katetriserbarare": "katetriserbar",
    "katetriserbarares": "katetriserbar",
    "katetriserbaras": "katetriserbar",
    "katetriserbarast": "katetriserbar",
    "katetriserbaraste": "katetriserbar",
    "katetriserbarastes": "katetriserbar",
    "katetriserbarasts": "katetriserbar",
    "katetriserbare": "katetriserbar",
    "katetriserbares": "katetriserbar",
    "katetriserbarheten": "katetriserbarhet",
    "katetriserbarhetens": "katetriserbarhet",
    "katetriserbarhets": "katetriserbarhet",
    "katetriserbars": "katetriserbar",
    "katetriserbart": "katetriserbar",
    "katetriserbarts": "katetriserbar",
    "katetriseringar": "katetrisering",
    "katetriseringarna": "katetrisering",
    "katetriseringarnas": "katetrisering",
    "katetriseringars": "katetrisering",
    "katetriseringen": "katetrisering",
    "katetriseringens": "katetrisering",
    "katetriserings": "katetrisering",
    "katets": "katet",
    "katguten": "katgut",
    "katgutens": "katgut",
    "katguts": "katgut",
    "katiga": "katig",
    "katigare": "katig",
    "katigares": "katig",
    "katigas": "katig",
    "katigast": "katig",
    "katigaste": "katig",
    "katigastes": "katig",
    "katigasts": "katig",
    "katige": "katig",
    "katiges": "katig",
    "katigs": "katig",
    "katigt": "katig",
    "katigts": "katig",
    "katjonen": "katjon",
    "katjonens": "katjon",
    "katjoner": "katjon",
    "katjonerna": "katjon",
    "katjonernas": "katjon",
    "katjoners": "katjon",
    "katjons": "katjon",
    "katoden": "katod",
    "katodens": "katod",
    "katoder": "katod",
    "katoderna": "katod",
    "katodernas": "katod",
    "katoders": "katod",
    "katods": "katod",
    "katodstrål": "katodstråle",
    "katodstrålar": "katodstråle",
    "katodstrålarna": "katodstråle",
    "katodstrålarnas": "katodstråle",
    "katodstrålars": "katodstråle",
    "katodstrålen": "katodstråle",
    "katodstrålens": "katodstråle",
    "katodstrålerören": "katodstrålerör",
    "katodstrålerörens": "katodstrålerör",
    "katodstråleröret": "katodstrålerör",
    "katodstrålerörets": "katodstrålerör",
    "katodstrålerörs": "katodstrålerör",
    "katodstråles": "katodstråle",
    "katodstråls": "katodstråle",
    "katolicismen": "katolicism",
    "katolicismens": "katolicism",
    "katolicismer": "katolicism",
    "katolicismerna": "katolicism",
    "katolicismernas": "katolicism",
    "katolicismers": "katolicism",
    "katolicisms": "katolicism",
    "katoliken": "katolik",
    "katolikens": "katolik",
    "katoliker": "katolik",
    "katolikerna": "katolik",
    "katolikernas": "katolik",
    "katolikers": "katolik",
    "katoliks": "katolik",
    "katolska": "katolsk",
    "katolskare": "katolsk",
    "katolskares": "katolsk",
    "katolskas": "katolsk",
    "katolskast": "katolsk",
    "katolskaste": "katolsk",
    "katolskastes": "katolsk",
    "katolskasts": "katolsk",
    "katolske": "katolsk",
    "katolskes": "katolsk",
    "katolsks": "katolsk",
    "katolskt": "katolsk",
    "katolskts": "katolsk",
    "katrinplommonen": "katrinplommon",
    "katrinplommonens": "katrinplommon",
    "katrinplommonet": "katrinplommon",
    "katrinplommonets": "katrinplommon",
    "katrinplommons": "katrinplommon",
    "kats": "katse",
    "katsan": "katsa",
    "katsans": "katsa",
    "katsar": "katse",
    "katsarna": "katse",
    "katsarnas": "katse",
    "katsars": "katse",
    "katsas": "katsa",
    "katse": "katsa",
    "katsen": "katse",
    "katsenjammern": "katsenjammer",
    "katsenjammerns": "katsenjammer",
    "katsenjammers": "katsenjammer",
    "katsens": "katse",
    "katses": "katse",
    "katsor": "katsa",
    "katsorna": "katsa",
    "katsornas": "katsa",
    "katsors": "katsa",
    "katt": "katta",
    "kattad": "katta",
    "kattade": "katta",
    "kattades": "katta",
    "kattads": "katta",
    "kattaktiga": "kattaktig",
    "kattaktigare": "kattaktig",
    "kattaktigares": "kattaktig",
    "kattaktigas": "kattaktig",
    "kattaktigast": "kattaktig",
    "kattaktigaste": "kattaktig",
    "kattaktigastes": "kattaktig",
    "kattaktigasts": "kattaktig",
    "kattaktige": "kattaktig",
    "kattaktiges": "kattaktig",
    "kattaktigheten": "kattaktighet",
    "kattaktighetens": "kattaktighet",
    "kattaktighets": "kattaktighet",
    "kattaktigs": "kattaktig",
    "kattaktigt": "kattaktig",
    "kattaktigts": "kattaktig",
    "kattan": "katta",
    "kattande": "katta",
    "kattanden": "kattande",
    "kattandena": "kattande",
    "kattandenas": "kattande",
    "kattandens": "kattande",
    "kattandes": "kattande",
    "kattandet": "kattande",
    "kattandets": "kattande",
    "kattans": "katta",
    "kattar": "katta",
    "kattas": "katta",
    "kattassar": "kattass",
    "kattassarna": "kattass",
    "kattassarnas": "kattass",
    "kattassars": "kattass",
    "kattassen": "kattass",
    "kattassens": "kattass",
    "kattat": "katta",
    "kattats": "katta",
    "kattdjuren": "kattdjur",
    "kattdjurens": "kattdjur",
    "kattdjuret": "kattdjur",
    "kattdjurets": "kattdjur",
    "kattdjurs": "kattdjur",
    "katte": "katta",
    "katten": "katt",
    "kattens": "katten",
    "katter": "katt",
    "katterna": "katt",
    "katternas": "katt",
    "katters": "katt",
    "kattfoten": "kattfot",
    "kattfotens": "kattfot",
    "kattfots": "kattfot",
    "kattgin": "kattgina",
    "kattginan": "kattgina",
    "kattginans": "kattgina",
    "kattginas": "kattgina",
    "kattgine": "kattgina",
    "kattginor": "kattgina",
    "kattginorna": "kattgina",
    "kattginornas": "kattgina",
    "kattginors": "kattgina",
    "kattgins": "kattgina",
    "kattguldet": "kattguld",
    "kattguldets": "kattguld",
    "kattgulds": "kattguld",
    "katthåren": "katthår",
    "katthårens": "katthår",
    "katthåret": "katthår",
    "katthårets": "katthår",
    "katthårs": "katthår",
    "kattmaten": "kattmat",
    "kattmatens": "kattmat",
    "kattmats": "kattmat",
    "kattmyntan": "kattmynta",
    "kattmyntans": "kattmynta",
    "kattmyntas": "kattmynta",
    "kattoaletten": "kattoalett",
    "kattoalettens": "kattoalett",
    "kattoaletter": "kattoalett",
    "kattoaletterna": "kattoalett",
    "kattoaletternas": "kattoalett",
    "kattoaletters": "kattoalett",
    "kattoaletts": "kattoalett",
    "kattor": "katta",
    "kattorna": "katta",
    "kattornas": "katta",
    "kattors": "katta",
    "kattosten": "kattost",
    "kattostens": "kattost",
    "kattosts": "kattost",
    "kattpesten": "kattpest",
    "kattpestens": "kattpest",
    "kattpests": "kattpest",
    "kattrakandes": "kattrakande",
    "kattrakandet": "kattrakande",
    "kattrakandets": "kattrakande",
    "kattrasen": "kattras",
    "kattrasens": "kattras",
    "kattraser": "kattras",
    "kattraserna": "kattras",
    "kattrasernas": "kattras",
    "kattrasers": "kattras",
    "katts": "katta",
    "kattsanden": "kattsand",
    "kattsandens": "kattsand",
    "kattsands": "kattsand",
    "kattsilvers": "kattsilver",
    "kattsilvret": "kattsilver",
    "kattsilvrets": "kattsilver",
    "kattugglan": "kattuggla",
    "kattugglans": "kattuggla",
    "kattugglas": "kattuggla",
    "kattuggle": "kattuggla",
    "kattugglor": "kattuggla",
    "kattugglorna": "kattuggla",
    "kattugglornas": "kattuggla",
    "kattugglors": "kattuggla",
    "kattunen": "kattun",
    "kattunens": "kattun",
    "kattuner": "kattun",
    "kattunerna": "kattun",
    "kattunernas": "kattun",
    "kattuners": "kattun",
    "kattunet": "kattun",
    "kattunets": "kattun",
    "kattungar": "kattunge",
    "kattungarna": "kattunge",
    "kattungarnas": "kattunge",
    "kattungars": "kattunge",
    "kattungen": "kattunge",
    "kattungens": "kattunge",
    "kattunges": "kattunge",
    "kattuns": "kattun",
    "kattögas": "kattöga",
    "kattögat": "kattöga",
    "kattögats": "kattöga",
    "kattögon": "kattöga",
    "kattögonen": "kattöga",
    "kattögonens": "kattöga",
    "kattögons": "kattöga",
    "katzenjammern": "katzenjammer",
    "katzenjammerns": "katzenjammer",
    "katzenjammers": "katzenjammer",
    "kaukasiern": "kaukasier",
    "kaukasierna": "kaukasier",
    "kaukasiernas": "kaukasier",
    "kaukasierns": "kaukasier",
    "kaukasiers": "kaukasier",
    "kaukasiska": "kaukasisk",
    "kaukasiskan": "kaukasiska",
    "kaukasiskans": "kaukasiska",
    "kaukasiskare": "kaukasisk",
    "kaukasiskares": "kaukasisk",
    "kaukasiskas": "kaukasiska",
    "kaukasiskast": "kaukasisk",
    "kaukasiskaste": "kaukasisk",
    "kaukasiskastes": "kaukasisk",
    "kaukasiskasts": "kaukasisk",
    "kaukasiske": "kaukasiska",
    "kaukasiskes": "kaukasisk",
    "kaukasiskor": "kaukasiska",
    "kaukasiskorna": "kaukasiska",
    "kaukasiskornas": "kaukasiska",
    "kaukasiskors": "kaukasiska",
    "kaukasisks": "kaukasisk",
    "kaukasiskt": "kaukasisk",
    "kaukasiskts": "kaukasisk",
    "kaurier": "kauri",
    "kaurierna": "kauri",
    "kauriernas": "kauri",
    "kauriers": "kauri",
    "kaurin": "kauri",
    "kaurins": "kauri",
    "kauris": "kauri",
    "kausala": "kausal",
    "kausalare": "kausal",
    "kausalares": "kausal",
    "kausalas": "kausal",
    "kausalast": "kausal",
    "kausalaste": "kausal",
    "kausalastes": "kausal",
    "kausalasts": "kausal",
    "kausale": "kausal",
    "kausales": "kausal",
    "kausalförhållanden": "kausalförhållande",
    "kausalförhållandena": "kausalförhållande",
    "kausalförhållandenas": "kausalförhållande",
    "kausalförhållandens": "kausalförhållande",
    "kausalförhållandes": "kausalförhållande",
    "kausalförhållandet": "kausalförhållande",
    "kausalförhållandets": "kausalförhållande",
    "kausaliteten": "kausalitet",
    "kausalitetens": "kausalitet",
    "kausaliteter": "kausalitet",
    "kausaliteterna": "kausalitet",
    "kausaliteternas": "kausalitet",
    "kausaliteters": "kausalitet",
    "kausalitets": "kausalitet",
    "kausals": "kausal",
    "kausalsatsen": "kausalsats",
    "kausalsatsens": "kausalsats",
    "kausalsatser": "kausalsats",
    "kausalsatserna": "kausalsats",
    "kausalsatsernas": "kausalsats",
    "kausalsatsers": "kausalsats",
    "kausalt": "kausal",
    "kausalts": "kausal",
    "kausativa": "kausativ",
    "kausativare": "kausativ",
    "kausativares": "kausativ",
    "kausativas": "kausativ",
    "kausativast": "kausativ",
    "kausativaste": "kausativ",
    "kausativastes": "kausativ",
    "kausativasts": "kausativ",
    "kausative": "kausativ",
    "kausatives": "kausativ",
    "kausativs": "kausativ",
    "kausativt": "kausativ",
    "kausativts": "kausativ",
    "kausen": "kaus",
    "kausens": "kaus",
    "kauser": "kaus",
    "kauserna": "kaus",
    "kausernas": "kaus",
    "kausers": "kaus",
    "kaustika": "kaustik",
    "kaustikan": "kaustika",
    "kaustikans": "kaustika",
    "kaustikare": "kaustik",
    "kaustikares": "kaustik",
    "kaustikas": "kaustika",
    "kaustikast": "kaustik",
    "kaustikaste": "kaustik",
    "kaustikastes": "kaustik",
    "kaustikasts": "kaustik",
    "kaustike": "kaustik",
    "kaustikes": "kaustik",
    "kaustikor": "kaustika",
    "kaustikorna": "kaustika",
    "kaustikornas": "kaustika",
    "kaustikors": "kaustika",
    "kaustiks": "kaustik",
    "kaustikt": "kaustik",
    "kaustikts": "kaustik",
    "kauteriserad": "kauterisera",
    "kauteriserade": "kauterisera",
    "kauteriserades": "kauterisera",
    "kauteriserads": "kauterisera",
    "kauteriserande": "kauterisera",
    "kauteriseranden": "kauteriserande",
    "kauteriserandena": "kauteriserande",
    "kauteriserandenas": "kauteriserande",
    "kauteriserandens": "kauteriserande",
    "kauteriserandes": "kauteriserande",
    "kauteriserandet": "kauteriserande",
    "kauteriserandets": "kauteriserande",
    "kauteriserar": "kauterisera",
    "kauteriseras": "kauterisera",
    "kauteriserat": "kauterisera",
    "kauteriserats": "kauterisera",
    "kauteriserbara": "kauteriserbar",
    "kauteriserbarare": "kauteriserbar",
    "kauteriserbarares": "kauteriserbar",
    "kauteriserbaras": "kauteriserbar",
    "kauteriserbarast": "kauteriserbar",
    "kauteriserbaraste": "kauteriserbar",
    "kauteriserbarastes": "kauteriserbar",
    "kauteriserbarasts": "kauteriserbar",
    "kauteriserbare": "kauteriserbar",
    "kauteriserbares": "kauteriserbar",
    "kauteriserbarheten": "kauteriserbarhet",
    "kauteriserbarhetens": "kauteriserbarhet",
    "kauteriserbarhets": "kauteriserbarhet",
    "kauteriserbars": "kauteriserbar",
    "kauteriserbart": "kauteriserbar",
    "kauteriserbarts": "kauteriserbar",
    "kauteriseringar": "kauterisering",
    "kauteriseringarna": "kauterisering",
    "kauteriseringarnas": "kauterisering",
    "kauteriseringars": "kauterisering",
    "kauteriseringen": "kauterisering",
    "kauteriseringens": "kauterisering",
    "kauteriserings": "kauterisering",
    "kautionen": "kaution",
    "kautionens": "kaution",
    "kautioner": "kaution",
    "kautionerna": "kaution",
    "kautionernas": "kaution",
    "kautioners": "kaution",
    "kautions": "kaution",
    "kautschukar": "kautschuk",
    "kautschukarna": "kautschuk",
    "kautschukarnas": "kautschuk",
    "kautschukars": "kautschuk",
    "kautschuken": "kautschuk",
    "kautschukens": "kautschuk",
    "kautschukparagrafen": "kautschukparagraf",
    "kautschukparagrafens": "kautschukparagraf",
    "kautschukparagrafer": "kautschukparagraf",
    "kautschukparagraferna": "kautschukparagraf",
    "kautschukparagrafernas": "kautschukparagraf",
    "kautschukparagrafers": "kautschukparagraf",
    "kautschukparagrafs": "kautschukparagraf",
    "kautschuks": "kautschuk",
    "kautschukträden": "kautschukträd",
    "kautschukträdens": "kautschukträd",
    "kautschukträdet": "kautschukträd",
    "kautschukträdets": "kautschukträd",
    "kautschukträds": "kautschukträd",
    "kautschukträn": "kautschukträd",
    "kautschukträna": "kautschukträd",
    "kautschuktränas": "kautschukträd",
    "kautschukträns": "kautschukträd",
    "kav": "kava",
    "kavade": "kava",
    "kavades": "kava",
    "kavajen": "kavaj",
    "kavajens": "kavaj",
    "kavajer": "kavaj",
    "kavajerna": "kavaj",
    "kavajernas": "kavaj",
    "kavajers": "kavaj",
    "kavajfick": "kavajficka",
    "kavajfickan": "kavajficka",
    "kavajfickans": "kavajficka",
    "kavajfickas": "kavajficka",
    "kavajficke": "kavajficka",
    "kavajfickor": "kavajficka",
    "kavajfickorna": "kavajficka",
    "kavajfickornas": "kavajficka",
    "kavajfickors": "kavajficka",
    "kavajficks": "kavajficka",
    "kavajkrag": "kavajkrage",
    "kavajkragar": "kavajkrage",
    "kavajkragarna": "kavajkrage",
    "kavajkragarnas": "kavajkrage",
    "kavajkragars": "kavajkrage",
    "kavajkragen": "kavajkrage",
    "kavajkragens": "kavajkrage",
    "kavajkrages": "kavajkrage",
    "kavajkrags": "kavajkrage",
    "kavajs": "kavaj",
    "kavaletten": "kavalett",
    "kavalettens": "kavalett",
    "kavaletter": "kavalett",
    "kavaletterna": "kavalett",
    "kavaletternas": "kavalett",
    "kavaletters": "kavalett",
    "kavaletts": "kavalett",
    "kavaljeren": "kavaljer",
    "kavaljerens": "kavaljer",
    "kavaljerer": "kavaljer",
    "kavaljererna": "kavaljer",
    "kavaljerernas": "kavaljer",
    "kavaljerers": "kavaljer",
    "kavaljern": "kavaljer",
    "kavaljerns": "kavaljer",
    "kavaljers": "kavaljer",
    "kavaljersflygeln": "kavaljersflygel",
    "kavaljersflygelns": "kavaljersflygel",
    "kavaljersflygels": "kavaljersflygel",
    "kavaljersflyglar": "kavaljersflygel",
    "kavaljersflyglarna": "kavaljersflygel",
    "kavaljersflyglarnas": "kavaljersflygel",
    "kavaljersflyglars": "kavaljersflygel",
    "kavalkaden": "kavalkad",
    "kavalkadens": "kavalkad",
    "kavalkader": "kavalkad",
    "kavalkaderna": "kavalkad",
    "kavalkadernas": "kavalkad",
    "kavalkaders": "kavalkad",
    "kavalkads": "kavalkad",
    "kavallen": "kavall",
    "kavallens": "kavall",
    "kavaller": "kavall",
    "kavallerichocken": "kavallerichock",
    "kavallerichockens": "kavallerichock",
    "kavallerichocker": "kavallerichock",
    "kavallerichockerna": "kavallerichock",
    "kavallerichockernas": "kavallerichock",
    "kavallerichockers": "kavallerichock",
    "kavallerichocks": "kavallerichock",
    "kavallerier": "kavalleri",
    "kavallerierna": "kavalleri",
    "kavalleriernas": "kavalleri",
    "kavalleriers": "kavalleri",
    "kavalleriet": "kavalleri",
    "kavalleriets": "kavalleri",
    "kavalleriofficerare": "kavalleriofficer",
    "kavalleriofficerares": "kavalleriofficer",
    "kavalleriofficerarna": "kavalleriofficer",
    "kavalleriofficerarnas": "kavalleriofficer",
    "kavalleriofficeren": "kavalleriofficer",
    "kavalleriofficerens": "kavalleriofficer",
    "kavalleriofficern": "kavalleriofficer",
    "kavalleriofficerns": "kavalleriofficer",
    "kavalleriofficers": "kavalleriofficer",
    "kavalleris": "kavalleri",
    "kavalleristen": "kavallerist",
    "kavalleristens": "kavallerist",
    "kavallerister": "kavallerist",
    "kavalleristerna": "kavallerist",
    "kavalleristernas": "kavallerist",
    "kavalleristers": "kavallerist",
    "kavallerists": "kavallerist",
    "kavallerit": "kavalleri",
    "kavalleritruppen": "kavalleritrupp",
    "kavalleritruppens": "kavalleritrupp",
    "kavalleritrupper": "kavalleritrupp",
    "kavalleritrupperna": "kavalleritrupp",
    "kavalleritruppernas": "kavalleritrupp",
    "kavalleritruppers": "kavalleritrupp",
    "kavalleritrupps": "kavalleritrupp",
    "kavallerits": "kavalleri",
    "kavallerna": "kavall",
    "kavallernas": "kavall",
    "kavallers": "kavall",
    "kavalls": "kavall",
    "kavande": "kava",
    "kavanden": "kavande",
    "kavandena": "kavande",
    "kavandenas": "kavande",
    "kavandens": "kavande",
    "kavandes": "kavande",
    "kavandet": "kavande",
    "kavandets": "kavande",
    "kavar": "kava",
    "kavas": "kava",
    "kavat": "kava",
    "kavata": "kavat",
    "kavatare": "kavat",
    "kavatares": "kavat",
    "kavatas": "kavat",
    "kavatast": "kavat",
    "kavataste": "kavat",
    "kavatastes": "kavat",
    "kavatasts": "kavat",
    "kavate": "kavat",
    "kavates": "kavat",
    "kavats": "kavat",
    "kavel": "kavla",
    "kavelbroar": "kavelbro",
    "kavelbroarna": "kavelbro",
    "kavelbroarnas": "kavelbro",
    "kavelbroars": "kavelbro",
    "kavelbron": "kavelbro",
    "kavelbrons": "kavelbro",
    "kavelbros": "kavelbro",
    "kaveldunet": "kaveldun",
    "kaveldunets": "kaveldun",
    "kavelduns": "kaveldun",
    "kaveln": "kavel",
    "kavelns": "kavel",
    "kavels": "kavel",
    "kavernen": "kavern",
    "kavernens": "kavern",
    "kaverner": "kavern",
    "kavernerna": "kavern",
    "kavernernas": "kavern",
    "kaverners": "kavern",
    "kaverns": "kavern",
    "kaviaren": "kaviar",
    "kaviarens": "kaviar",
    "kaviarn": "kaviar",
    "kaviarns": "kaviar",
    "kaviars": "kaviar",
    "kavitationen": "kavitation",
    "kavitationens": "kavitation",
    "kavitationer": "kavitation",
    "kavitationerna": "kavitation",
    "kavitationernas": "kavitation",
    "kavitationers": "kavitation",
    "kavitations": "kavitation",
    "kaviteten": "kavitet",
    "kavitetens": "kavitet",
    "kaviteter": "kavitet",
    "kaviteterna": "kavitet",
    "kaviteternas": "kavitet",
    "kaviteters": "kavitet",
    "kavitets": "kavitet",
    "kavitetsdjuren": "kavitetsdjur",
    "kavitetsdjurens": "kavitetsdjur",
    "kavitetsdjuret": "kavitetsdjur",
    "kavitetsdjurets": "kavitetsdjur",
    "kavitetsdjurs": "kavitetsdjur",
    "kavl": "kavle",
    "kavlad": "kavla",
    "kavlade": "kavla",
    "kavlades": "kavla",
    "kavlads": "kavla",
    "kavlande": "kavla",
    "kavlanden": "kavlande",
    "kavlandena": "kavlande",
    "kavlandenas": "kavlande",
    "kavlandens": "kavlande",
    "kavlandes": "kavlande",
    "kavlandet": "kavlande",
    "kavlandets": "kavlande",
    "kavlar": "kavle",
    "kavlarna": "kavle",
    "kavlarnas": "kavle",
    "kavlars": "kavle",
    "kavlas": "kavla",
    "kavlat": "kavla",
    "kavlats": "kavla",
    "kavlen": "kavle",
    "kavlens": "kavle",
    "kavles": "kavle",
    "kavls": "kavle",
    "kavringar": "kavring",
    "kavringarna": "kavring",
    "kavringarnas": "kavring",
    "kavringars": "kavring",
    "kavringen": "kavring",
    "kavringens": "kavring",
    "kavrings": "kavring",
    "kax": "kaxe",
    "kaxar": "kaxe",
    "kaxarna": "kaxe",
    "kaxarnas": "kaxe",
    "kaxars": "kaxe",
    "kaxen": "kaxe",
    "kaxens": "kaxe",
    "kaxes": "kaxe",
    "kaxiga": "kaxig",
    "kaxigare": "kaxig",
    "kaxigares": "kaxig",
    "kaxigas": "kaxig",
    "kaxigast": "kaxig",
    "kaxigaste": "kaxig",
    "kaxigastes": "kaxig",
    "kaxigasts": "kaxig",
    "kaxige": "kaxig",
    "kaxiges": "kaxig",
    "kaxigs": "kaxig",
    "kaxigt": "kaxig",
    "kaxigts": "kaxig",
    "kazaken": "kazak",
    "kazakens": "kazak",
    "kazaker": "kazak",
    "kazakerna": "kazak",
    "kazakernas": "kazak",
    "kazakers": "kazak",
    "kazakisk": "kazakiska",
    "kazakiska": "kazakisk",
    "kazakiskan": "kazakiska",
    "kazakiskans": "kazakiska",
    "kazakiskare": "kazakisk",
    "kazakiskares": "kazakisk",
    "kazakiskas": "kazakiska",
    "kazakiskast": "kazakisk",
    "kazakiskaste": "kazakisk",
    "kazakiskastes": "kazakisk",
    "kazakiskasts": "kazakisk",
    "kazakiske": "kazakiska",
    "kazakiskes": "kazakisk",
    "kazakiskor": "kazakiska",
    "kazakiskorna": "kazakiska",
    "kazakiskornas": "kazakiska",
    "kazakiskors": "kazakiska",
    "kazakisks": "kazakisk",
    "kazakiskt": "kazakisk",
    "kazakiskts": "kazakisk",
    "kazaks": "kazak",
    "kazooer": "kazoo",
    "kazooerna": "kazoo",
    "kazooernas": "kazoo",
    "kazooers": "kazoo",
    "kazoon": "kazoo",
    "kazoons": "kazoo",
    "kazoos": "kazoo",
    "kebaben": "kebab",
    "kebabens": "kebab",
    "kebaber": "kebab",
    "kebaberna": "kebab",
    "kebabernas": "kebab",
    "kebabers": "kebab",
    "kebabs": "kebab",
    "kebabstånden": "kebabstånd",
    "kebabståndens": "kebabstånd",
    "kebabståndet": "kebabstånd",
    "kebabståndets": "kebabstånd",
    "kebabstånds": "kebabstånd",
    "keden": "ked",
    "kedens": "ked",
    "keder": "ked",
    "kederna": "ked",
    "kedernas": "ked",
    "keders": "ked",
    "kediven": "kediv",
    "kedivens": "kediv",
    "kediver": "kediv",
    "kediverna": "kediv",
    "kedivernas": "kediv",
    "kedivers": "kediv",
    "kedivs": "kediv",
    "kedj": "kedja",
    "kedjad": "kedja",
    "kedjade": "kedja",
    "kedjades": "kedja",
    "kedjads": "kedja",
    "kedjan": "kedja",
    "kedjande": "kedja",
    "kedjanden": "kedjande",
    "kedjandena": "kedjande",
    "kedjandenas": "kedjande",
    "kedjandens": "kedjande",
    "kedjandes": "kedjande",
    "kedjandet": "kedjande",
    "kedjandets": "kedjande",
    "kedjans": "kedja",
    "kedjar": "kedja",
    "kedjas": "kedja",
    "kedjat": "kedja",
    "kedjats": "kedja",
    "kedje": "kedja",
    "kedjeblocken": "kedjeblock",
    "kedjeblockens": "kedjeblock",
    "kedjeblocket": "kedjeblock",
    "kedjeblockets": "kedjeblock",
    "kedjeblocks": "kedjeblock",
    "kedjebreven": "kedjebrev",
    "kedjebrevens": "kedjebrev",
    "kedjebrevet": "kedjebrev",
    "kedjebrevets": "kedjebrev",
    "kedjebrevs": "kedjebrev",
    "kedjebromsar": "kedjebroms",
    "kedjebromsarna": "kedjebroms",
    "kedjebromsarnas": "kedjebroms",
    "kedjebromsars": "kedjebroms",
    "kedjebromsen": "kedjebroms",
    "kedjebromsens": "kedjebroms",
    "kedjebråken": "kedjebråk",
    "kedjebråkens": "kedjebråk",
    "kedjebråket": "kedjebråk",
    "kedjebråkets": "kedjebråk",
    "kedjebråks": "kedjebråk",
    "kedjeformade": "kedjeformad",
    "kedjeformades": "kedjeformad",
    "kedjeformads": "kedjeformad",
    "kedjeformat": "kedjeformad",
    "kedjeformats": "kedjeformad",
    "kedjeföringar": "kedjeföring",
    "kedjeföringarna": "kedjeföring",
    "kedjeföringarnas": "kedjeföring",
    "kedjeföringars": "kedjeföring",
    "kedjeföringen": "kedjeföring",
    "kedjeföringens": "kedjeföring",
    "kedjeförings": "kedjeföring",
    "kedjehastigheten": "kedjehastighet",
    "kedjehastighetens": "kedjehastighet",
    "kedjehastighets": "kedjehastighet",
    "kedjehjulen": "kedjehjul",
    "kedjehjulens": "kedjehjul",
    "kedjehjulet": "kedjehjul",
    "kedjehjulets": "kedjehjul",
    "kedjehjuls": "kedjehjul",
    "kedjehusen": "kedjehus",
    "kedjehusens": "kedjehus",
    "kedjehuset": "kedjehus",
    "kedjehusets": "kedjehus",
    "kedjelyftblocken": "kedjelyftblock",
    "kedjelyftblockens": "kedjelyftblock",
    "kedjelyftblocket": "kedjelyftblock",
    "kedjelyftblockets": "kedjelyftblock",
    "kedjelyftblocks": "kedjelyftblock",
    "kedjemolekylen": "kedjemolekyl",
    "kedjemolekylens": "kedjemolekyl",
    "kedjemolekyler": "kedjemolekyl",
    "kedjemolekylerna": "kedjemolekyl",
    "kedjemolekylernas": "kedjemolekyl",
    "kedjemolekylers": "kedjemolekyl",
    "kedjemolekyls": "kedjemolekyl",
    "kedjereaktionen": "kedjereaktion",
    "kedjereaktionens": "kedjereaktion",
    "kedjereaktioner": "kedjereaktion",
    "kedjereaktionerna": "kedjereaktion",
    "kedjereaktionernas": "kedjereaktion",
    "kedjereaktioners": "kedjereaktion",
    "kedjereaktions": "kedjereaktion",
    "kedjerök": "kedjeröka",
    "kedjerökande": "kedjeröka",
    "kedjerökanden": "kedjerökande",
    "kedjerökandena": "kedjerökande",
    "kedjerökandenas": "kedjerökande",
    "kedjerökandens": "kedjerökande",
    "kedjerökandes": "kedjerökande",
    "kedjerökandet": "kedjerökande",
    "kedjerökandets": "kedjerökande",
    "kedjerökas": "kedjeröka",
    "kedjeröker": "kedjeröka",
    "kedjerökes": "kedjeröka",
    "kedjeröks": "kedjeröka",
    "kedjerökt": "kedjeröka",
    "kedjerökte": "kedjeröka",
    "kedjeröktes": "kedjeröka",
    "kedjerökts": "kedjeröka",
    "kedjeskydden": "kedjeskydd",
    "kedjeskyddens": "kedjeskydd",
    "kedjeskyddet": "kedjeskydd",
    "kedjeskyddets": "kedjeskydd",
    "kedjeskydds": "kedjeskydd",
    "kedjespänningen": "kedjespänning",
    "kedjespänningens": "kedjespänning",
    "kedjespännings": "kedjespänning",
    "kedjestygnen": "kedjestygn",
    "kedjestygnens": "kedjestygn",
    "kedjestygnet": "kedjestygn",
    "kedjestygnets": "kedjestygn",
    "kedjestygns": "kedjestygn",
    "kedjesågar": "kedjesåg",
    "kedjesågarna": "kedjesåg",
    "kedjesågarnas": "kedjesåg",
    "kedjesågars": "kedjesåg",
    "kedjesågen": "kedjesåg",
    "kedjesågens": "kedjesåg",
    "kedjesågs": "kedjesåg",
    "kedjesömmar": "kedjesöm",
    "kedjesömmarna": "kedjesöm",
    "kedjesömmarnas": "kedjesöm",
    "kedjesömmars": "kedjesöm",
    "kedjesömmen": "kedjesöm",
    "kedjesömmens": "kedjesöm",
    "kedjesöms": "kedjesöm",
    "kedjeväxeln": "kedjeväxel",
    "kedjeväxelns": "kedjeväxel",
    "kedjeväxels": "kedjeväxel",
    "kedjeväxlar": "kedjeväxel",
    "kedjeväxlarna": "kedjeväxel",
    "kedjeväxlarnas": "kedjeväxel",
    "kedjeväxlars": "kedjeväxel",
    "kedjor": "kedja",
    "kedjorna": "kedja",
    "kedjornas": "kedja",
    "kedjors": "kedja",
    "keds": "ked",
    "kefiren": "kefir",
    "kefirens": "kefir",
    "kefirn": "kefir",
    "kefirns": "kefir",
    "kefirs": "kefir",
    "kejsar": "kejsare",
    "kejsardömen": "kejsardöme",
    "kejsardömena": "kejsardöme",
    "kejsardömenas": "kejsardöme",
    "kejsardömens": "kejsardöme",
    "kejsardömes": "kejsardöme",
    "kejsardömet": "kejsardöme",
    "kejsardömets": "kejsardöme",
    "kejsaren": "kejsare",
    "kejsarens": "kejsare",
    "kejsares": "kejsare",
    "kejsarhärar": "kejsarhär",
    "kejsarhärarna": "kejsarhär",
    "kejsarhärarnas": "kejsarhär",
    "kejsarhärars": "kejsarhär",
    "kejsarhären": "kejsarhär",
    "kejsarhärens": "kejsarhär",
    "kejsarhärs": "kejsarhär",
    "kejsarinnan": "kejsarinna",
    "kejsarinnans": "kejsarinna",
    "kejsarinnas": "kejsarinna",
    "kejsarinne": "kejsarinna",
    "kejsarinnor": "kejsarinna",
    "kejsarinnorna": "kejsarinna",
    "kejsarinnornas": "kejsarinna",
    "kejsarinnors": "kejsarinna",
    "kejsarkron": "kejsarkrona",
    "kejsarkronan": "kejsarkrona",
    "kejsarkronans": "kejsarkrona",
    "kejsarkronas": "kejsarkrona",
    "kejsarkrone": "kejsarkrona",
    "kejsarkronor": "kejsarkrona",
    "kejsarkronorna": "kejsarkrona",
    "kejsarkronornas": "kejsarkrona",
    "kejsarkronors": "kejsarkrona",
    "kejsarkrons": "kejsarkrona",
    "kejsarna": "kejsare",
    "kejsarnas": "kejsare",
    "kejsarpingvinen": "kejsarpingvin",
    "kejsarpingvinens": "kejsarpingvin",
    "kejsarpingviner": "kejsarpingvin",
    "kejsarpingvinerna": "kejsarpingvin",
    "kejsarpingvinernas": "kejsarpingvin",
    "kejsarpingviners": "kejsarpingvin",
    "kejsarpingvins": "kejsarpingvin",
    "kejsars": "kejsar",
    "kejsarsnitten": "kejsarsnitt",
    "kejsarsnittens": "kejsarsnitt",
    "kejsarsnittet": "kejsarsnitt",
    "kejsarsnittets": "kejsarsnitt",
    "kejsarsnitts": "kejsarsnitt",
    "kejsarstilen": "kejsarstil",
    "kejsarstilens": "kejsarstil",
    "kejsarstils": "kejsarstil",
    "kejsarörnar": "kejsarörn",
    "kejsarörnarna": "kejsarörn",
    "kejsarörnarnas": "kejsarörn",
    "kejsarörnars": "kejsarörn",
    "kejsarörnen": "kejsarörn",
    "kejsarörnens": "kejsarörn",
    "kejsarörns": "kejsarörn",
    "kejserliga": "kejserlig",
    "kejserligare": "kejserlig",
    "kejserligares": "kejserlig",
    "kejserligas": "kejserlig",
    "kejserligast": "kejserlig",
    "kejserligaste": "kejserlig",
    "kejserligastes": "kejserlig",
    "kejserligasts": "kejserlig",
    "kejserlige": "kejserlig",
    "kejserliges": "kejserlig",
    "kejserligheten": "kejserlighet",
    "kejserlighetens": "kejserlighet",
    "kejserlighets": "kejserlighet",
    "kejserligs": "kejserlig",
    "kejserligt": "kejserlig",
    "kejserligts": "kejserlig",
    "kel": "kela",
    "kelade": "kela",
    "kelades": "kela",
    "kelande": "kela",
    "kelanden": "kelande",
    "kelandena": "kelande",
    "kelandenas": "kelande",
    "kelandens": "kelande",
    "kelandes": "kelande",
    "kelandet": "kelande",
    "kelandets": "kelande",
    "kelar": "kela",
    "kelas": "kela",
    "kelat": "kela",
    "kelats": "kela",
    "kelenheten": "kelenhet",
    "kelenhetens": "kelenhet",
    "kelenhets": "kelenhet",
    "kelens": "kelen",
    "kelet": "kelen",
    "kelets": "kelen",
    "kelgrisar": "kelgris",
    "kelgrisarna": "kelgris",
    "kelgrisarnas": "kelgris",
    "kelgrisars": "kelgris",
    "kelgrisen": "kelgris",
    "kelgrisens": "kelgris",
    "keliga": "kelig",
    "keligare": "kelig",
    "keligares": "kelig",
    "keligas": "kelig",
    "keligast": "kelig",
    "keligaste": "kelig",
    "keligastes": "kelig",
    "keligasts": "kelig",
    "kelige": "kelig",
    "keliges": "kelig",
    "keligheten": "kelighet",
    "kelighetens": "kelighet",
    "kelighets": "kelighet",
    "keligs": "kelig",
    "keligt": "kelig",
    "keligts": "kelig",
    "kelimen": "kelim",
    "kelimens": "kelim",
    "kelimer": "kelim",
    "kelimerna": "kelim",
    "kelimernas": "kelim",
    "kelimers": "kelim",
    "kelims": "kelim",
    "kelna": "kelen",
    "kelnare": "kelen",
    "kelnares": "kelen",
    "kelnas": "kelen",
    "kelnast": "kelen",
    "kelnaste": "kelen",
    "kelnastes": "kelen",
    "kelnasts": "kelen",
    "kelne": "kelen",
    "kelnes": "kelen",
    "kelpen": "kelp",
    "kelpens": "kelp",
    "kelps": "kelp",
    "kels": "kel",
    "kelsjuka": "kelsjuk",
    "kelsjukare": "kelsjuk",
    "kelsjukares": "kelsjuk",
    "kelsjukas": "kelsjuk",
    "kelsjukast": "kelsjuk",
    "kelsjukaste": "kelsjuk",
    "kelsjukastes": "kelsjuk",
    "kelsjukasts": "kelsjuk",
    "kelsjuke": "kelsjuk",
    "kelsjukes": "kelsjuk",
    "kelsjukheten": "kelsjukhet",
    "kelsjukhetens": "kelsjukhet",
    "kelsjukhets": "kelsjukhet",
    "kelsjuks": "kelsjuk",
    "kelsjukt": "kelsjuk",
    "kelsjukts": "kelsjuk",
    "kelten": "kelt",
    "keltens": "kelt",
    "kelter": "kelt",
    "kelterna": "kelt",
    "kelternas": "kelt",
    "kelters": "kelt",
    "keltisk": "keltiska",
    "keltiska": "keltisk",
    "keltiskan": "keltiska",
    "keltiskans": "keltiska",
    "keltiskare": "keltisk",
    "keltiskares": "keltisk",
    "keltiskas": "keltiska",
    "keltiskast": "keltisk",
    "keltiskaste": "keltisk",
    "keltiskastes": "keltisk",
    "keltiskasts": "keltisk",
    "keltiske": "keltiska",
    "keltiskes": "keltisk",
    "keltiskor": "keltiska",
    "keltiskorna": "keltiska",
    "keltiskornas": "keltiska",
    "keltiskors": "keltiska",
    "keltisks": "keltisk",
    "keltiskt": "keltisk",
    "keltiskts": "keltisk",
    "kelts": "kelt",
    "kelvinen": "kelvin",
    "kelvinens": "kelvin",
    "kelvins": "kelvin",
    "kemien": "kemi",
    "kemiens": "kemi",
    "kemigrafien": "kemigrafi",
    "kemigrafiens": "kemigrafi",
    "kemigrafin": "kemigrafi",
    "kemigrafins": "kemigrafi",
    "kemigrafis": "kemigrafi",
    "kemiindustrien": "kemiindustri",
    "kemiindustriens": "kemiindustri",
    "kemiindustrier": "kemiindustri",
    "kemiindustrierna": "kemiindustri",
    "kemiindustriernas": "kemiindustri",
    "kemiindustriers": "kemiindustri",
    "kemiindustrin": "kemiindustri",
    "kemiindustrins": "kemiindustri",
    "kemiindustris": "kemiindustri",
    "kemikalien": "kemikalie",
    "kemikaliens": "kemikalie",
    "kemikalier": "kemikalie",
    "kemikalierna": "kemikalie",
    "kemikaliernas": "kemikalie",
    "kemikaliers": "kemikalie",
    "kemikalies": "kemikalie",
    "kemikums": "kemikum",
    "kemilärar": "kemilärare",
    "kemiläraren": "kemilärare",
    "kemilärarens": "kemilärare",
    "kemilärares": "kemilärare",
    "kemilärarna": "kemilärare",
    "kemilärarnas": "kemilärare",
    "kemin": "kemi",
    "kemins": "kemi",
    "kemis": "kemi",
    "kemisamhällen": "kemisamhälle",
    "kemisamhällena": "kemisamhälle",
    "kemisamhällenas": "kemisamhälle",
    "kemisamhällens": "kemisamhälle",
    "kemisamhälles": "kemisamhälle",
    "kemisamhället": "kemisamhälle",
    "kemisamhällets": "kemisamhälle",
    "kemisamhälls": "kemisamhälle",
    "kemiska": "kemisk",
    "kemiskare": "kemisk",
    "kemiskares": "kemisk",
    "kemiskas": "kemisk",
    "kemiskast": "kemisk",
    "kemiskaste": "kemisk",
    "kemiskastes": "kemisk",
    "kemiskasts": "kemisk",
    "kemiske": "kemisk",
    "kemiskes": "kemisk",
    "kemisks": "kemisk",
    "kemiskt": "kemisk",
    "kemiskts": "kemisk",
    "kemisten": "kemist",
    "kemistens": "kemist",
    "kemister": "kemist",
    "kemisterna": "kemist",
    "kemisternas": "kemist",
    "kemisters": "kemist",
    "kemists": "kemist",
    "kemomaten": "kemomat",
    "kemomatens": "kemomat",
    "kemomater": "kemomat",
    "kemomaterna": "kemomat",
    "kemomaternas": "kemomat",
    "kemomaters": "kemomat",
    "kemomats": "kemomat",
    "kemoterapien": "kemoterapi",
    "kemoterapiens": "kemoterapi",
    "kemoterapier": "kemoterapi",
    "kemoterapierna": "kemoterapi",
    "kemoterapiernas": "kemoterapi",
    "kemoterapiers": "kemoterapi",
    "kemoterapin": "kemoterapi",
    "kemoterapins": "kemoterapi",
    "kemoterapis": "kemoterapi",
    "kems": "kem",
    "kemtvättar": "kemtvätt",
    "kemtvättarna": "kemtvätt",
    "kemtvättarnas": "kemtvätt",
    "kemtvättars": "kemtvätt",
    "kemtvätten": "kemtvätt",
    "kemtvättens": "kemtvätt",
    "kemtvätts": "kemtvätt",
    "kenlar": "kennel",
    "kenlarna": "kennel",
    "kenlarnas": "kennel",
    "kenlars": "kennel",
    "kenneln": "kennel",
    "kennelns": "kennel",
    "kennels": "kennel",
    "kenningar": "kenning",
    "kenningarna": "kenning",
    "kenningarnas": "kenning",
    "kenningars": "kenning",
    "kenningen": "kenning",
    "kenningens": "kenning",
    "kennings": "kenning",
    "kennlar": "kennel",
    "kennlarna": "kennel",
    "kennlarnas": "kennel",
    "kennlars": "kennel",
    "kenozoikums": "kenozoikum",
    "kentauren": "kentaur",
    "kentaurens": "kentaur",
    "kentaurer": "kentaur",
    "kentaurerna": "kentaur",
    "kentaurernas": "kentaur",
    "kentaurers": "kentaur",
    "kentaurs": "kentaur",
    "kenyanen": "kenyan",
    "kenyanens": "kenyan",
    "kenyaner": "kenyan",
    "kenyanerna": "kenyan",
    "kenyanernas": "kenyan",
    "kenyaners": "kenyan",
    "kenyans": "kenyan",
    "kenyanska": "kenyansk",
    "kenyanskan": "kenyanska",
    "kenyanskans": "kenyanska",
    "kenyanskare": "kenyansk",
    "kenyanskares": "kenyansk",
    "kenyanskas": "kenyanska",
    "kenyanskast": "kenyansk",
    "kenyanskaste": "kenyansk",
    "kenyanskastes": "kenyansk",
    "kenyanskasts": "kenyansk",
    "kenyanske": "kenyanska",
    "kenyanskes": "kenyansk",
    "kenyanskor": "kenyanska",
    "kenyanskorna": "kenyanska",
    "kenyanskornas": "kenyanska",
    "kenyanskors": "kenyanska",
    "kenyansks": "kenyansk",
    "kenyanskt": "kenyansk",
    "kenyanskts": "kenyansk",
    "kepsar": "keps",
    "kepsarna": "keps",
    "kepsarnas": "keps",
    "kepsars": "keps",
    "kepsen": "keps",
    "kepsens": "keps",
    "keramiken": "keramik",
    "keramikens": "keramik",
    "keramikern": "keramiker",
    "keramikerna": "keramiker",
    "keramikernas": "keramiker",
    "keramikerns": "keramiker",
    "keramikers": "keramiker",
    "keramikformar": "keramikform",
    "keramikformarna": "keramikform",
    "keramikformarnas": "keramikform",
    "keramikformars": "keramikform",
    "keramikformen": "keramikform",
    "keramikformens": "keramikform",
    "keramikforms": "keramikform",
    "keramikkruk": "keramikkruka",
    "keramikkrukan": "keramikkruka",
    "keramikkrukans": "keramikkruka",
    "keramikkrukas": "keramikkruka",
    "keramikkruke": "keramikkruka",
    "keramikkrukor": "keramikkruka",
    "keramikkrukorna": "keramikkruka",
    "keramikkrukornas": "keramikkruka",
    "keramikkrukors": "keramikkruka",
    "keramikkruks": "keramikkruka",
    "keramiklamp": "keramiklampa",
    "keramiklampan": "keramiklampa",
    "keramiklampans": "keramiklampa",
    "keramiklampas": "keramiklampa",
    "keramiklampe": "keramiklampa",
    "keramiklampor": "keramiklampa",
    "keramiklamporna": "keramiklampa",
    "keramiklampornas": "keramiklampa",
    "keramiklampors": "keramiklampa",
    "keramiklamps": "keramiklampa",
    "keramiks": "keramik",
    "keramikskärv": "keramikskärva",
    "keramikskärvan": "keramikskärva",
    "keramikskärvans": "keramikskärva",
    "keramikskärvas": "keramikskärva",
    "keramikskärve": "keramikskärva",
    "keramikskärvor": "keramikskärva",
    "keramikskärvorna": "keramikskärva",
    "keramikskärvornas": "keramikskärva",
    "keramikskärvors": "keramikskärva",
    "keramikskärvs": "keramikskärva",
    "keramiktomtar": "keramiktomte",
    "keramiktomtarna": "keramiktomte",
    "keramiktomtarnas": "keramiktomte",
    "keramiktomtars": "keramiktomte",
    "keramiktomten": "keramiktomte",
    "keramiktomtens": "keramiktomte",
    "keramiktomtes": "keramiktomte",
    "keramiska": "keramisk",
    "keramiskas": "keramisk",
    "keramiske": "keramisk",
    "keramiskes": "keramisk",
    "keramisks": "keramisk",
    "keramiskt": "keramisk",
    "keramiskts": "keramisk",
    "keruben": "kerub",
    "kerubens": "kerub",
    "keruber": "kerub",
    "keruberna": "kerub",
    "kerubernas": "kerub",
    "kerubers": "kerub",
    "kerubs": "kerub",
    "kes": "kesa",
    "kesade": "kesa",
    "kesades": "kesa",
    "kesande": "kesa",
    "kesanden": "kesande",
    "kesandena": "kesande",
    "kesandenas": "kesande",
    "kesandens": "kesande",
    "kesandes": "kesande",
    "kesandet": "kesande",
    "kesandets": "kesande",
    "kesar": "kesa",
    "kesas": "kesa",
    "kesat": "kesa",
    "kesats": "kesa",
    "keson": "keso",
    "kesons": "keso",
    "kesos": "keso",
    "ketchen": "ketch",
    "ketchens": "ketch",
    "ketcher": "ketch",
    "ketcherna": "ketch",
    "ketchernas": "ketch",
    "ketchers": "ketch",
    "ketchs": "ketch",
    "ketchupen": "ketchup",
    "ketchupens": "ketchup",
    "ketchups": "ketchup",
    "kevlaren": "kevlar",
    "kevlars": "kevlar",
    "kexen": "kex",
    "kexens": "kex",
    "kexet": "kex",
    "kexets": "kex",
    "khakifärgade": "khakifärgad",
    "khakifärgades": "khakifärgad",
    "khakifärgads": "khakifärgad",
    "khakifärgat": "khakifärgad",
    "khakifärgats": "khakifärgad",
    "khakigröna": "khakigrön",
    "khakigrönare": "khakigrön",
    "khakigrönares": "khakigrön",
    "khakigrönas": "khakigrön",
    "khakigrönast": "khakigrön",
    "khakigrönaste": "khakigrön",
    "khakigrönastes": "khakigrön",
    "khakigrönasts": "khakigrön",
    "khakigröne": "khakigrön",
    "khakigrönes": "khakigrön",
    "khakigröns": "khakigrön",
    "khakigrönt": "khakigrön",
    "khakigrönts": "khakigrön",
    "khakin": "khaki",
    "khakins": "khaki",
    "khakis": "khaki",
    "khanen": "khan",
    "khanens": "khan",
    "khaner": "khan",
    "khanerna": "khan",
    "khanernas": "khan",
    "khaners": "khan",
    "khans": "khan",
    "khmeren": "khmer",
    "khmerens": "khmer",
    "khmerer": "khmer",
    "khmererna": "khmer",
    "khmerernas": "khmer",
    "khmerers": "khmer",
    "khmers": "khmer",
    "kiasmen": "kiasm",
    "kiasmens": "kiasm",
    "kiasmer": "kiasm",
    "kiasmerna": "kiasm",
    "kiasmernas": "kiasm",
    "kiasmers": "kiasm",
    "kiasms": "kiasm",
    "kibbutzen": "kibbutz",
    "kibbutzens": "kibbutz",
    "kibbutzer": "kibbutz",
    "kibbutzerna": "kibbutz",
    "kibbutzernas": "kibbutz",
    "kibbutzers": "kibbutz",
    "kick": "kicka",
    "kick-offen": "kick-off",
    "kick-offens": "kick-off",
    "kick-offs": "kick-off",
    "kickad": "kicka",
    "kickade": "kicka",
    "kickades": "kicka",
    "kickads": "kicka",
    "kickan": "kicka",
    "kickande": "kicka",
    "kickanden": "kickande",
    "kickandena": "kickande",
    "kickandenas": "kickande",
    "kickandens": "kickande",
    "kickandes": "kickande",
    "kickandet": "kickande",
    "kickandets": "kickande",
    "kickans": "kicka",
    "kickar": "kicka",
    "kickarna": "kick",
    "kickarnas": "kick",
    "kickars": "kick",
    "kickas": "kicka",
    "kickat": "kicka",
    "kickats": "kicka",
    "kicke": "kicka",
    "kicken": "kick",
    "kickens": "kick",
    "kickor": "kicka",
    "kickorna": "kicka",
    "kickornas": "kicka",
    "kickors": "kicka",
    "kicks": "kicka",
    "kickstarten": "kickstart",
    "kickstartens": "kickstart",
    "kickstarter": "kickstart",
    "kickstarterna": "kickstart",
    "kickstarternas": "kickstart",
    "kickstarters": "kickstart",
    "kickstarts": "kickstart",
    "kiden": "kid",
    "kidens": "kid",
    "kidet": "kid",
    "kidets": "kid",
    "kidnapp": "kidnappa",
    "kidnappad": "kidnappa",
    "kidnappade": "kidnappa",
    "kidnappades": "kidnappa",
    "kidnappads": "kidnappa",
    "kidnappande": "kidnappa",
    "kidnappanden": "kidnappande",
    "kidnappandena": "kidnappande",
    "kidnappandenas": "kidnappande",
    "kidnappandens": "kidnappande",
    "kidnappandes": "kidnappande",
    "kidnappandet": "kidnappande",
    "kidnappandets": "kidnappande",
    "kidnappar": "kidnappare",
    "kidnapparen": "kidnappare",
    "kidnapparens": "kidnappare",
    "kidnappares": "kidnappare",
    "kidnapparna": "kidnappare",
    "kidnapparnas": "kidnappare",
    "kidnappas": "kidnappa",
    "kidnappat": "kidnappa",
    "kidnappats": "kidnappa",
    "kidnappningsförsöken": "kidnappningsförsök",
    "kidnappningsförsökens": "kidnappningsförsök",
    "kidnappningsförsöket": "kidnappningsförsök",
    "kidnappningsförsökets": "kidnappningsförsök",
    "kidnappningsförsöks": "kidnappningsförsök",
    "kids": "kid",
    "kidsen": "kids",
    "kidsens": "kids",
    "kik": "kika",
    "kikad": "kika",
    "kikade": "kika",
    "kikades": "kika",
    "kikads": "kika",
    "kikande": "kika",
    "kikanden": "kikande",
    "kikandena": "kikande",
    "kikandenas": "kikande",
    "kikandens": "kikande",
    "kikandes": "kikande",
    "kikandet": "kikande",
    "kikandets": "kikande",
    "kikar": "kikare",
    "kikaren": "kikare",
    "kikarens": "kikare",
    "kikares": "kikare",
    "kikarlinsen": "kikarlins",
    "kikarlinsens": "kikarlins",
    "kikarlinser": "kikarlins",
    "kikarlinserna": "kikarlins",
    "kikarlinsernas": "kikarlins",
    "kikarlinsers": "kikarlins",
    "kikarna": "kikare",
    "kikarnas": "kikare",
    "kikarsikten": "kikarsikte",
    "kikarsiktena": "kikarsikte",
    "kikarsiktenas": "kikarsikte",
    "kikarsiktens": "kikarsikte",
    "kikarsiktes": "kikarsikte",
    "kikarsiktet": "kikarsikte",
    "kikarsiktets": "kikarsikte",
    "kikas": "kika",
    "kikat": "kika",
    "kikats": "kika",
    "kikhost": "kikhosta",
    "kikhostan": "kikhosta",
    "kikhostans": "kikhosta",
    "kikhostas": "kikhosta",
    "kikhoste": "kikhosta",
    "kikhålen": "kikhål",
    "kikhålens": "kikhål",
    "kikhålet": "kikhål",
    "kikhålets": "kikhål",
    "kikhåls": "kikhål",
    "kikkranar": "kikkran",
    "kikkranarna": "kikkran",
    "kikkranarnas": "kikkran",
    "kikkranars": "kikkran",
    "kikkranen": "kikkran",
    "kikkranens": "kikkran",
    "kikkrans": "kikkran",
    "kiknade": "kikna",
    "kiknades": "kikna",
    "kiknande": "kikna",
    "kiknanden": "kiknande",
    "kiknandena": "kiknande",
    "kiknandenas": "kiknande",
    "kiknandens": "kiknande",
    "kiknandes": "kiknande",
    "kiknandet": "kiknande",
    "kiknandets": "kiknande",
    "kiknar": "kikna",
    "kiknas": "kikna",
    "kiknat": "kikna",
    "kiknats": "kikna",
    "kikärten": "kikärt",
    "kikärtens": "kikärt",
    "kikärter": "kikärt",
    "kikärterna": "kikärt",
    "kikärternas": "kikärt",
    "kikärters": "kikärt",
    "kikärts": "kikärt",
    "kikärtsbull": "kikärtsbulle",
    "kikärtsbullar": "kikärtsbulle",
    "kikärtsbullarna": "kikärtsbulle",
    "kikärtsbullarnas": "kikärtsbulle",
    "kikärtsbullars": "kikärtsbulle",
    "kikärtsbullen": "kikärtsbulle",
    "kikärtsbullens": "kikärtsbulle",
    "kikärtsbulles": "kikärtsbulle",
    "kikärtsbulls": "kikärtsbulle",
    "kilad": "kila",
    "kilade": "kila",
    "kilades": "kila",
    "kilads": "kila",
    "kilande": "kila",
    "kilanden": "kilande",
    "kilandena": "kilande",
    "kilandenas": "kilande",
    "kilandens": "kilande",
    "kilandes": "kilande",
    "kilandet": "kilande",
    "kilandets": "kilande",
    "kilar": "kila",
    "kilarna": "kil",
    "kilarnas": "kil",
    "kilars": "kil",
    "kilas": "kila",
    "kilat": "kila",
    "kilats": "kila",
    "kilbenen": "kilben",
    "kilbenens": "kilben",
    "kilbenet": "kilben",
    "kilbenets": "kilben",
    "kilbens": "kilben",
    "kilen": "kil",
    "kilens": "kil",
    "kilhälar": "kilhäl",
    "kilhälarna": "kilhäl",
    "kilhälarnas": "kilhäl",
    "kilhälars": "kilhäl",
    "kilhälen": "kilhäl",
    "kilhälens": "kilhäl",
    "kilhäls": "kilhäl",
    "kiliasmen": "kiliasm",
    "kiliasmens": "kiliasm",
    "kiliasms": "kiliasm",
    "kilklackar": "kilklack",
    "kilklackarna": "kilklack",
    "kilklackarnas": "kilklack",
    "kilklackars": "kilklack",
    "kilklacken": "kilklack",
    "kilklackens": "kilklack",
    "kilklacks": "kilklack",
    "kilklackskon": "kilklacksko",
    "kilklackskons": "kilklacksko",
    "kilklackskor": "kilklacksko",
    "kilklackskorna": "kilklacksko",
    "kilklackskornas": "kilklacksko",
    "kilklackskors": "kilklacksko",
    "kilklackskos": "kilklacksko",
    "kill": "kille",
    "killad": "killa",
    "killade": "killa",
    "killades": "killa",
    "killads": "killa",
    "killande": "killa",
    "killanden": "killande",
    "killandena": "killande",
    "killandenas": "killande",
    "killandens": "killande",
    "killandes": "killande",
    "killandet": "killande",
    "killandets": "killande",
    "killar": "kille",
    "killarna": "kille",
    "killarnas": "kille",
    "killars": "kille",
    "killas": "killa",
    "killat": "killa",
    "killats": "killa",
    "killen": "kille",
    "killens": "kille",
    "killerinstinkten": "killerinstinkt",
    "killerinstinktens": "killerinstinkt",
    "killerinstinkts": "killerinstinkt",
    "killes": "kille",
    "killespelen": "killespel",
    "killespelens": "killespel",
    "killespelet": "killespel",
    "killespelets": "killespel",
    "killespels": "killespel",
    "killiga": "killig",
    "killigare": "killig",
    "killigares": "killig",
    "killigas": "killig",
    "killigast": "killig",
    "killigaste": "killig",
    "killigastes": "killig",
    "killigasts": "killig",
    "killige": "killig",
    "killiges": "killig",
    "killigheten": "killighet",
    "killighetens": "killighet",
    "killighets": "killighet",
    "killigs": "killig",
    "killigt": "killig",
    "killigts": "killig",
    "killingar": "killing",
    "killingarna": "killing",
    "killingarnas": "killing",
    "killingars": "killing",
    "killingen": "killing",
    "killingens": "killing",
    "killings": "killing",
    "kills": "kille",
    "kilobyten": "kilobyte",
    "kilobytena": "kilobyte",
    "kilobytenas": "kilobyte",
    "kilobytens": "kilobyte",
    "kilobytes": "kilobyte",
    "kilogrammen": "kilogram",
    "kilogrammens": "kilogram",
    "kilogrammet": "kilogram",
    "kilogrammetern": "kilogrammeter",
    "kilogrammeterna": "kilogrammeter",
    "kilogrammeternas": "kilogrammeter",
    "kilogrammeterns": "kilogrammeter",
    "kilogrammeters": "kilogrammeter",
    "kilogrammetrar": "kilogrammeter",
    "kilogrammetrarna": "kilogrammeter",
    "kilogrammetrarnas": "kilogrammeter",
    "kilogrammetrars": "kilogrammeter",
    "kilogrammets": "kilogram",
    "kilograms": "kilogram",
    "kilometerhöga": "kilometerhög",
    "kilometerhögas": "kilometerhög",
    "kilometerhöge": "kilometerhög",
    "kilometerhöges": "kilometerhög",
    "kilometerhögs": "kilometerhög",
    "kilometerhögt": "kilometerhög",
    "kilometerhögts": "kilometerhög",
    "kilometerlånga": "kilometerlång",
    "kilometerlångas": "kilometerlång",
    "kilometerlånge": "kilometerlång",
    "kilometerlånges": "kilometerlång",
    "kilometerlångs": "kilometerlång",
    "kilometerlångt": "kilometerlång",
    "kilometerlångts": "kilometerlång",
    "kilometern": "kilometer",
    "kilometerna": "kilometer",
    "kilometernas": "kilometer",
    "kilometerns": "kilometer",
    "kilometers": "kilometer",
    "kilometerskatten": "kilometerskatt",
    "kilometerskattens": "kilometerskatt",
    "kilometerskatter": "kilometerskatt",
    "kilometerskatterna": "kilometerskatt",
    "kilometerskatternas": "kilometerskatt",
    "kilometerskatters": "kilometerskatt",
    "kilometerskatts": "kilometerskatt",
    "kilometertjocka": "kilometertjock",
    "kilometertjockare": "kilometertjock",
    "kilometertjockares": "kilometertjock",
    "kilometertjockas": "kilometertjock",
    "kilometertjockast": "kilometertjock",
    "kilometertjockaste": "kilometertjock",
    "kilometertjockastes": "kilometertjock",
    "kilometertjockasts": "kilometertjock",
    "kilometertjocke": "kilometertjock",
    "kilometertjockes": "kilometertjock",
    "kilometertjocks": "kilometertjock",
    "kilometertjockt": "kilometertjock",
    "kilometertjockts": "kilometertjock",
    "kilometrar": "kilometer",
    "kilometrarna": "kilometer",
    "kilometrarnas": "kilometer",
    "kilometrars": "kilometer",
    "kilon": "kilo",
    "kilona": "kilo",
    "kilonas": "kilo",
    "kilons": "kilo",
    "kiloponden": "kilopond",
    "kilopondens": "kilopond",
    "kilopondet": "kilopond",
    "kilopondets": "kilopond",
    "kilopondmetern": "kilopondmeter",
    "kilopondmeterna": "kilopondmeter",
    "kilopondmeternas": "kilopondmeter",
    "kilopondmeterns": "kilopondmeter",
    "kilopondmeters": "kilopondmeter",
    "kiloponds": "kilopond",
    "kiloprisen": "kilopris",
    "kiloprisens": "kilopris",
    "kilopriser": "kilopris",
    "kilopriserna": "kilopris",
    "kiloprisernas": "kilopris",
    "kiloprisers": "kilopris",
    "kilopriset": "kilopris",
    "kiloprisets": "kilopris",
    "kilos": "kilo",
    "kilot": "kilo",
    "kilotonnen": "kiloton",
    "kilotonnens": "kiloton",
    "kilotonnet": "kiloton",
    "kilotonnets": "kiloton",
    "kilotons": "kiloton",
    "kilots": "kilo",
    "kilowatten": "kilowatt",
    "kilowattens": "kilowatt",
    "kilowatts": "kilowatt",
    "kilramar": "kilram",
    "kilramarna": "kilram",
    "kilramarnas": "kilram",
    "kilramars": "kilram",
    "kilramen": "kilram",
    "kilramens": "kilram",
    "kilrams": "kilram",
    "kilremmar": "kilrem",
    "kilremmarna": "kilrem",
    "kilremmarnas": "kilrem",
    "kilremmars": "kilrem",
    "kilremmen": "kilrem",
    "kilremmens": "kilrem",
    "kilrems": "kilrem",
    "kilremsskivan": "kilremsskiva",
    "kilremsskivans": "kilremsskiva",
    "kilremsskivas": "kilremsskiva",
    "kilremsskive": "kilremsskiva",
    "kilremsskivor": "kilremsskiva",
    "kilremsskivorna": "kilremsskiva",
    "kilremsskivornas": "kilremsskiva",
    "kilremsskivors": "kilremsskiva",
    "kils": "kil",
    "kilskriften": "kilskrift",
    "kilskriftens": "kilskrift",
    "kilskrifts": "kilskrift",
    "kilspärrar": "kilspärr",
    "kilspärrarna": "kilspärr",
    "kilspärrarnas": "kilspärr",
    "kilspärrars": "kilspärr",
    "kilspärren": "kilspärr",
    "kilspärrens": "kilspärr",
    "kilspärrs": "kilspärr",
    "kilspåren": "kilspår",
    "kilspårens": "kilspår",
    "kilspåret": "kilspår",
    "kilspårets": "kilspår",
    "kilspårs": "kilspår",
    "kiltar": "kilt",
    "kiltarna": "kilt",
    "kiltarnas": "kilt",
    "kiltars": "kilt",
    "kilten": "kilt",
    "kiltens": "kilt",
    "kilts": "kilt",
    "kim": "kimma",
    "kimmade": "kimma",
    "kimmades": "kimma",
    "kimmande": "kimma",
    "kimmanden": "kimmande",
    "kimmandena": "kimmande",
    "kimmandenas": "kimmande",
    "kimmandens": "kimmande",
    "kimmandes": "kimmande",
    "kimmandet": "kimmande",
    "kimmandets": "kimmande",
    "kimmar": "kimma",
    "kimmas": "kimma",
    "kimmat": "kimma",
    "kimmats": "kimma",
    "kimonon": "kimono",
    "kimonons": "kimono",
    "kimonor": "kimono",
    "kimonorna": "kimono",
    "kimonornas": "kimono",
    "kimonors": "kimono",
    "kimonos": "kimono",
    "kimonosen": "kimono",
    "kimonosens": "kimono",
    "kimröken": "kimrök",
    "kimrökens": "kimrök",
    "kimröks": "kimrök",
    "kinaalkaloiden": "kinaalkaloid",
    "kinaalkaloidens": "kinaalkaloid",
    "kinaalkaloider": "kinaalkaloid",
    "kinaalkaloiderna": "kinaalkaloid",
    "kinaalkaloidernas": "kinaalkaloid",
    "kinaalkaloiders": "kinaalkaloid",
    "kinaalkaloids": "kinaalkaloid",
    "kinabarken": "kinabark",
    "kinabarkens": "kinabark",
    "kinabarks": "kinabark",
    "kinamaten": "kinamat",
    "kinamatens": "kinamat",
    "kinamats": "kinamat",
    "kinan": "kina",
    "kinans": "kina",
    "kinarestaurangen": "kinarestaurang",
    "kinarestaurangens": "kinarestaurang",
    "kinarestauranger": "kinarestaurang",
    "kinarestaurangerna": "kinarestaurang",
    "kinarestaurangernas": "kinarestaurang",
    "kinarestaurangers": "kinarestaurang",
    "kinarestaurangs": "kinarestaurang",
    "kinas": "kina",
    "kinaschacket": "kinaschack",
    "kinaschackets": "kinaschack",
    "kinaschacks": "kinaschack",
    "kindbenen": "kindben",
    "kindbenens": "kindben",
    "kindbenet": "kindben",
    "kindbenets": "kindben",
    "kindbens": "kindben",
    "kinden": "kind",
    "kindens": "kind",
    "kinder": "kind",
    "kindergartens": "kindergarten",
    "kinderna": "kind",
    "kindernas": "kind",
    "kinders": "kind",
    "kindkedjan": "kindkedja",
    "kindkedjans": "kindkedja",
    "kindkedjas": "kindkedja",
    "kindkedje": "kindkedja",
    "kindkedjor": "kindkedja",
    "kindkedjorna": "kindkedja",
    "kindkedjornas": "kindkedja",
    "kindkedjors": "kindkedja",
    "kindknot": "kindknota",
    "kindknotan": "kindknota",
    "kindknotans": "kindknota",
    "kindknotas": "kindknota",
    "kindknote": "kindknota",
    "kindknotor": "kindknota",
    "kindknotorna": "kindknota",
    "kindknotornas": "kindknota",
    "kindknotors": "kindknota",
    "kindknots": "kindknota",
    "kindkot": "kindkota",
    "kindkotan": "kindkota",
    "kindkotans": "kindkota",
    "kindkotas": "kindkota",
    "kindkote": "kindkota",
    "kindkotor": "kindkota",
    "kindkotorna": "kindkota",
    "kindkotornas": "kindkota",
    "kindkotors": "kindkota",
    "kindkots": "kindkota",
    "kindpustar": "kindpust",
    "kindpustarna": "kindpust",
    "kindpustarnas": "kindpust",
    "kindpustars": "kindpust",
    "kindpusten": "kindpust",
    "kindpustens": "kindpust",
    "kindpusts": "kindpust",
    "kindpås": "kindpåse",
    "kindpåsar": "kindpåse",
    "kindpåsarna": "kindpåse",
    "kindpåsarnas": "kindpåse",
    "kindpåsars": "kindpåse",
    "kindpåsen": "kindpåse",
    "kindpåsens": "kindpåse",
    "kindpåses": "kindpåse",
    "kinds": "kind",
    "kindtanden": "kindtand",
    "kindtandens": "kindtand",
    "kindtands": "kindtand",
    "kindtänder": "kindtand",
    "kindtänderna": "kindtand",
    "kindtändernas": "kindtand",
    "kindtänders": "kindtand",
    "kinematiken": "kinematik",
    "kinematikens": "kinematik",
    "kinematiks": "kinematik",
    "kinematografen": "kinematograf",
    "kinematografens": "kinematograf",
    "kinematografer": "kinematograf",
    "kinematograferna": "kinematograf",
    "kinematografernas": "kinematograf",
    "kinematografers": "kinematograf",
    "kinematografs": "kinematograf",
    "kinesade": "kinesa",
    "kinesades": "kinesa",
    "kinesande": "kinesa",
    "kinesanden": "kinesande",
    "kinesandena": "kinesande",
    "kinesandenas": "kinesande",
    "kinesandens": "kinesande",
    "kinesandes": "kinesande",
    "kinesandet": "kinesande",
    "kinesandets": "kinesande",
    "kinesar": "kinesa",
    "kinesas": "kinesa",
    "kinesat": "kinesa",
    "kinesats": "kinesa",
    "kinesen": "kines",
    "kinesens": "kines",
    "kineser": "kines",
    "kineserier": "kineseri",
    "kineserierna": "kineseri",
    "kineseriernas": "kineseri",
    "kineseriers": "kineseri",
    "kineseriet": "kineseri",
    "kineseriets": "kineseri",
    "kineseris": "kineseri",
    "kineserit": "kineseri",
    "kineserits": "kineseri",
    "kineserna": "kines",
    "kinesernas": "kines",
    "kinesers": "kines",
    "kinesisk": "kinesiska",
    "kinesiska": "kinesisk",
    "kinesiskan": "kinesiska",
    "kinesiskans": "kinesiska",
    "kinesiskare": "kinesisk",
    "kinesiskares": "kinesisk",
    "kinesiskas": "kinesiska",
    "kinesiskast": "kinesisk",
    "kinesiskaste": "kinesisk",
    "kinesiskastes": "kinesisk",
    "kinesiskasts": "kinesisk",
    "kinesiske": "kinesiska",
    "kinesiskes": "kinesisk",
    "kinesiskor": "kinesiska",
    "kinesiskorna": "kinesiska",
    "kinesiskornas": "kinesiska",
    "kinesiskors": "kinesiska",
    "kinesisks": "kinesisk",
    "kinesiskt": "kinesisk",
    "kinesiskts": "kinesisk",
    "kinestetiska": "kinestetisk",
    "kinestetiskare": "kinestetisk",
    "kinestetiskares": "kinestetisk",
    "kinestetiskas": "kinestetisk",
    "kinestetiskast": "kinestetisk",
    "kinestetiskaste": "kinestetisk",
    "kinestetiskastes": "kinestetisk",
    "kinestetiskasts": "kinestetisk",
    "kinestetiske": "kinestetisk",
    "kinestetiskes": "kinestetisk",
    "kinestetisks": "kinestetisk",
    "kinestetiskt": "kinestetisk",
    "kinestetiskts": "kinestetisk",
    "kinetiken": "kinetik",
    "kinetikens": "kinetik",
    "kinetiks": "kinetik",
    "kinetiska": "kinetisk",
    "kinetiskare": "kinetisk",
    "kinetiskares": "kinetisk",
    "kinetiskas": "kinetisk",
    "kinetiskast": "kinetisk",
    "kinetiskaste": "kinetisk",
    "kinetiskastes": "kinetisk",
    "kinetiskasts": "kinetisk",
    "kinetiske": "kinetisk",
    "kinetiskes": "kinetisk",
    "kinetisks": "kinetisk",
    "kinetiskt": "kinetisk",
    "kinetiskts": "kinetisk",
    "kininen": "kinin",
    "kininens": "kinin",
    "kininet": "kinin",
    "kininets": "kinin",
    "kinins": "kinin",
    "kinkade": "kinka",
    "kinkades": "kinka",
    "kinkande": "kinka",
    "kinkanden": "kinkande",
    "kinkandena": "kinkande",
    "kinkandenas": "kinkande",
    "kinkandens": "kinkande",
    "kinkandes": "kinkande",
    "kinkandet": "kinkande",
    "kinkandets": "kinkande",
    "kinkar": "kinka",
    "kinkarna": "kink",
    "kinkarnas": "kink",
    "kinkars": "kink",
    "kinkas": "kinka",
    "kinkat": "kinka",
    "kinkats": "kinka",
    "kinken": "kink",
    "kinkens": "kink",
    "kinket": "kink",
    "kinkets": "kink",
    "kinkiga": "kinkig",
    "kinkigare": "kinkig",
    "kinkigares": "kinkig",
    "kinkigas": "kinkig",
    "kinkigast": "kinkig",
    "kinkigaste": "kinkig",
    "kinkigastes": "kinkig",
    "kinkigasts": "kinkig",
    "kinkige": "kinkig",
    "kinkiges": "kinkig",
    "kinkigheten": "kinkighet",
    "kinkighetens": "kinkighet",
    "kinkighets": "kinkighet",
    "kinkigs": "kinkig",
    "kinkigt": "kinkig",
    "kinkigts": "kinkig",
    "kinks": "kink",
    "kiosken": "kiosk",
    "kioskens": "kiosk",
    "kiosker": "kiosk",
    "kioskerna": "kiosk",
    "kioskernas": "kiosk",
    "kioskers": "kiosk",
    "kiosklitteraturen": "kiosklitteratur",
    "kiosklitteraturens": "kiosklitteratur",
    "kiosklitteraturs": "kiosklitteratur",
    "kiosks": "kiosk",
    "kipar": "kip",
    "kiparna": "kip",
    "kiparnas": "kip",
    "kipars": "kip",
    "kipen": "kip",
    "kipens": "kip",
    "kipp": "kippa",
    "kippade": "kippa",
    "kippades": "kippa",
    "kippande": "kippa",
    "kippanden": "kippande",
    "kippandena": "kippande",
    "kippandenas": "kippande",
    "kippandens": "kippande",
    "kippandes": "kippande",
    "kippandet": "kippande",
    "kippandets": "kippande",
    "kippar": "kippa",
    "kippas": "kippa",
    "kippat": "kippa",
    "kippats": "kippa",
    "kippskodda": "kippskodd",
    "kippskoddare": "kippskodd",
    "kippskoddares": "kippskodd",
    "kippskoddas": "kippskodd",
    "kippskoddast": "kippskodd",
    "kippskoddaste": "kippskodd",
    "kippskoddastes": "kippskodd",
    "kippskoddasts": "kippskodd",
    "kippskodde": "kippskodd",
    "kippskoddes": "kippskodd",
    "kippskodds": "kippskodd",
    "kippskon": "kippsko",
    "kippskons": "kippsko",
    "kippskor": "kippsko",
    "kippskorna": "kippsko",
    "kippskornas": "kippsko",
    "kippskors": "kippsko",
    "kippskos": "kippsko",
    "kippskott": "kippskodd",
    "kippskotts": "kippskodd",
    "kips": "kip",
    "kirgisen": "kirgis",
    "kirgisens": "kirgis",
    "kirgiser": "kirgis",
    "kirgiserna": "kirgis",
    "kirgisernas": "kirgis",
    "kirgisers": "kirgis",
    "kirgisiern": "kirgisier",
    "kirgisierna": "kirgisier",
    "kirgisiernas": "kirgisier",
    "kirgisierns": "kirgisier",
    "kirgisiers": "kirgisier",
    "kirgisisk": "kirgisiska",
    "kirgisiskan": "kirgisiska",
    "kirgisiskans": "kirgisiska",
    "kirgisiskas": "kirgisiska",
    "kirgisiske": "kirgisiska",
    "kirgisiskor": "kirgisiska",
    "kirgisiskorna": "kirgisiska",
    "kirgisiskornas": "kirgisiska",
    "kirgisiskors": "kirgisiska",
    "kirgizen": "kirgiz",
    "kirgizens": "kirgiz",
    "kirgizer": "kirgiz",
    "kirgizerna": "kirgiz",
    "kirgizernas": "kirgiz",
    "kirgizers": "kirgiz",
    "kirgizisk": "kirgiziska",
    "kirgiziskan": "kirgiziska",
    "kirgiziskans": "kirgiziska",
    "kirgiziskas": "kirgiziska",
    "kirgiziske": "kirgiziska",
    "kirgiziskor": "kirgiziska",
    "kirgiziskorna": "kirgiziska",
    "kirgiziskornas": "kirgiziska",
    "kirgiziskors": "kirgiziska",
    "kiribatiern": "kiribatier",
    "kiribatierna": "kiribatier",
    "kiribatiernas": "kiribatier",
    "kiribatierns": "kiribatier",
    "kiribatiers": "kiribatier",
    "kiribatiska": "kiribatisk",
    "kiribatiskan": "kiribatiska",
    "kiribatiskans": "kiribatiska",
    "kiribatiskare": "kiribatisk",
    "kiribatiskares": "kiribatisk",
    "kiribatiskas": "kiribatiska",
    "kiribatiskast": "kiribatisk",
    "kiribatiskaste": "kiribatisk",
    "kiribatiskastes": "kiribatisk",
    "kiribatiskasts": "kiribatisk",
    "kiribatiske": "kiribatiska",
    "kiribatiskes": "kiribatisk",
    "kiribatiskor": "kiribatiska",
    "kiribatiskorna": "kiribatiska",
    "kiribatiskornas": "kiribatiska",
    "kiribatiskors": "kiribatiska",
    "kiribatisks": "kiribatisk",
    "kiribatiskt": "kiribatisk",
    "kiribatiskts": "kiribatisk",
    "kiromantien": "kiromanti",
    "kiromantiens": "kiromanti",
    "kiromantin": "kiromanti",
    "kiromantins": "kiromanti",
    "kiromantis": "kiromanti",
    "kiropraktiken": "kiropraktik",
    "kiropraktikens": "kiropraktik",
    "kiropraktikern": "kiropraktiker",
    "kiropraktikerna": "kiropraktiker",
    "kiropraktikernas": "kiropraktiker",
    "kiropraktikerns": "kiropraktiker",
    "kiropraktikers": "kiropraktiker",
    "kiropraktiks": "kiropraktik",
    "kiropraktorer": "kiropraktor",
    "kiropraktorerna": "kiropraktor",
    "kiropraktorernas": "kiropraktor",
    "kiropraktorers": "kiropraktor",
    "kiropraktorn": "kiropraktor",
    "kiropraktorns": "kiropraktor",
    "kiropraktors": "kiropraktor",
    "kirr": "kirra",
    "kirrad": "kirra",
    "kirrade": "kirra",
    "kirrades": "kirra",
    "kirrads": "kirra",
    "kirrande": "kirra",
    "kirranden": "kirrande",
    "kirrandena": "kirrande",
    "kirrandenas": "kirrande",
    "kirrandens": "kirrande",
    "kirrandes": "kirrande",
    "kirrandet": "kirrande",
    "kirrandets": "kirrande",
    "kirrar": "kirra",
    "kirras": "kirra",
    "kirrat": "kirra",
    "kirrats": "kirra",
    "kirskålen": "kirskål",
    "kirskålens": "kirskål",
    "kirskåls": "kirskål",
    "kirurgen": "kirurg",
    "kirurgens": "kirurg",
    "kirurger": "kirurg",
    "kirurgerna": "kirurg",
    "kirurgernas": "kirurg",
    "kirurgers": "kirurg",
    "kirurgien": "kirurgi",
    "kirurgiens": "kirurgi",
    "kirurgin": "kirurgi",
    "kirurgins": "kirurgi",
    "kirurgis": "kirurgi",
    "kirurgiska": "kirurgisk",
    "kirurgiskare": "kirurgisk",
    "kirurgiskares": "kirurgisk",
    "kirurgiskas": "kirurgisk",
    "kirurgiskast": "kirurgisk",
    "kirurgiskaste": "kirurgisk",
    "kirurgiskastes": "kirurgisk",
    "kirurgiskasts": "kirurgisk",
    "kirurgiske": "kirurgisk",
    "kirurgiskes": "kirurgisk",
    "kirurgisks": "kirurgisk",
    "kirurgiskt": "kirurgisk",
    "kirurgiskts": "kirurgisk",
    "kirurgs": "kirurg",
    "kirurgtänger": "kirurgtång",
    "kirurgtängerna": "kirurgtång",
    "kirurgtängernas": "kirurgtång",
    "kirurgtängers": "kirurgtång",
    "kirurgtången": "kirurgtång",
    "kirurgtångens": "kirurgtång",
    "kirurgtångs": "kirurgtång",
    "kis": "kisa",
    "kisade": "kisa",
    "kisades": "kisa",
    "kisande": "kisa",
    "kisanden": "kisande",
    "kisandena": "kisande",
    "kisandenas": "kisande",
    "kisandens": "kisande",
    "kisandes": "kisande",
    "kisandet": "kisande",
    "kisandets": "kisande",
    "kisar": "kisa",
    "kisarna": "kis",
    "kisarnas": "kis",
    "kisars": "kis",
    "kisas": "kisa",
    "kisat": "kisa",
    "kisats": "kisa",
    "kiselalgen": "kiselalg",
    "kiselalgens": "kiselalg",
    "kiselalger": "kiselalg",
    "kiselalgerna": "kiselalg",
    "kiselalgernas": "kiselalg",
    "kiselalgers": "kiselalg",
    "kiselalgs": "kiselalg",
    "kiseldammet": "kiseldamm",
    "kiseldammets": "kiseldamm",
    "kiseldamms": "kiseldamm",
    "kiselföreningar": "kiselförening",
    "kiselföreningarna": "kiselförening",
    "kiselföreningarnas": "kiselförening",
    "kiselföreningars": "kiselförening",
    "kiselföreningen": "kiselförening",
    "kiselföreningens": "kiselförening",
    "kiselförenings": "kiselförening",
    "kiselguren": "kiselgur",
    "kiselgurens": "kiselgur",
    "kiselguret": "kiselgur",
    "kiselgurets": "kiselgur",
    "kiselgurs": "kiselgur",
    "kiselkarbiden": "kiselkarbid",
    "kiselkarbidens": "kiselkarbid",
    "kiselkarbids": "kiselkarbid",
    "kiselkristallen": "kiselkristall",
    "kiselkristallens": "kiselkristall",
    "kiselkristaller": "kiselkristall",
    "kiselkristallerna": "kiselkristall",
    "kiselkristallernas": "kiselkristall",
    "kiselkristallers": "kiselkristall",
    "kiselkristalls": "kiselkristall",
    "kiseln": "kisel",
    "kiselns": "kisel",
    "kiselplatt": "kiselplatta",
    "kiselplattan": "kiselplatta",
    "kiselplattans": "kiselplatta",
    "kiselplattas": "kiselplatta",
    "kiselplatte": "kiselplatta",
    "kiselplattor": "kiselplatta",
    "kiselplattorna": "kiselplatta",
    "kiselplattornas": "kiselplatta",
    "kiselplattors": "kiselplatta",
    "kiselplatts": "kiselplatta",
    "kisels": "kisel",
    "kiselstenar": "kiselsten",
    "kiselstenarna": "kiselsten",
    "kiselstenarnas": "kiselsten",
    "kiselstenars": "kiselsten",
    "kiselstenen": "kiselsten",
    "kiselstenens": "kiselsten",
    "kiselstens": "kiselsten",
    "kiselsyran": "kiselsyra",
    "kiselsyrans": "kiselsyra",
    "kiselsyras": "kiselsyra",
    "kiselsyre": "kiselsyra",
    "kisen": "kis",
    "kisens": "kis",
    "kiser": "kis",
    "kiserna": "kis",
    "kisernas": "kis",
    "kisers": "kis",
    "kislet": "kisel",
    "kislets": "kisel",
    "kiss": "kisse",
    "kissad": "kissa",
    "kissade": "kissa",
    "kissades": "kissa",
    "kissads": "kissa",
    "kissande": "kissa",
    "kissanden": "kissande",
    "kissandena": "kissande",
    "kissandenas": "kissande",
    "kissandens": "kissande",
    "kissandes": "kissande",
    "kissandet": "kissande",
    "kissandets": "kissande",
    "kissar": "kisse",
    "kissarna": "kisse",
    "kissarnas": "kisse",
    "kissars": "kisse",
    "kissas": "kissa",
    "kissat": "kissa",
    "kissats": "kissa",
    "kissekatten": "kissekatt",
    "kissekattens": "kissekatt",
    "kissekatter": "kissekatt",
    "kissekatterna": "kissekatt",
    "kissekatternas": "kissekatt",
    "kissekatters": "kissekatt",
    "kissekatts": "kissekatt",
    "kissemissar": "kissemiss",
    "kissemissarna": "kissemiss",
    "kissemissarnas": "kissemiss",
    "kissemissars": "kissemiss",
    "kissemissen": "kissemiss",
    "kissemissens": "kissemiss",
    "kissen": "kisse",
    "kissens": "kisse",
    "kisses": "kisse",
    "kisset": "kiss",
    "kissets": "kiss",
    "kissnödiga": "kissnödig",
    "kissnödigare": "kissnödig",
    "kissnödigares": "kissnödig",
    "kissnödigas": "kissnödig",
    "kissnödigast": "kissnödig",
    "kissnödigaste": "kissnödig",
    "kissnödigastes": "kissnödig",
    "kissnödigasts": "kissnödig",
    "kissnödige": "kissnödig",
    "kissnödiges": "kissnödig",
    "kissnödigheten": "kissnödighet",
    "kissnödighetens": "kissnödighet",
    "kissnödighets": "kissnödighet",
    "kissnödigs": "kissnödig",
    "kissnödigt": "kissnödig",
    "kissnödigts": "kissnödig",
    "kist": "kista",
    "kistan": "kista",
    "kistans": "kista",
    "kistas": "kista",
    "kistbreven": "kistbrev",
    "kistbrevens": "kistbrev",
    "kistbrevet": "kistbrev",
    "kistbrevets": "kistbrev",
    "kistbrevs": "kistbrev",
    "kiste": "kista",
    "kistebreven": "kistebrev",
    "kistebrevens": "kistebrev",
    "kistebrevet": "kistebrev",
    "kistebrevets": "kistebrev",
    "kistebrevs": "kistebrev",
    "kistor": "kista",
    "kistorna": "kista",
    "kistornas": "kista",
    "kistors": "kista",
    "kiten": "kit",
    "kitens": "kit",
    "kitet": "kit",
    "kitets": "kit",
    "kitinen": "kitin",
    "kitinens": "kitin",
    "kitinet": "kitin",
    "kitinets": "kitin",
    "kitins": "kitin",
    "kitonen": "kiton",
    "kitonens": "kiton",
    "kitoner": "kiton",
    "kitonerna": "kiton",
    "kitonernas": "kiton",
    "kitoners": "kiton",
    "kitons": "kiton",
    "kits": "kit",
    "kitschen": "kitsch",
    "kitschens": "kitsch",
    "kitschet": "kitsch",
    "kitschets": "kitsch",
    "kitschs": "kitsch",
    "kitsliga": "kitslig",
    "kitsligare": "kitslig",
    "kitsligares": "kitslig",
    "kitsligas": "kitslig",
    "kitsligast": "kitslig",
    "kitsligaste": "kitslig",
    "kitsligastes": "kitslig",
    "kitsligasts": "kitslig",
    "kitslige": "kitslig",
    "kitsliges": "kitslig",
    "kitsligheten": "kitslighet",
    "kitslighetens": "kitslighet",
    "kitsligheter": "kitslighet",
    "kitsligheterna": "kitslighet",
    "kitsligheternas": "kitslighet",
    "kitsligheters": "kitslighet",
    "kitslighets": "kitslighet",
    "kitsligs": "kitslig",
    "kitsligt": "kitslig",
    "kitsligts": "kitslig",
    "kitt": "kitta",
    "kittad": "kitta",
    "kittade": "kitta",
    "kittades": "kitta",
    "kittads": "kitta",
    "kittande": "kitta",
    "kittanden": "kittande",
    "kittandena": "kittande",
    "kittandenas": "kittande",
    "kittandens": "kittande",
    "kittandes": "kittande",
    "kittandet": "kittande",
    "kittandets": "kittande",
    "kittar": "kitta",
    "kittas": "kitta",
    "kittat": "kitta",
    "kittats": "kitta",
    "kittel": "kittla",
    "kitteldalar": "kitteldal",
    "kitteldalarna": "kitteldal",
    "kitteldalarnas": "kitteldal",
    "kitteldalars": "kitteldal",
    "kitteldalen": "kitteldal",
    "kitteldalens": "kitteldal",
    "kitteldals": "kitteldal",
    "kittelflickar": "kittelflickare",
    "kittelflickaren": "kittelflickare",
    "kittelflickarens": "kittelflickare",
    "kittelflickares": "kittelflickare",
    "kittelflickarna": "kittelflickare",
    "kittelflickarnas": "kittelflickare",
    "kitteln": "kittel",
    "kittelns": "kittel",
    "kittels": "kittel",
    "kittet": "kitt",
    "kittets": "kitt",
    "kittlad": "kittla",
    "kittlade": "kittla",
    "kittlades": "kittlas",
    "kittlads": "kittla",
    "kittlande": "kittla",
    "kittlanden": "kittlande",
    "kittlandena": "kittlande",
    "kittlandenas": "kittlande",
    "kittlandens": "kittlande",
    "kittlandes": "kittlande",
    "kittlandet": "kittlande",
    "kittlandets": "kittlande",
    "kittlar": "kittlare",
    "kittlaren": "kittlare",
    "kittlarens": "kittlare",
    "kittlares": "kittlare",
    "kittlarna": "kittlare",
    "kittlarnas": "kittlare",
    "kittlars": "kittel",
    "kittlas": "kittla",
    "kittlat": "kittla",
    "kittlats": "kittlas",
    "kittliga": "kittlig",
    "kittligare": "kittlig",
    "kittligares": "kittlig",
    "kittligas": "kittlig",
    "kittligast": "kittlig",
    "kittligaste": "kittlig",
    "kittligastes": "kittlig",
    "kittligasts": "kittlig",
    "kittlige": "kittlig",
    "kittliges": "kittlig",
    "kittligheten": "kittlighet",
    "kittlighetens": "kittlighet",
    "kittlighets": "kittlighet",
    "kittligs": "kittlig",
    "kittligt": "kittlig",
    "kittligts": "kittlig",
    "kitts": "kitt",
    "kivades": "kivas",
    "kivats": "kivas",
    "kivet": "kiv",
    "kivets": "kiv",
    "kivier": "kivi",
    "kivierna": "kivi",
    "kiviernas": "kivi",
    "kiviers": "kivi",
    "kivin": "kivi",
    "kivins": "kivi",
    "kivis": "kivi",
    "kivs": "kiv",
    "kiwier": "kiwi",
    "kiwierna": "kiwi",
    "kiwiernas": "kiwi",
    "kiwiers": "kiwi",
    "kiwin": "kiwi",
    "kiwins": "kiwi",
    "kiwis": "kiwi",
    "kjolar": "kjol",
    "kjolarna": "kjol",
    "kjolarnas": "kjol",
    "kjolars": "kjol",
    "kjolen": "kjol",
    "kjolens": "kjol",
    "kjollösa": "kjollös",
    "kjollösas": "kjollös",
    "kjollöse": "kjollös",
    "kjollöses": "kjollös",
    "kjollösheten": "kjollöshet",
    "kjollöshetens": "kjollöshet",
    "kjollöshets": "kjollöshet",
    "kjollöst": "kjollös",
    "kjollösts": "kjollös",
    "kjols": "kjol",
    "kjoltygen": "kjoltyg",
    "kjoltygens": "kjoltyg",
    "kjoltyget": "kjoltyg",
    "kjoltygets": "kjoltyg",
    "kjoltygs": "kjoltyg",
    "kjorteln": "kjortel",
    "kjortelns": "kjortel",
    "kjortels": "kjortel",
    "kjortlar": "kjortel",
    "kjortlarna": "kjortel",
    "kjortlarnas": "kjortel",
    "kjortlars": "kjortel",
    "kjus": "kjusa",
    "kjusan": "kjusa",
    "kjusans": "kjusa",
    "kjusas": "kjusa",
    "kjuse": "kjusa",
    "kjusor": "kjusa",
    "kjusorna": "kjusa",
    "kjusornas": "kjusa",
    "kjusors": "kjusa",
    "klabb": "klabbe",
    "klabbade": "klabba",
    "klabbades": "klabba",
    "klabbande": "klabba",
    "klabbanden": "klabbande",
    "klabbandena": "klabbande",
    "klabbandenas": "klabbande",
    "klabbandens": "klabbande",
    "klabbandes": "klabbande",
    "klabbandet": "klabbande",
    "klabbandets": "klabbande",
    "klabbar": "klabbe",
    "klabbarna": "klabbe",
    "klabbarnas": "klabbe",
    "klabbars": "klabbe",
    "klabbas": "klabba",
    "klabbat": "klabba",
    "klabbats": "klabba",
    "klabben": "klabbe",
    "klabbens": "klabbe",
    "klabbes": "klabbe",
    "klabbet": "klabb",
    "klabbets": "klabb",
    "klabbs": "klabbe",
    "klabbsköt": "klabbsköte",
    "klabbskötar": "klabbsköte",
    "klabbskötarna": "klabbsköte",
    "klabbskötarnas": "klabbsköte",
    "klabbskötars": "klabbsköte",
    "klabbsköten": "klabbsköte",
    "klabbskötens": "klabbsköte",
    "klabbskötes": "klabbsköte",
    "klabbsköts": "klabbsköte",
    "klabbströmmingar": "klabbströmming",
    "klabbströmmingarna": "klabbströmming",
    "klabbströmmingarnas": "klabbströmming",
    "klabbströmmingars": "klabbströmming",
    "klabbströmmingen": "klabbströmming",
    "klabbströmmingens": "klabbströmming",
    "klabbströmmings": "klabbströmming",
    "klack": "klacka",
    "klackad": "klacka",
    "klackade": "klacka",
    "klackades": "klacka",
    "klackads": "klacka",
    "klackande": "klacka",
    "klackanden": "klackande",
    "klackandena": "klackande",
    "klackandenas": "klackande",
    "klackandens": "klackande",
    "klackandes": "klackande",
    "klackandet": "klackande",
    "klackandets": "klackande",
    "klackar": "klacka",
    "klackarna": "klack",
    "klackarnas": "klack",
    "klackars": "klack",
    "klackas": "klacka",
    "klackat": "klacka",
    "klackats": "klacka",
    "klackbaren": "klackbar",
    "klackbarens": "klackbar",
    "klackbarer": "klackbar",
    "klackbarerna": "klackbar",
    "klackbarernas": "klackbar",
    "klackbarers": "klackbar",
    "klackbars": "klackbar",
    "klacken": "klack",
    "klackens": "klack",
    "klackjärnen": "klackjärn",
    "klackjärnens": "klackjärn",
    "klackjärnet": "klackjärn",
    "klackjärnets": "klackjärn",
    "klackjärns": "klackjärn",
    "klackringar": "klackring",
    "klackringarna": "klackring",
    "klackringarnas": "klackring",
    "klackringars": "klackring",
    "klackringen": "klackring",
    "klackringens": "klackring",
    "klackrings": "klackring",
    "klacks": "klack",
    "klacksparkar": "klackspark",
    "klacksparkarna": "klackspark",
    "klacksparkarnas": "klackspark",
    "klacksparkars": "klackspark",
    "klacksparken": "klackspark",
    "klacksparkens": "klackspark",
    "klacksparks": "klackspark",
    "klackstöveln": "klackstövel",
    "klackstövelns": "klackstövel",
    "klackstövels": "klackstövel",
    "klackstövlar": "klackstövel",
    "klackstövlarna": "klackstövel",
    "klackstövlarnas": "klackstövel",
    "klackstövlars": "klackstövel",
    "kladd": "kladda",
    "kladdade": "kladda",
    "kladdades": "kladda",
    "kladdande": "kladda",
    "kladdanden": "kladdande",
    "kladdandena": "kladdande",
    "kladdandenas": "kladdande",
    "kladdandens": "kladdande",
    "kladdandes": "kladdande",
    "kladdandet": "kladdande",
    "kladdandets": "kladdande",
    "kladdar": "kladda",
    "kladdarna": "kladd",
    "kladdarnas": "kladd",
    "kladdars": "kladd",
    "kladdas": "kladda",
    "kladdat": "kladda",
    "kladdats": "kladda",
    "kladden": "kladd",
    "kladdens": "kladd",
    "kladdet": "kladd",
    "kladdets": "kladd",
    "kladdiga": "kladdig",
    "kladdigare": "kladdig",
    "kladdigares": "kladdig",
    "kladdigas": "kladdig",
    "kladdigast": "kladdig",
    "kladdigaste": "kladdig",
    "kladdigastes": "kladdig",
    "kladdigasts": "kladdig",
    "kladdige": "kladdig",
    "kladdiges": "kladdig",
    "kladdigheten": "kladdighet",
    "kladdighetens": "kladdighet",
    "kladdighets": "kladdighet",
    "kladdigs": "kladdig",
    "kladdigt": "kladdig",
    "kladdigts": "kladdig",
    "kladdkak": "kladdkaka",
    "kladdkakan": "kladdkaka",
    "kladdkakans": "kladdkaka",
    "kladdkakas": "kladdkaka",
    "kladdkake": "kladdkaka",
    "kladdkakor": "kladdkaka",
    "kladdkakorna": "kladdkaka",
    "kladdkakornas": "kladdkaka",
    "kladdkakors": "kladdkaka",
    "kladdkaks": "kladdkaka",
    "kladds": "kladd",
    "klaffade": "klaffa",
    "klaffades": "klaffa",
    "klaffande": "klaffa",
    "klaffanden": "klaffande",
    "klaffandena": "klaffande",
    "klaffandenas": "klaffande",
    "klaffandens": "klaffande",
    "klaffandes": "klaffande",
    "klaffandet": "klaffande",
    "klaffandets": "klaffande",
    "klaffar": "klaffa",
    "klaffarna": "klaff",
    "klaffarnas": "klaff",
    "klaffars": "klaff",
    "klaffas": "klaffa",
    "klaffat": "klaffa",
    "klaffats": "klaffa",
    "klaffborden": "klaffbord",
    "klaffbordens": "klaffbord",
    "klaffbordet": "klaffbord",
    "klaffbordets": "klaffbord",
    "klaffbords": "klaffbord",
    "klaffbroar": "klaffbro",
    "klaffbroarna": "klaffbro",
    "klaffbroarnas": "klaffbro",
    "klaffbroars": "klaffbro",
    "klaffbron": "klaffbro",
    "klaffbrons": "klaffbro",
    "klaffbros": "klaffbro",
    "klaffelen": "klaffel",
    "klaffelens": "klaffel",
    "klaffelet": "klaffel",
    "klaffelets": "klaffel",
    "klaffels": "klaffel",
    "klaffen": "klaff",
    "klaffens": "klaff",
    "klaffs": "klaff",
    "klafs": "klafsa",
    "klafsade": "klafsa",
    "klafsades": "klafsa",
    "klafsande": "klafsa",
    "klafsanden": "klafsande",
    "klafsandena": "klafsande",
    "klafsandenas": "klafsande",
    "klafsandens": "klafsande",
    "klafsandes": "klafsande",
    "klafsandet": "klafsande",
    "klafsandets": "klafsande",
    "klafsar": "klafsa",
    "klafsas": "klafsa",
    "klafsat": "klafsa",
    "klafsats": "klafsa",
    "klafset": "klafs",
    "klafsets": "klafs",
    "klag": "klaga",
    "klagad": "klaga",
    "klagade": "klaga",
    "klagades": "klaga",
    "klagads": "klaga",
    "klagande": "klaga",
    "klaganden": "klagande",
    "klagandena": "klagande",
    "klagandenas": "klagande",
    "klagandens": "klagande",
    "klagandes": "klagande",
    "klagans": "klagan",
    "klagar": "klaga",
    "klagas": "klaga",
    "klagat": "klaga",
    "klagats": "klaga",
    "klago": "klaga",
    "klagolåten": "klagolåt",
    "klagolåtens": "klagolåt",
    "klagolåts": "klagolåt",
    "klagomurar": "klagomur",
    "klagomurarna": "klagomur",
    "klagomurarnas": "klagomur",
    "klagomurars": "klagomur",
    "klagomuren": "klagomur",
    "klagomurens": "klagomur",
    "klagomurs": "klagomur",
    "klagomålen": "klagomål",
    "klagomålens": "klagomål",
    "klagomålet": "klagomål",
    "klagomålets": "klagomål",
    "klagomåls": "klagomål",
    "klagoropen": "klagorop",
    "klagoropens": "klagorop",
    "klagoropet": "klagorop",
    "klagoropets": "klagorop",
    "klagorops": "klagorop",
    "klagoskriften": "klagoskrift",
    "klagoskriftens": "klagoskrift",
    "klagoskrifter": "klagoskrift",
    "klagoskrifterna": "klagoskrift",
    "klagoskrifternas": "klagoskrift",
    "klagoskrifters": "klagoskrift",
    "klagoskrifts": "klagoskrift",
    "klagosången": "klagosång",
    "klagosångens": "klagosång",
    "klagosånger": "klagosång",
    "klagosångerna": "klagosång",
    "klagosångernas": "klagosång",
    "klagosångers": "klagosång",
    "klagosångs": "klagosång",
    "klagotiden": "klagotid",
    "klagotidens": "klagotid",
    "klagotider": "klagotid",
    "klagotiderna": "klagotid",
    "klagotidernas": "klagotid",
    "klagotiders": "klagotid",
    "klagotids": "klagotid",
    "klagotjuten": "klagotjut",
    "klagotjutens": "klagotjut",
    "klagotjutet": "klagotjut",
    "klagotjutets": "klagotjut",
    "klagotjuts": "klagotjut",
    "klagotonen": "klagoton",
    "klagotonens": "klagoton",
    "klagotoner": "klagoton",
    "klagotonerna": "klagoton",
    "klagotonernas": "klagoton",
    "klagotoners": "klagoton",
    "klagotons": "klagoton",
    "klagovis": "klagovisa",
    "klagovisan": "klagovisa",
    "klagovisans": "klagovisa",
    "klagovisas": "klagovisa",
    "klagovise": "klagovisa",
    "klagovisor": "klagovisa",
    "klagovisorna": "klagovisa",
    "klagovisornas": "klagovisa",
    "klagovisors": "klagovisa",
    "klammar": "klam",
    "klammarna": "klam",
    "klammarnas": "klam",
    "klammars": "klam",
    "klammen": "klam",
    "klammens": "klam",
    "klammerier": "klammeri",
    "klammerierna": "klammeri",
    "klammeriernas": "klammeri",
    "klammeriers": "klammeri",
    "klammeriet": "klammeri",
    "klammeriets": "klammeri",
    "klammeris": "klammeri",
    "klammerit": "klammeri",
    "klammerits": "klammeri",
    "klammern": "klammer",
    "klammerna": "klammer",
    "klammernas": "klammer",
    "klammerns": "klammer",
    "klammerpistolen": "klammerpistol",
    "klammerpistolens": "klammerpistol",
    "klammerpistoler": "klammerpistol",
    "klammerpistolerna": "klammerpistol",
    "klammerpistolernas": "klammerpistol",
    "klammerpistolers": "klammerpistol",
    "klammerpistols": "klammerpistol",
    "klammers": "klammer",
    "klamp": "klampa",
    "klampad": "klampa",
    "klampade": "klampa",
    "klampades": "klampa",
    "klampads": "klampa",
    "klampande": "klampa",
    "klampanden": "klampande",
    "klampandena": "klampande",
    "klampandenas": "klampande",
    "klampandens": "klampande",
    "klampandes": "klampande",
    "klampandet": "klampande",
    "klampandets": "klampande",
    "klampar": "klampa",
    "klamparna": "klamp",
    "klamparnas": "klamp",
    "klampars": "klamp",
    "klampas": "klampa",
    "klampat": "klampa",
    "klampats": "klampa",
    "klampen": "klamp",
    "klampens": "klamp",
    "klampet": "klamp",
    "klampets": "klamp",
    "klamps": "klamp",
    "klamrad": "klamra",
    "klamrade": "klamra",
    "klamrades": "klamra",
    "klamrads": "klamra",
    "klamrande": "klamra",
    "klamranden": "klamrande",
    "klamrandena": "klamrande",
    "klamrandenas": "klamrande",
    "klamrandens": "klamrande",
    "klamrandes": "klamrande",
    "klamrandet": "klamrande",
    "klamrandets": "klamrande",
    "klamrar": "klamra",
    "klamrarna": "klammer",
    "klamrarnas": "klammer",
    "klamrars": "klammer",
    "klamras": "klamra",
    "klamrat": "klamra",
    "klamrats": "klamra",
    "klams": "klam",
    "klamydian": "klamydia",
    "klamydians": "klamydia",
    "klamydias": "klamydia",
    "klamydiavaccinen": "klamydiavaccin",
    "klamydiavaccinens": "klamydiavaccin",
    "klamydiavacciner": "klamydiavaccin",
    "klamydiavaccinerna": "klamydiavaccin",
    "klamydiavaccinernas": "klamydiavaccin",
    "klamydiavacciners": "klamydiavaccin",
    "klamydiavaccins": "klamydiavaccin",
    "klander": "klandra",
    "klanderfria": "klanderfri",
    "klanderfriare": "klanderfri",
    "klanderfriares": "klanderfri",
    "klanderfrias": "klanderfri",
    "klanderfriast": "klanderfri",
    "klanderfriaste": "klanderfri",
    "klanderfriastes": "klanderfri",
    "klanderfriasts": "klanderfri",
    "klanderfrie": "klanderfri",
    "klanderfries": "klanderfri",
    "klanderfris": "klanderfri",
    "klanderfritt": "klanderfri",
    "klanderfritts": "klanderfri",
    "klanders": "klander",
    "klandervärda": "klandervärd",
    "klandervärdare": "klandervärd",
    "klandervärdares": "klandervärd",
    "klandervärdas": "klandervärd",
    "klandervärdast": "klandervärd",
    "klandervärdaste": "klandervärd",
    "klandervärdastes": "klandervärd",
    "klandervärdasts": "klandervärd",
    "klandervärde": "klandervärd",
    "klandervärdes": "klandervärd",
    "klandervärdheten": "klandervärdhet",
    "klandervärdhetens": "klandervärdhet",
    "klandervärdhets": "klandervärdhet",
    "klandervärds": "klandervärd",
    "klandervärt": "klandervärd",
    "klandervärts": "klandervärd",
    "klandrad": "klandra",
    "klandrade": "klandra",
    "klandrades": "klandra",
    "klandrads": "klandra",
    "klandrande": "klandra",
    "klandranden": "klandrande",
    "klandrandena": "klandrande",
    "klandrandenas": "klandrande",
    "klandrandens": "klandrande",
    "klandrandes": "klandrande",
    "klandrandet": "klandrande",
    "klandrandets": "klandrande",
    "klandrar": "klandra",
    "klandras": "klandra",
    "klandrat": "klandra",
    "klandrats": "klandra",
    "klandret": "klander",
    "klandrets": "klander",
    "klanen": "klan",
    "klanens": "klan",
    "klaner": "klan",
    "klanerna": "klan",
    "klanernas": "klan",
    "klaners": "klan",
    "klang": "klinga",
    "klangbottens": "klangbotten",
    "klangbottnar": "klangbotten",
    "klangbottnarna": "klangbotten",
    "klangbottnarnas": "klangbotten",
    "klangbottnars": "klangbotten",
    "klangbottnen": "klangbotten",
    "klangbottnens": "klangbotten",
    "klange": "klinga",
    "klangen": "klang",
    "klangens": "klang",
    "klanger": "klang",
    "klangerna": "klang",
    "klangernas": "klang",
    "klangers": "klang",
    "klangfulla": "klangfull",
    "klangfullare": "klangfull",
    "klangfullares": "klangfull",
    "klangfullas": "klangfull",
    "klangfullast": "klangfull",
    "klangfullaste": "klangfull",
    "klangfullastes": "klangfull",
    "klangfullasts": "klangfull",
    "klangfulle": "klangfull",
    "klangfulles": "klangfull",
    "klangfullheten": "klangfullhet",
    "klangfullhetens": "klangfullhet",
    "klangfullhets": "klangfullhet",
    "klangfulls": "klangfull",
    "klangfullt": "klangfull",
    "klangfullts": "klangfull",
    "klangfärgen": "klangfärg",
    "klangfärgens": "klangfärg",
    "klangfärger": "klangfärg",
    "klangfärgerna": "klangfärg",
    "klangfärgernas": "klangfärg",
    "klangfärgers": "klangfärg",
    "klangfärgs": "klangfärg",
    "klangliga": "klanglig",
    "klangligare": "klanglig",
    "klangligares": "klanglig",
    "klangligas": "klanglig",
    "klangligast": "klanglig",
    "klangligaste": "klanglig",
    "klangligastes": "klanglig",
    "klangligasts": "klanglig",
    "klanglige": "klanglig",
    "klangliges": "klanglig",
    "klangligs": "klanglig",
    "klangligt": "klanglig",
    "klangligts": "klanglig",
    "klanglösa": "klanglös",
    "klanglösare": "klanglös",
    "klanglösares": "klanglös",
    "klanglösas": "klanglös",
    "klanglösast": "klanglös",
    "klanglösaste": "klanglös",
    "klanglösastes": "klanglös",
    "klanglösasts": "klanglös",
    "klanglöse": "klanglös",
    "klanglöses": "klanglös",
    "klanglösheten": "klanglöshet",
    "klanglöshetens": "klanglöshet",
    "klanglöshets": "klanglöshet",
    "klanglöst": "klanglös",
    "klanglösts": "klanglös",
    "klangmässiga": "klangmässig",
    "klangmässigare": "klangmässig",
    "klangmässigares": "klangmässig",
    "klangmässigas": "klangmässig",
    "klangmässigast": "klangmässig",
    "klangmässigaste": "klangmässig",
    "klangmässigastes": "klangmässig",
    "klangmässigasts": "klangmässig",
    "klangmässige": "klangmässig",
    "klangmässiges": "klangmässig",
    "klangmässigs": "klangmässig",
    "klangmässigt": "klangmässig",
    "klangmässigts": "klangmässig",
    "klangs": "klang",
    "klanhövdingar": "klanhövding",
    "klanhövdingarna": "klanhövding",
    "klanhövdingarnas": "klanhövding",
    "klanhövdingars": "klanhövding",
    "klanhövdingen": "klanhövding",
    "klanhövdingens": "klanhövding",
    "klanhövdings": "klanhövding",
    "klankade": "klanka",
    "klankades": "klanka",
    "klankande": "klanka",
    "klankanden": "klankande",
    "klankandena": "klankande",
    "klankandenas": "klankande",
    "klankandens": "klankande",
    "klankandes": "klankande",
    "klankandet": "klankande",
    "klankandets": "klankande",
    "klankar": "klanka",
    "klankas": "klanka",
    "klankat": "klanka",
    "klankats": "klanka",
    "klanket": "klank",
    "klankets": "klank",
    "klanks": "klank",
    "klanmässiga": "klanmässig",
    "klanmässigare": "klanmässig",
    "klanmässigares": "klanmässig",
    "klanmässigas": "klanmässig",
    "klanmässigast": "klanmässig",
    "klanmässigaste": "klanmässig",
    "klanmässigastes": "klanmässig",
    "klanmässigasts": "klanmässig",
    "klanmässige": "klanmässig",
    "klanmässiges": "klanmässig",
    "klanmässigs": "klanmässig",
    "klanmässigt": "klanmässig",
    "klanmässigts": "klanmässig",
    "klans": "klan",
    "klansoldaten": "klansoldat",
    "klansoldatens": "klansoldat",
    "klansoldater": "klansoldat",
    "klansoldaterna": "klansoldat",
    "klansoldaternas": "klansoldat",
    "klansoldaters": "klansoldat",
    "klansoldats": "klansoldat",
    "klanstriden": "klanstrid",
    "klanstridens": "klanstrid",
    "klanstrider": "klanstrid",
    "klanstriderna": "klanstrid",
    "klanstridernas": "klanstrid",
    "klanstriders": "klanstrid",
    "klanstrids": "klanstrid",
    "klantar": "klant",
    "klantarna": "klant",
    "klantarnas": "klant",
    "klantars": "klant",
    "klanten": "klant",
    "klantens": "klant",
    "klantiga": "klantig",
    "klantigare": "klantig",
    "klantigares": "klantig",
    "klantigas": "klantig",
    "klantigast": "klantig",
    "klantigaste": "klantig",
    "klantigastes": "klantig",
    "klantigasts": "klantig",
    "klantige": "klantig",
    "klantiges": "klantig",
    "klantigheten": "klantighet",
    "klantighetens": "klantighet",
    "klantigheter": "klantighet",
    "klantigheterna": "klantighet",
    "klantigheternas": "klantighet",
    "klantigheters": "klantighet",
    "klantighets": "klantighet",
    "klantigs": "klantig",
    "klantigt": "klantig",
    "klantigts": "klantig",
    "klants": "klant",
    "klantskall": "klantskalle",
    "klantskallar": "klantskalle",
    "klantskallarna": "klantskalle",
    "klantskallarnas": "klantskalle",
    "klantskallars": "klantskalle",
    "klantskallen": "klantskalle",
    "klantskallens": "klantskalle",
    "klantskalles": "klantskalle",
    "klantskalls": "klantskalle",
    "klapp": "klappa",
    "klappad": "klappa",
    "klappade": "klappa",
    "klappades": "klappa",
    "klappads": "klappa",
    "klappan": "klappa",
    "klappande": "klappa",
    "klappanden": "klappande",
    "klappandena": "klappande",
    "klappandenas": "klappande",
    "klappandens": "klappande",
    "klappandes": "klappande",
    "klappandet": "klappande",
    "klappandets": "klappande",
    "klappans": "klappa",
    "klappar": "klappa",
    "klapparna": "klapp",
    "klapparnas": "klapp",
    "klappars": "klapp",
    "klappas": "klappa",
    "klappat": "klappa",
    "klappats": "klappa",
    "klappbrygg": "klappbrygga",
    "klappbryggan": "klappbrygga",
    "klappbryggans": "klappbrygga",
    "klappbryggas": "klappbrygga",
    "klappbrygge": "klappbrygga",
    "klappbryggor": "klappbrygga",
    "klappbryggorna": "klappbrygga",
    "klappbryggornas": "klappbrygga",
    "klappbryggors": "klappbrygga",
    "klappbryggs": "klappbrygga",
    "klappbräd": "klappbräda",
    "klappbrädan": "klappbräda",
    "klappbrädans": "klappbräda",
    "klappbrädas": "klappbräda",
    "klappbräde": "klappbräda",
    "klappbräden": "klappbräde",
    "klappbrädena": "klappbräde",
    "klappbrädenas": "klappbräde",
    "klappbrädens": "klappbräde",
    "klappbrädes": "klappbräde",
    "klappbrädet": "klappbräde",
    "klappbrädets": "klappbräde",
    "klappbrädor": "klappbräda",
    "klappbrädorna": "klappbräda",
    "klappbrädornas": "klappbräda",
    "klappbrädors": "klappbräda",
    "klappbräds": "klappbräda",
    "klappe": "klappa",
    "klappen": "klapp",
    "klappens": "klapp",
    "klapper": "klappra",
    "klappern": "klapper",
    "klapperns": "klapper",
    "klappers": "klapper",
    "klapperstenar": "klappersten",
    "klapperstenarna": "klappersten",
    "klapperstenarnas": "klappersten",
    "klapperstenars": "klappersten",
    "klapperstenen": "klappersten",
    "klapperstenens": "klappersten",
    "klapperstens": "klappersten",
    "klapperstenstranden": "klapperstenstrand",
    "klapperstenstrandens": "klapperstenstrand",
    "klapperstenstrands": "klapperstenstrand",
    "klapperstenstränder": "klapperstenstrand",
    "klapperstenstränderna": "klapperstenstrand",
    "klapperstensträndernas": "klapperstenstrand",
    "klapperstenstränders": "klapperstenstrand",
    "klappjakten": "klappjakt",
    "klappjaktens": "klappjakt",
    "klappjakter": "klappjakt",
    "klappjakterna": "klappjakt",
    "klappjakternas": "klappjakt",
    "klappjakters": "klappjakt",
    "klappjakts": "klappjakt",
    "klappor": "klappa",
    "klapporna": "klappa",
    "klappornas": "klappa",
    "klappors": "klappa",
    "klapprade": "klappra",
    "klapprades": "klappra",
    "klapprande": "klappra",
    "klappranden": "klapprande",
    "klapprandena": "klapprande",
    "klapprandenas": "klapprande",
    "klapprandens": "klapprande",
    "klapprandes": "klapprande",
    "klapprandet": "klapprande",
    "klapprandets": "klapprande",
    "klapprar": "klappra",
    "klappras": "klappra",
    "klapprat": "klappra",
    "klapprats": "klappra",
    "klappret": "klapper",
    "klapprets": "klapper",
    "klapps": "klappa",
    "klappshoppingen": "klappshopping",
    "klappshoppingens": "klappshopping",
    "klappshoppings": "klappshopping",
    "klappträet": "klappträ",
    "klappträets": "klappträ",
    "klappträn": "klappträ",
    "klappträna": "klappträ",
    "klapptränas": "klappträ",
    "klappträns": "klappträ",
    "klappträs": "klappträ",
    "klappträt": "klappträ",
    "klappträts": "klappträ",
    "klara": "klar",
    "klarad": "klara",
    "klarade": "klara",
    "klarades": "klara",
    "klarads": "klara",
    "klarande": "klara",
    "klaranden": "klarande",
    "klarandena": "klarande",
    "klarandenas": "klarande",
    "klarandens": "klarande",
    "klarandes": "klarande",
    "klarandet": "klarande",
    "klarandets": "klarande",
    "klarar": "klara",
    "klarare": "klar",
    "klarares": "klar",
    "klaras": "klara",
    "klarast": "klar",
    "klaraste": "klar",
    "klarastes": "klar",
    "klarasts": "klar",
    "klarat": "klara",
    "klarats": "klara",
    "klarblåa": "klarblå",
    "klarblåare": "klarblå",
    "klarblåares": "klarblå",
    "klarblåas": "klarblå",
    "klarblåast": "klarblå",
    "klarblåaste": "klarblå",
    "klarblåastes": "klarblå",
    "klarblåasts": "klarblå",
    "klarblåe": "klarblå",
    "klarblåes": "klarblå",
    "klarblås": "klarblå",
    "klarblått": "klarblå",
    "klarblåtts": "klarblå",
    "klarbären": "klarbär",
    "klarbärens": "klarbär",
    "klarbäret": "klarbär",
    "klarbärets": "klarbär",
    "klarbärs": "klarbär",
    "klare": "klar",
    "klarerad": "klarera",
    "klarerade": "klarera",
    "klarerades": "klarera",
    "klarerads": "klarera",
    "klarerande": "klarera",
    "klareranden": "klarerande",
    "klarerandena": "klarerande",
    "klarerandenas": "klarerande",
    "klarerandens": "klarerande",
    "klarerandes": "klarerande",
    "klarerandet": "klarerande",
    "klarerandets": "klarerande",
    "klarerar": "klarera",
    "klareras": "klarera",
    "klarerat": "klarera",
    "klarerats": "klarera",
    "klarerbara": "klarerbar",
    "klarerbarare": "klarerbar",
    "klarerbarares": "klarerbar",
    "klarerbaras": "klarerbar",
    "klarerbarast": "klarerbar",
    "klarerbaraste": "klarerbar",
    "klarerbarastes": "klarerbar",
    "klarerbarasts": "klarerbar",
    "klarerbare": "klarerbar",
    "klarerbares": "klarerbar",
    "klarerbarheten": "klarerbarhet",
    "klarerbarhetens": "klarerbarhet",
    "klarerbarhets": "klarerbarhet",
    "klarerbars": "klarerbar",
    "klarerbart": "klarerbar",
    "klarerbarts": "klarerbar",
    "klareringar": "klarering",
    "klareringarna": "klarering",
    "klareringarnas": "klarering",
    "klareringars": "klarering",
    "klareringen": "klarering",
    "klareringens": "klarering",
    "klarerings": "klarering",
    "klares": "klar",
    "klargjord": "klargöra",
    "klargjorda": "klargöra",
    "klargjordas": "klargöra",
    "klargjorde": "klargöra",
    "klargjordes": "klargöra",
    "klargjords": "klargöra",
    "klargjort": "klargöra",
    "klargjorts": "klargöra",
    "klargör": "klargöra",
    "klargörande": "klargöra",
    "klargöranden": "klargörande",
    "klargörandena": "klargörande",
    "klargörandenas": "klargörande",
    "klargörandens": "klargörande",
    "klargörandes": "klargörande",
    "klargörandet": "klargörande",
    "klargörandets": "klargörande",
    "klargöras": "klargöra",
    "klargöres": "klargöra",
    "klargörs": "klargöra",
    "klarheten": "klarhet",
    "klarhetens": "klarhet",
    "klarheter": "klarhet",
    "klarheterna": "klarhet",
    "klarheternas": "klarhet",
    "klarheters": "klarhet",
    "klarhets": "klarhet",
    "klarinetten": "klarinett",
    "klarinettens": "klarinett",
    "klarinetter": "klarinett",
    "klarinetterna": "klarinett",
    "klarinetternas": "klarinett",
    "klarinetters": "klarinett",
    "klarinettisten": "klarinettist",
    "klarinettistens": "klarinettist",
    "klarinettister": "klarinettist",
    "klarinettisterna": "klarinettist",
    "klarinettisternas": "klarinettist",
    "klarinettisters": "klarinettist",
    "klarinettists": "klarinettist",
    "klarinetts": "klarinett",
    "klarla": "klarlägga",
    "klarlacker": "klarlack",
    "klarlackerna": "klarlack",
    "klarlackernas": "klarlack",
    "klarlackers": "klarlack",
    "klarlacket": "klarlack",
    "klarlackets": "klarlack",
    "klarlacks": "klarlack",
    "klarlade": "klarlägga",
    "klarlades": "klarlägga",
    "klarlagd": "klarlägga",
    "klarlagda": "klarlägga",
    "klarlagdas": "klarlägga",
    "klarlagde": "klarlägga",
    "klarlagdes": "klarlägga",
    "klarlagds": "klarlägga",
    "klarlagt": "klarlägga",
    "klarlagts": "klarlägga",
    "klarlas": "klarlägga",
    "klarlägg": "klarlägga",
    "klarläggande": "klarlägga",
    "klarlägganden": "klarläggande",
    "klarläggandena": "klarläggande",
    "klarläggandenas": "klarläggande",
    "klarläggandens": "klarläggande",
    "klarläggandes": "klarläggande",
    "klarläggandet": "klarläggande",
    "klarläggandets": "klarläggande",
    "klarläggas": "klarlägga",
    "klarlägger": "klarlägga",
    "klarlägges": "klarlägga",
    "klarläggs": "klarlägga",
    "klarmedels": "klarmedel",
    "klarmedlen": "klarmedel",
    "klarmedlens": "klarmedel",
    "klarmedlet": "klarmedel",
    "klarmedlets": "klarmedel",
    "klarnade": "klarna",
    "klarnades": "klarna",
    "klarnande": "klarna",
    "klarnanden": "klarnande",
    "klarnandena": "klarnande",
    "klarnandenas": "klarnande",
    "klarnandens": "klarnande",
    "klarnandes": "klarnande",
    "klarnandet": "klarnande",
    "klarnandets": "klarnande",
    "klarnar": "klarna",
    "klarnas": "klarna",
    "klarnat": "klarna",
    "klarnats": "klarna",
    "klarröda": "klarröd",
    "klarrödare": "klarröd",
    "klarrödares": "klarröd",
    "klarrödas": "klarröd",
    "klarrödast": "klarröd",
    "klarrödaste": "klarröd",
    "klarrödastes": "klarröd",
    "klarrödasts": "klarröd",
    "klarröde": "klarröd",
    "klarrödes": "klarröd",
    "klarröds": "klarröd",
    "klarrött": "klarröd",
    "klarrötts": "klarröd",
    "klars": "klar",
    "klarsignalen": "klarsignal",
    "klarsignalens": "klarsignal",
    "klarsignaler": "klarsignal",
    "klarsignalerna": "klarsignal",
    "klarsignalernas": "klarsignal",
    "klarsignalers": "klarsignal",
    "klarsignals": "klarsignal",
    "klarskinnen": "klarskinn",
    "klarskinnens": "klarskinn",
    "klarskinnet": "klarskinn",
    "klarskinnets": "klarskinn",
    "klarskinns": "klarskinn",
    "klarspråket": "klarspråk",
    "klarspråkets": "klarspråk",
    "klarspråks": "klarspråk",
    "klarsynen": "klarsyn",
    "klarsynens": "klarsyn",
    "klarsyns": "klarsyn",
    "klarsynta": "klarsynt",
    "klarsyntare": "klarsynt",
    "klarsyntares": "klarsynt",
    "klarsyntas": "klarsynt",
    "klarsyntast": "klarsynt",
    "klarsyntaste": "klarsynt",
    "klarsyntastes": "klarsynt",
    "klarsyntasts": "klarsynt",
    "klarsynte": "klarsynt",
    "klarsyntes": "klarsynt",
    "klarsyntheten": "klarsynthet",
    "klarsynthetens": "klarsynthet",
    "klarsynthets": "klarsynthet",
    "klarsynts": "klarsynt",
    "klart": "klar",
    "klarteckens": "klartecken",
    "klartecknen": "klartecken",
    "klartecknens": "klartecken",
    "klartecknet": "klartecken",
    "klartecknets": "klartecken",
    "klartexten": "klartext",
    "klartextens": "klartext",
    "klartexts": "klartext",
    "klarts": "klar",
    "klartänkta": "klartänkt",
    "klartänktare": "klartänkt",
    "klartänktares": "klartänkt",
    "klartänktas": "klartänkt",
    "klartänktast": "klartänkt",
    "klartänktaste": "klartänkt",
    "klartänktastes": "klartänkt",
    "klartänktasts": "klartänkt",
    "klartänkte": "klartänkt",
    "klartänktes": "klartänkt",
    "klartänktheten": "klartänkthet",
    "klartänkthetens": "klartänkthet",
    "klartänkthets": "klartänkthet",
    "klartänkts": "klartänkt",
    "klarvakenheten": "klarvakenhet",
    "klarvakenhetens": "klarvakenhet",
    "klarvakenhets": "klarvakenhet",
    "klarvakens": "klarvaken",
    "klarvaket": "klarvaken",
    "klarvakets": "klarvaken",
    "klarvakna": "klarvaken",
    "klarvaknare": "klarvaken",
    "klarvaknares": "klarvaken",
    "klarvaknas": "klarvaken",
    "klarvaknast": "klarvaken",
    "klarvaknaste": "klarvaken",
    "klarvaknastes": "klarvaken",
    "klarvaknasts": "klarvaken",
    "klarvakne": "klarvaken",
    "klarvaknes": "klarvaken",
    "klarögda": "klarögd",
    "klarögdare": "klarögd",
    "klarögdares": "klarögd",
    "klarögdas": "klarögd",
    "klarögdast": "klarögd",
    "klarögdaste": "klarögd",
    "klarögdastes": "klarögd",
    "klarögdasts": "klarögd",
    "klarögde": "klarögd",
    "klarögdes": "klarögd",
    "klarögdheten": "klarögdhet",
    "klarögdhetens": "klarögdhet",
    "klarögdhets": "klarögdhet",
    "klarögds": "klarögd",
    "klarögt": "klarögd",
    "klarögts": "klarögd",
    "klas": "klase",
    "klasar": "klase",
    "klasarna": "klase",
    "klasarnas": "klase",
    "klasars": "klase",
    "klasen": "klase",
    "klasens": "klase",
    "klases": "klase",
    "klass": "klassa",
    "klassad": "klassa",
    "klassade": "klassa",
    "klassades": "klassa",
    "klassads": "klassa",
    "klassamhällen": "klassamhälle",
    "klassamhällena": "klassamhälle",
    "klassamhällenas": "klassamhälle",
    "klassamhällens": "klassamhälle",
    "klassamhälles": "klassamhälle",
    "klassamhället": "klassamhälle",
    "klassamhällets": "klassamhälle",
    "klassamhälls": "klassamhälle",
    "klassande": "klassa",
    "klassanden": "klassande",
    "klassandena": "klassande",
    "klassandenas": "klassande",
    "klassandens": "klassande",
    "klassandes": "klassande",
    "klassandet": "klassande",
    "klassandets": "klassande",
    "klassar": "klassa",
    "klassas": "klassa",
    "klassat": "klassa",
    "klassats": "klassa",
    "klassboken": "klassbok",
    "klassbokens": "klassbok",
    "klassboks": "klassbok",
    "klassböcker": "klassbok",
    "klassböckerna": "klassbok",
    "klassböckernas": "klassbok",
    "klassböckers": "klassbok",
    "klassen": "klass",
    "klassens": "klass",
    "klasser": "klass",
    "klasserna": "klass",
    "klassernas": "klass",
    "klassers": "klass",
    "klassföreståndar": "klassföreståndare",
    "klassföreståndaren": "klassföreståndare",
    "klassföreståndarens": "klassföreståndare",
    "klassföreståndares": "klassföreståndare",
    "klassföreståndarna": "klassföreståndare",
    "klassföreståndarnas": "klassföreståndare",
    "klassförrädar": "klassförrädare",
    "klassförrädaren": "klassförrädare",
    "klassförrädarens": "klassförrädare",
    "klassförrädares": "klassförrädare",
    "klassförrädarna": "klassförrädare",
    "klassförrädarnas": "klassförrädare",
    "klassicismen": "klassicism",
    "klassicismens": "klassicism",
    "klassicismer": "klassicism",
    "klassicismerna": "klassicism",
    "klassicismernas": "klassicism",
    "klassicismers": "klassicism",
    "klassicisms": "klassicism",
    "klassicistiska": "klassicistisk",
    "klassicistiskas": "klassicistisk",
    "klassicistiske": "klassicistisk",
    "klassicistiskes": "klassicistisk",
    "klassicistisks": "klassicistisk",
    "klassicistiskt": "klassicistisk",
    "klassicistiskts": "klassicistisk",
    "klassiciteten": "klassicitet",
    "klassicitetens": "klassicitet",
    "klassiciteter": "klassicitet",
    "klassiciteterna": "klassicitet",
    "klassiciteternas": "klassicitet",
    "klassiciteters": "klassicitet",
    "klassicitets": "klassicitet",
    "klassificerad": "klassificera",
    "klassificerade": "klassificera",
    "klassificerades": "klassificera",
    "klassificerads": "klassificera",
    "klassificerande": "klassificera",
    "klassificeranden": "klassificerande",
    "klassificerandena": "klassificerande",
    "klassificerandenas": "klassificerande",
    "klassificerandens": "klassificerande",
    "klassificerandes": "klassificerande",
    "klassificerandet": "klassificerande",
    "klassificerandets": "klassificerande",
    "klassificerar": "klassificera",
    "klassificeras": "klassificera",
    "klassificerat": "klassificera",
    "klassificerats": "klassificera",
    "klassificerbara": "klassificerbar",
    "klassificerbarare": "klassificerbar",
    "klassificerbarares": "klassificerbar",
    "klassificerbaras": "klassificerbar",
    "klassificerbarast": "klassificerbar",
    "klassificerbaraste": "klassificerbar",
    "klassificerbarastes": "klassificerbar",
    "klassificerbarasts": "klassificerbar",
    "klassificerbare": "klassificerbar",
    "klassificerbares": "klassificerbar",
    "klassificerbarheten": "klassificerbarhet",
    "klassificerbarhetens": "klassificerbarhet",
    "klassificerbarhets": "klassificerbarhet",
    "klassificerbars": "klassificerbar",
    "klassificerbart": "klassificerbar",
    "klassificerbarts": "klassificerbar",
    "klassificeringar": "klassificering",
    "klassificeringarna": "klassificering",
    "klassificeringarnas": "klassificering",
    "klassificeringars": "klassificering",
    "klassificeringen": "klassificering",
    "klassificeringens": "klassificering",
    "klassificerings": "klassificering",
    "klassifikationen": "klassifikation",
    "klassifikationens": "klassifikation",
    "klassifikationer": "klassifikation",
    "klassifikationerna": "klassifikation",
    "klassifikationernas": "klassifikation",
    "klassifikationers": "klassifikation",
    "klassifikations": "klassifikation",
    "klassiken": "klassik",
    "klassikens": "klassik",
    "klassiker": "klassik",
    "klassikern": "klassiker",
    "klassikerna": "klassiker",
    "klassikernas": "klassiker",
    "klassikerns": "klassiker",
    "klassikers": "klassiker",
    "klassiks": "klassik",
    "klassiska": "klassisk",
    "klassiskare": "klassisk",
    "klassiskares": "klassisk",
    "klassiskas": "klassisk",
    "klassiskast": "klassisk",
    "klassiskaste": "klassisk",
    "klassiskastes": "klassisk",
    "klassiskasts": "klassisk",
    "klassiske": "klassisk",
    "klassiskes": "klassisk",
    "klassisks": "klassisk",
    "klassiskt": "klassisk",
    "klassiskts": "klassisk",
    "klasskampen": "klasskamp",
    "klasskampens": "klasskamp",
    "klasskamper": "klasskamp",
    "klasskamperna": "klasskamp",
    "klasskampernas": "klasskamp",
    "klasskampers": "klasskamp",
    "klasskamps": "klasskamp",
    "klasskamraten": "klasskamrat",
    "klasskamratens": "klasskamrat",
    "klasskamrater": "klasskamrat",
    "klasskamraterna": "klasskamrat",
    "klasskamraternas": "klasskamrat",
    "klasskamraters": "klasskamrat",
    "klasskamrats": "klasskamrat",
    "klasskillnaden": "klasskillnad",
    "klasskillnadens": "klasskillnad",
    "klasskillnader": "klasskillnad",
    "klasskillnaderna": "klasskillnad",
    "klasskillnadernas": "klasskillnad",
    "klasskillnaders": "klasskillnad",
    "klasskillnads": "klasskillnad",
    "klassklyftan": "klassklyfta",
    "klassklyftans": "klassklyfta",
    "klassklyftas": "klassklyfta",
    "klassklyfte": "klassklyfta",
    "klassklyftor": "klassklyfta",
    "klassklyftorna": "klassklyfta",
    "klassklyftornas": "klassklyfta",
    "klassklyftors": "klassklyfta",
    "klasskonferensen": "klasskonferens",
    "klasskonferensens": "klasskonferens",
    "klasskonferenser": "klasskonferens",
    "klasskonferenserna": "klasskonferens",
    "klasskonferensernas": "klasskonferens",
    "klasskonferensers": "klasskonferens",
    "klasslagar": "klasslag",
    "klasslagarna": "klasslag",
    "klasslagarnas": "klasslag",
    "klasslagars": "klasslag",
    "klasslagen": "klasslag",
    "klasslagens": "klasslag",
    "klasslaget": "klasslag",
    "klasslagets": "klasslag",
    "klasslags": "klasslag",
    "klasslärar": "klasslärare",
    "klassläraren": "klasslärare",
    "klasslärarens": "klasslärare",
    "klasslärares": "klasslärare",
    "klasslärarna": "klasslärare",
    "klasslärarnas": "klasslärare",
    "klasslösa": "klasslös",
    "klasslösare": "klasslös",
    "klasslösares": "klasslös",
    "klasslösas": "klasslös",
    "klasslösast": "klasslös",
    "klasslösaste": "klasslös",
    "klasslösastes": "klasslös",
    "klasslösasts": "klasslös",
    "klasslöse": "klasslös",
    "klasslöses": "klasslös",
    "klasslösheten": "klasslöshet",
    "klasslöshetens": "klasslöshet",
    "klasslöshets": "klasslöshet",
    "klasslöst": "klasslös",
    "klasslösts": "klasslös",
    "klassmamman": "klassmamma",
    "klassmammans": "klassmamma",
    "klassmammas": "klassmamma",
    "klassmamme": "klassmamma",
    "klassmammor": "klassmamma",
    "klassmammorna": "klassmamma",
    "klassmammornas": "klassmamma",
    "klassmammors": "klassmamma",
    "klassmedvetandes": "klassmedvetande",
    "klassmedvetandet": "klassmedvetande",
    "klassmedvetandets": "klassmedvetande",
    "klassmedvetenheten": "klassmedvetenhet",
    "klassmedvetenhetens": "klassmedvetenhet",
    "klassmedvetenhets": "klassmedvetenhet",
    "klassmedvetens": "klassmedveten",
    "klassmedvetet": "klassmedveten",
    "klassmedvetets": "klassmedveten",
    "klassmedvetna": "klassmedveten",
    "klassmedvetnare": "klassmedveten",
    "klassmedvetnares": "klassmedveten",
    "klassmedvetnas": "klassmedveten",
    "klassmedvetnast": "klassmedveten",
    "klassmedvetnaste": "klassmedveten",
    "klassmedvetnastes": "klassmedveten",
    "klassmedvetnasts": "klassmedveten",
    "klassmedvetne": "klassmedveten",
    "klassmedvetnes": "klassmedveten",
    "klassmotsättningar": "klassmotsättning",
    "klassmotsättningarna": "klassmotsättning",
    "klassmotsättningarnas": "klassmotsättning",
    "klassmotsättningars": "klassmotsättning",
    "klassmotsättningen": "klassmotsättning",
    "klassmotsättningens": "klassmotsättning",
    "klassmotsättnings": "klassmotsättning",
    "klassmärken": "klassmärke",
    "klassmärkena": "klassmärke",
    "klassmärkenas": "klassmärke",
    "klassmärkens": "klassmärke",
    "klassmärkes": "klassmärke",
    "klassmärket": "klassmärke",
    "klassmärkets": "klassmärke",
    "klassmässiga": "klassmässig",
    "klassmässigare": "klassmässig",
    "klassmässigares": "klassmässig",
    "klassmässigas": "klassmässig",
    "klassmässigast": "klassmässig",
    "klassmässigaste": "klassmässig",
    "klassmässigastes": "klassmässig",
    "klassmässigasts": "klassmässig",
    "klassmässige": "klassmässig",
    "klassmässiges": "klassmässig",
    "klassmässigs": "klassmässig",
    "klassmässigt": "klassmässig",
    "klassmässigts": "klassmässig",
    "klassmörjen": "klassmörj",
    "klassmörjens": "klassmörj",
    "klassmörjet": "klassmörj",
    "klassmörjets": "klassmörj",
    "klassmörjs": "klassmörj",
    "klasspappan": "klasspappa",
    "klasspappans": "klasspappa",
    "klasspappas": "klasspappa",
    "klasspappor": "klasspappa",
    "klasspapporna": "klasspappa",
    "klasspappornas": "klasspappa",
    "klasspappors": "klasspappa",
    "klassresan": "klassresa",
    "klassresans": "klassresa",
    "klassresas": "klassresa",
    "klassrese": "klassresa",
    "klassresor": "klassresa",
    "klassresorna": "klassresa",
    "klassresornas": "klassresa",
    "klassresors": "klassresa",
    "klassrummen": "klassrum",
    "klassrummens": "klassrum",
    "klassrummet": "klassrum",
    "klassrummets": "klassrum",
    "klassrums": "klassrum",
    "klasstillhörigheten": "klasstillhörighet",
    "klasstillhörighetens": "klasstillhörighet",
    "klasstillhörighets": "klasstillhörighet",
    "klasstrukturen": "klasstruktur",
    "klasstrukturens": "klasstruktur",
    "klasstrukturer": "klasstruktur",
    "klasstrukturerna": "klasstruktur",
    "klasstrukturernas": "klasstruktur",
    "klasstrukturers": "klasstruktur",
    "klasstrukturs": "klasstruktur",
    "klasstryket": "klasstryk",
    "klasstrykets": "klasstryk",
    "klasstryks": "klasstryk",
    "klassundervisningar": "klassundervisning",
    "klassundervisningarna": "klassundervisning",
    "klassundervisningarnas": "klassundervisning",
    "klassundervisningars": "klassundervisning",
    "klassundervisningen": "klassundervisning",
    "klassundervisningens": "klassundervisning",
    "klassundervisnings": "klassundervisning",
    "klatraten": "klatrat",
    "klatratens": "klatrat",
    "klatrater": "klatrat",
    "klatraterna": "klatrat",
    "klatraternas": "klatrat",
    "klatraters": "klatrat",
    "klatrathydraten": "klatrathydrat",
    "klatrathydratens": "klatrathydrat",
    "klatrathydrater": "klatrathydrat",
    "klatrathydraterna": "klatrathydrat",
    "klatrathydraternas": "klatrathydrat",
    "klatrathydraters": "klatrathydrat",
    "klatrathydrats": "klatrathydrat",
    "klatratkomplexen": "klatratkomplex",
    "klatratkomplexens": "klatratkomplex",
    "klatratkomplexet": "klatratkomplex",
    "klatratkomplexets": "klatratkomplex",
    "klatrats": "klatrat",
    "klatsch": "klatscha",
    "klatschad": "klatscha",
    "klatschade": "klatscha",
    "klatschades": "klatscha",
    "klatschads": "klatscha",
    "klatschande": "klatscha",
    "klatschanden": "klatschande",
    "klatschandena": "klatschande",
    "klatschandenas": "klatschande",
    "klatschandens": "klatschande",
    "klatschandes": "klatschande",
    "klatschandet": "klatschande",
    "klatschandets": "klatschande",
    "klatschar": "klatscha",
    "klatscharna": "klatsch",
    "klatscharnas": "klatsch",
    "klatschars": "klatsch",
    "klatschas": "klatscha",
    "klatschat": "klatscha",
    "klatschats": "klatscha",
    "klatschen": "klatsch",
    "klatschens": "klatsch",
    "klatschiga": "klatschig",
    "klatschigare": "klatschig",
    "klatschigares": "klatschig",
    "klatschigas": "klatschig",
    "klatschigast": "klatschig",
    "klatschigaste": "klatschig",
    "klatschigastes": "klatschig",
    "klatschigasts": "klatschig",
    "klatschige": "klatschig",
    "klatschiges": "klatschig",
    "klatschigheten": "klatschighet",
    "klatschighetens": "klatschighet",
    "klatschighets": "klatschighet",
    "klatschigs": "klatschig",
    "klatschigt": "klatschig",
    "klatschigts": "klatschig",
    "klatschs": "klatsch",
    "klaustrofobien": "klaustrofobi",
    "klaustrofobiens": "klaustrofobi",
    "klaustrofobin": "klaustrofobi",
    "klaustrofobins": "klaustrofobi",
    "klaustrofobis": "klaustrofobi",
    "klausulen": "klausul",
    "klausulens": "klausul",
    "klausuler": "klausul",
    "klausulerna": "klausul",
    "klausulernas": "klausul",
    "klausulers": "klausul",
    "klausuls": "klausul",
    "klav": "klave",
    "klavar": "klave",
    "klavarna": "klave",
    "klavarnas": "klave",
    "klavars": "klave",
    "klavband": "klavbinda",
    "klavbands": "klavbinda",
    "klavbind": "klavbinda",
    "klavbindande": "klavbinda",
    "klavbindanden": "klavbindande",
    "klavbindandena": "klavbindande",
    "klavbindandenas": "klavbindande",
    "klavbindandens": "klavbindande",
    "klavbindandes": "klavbindande",
    "klavbindandet": "klavbindande",
    "klavbindandets": "klavbindande",
    "klavbindas": "klavbinda",
    "klavbinde": "klavbinda",
    "klavbinder": "klavbinda",
    "klavbindes": "klavbinda",
    "klavbinds": "klavbinda",
    "klavbunde": "klavbinda",
    "klavbunden": "klavbinda",
    "klavbundens": "klavbinda",
    "klavbundes": "klavbinda",
    "klavbundet": "klavbinda",
    "klavbundets": "klavbinda",
    "klavbundit": "klavbinda",
    "klavbundits": "klavbinda",
    "klavbundna": "klavbinda",
    "klavbundnas": "klavbinda",
    "klavbundne": "klavbinda",
    "klavbundnes": "klavbinda",
    "klavecinen": "klavecin",
    "klavecinens": "klavecin",
    "klaveciner": "klavecin",
    "klavecinerna": "klavecin",
    "klavecinernas": "klavecin",
    "klaveciners": "klavecin",
    "klavecins": "klavecin",
    "klaven": "klave",
    "klavens": "klave",
    "klaver": "klav",
    "klaveren": "klaver",
    "klaverens": "klaver",
    "klaveret": "klaver",
    "klaverets": "klaver",
    "klaverna": "klav",
    "klavernas": "klav",
    "klavers": "klaver",
    "klavertrampen": "klavertramp",
    "klavertrampens": "klavertramp",
    "klavertrampet": "klavertramp",
    "klavertrampets": "klavertramp",
    "klavertramps": "klavertramp",
    "klaverutdragen": "klaverutdrag",
    "klaverutdragens": "klaverutdrag",
    "klaverutdraget": "klaverutdrag",
    "klaverutdragets": "klaverutdrag",
    "klaverutdrags": "klaverutdrag",
    "klaves": "klave",
    "klaviaturen": "klaviatur",
    "klaviaturens": "klaviatur",
    "klaviaturer": "klaviatur",
    "klaviaturerna": "klaviatur",
    "klaviaturernas": "klaviatur",
    "klaviaturers": "klaviatur",
    "klaviaturs": "klaviatur",
    "klavikorden": "klavikord",
    "klavikordens": "klavikord",
    "klavikordet": "klavikord",
    "klavikordets": "klavikord",
    "klavikords": "klavikord",
    "klavs": "klave",
    "klem": "klema",
    "klemade": "klema",
    "klemades": "klema",
    "klemande": "klema",
    "klemanden": "klemande",
    "klemandena": "klemande",
    "klemandenas": "klemande",
    "klemandens": "klemande",
    "klemandes": "klemande",
    "klemandet": "klemande",
    "klemandets": "klemande",
    "klemar": "klema",
    "klemas": "klema",
    "klemat": "klema",
    "klematisar": "klematis",
    "klematisarna": "klematis",
    "klematisarnas": "klematis",
    "klematisars": "klematis",
    "klematisen": "klematis",
    "klematisens": "klematis",
    "klemats": "klema",
    "klementinen": "klementin",
    "klementinens": "klementin",
    "klementiner": "klementin",
    "klementinerna": "klementin",
    "klementinernas": "klementin",
    "klementiners": "klementin",
    "klementins": "klementin",
    "klemiga": "klemig",
    "klemigare": "klemig",
    "klemigares": "klemig",
    "klemigas": "klemig",
    "klemigast": "klemig",
    "klemigaste": "klemig",
    "klemigastes": "klemig",
    "klemigasts": "klemig",
    "klemige": "klemig",
    "klemiges": "klemig",
    "klemigs": "klemig",
    "klemigt": "klemig",
    "klemigts": "klemig",
    "klen": "klena",
    "klena": "klen",
    "klenad": "klena",
    "klenade": "klena",
    "klenades": "klena",
    "klenads": "klena",
    "klenande": "klena",
    "klenanden": "klenande",
    "klenandena": "klenande",
    "klenandenas": "klenande",
    "klenandens": "klenande",
    "klenandes": "klenande",
    "klenandet": "klenande",
    "klenandets": "klenande",
    "klenar": "klena",
    "klenare": "klen",
    "klenares": "klen",
    "klenas": "klena",
    "klenast": "klen",
    "klenaste": "klen",
    "klenastes": "klen",
    "klenasts": "klen",
    "klenat": "klena",
    "klenats": "klena",
    "klene": "klen",
    "klenes": "klen",
    "klenheten": "klenhet",
    "klenhetens": "klenhet",
    "klenhets": "klenhet",
    "klenhusen": "klenhus",
    "klenhusens": "klenhus",
    "klenhuset": "klenhus",
    "klenhusets": "klenhus",
    "klenmodet": "klenmod",
    "klenmodets": "klenmod",
    "klenmods": "klenmod",
    "klenoden": "klenod",
    "klenodens": "klenod",
    "klenoder": "klenod",
    "klenoderna": "klenod",
    "klenodernas": "klenod",
    "klenoders": "klenod",
    "klenods": "klenod",
    "klens": "klen",
    "klensmeden": "klensmed",
    "klensmedens": "klensmed",
    "klensmeder": "klensmed",
    "klensmederna": "klensmed",
    "klensmedernas": "klensmed",
    "klensmeders": "klensmed",
    "klensmeds": "klensmed",
    "klensmiden": "klensmide",
    "klensmidena": "klensmide",
    "klensmidenas": "klensmide",
    "klensmidens": "klensmide",
    "klensmides": "klensmide",
    "klensmidet": "klensmide",
    "klensmidets": "klensmide",
    "klenspänningar": "klenspänning",
    "klenspänningarna": "klenspänning",
    "klenspänningarnas": "klenspänning",
    "klenspänningars": "klenspänning",
    "klenspänningen": "klenspänning",
    "klenspänningens": "klenspänning",
    "klenspännings": "klenspänning",
    "klent": "klen",
    "klentrogenheten": "klentrogenhet",
    "klentrogenhetens": "klentrogenhet",
    "klentrogenhets": "klentrogenhet",
    "klentrogens": "klentrogen",
    "klentroget": "klentrogen",
    "klentrogets": "klentrogen",
    "klentrogna": "klentrogen",
    "klentrognare": "klentrogen",
    "klentrognares": "klentrogen",
    "klentrognas": "klentrogen",
    "klentrognast": "klentrogen",
    "klentrognaste": "klentrogen",
    "klentrognastes": "klentrogen",
    "klentrognasts": "klentrogen",
    "klentrogne": "klentrogen",
    "klentrognes": "klentrogen",
    "klentron": "klentro",
    "klentrons": "klentro",
    "klentros": "klentro",
    "klents": "klen",
    "klenvuxenheten": "klenvuxenhet",
    "klenvuxenhetens": "klenvuxenhet",
    "klenvuxenhets": "klenvuxenhet",
    "klenvuxens": "klenvuxen",
    "klenvuxet": "klenvuxen",
    "klenvuxets": "klenvuxen",
    "klenvuxna": "klenvuxen",
    "klenvuxnare": "klenvuxen",
    "klenvuxnares": "klenvuxen",
    "klenvuxnas": "klenvuxen",
    "klenvuxnast": "klenvuxen",
    "klenvuxnaste": "klenvuxen",
    "klenvuxnastes": "klenvuxen",
    "klenvuxnasts": "klenvuxen",
    "klenvuxne": "klenvuxen",
    "klenvuxnes": "klenvuxen",
    "klenäten": "klenät",
    "klenätens": "klenät",
    "klenäter": "klenät",
    "klenäterna": "klenät",
    "klenäternas": "klenät",
    "klenäters": "klenät",
    "klenäts": "klenät",
    "kleptomanen": "kleptoman",
    "kleptomanens": "kleptoman",
    "kleptomaner": "kleptoman",
    "kleptomanerna": "kleptoman",
    "kleptomanernas": "kleptoman",
    "kleptomaners": "kleptoman",
    "kleptomanien": "kleptomani",
    "kleptomaniens": "kleptomani",
    "kleptomanin": "kleptomani",
    "kleptomanins": "kleptomani",
    "kleptomanis": "kleptomani",
    "kleptomans": "kleptoman",
    "kleresiet": "kleresi",
    "kleresiets": "kleresi",
    "kleresis": "kleresi",
    "kleresit": "kleresi",
    "kleresits": "kleresi",
    "klerikala": "klerikal",
    "klerikalare": "klerikal",
    "klerikalares": "klerikal",
    "klerikalas": "klerikal",
    "klerikalast": "klerikal",
    "klerikalaste": "klerikal",
    "klerikalastes": "klerikal",
    "klerikalasts": "klerikal",
    "klerikale": "klerikal",
    "klerikales": "klerikal",
    "klerikalismen": "klerikalism",
    "klerikalismens": "klerikalism",
    "klerikalismer": "klerikalism",
    "klerikalismerna": "klerikalism",
    "klerikalismernas": "klerikalism",
    "klerikalismers": "klerikalism",
    "klerikalisms": "klerikalism",
    "klerikals": "klerikal",
    "klerikalt": "klerikal",
    "klerikalts": "klerikal",
    "klerikofascistiska": "klerikofascistisk",
    "klerikofascistiskas": "klerikofascistisk",
    "klerikofascistiske": "klerikofascistisk",
    "klerikofascistiskes": "klerikofascistisk",
    "klerikofascistisks": "klerikofascistisk",
    "klerikofascistiskt": "klerikofascistisk",
    "klerikofascistiskts": "klerikofascistisk",
    "klerken": "klerk",
    "klerkens": "klerk",
    "klerker": "klerk",
    "klerkerna": "klerk",
    "klerkernas": "klerk",
    "klerkers": "klerk",
    "klerks": "klerk",
    "klet": "kleta",
    "kletad": "kleta",
    "kletade": "kleta",
    "kletades": "kleta",
    "kletads": "kleta",
    "kletande": "kleta",
    "kletanden": "kletande",
    "kletandena": "kletande",
    "kletandenas": "kletande",
    "kletandens": "kletande",
    "kletandes": "kletande",
    "kletandet": "kletande",
    "kletandets": "kletande",
    "kletar": "kleta",
    "kletas": "kleta",
    "kletat": "kleta",
    "kletats": "kleta",
    "kletet": "klet",
    "kletets": "klet",
    "kletiga": "kletig",
    "kletigare": "kletig",
    "kletigares": "kletig",
    "kletigas": "kletig",
    "kletigast": "kletig",
    "kletigaste": "kletig",
    "kletigastes": "kletig",
    "kletigasts": "kletig",
    "kletige": "kletig",
    "kletiges": "kletig",
    "kletigheten": "kletighet",
    "kletighetens": "kletighet",
    "kletigheter": "kletighet",
    "kletigheterna": "kletighet",
    "kletigheternas": "kletighet",
    "kletigheters": "kletighet",
    "kletighets": "kletighet",
    "kletigs": "kletig",
    "kletigt": "kletig",
    "kletigts": "kletig",
    "klets": "klet",
    "klev": "kliva",
    "kleven": "klev",
    "klevens": "klev",
    "klevet": "klev",
    "klevets": "klev",
    "klevs": "kliva",
    "kli": "klia",
    "kliad": "klia",
    "kliade": "klia",
    "kliades": "klia",
    "kliads": "klia",
    "kliande": "klia",
    "klianden": "kliande",
    "kliandena": "kliande",
    "kliandenas": "kliande",
    "kliandens": "kliande",
    "kliandes": "kliande",
    "kliandet": "kliande",
    "kliandets": "kliande",
    "kliar": "klia",
    "klias": "klia",
    "kliat": "klia",
    "kliats": "klia",
    "klibb": "klibba",
    "klibbade": "klibba",
    "klibbades": "klibba",
    "klibbalar": "klibbal",
    "klibbalarna": "klibbal",
    "klibbalarnas": "klibbal",
    "klibbalars": "klibbal",
    "klibbalen": "klibbal",
    "klibbalens": "klibbal",
    "klibbals": "klibbal",
    "klibbande": "klibba",
    "klibbanden": "klibbande",
    "klibbandena": "klibbande",
    "klibbandenas": "klibbande",
    "klibbandens": "klibbande",
    "klibbandes": "klibbande",
    "klibbandet": "klibbande",
    "klibbandets": "klibbande",
    "klibbar": "klibba",
    "klibbas": "klibba",
    "klibbat": "klibba",
    "klibbats": "klibba",
    "klibbet": "klibb",
    "klibbets": "klibb",
    "klibbiga": "klibbig",
    "klibbigare": "klibbig",
    "klibbigares": "klibbig",
    "klibbigas": "klibbig",
    "klibbigast": "klibbig",
    "klibbigaste": "klibbig",
    "klibbigastes": "klibbig",
    "klibbigasts": "klibbig",
    "klibbige": "klibbig",
    "klibbiges": "klibbig",
    "klibbigheten": "klibbighet",
    "klibbighetens": "klibbighet",
    "klibbighets": "klibbighet",
    "klibbigs": "klibbig",
    "klibbigt": "klibbig",
    "klibbigts": "klibbig",
    "klibbs": "klibb",
    "klichéer": "kliché",
    "klichéerna": "kliché",
    "klichéernas": "kliché",
    "klichéers": "kliché",
    "klichémässiga": "klichémässig",
    "klichémässigare": "klichémässig",
    "klichémässigares": "klichémässig",
    "klichémässigas": "klichémässig",
    "klichémässigast": "klichémässig",
    "klichémässigaste": "klichémässig",
    "klichémässigastes": "klichémässig",
    "klichémässigasts": "klichémässig",
    "klichémässige": "klichémässig",
    "klichémässiges": "klichémässig",
    "klichémässigs": "klichémässig",
    "klichémässigt": "klichémässig",
    "klichémässigts": "klichémässig",
    "klichén": "kliché",
    "klichéns": "kliché",
    "klichés": "kliché",
    "klick": "klicka",
    "klickade": "klicka",
    "klickades": "klicka",
    "klickande": "klicka",
    "klickanden": "klickande",
    "klickandena": "klickande",
    "klickandenas": "klickande",
    "klickandens": "klickande",
    "klickandes": "klickande",
    "klickandet": "klickande",
    "klickandets": "klickande",
    "klickar": "klicka",
    "klickarna": "klick",
    "klickarnas": "klick",
    "klickars": "klick",
    "klickas": "klicka",
    "klickat": "klicka",
    "klickats": "klicka",
    "klicken": "klick",
    "klickens": "klick",
    "klicket": "klick",
    "klickets": "klick",
    "klicklåsen": "klicklås",
    "klicklåsens": "klicklås",
    "klicklåset": "klicklås",
    "klicklåsets": "klicklås",
    "klicks": "klick",
    "klientelen": "klientel",
    "klientelens": "klientel",
    "klientelet": "klientel",
    "klientelets": "klientel",
    "klientels": "klientel",
    "klienten": "klient",
    "klientens": "klient",
    "klienter": "klient",
    "klienterna": "klient",
    "klienternas": "klient",
    "klienters": "klient",
    "klients": "klient",
    "kliet": "kli",
    "kliets": "kli",
    "klifset": "klifs",
    "klifsets": "klifs",
    "klimakteriehäx": "klimakteriehäxa",
    "klimakteriehäxan": "klimakteriehäxa",
    "klimakteriehäxans": "klimakteriehäxa",
    "klimakteriehäxas": "klimakteriehäxa",
    "klimakteriehäxe": "klimakteriehäxa",
    "klimakteriehäxor": "klimakteriehäxa",
    "klimakteriehäxorna": "klimakteriehäxa",
    "klimakteriehäxornas": "klimakteriehäxa",
    "klimakteriehäxors": "klimakteriehäxa",
    "klimakteriet": "klimakterium",
    "klimakteriets": "klimakterium",
    "klimakteriums": "klimakterium",
    "klimataktivisten": "klimataktivist",
    "klimataktivistens": "klimataktivist",
    "klimataktivister": "klimataktivist",
    "klimataktivisterna": "klimataktivist",
    "klimataktivisternas": "klimataktivist",
    "klimataktivisters": "klimataktivist",
    "klimataktivists": "klimataktivist",
    "klimatalarmen": "klimatalarm",
    "klimatalarmens": "klimatalarm",
    "klimatalarmet": "klimatalarm",
    "klimatalarmets": "klimatalarm",
    "klimatalarmismen": "klimatalarmism",
    "klimatalarmismens": "klimatalarmism",
    "klimatalarmisms": "klimatalarmism",
    "klimatalarmisten": "klimatalarmist",
    "klimatalarmistens": "klimatalarmist",
    "klimatalarmister": "klimatalarmist",
    "klimatalarmisterna": "klimatalarmist",
    "klimatalarmisternas": "klimatalarmist",
    "klimatalarmisters": "klimatalarmist",
    "klimatalarmists": "klimatalarmist",
    "klimatalarms": "klimatalarm",
    "klimatavtalen": "klimatavtal",
    "klimatavtalens": "klimatavtal",
    "klimatavtalet": "klimatavtal",
    "klimatavtalets": "klimatavtal",
    "klimatavtals": "klimatavtal",
    "klimatdebatten": "klimatdebatt",
    "klimatdebattens": "klimatdebatt",
    "klimatdebatter": "klimatdebatt",
    "klimatdebatterna": "klimatdebatt",
    "klimatdebatternas": "klimatdebatt",
    "klimatdebatters": "klimatdebatt",
    "klimatdebatts": "klimatdebatt",
    "klimaten": "klimat",
    "klimatens": "klimat",
    "klimatet": "klimat",
    "klimatets": "klimat",
    "klimatforskar": "klimatforskare",
    "klimatforskaren": "klimatforskare",
    "klimatforskarens": "klimatforskare",
    "klimatforskares": "klimatforskare",
    "klimatforskarna": "klimatforskare",
    "klimatforskarnas": "klimatforskare",
    "klimatforskningen": "klimatforskning",
    "klimatforskningens": "klimatforskning",
    "klimatforsknings": "klimatforskning",
    "klimatfrågan": "klimatfråga",
    "klimatfrågans": "klimatfråga",
    "klimatfrågas": "klimatfråga",
    "klimatfråge": "klimatfråga",
    "klimatfrågor": "klimatfråga",
    "klimatfrågorna": "klimatfråga",
    "klimatfrågornas": "klimatfråga",
    "klimatfrågors": "klimatfråga",
    "klimatförändringar": "klimatförändring",
    "klimatförändringarna": "klimatförändring",
    "klimatförändringarnas": "klimatförändring",
    "klimatförändringars": "klimatförändring",
    "klimatförändringen": "klimatförändring",
    "klimatförändringens": "klimatförändring",
    "klimatförändrings": "klimatförändring",
    "klimatförändringsskeptikern": "klimatförändringsskeptiker",
    "klimatförändringsskeptikerna": "klimatförändringsskeptiker",
    "klimatförändringsskeptikernas": "klimatförändringsskeptiker",
    "klimatförändringsskeptikerns": "klimatförändringsskeptiker",
    "klimatförändringsskeptikers": "klimatförändringsskeptiker",
    "klimatgränsen": "klimatgräns",
    "klimatgränsens": "klimatgräns",
    "klimatgränser": "klimatgräns",
    "klimatgränserna": "klimatgräns",
    "klimatgränsernas": "klimatgräns",
    "klimatgränsers": "klimatgräns",
    "klimathoten": "klimathot",
    "klimathotens": "klimathot",
    "klimathotet": "klimathot",
    "klimathotets": "klimathot",
    "klimathots": "klimathot",
    "klimatkammar": "klimatkammare",
    "klimatkammaren": "klimatkammare",
    "klimatkammarens": "klimatkammare",
    "klimatkammares": "klimatkammare",
    "klimatkamrar": "klimatkammare",
    "klimatkamrarna": "klimatkammare",
    "klimatkamrarnas": "klimatkammare",
    "klimatkamrars": "klimatkammare",
    "klimatkonferensen": "klimatkonferens",
    "klimatkonferensens": "klimatkonferens",
    "klimatkonferenser": "klimatkonferens",
    "klimatkonferenserna": "klimatkonferens",
    "klimatkonferensernas": "klimatkonferens",
    "klimatkonferensers": "klimatkonferens",
    "klimatkrisen": "klimatkris",
    "klimatkrisens": "klimatkris",
    "klimatkriser": "klimatkris",
    "klimatkriserna": "klimatkris",
    "klimatkrisernas": "klimatkris",
    "klimatkrisers": "klimatkris",
    "klimatläran": "klimatlära",
    "klimatlärans": "klimatlära",
    "klimatläras": "klimatlära",
    "klimatmedvetenheten": "klimatmedvetenhet",
    "klimatmedvetenhetens": "klimatmedvetenhet",
    "klimatmedvetenheter": "klimatmedvetenhet",
    "klimatmedvetenheterna": "klimatmedvetenhet",
    "klimatmedvetenheternas": "klimatmedvetenhet",
    "klimatmedvetenheters": "klimatmedvetenhet",
    "klimatmedvetenhets": "klimatmedvetenhet",
    "klimatmedvetens": "klimatmedveten",
    "klimatmedvetet": "klimatmedveten",
    "klimatmedvetets": "klimatmedveten",
    "klimatmedvetna": "klimatmedveten",
    "klimatmedvetnare": "klimatmedveten",
    "klimatmedvetnares": "klimatmedveten",
    "klimatmedvetnas": "klimatmedveten",
    "klimatmedvetnast": "klimatmedveten",
    "klimatmedvetnaste": "klimatmedveten",
    "klimatmedvetnastes": "klimatmedveten",
    "klimatmedvetnasts": "klimatmedveten",
    "klimatmedvetne": "klimatmedveten",
    "klimatmedvetnes": "klimatmedveten",
    "klimatmodellen": "klimatmodell",
    "klimatmodellens": "klimatmodell",
    "klimatmodeller": "klimatmodell",
    "klimatmodellerna": "klimatmodell",
    "klimatmodellernas": "klimatmodell",
    "klimatmodellers": "klimatmodell",
    "klimatmodells": "klimatmodell",
    "klimatmässiga": "klimatmässig",
    "klimatmässigare": "klimatmässig",
    "klimatmässigares": "klimatmässig",
    "klimatmässigas": "klimatmässig",
    "klimatmässigast": "klimatmässig",
    "klimatmässigaste": "klimatmässig",
    "klimatmässigastes": "klimatmässig",
    "klimatmässigasts": "klimatmässig",
    "klimatmässige": "klimatmässig",
    "klimatmässiges": "klimatmässig",
    "klimatmässigs": "klimatmässig",
    "klimatmässigt": "klimatmässig",
    "klimatmässigts": "klimatmässig",
    "klimatologien": "klimatologi",
    "klimatologiens": "klimatologi",
    "klimatologin": "klimatologi",
    "klimatologins": "klimatologi",
    "klimatologis": "klimatologi",
    "klimatologiska": "klimatologisk",
    "klimatologiskare": "klimatologisk",
    "klimatologiskares": "klimatologisk",
    "klimatologiskas": "klimatologisk",
    "klimatologiskast": "klimatologisk",
    "klimatologiskaste": "klimatologisk",
    "klimatologiskastes": "klimatologisk",
    "klimatologiskasts": "klimatologisk",
    "klimatologiske": "klimatologisk",
    "klimatologiskes": "klimatologisk",
    "klimatologisks": "klimatologisk",
    "klimatologiskt": "klimatologisk",
    "klimatologiskts": "klimatologisk",
    "klimatombyten": "klimatombyte",
    "klimatombytena": "klimatombyte",
    "klimatombytenas": "klimatombyte",
    "klimatombytens": "klimatombyte",
    "klimatombytes": "klimatombyte",
    "klimatombytet": "klimatombyte",
    "klimatombytets": "klimatombyte",
    "klimatoterapien": "klimatoterapi",
    "klimatoterapiens": "klimatoterapi",
    "klimatoterapin": "klimatoterapi",
    "klimatoterapins": "klimatoterapi",
    "klimatoterapis": "klimatoterapi",
    "klimatpanelen": "klimatpanel",
    "klimatpanelens": "klimatpanel",
    "klimatpaneler": "klimatpanel",
    "klimatpanelerna": "klimatpanel",
    "klimatpanelernas": "klimatpanel",
    "klimatpanelers": "klimatpanel",
    "klimatpanels": "klimatpanel",
    "klimatpåverkans": "klimatpåverkan",
    "klimatreglerade": "klimatreglerad",
    "klimatreglerades": "klimatreglerad",
    "klimatreglerads": "klimatreglerad",
    "klimatreglerat": "klimatreglerad",
    "klimatreglerats": "klimatreglerad",
    "klimats": "klimat",
    "klimatskeptikern": "klimatskeptiker",
    "klimatskeptikerna": "klimatskeptiker",
    "klimatskeptikernas": "klimatskeptiker",
    "klimatskeptikerns": "klimatskeptiker",
    "klimatskeptikers": "klimatskeptiker",
    "klimatskälen": "klimatskäl",
    "klimatskälens": "klimatskäl",
    "klimatskälet": "klimatskäl",
    "klimatskälets": "klimatskäl",
    "klimatskäls": "klimatskäl",
    "klimatsmarta": "klimatsmart",
    "klimatsmartare": "klimatsmart",
    "klimatsmartares": "klimatsmart",
    "klimatsmartas": "klimatsmart",
    "klimatsmartast": "klimatsmart",
    "klimatsmartaste": "klimatsmart",
    "klimatsmartastes": "klimatsmart",
    "klimatsmartasts": "klimatsmart",
    "klimatsmarte": "klimatsmart",
    "klimatsmartes": "klimatsmart",
    "klimatsmartheten": "klimatsmarthet",
    "klimatsmarthetens": "klimatsmarthet",
    "klimatsmartheter": "klimatsmarthet",
    "klimatsmartheterna": "klimatsmarthet",
    "klimatsmartheternas": "klimatsmarthet",
    "klimatsmartheters": "klimatsmarthet",
    "klimatsmarthets": "klimatsmarthet",
    "klimatsmarts": "klimatsmart",
    "klimatstatistiken": "klimatstatistik",
    "klimatstatistikens": "klimatstatistik",
    "klimatstatistiks": "klimatstatistik",
    "klimatstrategien": "klimatstrategi",
    "klimatstrategiens": "klimatstrategi",
    "klimatstrategier": "klimatstrategi",
    "klimatstrategierna": "klimatstrategi",
    "klimatstrategiernas": "klimatstrategi",
    "klimatstrategiers": "klimatstrategi",
    "klimatstrategin": "klimatstrategi",
    "klimatstrategins": "klimatstrategi",
    "klimatstrategis": "klimatstrategi",
    "klimatsvängningar": "klimatsvängning",
    "klimatsvängningarna": "klimatsvängning",
    "klimatsvängningarnas": "klimatsvängning",
    "klimatsvängningars": "klimatsvängning",
    "klimatsvängningen": "klimatsvängning",
    "klimatsvängningens": "klimatsvängning",
    "klimatsvängnings": "klimatsvängning",
    "klimatsystemen": "klimatsystem",
    "klimatsystemens": "klimatsystem",
    "klimatsystemet": "klimatsystem",
    "klimatsystemets": "klimatsystem",
    "klimatsystems": "klimatsystem",
    "klimattoppmöten": "klimattoppmöte",
    "klimattoppmötena": "klimattoppmöte",
    "klimattoppmötenas": "klimattoppmöte",
    "klimattoppmötens": "klimattoppmöte",
    "klimattoppmötes": "klimattoppmöte",
    "klimattoppmötet": "klimattoppmöte",
    "klimattoppmötets": "klimattoppmöte",
    "klimatvariationen": "klimatvariation",
    "klimatvariationens": "klimatvariation",
    "klimatvariationer": "klimatvariation",
    "klimatvariationerna": "klimatvariation",
    "klimatvariationernas": "klimatvariation",
    "klimatvariationers": "klimatvariation",
    "klimatvariations": "klimatvariation",
    "klimatvärstingar": "klimatvärsting",
    "klimatvärstingarna": "klimatvärsting",
    "klimatvärstingarnas": "klimatvärsting",
    "klimatvärstingars": "klimatvärsting",
    "klimatvärstingen": "klimatvärsting",
    "klimatvärstingens": "klimatvärsting",
    "klimatvärstings": "klimatvärsting",
    "klimatväxlingar": "klimatväxling",
    "klimatväxlingarna": "klimatväxling",
    "klimatväxlingarnas": "klimatväxling",
    "klimatväxlingars": "klimatväxling",
    "klimatväxlingen": "klimatväxling",
    "klimatväxlingens": "klimatväxling",
    "klimatväxlings": "klimatväxling",
    "klimatzonen": "klimatzon",
    "klimatzonens": "klimatzon",
    "klimatzoner": "klimatzon",
    "klimatzonerna": "klimatzon",
    "klimatzonernas": "klimatzon",
    "klimatzoners": "klimatzon",
    "klimatzons": "klimatzon",
    "klimatändringar": "klimatändring",
    "klimatändringarna": "klimatändring",
    "klimatändringarnas": "klimatändring",
    "klimatändringars": "klimatändring",
    "klimatändringen": "klimatändring",
    "klimatändringens": "klimatändring",
    "klimatändrings": "klimatändring",
    "klimatångesten": "klimatångest",
    "klimatångestens": "klimatångest",
    "klimatångests": "klimatångest",
    "klimatåtgärden": "klimatåtgärd",
    "klimatåtgärdens": "klimatåtgärd",
    "klimatåtgärder": "klimatåtgärd",
    "klimatåtgärderna": "klimatåtgärd",
    "klimatåtgärdernas": "klimatåtgärd",
    "klimatåtgärders": "klimatåtgärd",
    "klimatåtgärds": "klimatåtgärd",
    "klimaxar": "klimax",
    "klimaxarna": "klimax",
    "klimaxarnas": "klimax",
    "klimaxars": "klimax",
    "klimaxen": "klimax",
    "klimaxens": "klimax",
    "klimp": "klimpa",
    "klimpade": "klimpa",
    "klimpades": "klimpa",
    "klimpande": "klimpa",
    "klimpanden": "klimpande",
    "klimpandena": "klimpande",
    "klimpandenas": "klimpande",
    "klimpandens": "klimpande",
    "klimpandes": "klimpande",
    "klimpandet": "klimpande",
    "klimpandets": "klimpande",
    "klimpar": "klimpa",
    "klimparna": "klimp",
    "klimparnas": "klimp",
    "klimpars": "klimp",
    "klimpas": "klimpa",
    "klimpat": "klimpa",
    "klimpats": "klimpa",
    "klimpen": "klimp",
    "klimpens": "klimp",
    "klimps": "klimp",
    "kling": "klinga",
    "klingade": "klinga",
    "klingan": "klinga",
    "klingande": "klinga",
    "klinganden": "klingande",
    "klingandena": "klingande",
    "klingandenas": "klingande",
    "klingandens": "klingande",
    "klingandes": "klingande",
    "klingandet": "klingande",
    "klingandets": "klingande",
    "klingans": "klinga",
    "klingar": "klinga",
    "klingas": "klinga",
    "klingat": "klinga",
    "klinge": "klinga",
    "klinget": "kling",
    "klingets": "kling",
    "klingons": "klingon",
    "klingor": "klinga",
    "klingorna": "klinga",
    "klingornas": "klinga",
    "klingors": "klinga",
    "klings": "klinga",
    "klinhusen": "klinhus",
    "klinhusens": "klinhus",
    "klinhuset": "klinhus",
    "klinhusets": "klinhus",
    "kliniken": "klinik",
    "klinikens": "klinik",
    "kliniker": "klinik",
    "klinikern": "kliniker",
    "klinikerna": "kliniker",
    "klinikernas": "kliniker",
    "klinikerns": "kliniker",
    "klinikers": "kliniker",
    "kliniks": "klinik",
    "kliniska": "klinisk",
    "kliniskare": "klinisk",
    "kliniskares": "klinisk",
    "kliniskas": "klinisk",
    "kliniskast": "klinisk",
    "kliniskaste": "klinisk",
    "kliniskastes": "klinisk",
    "kliniskasts": "klinisk",
    "kliniske": "klinisk",
    "kliniskes": "klinisk",
    "klinisks": "klinisk",
    "kliniskt": "klinisk",
    "kliniskts": "klinisk",
    "klink": "klinka",
    "klinkade": "klinka",
    "klinkades": "klinka",
    "klinkan": "klinka",
    "klinkande": "klinka",
    "klinkanden": "klinkande",
    "klinkandena": "klinkande",
    "klinkandenas": "klinkande",
    "klinkandens": "klinkande",
    "klinkandes": "klinkande",
    "klinkandet": "klinkande",
    "klinkandets": "klinkande",
    "klinkans": "klinka",
    "klinkar": "klinka",
    "klinkas": "klinka",
    "klinkat": "klinka",
    "klinkats": "klinka",
    "klinkbyggda": "klinkbyggd",
    "klinkbyggdare": "klinkbyggd",
    "klinkbyggdares": "klinkbyggd",
    "klinkbyggdas": "klinkbyggd",
    "klinkbyggdast": "klinkbyggd",
    "klinkbyggdaste": "klinkbyggd",
    "klinkbyggdastes": "klinkbyggd",
    "klinkbyggdasts": "klinkbyggd",
    "klinkbyggde": "klinkbyggd",
    "klinkbyggdes": "klinkbyggd",
    "klinkbyggds": "klinkbyggd",
    "klinkbyggt": "klinkbyggd",
    "klinkbyggts": "klinkbyggd",
    "klinke": "klinka",
    "klinkern": "klinker",
    "klinkerna": "klinker",
    "klinkernas": "klinker",
    "klinkerns": "klinker",
    "klinkers": "klinker",
    "klinkerskärar": "klinkerskärare",
    "klinkerskäraren": "klinkerskärare",
    "klinkerskärarens": "klinkerskärare",
    "klinkerskärares": "klinkerskärare",
    "klinkerskärarna": "klinkerskärare",
    "klinkerskärarnas": "klinkerskärare",
    "klinket": "klink",
    "klinkets": "klink",
    "klinkor": "klinka",
    "klinkorna": "klinka",
    "klinkornas": "klinka",
    "klinkors": "klinka",
    "klinks": "klinka",
    "klintar": "klint",
    "klintarna": "klint",
    "klintarnas": "klint",
    "klintars": "klint",
    "klinten": "klint",
    "klintens": "klint",
    "klinter": "klint",
    "klinterna": "klint",
    "klinternas": "klint",
    "klinters": "klint",
    "klints": "klint",
    "klipp": "klippa",
    "klippan": "klippa",
    "klippande": "klippa",
    "klippanden": "klippande",
    "klippandena": "klippande",
    "klippandenas": "klippande",
    "klippandens": "klippande",
    "klippandes": "klippande",
    "klippandet": "klippande",
    "klippandets": "klippande",
    "klippans": "klippa",
    "klippar": "klippare",
    "klipparen": "klippare",
    "klipparens": "klippare",
    "klippares": "klippare",
    "klipparna": "klippare",
    "klipparnas": "klippare",
    "klippas": "klippa",
    "klippblocken": "klippblock",
    "klippblockens": "klippblock",
    "klippblocket": "klippblock",
    "klippblockets": "klippblock",
    "klippblocks": "klippblock",
    "klippbredden": "klippbredd",
    "klippbreddens": "klippbredd",
    "klippbredder": "klippbredd",
    "klippbredderna": "klippbredd",
    "klippbreddernas": "klippbredd",
    "klippbredders": "klippbredd",
    "klippbredds": "klippbredd",
    "klippdassar": "klippdass",
    "klippdassarna": "klippdass",
    "klippdassarnas": "klippdass",
    "klippdassars": "klippdass",
    "klippdassen": "klippdass",
    "klippdassens": "klippdass",
    "klippdock": "klippdocka",
    "klippdockan": "klippdocka",
    "klippdockans": "klippdocka",
    "klippdockas": "klippdocka",
    "klippdocke": "klippdocka",
    "klippdockor": "klippdocka",
    "klippdockorna": "klippdocka",
    "klippdockornas": "klippdocka",
    "klippdockors": "klippdocka",
    "klippdocks": "klippdocka",
    "klippe": "klippa",
    "klippen": "klipp",
    "klippens": "klipp",
    "klipper": "klippa",
    "klippern": "klipper",
    "klipperns": "klipper",
    "klippers": "klipper",
    "klipperstävar": "klipperstäv",
    "klipperstävarna": "klipperstäv",
    "klipperstävarnas": "klipperstäv",
    "klipperstävars": "klipperstäv",
    "klipperstäven": "klipperstäv",
    "klipperstävens": "klipperstäv",
    "klipperstävs": "klipperstäv",
    "klippes": "klippa",
    "klippet": "klipp",
    "klippets": "klipp",
    "klippfiskar": "klippfisk",
    "klippfiskarna": "klippfisk",
    "klippfiskarnas": "klippfisk",
    "klippfiskars": "klippfisk",
    "klippfisken": "klippfisk",
    "klippfiskens": "klippfisk",
    "klippfisks": "klippfisk",
    "klippformationen": "klippformation",
    "klippformationens": "klippformation",
    "klippformationer": "klippformation",
    "klippformationerna": "klippformation",
    "klippformationernas": "klippformation",
    "klippformationers": "klippformation",
    "klippformations": "klippformation",
    "klippfyrar": "klippfyr",
    "klippfyrarna": "klippfyr",
    "klippfyrarnas": "klippfyr",
    "klippfyrars": "klippfyr",
    "klippfyren": "klippfyr",
    "klippfyrens": "klippfyr",
    "klippfyrs": "klippfyr",
    "klippgravar": "klippgrav",
    "klippgravarna": "klippgrav",
    "klippgravarnas": "klippgrav",
    "klippgravars": "klippgrav",
    "klippgraven": "klippgrav",
    "klippgravens": "klippgrav",
    "klippgravs": "klippgrav",
    "klipphuvuden": "klipphuvud",
    "klipphuvudena": "klipphuvud",
    "klipphuvudenas": "klipphuvud",
    "klipphuvudens": "klipphuvud",
    "klipphuvudet": "klipphuvud",
    "klipphuvudets": "klipphuvud",
    "klipphuvuds": "klipphuvud",
    "klipphål": "klipphåla",
    "klipphålan": "klipphåla",
    "klipphålans": "klipphåla",
    "klipphålas": "klipphåla",
    "klipphåle": "klipphåla",
    "klipphålor": "klipphåla",
    "klipphålorna": "klipphåla",
    "klipphålornas": "klipphåla",
    "klipphålors": "klipphåla",
    "klipphåls": "klipphåla",
    "klipphöjden": "klipphöjd",
    "klipphöjdens": "klipphöjd",
    "klipphöjder": "klipphöjd",
    "klipphöjderna": "klipphöjd",
    "klipphöjdernas": "klipphöjd",
    "klipphöjders": "klipphöjd",
    "klipphöjds": "klipphöjd",
    "klippiga": "klippig",
    "klippigare": "klippig",
    "klippigares": "klippig",
    "klippigas": "klippig",
    "klippigast": "klippig",
    "klippigaste": "klippig",
    "klippigastes": "klippig",
    "klippigasts": "klippig",
    "klippige": "klippig",
    "klippiges": "klippig",
    "klippigheten": "klippighet",
    "klippighetens": "klippighet",
    "klippighets": "klippighet",
    "klippigs": "klippig",
    "klippigt": "klippig",
    "klippigts": "klippig",
    "klippingar": "klipping",
    "klippingarna": "klipping",
    "klippingarnas": "klipping",
    "klippingars": "klipping",
    "klippingen": "klipping",
    "klippingens": "klipping",
    "klippings": "klipping",
    "klippkorten": "klippkort",
    "klippkortens": "klippkort",
    "klippkortet": "klippkort",
    "klippkortets": "klippkort",
    "klippkorts": "klippkort",
    "klippljusen": "klippljus",
    "klippljusens": "klippljus",
    "klippljuset": "klippljus",
    "klippljusets": "klippljus",
    "klippmassiven": "klippmassiv",
    "klippmassivens": "klippmassiv",
    "klippmassivet": "klippmassiv",
    "klippmassivets": "klippmassiv",
    "klippmassivs": "klippmassiv",
    "klippmålningar": "klippmålning",
    "klippmålningarna": "klippmålning",
    "klippmålningarnas": "klippmålning",
    "klippmålningars": "klippmålning",
    "klippmålningen": "klippmålning",
    "klippmålningens": "klippmålning",
    "klippmålnings": "klippmålning",
    "klippningar": "klippning",
    "klippningarna": "klippning",
    "klippningarnas": "klippning",
    "klippningars": "klippning",
    "klippningen": "klippning",
    "klippningens": "klippning",
    "klippnings": "klippning",
    "klippor": "klippa",
    "klipporna": "klippa",
    "klippornas": "klippa",
    "klippors": "klippa",
    "klippoteken": "klippotek",
    "klippotekens": "klippotek",
    "klippoteket": "klippotek",
    "klippotekets": "klippotek",
    "klippoteks": "klippotek",
    "klipprar": "klipper",
    "klipprarna": "klipper",
    "klipprarnas": "klipper",
    "klipprars": "klipper",
    "klipprummen": "klipprum",
    "klipprummens": "klipprum",
    "klipprummet": "klipprum",
    "klipprummets": "klipprum",
    "klipprums": "klipprum",
    "klipps": "klippa",
    "klippskrevan": "klippskreva",
    "klippskrevans": "klippskreva",
    "klippskrevas": "klippskreva",
    "klippskreve": "klippskreva",
    "klippskrevor": "klippskreva",
    "klippskrevorna": "klippskreva",
    "klippskrevornas": "klippskreva",
    "klippskrevors": "klippskreva",
    "klippspikar": "klippspik",
    "klippspikarna": "klippspik",
    "klippspikarnas": "klippspik",
    "klippspikars": "klippspik",
    "klippspiken": "klippspik",
    "klippspikens": "klippspik",
    "klippspiks": "klippspik",
    "klippstugan": "klippstuga",
    "klippstugans": "klippstuga",
    "klippstugas": "klippstuga",
    "klippstuge": "klippstuga",
    "klippstugor": "klippstuga",
    "klippstugorna": "klippstuga",
    "klippstugornas": "klippstuga",
    "klippstugors": "klippstuga",
    "klippstugu": "klippstuga",
    "klippstupen": "klippstup",
    "klippstupens": "klippstup",
    "klippstupet": "klippstup",
    "klippstupets": "klippstup",
    "klippstups": "klippstup",
    "klippstycken": "klippstycke",
    "klippstyckena": "klippstycke",
    "klippstyckenas": "klippstycke",
    "klippstyckens": "klippstycke",
    "klippstyckes": "klippstycke",
    "klippstycket": "klippstycke",
    "klippstyckets": "klippstycke",
    "klippstycks": "klippstycke",
    "klippt": "klippa",
    "klippta": "klippa",
    "klipptas": "klippa",
    "klippte": "klippa",
    "klipptes": "klippa",
    "klippts": "klippa",
    "klipptänger": "klipptång",
    "klipptängerna": "klipptång",
    "klipptängernas": "klipptång",
    "klipptängers": "klipptång",
    "klipptången": "klipptång",
    "klipptångens": "klipptång",
    "klipptångs": "klipptång",
    "klippväggar": "klippvägg",
    "klippväggarna": "klippvägg",
    "klippväggarnas": "klippvägg",
    "klippväggars": "klippvägg",
    "klippväggen": "klippvägg",
    "klippväggens": "klippvägg",
    "klippväggs": "klippvägg",
    "klipska": "klipsk",
    "klipskare": "klipsk",
    "klipskares": "klipsk",
    "klipskas": "klipsk",
    "klipskast": "klipsk",
    "klipskaste": "klipsk",
    "klipskastes": "klipsk",
    "klipskasts": "klipsk",
    "klipske": "klipsk",
    "klipskes": "klipsk",
    "klipskheten": "klipskhet",
    "klipskhetens": "klipskhet",
    "klipskheter": "klipskhet",
    "klipskheterna": "klipskhet",
    "klipskheternas": "klipskhet",
    "klipskheters": "klipskhet",
    "klipskhets": "klipskhet",
    "klipsks": "klipsk",
    "klipskt": "klipsk",
    "klipskts": "klipsk",
    "klipulvers": "klipulver",
    "klipulvret": "klipulver",
    "klipulvrets": "klipulver",
    "klir": "klira",
    "klirad": "klira",
    "klirade": "klira",
    "klirades": "klira",
    "klirads": "klira",
    "klirande": "klira",
    "kliranden": "klirande",
    "klirandena": "klirande",
    "klirandenas": "klirande",
    "klirandens": "klirande",
    "klirandes": "klirande",
    "klirandet": "klirande",
    "klirandets": "klirande",
    "klirar": "klira",
    "kliras": "klira",
    "klirat": "klira",
    "klirats": "klira",
    "klirr": "klirra",
    "klirrade": "klirra",
    "klirrades": "klirra",
    "klirrande": "klirra",
    "klirranden": "klirrande",
    "klirrandena": "klirrande",
    "klirrandenas": "klirrande",
    "klirrandens": "klirrande",
    "klirrandes": "klirrande",
    "klirrandet": "klirrande",
    "klirrandets": "klirrande",
    "klirrar": "klirra",
    "klirras": "klirra",
    "klirrat": "klirra",
    "klirrats": "klirra",
    "klirret": "klirr",
    "klirrets": "klirr",
    "klirrs": "klirr",
    "klis": "kli",
    "klister": "klistra",
    "klistermärken": "klistermärke",
    "klistermärkena": "klistermärke",
    "klistermärkenas": "klistermärke",
    "klistermärkens": "klistermärke",
    "klistermärkes": "klistermärke",
    "klistermärket": "klistermärke",
    "klistermärkets": "klistermärke",
    "klisterrems": "klisterremsa",
    "klisterremsan": "klisterremsa",
    "klisterremsans": "klisterremsa",
    "klisterremsas": "klisterremsa",
    "klisterremse": "klisterremsa",
    "klisterremsor": "klisterremsa",
    "klisterremsorna": "klisterremsa",
    "klisterremsornas": "klisterremsa",
    "klisterremsors": "klisterremsa",
    "klisters": "klister",
    "klistervallan": "klistervalla",
    "klistervallans": "klistervalla",
    "klistervallas": "klistervalla",
    "klistrad": "klistra",
    "klistrade": "klistra",
    "klistrades": "klistra",
    "klistrads": "klistra",
    "klistrande": "klistra",
    "klistranden": "klistrande",
    "klistrandena": "klistrande",
    "klistrandenas": "klistrande",
    "klistrandens": "klistrande",
    "klistrandes": "klistrande",
    "klistrandet": "klistrande",
    "klistrandets": "klistrande",
    "klistrar": "klistra",
    "klistras": "klistra",
    "klistrat": "klistra",
    "klistrats": "klistra",
    "klistret": "klister",
    "klistrets": "klister",
    "klistriga": "klistrig",
    "klistrigare": "klistrig",
    "klistrigares": "klistrig",
    "klistrigas": "klistrig",
    "klistrigast": "klistrig",
    "klistrigaste": "klistrig",
    "klistrigastes": "klistrig",
    "klistrigasts": "klistrig",
    "klistrige": "klistrig",
    "klistriges": "klistrig",
    "klistrigheten": "klistrighet",
    "klistrighetens": "klistrighet",
    "klistrighets": "klistrighet",
    "klistrigs": "klistrig",
    "klistrigt": "klistrig",
    "klistrigts": "klistrig",
    "klit": "kli",
    "klitorisar": "klitoris",
    "klitorisarna": "klitoris",
    "klitorisarnas": "klitoris",
    "klitorisars": "klitoris",
    "klitorisen": "klitoris",
    "klitorisens": "klitoris",
    "klits": "kli",
    "klitt": "klitter",
    "klitterna": "klitter",
    "klitternas": "klitter",
    "klitters": "klitter",
    "klitts": "klitter",
    "kliv": "kliva",
    "klivande": "kliva",
    "klivanden": "klivande",
    "klivandena": "klivande",
    "klivandenas": "klivande",
    "klivandens": "klivande",
    "klivandes": "klivande",
    "klivandet": "klivande",
    "klivandets": "klivande",
    "klivas": "kliva",
    "klive": "kliva",
    "kliven": "kliv",
    "klivens": "kliv",
    "kliver": "kliva",
    "klives": "kliva",
    "klivet": "kliv",
    "klivets": "kliv",
    "klivit": "kliva",
    "klivits": "kliva",
    "klivs": "kliva",
    "klivstätt": "klivstätta",
    "klivstättan": "klivstätta",
    "klivstättans": "klivstätta",
    "klivstättas": "klivstätta",
    "klivstätte": "klivstätta",
    "klivstättor": "klivstätta",
    "klivstättorna": "klivstätta",
    "klivstättornas": "klivstätta",
    "klivstättors": "klivstätta",
    "klivstätts": "klivstätta",
    "kloakdjuren": "kloakdjur",
    "kloakdjurens": "kloakdjur",
    "kloakdjuret": "kloakdjur",
    "kloakdjurets": "kloakdjur",
    "kloakdjurs": "kloakdjur",
    "kloaken": "kloak",
    "kloakens": "kloak",
    "kloaker": "kloak",
    "kloakerna": "kloak",
    "kloakernas": "kloak",
    "kloakers": "kloak",
    "kloaks": "kloak",
    "kloasongväggar": "kloasongvägg",
    "kloasongväggarna": "kloasongvägg",
    "kloasongväggarnas": "kloasongvägg",
    "kloasongväggars": "kloasongvägg",
    "kloasongväggen": "kloasongvägg",
    "kloasongväggens": "kloasongvägg",
    "kloasongväggs": "kloasongvägg",
    "klock": "klocka",
    "klockad": "klocka",
    "klockade": "klockad",
    "klockades": "klockad",
    "klockads": "klockad",
    "klockan": "klocka",
    "klockande": "klocka",
    "klockanden": "klockande",
    "klockandena": "klockande",
    "klockandenas": "klockande",
    "klockandens": "klockande",
    "klockandes": "klockande",
    "klockandet": "klockande",
    "klockandets": "klockande",
    "klockans": "klocka",
    "klockar": "klockare",
    "klockaren": "klockare",
    "klockarens": "klockare",
    "klockares": "klockare",
    "klockarkärlekar": "klockarkärlek",
    "klockarkärlekarna": "klockarkärlek",
    "klockarkärlekarnas": "klockarkärlek",
    "klockarkärlekars": "klockarkärlek",
    "klockarkärleken": "klockarkärlek",
    "klockarkärlekens": "klockarkärlek",
    "klockarkärleks": "klockarkärlek",
    "klockarna": "klockare",
    "klockarnas": "klockare",
    "klockas": "klocka",
    "klockat": "klockad",
    "klockats": "klockad",
    "klockbojar": "klockboj",
    "klockbojarna": "klockboj",
    "klockbojarnas": "klockboj",
    "klockbojars": "klockboj",
    "klockbojen": "klockboj",
    "klockbojens": "klockboj",
    "klockbojs": "klockboj",
    "klocke": "klocka",
    "klockformade": "klockformad",
    "klockformades": "klockformad",
    "klockformads": "klockformad",
    "klockformat": "klockformad",
    "klockformats": "klockformad",
    "klockformen": "klockform",
    "klockformens": "klockform",
    "klockformiga": "klockformig",
    "klockformigare": "klockformig",
    "klockformigares": "klockformig",
    "klockformigas": "klockformig",
    "klockformigast": "klockformig",
    "klockformigaste": "klockformig",
    "klockformigastes": "klockformig",
    "klockformigasts": "klockformig",
    "klockformige": "klockformig",
    "klockformiges": "klockformig",
    "klockformigs": "klockformig",
    "klockformigt": "klockformig",
    "klockformigts": "klockformig",
    "klockforms": "klockform",
    "klockgrod": "klockgroda",
    "klockgrodan": "klockgroda",
    "klockgrodans": "klockgroda",
    "klockgrodas": "klockgroda",
    "klockgrode": "klockgroda",
    "klockgrodor": "klockgroda",
    "klockgrodorna": "klockgroda",
    "klockgrodornas": "klockgroda",
    "klockgrodors": "klockgroda",
    "klockgrods": "klockgroda",
    "klockkedjan": "klockkedja",
    "klockkedjans": "klockkedja",
    "klockkedjas": "klockkedja",
    "klockkedje": "klockkedja",
    "klockkedjor": "klockkedja",
    "klockkedjorna": "klockkedja",
    "klockkedjornas": "klockkedja",
    "klockkedjors": "klockkedja",
    "klockkläppar": "klockkläpp",
    "klockkläpparna": "klockkläpp",
    "klockkläpparnas": "klockkläpp",
    "klockkläppars": "klockkläpp",
    "klockkläppen": "klockkläpp",
    "klockkläppens": "klockkläpp",
    "klockkläpps": "klockkläpp",
    "klockljungen": "klockljung",
    "klockljungens": "klockljung",
    "klockljungs": "klockljung",
    "klockor": "klocka",
    "klockorna": "klocka",
    "klockornas": "klocka",
    "klockors": "klocka",
    "klockradion": "klockradio",
    "klockradions": "klockradio",
    "klockradios": "klockradio",
    "klockrena": "klockren",
    "klockrenare": "klockren",
    "klockrenares": "klockren",
    "klockrenas": "klockren",
    "klockrenast": "klockren",
    "klockrenaste": "klockren",
    "klockrenastes": "klockren",
    "klockrenasts": "klockren",
    "klockrene": "klockren",
    "klockrenes": "klockren",
    "klockrenheten": "klockrenhet",
    "klockrenhetens": "klockrenhet",
    "klockrenhets": "klockrenhet",
    "klockrens": "klockren",
    "klockrent": "klockren",
    "klockrents": "klockren",
    "klockringningar": "klockringning",
    "klockringningarna": "klockringning",
    "klockringningarnas": "klockringning",
    "klockringningars": "klockringning",
    "klockringningen": "klockringning",
    "klockringningens": "klockringning",
    "klockringnings": "klockringning",
    "klocks": "klocka",
    "klocksignalen": "klocksignal",
    "klocksignalens": "klocksignal",
    "klocksignaler": "klocksignal",
    "klocksignalerna": "klocksignal",
    "klocksignalernas": "klocksignal",
    "klocksignalers": "klocksignal",
    "klocksignals": "klocksignal",
    "klockslagen": "klockslag",
    "klockslagens": "klockslag",
    "klockslaget": "klockslag",
    "klockslagets": "klockslag",
    "klockslags": "klockslag",
    "klockspelen": "klockspel",
    "klockspelens": "klockspel",
    "klockspelet": "klockspel",
    "klockspelets": "klockspel",
    "klockspels": "klockspel",
    "klockstapeln": "klockstapel",
    "klockstapelns": "klockstapel",
    "klockstapels": "klockstapel",
    "klockstaplar": "klockstapel",
    "klockstaplarna": "klockstapel",
    "klockstaplarnas": "klockstapel",
    "klockstaplars": "klockstapel",
    "klocksträngar": "klocksträng",
    "klocksträngarna": "klocksträng",
    "klocksträngarnas": "klocksträng",
    "klocksträngars": "klocksträng",
    "klocksträngen": "klocksträng",
    "klocksträngens": "klocksträng",
    "klocksträngs": "klocksträng",
    "klocktiden": "klocktid",
    "klocktidens": "klocktid",
    "klocktider": "klocktid",
    "klocktiderna": "klocktid",
    "klocktidernas": "klocktid",
    "klocktiders": "klocktid",
    "klocktids": "klocktid",
    "klocktornen": "klocktorn",
    "klocktornens": "klocktorn",
    "klocktornet": "klocktorn",
    "klocktornets": "klocktorn",
    "klocktorns": "klocktorn",
    "kloka": "klok",
    "klokare": "klok",
    "klokares": "klok",
    "klokas": "klok",
    "klokast": "klok",
    "klokaste": "klok",
    "klokastes": "klok",
    "klokasts": "klok",
    "kloke": "klok",
    "klokes": "klok",
    "klokheten": "klokhet",
    "klokhetens": "klokhet",
    "klokheter": "klokhet",
    "klokheterna": "klokhet",
    "klokheternas": "klokhet",
    "klokheters": "klokhet",
    "klokhets": "klokhet",
    "klokhuvuden": "klokhuvud",
    "klokhuvudena": "klokhuvud",
    "klokhuvudenas": "klokhuvud",
    "klokhuvudens": "klokhuvud",
    "klokhuvudet": "klokhuvud",
    "klokhuvudets": "klokhuvud",
    "klokhuvuds": "klokhuvud",
    "kloks": "klok",
    "klokskapet": "klokskap",
    "klokskapets": "klokskap",
    "klokskaps": "klokskap",
    "klokt": "klok",
    "klokts": "klok",
    "klon": "klona",
    "klonad": "klona",
    "klonade": "klona",
    "klonades": "klona",
    "klonads": "klona",
    "klonande": "klona",
    "klonanden": "klonande",
    "klonandena": "klonande",
    "klonandenas": "klonande",
    "klonandens": "klonande",
    "klonandes": "klonande",
    "klonandet": "klonande",
    "klonandets": "klonande",
    "klonar": "klona",
    "klonas": "klona",
    "klonat": "klona",
    "klonats": "klona",
    "klonen": "klon",
    "klonens": "klon",
    "kloner": "klon",
    "kloneringar": "klonering",
    "kloneringarna": "klonering",
    "kloneringarnas": "klonering",
    "kloneringars": "klonering",
    "kloneringen": "klonering",
    "kloneringens": "klonering",
    "klonerings": "klonering",
    "klonerna": "klon",
    "klonernas": "klon",
    "kloners": "klon",
    "klons": "klon",
    "klor": "klo",
    "kloraten": "klorat",
    "kloratens": "klorat",
    "klorater": "klorat",
    "kloraterna": "klorat",
    "kloraternas": "klorat",
    "kloraters": "klorat",
    "kloratet": "klorat",
    "kloratets": "klorat",
    "kloratomen": "kloratom",
    "kloratomens": "kloratom",
    "kloratomer": "kloratom",
    "kloratomerna": "kloratom",
    "kloratomernas": "kloratom",
    "kloratomers": "kloratom",
    "kloratoms": "kloratom",
    "klorats": "klorat",
    "kloren": "klor",
    "klorens": "klor",
    "klorerad": "klorera",
    "klorerade": "klorera",
    "klorerades": "klorera",
    "klorerads": "klorera",
    "klorerande": "klorera",
    "kloreranden": "klorerande",
    "klorerandena": "klorerande",
    "klorerandenas": "klorerande",
    "klorerandens": "klorerande",
    "klorerandes": "klorerande",
    "klorerandet": "klorerande",
    "klorerandets": "klorerande",
    "klorerar": "klorera",
    "kloreras": "klorera",
    "klorerat": "klorera",
    "klorerats": "klorera",
    "klorerbara": "klorerbar",
    "klorerbarare": "klorerbar",
    "klorerbarares": "klorerbar",
    "klorerbaras": "klorerbar",
    "klorerbarast": "klorerbar",
    "klorerbaraste": "klorerbar",
    "klorerbarastes": "klorerbar",
    "klorerbarasts": "klorerbar",
    "klorerbare": "klorerbar",
    "klorerbares": "klorerbar",
    "klorerbarheten": "klorerbarhet",
    "klorerbarhetens": "klorerbarhet",
    "klorerbarhets": "klorerbarhet",
    "klorerbars": "klorerbar",
    "klorerbart": "klorerbar",
    "klorerbarts": "klorerbar",
    "kloreringar": "klorering",
    "kloreringarna": "klorering",
    "kloreringarnas": "klorering",
    "kloreringars": "klorering",
    "kloreringen": "klorering",
    "kloreringens": "klorering",
    "klorerings": "klorering",
    "klorexen": "klorex",
    "klorexens": "klorex",
    "klorfenolen": "klorfenol",
    "klorfenolens": "klorfenol",
    "klorfenoler": "klorfenol",
    "klorfenolerna": "klorfenol",
    "klorfenolernas": "klorfenol",
    "klorfenolers": "klorfenol",
    "klorfenols": "klorfenol",
    "kloriden": "klorid",
    "kloridens": "klorid",
    "klorider": "klorid",
    "kloriderna": "klorid",
    "kloridernas": "klorid",
    "kloriders": "klorid",
    "klorids": "klorid",
    "klorkalken": "klorkalk",
    "klorkalkens": "klorkalk",
    "klorkalks": "klorkalk",
    "klorkolväten": "klorkolväte",
    "klorkolvätena": "klorkolväte",
    "klorkolvätenas": "klorkolväte",
    "klorkolvätens": "klorkolväte",
    "klorkolvätes": "klorkolväte",
    "klorkolvätet": "klorkolväte",
    "klorkolvätets": "klorkolväte",
    "klorkolväts": "klorkolväte",
    "klorna": "klo",
    "klornas": "klo",
    "kloroformen": "kloroform",
    "kloroformens": "kloroform",
    "kloroforms": "kloroform",
    "klorofyllen": "klorofyll",
    "klorofyllens": "klorofyll",
    "klorofyllet": "klorofyll",
    "klorofyllets": "klorofyll",
    "klorofylls": "klorofyll",
    "klors": "klor",
    "klorsyran": "klorsyra",
    "klorsyrans": "klorsyra",
    "klorsyras": "klorsyra",
    "klorsyre": "klorsyra",
    "klorsyror": "klorsyra",
    "klorsyrorna": "klorsyra",
    "klorsyrornas": "klorsyra",
    "klorsyrors": "klorsyra",
    "klorvätes": "klorväte",
    "klorvätesyran": "klorvätesyra",
    "klorvätesyrans": "klorvätesyra",
    "klorvätesyras": "klorvätesyra",
    "klorvätesyre": "klorvätesyra",
    "klorvätesyror": "klorvätesyra",
    "klorvätesyrorna": "klorvätesyra",
    "klorvätesyrornas": "klorvätesyra",
    "klorvätesyrors": "klorvätesyra",
    "klorvätet": "klorväte",
    "klorvätets": "klorväte",
    "klos": "klo",
    "klosetten": "klosett",
    "klosettens": "klosett",
    "klosetter": "klosett",
    "klosetterna": "klosett",
    "klosetternas": "klosett",
    "klosetters": "klosett",
    "klosetts": "klosett",
    "klossar": "kloss",
    "klossarna": "kloss",
    "klossarnas": "kloss",
    "klossars": "kloss",
    "klossen": "kloss",
    "klossens": "kloss",
    "klossiga": "klossig",
    "klossigare": "klossig",
    "klossigares": "klossig",
    "klossigas": "klossig",
    "klossigast": "klossig",
    "klossigaste": "klossig",
    "klossigastes": "klossig",
    "klossigasts": "klossig",
    "klossige": "klossig",
    "klossiges": "klossig",
    "klossigheten": "klossighet",
    "klossighetens": "klossighet",
    "klossighets": "klossighet",
    "klossigs": "klossig",
    "klossigt": "klossig",
    "klossigts": "klossig",
    "klosterbrodern": "klosterbroder",
    "klosterbroderns": "klosterbroder",
    "klosterbroders": "klosterbroder",
    "klosterbröder": "klosterbroder",
    "klosterbröderna": "klosterbroder",
    "klosterbrödernas": "klosterbroder",
    "klosterbröders": "klosterbroder",
    "klostercellen": "klostercell",
    "klostercellens": "klostercell",
    "klosterceller": "klostercell",
    "klostercellerna": "klostercell",
    "klostercellernas": "klostercell",
    "klostercellers": "klostercell",
    "klostercells": "klostercell",
    "klosterkyrk": "klosterkyrka",
    "klosterkyrkan": "klosterkyrka",
    "klosterkyrkans": "klosterkyrka",
    "klosterkyrkas": "klosterkyrka",
    "klosterkyrke": "klosterkyrka",
    "klosterkyrko": "klosterkyrka",
    "klosterkyrkor": "klosterkyrka",
    "klosterkyrkorna": "klosterkyrka",
    "klosterkyrkornas": "klosterkyrka",
    "klosterkyrkors": "klosterkyrka",
    "klosterkyrks": "klosterkyrka",
    "klosterlikören": "klosterlikör",
    "klosterlikörens": "klosterlikör",
    "klosterlikörer": "klosterlikör",
    "klosterlikörerna": "klosterlikör",
    "klosterlikörernas": "klosterlikör",
    "klosterlikörers": "klosterlikör",
    "klosterlikörs": "klosterlikör",
    "klosterlöften": "klosterlöfte",
    "klosterlöftena": "klosterlöfte",
    "klosterlöftenas": "klosterlöfte",
    "klosterlöftens": "klosterlöfte",
    "klosterlöftes": "klosterlöfte",
    "klosterlöftet": "klosterlöfte",
    "klosterlöftets": "klosterlöfte",
    "klosterna": "kloster",
    "klosternas": "kloster",
    "klosterordens": "klosterorden",
    "klosterordnar": "klosterorden",
    "klosterordnarna": "klosterorden",
    "klosterordnarnas": "klosterorden",
    "klosterordnars": "klosterorden",
    "klosterordnen": "klosterorden",
    "klosterordnens": "klosterorden",
    "klosterregeln": "klosterregel",
    "klosterregelns": "klosterregel",
    "klosterregels": "klosterregel",
    "klosterregler": "klosterregel",
    "klosterreglerna": "klosterregel",
    "klosterreglernas": "klosterregel",
    "klosterreglers": "klosterregel",
    "klosters": "kloster",
    "klostersystern": "klostersyster",
    "klostersysterns": "klostersyster",
    "klostersysters": "klostersyster",
    "klostersystrar": "klostersyster",
    "klostersystrarna": "klostersyster",
    "klostersystrarnas": "klostersyster",
    "klostersystrars": "klostersyster",
    "klosterträdgårdar": "klosterträdgård",
    "klosterträdgårdarna": "klosterträdgård",
    "klosterträdgårdarnas": "klosterträdgård",
    "klosterträdgårdars": "klosterträdgård",
    "klosterträdgården": "klosterträdgård",
    "klosterträdgårdens": "klosterträdgård",
    "klosterträdgårds": "klosterträdgård",
    "klostren": "kloster",
    "klostrens": "kloster",
    "klostret": "kloster",
    "klostrets": "kloster",
    "klotblixtar": "klotblixt",
    "klotblixtarna": "klotblixt",
    "klotblixtarnas": "klotblixt",
    "klotblixtars": "klotblixt",
    "klotblixten": "klotblixt",
    "klotblixtens": "klotblixt",
    "klotblixts": "klotblixt",
    "kloten": "klot",
    "klotens": "klot",
    "klotet": "klot",
    "klotets": "klot",
    "klotformiga": "klotformig",
    "klotformigas": "klotformig",
    "klotformige": "klotformig",
    "klotformiges": "klotformig",
    "klotformigs": "klotformig",
    "klotformigt": "klotformig",
    "klotformigts": "klotformig",
    "klotgrillar": "klotgrill",
    "klotgrillarna": "klotgrill",
    "klotgrillarnas": "klotgrill",
    "klotgrillars": "klotgrill",
    "klotgrillen": "klotgrill",
    "klotgrillens": "klotgrill",
    "klotgrills": "klotgrill",
    "klotrunda": "klotrund",
    "klotrundare": "klotrund",
    "klotrundares": "klotrund",
    "klotrundas": "klotrund",
    "klotrundast": "klotrund",
    "klotrundaste": "klotrund",
    "klotrundastes": "klotrund",
    "klotrundasts": "klotrund",
    "klotrunde": "klotrund",
    "klotrundes": "klotrund",
    "klotrundheten": "klotrundhet",
    "klotrundhetens": "klotrundhet",
    "klotrundhets": "klotrundhet",
    "klotrunds": "klotrund",
    "klotrunt": "klotrund",
    "klotrunts": "klotrund",
    "klots": "klot",
    "klotsar": "klots",
    "klotsarna": "klots",
    "klotsarnas": "klots",
    "klotsars": "klots",
    "klotsen": "klots",
    "klotsens": "klots",
    "klotter": "klottra",
    "klotterplanken": "klotterplank",
    "klotterplankens": "klotterplank",
    "klotterplanket": "klotterplank",
    "klotterplankets": "klotterplank",
    "klotterplanks": "klotterplank",
    "klotters": "klotter",
    "klottrad": "klottra",
    "klottrade": "klottra",
    "klottrades": "klottra",
    "klottrads": "klottra",
    "klottrande": "klottra",
    "klottranden": "klottrande",
    "klottrandena": "klottrande",
    "klottrandenas": "klottrande",
    "klottrandens": "klottrande",
    "klottrandes": "klottrande",
    "klottrandet": "klottrande",
    "klottrandets": "klottrande",
    "klottrar": "klottra",
    "klottras": "klottra",
    "klottrat": "klottra",
    "klottrats": "klottra",
    "klottret": "klotter",
    "klottrets": "klotter",
    "klottriga": "klottrig",
    "klottrigare": "klottrig",
    "klottrigares": "klottrig",
    "klottrigas": "klottrig",
    "klottrigast": "klottrig",
    "klottrigaste": "klottrig",
    "klottrigastes": "klottrig",
    "klottrigasts": "klottrig",
    "klottrige": "klottrig",
    "klottriges": "klottrig",
    "klottrigheten": "klottrighet",
    "klottrighetens": "klottrighet",
    "klottrighets": "klottrighet",
    "klottrigs": "klottrig",
    "klottrigt": "klottrig",
    "klottrigts": "klottrig",
    "klotytan": "klotyta",
    "klotytans": "klotyta",
    "klotytas": "klotyta",
    "klotyte": "klotyta",
    "klotytor": "klotyta",
    "klotytorna": "klotyta",
    "klotytornas": "klotyta",
    "klotytors": "klotyta",
    "klotänger": "klotång",
    "klotängerna": "klotång",
    "klotängernas": "klotång",
    "klotängers": "klotång",
    "klotången": "klotång",
    "klotångens": "klotång",
    "klotångs": "klotång",
    "klov": "klove",
    "klovar": "klove",
    "klovarna": "klove",
    "klovarnas": "klove",
    "klovars": "klove",
    "kloven": "klove",
    "klovens": "klove",
    "kloves": "klove",
    "klovs": "klove",
    "klubb": "klubba",
    "klubbad": "klubba",
    "klubbade": "klubba",
    "klubbades": "klubba",
    "klubbads": "klubba",
    "klubbaftnar": "klubbafton",
    "klubbaftnarna": "klubbafton",
    "klubbaftnarnas": "klubbafton",
    "klubbaftnars": "klubbafton",
    "klubbaftonen": "klubbafton",
    "klubbaftonens": "klubbafton",
    "klubbaftons": "klubbafton",
    "klubban": "klubba",
    "klubbande": "klubba",
    "klubbanden": "klubbande",
    "klubbandena": "klubbande",
    "klubbandenas": "klubbande",
    "klubbandens": "klubbande",
    "klubbandes": "klubbande",
    "klubbandet": "klubbande",
    "klubbandets": "klubbande",
    "klubbans": "klubba",
    "klubbar": "klubba",
    "klubbarna": "klubb",
    "klubbarnas": "klubb",
    "klubbars": "klubb",
    "klubbas": "klubba",
    "klubbat": "klubba",
    "klubbats": "klubba",
    "klubbe": "klubba",
    "klubben": "klubb",
    "klubbens": "klubb",
    "klubbjack": "klubbjacka",
    "klubbjackan": "klubbjacka",
    "klubbjackans": "klubbjacka",
    "klubbjackas": "klubbjacka",
    "klubbjacke": "klubbjacka",
    "klubbjackor": "klubbjacka",
    "klubbjackorna": "klubbjacka",
    "klubbjackornas": "klubbjacka",
    "klubbjackors": "klubbjacka",
    "klubbjacks": "klubbjacka",
    "klubblängden": "klubblängd",
    "klubblängdens": "klubblängd",
    "klubblängder": "klubblängd",
    "klubblängderna": "klubblängd",
    "klubblängdernas": "klubblängd",
    "klubblängders": "klubblängd",
    "klubblängds": "klubblängd",
    "klubbmärken": "klubbmärke",
    "klubbmärkena": "klubbmärke",
    "klubbmärkenas": "klubbmärke",
    "klubbmärkens": "klubbmärke",
    "klubbmärkes": "klubbmärke",
    "klubbmärket": "klubbmärke",
    "klubbmärkets": "klubbmärke",
    "klubbmästar": "klubbmästare",
    "klubbmästaren": "klubbmästare",
    "klubbmästarens": "klubbmästare",
    "klubbmästares": "klubbmästare",
    "klubbmästarna": "klubbmästare",
    "klubbmästarnas": "klubbmästare",
    "klubbor": "klubba",
    "klubborna": "klubba",
    "klubbornas": "klubba",
    "klubbors": "klubba",
    "klubbs": "klubba",
    "klubbsandwichar": "klubbsandwich",
    "klubbsandwicharna": "klubbsandwich",
    "klubbsandwicharnas": "klubbsandwich",
    "klubbsandwichars": "klubbsandwich",
    "klubbsandwichen": "klubbsandwich",
    "klubbsandwichens": "klubbsandwich",
    "klubbsandwichs": "klubbsandwich",
    "klubbslagen": "klubbslag",
    "klubbslagens": "klubbslag",
    "klubbslaget": "klubbslag",
    "klubbslagets": "klubbslag",
    "klubbslags": "klubbslag",
    "kluck": "klucka",
    "kluckade": "klucka",
    "kluckades": "klucka",
    "kluckande": "klucka",
    "kluckanden": "kluckande",
    "kluckandena": "kluckande",
    "kluckandenas": "kluckande",
    "kluckandens": "kluckande",
    "kluckandes": "kluckande",
    "kluckandet": "kluckande",
    "kluckandets": "kluckande",
    "kluckar": "klucka",
    "kluckas": "klucka",
    "kluckat": "klucka",
    "kluckats": "klucka",
    "klucket": "kluck",
    "kluckets": "kluck",
    "klucks": "kluck",
    "kludd": "kludda",
    "kluddad": "kludda",
    "kluddade": "kludda",
    "kluddades": "kludda",
    "kluddads": "kludda",
    "kluddande": "kludda",
    "kluddanden": "kluddande",
    "kluddandena": "kluddande",
    "kluddandenas": "kluddande",
    "kluddandens": "kluddande",
    "kluddandes": "kluddande",
    "kluddandet": "kluddande",
    "kluddandets": "kluddande",
    "kluddar": "kludda",
    "kluddarna": "kludd",
    "kluddarnas": "kludd",
    "kluddars": "kludd",
    "kluddas": "kludda",
    "kluddat": "kludda",
    "kluddats": "kludda",
    "kludden": "kludd",
    "kluddens": "kludd",
    "kludders": "kludder",
    "kluddet": "kludd",
    "kluddets": "kludd",
    "kluddret": "kludder",
    "kluddrets": "kludder",
    "kludds": "kludd",
    "klumpackorden": "klumpackord",
    "klumpackordens": "klumpackord",
    "klumpackordet": "klumpackord",
    "klumpackordets": "klumpackord",
    "klumpackords": "klumpackord",
    "klumpar": "klump",
    "klumparna": "klump",
    "klumparnas": "klump",
    "klumpars": "klump",
    "klumpedumpar": "klumpedump",
    "klumpedumparna": "klumpedump",
    "klumpedumparnas": "klumpedump",
    "klumpedumpars": "klumpedump",
    "klumpedumpen": "klumpedump",
    "klumpedumpens": "klumpedump",
    "klumpedumps": "klumpedump",
    "klumpedunsar": "klumpeduns",
    "klumpedunsarna": "klumpeduns",
    "klumpedunsarnas": "klumpeduns",
    "klumpedunsars": "klumpeduns",
    "klumpedunsen": "klumpeduns",
    "klumpedunsens": "klumpeduns",
    "klumpen": "klump",
    "klumpens": "klump",
    "klumpfiskar": "klumpfisk",
    "klumpfiskarna": "klumpfisk",
    "klumpfiskarnas": "klumpfisk",
    "klumpfiskars": "klumpfisk",
    "klumpfisken": "klumpfisk",
    "klumpfiskens": "klumpfisk",
    "klumpfisks": "klumpfisk",
    "klumpfoten": "klumpfot",
    "klumpfotens": "klumpfot",
    "klumpfots": "klumpfot",
    "klumpiga": "klumpig",
    "klumpigare": "klumpig",
    "klumpigares": "klumpig",
    "klumpigas": "klumpig",
    "klumpigast": "klumpig",
    "klumpigaste": "klumpig",
    "klumpigastes": "klumpig",
    "klumpigasts": "klumpig",
    "klumpige": "klumpig",
    "klumpiges": "klumpig",
    "klumpigheten": "klumpighet",
    "klumpighetens": "klumpighet",
    "klumpigheter": "klumpighet",
    "klumpigheterna": "klumpighet",
    "klumpigheternas": "klumpighet",
    "klumpigheters": "klumpighet",
    "klumpighets": "klumpighet",
    "klumpigs": "klumpig",
    "klumpigt": "klumpig",
    "klumpigts": "klumpig",
    "klumps": "klump",
    "klumpsumman": "klumpsumma",
    "klumpsummans": "klumpsumma",
    "klumpsummas": "klumpsumma",
    "klumpsumme": "klumpsumma",
    "klumpsummor": "klumpsumma",
    "klumpsummorna": "klumpsumma",
    "klumpsummornas": "klumpsumma",
    "klumpsummors": "klumpsumma",
    "klumpsömmar": "klumpsöm",
    "klumpsömmarna": "klumpsöm",
    "klumpsömmarnas": "klumpsöm",
    "klumpsömmars": "klumpsöm",
    "klumpsömmen": "klumpsöm",
    "klumpsömmens": "klumpsöm",
    "klumpsöms": "klumpsöm",
    "klung": "klunga",
    "klungan": "klunga",
    "klungans": "klunga",
    "klungas": "klunga",
    "klunge": "klunga",
    "klungor": "klunga",
    "klungorna": "klunga",
    "klungornas": "klunga",
    "klungors": "klunga",
    "klungs": "klunga",
    "klunkade": "klunka",
    "klunkades": "klunka",
    "klunkande": "klunka",
    "klunkanden": "klunkande",
    "klunkandena": "klunkande",
    "klunkandenas": "klunkande",
    "klunkandens": "klunkande",
    "klunkandes": "klunkande",
    "klunkandet": "klunkande",
    "klunkandets": "klunkande",
    "klunkar": "klunka",
    "klunkarna": "klunk",
    "klunkarnas": "klunk",
    "klunkars": "klunk",
    "klunkas": "klunka",
    "klunkat": "klunka",
    "klunkats": "klunka",
    "klunken": "klunk",
    "klunkens": "klunk",
    "klunks": "klunk",
    "klunsar": "kluns",
    "klunsarna": "kluns",
    "klunsarnas": "kluns",
    "klunsars": "kluns",
    "klunsen": "kluns",
    "klunsens": "kluns",
    "klunsiga": "klunsig",
    "klunsigare": "klunsig",
    "klunsigares": "klunsig",
    "klunsigas": "klunsig",
    "klunsigast": "klunsig",
    "klunsigaste": "klunsig",
    "klunsigastes": "klunsig",
    "klunsigasts": "klunsig",
    "klunsige": "klunsig",
    "klunsiges": "klunsig",
    "klunsigheten": "klunsighet",
    "klunsighetens": "klunsighet",
    "klunsighets": "klunsighet",
    "klunsigs": "klunsig",
    "klunsigt": "klunsig",
    "klunsigts": "klunsig",
    "kluriga": "klurig",
    "klurigare": "klurig",
    "klurigares": "klurig",
    "klurigas": "klurig",
    "klurigast": "klurig",
    "klurigaste": "klurig",
    "klurigastes": "klurig",
    "klurigasts": "klurig",
    "klurige": "klurig",
    "kluriges": "klurig",
    "klurigheten": "klurighet",
    "klurighetens": "klurighet",
    "klurigheter": "klurighet",
    "klurigheterna": "klurighet",
    "klurigheternas": "klurighet",
    "klurigheters": "klurighet",
    "klurighets": "klurighet",
    "klurigs": "klurig",
    "klurigt": "klurig",
    "klurigts": "klurig",
    "kluringar": "kluring",
    "kluringarna": "kluring",
    "kluringarnas": "kluring",
    "kluringars": "kluring",
    "kluringen": "kluring",
    "kluringens": "kluring",
    "klurings": "kluring",
    "klusilen": "klusil",
    "klusilens": "klusil",
    "klusiler": "klusil",
    "klusilerna": "klusil",
    "klusilernas": "klusil",
    "klusilers": "klusil",
    "klusils": "klusil",
    "klusterbomben": "klusterbomb",
    "klusterbombens": "klusterbomb",
    "klusterbomber": "klusterbomb",
    "klusterbomberna": "klusterbomb",
    "klusterbombernas": "klusterbomb",
    "klusterbombers": "klusterbomb",
    "klusterbombs": "klusterbomb",
    "klusterna": "kluster",
    "klusternas": "kluster",
    "klusters": "kluster",
    "klustren": "kluster",
    "klustrens": "kluster",
    "klustret": "kluster",
    "klustrets": "kluster",
    "klutar": "klut",
    "klutarna": "klut",
    "klutarnas": "klut",
    "klutars": "klut",
    "kluten": "klut",
    "klutens": "klut",
    "kluts": "klut",
    "kluven": "klyva",
    "kluvenheten": "kluvenhet",
    "kluvenhetens": "kluvenhet",
    "kluvenheter": "kluvenhet",
    "kluvenheterna": "kluvenhet",
    "kluvenheternas": "kluvenhet",
    "kluvenheters": "kluvenhet",
    "kluvenhets": "kluvenhet",
    "kluvens": "klyva",
    "kluvet": "klyva",
    "kluvets": "klyva",
    "kluvit": "klyva",
    "kluvits": "klyva",
    "kluvna": "klyva",
    "kluvnare": "kluven",
    "kluvnares": "kluven",
    "kluvnas": "klyva",
    "kluvnast": "kluven",
    "kluvnaste": "kluven",
    "kluvnastes": "kluven",
    "kluvnasts": "kluven",
    "kluvne": "klyva",
    "kluvnes": "klyva",
    "klyft": "klyfta",
    "klyftad": "klyfta",
    "klyftade": "klyfta",
    "klyftades": "klyfta",
    "klyftads": "klyfta",
    "klyftan": "klyfta",
    "klyftande": "klyfta",
    "klyftanden": "klyftande",
    "klyftandena": "klyftande",
    "klyftandenas": "klyftande",
    "klyftandens": "klyftande",
    "klyftandes": "klyftande",
    "klyftandet": "klyftande",
    "klyftandets": "klyftande",
    "klyftans": "klyfta",
    "klyftar": "klyfta",
    "klyftas": "klyfta",
    "klyftat": "klyfta",
    "klyftats": "klyfta",
    "klyfte": "klyfta",
    "klyften": "klyft",
    "klyftens": "klyft",
    "klyfter": "klyft",
    "klyfterna": "klyft",
    "klyfternas": "klyft",
    "klyfters": "klyft",
    "klyftiga": "klyftig",
    "klyftigare": "klyftig",
    "klyftigares": "klyftig",
    "klyftigas": "klyftig",
    "klyftigast": "klyftig",
    "klyftigaste": "klyftig",
    "klyftigastes": "klyftig",
    "klyftigasts": "klyftig",
    "klyftige": "klyftig",
    "klyftiges": "klyftig",
    "klyftigheten": "klyftighet",
    "klyftighetens": "klyftighet",
    "klyftighets": "klyftighet",
    "klyftigs": "klyftig",
    "klyftigt": "klyftig",
    "klyftigts": "klyftig",
    "klyftor": "klyfta",
    "klyftorna": "klyfta",
    "klyftornas": "klyfta",
    "klyftors": "klyfta",
    "klyftpotatisen": "klyftpotatis",
    "klyftpotatisens": "klyftpotatis",
    "klyfts": "klyfta",
    "klyk": "klyka",
    "klykan": "klyka",
    "klykans": "klyka",
    "klykas": "klyka",
    "klyke": "klyka",
    "klykor": "klyka",
    "klykorna": "klyka",
    "klykornas": "klyka",
    "klykors": "klyka",
    "klyks": "klyka",
    "klysch": "klyscha",
    "klyschan": "klyscha",
    "klyschans": "klyscha",
    "klyschas": "klyscha",
    "klysche": "klyscha",
    "klyschiga": "klyschig",
    "klyschigare": "klyschig",
    "klyschigares": "klyschig",
    "klyschigas": "klyschig",
    "klyschigast": "klyschig",
    "klyschigaste": "klyschig",
    "klyschigastes": "klyschig",
    "klyschigasts": "klyschig",
    "klyschige": "klyschig",
    "klyschiges": "klyschig",
    "klyschigheten": "klyschighet",
    "klyschighetens": "klyschighet",
    "klyschighets": "klyschighet",
    "klyschigs": "klyschig",
    "klyschigt": "klyschig",
    "klyschigts": "klyschig",
    "klyschor": "klyscha",
    "klyschorna": "klyscha",
    "klyschornas": "klyscha",
    "klyschors": "klyscha",
    "klysen": "klys",
    "klysens": "klys",
    "klyset": "klys",
    "klysets": "klys",
    "klyv": "klyva",
    "klyvande": "klyva",
    "klyvanden": "klyvande",
    "klyvandena": "klyvande",
    "klyvandenas": "klyvande",
    "klyvandens": "klyvande",
    "klyvandes": "klyvande",
    "klyvandet": "klyvande",
    "klyvandets": "klyvande",
    "klyvar": "klyvare",
    "klyvarbommar": "klyvarbom",
    "klyvarbommarna": "klyvarbom",
    "klyvarbommarnas": "klyvarbom",
    "klyvarbommars": "klyvarbom",
    "klyvarbommen": "klyvarbom",
    "klyvarbommens": "klyvarbom",
    "klyvarboms": "klyvarbom",
    "klyvaren": "klyvare",
    "klyvarens": "klyvare",
    "klyvares": "klyvare",
    "klyvarna": "klyvare",
    "klyvarnas": "klyvare",
    "klyvars": "klyv",
    "klyvas": "klyva",
    "klyvbara": "klyvbar",
    "klyvbarare": "klyvbar",
    "klyvbarares": "klyvbar",
    "klyvbaras": "klyvbar",
    "klyvbarast": "klyvbar",
    "klyvbaraste": "klyvbar",
    "klyvbarastes": "klyvbar",
    "klyvbarasts": "klyvbar",
    "klyvbare": "klyvbar",
    "klyvbares": "klyvbar",
    "klyvbarheten": "klyvbarhet",
    "klyvbarhetens": "klyvbarhet",
    "klyvbarhets": "klyvbarhet",
    "klyvbars": "klyvbar",
    "klyvbart": "klyvbar",
    "klyvbarts": "klyvbar",
    "klyve": "klyva",
    "klyven": "klyv",
    "klyvens": "klyv",
    "klyver": "klyva",
    "klyves": "klyva",
    "klyvit": "klyva",
    "klyvits": "klyva",
    "klyvningar": "klyvning",
    "klyvningarna": "klyvning",
    "klyvningarnas": "klyvning",
    "klyvningars": "klyvning",
    "klyvningen": "klyvning",
    "klyvningens": "klyvning",
    "klyvnings": "klyvning",
    "klyvningsreaktionen": "klyvningsreaktion",
    "klyvningsreaktionens": "klyvningsreaktion",
    "klyvningsreaktioner": "klyvningsreaktion",
    "klyvningsreaktionerna": "klyvningsreaktion",
    "klyvningsreaktionernas": "klyvningsreaktion",
    "klyvningsreaktioners": "klyvningsreaktion",
    "klyvningsreaktions": "klyvningsreaktion",
    "klyvs": "klyva",
    "klyvsågar": "klyvsåg",
    "klyvsågarna": "klyvsåg",
    "klyvsågarnas": "klyvsåg",
    "klyvsågars": "klyvsåg",
    "klyvsågen": "klyvsåg",
    "klyvsågens": "klyvsåg",
    "klyvsågs": "klyvsåg",
    "klyvt": "klyva",
    "klyvts": "klyva",
    "klyvyx": "klyvyxa",
    "klyvyxan": "klyvyxa",
    "klyvyxans": "klyvyxa",
    "klyvyxas": "klyvyxa",
    "klyvyxe": "klyvyxa",
    "klyvyxor": "klyvyxa",
    "klyvyxorna": "klyvyxa",
    "klyvyxornas": "klyvyxa",
    "klyvyxors": "klyvyxa",
    "klyvöppningar": "klyvöppning",
    "klyvöppningarna": "klyvöppning",
    "klyvöppningarnas": "klyvöppning",
    "klyvöppningars": "klyvöppning",
    "klyvöppningen": "klyvöppning",
    "klyvöppningens": "klyvöppning",
    "klyvöppnings": "klyvöppning",
    "kläck": "kläcka",
    "kläckande": "kläcka",
    "kläckanden": "kläckande",
    "kläckandena": "kläckande",
    "kläckandenas": "kläckande",
    "kläckandens": "kläckande",
    "kläckandes": "kläckande",
    "kläckandet": "kläckande",
    "kläckandets": "kläckande",
    "kläckas": "kläcka",
    "kläcker": "kläcka",
    "kläckes": "kläcka",
    "kläcks": "kläcka",
    "kläckt": "kläcka",
    "kläckta": "kläcka",
    "kläcktas": "kläcka",
    "kläckte": "kläcka",
    "kläcktes": "kläckas",
    "kläckts": "kläckas",
    "kläd": "kläder",
    "kläda": "klä",
    "klädande": "klä",
    "klädanden": "klädande",
    "klädandena": "klädande",
    "klädandenas": "klädande",
    "klädandens": "klädande",
    "klädandes": "klädande",
    "klädandet": "klädande",
    "klädandets": "klädande",
    "klädas": "klä",
    "klädbyten": "klädbyte",
    "klädbytena": "klädbyte",
    "klädbytenas": "klädbyte",
    "klädbytens": "klädbyte",
    "klädbytes": "klädbyte",
    "klädbytet": "klädbyte",
    "klädbytets": "klädbyte",
    "klädd": "klä",
    "klädda": "klädd",
    "kläddare": "klädd",
    "kläddares": "klädd",
    "kläddas": "klädd",
    "kläddast": "klädd",
    "kläddaste": "klädd",
    "kläddastes": "klädd",
    "kläddasts": "klädd",
    "klädde": "klädd",
    "kläddes": "klädd",
    "klädds": "klädd",
    "klädedräkten": "klädedräkt",
    "klädedräktens": "klädedräkt",
    "klädedräkter": "klädedräkt",
    "klädedräkterna": "klädedräkt",
    "klädedräkternas": "klädedräkt",
    "klädedräkters": "klädedräkt",
    "klädedräkts": "klädedräkt",
    "kläden": "kläde",
    "klädena": "kläde",
    "klädenas": "kläde",
    "klädens": "kläde",
    "kläder": "klä",
    "kläderna": "kläder",
    "klädernas": "kläder",
    "kläders": "kläder",
    "klädes": "kläder",
    "klädesmässiga": "klädesmässig",
    "klädesmässigare": "klädesmässig",
    "klädesmässigares": "klädesmässig",
    "klädesmässigas": "klädesmässig",
    "klädesmässigast": "klädesmässig",
    "klädesmässigaste": "klädesmässig",
    "klädesmässigastes": "klädesmässig",
    "klädesmässigasts": "klädesmässig",
    "klädesmässige": "klädesmässig",
    "klädesmässiges": "klädesmässig",
    "klädesmässigs": "klädesmässig",
    "klädesmässigt": "klädesmässig",
    "klädesmässigts": "klädesmässig",
    "klädespersedeln": "klädespersedel",
    "klädespersedelns": "klädespersedel",
    "klädespersedels": "klädespersedel",
    "klädespersedlar": "klädespersedel",
    "klädespersedlarna": "klädespersedel",
    "klädespersedlarnas": "klädespersedel",
    "klädespersedlars": "klädespersedel",
    "klädesplaggen": "klädesplagg",
    "klädesplaggens": "klädesplagg",
    "klädesplagget": "klädesplagg",
    "klädesplaggets": "klädesplagg",
    "klädesplaggs": "klädesplagg",
    "klädet": "kläde",
    "klädets": "kläde",
    "klädgalenheten": "klädgalenhet",
    "klädgalenhetens": "klädgalenhet",
    "klädgalenhets": "klädgalenhet",
    "klädgalens": "klädgalen",
    "klädgalet": "klädgalen",
    "klädgalets": "klädgalen",
    "klädgalna": "klädgalen",
    "klädgalnare": "klädgalen",
    "klädgalnares": "klädgalen",
    "klädgalnas": "klädgalen",
    "klädgalnast": "klädgalen",
    "klädgalnaste": "klädgalen",
    "klädgalnastes": "klädgalen",
    "klädgalnasts": "klädgalen",
    "klädgalne": "klädgalen",
    "klädgalnes": "klädgalen",
    "klädhängar": "klädhängare",
    "klädhängaren": "klädhängare",
    "klädhängarens": "klädhängare",
    "klädhängares": "klädhängare",
    "klädhängarna": "klädhängare",
    "klädhängarnas": "klädhängare",
    "klädhögar": "klädhög",
    "klädhögarna": "klädhög",
    "klädhögarnas": "klädhög",
    "klädhögars": "klädhög",
    "klädhögen": "klädhög",
    "klädhögens": "klädhög",
    "klädhögs": "klädhög",
    "klädkammar": "klädkammare",
    "klädkammaren": "klädkammare",
    "klädkammarens": "klädkammare",
    "klädkammares": "klädkammare",
    "klädkamrar": "klädkammare",
    "klädkamrarna": "klädkammare",
    "klädkamrarnas": "klädkammare",
    "klädkamrars": "klädkammare",
    "klädkoden": "klädkod",
    "klädkodens": "klädkod",
    "klädkoder": "klädkod",
    "klädkoderna": "klädkod",
    "klädkodernas": "klädkod",
    "klädkoders": "klädkod",
    "klädkods": "klädkod",
    "klädkorgar": "klädkorg",
    "klädkorgarna": "klädkorg",
    "klädkorgarnas": "klädkorg",
    "klädkorgars": "klädkorg",
    "klädkorgen": "klädkorg",
    "klädkorgens": "klädkorg",
    "klädkorgs": "klädkorg",
    "klädlusen": "klädlus",
    "klädlusens": "klädlus",
    "klädlöss": "klädlus",
    "klädlössen": "klädlus",
    "klädlössens": "klädlus",
    "klädmalar": "klädmal",
    "klädmalarna": "klädmal",
    "klädmalarnas": "klädmal",
    "klädmalars": "klädmal",
    "klädmalen": "klädmal",
    "klädmalens": "klädmal",
    "klädmals": "klädmal",
    "klädnaden": "klädnad",
    "klädnadens": "klädnad",
    "klädnader": "klädnad",
    "klädnaderna": "klädnad",
    "klädnadernas": "klädnad",
    "klädnaders": "klädnad",
    "klädnads": "klädnad",
    "klädnyp": "klädnypa",
    "klädnypan": "klädnypa",
    "klädnypans": "klädnypa",
    "klädnypas": "klädnypa",
    "klädnype": "klädnypa",
    "klädnypor": "klädnypa",
    "klädnyporna": "klädnypa",
    "klädnypornas": "klädnypa",
    "klädnypors": "klädnypa",
    "klädnyps": "klädnypa",
    "klädpokern": "klädpoker",
    "klädpokerns": "klädpoker",
    "klädpokers": "klädpoker",
    "kläds": "kläder",
    "klädsamheten": "klädsamhet",
    "klädsamhetens": "klädsamhet",
    "klädsamhets": "klädsamhet",
    "klädsamma": "klädsam",
    "klädsammare": "klädsam",
    "klädsammares": "klädsam",
    "klädsammas": "klädsam",
    "klädsammast": "klädsam",
    "klädsammaste": "klädsam",
    "klädsammastes": "klädsam",
    "klädsammasts": "klädsam",
    "klädsamme": "klädsam",
    "klädsammes": "klädsam",
    "klädsams": "klädsam",
    "klädsamt": "klädsam",
    "klädsamts": "klädsam",
    "klädseln": "klädsel",
    "klädselns": "klädsel",
    "klädsels": "klädsel",
    "klädseltvättar": "klädseltvätt",
    "klädseltvättarna": "klädseltvätt",
    "klädseltvättarnas": "klädseltvätt",
    "klädseltvättars": "klädseltvätt",
    "klädseltvätten": "klädseltvätt",
    "klädseltvättens": "klädseltvätt",
    "klädseltvätts": "klädseltvätt",
    "klädsimmet": "klädsim",
    "klädsimmets": "klädsim",
    "klädsims": "klädsim",
    "klädskåpen": "klädskåp",
    "klädskåpens": "klädskåp",
    "klädskåpet": "klädskåp",
    "klädskåpets": "klädskåp",
    "klädskåps": "klädskåp",
    "klädslar": "klädsel",
    "klädslarna": "klädsel",
    "klädslarnas": "klädsel",
    "klädslars": "klädsel",
    "klädspännen": "klädspänne",
    "klädspännena": "klädspänne",
    "klädspännenas": "klädspänne",
    "klädspännens": "klädspänne",
    "klädspännes": "klädspänne",
    "klädspännet": "klädspänne",
    "klädspännets": "klädspänne",
    "klädstorlekar": "klädstorlek",
    "klädstorlekarna": "klädstorlek",
    "klädstorlekarnas": "klädstorlek",
    "klädstorlekars": "klädstorlek",
    "klädstorleken": "klädstorlek",
    "klädstorlekens": "klädstorlek",
    "klädstorleks": "klädstorlek",
    "klädstrecken": "klädstreck",
    "klädstreckens": "klädstreck",
    "klädstrecket": "klädstreck",
    "klädstreckets": "klädstreck",
    "klädstrecks": "klädstreck",
    "klädsömnaden": "klädsömnad",
    "klädsömnadens": "klädsömnad",
    "klädsömnads": "klädsömnad",
    "klädtras": "klädtrasa",
    "klädtrasan": "klädtrasa",
    "klädtrasans": "klädtrasa",
    "klädtrasas": "klädtrasa",
    "klädtrase": "klädtrasa",
    "klädtrasor": "klädtrasa",
    "klädtrasorna": "klädtrasa",
    "klädtrasornas": "klädtrasa",
    "klädtrasors": "klädtrasa",
    "klädtvättar": "klädtvätt",
    "klädtvättarna": "klädtvätt",
    "klädtvättarnas": "klädtvätt",
    "klädtvättars": "klädtvätt",
    "klädtvätten": "klädtvätt",
    "klädtvättens": "klädtvätt",
    "klädtvätts": "klädtvätt",
    "kläende": "klä",
    "kläenden": "kläende",
    "kläendena": "kläende",
    "kläendenas": "kläende",
    "kläendens": "kläende",
    "kläendes": "kläende",
    "kläendet": "kläende",
    "kläendets": "kläende",
    "kläm": "klämma",
    "klämd": "klämma",
    "klämda": "klämma",
    "klämdagar": "klämdag",
    "klämdagarna": "klämdag",
    "klämdagarnas": "klämdag",
    "klämdagars": "klämdag",
    "klämdagen": "klämdag",
    "klämdagens": "klämdag",
    "klämdags": "klämdag",
    "klämdas": "klämma",
    "klämde": "klämma",
    "klämdes": "klämma",
    "klämds": "klämma",
    "klämkäckhetet": "klämkäckhet",
    "klämkäckhetets": "klämkäckhet",
    "klämkäckhets": "klämkäckhet",
    "klämman": "klämma",
    "klämmande": "klämma",
    "klämmanden": "klämmande",
    "klämmandena": "klämmande",
    "klämmandenas": "klämmande",
    "klämmandens": "klämmande",
    "klämmandes": "klämmande",
    "klämmandet": "klämmande",
    "klämmandets": "klämmande",
    "klämmans": "klämma",
    "klämmar": "klämmare",
    "klämmaren": "klämmare",
    "klämmarens": "klämmare",
    "klämmares": "klämmare",
    "klämmarna": "klämmare",
    "klämmarnas": "klämmare",
    "klämmars": "kläm",
    "klämmas": "klämma",
    "klämme": "klämma",
    "klämmen": "kläm",
    "klämmens": "kläm",
    "klämmer": "klämma",
    "klämmiga": "klämmig",
    "klämmigare": "klämmig",
    "klämmigares": "klämmig",
    "klämmigas": "klämmig",
    "klämmigast": "klämmig",
    "klämmigaste": "klämmig",
    "klämmigastes": "klämmig",
    "klämmigasts": "klämmig",
    "klämmige": "klämmig",
    "klämmiges": "klämmig",
    "klämmigheten": "klämmighet",
    "klämmighetens": "klämmighet",
    "klämmighets": "klämmighet",
    "klämmigs": "klämmig",
    "klämmigt": "klämmig",
    "klämmigts": "klämmig",
    "klämmor": "klämma",
    "klämmorna": "klämma",
    "klämmornas": "klämma",
    "klämmors": "klämma",
    "kläms": "klämma",
    "klämt": "klämta",
    "klämtade": "klämta",
    "klämtades": "klämta",
    "klämtande": "klämta",
    "klämtanden": "klämtande",
    "klämtandena": "klämtande",
    "klämtandenas": "klämtande",
    "klämtandens": "klämtande",
    "klämtandes": "klämtande",
    "klämtandet": "klämtande",
    "klämtandets": "klämtande",
    "klämtar": "klämtare",
    "klämtaren": "klämtare",
    "klämtarens": "klämtare",
    "klämtares": "klämtare",
    "klämtarna": "klämtare",
    "klämtarnas": "klämtare",
    "klämtas": "klämta",
    "klämtat": "klämta",
    "klämtats": "klämta",
    "klämts": "klämma",
    "kläng": "klänga",
    "klängande": "klänga",
    "klänganden": "klängande",
    "klängandena": "klängande",
    "klängandenas": "klängande",
    "klängandens": "klängande",
    "klängandes": "klängande",
    "klängandet": "klängande",
    "klängandets": "klängande",
    "klängas": "klänga",
    "klängd": "klänga",
    "klängda": "klänga",
    "klängdas": "klänga",
    "klängde": "klänga",
    "klängdes": "klänga",
    "klängds": "klänga",
    "klängen": "klänge",
    "klängena": "klänge",
    "klängenas": "klänge",
    "klängens": "klänge",
    "klänger": "klänga",
    "klänges": "klänge",
    "klänget": "klänge",
    "klängets": "klänge",
    "klängiga": "klängig",
    "klängigare": "klängig",
    "klängigares": "klängig",
    "klängigas": "klängig",
    "klängigast": "klängig",
    "klängigaste": "klängig",
    "klängigastes": "klängig",
    "klängigasts": "klängig",
    "klängige": "klängig",
    "klängiges": "klängig",
    "klängigheten": "klängighet",
    "klängighetens": "klängighet",
    "klängighets": "klängighet",
    "klängigs": "klängig",
    "klängigt": "klängig",
    "klängigts": "klängig",
    "klängrank": "klängranka",
    "klängrankan": "klängranka",
    "klängrankans": "klängranka",
    "klängrankas": "klängranka",
    "klängranke": "klängranka",
    "klängrankor": "klängranka",
    "klängrankorna": "klängranka",
    "klängrankornas": "klängranka",
    "klängrankors": "klängranka",
    "klängranks": "klängranka",
    "klängs": "klänge",
    "klängt": "klänga",
    "klängts": "klänga",
    "klängväxten": "klängväxt",
    "klängväxtens": "klängväxt",
    "klängväxter": "klängväxt",
    "klängväxterna": "klängväxt",
    "klängväxternas": "klängväxt",
    "klängväxters": "klängväxt",
    "klängväxts": "klängväxt",
    "klänningar": "klänning",
    "klänningarna": "klänning",
    "klänningarnas": "klänning",
    "klänningars": "klänning",
    "klänningen": "klänning",
    "klänningens": "klänning",
    "klännings": "klänning",
    "klänningsliven": "klänningsliv",
    "klänningslivens": "klänningsliv",
    "klänningslivet": "klänningsliv",
    "klänningslivets": "klänningsliv",
    "klänningslivs": "klänningsliv",
    "kläppar": "kläpp",
    "kläpparna": "kläpp",
    "kläpparnas": "kläpp",
    "kläppars": "kläpp",
    "kläppen": "kläpp",
    "kläppens": "kläpp",
    "kläpps": "kläpp",
    "klär": "klä",
    "klärobskyren": "klärobskyr",
    "klärobskyrens": "klärobskyr",
    "klärobskyrer": "klärobskyr",
    "klärobskyrerna": "klärobskyr",
    "klärobskyrernas": "klärobskyr",
    "klärobskyrers": "klärobskyr",
    "klärobskyrs": "klärobskyr",
    "klärvoajansen": "klärvoajans",
    "klärvoajansens": "klärvoajans",
    "klärvoajanta": "klärvoajant",
    "klärvoajantare": "klärvoajant",
    "klärvoajantares": "klärvoajant",
    "klärvoajantas": "klärvoajant",
    "klärvoajantast": "klärvoajant",
    "klärvoajantaste": "klärvoajant",
    "klärvoajantastes": "klärvoajant",
    "klärvoajantasts": "klärvoajant",
    "klärvoajante": "klärvoajant",
    "klärvoajantes": "klärvoajant",
    "klärvoajants": "klärvoajant",
    "kläs": "klä",
    "klätt": "klädd",
    "klättar": "klätt",
    "klättarna": "klätt",
    "klättarnas": "klätt",
    "klättars": "klätt",
    "klätten": "klätt",
    "klättens": "klätt",
    "klätter": "klättra",
    "klätterfoten": "klätterfot",
    "klätterfotens": "klätterfot",
    "klätterfots": "klätterfot",
    "klätterfågeln": "klätterfågel",
    "klätterfågelns": "klätterfågel",
    "klätterfågels": "klätterfågel",
    "klätterfåglar": "klätterfågel",
    "klätterfåglarna": "klätterfågel",
    "klätterfåglarnas": "klätterfågel",
    "klätterfåglars": "klätterfågel",
    "klätterfötter": "klätterfot",
    "klätterfötterna": "klätterfot",
    "klätterfötternas": "klätterfot",
    "klätterfötters": "klätterfot",
    "klätterjärnen": "klätterjärn",
    "klätterjärnens": "klätterjärn",
    "klätterjärnet": "klätterjärn",
    "klätterjärnets": "klätterjärn",
    "klätterjärns": "klätterjärn",
    "klätterrepen": "klätterrep",
    "klätterrepens": "klätterrep",
    "klätterrepet": "klätterrep",
    "klätterrepets": "klätterrep",
    "klätterreps": "klätterrep",
    "klätterrosen": "klätterros",
    "klätterrosens": "klätterros",
    "klätterrosor": "klätterros",
    "klätterrosorna": "klätterros",
    "klätterrosornas": "klätterros",
    "klätterrosors": "klätterros",
    "klätterskon": "klättersko",
    "klätterskons": "klättersko",
    "klätterskor": "klättersko",
    "klätterskorna": "klättersko",
    "klätterskornas": "klättersko",
    "klätterskors": "klättersko",
    "klätterskos": "klättersko",
    "klätterställningar": "klätterställning",
    "klätterställningarna": "klätterställning",
    "klätterställningarnas": "klätterställning",
    "klätterställningars": "klätterställning",
    "klätterställningen": "klätterställning",
    "klätterställningens": "klätterställning",
    "klätterställnings": "klätterställning",
    "klätterväxten": "klätterväxt",
    "klätterväxtens": "klätterväxt",
    "klätterväxter": "klätterväxt",
    "klätterväxterna": "klätterväxt",
    "klätterväxternas": "klätterväxt",
    "klätterväxters": "klätterväxt",
    "klätterväxts": "klätterväxt",
    "klättrad": "klättra",
    "klättrade": "klättra",
    "klättrades": "klättra",
    "klättrads": "klättra",
    "klättrande": "klättra",
    "klättranden": "klättrande",
    "klättrandena": "klättrande",
    "klättrandenas": "klättrande",
    "klättrandens": "klättrande",
    "klättrandes": "klättrande",
    "klättrandet": "klättrande",
    "klättrandets": "klättrande",
    "klättrar": "klättrare",
    "klättraren": "klättrare",
    "klättrarens": "klättrare",
    "klättrares": "klättrare",
    "klättrarna": "klättrare",
    "klättrarnas": "klättrare",
    "klättras": "klättra",
    "klättrat": "klättra",
    "klättrats": "klättra",
    "klättringar": "klättring",
    "klättringarna": "klättring",
    "klättringarnas": "klättring",
    "klättringars": "klättring",
    "klättringen": "klättring",
    "klättringens": "klättring",
    "klättrings": "klättring",
    "klätts": "klätt",
    "klådan": "klåda",
    "klådans": "klåda",
    "klådas": "klåda",
    "klådd": "klå",
    "klådda": "klå",
    "klåddas": "klå",
    "klådde": "klå",
    "klåddes": "klå",
    "klådds": "klå",
    "klående": "klå",
    "klåenden": "klående",
    "klåendena": "klående",
    "klåendenas": "klående",
    "klåendens": "klående",
    "klåendes": "klående",
    "klåendet": "klående",
    "klåendets": "klående",
    "klåfingriga": "klåfingrig",
    "klåfingrigare": "klåfingrig",
    "klåfingrigares": "klåfingrig",
    "klåfingrigas": "klåfingrig",
    "klåfingrigast": "klåfingrig",
    "klåfingrigaste": "klåfingrig",
    "klåfingrigastes": "klåfingrig",
    "klåfingrigasts": "klåfingrig",
    "klåfingrige": "klåfingrig",
    "klåfingriges": "klåfingrig",
    "klåfingrigheten": "klåfingrighet",
    "klåfingrighetens": "klåfingrighet",
    "klåfingrighets": "klåfingrighet",
    "klåfingrigs": "klåfingrig",
    "klåfingrigt": "klåfingrig",
    "klåfingrigts": "klåfingrig",
    "klåp": "klåpa",
    "klåpade": "klåpa",
    "klåpades": "klåpa",
    "klåpande": "klåpa",
    "klåpanden": "klåpande",
    "klåpandena": "klåpande",
    "klåpandenas": "klåpande",
    "klåpandens": "klåpande",
    "klåpandes": "klåpande",
    "klåpandet": "klåpande",
    "klåpandets": "klåpande",
    "klåpar": "klåpare",
    "klåparen": "klåpare",
    "klåparens": "klåpare",
    "klåpares": "klåpare",
    "klåparna": "klåpare",
    "klåparnas": "klåpare",
    "klåpas": "klåpa",
    "klåpat": "klåpa",
    "klåpats": "klåpa",
    "klår": "klå",
    "klås": "klå",
    "klått": "klå",
    "klåtts": "klå",
    "klös": "klösa",
    "klösande": "klösa",
    "klösanden": "klösande",
    "klösandena": "klösande",
    "klösandenas": "klösande",
    "klösandens": "klösande",
    "klösandes": "klösande",
    "klösandet": "klösande",
    "klösandets": "klösande",
    "klösas": "klösa",
    "klöser": "klösa",
    "klöses": "klösa",
    "klöst": "klösa",
    "klösta": "klösa",
    "klöstas": "klösa",
    "klöste": "klösa",
    "klöstes": "klösas",
    "klösts": "klösas",
    "klöv": "klyva",
    "klövade": "klövad",
    "klövades": "klövad",
    "klövads": "klövad",
    "klövar": "klöv",
    "klövarna": "klöv",
    "klövarnas": "klöv",
    "klövars": "klöv",
    "klövat": "klövad",
    "klövats": "klövad",
    "klöve": "klyva",
    "klöven": "klöv",
    "klövens": "klöv",
    "klöverbladen": "klöverblad",
    "klöverbladens": "klöverblad",
    "klöverbladet": "klöverblad",
    "klöverbladets": "klöverblad",
    "klöverblads": "klöverblad",
    "klövern": "klöver",
    "klöverna": "klöver",
    "klövernas": "klöver",
    "klöverns": "klöver",
    "klövers": "klöver",
    "klöversnärjan": "klöversnärja",
    "klöversnärjans": "klöversnärja",
    "klöversnärjas": "klöversnärja",
    "klöversnärje": "klöversnärja",
    "klöversnärjor": "klöversnärja",
    "klöversnärjorna": "klöversnärja",
    "klöversnärjornas": "klöversnärja",
    "klöversnärjors": "klöversnärja",
    "klövertrötta": "klövertrött",
    "klövertröttare": "klövertrött",
    "klövertröttares": "klövertrött",
    "klövertröttas": "klövertrött",
    "klövertröttast": "klövertrött",
    "klövertröttaste": "klövertrött",
    "klövertröttastes": "klövertrött",
    "klövertröttasts": "klövertrött",
    "klövertrötte": "klövertrött",
    "klövertröttes": "klövertrött",
    "klövertröttheten": "klövertrötthet",
    "klövertrötthetens": "klövertrötthet",
    "klövertrötthets": "klövertrötthet",
    "klövertrötts": "klövertrött",
    "klöves": "klyva",
    "klövj": "klövja",
    "klövjad": "klövja",
    "klövjade": "klövja",
    "klövjades": "klövja",
    "klövjads": "klövja",
    "klövjande": "klövja",
    "klövjanden": "klövjande",
    "klövjandena": "klövjande",
    "klövjandenas": "klövjande",
    "klövjandens": "klövjande",
    "klövjandes": "klövjande",
    "klövjandet": "klövjande",
    "klövjandets": "klövjande",
    "klövjar": "klövja",
    "klövjas": "klövja",
    "klövjat": "klövja",
    "klövjats": "klövja",
    "klövjerenar": "klövjeren",
    "klövjerenarna": "klövjeren",
    "klövjerenarnas": "klövjeren",
    "klövjerenars": "klövjeren",
    "klövjerenen": "klövjeren",
    "klövjerenens": "klövjeren",
    "klövjerens": "klövjeren",
    "klövjesadeln": "klövjesadel",
    "klövjesadelns": "klövjesadel",
    "klövjesadels": "klövjesadel",
    "klövjesadlar": "klövjesadel",
    "klövjesadlarna": "klövjesadel",
    "klövjesadlarnas": "klövjesadel",
    "klövjesadlars": "klövjesadel",
    "klövs": "klyva",
    "klövsadelbyggnaden": "klövsadelbyggnad",
    "klövsadelbyggnadens": "klövsadelbyggnad",
    "klövsadelbyggnader": "klövsadelbyggnad",
    "klövsadelbyggnaderna": "klövsadelbyggnad",
    "klövsadelbyggnadernas": "klövsadelbyggnad",
    "klövsadelbyggnaders": "klövsadelbyggnad",
    "klövsadelbyggnads": "klövsadelbyggnad",
    "klövsadelkyrk": "klövsadelkyrka",
    "klövsadelkyrkan": "klövsadelkyrka",
    "klövsadelkyrkans": "klövsadelkyrka",
    "klövsadelkyrkas": "klövsadelkyrka",
    "klövsadelkyrke": "klövsadelkyrka",
    "klövsadelkyrko": "klövsadelkyrka",
    "klövsadelkyrkor": "klövsadelkyrka",
    "klövsadelkyrkorna": "klövsadelkyrka",
    "klövsadelkyrkornas": "klövsadelkyrka",
    "klövsadelkyrkors": "klövsadelkyrka",
    "klövsadelkyrks": "klövsadelkyrka",
    "klövsadeln": "klövsadel",
    "klövsadelns": "klövsadel",
    "klövsadels": "klövsadel",
    "klövsadelsbyggnaden": "klövsadelsbyggnad",
    "klövsadelsbyggnadens": "klövsadelsbyggnad",
    "klövsadelsbyggnader": "klövsadelsbyggnad",
    "klövsadelsbyggnaderna": "klövsadelsbyggnad",
    "klövsadelsbyggnadernas": "klövsadelsbyggnad",
    "klövsadelsbyggnaders": "klövsadelsbyggnad",
    "klövsadelsbyggnads": "klövsadelsbyggnad",
    "klövsadelskyrk": "klövsadelskyrka",
    "klövsadelskyrkan": "klövsadelskyrka",
    "klövsadelskyrkans": "klövsadelskyrka",
    "klövsadelskyrkas": "klövsadelskyrka",
    "klövsadelskyrke": "klövsadelskyrka",
    "klövsadelskyrko": "klövsadelskyrka",
    "klövsadelskyrkor": "klövsadelskyrka",
    "klövsadelskyrkorna": "klövsadelskyrka",
    "klövsadelskyrkornas": "klövsadelskyrka",
    "klövsadelskyrkors": "klövsadelskyrka",
    "klövsadelskyrks": "klövsadelskyrka",
    "klövsadlar": "klövsadel",
    "klövsadlarna": "klövsadel",
    "klövsadlarnas": "klövsadel",
    "klövsadlars": "klövsadel",
    "knack": "knacka",
    "knackad": "knacka",
    "knackade": "knacka",
    "knackades": "knacka",
    "knackads": "knacka",
    "knackande": "knacka",
    "knackanden": "knackande",
    "knackandena": "knackande",
    "knackandenas": "knackande",
    "knackandens": "knackande",
    "knackandes": "knackande",
    "knackandet": "knackande",
    "knackandets": "knackande",
    "knackar": "knacka",
    "knackas": "knacka",
    "knackat": "knacka",
    "knackats": "knacka",
    "knacken": "knack",
    "knackens": "knack",
    "knacket": "knack",
    "knackets": "knack",
    "knackiga": "knackig",
    "knackigare": "knackig",
    "knackigares": "knackig",
    "knackigas": "knackig",
    "knackigast": "knackig",
    "knackigaste": "knackig",
    "knackigastes": "knackig",
    "knackigasts": "knackig",
    "knackige": "knackig",
    "knackiges": "knackig",
    "knackigheten": "knackighet",
    "knackighetens": "knackighet",
    "knackighets": "knackighet",
    "knackigs": "knackig",
    "knackigt": "knackig",
    "knackigts": "knackig",
    "knackningar": "knackning",
    "knackningarna": "knackning",
    "knackningarnas": "knackning",
    "knackningars": "knackning",
    "knackningen": "knackning",
    "knackningens": "knackning",
    "knacknings": "knackning",
    "knacks": "knack",
    "knackvurstar": "knackvurst",
    "knackvurstarna": "knackvurst",
    "knackvurstarnas": "knackvurst",
    "knackvurstars": "knackvurst",
    "knackvursten": "knackvurst",
    "knackvurstens": "knackvurst",
    "knackvursts": "knackvurst",
    "knagg": "knagge",
    "knaggar": "knagge",
    "knaggarna": "knagge",
    "knaggarnas": "knagge",
    "knaggars": "knagge",
    "knaggel": "knaggla",
    "knaggen": "knagge",
    "knaggens": "knagge",
    "knagges": "knagge",
    "knagglade": "knaggla",
    "knagglades": "knaggla",
    "knagglande": "knaggla",
    "knagglanden": "knagglande",
    "knagglandena": "knagglande",
    "knagglandenas": "knagglande",
    "knagglandens": "knagglande",
    "knagglandes": "knagglande",
    "knagglandet": "knagglande",
    "knagglandets": "knagglande",
    "knagglar": "knaggla",
    "knagglas": "knaggla",
    "knagglat": "knaggla",
    "knagglats": "knaggla",
    "knaggliga": "knagglig",
    "knaggligare": "knagglig",
    "knaggligares": "knagglig",
    "knaggligas": "knagglig",
    "knaggligast": "knagglig",
    "knaggligaste": "knagglig",
    "knaggligastes": "knagglig",
    "knaggligasts": "knagglig",
    "knagglige": "knagglig",
    "knaggliges": "knagglig",
    "knaggligheten": "knagglighet",
    "knagglighetens": "knagglighet",
    "knaggligheter": "knagglighet",
    "knaggligheterna": "knagglighet",
    "knaggligheternas": "knagglighet",
    "knaggligheters": "knagglighet",
    "knagglighets": "knagglighet",
    "knaggligs": "knagglig",
    "knaggligt": "knagglig",
    "knaggligts": "knagglig",
    "knaggs": "knagge",
    "knak": "knaka",
    "knakade": "knaka",
    "knakades": "knaka",
    "knakande": "knaka",
    "knakandes": "knakande",
    "knakandet": "knakande",
    "knakandets": "knakande",
    "knakar": "knaka",
    "knakas": "knaka",
    "knakat": "knaka",
    "knakats": "knaka",
    "knaket": "knak",
    "knakets": "knak",
    "knaks": "knak",
    "knala": "knal",
    "knalare": "knal",
    "knalares": "knal",
    "knalas": "knal",
    "knalast": "knal",
    "knalaste": "knal",
    "knalastes": "knal",
    "knalasts": "knal",
    "knale": "knal",
    "knales": "knal",
    "knalheten": "knalhet",
    "knalhetens": "knalhet",
    "knalhets": "knalhet",
    "knall": "knalle",
    "knalla": "knall",
    "knallade": "knalla",
    "knallades": "knalla",
    "knallande": "knalla",
    "knallanden": "knallande",
    "knallandena": "knallande",
    "knallandenas": "knallande",
    "knallandens": "knallande",
    "knallandes": "knallande",
    "knallandet": "knallande",
    "knallandets": "knallande",
    "knallar": "knalle",
    "knallare": "knall",
    "knallares": "knall",
    "knallarna": "knalle",
    "knallarnas": "knalle",
    "knallars": "knalle",
    "knallas": "knalla",
    "knallast": "knall",
    "knallaste": "knall",
    "knallastes": "knall",
    "knallasts": "knall",
    "knallat": "knalla",
    "knallats": "knalla",
    "knalldos": "knalldosa",
    "knalldosan": "knalldosa",
    "knalldosans": "knalldosa",
    "knalldosas": "knalldosa",
    "knalldose": "knalldosa",
    "knalldosor": "knalldosa",
    "knalldosorna": "knalldosa",
    "knalldosornas": "knalldosa",
    "knalldosors": "knalldosa",
    "knalle": "knall",
    "knallen": "knalle",
    "knallens": "knalle",
    "knalles": "knalle",
    "knallgasen": "knallgas",
    "knallgasens": "knallgas",
    "knallhattar": "knallhatt",
    "knallhattarna": "knallhatt",
    "knallhattarnas": "knallhatt",
    "knallhattars": "knallhatt",
    "knallhatten": "knallhatt",
    "knallhattens": "knallhatt",
    "knallhatts": "knallhatt",
    "knallheten": "knallhet",
    "knallhetens": "knallhet",
    "knallhets": "knallhet",
    "knallhårda": "knallhård",
    "knallhårdare": "knallhård",
    "knallhårdares": "knallhård",
    "knallhårdas": "knallhård",
    "knallhårdast": "knallhård",
    "knallhårdaste": "knallhård",
    "knallhårdastes": "knallhård",
    "knallhårdasts": "knallhård",
    "knallhårde": "knallhård",
    "knallhårdes": "knallhård",
    "knallhårds": "knallhård",
    "knallhårt": "knallhård",
    "knallhårts": "knallhård",
    "knallkvicksilvers": "knallkvicksilver",
    "knallkvicksilvret": "knallkvicksilver",
    "knallkvicksilvrets": "knallkvicksilver",
    "knalloranga": "knallorange",
    "knallorangare": "knallorange",
    "knallorangares": "knallorange",
    "knallorangas": "knallorange",
    "knallorangast": "knallorange",
    "knallorangaste": "knallorange",
    "knallorangastes": "knallorange",
    "knallorangasts": "knallorange",
    "knallorangea": "knallorange",
    "knallorangeare": "knallorange",
    "knallorangeares": "knallorange",
    "knallorangeas": "knallorange",
    "knallorangeast": "knallorange",
    "knallorangeaste": "knallorange",
    "knallorangeastes": "knallorange",
    "knallorangeasts": "knallorange",
    "knalloranges": "knallorange",
    "knalloranget": "knallorange",
    "knallorangets": "knallorange",
    "knallorangt": "knallorange",
    "knallorangts": "knallorange",
    "knallpulvers": "knallpulver",
    "knallpulvret": "knallpulver",
    "knallpulvrets": "knallpulver",
    "knallröda": "knallröd",
    "knallrödare": "knallröd",
    "knallrödares": "knallröd",
    "knallrödas": "knallröd",
    "knallrödast": "knallröd",
    "knallrödaste": "knallröd",
    "knallrödastes": "knallröd",
    "knallrödasts": "knallröd",
    "knallröde": "knallröd",
    "knallrödes": "knallröd",
    "knallröds": "knallröd",
    "knallrött": "knallröd",
    "knallrötts": "knallröd",
    "knalls": "knalle",
    "knallskotten": "knallskott",
    "knallskottens": "knallskott",
    "knallskottet": "knallskott",
    "knallskottets": "knallskott",
    "knallskotts": "knallskott",
    "knalltransporten": "knalltransport",
    "knalltransportens": "knalltransport",
    "knalltransporter": "knalltransport",
    "knalltransporterna": "knalltransport",
    "knalltransporternas": "knalltransport",
    "knalltransporters": "knalltransport",
    "knalltransports": "knalltransport",
    "knals": "knal",
    "knalt": "knal",
    "knalts": "knal",
    "knap": "knape",
    "knapadeln": "knapadel",
    "knapadelns": "knapadel",
    "knapadels": "knapadel",
    "knapar": "knape",
    "knaparna": "knape",
    "knaparnas": "knape",
    "knapars": "knape",
    "knapen": "knape",
    "knapens": "knape",
    "knaper": "knapra",
    "knapers": "knaper",
    "knapert": "knaper",
    "knaperts": "knaper",
    "knapes": "knape",
    "knappa": "knapp",
    "knappar": "knapp",
    "knappare": "knapp",
    "knappares": "knapp",
    "knapparna": "knapp",
    "knapparnas": "knapp",
    "knappars": "knapp",
    "knappas": "knapp",
    "knappast": "knapp",
    "knappaste": "knapp",
    "knappastes": "knapp",
    "knappasts": "knapp",
    "knappe": "knapp",
    "knappen": "knapp",
    "knappens": "knapp",
    "knappes": "knapp",
    "knappheten": "knapphet",
    "knapphetens": "knapphet",
    "knappheter": "knapphet",
    "knappheterna": "knapphet",
    "knappheternas": "knapphet",
    "knappheters": "knapphet",
    "knapphets": "knapphet",
    "knapphändiga": "knapphändig",
    "knapphändigare": "knapphändig",
    "knapphändigares": "knapphändig",
    "knapphändigas": "knapphändig",
    "knapphändigast": "knapphändig",
    "knapphändigaste": "knapphändig",
    "knapphändigastes": "knapphändig",
    "knapphändigasts": "knapphändig",
    "knapphändige": "knapphändig",
    "knapphändiges": "knapphändig",
    "knapphändigheten": "knapphändighet",
    "knapphändighetens": "knapphändighet",
    "knapphändighets": "knapphändighet",
    "knapphändigs": "knapphändig",
    "knapphändigt": "knapphändig",
    "knapphändigts": "knapphändig",
    "knapphålen": "knapphål",
    "knapphålens": "knapphål",
    "knapphålet": "knapphål",
    "knapphålets": "knapphål",
    "knapphåls": "knapphål",
    "knapphålsblom": "knapphålsblomma",
    "knapphålsblomman": "knapphålsblomma",
    "knapphålsblommans": "knapphålsblomma",
    "knapphålsblommas": "knapphålsblomma",
    "knapphålsblomme": "knapphålsblomma",
    "knapphålsblommor": "knapphålsblomma",
    "knapphålsblommorna": "knapphålsblomma",
    "knapphålsblommornas": "knapphålsblomma",
    "knapphålsblommors": "knapphålsblomma",
    "knapphålsbloms": "knapphålsblomma",
    "knappnålar": "knappnål",
    "knappnålarna": "knappnål",
    "knappnålarnas": "knappnål",
    "knappnålars": "knappnål",
    "knappnålen": "knappnål",
    "knappnålens": "knappnål",
    "knappnåls": "knappnål",
    "knappnålshuvuden": "knappnålshuvud",
    "knappnålshuvudena": "knappnålshuvud",
    "knappnålshuvudenas": "knappnålshuvud",
    "knappnålshuvudens": "knappnålshuvud",
    "knappnålshuvudet": "knappnålshuvud",
    "knappnålshuvudets": "knappnålshuvud",
    "knappnålshuvuds": "knappnålshuvud",
    "knappologien": "knappologi",
    "knappologiens": "knappologi",
    "knappologin": "knappologi",
    "knappologins": "knappologi",
    "knappologis": "knappologi",
    "knapps": "knapp",
    "knappt": "knapp",
    "knapptelefonen": "knapptelefon",
    "knapptelefonens": "knapptelefon",
    "knapptelefoner": "knapptelefon",
    "knapptelefonerna": "knapptelefon",
    "knapptelefonernas": "knapptelefon",
    "knapptelefoners": "knapptelefon",
    "knapptelefons": "knapptelefon",
    "knapptrycken": "knapptryck",
    "knapptryckens": "knapptryck",
    "knapptrycket": "knapptryck",
    "knapptryckets": "knapptryck",
    "knapptryckningar": "knapptryckning",
    "knapptryckningarna": "knapptryckning",
    "knapptryckningarnas": "knapptryckning",
    "knapptryckningars": "knapptryckning",
    "knapptryckningen": "knapptryckning",
    "knapptryckningens": "knapptryckning",
    "knapptrycknings": "knapptryckning",
    "knapptrycks": "knapptryck",
    "knappts": "knapp",
    "knapra": "knaper",
    "knaprad": "knapra",
    "knaprade": "knapra",
    "knaprades": "knapra",
    "knaprads": "knapra",
    "knaprande": "knapra",
    "knapranden": "knaprande",
    "knaprandena": "knaprande",
    "knaprandenas": "knaprande",
    "knaprandens": "knaprande",
    "knaprandes": "knaprande",
    "knaprandet": "knaprande",
    "knaprandets": "knaprande",
    "knaprar": "knapra",
    "knaprare": "knaper",
    "knaprares": "knaper",
    "knapras": "knapra",
    "knaprast": "knaper",
    "knapraste": "knaper",
    "knaprastes": "knaper",
    "knaprasts": "knaper",
    "knaprat": "knapra",
    "knaprats": "knapra",
    "knapre": "knaper",
    "knapres": "knaper",
    "knapriga": "knaprig",
    "knaprigare": "knaprig",
    "knaprigares": "knaprig",
    "knaprigas": "knaprig",
    "knaprigast": "knaprig",
    "knaprigaste": "knaprig",
    "knaprigastes": "knaprig",
    "knaprigasts": "knaprig",
    "knaprige": "knaprig",
    "knapriges": "knaprig",
    "knaprigheten": "knaprighet",
    "knaprighetens": "knaprighet",
    "knaprighets": "knaprighet",
    "knaprigs": "knaprig",
    "knaprigt": "knaprig",
    "knaprigts": "knaprig",
    "knaps": "knape",
    "knark": "knarka",
    "knarkad": "knarka",
    "knarkade": "knarka",
    "knarkades": "knarka",
    "knarkads": "knarka",
    "knarkande": "knarka",
    "knarkanden": "knarkande",
    "knarkandena": "knarkande",
    "knarkandenas": "knarkande",
    "knarkandens": "knarkande",
    "knarkandes": "knarkande",
    "knarkandet": "knarkande",
    "knarkandets": "knarkande",
    "knarkar": "knarkare",
    "knarkaren": "knarkare",
    "knarkarens": "knarkare",
    "knarkares": "knarkare",
    "knarkarkvartar": "knarkarkvart",
    "knarkarkvartarna": "knarkarkvart",
    "knarkarkvartarnas": "knarkarkvart",
    "knarkarkvartars": "knarkarkvart",
    "knarkarkvarten": "knarkarkvart",
    "knarkarkvartens": "knarkarkvart",
    "knarkarkvarts": "knarkarkvart",
    "knarkarna": "knarkare",
    "knarkarnas": "knarkare",
    "knarkas": "knarka",
    "knarkat": "knarka",
    "knarkats": "knarka",
    "knarkbekämpar": "knarkbekämpare",
    "knarkbekämparen": "knarkbekämpare",
    "knarkbekämparens": "knarkbekämpare",
    "knarkbekämpares": "knarkbekämpare",
    "knarkbekämparna": "knarkbekämpare",
    "knarkbekämparnas": "knarkbekämpare",
    "knarkbekämpningen": "knarkbekämpning",
    "knarkbekämpningens": "knarkbekämpning",
    "knarkbekämpnings": "knarkbekämpning",
    "knarket": "knark",
    "knarkets": "knark",
    "knarkhandeln": "knarkhandel",
    "knarkhandelns": "knarkhandel",
    "knarkhandels": "knarkhandel",
    "knarkhundar": "knarkhund",
    "knarkhundarna": "knarkhund",
    "knarkhundarnas": "knarkhund",
    "knarkhundars": "knarkhund",
    "knarkhunden": "knarkhund",
    "knarkhundens": "knarkhund",
    "knarkhunds": "knarkhund",
    "knarkhärvan": "knarkhärva",
    "knarkhärvans": "knarkhärva",
    "knarkhärvas": "knarkhärva",
    "knarkhärve": "knarkhärva",
    "knarkhärvor": "knarkhärva",
    "knarkhärvorna": "knarkhärva",
    "knarkhärvornas": "knarkhärva",
    "knarkhärvors": "knarkhärva",
    "knarkkuriren": "knarkkurir",
    "knarkkurirens": "knarkkurir",
    "knarkkurirer": "knarkkurir",
    "knarkkurirerna": "knarkkurir",
    "knarkkurirernas": "knarkkurir",
    "knarkkurirers": "knarkkurir",
    "knarkkurirs": "knarkkurir",
    "knarks": "knark",
    "knarksmugglar": "knarksmugglare",
    "knarksmugglaren": "knarksmugglare",
    "knarksmugglarens": "knarksmugglare",
    "knarksmugglares": "knarksmugglare",
    "knarksmugglarna": "knarksmugglare",
    "knarksmugglarnas": "knarksmugglare",
    "knarksmugglingen": "knarksmuggling",
    "knarksmugglingens": "knarksmuggling",
    "knarksmugglings": "knarksmuggling",
    "knarrade": "knarra",
    "knarrades": "knarra",
    "knarrande": "knarra",
    "knarranden": "knarrande",
    "knarrandena": "knarrande",
    "knarrandenas": "knarrande",
    "knarrandens": "knarrande",
    "knarrandes": "knarrande",
    "knarrandet": "knarrande",
    "knarrandets": "knarrande",
    "knarrar": "knarra",
    "knarrarna": "knarr",
    "knarrarnas": "knarr",
    "knarrars": "knarr",
    "knarras": "knarra",
    "knarrat": "knarra",
    "knarrats": "knarra",
    "knarren": "knarr",
    "knarrens": "knarr",
    "knarret": "knarr",
    "knarrets": "knarr",
    "knarriga": "knarrig",
    "knarrigare": "knarrig",
    "knarrigares": "knarrig",
    "knarrigas": "knarrig",
    "knarrigast": "knarrig",
    "knarrigaste": "knarrig",
    "knarrigastes": "knarrig",
    "knarrigasts": "knarrig",
    "knarrige": "knarrig",
    "knarriges": "knarrig",
    "knarrigheten": "knarrighet",
    "knarrighetens": "knarrighet",
    "knarrighets": "knarrighet",
    "knarrigs": "knarrig",
    "knarrigt": "knarrig",
    "knarrigts": "knarrig",
    "knarrs": "knarr",
    "knasbollar": "knasboll",
    "knasbollarna": "knasboll",
    "knasbollarnas": "knasboll",
    "knasbollars": "knasboll",
    "knasbollen": "knasboll",
    "knasbollens": "knasboll",
    "knasbolls": "knasboll",
    "knasiga": "knasig",
    "knasigare": "knasig",
    "knasigares": "knasig",
    "knasigas": "knasig",
    "knasigast": "knasig",
    "knasigaste": "knasig",
    "knasigastes": "knasig",
    "knasigasts": "knasig",
    "knasige": "knasig",
    "knasiges": "knasig",
    "knasigheten": "knasighet",
    "knasighetens": "knasighet",
    "knasigheter": "knasighet",
    "knasigheterna": "knasighet",
    "knasigheternas": "knasighet",
    "knasigheters": "knasighet",
    "knasighets": "knasighet",
    "knasigs": "knasig",
    "knasigt": "knasig",
    "knasigts": "knasig",
    "knaspriga": "knasprig",
    "knasprigare": "knasprig",
    "knasprigares": "knasprig",
    "knasprigas": "knasprig",
    "knasprigast": "knasprig",
    "knasprigaste": "knasprig",
    "knasprigastes": "knasprig",
    "knasprigasts": "knasprig",
    "knasprige": "knasprig",
    "knaspriges": "knasprig",
    "knasprigheten": "knasprighet",
    "knasprighetens": "knasprighet",
    "knasprighets": "knasprighet",
    "knasprigs": "knasprig",
    "knasprigt": "knasprig",
    "knasprigts": "knasprig",
    "knastar": "knast",
    "knastarna": "knast",
    "knastarnas": "knast",
    "knastars": "knast",
    "knasten": "knast",
    "knastens": "knast",
    "knaster": "knastra",
    "knastern": "knaster",
    "knasterna": "knaster",
    "knasternas": "knaster",
    "knasterns": "knaster",
    "knasters": "knaster",
    "knastrade": "knastra",
    "knastrades": "knastra",
    "knastrande": "knastra",
    "knastranden": "knastrande",
    "knastrandena": "knastrande",
    "knastrandenas": "knastrande",
    "knastrandens": "knastrande",
    "knastrandes": "knastrande",
    "knastrandet": "knastrande",
    "knastrandets": "knastrande",
    "knastrar": "knastra",
    "knastrarna": "knaster",
    "knastrarnas": "knaster",
    "knastrars": "knaster",
    "knastras": "knastra",
    "knastrat": "knastra",
    "knastrats": "knastra",
    "knastren": "knaster",
    "knastrens": "knaster",
    "knastret": "knaster",
    "knastrets": "knaster",
    "knastriga": "knastrig",
    "knastrigare": "knastrig",
    "knastrigares": "knastrig",
    "knastrigas": "knastrig",
    "knastrigast": "knastrig",
    "knastrigaste": "knastrig",
    "knastrigastes": "knastrig",
    "knastrigasts": "knastrig",
    "knastrige": "knastrig",
    "knastriges": "knastrig",
    "knastrigheten": "knastrighet",
    "knastrighetens": "knastrighet",
    "knastrighets": "knastrighet",
    "knastrigs": "knastrig",
    "knastrigt": "knastrig",
    "knastrigts": "knastrig",
    "knasts": "knast",
    "knat": "knata",
    "knatad": "knata",
    "knatade": "knata",
    "knatades": "knata",
    "knatads": "knata",
    "knatande": "knata",
    "knatanden": "knatande",
    "knatandena": "knatande",
    "knatandenas": "knatande",
    "knatandens": "knatande",
    "knatandes": "knatande",
    "knatandet": "knatande",
    "knatandets": "knatande",
    "knatar": "knata",
    "knatas": "knata",
    "knatat": "knata",
    "knatats": "knata",
    "knatt": "knatte",
    "knattar": "knatte",
    "knattarna": "knatte",
    "knattarnas": "knatte",
    "knattars": "knatte",
    "knatten": "knatte",
    "knattens": "knatte",
    "knatter": "knattra",
    "knatters": "knatter",
    "knattes": "knatte",
    "knattingar": "knatting",
    "knattingarna": "knatting",
    "knattingarnas": "knatting",
    "knattingars": "knatting",
    "knattingen": "knatting",
    "knattingens": "knatting",
    "knattings": "knatting",
    "knattrade": "knattra",
    "knattrades": "knattra",
    "knattrande": "knattra",
    "knattranden": "knattrande",
    "knattrandena": "knattrande",
    "knattrandenas": "knattrande",
    "knattrandens": "knattrande",
    "knattrandes": "knattrande",
    "knattrandet": "knattrande",
    "knattrandets": "knattrande",
    "knattrar": "knattra",
    "knattras": "knattra",
    "knattrat": "knattra",
    "knattrats": "knattra",
    "knattret": "knatter",
    "knattrets": "knatter",
    "knatts": "knatte",
    "knegade": "knega",
    "knegades": "knega",
    "knegande": "knega",
    "kneganden": "knegande",
    "knegandena": "knegande",
    "knegandenas": "knegande",
    "knegandens": "knegande",
    "knegandes": "knegande",
    "knegandet": "knegande",
    "knegandets": "knegande",
    "knegar": "knegare",
    "knegaren": "knegare",
    "knegarens": "knegare",
    "knegares": "knegare",
    "knegarna": "knegare",
    "knegarnas": "knegare",
    "knegas": "knega",
    "knegat": "knega",
    "knegats": "knega",
    "knegen": "kneg",
    "knegens": "kneg",
    "kneget": "kneg",
    "knegets": "kneg",
    "knegs": "kneg",
    "kneippkuren": "kneippkur",
    "kneippkurens": "kneippkur",
    "kneippkurer": "kneippkur",
    "kneippkurerna": "kneippkur",
    "kneippkurernas": "kneippkur",
    "kneippkurers": "kneippkur",
    "kneippkurs": "kneippkur",
    "knejpkuren": "knejpkur",
    "knejpkurens": "knejpkur",
    "knejpkurer": "knejpkur",
    "knejpkurerna": "knejpkur",
    "knejpkurernas": "knejpkur",
    "knejpkurers": "knejpkur",
    "knejpkurs": "knejpkur",
    "knektar": "knekt",
    "knektarna": "knekt",
    "knektarnas": "knekt",
    "knektars": "knekt",
    "knekten": "knekt",
    "knektens": "knekt",
    "knektmentaliteten": "knektmentalitet",
    "knektmentalitetens": "knektmentalitet",
    "knektmentaliteter": "knektmentalitet",
    "knektmentaliteterna": "knektmentalitet",
    "knektmentaliteternas": "knektmentalitet",
    "knektmentaliteters": "knektmentalitet",
    "knektmentalitets": "knektmentalitet",
    "knekts": "knekt",
    "knep": "knipa",
    "knepen": "knep",
    "knepens": "knep",
    "knepet": "knep",
    "knepets": "knep",
    "knepiga": "knepig",
    "knepigare": "knepig",
    "knepigares": "knepig",
    "knepigas": "knepig",
    "knepigast": "knepig",
    "knepigaste": "knepig",
    "knepigastes": "knepig",
    "knepigasts": "knepig",
    "knepige": "knepig",
    "knepiges": "knepig",
    "knepigheten": "knepighet",
    "knepighetens": "knepighet",
    "knepigheter": "knepighet",
    "knepigheterna": "knepighet",
    "knepigheternas": "knepighet",
    "knepigheters": "knepighet",
    "knepighets": "knepighet",
    "knepigs": "knepig",
    "knepigt": "knepig",
    "knepigts": "knepig",
    "kneps": "knipa",
    "knickar": "knick",
    "knickarna": "knick",
    "knickarnas": "knick",
    "knickars": "knick",
    "knicken": "knick",
    "knickens": "knick",
    "knickersen": "knickers",
    "knickersens": "knickers",
    "knicks": "knick",
    "knip": "knipa",
    "knipan": "knipa",
    "knipande": "knipa",
    "knipanden": "knipande",
    "knipandena": "knipande",
    "knipandenas": "knipande",
    "knipandens": "knipande",
    "knipandes": "knipande",
    "knipandet": "knipande",
    "knipandets": "knipande",
    "knipans": "knipa",
    "knipas": "knipa",
    "knipe": "knipa",
    "knipen": "knipa",
    "knipens": "knipa",
    "kniper": "knipa",
    "knipes": "knipa",
    "knipet": "knipa",
    "knipets": "knipa",
    "knipit": "knipa",
    "knipits": "knipa",
    "knipna": "knipa",
    "knipnas": "knipa",
    "knipne": "knipa",
    "knipnes": "knipa",
    "knipor": "knipa",
    "kniporna": "knipa",
    "knipornas": "knipa",
    "knipors": "knipa",
    "knipp": "knippe",
    "knippan": "knippa",
    "knippans": "knippa",
    "knippas": "knippa",
    "knippe": "knippa",
    "knippen": "knippe",
    "knippena": "knippe",
    "knippenas": "knippe",
    "knippens": "knippe",
    "knippes": "knippe",
    "knippet": "knippe",
    "knippets": "knippe",
    "knippor": "knippa",
    "knipporna": "knippa",
    "knippornas": "knippa",
    "knippors": "knippa",
    "knipps": "knippe",
    "knips": "knipsa",
    "knipsad": "knipsa",
    "knipsade": "knipsa",
    "knipsades": "knipsa",
    "knipsads": "knipsa",
    "knipsande": "knipsa",
    "knipsanden": "knipsande",
    "knipsandena": "knipsande",
    "knipsandenas": "knipsande",
    "knipsandens": "knipsande",
    "knipsandes": "knipsande",
    "knipsandet": "knipsande",
    "knipsandets": "knipsande",
    "knipsar": "knipsa",
    "knipsas": "knipsa",
    "knipsat": "knipsa",
    "knipsats": "knipsa",
    "knipsluga": "knipslug",
    "knipslugare": "knipslug",
    "knipslugares": "knipslug",
    "knipslugas": "knipslug",
    "knipslugast": "knipslug",
    "knipslugaste": "knipslug",
    "knipslugastes": "knipslug",
    "knipslugasts": "knipslug",
    "knipsluge": "knipslug",
    "knipsluges": "knipslug",
    "knipslugheten": "knipslughet",
    "knipslughetens": "knipslughet",
    "knipslughets": "knipslughet",
    "knipslugs": "knipslug",
    "knipslugt": "knipslug",
    "knipslugts": "knipslug",
    "kniptänger": "kniptång",
    "kniptängerna": "kniptång",
    "kniptängernas": "kniptång",
    "kniptängers": "kniptång",
    "kniptången": "kniptång",
    "kniptångens": "kniptång",
    "kniptångs": "kniptång",
    "kniptångsmanövern": "kniptångsmanöver",
    "kniptångsmanöverns": "kniptångsmanöver",
    "kniptångsmanövers": "kniptångsmanöver",
    "kniptångsmanövrar": "kniptångsmanöver",
    "kniptångsmanövrarna": "kniptångsmanöver",
    "kniptångsmanövrarnas": "kniptångsmanöver",
    "kniptångsmanövrars": "kniptångsmanöver",
    "kniptångsmanövrer": "kniptångsmanöver",
    "kniptångsmanövrerna": "kniptångsmanöver",
    "kniptångsmanövrernas": "kniptångsmanöver",
    "kniptångsmanövrers": "kniptångsmanöver",
    "knirkade": "knirka",
    "knirkades": "knirka",
    "knirkande": "knirka",
    "knirkanden": "knirkande",
    "knirkandena": "knirkande",
    "knirkandenas": "knirkande",
    "knirkandens": "knirkande",
    "knirkandes": "knirkande",
    "knirkandet": "knirkande",
    "knirkandets": "knirkande",
    "knirkar": "knirka",
    "knirkas": "knirka",
    "knirkat": "knirka",
    "knirkats": "knirka",
    "knirket": "knirk",
    "knirkets": "knirk",
    "knirks": "knirk",
    "knirrade": "knirra",
    "knirrades": "knirra",
    "knirrande": "knirra",
    "knirranden": "knirrande",
    "knirrandena": "knirrande",
    "knirrandenas": "knirrande",
    "knirrandens": "knirrande",
    "knirrandes": "knirrande",
    "knirrandet": "knirrande",
    "knirrandets": "knirrande",
    "knirrar": "knirra",
    "knirras": "knirra",
    "knirrat": "knirra",
    "knirrats": "knirra",
    "knirret": "knirr",
    "knirrets": "knirr",
    "knirrs": "knirr",
    "knister": "knistra",
    "knistrade": "knistra",
    "knistrades": "knistra",
    "knistrande": "knistra",
    "knistranden": "knistrande",
    "knistrandena": "knistrande",
    "knistrandenas": "knistrande",
    "knistrandens": "knistrande",
    "knistrandes": "knistrande",
    "knistrandet": "knistrande",
    "knistrandets": "knistrande",
    "knistrar": "knistra",
    "knistras": "knistra",
    "knistrat": "knistra",
    "knistrats": "knistra",
    "knitteln": "knittel",
    "knittelns": "knittel",
    "knittels": "knittel",
    "knitter": "knittra",
    "knitters": "knitter",
    "knittrade": "knittra",
    "knittrades": "knittra",
    "knittrande": "knittra",
    "knittranden": "knittrande",
    "knittrandena": "knittrande",
    "knittrandenas": "knittrande",
    "knittrandens": "knittrande",
    "knittrandes": "knittrande",
    "knittrandet": "knittrande",
    "knittrandets": "knittrande",
    "knittrar": "knittra",
    "knittras": "knittra",
    "knittrat": "knittra",
    "knittrats": "knittra",
    "knittret": "knitter",
    "knittrets": "knitter",
    "knivad": "kniva",
    "knivade": "kniva",
    "knivades": "kniva",
    "knivads": "kniva",
    "knivande": "kniva",
    "knivanden": "knivande",
    "knivandena": "knivande",
    "knivandenas": "knivande",
    "knivandens": "knivande",
    "knivandes": "knivande",
    "knivandet": "knivande",
    "knivandets": "knivande",
    "knivar": "kniva",
    "knivarna": "kniv",
    "knivarnas": "kniv",
    "knivars": "kniv",
    "knivas": "kniva",
    "knivat": "kniva",
    "knivats": "kniva",
    "knivavståndet": "knivavstånd",
    "knivavståndets": "knivavstånd",
    "knivavstånds": "knivavstånd",
    "knivbeväpnade": "knivbeväpnad",
    "knivbeväpnades": "knivbeväpnad",
    "knivbeväpnads": "knivbeväpnad",
    "knivbeväpnat": "knivbeväpnad",
    "knivbeväpnats": "knivbeväpnad",
    "knivbladen": "knivblad",
    "knivbladens": "knivblad",
    "knivbladet": "knivblad",
    "knivbladets": "knivblad",
    "knivblads": "knivblad",
    "knivbladslika": "knivbladslik",
    "knivbladslikare": "knivbladslik",
    "knivbladslikares": "knivbladslik",
    "knivbladslikas": "knivbladslik",
    "knivbladslikast": "knivbladslik",
    "knivbladslikaste": "knivbladslik",
    "knivbladslikastes": "knivbladslik",
    "knivbladslikasts": "knivbladslik",
    "knivbladslike": "knivbladslik",
    "knivbladslikes": "knivbladslik",
    "knivbladsliks": "knivbladslik",
    "knivbladslikt": "knivbladslik",
    "knivbladslikts": "knivbladslik",
    "knivbromsar": "knivbroms",
    "knivbromsarna": "knivbroms",
    "knivbromsarnas": "knivbroms",
    "knivbromsars": "knivbroms",
    "knivbromsen": "knivbroms",
    "knivbromsens": "knivbroms",
    "kniven": "kniv",
    "knivens": "kniv",
    "knivhuggen": "knivhugg",
    "knivhuggens": "knivhugg",
    "knivhugget": "knivhugg",
    "knivhuggets": "knivhugg",
    "knivhuggs": "knivhugg",
    "kniviga": "knivig",
    "knivigare": "knivig",
    "knivigares": "knivig",
    "knivigas": "knivig",
    "knivigast": "knivig",
    "knivigaste": "knivig",
    "knivigastes": "knivig",
    "knivigasts": "knivig",
    "knivige": "knivig",
    "kniviges": "knivig",
    "knivigheten": "knivighet",
    "knivighetens": "knivighet",
    "knivigheter": "knivighet",
    "knivigheterna": "knivighet",
    "knivigheternas": "knivighet",
    "knivigheters": "knivighet",
    "knivighets": "knivighet",
    "knivigs": "knivig",
    "knivigt": "knivig",
    "knivigts": "knivig",
    "knivkastningar": "knivkastning",
    "knivkastningarna": "knivkastning",
    "knivkastningarnas": "knivkastning",
    "knivkastningars": "knivkastning",
    "knivkastningen": "knivkastning",
    "knivkastningens": "knivkastning",
    "knivkastnings": "knivkastning",
    "knivkontakten": "knivkontakt",
    "knivkontaktens": "knivkontakt",
    "knivkontakter": "knivkontakt",
    "knivkontakterna": "knivkontakt",
    "knivkontakternas": "knivkontakt",
    "knivkontakters": "knivkontakt",
    "knivkontakts": "knivkontakt",
    "knivläggar": "knivläggare",
    "knivläggaren": "knivläggare",
    "knivläggarens": "knivläggare",
    "knivläggares": "knivläggare",
    "knivläggarna": "knivläggare",
    "knivläggarnas": "knivläggare",
    "knivlåd": "knivlåda",
    "knivlådan": "knivlåda",
    "knivlådans": "knivlåda",
    "knivlådas": "knivlåda",
    "knivlåde": "knivlåda",
    "knivlådor": "knivlåda",
    "knivlådorna": "knivlåda",
    "knivlådornas": "knivlåda",
    "knivlådors": "knivlåda",
    "knivlåds": "knivlåda",
    "knivmannen": "knivman",
    "knivmannens": "knivman",
    "knivmans": "knivman",
    "knivmorden": "knivmord",
    "knivmordens": "knivmord",
    "knivmordet": "knivmord",
    "knivmordets": "knivmord",
    "knivmords": "knivmord",
    "knivmän": "knivman",
    "knivmännen": "knivman",
    "knivmännens": "knivman",
    "knivmäns": "knivman",
    "knivmördad": "knivmörda",
    "knivmördade": "knivmörda",
    "knivmördades": "knivmörda",
    "knivmördads": "knivmörda",
    "knivmördande": "knivmörda",
    "knivmördanden": "knivmördande",
    "knivmördandena": "knivmördande",
    "knivmördandenas": "knivmördande",
    "knivmördandens": "knivmördande",
    "knivmördandes": "knivmördande",
    "knivmördandet": "knivmördande",
    "knivmördandets": "knivmördande",
    "knivmördar": "knivmörda",
    "knivmördas": "knivmörda",
    "knivmördat": "knivmörda",
    "knivmördats": "knivmörda",
    "knivryggar": "knivrygg",
    "knivryggarna": "knivrygg",
    "knivryggarnas": "knivrygg",
    "knivryggars": "knivrygg",
    "knivryggen": "knivrygg",
    "knivryggens": "knivrygg",
    "knivryggs": "knivrygg",
    "knivrörelsen": "knivrörelse",
    "knivrörelsens": "knivrörelse",
    "knivrörelser": "knivrörelse",
    "knivrörelserna": "knivrörelse",
    "knivrörelsernas": "knivrörelse",
    "knivrörelsers": "knivrörelse",
    "knivrörelses": "knivrörelse",
    "knivs": "kniv",
    "knivseggar": "knivsegg",
    "knivseggarna": "knivsegg",
    "knivseggarnas": "knivsegg",
    "knivseggars": "knivsegg",
    "knivseggen": "knivsegg",
    "knivseggens": "knivsegg",
    "knivseggs": "knivsegg",
    "knivskaften": "knivskaft",
    "knivskaftens": "knivskaft",
    "knivskaftet": "knivskaft",
    "knivskaftets": "knivskaft",
    "knivskafts": "knivskaft",
    "knivskar": "knivskära",
    "knivskarpa": "knivskarp",
    "knivskarpare": "knivskarp",
    "knivskarpares": "knivskarp",
    "knivskarpas": "knivskarp",
    "knivskarpast": "knivskarp",
    "knivskarpaste": "knivskarp",
    "knivskarpastes": "knivskarp",
    "knivskarpasts": "knivskarp",
    "knivskarpe": "knivskarp",
    "knivskarpes": "knivskarp",
    "knivskarpheten": "knivskarphet",
    "knivskarphetens": "knivskarphet",
    "knivskarphets": "knivskarphet",
    "knivskarps": "knivskarp",
    "knivskarpt": "knivskarp",
    "knivskarpts": "knivskarp",
    "knivskars": "knivskära",
    "knivskure": "knivskära",
    "knivskuren": "knivskära",
    "knivskurens": "knivskuren",
    "knivskures": "knivskära",
    "knivskuret": "knivskuren",
    "knivskurets": "knivskuren",
    "knivskurit": "knivskära",
    "knivskurits": "knivskära",
    "knivskurna": "knivskuren",
    "knivskurnare": "knivskuren",
    "knivskurnares": "knivskuren",
    "knivskurnas": "knivskuren",
    "knivskurnast": "knivskuren",
    "knivskurnaste": "knivskuren",
    "knivskurnastes": "knivskuren",
    "knivskurnasts": "knivskuren",
    "knivskurne": "knivskuren",
    "knivskurnes": "knivskuren",
    "knivskär": "knivskära",
    "knivskärande": "knivskära",
    "knivskärandes": "knivskära",
    "knivskäras": "knivskära",
    "knivskäre": "knivskära",
    "knivskäres": "knivskära",
    "knivskärs": "knivskära",
    "knivslid": "knivslida",
    "knivslidan": "knivslida",
    "knivslidans": "knivslida",
    "knivslidas": "knivslida",
    "knivslide": "knivslida",
    "knivslidor": "knivslida",
    "knivslidorna": "knivslida",
    "knivslidornas": "knivslida",
    "knivslidors": "knivslida",
    "knivslids": "knivslida",
    "knivsryggar": "knivsrygg",
    "knivsryggarna": "knivsrygg",
    "knivsryggarnas": "knivsrygg",
    "knivsryggars": "knivsrygg",
    "knivsryggen": "knivsrygg",
    "knivsryggens": "knivsrygg",
    "knivsryggs": "knivsrygg",
    "knivsuddar": "knivsudd",
    "knivsuddarna": "knivsudd",
    "knivsuddarnas": "knivsudd",
    "knivsuddars": "knivsudd",
    "knivsudden": "knivsudd",
    "knivsuddens": "knivsudd",
    "knivsudds": "knivsudd",
    "knixade": "knixa",
    "knixades": "knixa",
    "knixande": "knixa",
    "knixanden": "knixande",
    "knixandena": "knixande",
    "knixandenas": "knixande",
    "knixandens": "knixande",
    "knixandes": "knixande",
    "knixandet": "knixande",
    "knixandets": "knixande",
    "knixar": "knixa",
    "knixarna": "knix",
    "knixarnas": "knix",
    "knixars": "knix",
    "knixas": "knixa",
    "knixat": "knixa",
    "knixats": "knixa",
    "knixen": "knix",
    "knixens": "knix",
    "knock": "knocka",
    "knockad": "knocka",
    "knockade": "knocka",
    "knockades": "knocka",
    "knockads": "knocka",
    "knockande": "knocka",
    "knockanden": "knockande",
    "knockandena": "knockande",
    "knockandenas": "knockande",
    "knockandens": "knockande",
    "knockandes": "knockande",
    "knockandet": "knockande",
    "knockandets": "knockande",
    "knockar": "knocka",
    "knockas": "knocka",
    "knockat": "knocka",
    "knockats": "knocka",
    "knockdownen": "knockdown",
    "knockdownens": "knockdown",
    "knockdowner": "knockdown",
    "knockdownerna": "knockdown",
    "knockdownernas": "knockdown",
    "knockdowners": "knockdown",
    "knockdowns": "knockdown",
    "knockouten": "knockout",
    "knockoutens": "knockout",
    "knockouter": "knockout",
    "knockouterna": "knockout",
    "knockouternas": "knockout",
    "knockouters": "knockout",
    "knockouts": "knockout",
    "knoddar": "knodd",
    "knoddarna": "knodd",
    "knoddarnas": "knodd",
    "knoddars": "knodd",
    "knodden": "knodd",
    "knoddens": "knodd",
    "knodds": "knodd",
    "knoddäna": "knoddän",
    "knoddänare": "knoddän",
    "knoddänares": "knoddän",
    "knoddänas": "knoddän",
    "knoddänast": "knoddän",
    "knoddänaste": "knoddän",
    "knoddänastes": "knoddän",
    "knoddänasts": "knoddän",
    "knoddäne": "knoddän",
    "knoddänes": "knoddän",
    "knoddäns": "knoddän",
    "knoddänt": "knoddän",
    "knoddänts": "knoddän",
    "knog": "knoge",
    "knogade": "knoga",
    "knogades": "knoga",
    "knogande": "knoga",
    "knoganden": "knogande",
    "knogandena": "knogande",
    "knogandenas": "knogande",
    "knogandens": "knogande",
    "knogandes": "knogande",
    "knogandet": "knogande",
    "knogandets": "knogande",
    "knogar": "knoge",
    "knogarna": "knoge",
    "knogarnas": "knoge",
    "knogars": "knoge",
    "knogas": "knoga",
    "knogat": "knoga",
    "knogats": "knoga",
    "knogen": "knoge",
    "knogens": "knoge",
    "knoges": "knoge",
    "knoget": "knog",
    "knogets": "knog",
    "knogiga": "knogig",
    "knogigare": "knogig",
    "knogigares": "knogig",
    "knogigas": "knogig",
    "knogigast": "knogig",
    "knogigaste": "knogig",
    "knogigastes": "knogig",
    "knogigasts": "knogig",
    "knogige": "knogig",
    "knogiges": "knogig",
    "knogigs": "knogig",
    "knogigt": "knogig",
    "knogigts": "knogig",
    "knogjärnen": "knogjärn",
    "knogjärnens": "knogjärn",
    "knogjärnet": "knogjärn",
    "knogjärnets": "knogjärn",
    "knogjärns": "knogjärn",
    "knogs": "knoge",
    "knoller": "knollra",
    "knollrad": "knollra",
    "knollrade": "knollra",
    "knollrades": "knollra",
    "knollrads": "knollra",
    "knollrande": "knollra",
    "knollranden": "knollrande",
    "knollrandena": "knollrande",
    "knollrandenas": "knollrande",
    "knollrandens": "knollrande",
    "knollrandes": "knollrande",
    "knollrandet": "knollrande",
    "knollrandets": "knollrande",
    "knollrar": "knollra",
    "knollras": "knollra",
    "knollrat": "knollra",
    "knollrats": "knollra",
    "knollriga": "knollrig",
    "knollrigare": "knollrig",
    "knollrigares": "knollrig",
    "knollrigas": "knollrig",
    "knollrigast": "knollrig",
    "knollrigaste": "knollrig",
    "knollrigastes": "knollrig",
    "knollrigasts": "knollrig",
    "knollrige": "knollrig",
    "knollriges": "knollrig",
    "knollrigheten": "knollrighet",
    "knollrighetens": "knollrighet",
    "knollrigheter": "knollrighet",
    "knollrigheterna": "knollrighet",
    "knollrigheternas": "knollrighet",
    "knollrigheters": "knollrighet",
    "knollrighets": "knollrighet",
    "knollrigs": "knollrig",
    "knollrigt": "knollrig",
    "knollrigts": "knollrig",
    "knopad": "knopa",
    "knopade": "knopa",
    "knopades": "knopa",
    "knopads": "knopa",
    "knopande": "knopa",
    "knopanden": "knopande",
    "knopandena": "knopande",
    "knopandenas": "knopande",
    "knopandens": "knopande",
    "knopandes": "knopande",
    "knopandet": "knopande",
    "knopandets": "knopande",
    "knopar": "knopa",
    "knoparna": "knop",
    "knoparnas": "knop",
    "knopars": "knop",
    "knopas": "knopa",
    "knopat": "knopa",
    "knopats": "knopa",
    "knopen": "knop",
    "knopens": "knop",
    "knoppades": "knoppas",
    "knoppar": "knopp",
    "knopparna": "knopp",
    "knopparnas": "knopp",
    "knoppars": "knopp",
    "knoppats": "knoppas",
    "knoppen": "knopp",
    "knoppens": "knopp",
    "knoppiga": "knoppig",
    "knoppigare": "knoppig",
    "knoppigares": "knoppig",
    "knoppigas": "knoppig",
    "knoppigast": "knoppig",
    "knoppigaste": "knoppig",
    "knoppigastes": "knoppig",
    "knoppigasts": "knoppig",
    "knoppige": "knoppig",
    "knoppiges": "knoppig",
    "knoppigheten": "knoppighet",
    "knoppighetens": "knoppighet",
    "knoppighets": "knoppighet",
    "knoppigs": "knoppig",
    "knoppigt": "knoppig",
    "knoppigts": "knoppig",
    "knoppningar": "knoppning",
    "knoppningarna": "knoppning",
    "knoppningarnas": "knoppning",
    "knoppningars": "knoppning",
    "knoppningen": "knoppning",
    "knoppningens": "knoppning",
    "knoppnings": "knoppning",
    "knopps": "knopp",
    "knoppsprickningar": "knoppsprickning",
    "knoppsprickningarna": "knoppsprickning",
    "knoppsprickningarnas": "knoppsprickning",
    "knoppsprickningars": "knoppsprickning",
    "knoppsprickningen": "knoppsprickning",
    "knoppsprickningens": "knoppsprickning",
    "knoppspricknings": "knoppsprickning",
    "knoppsättningar": "knoppsättning",
    "knoppsättningarna": "knoppsättning",
    "knoppsättningarnas": "knoppsättning",
    "knoppsättningars": "knoppsättning",
    "knoppsättningen": "knoppsättning",
    "knoppsättningens": "knoppsättning",
    "knoppsättnings": "knoppsättning",
    "knops": "knop",
    "knorr": "knorra",
    "knorrade": "knorra",
    "knorrades": "knorra",
    "knorrande": "knorra",
    "knorranden": "knorrande",
    "knorrandena": "knorrande",
    "knorrandenas": "knorrande",
    "knorrandens": "knorrande",
    "knorrandes": "knorrande",
    "knorrandet": "knorrande",
    "knorrandets": "knorrande",
    "knorrar": "knorra",
    "knorrarna": "knorr",
    "knorrarnas": "knorr",
    "knorrars": "knorr",
    "knorras": "knorra",
    "knorrat": "knorra",
    "knorrats": "knorra",
    "knorren": "knorr",
    "knorrens": "knorr",
    "knorret": "knorr",
    "knorrets": "knorr",
    "knorrhan": "knorrhane",
    "knorrhanar": "knorrhane",
    "knorrhanarna": "knorrhane",
    "knorrhanarnas": "knorrhane",
    "knorrhanars": "knorrhane",
    "knorrhanen": "knorrhane",
    "knorrhanens": "knorrhane",
    "knorrhanes": "knorrhane",
    "knorrhans": "knorrhane",
    "knorrs": "knorr",
    "knorv": "knorva",
    "knorvad": "knorva",
    "knorvade": "knorva",
    "knorvades": "knorva",
    "knorvads": "knorva",
    "knorvande": "knorva",
    "knorvanden": "knorvande",
    "knorvandena": "knorvande",
    "knorvandenas": "knorvande",
    "knorvandens": "knorvande",
    "knorvandes": "knorvande",
    "knorvandet": "knorvande",
    "knorvandets": "knorvande",
    "knorvar": "knorva",
    "knorvas": "knorva",
    "knorvat": "knorva",
    "knorvats": "knorva",
    "knosterna": "knoster",
    "knosternas": "knoster",
    "knosters": "knoster",
    "knostren": "knoster",
    "knostrens": "knoster",
    "knostret": "knoster",
    "knostrets": "knoster",
    "knot": "knota",
    "knotade": "knota",
    "knotades": "knota",
    "knotan": "knota",
    "knotande": "knota",
    "knotanden": "knotande",
    "knotandena": "knotande",
    "knotandenas": "knotande",
    "knotandens": "knotande",
    "knotandes": "knotande",
    "knotandet": "knotande",
    "knotandets": "knotande",
    "knotans": "knota",
    "knotar": "knota",
    "knotarna": "knot",
    "knotarnas": "knot",
    "knotars": "knot",
    "knotas": "knota",
    "knotat": "knota",
    "knotats": "knota",
    "knote": "knota",
    "knoten": "knot",
    "knotens": "knot",
    "knotet": "knot",
    "knotets": "knot",
    "knotiga": "knotig",
    "knotigare": "knotig",
    "knotigares": "knotig",
    "knotigas": "knotig",
    "knotigast": "knotig",
    "knotigaste": "knotig",
    "knotigastes": "knotig",
    "knotigasts": "knotig",
    "knotige": "knotig",
    "knotiges": "knotig",
    "knotigheten": "knotighet",
    "knotighetens": "knotighet",
    "knotigheter": "knotighet",
    "knotigheterna": "knotighet",
    "knotigheternas": "knotighet",
    "knotigheters": "knotighet",
    "knotighets": "knotighet",
    "knotigs": "knotig",
    "knotigt": "knotig",
    "knotigts": "knotig",
    "knotor": "knota",
    "knotorna": "knota",
    "knotornas": "knota",
    "knotors": "knota",
    "knots": "knota",
    "knotten": "knott",
    "knottens": "knott",
    "knotter": "knottra",
    "knotters": "knotter",
    "knottet": "knott",
    "knottets": "knott",
    "knottrade": "knottra",
    "knottrades": "knottra",
    "knottran": "knottra",
    "knottrande": "knottra",
    "knottranden": "knottrande",
    "knottrandena": "knottrande",
    "knottrandenas": "knottrande",
    "knottrandens": "knottrande",
    "knottrandes": "knottrande",
    "knottrandet": "knottrande",
    "knottrandets": "knottrande",
    "knottrans": "knottra",
    "knottrar": "knottra",
    "knottras": "knottra",
    "knottrat": "knottra",
    "knottrats": "knottra",
    "knottre": "knottra",
    "knottret": "knotter",
    "knottrets": "knotter",
    "knottriga": "knottrig",
    "knottrigare": "knottrig",
    "knottrigares": "knottrig",
    "knottrigas": "knottrig",
    "knottrigast": "knottrig",
    "knottrigaste": "knottrig",
    "knottrigastes": "knottrig",
    "knottrigasts": "knottrig",
    "knottrige": "knottrig",
    "knottriges": "knottrig",
    "knottrigheten": "knottrighet",
    "knottrighetens": "knottrighet",
    "knottrighets": "knottrighet",
    "knottrigs": "knottrig",
    "knottrigt": "knottrig",
    "knottrigts": "knottrig",
    "knottror": "knottra",
    "knottrorna": "knottra",
    "knottrornas": "knottra",
    "knottrors": "knottra",
    "knotts": "knott",
    "know-howet": "know-how",
    "know-howets": "know-how",
    "know-hows": "know-how",
    "knubbiga": "knubbig",
    "knubbigare": "knubbig",
    "knubbigares": "knubbig",
    "knubbigas": "knubbig",
    "knubbigast": "knubbig",
    "knubbigaste": "knubbig",
    "knubbigastes": "knubbig",
    "knubbigasts": "knubbig",
    "knubbige": "knubbig",
    "knubbiges": "knubbig",
    "knubbigheten": "knubbighet",
    "knubbighetens": "knubbighet",
    "knubbighets": "knubbighet",
    "knubbigs": "knubbig",
    "knubbigt": "knubbig",
    "knubbigts": "knubbig",
    "knubbsälar": "knubbsäl",
    "knubbsälarna": "knubbsäl",
    "knubbsälarnas": "knubbsäl",
    "knubbsälars": "knubbsäl",
    "knubbsälen": "knubbsäl",
    "knubbsälens": "knubbsäl",
    "knubbsäls": "knubbsäl",
    "knuff": "knuffa",
    "knuffad": "knuffa",
    "knuffade": "knuffa",
    "knuffades": "knuffas",
    "knuffads": "knuffa",
    "knuffande": "knuffa",
    "knuffanden": "knuffande",
    "knuffandena": "knuffande",
    "knuffandenas": "knuffande",
    "knuffandens": "knuffande",
    "knuffandes": "knuffande",
    "knuffandet": "knuffande",
    "knuffandets": "knuffande",
    "knuffar": "knuffa",
    "knuffarna": "knuff",
    "knuffarnas": "knuff",
    "knuffars": "knuff",
    "knuffas": "knuffa",
    "knuffat": "knuffa",
    "knuffats": "knuffas",
    "knuffen": "knuff",
    "knuffens": "knuff",
    "knuffs": "knuff",
    "knull": "knulla",
    "knullad": "knulla",
    "knullade": "knulla",
    "knullades": "knulla",
    "knullads": "knulla",
    "knullande": "knulla",
    "knullanden": "knullande",
    "knullandena": "knullande",
    "knullandenas": "knullande",
    "knullandens": "knullande",
    "knullandes": "knullande",
    "knullandet": "knullande",
    "knullandets": "knullande",
    "knullar": "knulla",
    "knullas": "knulla",
    "knullat": "knulla",
    "knullats": "knulla",
    "knullen": "knull",
    "knullens": "knull",
    "knullet": "knull",
    "knullets": "knull",
    "knulls": "knull",
    "knussel": "knussla",
    "knussels": "knussel",
    "knusslade": "knussla",
    "knusslades": "knussla",
    "knusslande": "knussla",
    "knusslanden": "knusslande",
    "knusslandena": "knusslande",
    "knusslandenas": "knusslande",
    "knusslandens": "knusslande",
    "knusslandes": "knusslande",
    "knusslandet": "knusslande",
    "knusslandets": "knusslande",
    "knusslar": "knussla",
    "knusslas": "knussla",
    "knusslat": "knussla",
    "knusslats": "knussla",
    "knusslet": "knussel",
    "knusslets": "knussel",
    "knussliga": "knusslig",
    "knussligare": "knusslig",
    "knussligares": "knusslig",
    "knussligas": "knusslig",
    "knussligast": "knusslig",
    "knussligaste": "knusslig",
    "knussligastes": "knusslig",
    "knussligasts": "knusslig",
    "knusslige": "knusslig",
    "knussliges": "knusslig",
    "knussligheten": "knusslighet",
    "knusslighetens": "knusslighet",
    "knussligheter": "knusslighet",
    "knussligheterna": "knusslighet",
    "knussligheternas": "knusslighet",
    "knussligheters": "knusslighet",
    "knusslighets": "knusslighet",
    "knussligs": "knusslig",
    "knussligt": "knusslig",
    "knussligts": "knusslig",
    "knut": "knuta",
    "knutan": "knuta",
    "knutans": "knuta",
    "knutar": "knut",
    "knutarnas": "knut",
    "knutas": "knuta",
    "knutbroderier": "knutbroderi",
    "knutbroderierna": "knutbroderi",
    "knutbroderiernas": "knutbroderi",
    "knutbroderiers": "knutbroderi",
    "knutbroderiet": "knutbroderi",
    "knutbroderiets": "knutbroderi",
    "knutbroderis": "knutbroderi",
    "knutbroderit": "knutbroderi",
    "knutbroderits": "knutbroderi",
    "knute": "knuta",
    "knuten": "knyta",
    "knutens": "knyta",
    "knutet": "knyta",
    "knutets": "knyta",
    "knutiga": "knutig",
    "knutigare": "knutig",
    "knutigares": "knutig",
    "knutigas": "knutig",
    "knutigast": "knutig",
    "knutigaste": "knutig",
    "knutigastes": "knutig",
    "knutigasts": "knutig",
    "knutige": "knutig",
    "knutiges": "knutig",
    "knutigs": "knutig",
    "knutigt": "knutig",
    "knutigts": "knutig",
    "knutit": "knyta",
    "knutits": "knyta",
    "knutna": "knyta",
    "knutnare": "knuten",
    "knutnares": "knuten",
    "knutnas": "knyta",
    "knutnast": "knuten",
    "knutnaste": "knuten",
    "knutnastes": "knuten",
    "knutnasts": "knuten",
    "knutne": "knyta",
    "knutnes": "knyta",
    "knutor": "knuta",
    "knutorna": "knuta",
    "knutornas": "knuta",
    "knutors": "knuta",
    "knutpisk": "knutpiska",
    "knutpiskan": "knutpiska",
    "knutpiskans": "knutpiska",
    "knutpiskas": "knutpiska",
    "knutpiske": "knutpiska",
    "knutpiskor": "knutpiska",
    "knutpiskorna": "knutpiska",
    "knutpiskornas": "knutpiska",
    "knutpiskors": "knutpiska",
    "knutpunkten": "knutpunkt",
    "knutpunktens": "knutpunkt",
    "knutpunkter": "knutpunkt",
    "knutpunkterna": "knutpunkt",
    "knutpunkternas": "knutpunkt",
    "knutpunkters": "knutpunkt",
    "knutpunkts": "knutpunkt",
    "knuts": "knuta",
    "knutt": "knutte",
    "knuttar": "knutte",
    "knuttarna": "knutte",
    "knuttarnas": "knutte",
    "knuttars": "knutte",
    "knutten": "knutte",
    "knuttens": "knutte",
    "knuttes": "knutte",
    "knuttimrad": "knuttimra",
    "knuttimrade": "knuttimra",
    "knuttimrades": "knuttimra",
    "knuttimrads": "knuttimra",
    "knuttimrande": "knuttimra",
    "knuttimranden": "knuttimrande",
    "knuttimrandena": "knuttimrande",
    "knuttimrandenas": "knuttimrande",
    "knuttimrandens": "knuttimrande",
    "knuttimrandes": "knuttimrande",
    "knuttimrandet": "knuttimrande",
    "knuttimrandets": "knuttimrande",
    "knuttimrar": "knuttimra",
    "knuttimras": "knuttimra",
    "knuttimrat": "knuttimra",
    "knuttimrats": "knuttimra",
    "knutts": "knutte",
    "knyck": "knycka",
    "knyckande": "knycka",
    "knyckanden": "knyckande",
    "knyckandena": "knyckande",
    "knyckandenas": "knyckande",
    "knyckandens": "knyckande",
    "knyckandes": "knyckande",
    "knyckandet": "knyckande",
    "knyckandets": "knyckande",
    "knyckar": "knyck",
    "knyckarna": "knyck",
    "knyckarnas": "knyck",
    "knyckars": "knyck",
    "knyckas": "knycka",
    "knyckel": "knyckla",
    "knycken": "knyck",
    "knyckens": "knyck",
    "knycker": "knycka",
    "knyckes": "knycka",
    "knyckiga": "knyckig",
    "knyckigare": "knyckig",
    "knyckigares": "knyckig",
    "knyckigas": "knyckig",
    "knyckigast": "knyckig",
    "knyckigaste": "knyckig",
    "knyckigastes": "knyckig",
    "knyckigasts": "knyckig",
    "knyckige": "knyckig",
    "knyckiges": "knyckig",
    "knyckigheten": "knyckighet",
    "knyckighetens": "knyckighet",
    "knyckighets": "knyckighet",
    "knyckigs": "knyckig",
    "knyckigt": "knyckig",
    "knyckigts": "knyckig",
    "knycklad": "knyckla",
    "knycklade": "knyckla",
    "knycklades": "knyckla",
    "knycklads": "knyckla",
    "knycklande": "knyckla",
    "knycklanden": "knycklande",
    "knycklandena": "knycklande",
    "knycklandenas": "knycklande",
    "knycklandens": "knycklande",
    "knycklandes": "knycklande",
    "knycklandet": "knycklande",
    "knycklandets": "knycklande",
    "knycklar": "knyckla",
    "knycklas": "knyckla",
    "knycklat": "knyckla",
    "knycklats": "knyckla",
    "knycks": "knycka",
    "knyckt": "knycka",
    "knyckta": "knycka",
    "knycktas": "knycka",
    "knyckte": "knycka",
    "knycktes": "knycka",
    "knyckts": "knycka",
    "knylhavren": "knylhavre",
    "knylhavrens": "knylhavre",
    "knylhavres": "knylhavre",
    "knyppel": "knyppla",
    "knyppeldyn": "knyppeldyna",
    "knyppeldynan": "knyppeldyna",
    "knyppeldynans": "knyppeldyna",
    "knyppeldynas": "knyppeldyna",
    "knyppeldyne": "knyppeldyna",
    "knyppeldynor": "knyppeldyna",
    "knyppeldynorna": "knyppeldyna",
    "knyppeldynornas": "knyppeldyna",
    "knyppeldynors": "knyppeldyna",
    "knyppeldyns": "knyppeldyna",
    "knypplad": "knyppla",
    "knypplade": "knyppla",
    "knypplades": "knyppla",
    "knypplads": "knyppla",
    "knypplande": "knyppla",
    "knypplanden": "knypplande",
    "knypplandena": "knypplande",
    "knypplandenas": "knypplande",
    "knypplandens": "knypplande",
    "knypplandes": "knypplande",
    "knypplandet": "knypplande",
    "knypplandets": "knypplande",
    "knypplar": "knyppla",
    "knypplas": "knyppla",
    "knypplat": "knyppla",
    "knypplats": "knyppla",
    "knystade": "knysta",
    "knystades": "knysta",
    "knystande": "knysta",
    "knystanden": "knystande",
    "knystandena": "knystande",
    "knystandenas": "knystande",
    "knystandens": "knystande",
    "knystandes": "knystande",
    "knystandet": "knystande",
    "knystandets": "knystande",
    "knystar": "knysta",
    "knystas": "knysta",
    "knystat": "knysta",
    "knystats": "knysta",
    "knysten": "knyst",
    "knystens": "knyst",
    "knystet": "knyst",
    "knystets": "knyst",
    "knysts": "knyst",
    "knyt": "knyta",
    "knytande": "knyta",
    "knytanden": "knytande",
    "knytandena": "knytande",
    "knytandenas": "knytande",
    "knytandens": "knytande",
    "knytandes": "knytande",
    "knytandet": "knytande",
    "knytandets": "knytande",
    "knytas": "knyta",
    "knyte": "knyta",
    "knyten": "knyte",
    "knytena": "knyte",
    "knytenas": "knyte",
    "knytens": "knyte",
    "knyter": "knyta",
    "knytes": "knyte",
    "knytet": "knyte",
    "knytets": "knyte",
    "knytkalasen": "knytkalas",
    "knytkalasens": "knytkalas",
    "knytkalaset": "knytkalas",
    "knytkalasets": "knytkalas",
    "knytnäv": "knytnäve",
    "knytnävar": "knytnäve",
    "knytnävarna": "knytnäve",
    "knytnävarnas": "knytnäve",
    "knytnävars": "knytnäve",
    "knytnäven": "knytnäve",
    "knytnävens": "knytnäve",
    "knytnäves": "knytnäve",
    "knytnävs": "knytnäve",
    "knytnävsslagen": "knytnävsslag",
    "knytnävsslagens": "knytnävsslag",
    "knytnävsslaget": "knytnävsslag",
    "knytnävsslagets": "knytnävsslag",
    "knytnävsslags": "knytnävsslag",
    "knyts": "knyte",
    "knytskärpen": "knytskärp",
    "knytskärpens": "knytskärp",
    "knytskärpet": "knytskärp",
    "knytskärpets": "knytskärp",
    "knytskärps": "knytskärp",
    "knäad": "knäa",
    "knäade": "knäa",
    "knäades": "knäa",
    "knäads": "knäa",
    "knäande": "knäa",
    "knäanden": "knäande",
    "knäandena": "knäande",
    "knäandenas": "knäande",
    "knäandens": "knäande",
    "knäandes": "knäande",
    "knäandet": "knäande",
    "knäandets": "knäande",
    "knäar": "knäa",
    "knäas": "knäa",
    "knäat": "knäa",
    "knäats": "knäa",
    "knäbyx": "knäbyxa",
    "knäbyxan": "knäbyxa",
    "knäbyxans": "knäbyxa",
    "knäbyxas": "knäbyxa",
    "knäbyxe": "knäbyxa",
    "knäbyxor": "knäbyxa",
    "knäbyxorna": "knäbyxa",
    "knäbyxornas": "knäbyxa",
    "knäbyxors": "knäbyxa",
    "knäböj": "knäböja",
    "knäböjande": "knäböja",
    "knäböjanden": "knäböjande",
    "knäböjandena": "knäböjande",
    "knäböjandenas": "knäböjande",
    "knäböjandens": "knäböjande",
    "knäböjandes": "knäböjande",
    "knäböjandet": "knäböjande",
    "knäböjandets": "knäböjande",
    "knäböjas": "knäböja",
    "knäböjd": "knäböja",
    "knäböjda": "knäböja",
    "knäböjdas": "knäböja",
    "knäböjde": "knäböja",
    "knäböjdes": "knäböja",
    "knäböjds": "knäböja",
    "knäböjer": "knäböja",
    "knäböjes": "knäböja",
    "knäböjs": "knäböja",
    "knäböjt": "knäböja",
    "knäböjts": "knäböja",
    "knäck": "knäcka",
    "knäckande": "knäcka",
    "knäckanden": "knäckande",
    "knäckandena": "knäckande",
    "knäckandenas": "knäckande",
    "knäckandens": "knäckande",
    "knäckandes": "knäckande",
    "knäckandet": "knäckande",
    "knäckandets": "knäckande",
    "knäckar": "knäck",
    "knäckarna": "knäck",
    "knäckarnas": "knäck",
    "knäckars": "knäck",
    "knäckas": "knäcka",
    "knäckebröden": "knäckebröd",
    "knäckebrödens": "knäckebröd",
    "knäckebrödet": "knäckebröd",
    "knäckebrödets": "knäckebröd",
    "knäckebröds": "knäckebröd",
    "knäcken": "knäck",
    "knäckens": "knäck",
    "knäckepilar": "knäckepil",
    "knäckepilarna": "knäckepil",
    "knäckepilarnas": "knäckepil",
    "knäckepilars": "knäckepil",
    "knäckepilen": "knäckepil",
    "knäckepilens": "knäckepil",
    "knäckepils": "knäckepil",
    "knäcker": "knäcka",
    "knäckes": "knäcka",
    "knäcket": "knäck",
    "knäckets": "knäck",
    "knäckformar": "knäckform",
    "knäckformarna": "knäckform",
    "knäckformarnas": "knäckform",
    "knäckformars": "knäckform",
    "knäckformen": "knäckform",
    "knäckformens": "knäckform",
    "knäckforms": "knäckform",
    "knäckfrågan": "knäckfråga",
    "knäckfrågans": "knäckfråga",
    "knäckfrågas": "knäckfråga",
    "knäckfråge": "knäckfråga",
    "knäckfrågor": "knäckfråga",
    "knäckfrågorna": "knäckfråga",
    "knäckfrågornas": "knäckfråga",
    "knäckfrågors": "knäckfråga",
    "knäcks": "knäcka",
    "knäckt": "knäcka",
    "knäckta": "knäckt",
    "knäcktare": "knäckt",
    "knäcktares": "knäckt",
    "knäcktas": "knäckt",
    "knäcktast": "knäckt",
    "knäcktaste": "knäckt",
    "knäcktastes": "knäckt",
    "knäcktasts": "knäckt",
    "knäckte": "knäckt",
    "knäcktes": "knäckt",
    "knäcktheten": "knäckthet",
    "knäckthetens": "knäckthet",
    "knäckthets": "knäckthet",
    "knäckts": "knäckt",
    "knäet": "knä",
    "knäets": "knä",
    "knäfall": "knäfalla",
    "knäfallande": "knäfalla",
    "knäfallanden": "knäfallande",
    "knäfallandena": "knäfallande",
    "knäfallandenas": "knäfallande",
    "knäfallandens": "knäfallande",
    "knäfallandes": "knäfallande",
    "knäfallandet": "knäfallande",
    "knäfallandets": "knäfallande",
    "knäfallas": "knäfalla",
    "knäfalle": "knäfalla",
    "knäfallen": "knäfalla",
    "knäfallens": "knäfalla",
    "knäfaller": "knäfalla",
    "knäfalles": "knäfalla",
    "knäfallet": "knäfalla",
    "knäfallets": "knäfalla",
    "knäfallit": "knäfalla",
    "knäfallits": "knäfalla",
    "knäfallna": "knäfalla",
    "knäfallnas": "knäfalla",
    "knäfallne": "knäfalla",
    "knäfallnes": "knäfalla",
    "knäfalls": "knäfalla",
    "knäföll": "knäfalla",
    "knäfölle": "knäfalla",
    "knäfölles": "knäfalla",
    "knäfölls": "knäfalla",
    "knähundar": "knähund",
    "knähundarna": "knähund",
    "knähundarnas": "knähund",
    "knähundars": "knähund",
    "knähunden": "knähund",
    "knähundens": "knähund",
    "knähunds": "knähund",
    "knähöga": "knähög",
    "knähögare": "knähög",
    "knähögares": "knähög",
    "knähögas": "knähög",
    "knähögast": "knähög",
    "knähögaste": "knähög",
    "knähögastes": "knähög",
    "knähögasts": "knähög",
    "knähöge": "knähög",
    "knähöges": "knähög",
    "knähögs": "knähög",
    "knähögt": "knähög",
    "knähögts": "knähög",
    "knähöjds": "knähöjd",
    "knäkorta": "knäkort",
    "knäkortare": "knäkort",
    "knäkortares": "knäkort",
    "knäkortas": "knäkort",
    "knäkortast": "knäkort",
    "knäkortaste": "knäkort",
    "knäkortastes": "knäkort",
    "knäkortasts": "knäkort",
    "knäkorte": "knäkort",
    "knäkortes": "knäkort",
    "knäkorts": "knäkort",
    "knäleden": "knäled",
    "knäledens": "knäled",
    "knäleder": "knäled",
    "knälederna": "knäled",
    "knäledernas": "knäled",
    "knäleders": "knäled",
    "knäleds": "knäled",
    "knälånga": "knälång",
    "knälångare": "knälång",
    "knälångares": "knälång",
    "knälångas": "knälång",
    "knälångast": "knälång",
    "knälångaste": "knälång",
    "knälångastes": "knälång",
    "knälångasts": "knälång",
    "knälånge": "knälång",
    "knälånges": "knälång",
    "knälångs": "knälång",
    "knälångt": "knälång",
    "knälångts": "knälång",
    "knän": "knä",
    "knäna": "knä",
    "knänas": "knä",
    "knäns": "knä",
    "knäpp": "knäppa",
    "knäppa": "knäpp",
    "knäppande": "knäppa",
    "knäppanden": "knäppande",
    "knäppandena": "knäppande",
    "knäppandenas": "knäppande",
    "knäppandens": "knäppande",
    "knäppandes": "knäppande",
    "knäppandet": "knäppande",
    "knäppandets": "knäppande",
    "knäppar": "knäpp",
    "knäppare": "knäpp",
    "knäppares": "knäpp",
    "knäpparna": "knäpp",
    "knäpparnas": "knäpp",
    "knäppars": "knäpp",
    "knäppas": "knäppa",
    "knäppast": "knäpp",
    "knäppaste": "knäpp",
    "knäppastes": "knäpp",
    "knäppasts": "knäpp",
    "knäppbagg": "knäppbagge",
    "knäppbaggar": "knäppbagge",
    "knäppbaggarna": "knäppbagge",
    "knäppbaggarnas": "knäppbagge",
    "knäppbaggars": "knäppbagge",
    "knäppbaggen": "knäppbagge",
    "knäppbaggens": "knäppbagge",
    "knäppbagges": "knäppbagge",
    "knäppbaggs": "knäppbagge",
    "knäppe": "knäpp",
    "knäppen": "knäppe",
    "knäppena": "knäppe",
    "knäppenas": "knäppe",
    "knäppens": "knäppe",
    "knäpper": "knäppa",
    "knäppes": "knäppe",
    "knäppet": "knäppe",
    "knäppets": "knäppe",
    "knäppfamiljen": "knäppfamilj",
    "knäppfamiljens": "knäppfamilj",
    "knäppfamiljer": "knäppfamilj",
    "knäppfamiljerna": "knäppfamilj",
    "knäppfamiljernas": "knäppfamilj",
    "knäppfamiljers": "knäppfamilj",
    "knäppfamiljs": "knäppfamilj",
    "knäppgökar": "knäppgök",
    "knäppgökarna": "knäppgök",
    "knäppgökarnas": "knäppgök",
    "knäppgökars": "knäppgök",
    "knäppgöken": "knäppgök",
    "knäppgökens": "knäppgök",
    "knäppgöks": "knäppgök",
    "knäppheten": "knäpphet",
    "knäpphetens": "knäpphet",
    "knäpphets": "knäpphet",
    "knäppkäng": "knäppkänga",
    "knäppkängan": "knäppkänga",
    "knäppkängans": "knäppkänga",
    "knäppkängas": "knäppkänga",
    "knäppkänge": "knäppkänga",
    "knäppkängor": "knäppkänga",
    "knäppkängorna": "knäppkänga",
    "knäppkängornas": "knäppkänga",
    "knäppkängors": "knäppkänga",
    "knäppkängs": "knäppkänga",
    "knäppningar": "knäppning",
    "knäppningarna": "knäppning",
    "knäppningarnas": "knäppning",
    "knäppningars": "knäppning",
    "knäppningen": "knäppning",
    "knäppningens": "knäppning",
    "knäppnings": "knäppning",
    "knäpps": "knäppe",
    "knäppt": "knäppa",
    "knäppta": "knäppa",
    "knäpptas": "knäppa",
    "knäppte": "knäppa",
    "knäpptes": "knäppa",
    "knäppts": "knäppa",
    "knäpptysta": "knäpptyst",
    "knäpptystare": "knäpptyst",
    "knäpptystares": "knäpptyst",
    "knäpptystas": "knäpptyst",
    "knäpptystast": "knäpptyst",
    "knäpptystaste": "knäpptyst",
    "knäpptystastes": "knäpptyst",
    "knäpptystasts": "knäpptyst",
    "knäpptyste": "knäpptyst",
    "knäpptystes": "knäpptyst",
    "knäpptysts": "knäpptyst",
    "knärören": "knärör",
    "knärörens": "knärör",
    "knäröret": "knärör",
    "knärörets": "knärör",
    "knärörs": "knärör",
    "knäs": "knä",
    "knäsatt": "knäsätta",
    "knäsatta": "knäsätta",
    "knäsattas": "knäsätta",
    "knäsatte": "knäsätta",
    "knäsattes": "knäsätta",
    "knäsatts": "knäsätta",
    "knäskadade": "knäskadad",
    "knäskadades": "knäskadad",
    "knäskadads": "knäskadad",
    "knäskadan": "knäskada",
    "knäskadans": "knäskada",
    "knäskadas": "knäskada",
    "knäskadat": "knäskadad",
    "knäskadats": "knäskadad",
    "knäskade": "knäskada",
    "knäskador": "knäskada",
    "knäskadorna": "knäskada",
    "knäskadornas": "knäskada",
    "knäskadors": "knäskada",
    "knäskydden": "knäskydd",
    "knäskyddens": "knäskydd",
    "knäskyddet": "knäskydd",
    "knäskyddets": "knäskydd",
    "knäskydds": "knäskydd",
    "knäskålar": "knäskål",
    "knäskålarna": "knäskål",
    "knäskålarnas": "knäskål",
    "knäskålars": "knäskål",
    "knäskålen": "knäskål",
    "knäskålens": "knäskål",
    "knäskåls": "knäskål",
    "knäsluten": "knäslut",
    "knäslutens": "knäslut",
    "knäslutet": "knäslut",
    "knäslutets": "knäslut",
    "knäsluts": "knäslut",
    "knästrump": "knästrumpa",
    "knästrumpan": "knästrumpa",
    "knästrumpans": "knästrumpa",
    "knästrumpas": "knästrumpa",
    "knästrumpe": "knästrumpa",
    "knästrumpor": "knästrumpa",
    "knästrumporna": "knästrumpa",
    "knästrumpornas": "knästrumpa",
    "knästrumpors": "knästrumpa",
    "knästrumps": "knästrumpa",
    "knäståendes": "knästående",
    "knäståendet": "knästående",
    "knäståendets": "knästående",
    "knäsvaga": "knäsvag",
    "knäsvagare": "knäsvag",
    "knäsvagares": "knäsvag",
    "knäsvagas": "knäsvag",
    "knäsvagast": "knäsvag",
    "knäsvagaste": "knäsvag",
    "knäsvagastes": "knäsvag",
    "knäsvagasts": "knäsvag",
    "knäsvage": "knäsvag",
    "knäsvages": "knäsvag",
    "knäsvagheten": "knäsvaghet",
    "knäsvaghetens": "knäsvaghet",
    "knäsvaghets": "knäsvaghet",
    "knäsvags": "knäsvag",
    "knäsvagt": "knäsvag",
    "knäsvagts": "knäsvag",
    "knäsätt": "knäsätta",
    "knäsättande": "knäsätta",
    "knäsättanden": "knäsättande",
    "knäsättandena": "knäsättande",
    "knäsättandenas": "knäsättande",
    "knäsättandens": "knäsättande",
    "knäsättandes": "knäsättande",
    "knäsättandet": "knäsättande",
    "knäsättandets": "knäsättande",
    "knäsättas": "knäsätta",
    "knäsätter": "knäsätta",
    "knäsättes": "knäsätta",
    "knäsätts": "knäsätta",
    "knät": "knä",
    "knätofsar": "knätofs",
    "knätofsarna": "knätofs",
    "knätofsarnas": "knätofs",
    "knätofsars": "knätofs",
    "knätofsen": "knätofs",
    "knätofsens": "knätofs",
    "knätrakten": "knätrakt",
    "knätraktens": "knätrakt",
    "knätrakter": "knätrakt",
    "knätrakterna": "knätrakt",
    "knätrakternas": "knätrakt",
    "knätrakters": "knätrakt",
    "knätrakts": "knätrakt",
    "knäts": "knä",
    "knävecken": "knäveck",
    "knäveckens": "knäveck",
    "knävecket": "knäveck",
    "knäveckets": "knäveck",
    "knävecks": "knäveck",
    "knävelborrar": "knävelborr",
    "knävelborrarna": "knävelborr",
    "knävelborrarnas": "knävelborr",
    "knävelborrars": "knävelborr",
    "knävelborren": "knävelborr",
    "knävelborrens": "knävelborr",
    "knävelborrs": "knävelborr",
    "knävringar": "knävring",
    "knävringarna": "knävring",
    "knävringarnas": "knävring",
    "knävringars": "knävring",
    "knävringen": "knävring",
    "knävringens": "knävring",
    "knävrings": "knävring",
    "knåd": "knåda",
    "knådad": "knåda",
    "knådade": "knåda",
    "knådades": "knåda",
    "knådads": "knåda",
    "knådande": "knåda",
    "knådanden": "knådande",
    "knådandena": "knådande",
    "knådandenas": "knådande",
    "knådandens": "knådande",
    "knådandes": "knådande",
    "knådandet": "knådande",
    "knådandets": "knådande",
    "knådar": "knåda",
    "knådas": "knåda",
    "knådat": "knåda",
    "knådats": "knåda",
    "knåpade": "knåpa",
    "knåpades": "knåpa",
    "knåpande": "knåpa",
    "knåpanden": "knåpande",
    "knåpandena": "knåpande",
    "knåpandenas": "knåpande",
    "knåpandens": "knåpande",
    "knåpandes": "knåpande",
    "knåpandet": "knåpande",
    "knåpandets": "knåpande",
    "knåpar": "knåpa",
    "knåpas": "knåpa",
    "knåpat": "knåpa",
    "knåpats": "knåpa",
    "knåpet": "knåp",
    "knåpets": "knåp",
    "knåps": "knåp",
    "knödeln": "knödel",
    "knödelns": "knödel",
    "knödels": "knödel",
    "knödlar": "knödel",
    "knödlarna": "knödel",
    "knödlarnas": "knödel",
    "knödlars": "knödel",
    "knök": "knöka",
    "knökade": "knöka",
    "knökades": "knöka",
    "knökande": "knöka",
    "knökanden": "knökande",
    "knökandena": "knökande",
    "knökandenas": "knökande",
    "knökandens": "knökande",
    "knökandes": "knökande",
    "knökandet": "knökande",
    "knökandets": "knökande",
    "knökar": "knöka",
    "knökas": "knöka",
    "knökat": "knöka",
    "knökats": "knöka",
    "knökfulla": "knökfull",
    "knökfullare": "knökfull",
    "knökfullares": "knökfull",
    "knökfullas": "knökfull",
    "knökfullast": "knökfull",
    "knökfullaste": "knökfull",
    "knökfullastes": "knökfull",
    "knökfullasts": "knökfull",
    "knökfulle": "knökfull",
    "knökfulles": "knökfull",
    "knökfullheten": "knökfullhet",
    "knökfullhetens": "knökfullhet",
    "knökfullhets": "knökfullhet",
    "knökfulls": "knökfull",
    "knökfullt": "knökfull",
    "knökfullts": "knökfull",
    "knöl": "knöla",
    "knölad": "knöla",
    "knölade": "knöla",
    "knölades": "knöla",
    "knölads": "knöla",
    "knölaktiga": "knölaktig",
    "knölaktigare": "knölaktig",
    "knölaktigares": "knölaktig",
    "knölaktigas": "knölaktig",
    "knölaktigast": "knölaktig",
    "knölaktigaste": "knölaktig",
    "knölaktigastes": "knölaktig",
    "knölaktigasts": "knölaktig",
    "knölaktige": "knölaktig",
    "knölaktiges": "knölaktig",
    "knölaktigheten": "knölaktighet",
    "knölaktighetens": "knölaktighet",
    "knölaktighets": "knölaktighet",
    "knölaktigs": "knölaktig",
    "knölaktigt": "knölaktig",
    "knölaktigts": "knölaktig",
    "knölande": "knöla",
    "knölanden": "knölande",
    "knölandena": "knölande",
    "knölandenas": "knölande",
    "knölandens": "knölande",
    "knölandes": "knölande",
    "knölandet": "knölande",
    "knölandets": "knölande",
    "knölar": "knöla",
    "knölarna": "knöl",
    "knölarnas": "knöl",
    "knölars": "knöl",
    "knölas": "knöla",
    "knölat": "knöla",
    "knölats": "knöla",
    "knölen": "knöl",
    "knölens": "knöl",
    "knöliga": "knölig",
    "knöligare": "knölig",
    "knöligares": "knölig",
    "knöligas": "knölig",
    "knöligast": "knölig",
    "knöligaste": "knölig",
    "knöligastes": "knölig",
    "knöligasts": "knölig",
    "knölige": "knölig",
    "knöliges": "knölig",
    "knöligheten": "knölighet",
    "knölighetens": "knölighet",
    "knöligheter": "knölighet",
    "knöligheterna": "knölighet",
    "knöligheternas": "knölighet",
    "knöligheters": "knölighet",
    "knölighets": "knölighet",
    "knöligs": "knölig",
    "knöligt": "knölig",
    "knöligts": "knölig",
    "knölpåkar": "knölpåk",
    "knölpåkarna": "knölpåk",
    "knölpåkarnas": "knölpåk",
    "knölpåkars": "knölpåk",
    "knölpåken": "knölpåk",
    "knölpåkens": "knölpåk",
    "knölpåks": "knölpåk",
    "knölrosen": "knölros",
    "knölrosens": "knölros",
    "knölroten": "knölrot",
    "knölrotens": "knölrot",
    "knölrots": "knölrot",
    "knölrötter": "knölrot",
    "knölrötterna": "knölrot",
    "knölrötternas": "knölrot",
    "knölrötters": "knölrot",
    "knöls": "knöl",
    "knölstammar": "knölstam",
    "knölstammarna": "knölstam",
    "knölstammarnas": "knölstam",
    "knölstammars": "knölstam",
    "knölstammen": "knölstam",
    "knölstammens": "knölstam",
    "knölstams": "knölstam",
    "knölsvanar": "knölsvan",
    "knölsvanarna": "knölsvan",
    "knölsvanarnas": "knölsvan",
    "knölsvanars": "knölsvan",
    "knölsvanen": "knölsvan",
    "knölsvanens": "knölsvan",
    "knölsvans": "knölsvan",
    "knösar": "knös",
    "knösarna": "knös",
    "knösarnas": "knös",
    "knösars": "knös",
    "knösen": "knös",
    "knösens": "knös",
    "knöt": "knyta",
    "knöte": "knyta",
    "knötes": "knyta",
    "knöts": "knyta",
    "koafferad": "koaffera",
    "koafferade": "koaffera",
    "koafferades": "koaffera",
    "koafferads": "koaffera",
    "koafferande": "koaffera",
    "koafferanden": "koafferande",
    "koafferandena": "koafferande",
    "koafferandenas": "koafferande",
    "koafferandens": "koafferande",
    "koafferandes": "koafferande",
    "koafferandet": "koafferande",
    "koafferandets": "koafferande",
    "koafferar": "koaffera",
    "koafferas": "koaffera",
    "koafferat": "koaffera",
    "koafferats": "koaffera",
    "koafferbara": "koafferbar",
    "koafferbarare": "koafferbar",
    "koafferbarares": "koafferbar",
    "koafferbaras": "koafferbar",
    "koafferbarast": "koafferbar",
    "koafferbaraste": "koafferbar",
    "koafferbarastes": "koafferbar",
    "koafferbarasts": "koafferbar",
    "koafferbare": "koafferbar",
    "koafferbares": "koafferbar",
    "koafferbarheten": "koafferbarhet",
    "koafferbarhetens": "koafferbarhet",
    "koafferbarhets": "koafferbarhet",
    "koafferbars": "koafferbar",
    "koafferbart": "koafferbar",
    "koafferbarts": "koafferbar",
    "koafferingar": "koaffering",
    "koafferingarna": "koaffering",
    "koafferingarnas": "koaffering",
    "koafferingars": "koaffering",
    "koafferingen": "koaffering",
    "koafferingens": "koaffering",
    "koafferings": "koaffering",
    "koaffyren": "koaffyr",
    "koaffyrens": "koaffyr",
    "koaffyrer": "koaffyr",
    "koaffyrerna": "koaffyr",
    "koaffyrernas": "koaffyr",
    "koaffyrers": "koaffyr",
    "koaffyrs": "koaffyr",
    "koaffören": "koafför",
    "koafförens": "koafför",
    "koafförer": "koafför",
    "koafförerna": "koafför",
    "koafförernas": "koafför",
    "koafförers": "koafför",
    "koafförs": "koafför",
    "koagulationen": "koagulation",
    "koagulationens": "koagulation",
    "koagulationer": "koagulation",
    "koagulationerna": "koagulation",
    "koagulationernas": "koagulation",
    "koagulationers": "koagulation",
    "koagulations": "koagulation",
    "koagulerad": "koagulera",
    "koagulerade": "koagulera",
    "koagulerades": "koagulera",
    "koagulerads": "koagulera",
    "koagulerande": "koagulera",
    "koaguleranden": "koagulerande",
    "koagulerandena": "koagulerande",
    "koagulerandenas": "koagulerande",
    "koagulerandens": "koagulerande",
    "koagulerandes": "koagulerande",
    "koagulerandet": "koagulerande",
    "koagulerandets": "koagulerande",
    "koagulerar": "koagulera",
    "koaguleras": "koagulera",
    "koagulerat": "koagulera",
    "koagulerats": "koagulera",
    "koagulerbara": "koagulerbar",
    "koagulerbarare": "koagulerbar",
    "koagulerbarares": "koagulerbar",
    "koagulerbaras": "koagulerbar",
    "koagulerbarast": "koagulerbar",
    "koagulerbaraste": "koagulerbar",
    "koagulerbarastes": "koagulerbar",
    "koagulerbarasts": "koagulerbar",
    "koagulerbare": "koagulerbar",
    "koagulerbares": "koagulerbar",
    "koagulerbarheten": "koagulerbarhet",
    "koagulerbarhetens": "koagulerbarhet",
    "koagulerbarhets": "koagulerbarhet",
    "koagulerbars": "koagulerbar",
    "koagulerbart": "koagulerbar",
    "koagulerbarts": "koagulerbar",
    "koaguleringar": "koagulering",
    "koaguleringarna": "koagulering",
    "koaguleringarnas": "koagulering",
    "koaguleringars": "koagulering",
    "koaguleringen": "koagulering",
    "koaguleringens": "koagulering",
    "koagulerings": "koagulering",
    "koal": "koala",
    "koalan": "koala",
    "koalans": "koala",
    "koalas": "koala",
    "koale": "koala",
    "koalitionen": "koalition",
    "koalitionens": "koalition",
    "koalitioner": "koalition",
    "koalitionerna": "koalition",
    "koalitionernas": "koalition",
    "koalitioners": "koalition",
    "koalitions": "koalition",
    "koalitionsregeringar": "koalitionsregering",
    "koalitionsregeringarna": "koalitionsregering",
    "koalitionsregeringarnas": "koalitionsregering",
    "koalitionsregeringars": "koalitionsregering",
    "koalitionsregeringen": "koalitionsregering",
    "koalitionsregeringens": "koalitionsregering",
    "koalitionsregerings": "koalitionsregering",
    "koalor": "koala",
    "koalorna": "koala",
    "koalornas": "koala",
    "koalors": "koala",
    "koals": "koala",
    "koaxialkabeln": "koaxialkabel",
    "koaxialkabelns": "koaxialkabel",
    "koaxialkabels": "koaxialkabel",
    "koaxialkablar": "koaxialkabel",
    "koaxialkablarna": "koaxialkabel",
    "koaxialkablarnas": "koaxialkabel",
    "koaxialkablars": "koaxialkabel",
    "kobb": "kobbe",
    "kobbar": "kobbe",
    "kobbarna": "kobbe",
    "kobbarnas": "kobbe",
    "kobbars": "kobbe",
    "kobbeln": "kobbel",
    "kobbelns": "kobbel",
    "kobbels": "kobbel",
    "kobben": "kobbe",
    "kobbens": "kobbe",
    "kobbes": "kobbe",
    "kobblar": "kobbel",
    "kobblarna": "kobbel",
    "kobblarnas": "kobbel",
    "kobblars": "kobbel",
    "kobbs": "kobbe",
    "kobenta": "kobent",
    "kobentare": "kobent",
    "kobentares": "kobent",
    "kobentas": "kobent",
    "kobentast": "kobent",
    "kobentaste": "kobent",
    "kobentastes": "kobent",
    "kobentasts": "kobent",
    "kobente": "kobent",
    "kobentes": "kobent",
    "kobentheten": "kobenthet",
    "kobenthetens": "kobenthet",
    "kobenthets": "kobenthet",
    "kobents": "kobent",
    "koboltblåtts": "koboltblått",
    "kobolten": "kobolt",
    "koboltens": "kobolt",
    "koboltglansen": "koboltglans",
    "koboltglansens": "koboltglans",
    "kobolthalten": "kobolthalt",
    "kobolthaltens": "kobolthalt",
    "kobolthalter": "kobolthalt",
    "kobolthalterna": "kobolthalt",
    "kobolthalternas": "kobolthalt",
    "kobolthalters": "kobolthalt",
    "kobolthaltiga": "kobolthaltig",
    "kobolthaltigare": "kobolthaltig",
    "kobolthaltigares": "kobolthaltig",
    "kobolthaltigas": "kobolthaltig",
    "kobolthaltigast": "kobolthaltig",
    "kobolthaltigaste": "kobolthaltig",
    "kobolthaltigastes": "kobolthaltig",
    "kobolthaltigasts": "kobolthaltig",
    "kobolthaltige": "kobolthaltig",
    "kobolthaltiges": "kobolthaltig",
    "kobolthaltigs": "kobolthaltig",
    "kobolthaltigt": "kobolthaltig",
    "kobolthaltigts": "kobolthaltig",
    "kobolthalts": "kobolthalt",
    "koboltjonen": "koboltjon",
    "koboltjonens": "koboltjon",
    "koboltjoner": "koboltjon",
    "koboltjonerna": "koboltjon",
    "koboltjonernas": "koboltjon",
    "koboltjoners": "koboltjon",
    "koboltjons": "koboltjon",
    "koboltkanonen": "koboltkanon",
    "koboltkanonens": "koboltkanon",
    "koboltkanoner": "koboltkanon",
    "koboltkanonerna": "koboltkanon",
    "koboltkanonernas": "koboltkanon",
    "koboltkanoners": "koboltkanon",
    "koboltkanons": "koboltkanon",
    "kobolts": "kobolt",
    "kobr": "kobra",
    "kobran": "kobra",
    "kobrans": "kobra",
    "kobras": "kobra",
    "kobre": "kobra",
    "kobror": "kobra",
    "kobrorna": "kobra",
    "kobrornas": "kobra",
    "kobrors": "kobra",
    "kobrs": "kobra",
    "kobrygg": "kobrygga",
    "kobryggan": "kobrygga",
    "kobryggans": "kobrygga",
    "kobryggas": "kobrygga",
    "kobrygge": "kobrygga",
    "kobryggor": "kobrygga",
    "kobryggorna": "kobrygga",
    "kobryggornas": "kobrygga",
    "kobryggors": "kobrygga",
    "kobryggs": "kobrygga",
    "kock": "kocka",
    "kockan": "kocka",
    "kockans": "kocka",
    "kockar": "kock",
    "kockarna": "kock",
    "kockarnas": "kock",
    "kockars": "kock",
    "kockas": "kocka",
    "kocke": "kocka",
    "kocken": "kock",
    "kockens": "kock",
    "kocker": "kock",
    "kockerna": "kock",
    "kockernas": "kock",
    "kockers": "kock",
    "kockmöss": "kockmössa",
    "kockmössan": "kockmössa",
    "kockmössans": "kockmössa",
    "kockmössas": "kockmössa",
    "kockmösse": "kockmössa",
    "kockmössor": "kockmössa",
    "kockmössorna": "kockmössa",
    "kockmössornas": "kockmössa",
    "kockmössors": "kockmössa",
    "kockor": "kocka",
    "kockorna": "kocka",
    "kockornas": "kocka",
    "kockors": "kocka",
    "kocks": "kocka",
    "kodad": "koda",
    "kodade": "koda",
    "kodades": "koda",
    "kodads": "koda",
    "kodande": "koda",
    "kodanden": "kodande",
    "kodandena": "kodande",
    "kodandenas": "kodande",
    "kodandens": "kodande",
    "kodandes": "kodande",
    "kodandet": "kodande",
    "kodandets": "kodande",
    "kodar": "koda",
    "kodas": "koda",
    "kodat": "koda",
    "kodats": "koda",
    "kodeinen": "kodein",
    "kodeinens": "kodein",
    "kodeinet": "kodein",
    "kodeinets": "kodein",
    "kodeins": "kodein",
    "koden": "kod",
    "kodens": "kod",
    "koder": "kod",
    "koderna": "kod",
    "kodernas": "kod",
    "koders": "kod",
    "kodexar": "kodex",
    "kodexarna": "kodex",
    "kodexarnas": "kodex",
    "kodexars": "kodex",
    "kodexen": "kodex",
    "kodexens": "kodex",
    "kodicillen": "kodicill",
    "kodicillens": "kodicill",
    "kodiciller": "kodicill",
    "kodicillerna": "kodicill",
    "kodicillernas": "kodicill",
    "kodicillers": "kodicill",
    "kodicills": "kodicill",
    "kodifierad": "kodifiera",
    "kodifierade": "kodifiera",
    "kodifierades": "kodifiera",
    "kodifierads": "kodifiera",
    "kodifierande": "kodifiera",
    "kodifieranden": "kodifierande",
    "kodifierandena": "kodifierande",
    "kodifierandenas": "kodifierande",
    "kodifierandens": "kodifierande",
    "kodifierandes": "kodifierande",
    "kodifierandet": "kodifierande",
    "kodifierandets": "kodifierande",
    "kodifierar": "kodifiera",
    "kodifieras": "kodifiera",
    "kodifierat": "kodifiera",
    "kodifierats": "kodifiera",
    "kodifierbara": "kodifierbar",
    "kodifierbarare": "kodifierbar",
    "kodifierbarares": "kodifierbar",
    "kodifierbaras": "kodifierbar",
    "kodifierbarast": "kodifierbar",
    "kodifierbaraste": "kodifierbar",
    "kodifierbarastes": "kodifierbar",
    "kodifierbarasts": "kodifierbar",
    "kodifierbare": "kodifierbar",
    "kodifierbares": "kodifierbar",
    "kodifierbarheten": "kodifierbarhet",
    "kodifierbarhetens": "kodifierbarhet",
    "kodifierbarhets": "kodifierbarhet",
    "kodifierbars": "kodifierbar",
    "kodifierbart": "kodifierbar",
    "kodifierbarts": "kodifierbar",
    "kodifieringar": "kodifiering",
    "kodifieringarna": "kodifiering",
    "kodifieringarnas": "kodifiering",
    "kodifieringars": "kodifiering",
    "kodifieringen": "kodifiering",
    "kodifieringens": "kodifiering",
    "kodifierings": "kodifiering",
    "kodifikationen": "kodifikation",
    "kodifikationens": "kodifikation",
    "kodifikationer": "kodifikation",
    "kodifikationerna": "kodifikation",
    "kodifikationernas": "kodifikation",
    "kodifikationers": "kodifikation",
    "kodifikations": "kodifikation",
    "kodiljen": "kodilj",
    "kodiljens": "kodilj",
    "kodiljs": "kodilj",
    "kodlåsen": "kodlås",
    "kodlåsens": "kodlås",
    "kodlåset": "kodlås",
    "kodlåsets": "kodlås",
    "kods": "kod",
    "koefficienten": "koefficient",
    "koefficientens": "koefficient",
    "koefficienter": "koefficient",
    "koefficienterna": "koefficient",
    "koefficienternas": "koefficient",
    "koefficienters": "koefficient",
    "koefficients": "koefficient",
    "koexistensen": "koexistens",
    "koexistensens": "koexistens",
    "koffar": "koff",
    "koffarna": "koff",
    "koffarnas": "koff",
    "koffars": "koff",
    "koffeinen": "koffein",
    "koffeinens": "koffein",
    "koffeinet": "koffein",
    "koffeinets": "koffein",
    "koffeins": "koffein",
    "koffen": "koff",
    "koffens": "koff",
    "kofferdammar": "kofferdamm",
    "kofferdammarna": "kofferdamm",
    "kofferdammarnas": "kofferdamm",
    "kofferdammars": "kofferdamm",
    "kofferdammen": "kofferdamm",
    "kofferdammens": "kofferdamm",
    "kofferdamms": "kofferdamm",
    "kofferdiflott": "kofferdiflotta",
    "kofferdiflottan": "kofferdiflotta",
    "kofferdiflottans": "kofferdiflotta",
    "kofferdiflottas": "kofferdiflotta",
    "kofferdiflotte": "kofferdiflotta",
    "kofferdiflottor": "kofferdiflotta",
    "kofferdiflottorna": "kofferdiflotta",
    "kofferdiflottornas": "kofferdiflotta",
    "kofferdiflottors": "kofferdiflotta",
    "kofferdiflotts": "kofferdiflotta",
    "kofferdisten": "kofferdist",
    "kofferdistens": "kofferdist",
    "kofferdister": "kofferdist",
    "kofferdisterna": "kofferdist",
    "kofferdisternas": "kofferdist",
    "kofferdisters": "kofferdist",
    "kofferdists": "kofferdist",
    "koffernageln": "koffernagel",
    "koffernagelns": "koffernagel",
    "koffernagels": "koffernagel",
    "koffernaglar": "koffernagel",
    "koffernaglarna": "koffernagel",
    "koffernaglarnas": "koffernagel",
    "koffernaglars": "koffernagel",
    "koffertar": "koffert",
    "koffertarna": "koffert",
    "koffertarnas": "koffert",
    "koffertars": "koffert",
    "kofferten": "koffert",
    "koffertens": "koffert",
    "koffertfiskar": "koffertfisk",
    "koffertfiskarna": "koffertfisk",
    "koffertfiskarnas": "koffertfisk",
    "koffertfiskars": "koffertfisk",
    "koffertfisken": "koffertfisk",
    "koffertfiskens": "koffertfisk",
    "koffertfisks": "koffertfisk",
    "kofferts": "koffert",
    "koffs": "koff",
    "kofotar": "kofot",
    "kofotarna": "kofot",
    "kofotarnas": "kofot",
    "kofotars": "kofot",
    "kofoten": "kofot",
    "kofotens": "kofot",
    "kofots": "kofot",
    "koft": "kofta",
    "koftan": "kofta",
    "koftans": "kofta",
    "koftas": "kofta",
    "kofte": "kofta",
    "koftgråa": "koftgrå",
    "koftgråare": "koftgrå",
    "koftgråares": "koftgrå",
    "koftgråas": "koftgrå",
    "koftgråast": "koftgrå",
    "koftgråaste": "koftgrå",
    "koftgråastes": "koftgrå",
    "koftgråasts": "koftgrå",
    "koftgråe": "koftgrå",
    "koftgråes": "koftgrå",
    "koftgrås": "koftgrå",
    "koftgrått": "koftgrå",
    "koftgråtts": "koftgrå",
    "koftor": "kofta",
    "koftorna": "kofta",
    "koftornas": "kofta",
    "koftors": "kofta",
    "kofts": "kofta",
    "kofångar": "kofångare",
    "kofångaren": "kofångare",
    "kofångarens": "kofångare",
    "kofångares": "kofångare",
    "kofångarna": "kofångare",
    "kofångarnas": "kofångare",
    "kofötter": "kofot",
    "kofötterna": "kofot",
    "kofötternas": "kofot",
    "kofötters": "kofot",
    "kogerna": "koger",
    "kogernas": "koger",
    "kogers": "koger",
    "koggar": "kogg",
    "koggarna": "kogg",
    "koggarnas": "kogg",
    "koggars": "kogg",
    "koggen": "kogg",
    "koggens": "kogg",
    "koggs": "kogg",
    "kognaten": "kognat",
    "kognatens": "kognat",
    "kognater": "kognat",
    "kognaterna": "kognat",
    "kognaternas": "kognat",
    "kognaters": "kognat",
    "kognatiska": "kognatisk",
    "kognatiskare": "kognatisk",
    "kognatiskares": "kognatisk",
    "kognatiskas": "kognatisk",
    "kognatiskast": "kognatisk",
    "kognatiskaste": "kognatisk",
    "kognatiskastes": "kognatisk",
    "kognatiskasts": "kognatisk",
    "kognatiske": "kognatisk",
    "kognatiskes": "kognatisk",
    "kognatisks": "kognatisk",
    "kognatiskt": "kognatisk",
    "kognatiskts": "kognatisk",
    "kognats": "kognat",
    "kognitionen": "kognition",
    "kognitionens": "kognition",
    "kognitioner": "kognition",
    "kognitionerna": "kognition",
    "kognitionernas": "kognition",
    "kognitioners": "kognition",
    "kognitions": "kognition",
    "kognitiva": "kognitiv",
    "kognitivare": "kognitiv",
    "kognitivares": "kognitiv",
    "kognitivas": "kognitiv",
    "kognitivast": "kognitiv",
    "kognitivaste": "kognitiv",
    "kognitivastes": "kognitiv",
    "kognitivasts": "kognitiv",
    "kognitive": "kognitiv",
    "kognitives": "kognitiv",
    "kognitivs": "kognitiv",
    "kognitivt": "kognitiv",
    "kognitivts": "kognitiv",
    "kogren": "koger",
    "kogrens": "koger",
    "kogret": "koger",
    "kogrets": "koger",
    "kohandeln": "kohandel",
    "kohandelns": "kohandel",
    "kohandels": "kohandel",
    "kohandlade": "kohandla",
    "kohandlades": "kohandla",
    "kohandlande": "kohandla",
    "kohandlanden": "kohandlande",
    "kohandlandena": "kohandlande",
    "kohandlandenas": "kohandlande",
    "kohandlandens": "kohandlande",
    "kohandlandes": "kohandlande",
    "kohandlandet": "kohandlande",
    "kohandlandets": "kohandlande",
    "kohandlar": "kohandla",
    "kohandlas": "kohandla",
    "kohandlat": "kohandla",
    "kohandlats": "kohandla",
    "koherensen": "koherens",
    "koherensens": "koherens",
    "koherenta": "koherent",
    "koherentare": "koherent",
    "koherentares": "koherent",
    "koherentas": "koherent",
    "koherentast": "koherent",
    "koherentaste": "koherent",
    "koherentastes": "koherent",
    "koherentasts": "koherent",
    "koherente": "koherent",
    "koherentes": "koherent",
    "koherents": "koherent",
    "kohesionen": "kohesion",
    "kohesionens": "kohesion",
    "kohesioner": "kohesion",
    "kohesionerna": "kohesion",
    "kohesionernas": "kohesion",
    "kohesioners": "kohesion",
    "kohesions": "kohesion",
    "kohls": "kohl",
    "kohorten": "kohort",
    "kohortens": "kohort",
    "kohorter": "kohort",
    "kohorterna": "kohort",
    "kohorternas": "kohort",
    "kohorters": "kohort",
    "kohorts": "kohort",
    "kohudar": "kohud",
    "kohudarna": "kohud",
    "kohudarnas": "kohud",
    "kohudars": "kohud",
    "kohuden": "kohud",
    "kohudens": "kohud",
    "kohuds": "kohud",
    "koineiseringen": "koineisering",
    "koineiseringens": "koineisering",
    "koineiserings": "koineisering",
    "koinen": "koine",
    "koinens": "koine",
    "koines": "koine",
    "koinet": "koine",
    "koinets": "koine",
    "koinén": "koiné",
    "koinéns": "koiné",
    "koinés": "koiné",
    "koinét": "koiné",
    "koinéts": "koiné",
    "koj": "koja",
    "kojad": "koja",
    "kojade": "koja",
    "kojades": "koja",
    "kojads": "koja",
    "kojan": "koja",
    "kojande": "koja",
    "kojanden": "kojande",
    "kojandena": "kojande",
    "kojandenas": "kojande",
    "kojandens": "kojande",
    "kojandes": "kojande",
    "kojandet": "kojande",
    "kojandets": "kojande",
    "kojans": "koja",
    "kojar": "koja",
    "kojas": "koja",
    "kojat": "koja",
    "kojats": "koja",
    "koje": "koja",
    "kojen": "koj",
    "kojens": "koj",
    "kojer": "koj",
    "kojerna": "koj",
    "kojernas": "koj",
    "kojers": "koj",
    "kojor": "koja",
    "kojorna": "koja",
    "kojornas": "koja",
    "kojors": "koja",
    "kojs": "koja",
    "kojsad": "kojsa",
    "kojsade": "kojsa",
    "kojsades": "kojsa",
    "kojsads": "kojsa",
    "kojsande": "kojsa",
    "kojsanden": "kojsande",
    "kojsandena": "kojsande",
    "kojsandenas": "kojsande",
    "kojsandens": "kojsande",
    "kojsandes": "kojsande",
    "kojsandet": "kojsande",
    "kojsandets": "kojsande",
    "kojsar": "kojsa",
    "kojsas": "kojsa",
    "kojsat": "kojsa",
    "kojsats": "kojsa",
    "kok": "koka",
    "kokad": "koka",
    "kokade": "koka",
    "kokades": "koka",
    "kokads": "koka",
    "kokainen": "kokain",
    "kokainens": "kokain",
    "kokainet": "kokain",
    "kokainets": "kokain",
    "kokainhandeln": "kokainhandel",
    "kokainhandelns": "kokainhandel",
    "kokainhandels": "kokainhandel",
    "kokainismen": "kokainism",
    "kokainismens": "kokainism",
    "kokainismer": "kokainism",
    "kokainismerna": "kokainism",
    "kokainismernas": "kokainism",
    "kokainismers": "kokainism",
    "kokainisms": "kokainism",
    "kokainligan": "kokainliga",
    "kokainligans": "kokainliga",
    "kokainligas": "kokainliga",
    "kokainlige": "kokainliga",
    "kokainligor": "kokainliga",
    "kokainligorna": "kokainliga",
    "kokainligornas": "kokainliga",
    "kokainligors": "kokainliga",
    "kokains": "kokain",
    "kokakolan": "kokakola",
    "kokakolans": "kokakola",
    "kokakolas": "kokakola",
    "kokakolor": "kokakola",
    "kokakolorna": "kokakola",
    "kokakolornas": "kokakola",
    "kokakolors": "kokakola",
    "kokalvar": "kokalv",
    "kokalvarna": "kokalv",
    "kokalvarnas": "kokalv",
    "kokalvars": "kokalv",
    "kokalven": "kokalv",
    "kokalvens": "kokalv",
    "kokalvs": "kokalv",
    "kokan": "koka",
    "kokande": "koka",
    "kokanden": "kokande",
    "kokandena": "kokande",
    "kokandenas": "kokande",
    "kokandens": "kokande",
    "kokandes": "kokande",
    "kokandet": "kokande",
    "kokandets": "kokande",
    "kokans": "koka",
    "kokapparaten": "kokapparat",
    "kokapparatens": "kokapparat",
    "kokapparater": "kokapparat",
    "kokapparaterna": "kokapparat",
    "kokapparaternas": "kokapparat",
    "kokapparaters": "kokapparat",
    "kokapparats": "kokapparat",
    "kokar": "kokare",
    "kokarden": "kokard",
    "kokardens": "kokard",
    "kokarder": "kokard",
    "kokarderna": "kokard",
    "kokardernas": "kokard",
    "kokarders": "kokard",
    "kokards": "kokard",
    "kokaren": "kokare",
    "kokarens": "kokare",
    "kokares": "kokare",
    "kokarna": "kokare",
    "kokarnas": "kokare",
    "kokarreaktorer": "kokarreaktor",
    "kokarreaktorerna": "kokarreaktor",
    "kokarreaktorernas": "kokarreaktor",
    "kokarreaktorers": "kokarreaktor",
    "kokarreaktorn": "kokarreaktor",
    "kokarreaktorns": "kokarreaktor",
    "kokarreaktors": "kokarreaktor",
    "kokas": "koka",
    "kokat": "koka",
    "kokats": "koka",
    "kokbarometern": "kokbarometer",
    "kokbarometerns": "kokbarometer",
    "kokbarometers": "kokbarometer",
    "kokbarometrar": "kokbarometer",
    "kokbarometrarna": "kokbarometer",
    "kokbarometrarnas": "kokbarometer",
    "kokbarometrars": "kokbarometer",
    "kokboken": "kokbok",
    "kokbokens": "kokbok",
    "kokboks": "kokbok",
    "kokboksstölden": "kokboksstöld",
    "kokboksstöldens": "kokboksstöld",
    "kokboksstölder": "kokboksstöld",
    "kokboksstölderna": "kokboksstöld",
    "kokboksstöldernas": "kokboksstöld",
    "kokboksstölders": "kokboksstöld",
    "kokboksstölds": "kokboksstöld",
    "kokböcker": "kokbok",
    "kokböckerna": "kokbok",
    "kokböckernas": "kokbok",
    "kokböckers": "kokbok",
    "koke": "koka",
    "koken": "kok",
    "kokens": "kok",
    "koker": "koka",
    "kokerier": "kokeri",
    "kokerierna": "kokeri",
    "kokeriernas": "kokeri",
    "kokeriers": "kokeri",
    "kokeriet": "kokeri",
    "kokeriets": "kokeri",
    "kokeris": "kokeri",
    "kokerit": "kokeri",
    "kokerits": "kokeri",
    "kokerskan": "kokerska",
    "kokerskans": "kokerska",
    "kokerskas": "kokerska",
    "kokerske": "kokerska",
    "kokerskor": "kokerska",
    "kokerskorna": "kokerska",
    "kokerskornas": "kokerska",
    "kokerskors": "kokerska",
    "kokes": "koka",
    "koket": "kok",
    "kokets": "kok",
    "koketta": "kokett",
    "kokettare": "kokett",
    "kokettares": "kokett",
    "kokettas": "kokett",
    "kokettast": "kokett",
    "kokettaste": "kokett",
    "kokettastes": "kokett",
    "kokettasts": "kokett",
    "kokette": "kokett",
    "koketten": "kokett",
    "kokettens": "kokett",
    "koketter": "kokett",
    "koketterade": "kokettera",
    "koketterades": "kokettera",
    "koketterande": "kokettera",
    "koketteranden": "koketterande",
    "koketterandena": "koketterande",
    "koketterandenas": "koketterande",
    "koketterandens": "koketterande",
    "koketterandes": "koketterande",
    "koketterandet": "koketterande",
    "koketterandets": "koketterande",
    "koketterar": "kokettera",
    "koketteras": "kokettera",
    "koketterat": "kokettera",
    "koketterats": "kokettera",
    "koketterier": "koketteri",
    "koketterierna": "koketteri",
    "koketteriernas": "koketteri",
    "koketteriers": "koketteri",
    "koketteriet": "koketteri",
    "koketteriets": "koketteri",
    "koketteringar": "kokettering",
    "koketteringarna": "kokettering",
    "koketteringarnas": "kokettering",
    "koketteringars": "kokettering",
    "koketteringen": "kokettering",
    "koketteringens": "kokettering",
    "koketterings": "kokettering",
    "koketteris": "koketteri",
    "koketterit": "koketteri",
    "koketterits": "koketteri",
    "koketterna": "kokett",
    "koketternas": "kokett",
    "koketters": "kokett",
    "kokettes": "kokett",
    "kokettheten": "koketthet",
    "koketthetens": "koketthet",
    "koketthets": "koketthet",
    "koketts": "kokett",
    "kokgropar": "kokgrop",
    "kokgroparna": "kokgrop",
    "kokgroparnas": "kokgrop",
    "kokgropars": "kokgrop",
    "kokgropen": "kokgrop",
    "kokgropens": "kokgrop",
    "kokgrops": "kokgrop",
    "kokheta": "kokhet",
    "kokhetare": "kokhet",
    "kokhetares": "kokhet",
    "kokhetas": "kokhet",
    "kokhetast": "kokhet",
    "kokhetaste": "kokhet",
    "kokhetastes": "kokhet",
    "kokhetasts": "kokhet",
    "kokhete": "kokhet",
    "kokhetes": "kokhet",
    "kokhets": "kokhet",
    "kokhett": "kokhet",
    "kokhetts": "kokhet",
    "kokillen": "kokill",
    "kokillens": "kokill",
    "kokiller": "kokill",
    "kokillerna": "kokill",
    "kokillernas": "kokill",
    "kokillers": "kokill",
    "kokills": "kokill",
    "kokkaffen": "kokkaffe",
    "kokkaffena": "kokkaffe",
    "kokkaffenas": "kokkaffe",
    "kokkaffens": "kokkaffe",
    "kokkaffes": "kokkaffe",
    "kokkaffet": "kokkaffe",
    "kokkaffets": "kokkaffe",
    "kokkonsten": "kokkonst",
    "kokkonstens": "kokkonst",
    "kokkonsts": "kokkonst",
    "kokkorvar": "kokkorv",
    "kokkorvarna": "kokkorv",
    "kokkorvarnas": "kokkorv",
    "kokkorvars": "kokkorv",
    "kokkorven": "kokkorv",
    "kokkorvens": "kokkorv",
    "kokkorvs": "kokkorv",
    "kokkärlen": "kokkärl",
    "kokkärlens": "kokkärl",
    "kokkärlet": "kokkärl",
    "kokkärlets": "kokkärl",
    "kokkärls": "kokkärl",
    "kokköttet": "kokkött",
    "kokköttets": "kokkött",
    "kokkötts": "kokkött",
    "koklåd": "koklåda",
    "koklådan": "koklåda",
    "koklådans": "koklåda",
    "koklådas": "koklåda",
    "koklåde": "koklåda",
    "koklådor": "koklåda",
    "koklådorna": "koklåda",
    "koklådornas": "koklåda",
    "koklådors": "koklåda",
    "koklåds": "koklåda",
    "kokmalde": "kokmald",
    "kokmaldes": "kokmald",
    "kokmalds": "kokmald",
    "kokmalt": "kokmald",
    "kokmalts": "kokmald",
    "kokningar": "kokning",
    "kokningarna": "kokning",
    "kokningarnas": "kokning",
    "kokningars": "kokning",
    "kokningen": "kokning",
    "kokningens": "kokning",
    "koknings": "kokning",
    "kokongen": "kokong",
    "kokongens": "kokong",
    "kokonger": "kokong",
    "kokongerna": "kokong",
    "kokongernas": "kokong",
    "kokongers": "kokong",
    "kokongs": "kokong",
    "kokopporna": "kokoppor",
    "kokoppornas": "kokoppor",
    "kokoppors": "kokoppor",
    "kokopps": "kokoppor",
    "kokor": "koka",
    "kokorna": "koka",
    "kokornas": "koka",
    "kokors": "koka",
    "kokosbollar": "kokosboll",
    "kokosbollarna": "kokosboll",
    "kokosbollarnas": "kokosboll",
    "kokosbollars": "kokosboll",
    "kokosbollen": "kokosboll",
    "kokosbollens": "kokosboll",
    "kokosbolls": "kokosboll",
    "kokosen": "kokos",
    "kokosens": "kokos",
    "kokosfettet": "kokosfett",
    "kokosfettets": "kokosfett",
    "kokosfetts": "kokosfett",
    "kokosfibern": "kokosfiber",
    "kokosfiberns": "kokosfiber",
    "kokosfibers": "kokosfiber",
    "kokosfibrer": "kokosfiber",
    "kokosfibrerna": "kokosfiber",
    "kokosfibrernas": "kokosfiber",
    "kokosfibrers": "kokosfiber",
    "kokoskak": "kokoskaka",
    "kokoskakan": "kokoskaka",
    "kokoskakans": "kokoskaka",
    "kokoskakas": "kokoskaka",
    "kokoskake": "kokoskaka",
    "kokoskakor": "kokoskaka",
    "kokoskakorna": "kokoskaka",
    "kokoskakornas": "kokoskaka",
    "kokoskakors": "kokoskaka",
    "kokoskaks": "kokoskaka",
    "kokosmatt": "kokosmatta",
    "kokosmattan": "kokosmatta",
    "kokosmattans": "kokosmatta",
    "kokosmattas": "kokosmatta",
    "kokosmatte": "kokosmatta",
    "kokosmattor": "kokosmatta",
    "kokosmattorna": "kokosmatta",
    "kokosmattornas": "kokosmatta",
    "kokosmattors": "kokosmatta",
    "kokosmatts": "kokosmatta",
    "kokosmjölken": "kokosmjölk",
    "kokosmjölkens": "kokosmjölk",
    "kokosmjölks": "kokosmjölk",
    "kokosnöten": "kokosnöt",
    "kokosnötens": "kokosnöt",
    "kokosnöts": "kokosnöt",
    "kokosnötter": "kokosnöt",
    "kokosnötterna": "kokosnöt",
    "kokosnötternas": "kokosnöt",
    "kokosnötters": "kokosnöt",
    "kokospalmen": "kokospalm",
    "kokospalmens": "kokospalm",
    "kokospalmer": "kokospalm",
    "kokospalmerna": "kokospalm",
    "kokospalmernas": "kokospalm",
    "kokospalmers": "kokospalm",
    "kokospalms": "kokospalm",
    "kokotten": "kokott",
    "kokottens": "kokott",
    "kokotter": "kokott",
    "kokotterna": "kokott",
    "kokotternas": "kokott",
    "kokotters": "kokott",
    "kokotts": "kokott",
    "kokplatt": "kokplatta",
    "kokplattan": "kokplatta",
    "kokplattans": "kokplatta",
    "kokplattas": "kokplatta",
    "kokplatte": "kokplatta",
    "kokplattor": "kokplatta",
    "kokplattorna": "kokplatta",
    "kokplattornas": "kokplatta",
    "kokplattors": "kokplatta",
    "kokplatts": "kokplatta",
    "kokpunkten": "kokpunkt",
    "kokpunktens": "kokpunkt",
    "kokpunkter": "kokpunkt",
    "kokpunkterna": "kokpunkt",
    "kokpunkternas": "kokpunkt",
    "kokpunkters": "kokpunkt",
    "kokpunkts": "kokpunkt",
    "koks": "koka",
    "koksade": "koksa",
    "koksades": "koksa",
    "koksaltet": "koksalt",
    "koksaltets": "koksalt",
    "koksalts": "koksalt",
    "koksande": "koksa",
    "koksanden": "koksande",
    "koksandena": "koksande",
    "koksandenas": "koksande",
    "koksandens": "koksande",
    "koksandes": "koksande",
    "koksandet": "koksande",
    "koksandets": "koksande",
    "koksar": "koksa",
    "koksas": "koksa",
    "koksat": "koksa",
    "koksats": "koksa",
    "koksen": "koks",
    "koksens": "koks",
    "koksgråa": "koksgrå",
    "koksgråare": "koksgrå",
    "koksgråares": "koksgrå",
    "koksgråas": "koksgrå",
    "koksgråast": "koksgrå",
    "koksgråaste": "koksgrå",
    "koksgråastes": "koksgrå",
    "koksgråasts": "koksgrå",
    "koksgråe": "koksgrå",
    "koksgråes": "koksgrå",
    "koksgrås": "koksgrå",
    "koksgrått": "koksgrå",
    "koksgråtts": "koksgrå",
    "kokt": "koka",
    "kokta": "kokt",
    "koktare": "kokt",
    "koktares": "kokt",
    "koktas": "kokt",
    "koktast": "kokt",
    "koktaste": "kokt",
    "koktastes": "kokt",
    "koktasts": "kokt",
    "kokte": "kokt",
    "koktes": "kokt",
    "koktiden": "koktid",
    "koktidens": "koktid",
    "koktider": "koktid",
    "koktiderna": "koktid",
    "koktidernas": "koktid",
    "koktiders": "koktid",
    "koktids": "koktid",
    "kokts": "kokt",
    "kokvagnar": "kokvagn",
    "kokvagnarna": "kokvagn",
    "kokvagnarnas": "kokvagn",
    "kokvagnars": "kokvagn",
    "kokvagnen": "kokvagn",
    "kokvagnens": "kokvagn",
    "kokvagns": "kokvagn",
    "kokvrån": "kokvrå",
    "kokvråns": "kokvrå",
    "kokvrår": "kokvrå",
    "kokvrårna": "kokvrå",
    "kokvrårnas": "kokvrå",
    "kokvrårs": "kokvrå",
    "kokvrås": "kokvrå",
    "kol": "kola",
    "kol-14-laboratorie": "kol-14-laboratorium",
    "kol-14-laboratorier": "kol-14-laboratorium",
    "kol-14-laboratorierna": "kol-14-laboratorium",
    "kol-14-laboratoriernas": "kol-14-laboratorium",
    "kol-14-laboratoriers": "kol-14-laboratorium",
    "kol-14-laboratoriet": "kol-14-laboratorium",
    "kol-14-laboratoriets": "kol-14-laboratorium",
    "kol-14-laboratoriums": "kol-14-laboratorium",
    "kol-14-metoden": "kol-14-metod",
    "kol-14-metodens": "kol-14-metod",
    "kol-14-metods": "kol-14-metod",
    "kol-14-s": "kol-14",
    "kol-14:s": "kol-14",
    "kolad": "kola",
    "kolade": "kola",
    "kolades": "kola",
    "kolads": "kola",
    "kolan": "kola",
    "kolande": "kola",
    "kolanden": "kolande",
    "kolandena": "kolande",
    "kolandenas": "kolande",
    "kolandens": "kolande",
    "kolandes": "kolande",
    "kolandet": "kolande",
    "kolandets": "kolande",
    "kolans": "kola",
    "kolar": "kolare",
    "kolaren": "kolare",
    "kolarens": "kolare",
    "kolares": "kolare",
    "kolarna": "kolare",
    "kolarnas": "kolare",
    "kolartron": "kolartro",
    "kolartrons": "kolartro",
    "kolartros": "kolartro",
    "kolas": "kola",
    "kolat": "kola",
    "kolatomen": "kolatom",
    "kolatomens": "kolatom",
    "kolatomer": "kolatom",
    "kolatomerna": "kolatom",
    "kolatomernas": "kolatom",
    "kolatomers": "kolatom",
    "kolatoms": "kolatom",
    "kolaträden": "kolaträd",
    "kolaträdens": "kolaträd",
    "kolaträdet": "kolaträd",
    "kolaträdets": "kolaträd",
    "kolaträds": "kolaträd",
    "kolats": "kola",
    "kolbitar": "kolbit",
    "kolbitarna": "kolbit",
    "kolbitarnas": "kolbit",
    "kolbitars": "kolbit",
    "kolbiten": "kolbit",
    "kolbitens": "kolbit",
    "kolbits": "kolbit",
    "kolborst": "kolborste",
    "kolborstar": "kolborste",
    "kolborstarna": "kolborste",
    "kolborstarnas": "kolborste",
    "kolborstars": "kolborste",
    "kolborsten": "kolborste",
    "kolborstens": "kolborste",
    "kolborstes": "kolborste",
    "kolbottens": "kolbotten",
    "kolbottnar": "kolbotten",
    "kolbottnarna": "kolbotten",
    "kolbottnarnas": "kolbotten",
    "kolbottnars": "kolbotten",
    "kolbottnen": "kolbotten",
    "kolbottnens": "kolbotten",
    "kolboxar": "kolbox",
    "kolboxarna": "kolbox",
    "kolboxarnas": "kolbox",
    "kolboxars": "kolbox",
    "kolboxen": "kolbox",
    "kolboxens": "kolbox",
    "kolbriketten": "kolbrikett",
    "kolbrikettens": "kolbrikett",
    "kolbriketter": "kolbrikett",
    "kolbriketterna": "kolbrikett",
    "kolbriketternas": "kolbrikett",
    "kolbriketters": "kolbrikett",
    "kolbriketts": "kolbrikett",
    "kolbull": "kolbulle",
    "kolbullar": "kolbulle",
    "kolbullarna": "kolbulle",
    "kolbullarnas": "kolbulle",
    "kolbullars": "kolbulle",
    "kolbullen": "kolbulle",
    "kolbullens": "kolbulle",
    "kolbulles": "kolbulle",
    "kolbulls": "kolbulle",
    "kolbärar": "kolbärare",
    "kolbäraren": "kolbärare",
    "kolbärarens": "kolbärare",
    "kolbärares": "kolbärare",
    "kolbärarna": "kolbärare",
    "kolbärarnas": "kolbärare",
    "kolchosen": "kolchos",
    "kolchosens": "kolchos",
    "kolchoser": "kolchos",
    "kolchoserna": "kolchos",
    "kolchosernas": "kolchos",
    "kolchosers": "kolchos",
    "koldioxiden": "koldioxid",
    "koldioxidens": "koldioxid",
    "koldioxider": "koldioxid",
    "koldioxiderna": "koldioxid",
    "koldioxidernas": "koldioxid",
    "koldioxiders": "koldioxid",
    "koldioxidfria": "koldioxidfri",
    "koldioxidfriare": "koldioxidfri",
    "koldioxidfriares": "koldioxidfri",
    "koldioxidfrias": "koldioxidfri",
    "koldioxidfriast": "koldioxidfri",
    "koldioxidfriaste": "koldioxidfri",
    "koldioxidfriastes": "koldioxidfri",
    "koldioxidfriasts": "koldioxidfri",
    "koldioxidfrie": "koldioxidfri",
    "koldioxidfries": "koldioxidfri",
    "koldioxidfris": "koldioxidfri",
    "koldioxidfritt": "koldioxidfri",
    "koldioxidfritts": "koldioxidfri",
    "koldioxidhalten": "koldioxidhalt",
    "koldioxidhaltens": "koldioxidhalt",
    "koldioxidhalter": "koldioxidhalt",
    "koldioxidhalterna": "koldioxidhalt",
    "koldioxidhalternas": "koldioxidhalt",
    "koldioxidhalters": "koldioxidhalt",
    "koldioxidhalts": "koldioxidhalt",
    "koldioxidkanalen": "koldioxidkanal",
    "koldioxidkanalens": "koldioxidkanal",
    "koldioxidkanaler": "koldioxidkanal",
    "koldioxidkanalerna": "koldioxidkanal",
    "koldioxidkanalernas": "koldioxidkanal",
    "koldioxidkanalers": "koldioxidkanal",
    "koldioxidkanals": "koldioxidkanal",
    "koldioxidlagringen": "koldioxidlagring",
    "koldioxidlagringens": "koldioxidlagring",
    "koldioxidlagrings": "koldioxidlagring",
    "koldioxidmolekylen": "koldioxidmolekyl",
    "koldioxidmolekylens": "koldioxidmolekyl",
    "koldioxidmolekyler": "koldioxidmolekyl",
    "koldioxidmolekylerna": "koldioxidmolekyl",
    "koldioxidmolekylernas": "koldioxidmolekyl",
    "koldioxidmolekylers": "koldioxidmolekyl",
    "koldioxidmolekyls": "koldioxidmolekyl",
    "koldioxids": "koldioxid",
    "koldioxidutsläppen": "koldioxidutsläpp",
    "koldioxidutsläppens": "koldioxidutsläpp",
    "koldioxidutsläppet": "koldioxidutsläpp",
    "koldioxidutsläppets": "koldioxidutsläpp",
    "koldioxidutsläpps": "koldioxidutsläpp",
    "koldisulfiden": "koldisulfid",
    "koldisulfidens": "koldisulfid",
    "koldisulfids": "koldisulfid",
    "koleldar": "koleld",
    "koleldarna": "koleld",
    "koleldarnas": "koleld",
    "koleldars": "koleld",
    "kolelden": "koleld",
    "koleldens": "koleld",
    "kolelds": "koleld",
    "kolen": "kol",
    "kolens": "kol",
    "kolerabakterien": "kolerabakterie",
    "kolerabakteriens": "kolerabakterie",
    "kolerabakterier": "kolerabakterie",
    "kolerabakterierna": "kolerabakterie",
    "kolerabakteriernas": "kolerabakterie",
    "kolerabakteriers": "kolerabakterie",
    "kolerabakteries": "kolerabakterie",
    "koleraflagg": "koleraflagga",
    "koleraflaggan": "koleraflagga",
    "koleraflaggans": "koleraflagga",
    "koleraflaggas": "koleraflagga",
    "koleraflagge": "koleraflagga",
    "koleraflaggor": "koleraflagga",
    "koleraflaggorna": "koleraflagga",
    "koleraflaggornas": "koleraflagga",
    "koleraflaggors": "koleraflagga",
    "koleraflaggs": "koleraflagga",
    "kolerakyrkogårdar": "kolerakyrkogård",
    "kolerakyrkogårdarna": "kolerakyrkogård",
    "kolerakyrkogårdarnas": "kolerakyrkogård",
    "kolerakyrkogårdars": "kolerakyrkogård",
    "kolerakyrkogården": "kolerakyrkogård",
    "kolerakyrkogårdens": "kolerakyrkogård",
    "kolerakyrkogårds": "kolerakyrkogård",
    "koleran": "kolera",
    "kolerans": "kolera",
    "koleras": "kolera",
    "kolerikern": "koleriker",
    "kolerikerna": "koleriker",
    "kolerikernas": "koleriker",
    "kolerikerns": "koleriker",
    "kolerikers": "koleriker",
    "koleriska": "kolerisk",
    "koleriskare": "kolerisk",
    "koleriskares": "kolerisk",
    "koleriskas": "kolerisk",
    "koleriskast": "kolerisk",
    "koleriskaste": "kolerisk",
    "koleriskastes": "kolerisk",
    "koleriskasts": "kolerisk",
    "koleriske": "kolerisk",
    "koleriskes": "kolerisk",
    "kolerisks": "kolerisk",
    "koleriskt": "kolerisk",
    "koleriskts": "kolerisk",
    "kolesterolen": "kolesterol",
    "kolesterolens": "kolesterol",
    "kolesterolet": "kolesterol",
    "kolesterolets": "kolesterol",
    "kolesterols": "kolesterol",
    "kolet": "kol",
    "kolets": "kol",
    "kolfilterna": "kolfilter",
    "kolfilternas": "kolfilter",
    "kolfilters": "kolfilter",
    "kolfiltren": "kolfilter",
    "kolfiltrens": "kolfilter",
    "kolfiltret": "kolfilter",
    "kolfiltrets": "kolfilter",
    "kolflötsen": "kolflöts",
    "kolflötsens": "kolflöts",
    "kolflötser": "kolflöts",
    "kolflötserna": "kolflöts",
    "kolflötsernas": "kolflöts",
    "kolflötsers": "kolflöts",
    "kolföreningar": "kolförening",
    "kolföreningarna": "kolförening",
    "kolföreningarnas": "kolförening",
    "kolföreningars": "kolförening",
    "kolföreningen": "kolförening",
    "kolföreningens": "kolförening",
    "kolförenings": "kolförening",
    "kolgruv": "kolgruva",
    "kolgruvan": "kolgruva",
    "kolgruvans": "kolgruva",
    "kolgruvas": "kolgruva",
    "kolgruve": "kolgruva",
    "kolgruveolyck": "kolgruveolycka",
    "kolgruveolyckan": "kolgruveolycka",
    "kolgruveolyckans": "kolgruveolycka",
    "kolgruveolyckas": "kolgruveolycka",
    "kolgruveolycke": "kolgruveolycka",
    "kolgruveolyckor": "kolgruveolycka",
    "kolgruveolyckorna": "kolgruveolycka",
    "kolgruveolyckornas": "kolgruveolycka",
    "kolgruveolyckors": "kolgruveolycka",
    "kolgruveolycks": "kolgruveolycka",
    "kolgruvor": "kolgruva",
    "kolgruvorna": "kolgruva",
    "kolgruvornas": "kolgruva",
    "kolgruvors": "kolgruva",
    "kolgruvs": "kolgruva",
    "kolhalten": "kolhalt",
    "kolhaltens": "kolhalt",
    "kolhalter": "kolhalt",
    "kolhalterna": "kolhalt",
    "kolhalternas": "kolhalt",
    "kolhalters": "kolhalt",
    "kolhaltiga": "kolhaltig",
    "kolhaltigare": "kolhaltig",
    "kolhaltigares": "kolhaltig",
    "kolhaltigas": "kolhaltig",
    "kolhaltigast": "kolhaltig",
    "kolhaltigaste": "kolhaltig",
    "kolhaltigastes": "kolhaltig",
    "kolhaltigasts": "kolhaltig",
    "kolhaltige": "kolhaltig",
    "kolhaltiges": "kolhaltig",
    "kolhaltigs": "kolhaltig",
    "kolhaltigt": "kolhaltig",
    "kolhaltigts": "kolhaltig",
    "kolhalts": "kolhalt",
    "kolhydraten": "kolhydrat",
    "kolhydratens": "kolhydrat",
    "kolhydrater": "kolhydrat",
    "kolhydraterna": "kolhydrat",
    "kolhydraternas": "kolhydrat",
    "kolhydraters": "kolhydrat",
    "kolhydratet": "kolhydrat",
    "kolhydratets": "kolhydrat",
    "kolhydrats": "kolhydrat",
    "kolhämtar": "kolhämtare",
    "kolhämtaren": "kolhämtare",
    "kolhämtarens": "kolhämtare",
    "kolhämtares": "kolhämtare",
    "kolhämtarna": "kolhämtare",
    "kolhämtarnas": "kolhämtare",
    "kolhögar": "kolhög",
    "kolhögarna": "kolhög",
    "kolhögarnas": "kolhög",
    "kolhögars": "kolhög",
    "kolhögen": "kolhög",
    "kolhögens": "kolhög",
    "kolhögs": "kolhög",
    "kolibakterien": "kolibakterie",
    "kolibakteriens": "kolibakterie",
    "kolibakterier": "kolibakterie",
    "kolibakterierna": "kolibakterie",
    "kolibakteriernas": "kolibakterie",
    "kolibakteriers": "kolibakterie",
    "kolibakteries": "kolibakterie",
    "kolibrier": "kolibri",
    "kolibrierna": "kolibri",
    "kolibriernas": "kolibri",
    "kolibriers": "kolibri",
    "kolibrin": "kolibri",
    "kolibrins": "kolibri",
    "kolibris": "kolibri",
    "kolifejet": "kolifej",
    "kolifejets": "kolifej",
    "kolifejs": "kolifej",
    "kolikanfallen": "kolikanfall",
    "kolikanfallens": "kolikanfall",
    "kolikanfallet": "kolikanfall",
    "kolikanfallets": "kolikanfall",
    "kolikanfalls": "kolikanfall",
    "koliken": "kolik",
    "kolikens": "kolik",
    "koliks": "kolik",
    "kolingar": "koling",
    "kolingarna": "koling",
    "kolingarnas": "koling",
    "kolingars": "koling",
    "kolingen": "koling",
    "kolingens": "koling",
    "kolings": "koling",
    "kolisotopen": "kolisotop",
    "kolisotopens": "kolisotop",
    "kolisotoper": "kolisotop",
    "kolisotoperna": "kolisotop",
    "kolisotopernas": "kolisotop",
    "kolisotopers": "kolisotop",
    "kolisotops": "kolisotop",
    "koliten": "kolit",
    "kolitens": "kolit",
    "kolits": "kolit",
    "kolj": "kolja",
    "koljan": "kolja",
    "koljans": "kolja",
    "koljas": "kolja",
    "kolje": "kolja",
    "koljor": "kolja",
    "koljorna": "kolja",
    "koljornas": "kolja",
    "koljors": "kolja",
    "koljs": "kolja",
    "koljéer": "koljé",
    "koljéerna": "koljé",
    "koljéernas": "koljé",
    "koljéers": "koljé",
    "koljén": "koljé",
    "koljéns": "koljé",
    "koljés": "koljé",
    "kolk": "kolka",
    "kolkad": "kolka",
    "kolkade": "kolka",
    "kolkades": "kolka",
    "kolkads": "kolka",
    "kolkande": "kolka",
    "kolkanden": "kolkande",
    "kolkandena": "kolkande",
    "kolkandenas": "kolkande",
    "kolkandens": "kolkande",
    "kolkandes": "kolkande",
    "kolkandet": "kolkande",
    "kolkandets": "kolkande",
    "kolkar": "kolka",
    "kolkas": "kolka",
    "kolkat": "kolka",
    "kolkats": "kolka",
    "koll": "kolla",
    "kollaberade": "kollabera",
    "kollaberades": "kollabera",
    "kollaberande": "kollabera",
    "kollaberanden": "kollaberande",
    "kollaberandena": "kollaberande",
    "kollaberandenas": "kollaberande",
    "kollaberandens": "kollaberande",
    "kollaberandes": "kollaberande",
    "kollaberandet": "kollaberande",
    "kollaberandets": "kollaberande",
    "kollaberar": "kollabera",
    "kollaberas": "kollabera",
    "kollaberat": "kollabera",
    "kollaberats": "kollabera",
    "kollaberingar": "kollabering",
    "kollaberingarna": "kollabering",
    "kollaberingarnas": "kollabering",
    "kollaberingars": "kollabering",
    "kollaberingen": "kollabering",
    "kollaberingens": "kollabering",
    "kollaberings": "kollabering",
    "kollaboratören": "kollaboratör",
    "kollaboratörens": "kollaboratör",
    "kollaboratörer": "kollaboratör",
    "kollaboratörerna": "kollaboratör",
    "kollaboratörernas": "kollaboratör",
    "kollaboratörers": "kollaboratör",
    "kollaboratörs": "kollaboratör",
    "kollaborerade": "kollaborera",
    "kollaborerades": "kollaborera",
    "kollaborerande": "kollaborera",
    "kollaboreranden": "kollaborerande",
    "kollaborerandena": "kollaborerande",
    "kollaborerandenas": "kollaborerande",
    "kollaborerandens": "kollaborerande",
    "kollaborerandes": "kollaborerande",
    "kollaborerandet": "kollaborerande",
    "kollaborerandets": "kollaborerande",
    "kollaborerar": "kollaborera",
    "kollaboreras": "kollaborera",
    "kollaborerat": "kollaborera",
    "kollaborerats": "kollaborera",
    "kollaboreringar": "kollaborering",
    "kollaboreringarna": "kollaborering",
    "kollaboreringarnas": "kollaborering",
    "kollaboreringars": "kollaborering",
    "kollaboreringen": "kollaborering",
    "kollaboreringens": "kollaborering",
    "kollaborerings": "kollaborering",
    "kollad": "kolla",
    "kollade": "kolla",
    "kollades": "kolla",
    "kollads": "kolla",
    "kollagen": "kollage",
    "kollagens": "kollage",
    "kollages": "kollage",
    "kollaget": "kollage",
    "kollagets": "kollage",
    "kollande": "kolla",
    "kollanden": "kollande",
    "kollandena": "kollande",
    "kollandenas": "kollande",
    "kollandens": "kollande",
    "kollandes": "kollande",
    "kollandet": "kollande",
    "kollandets": "kollande",
    "kollaps": "kollapsa",
    "kollapsad": "kollapsa",
    "kollapsade": "kollapsa",
    "kollapsades": "kollapsa",
    "kollapsads": "kollapsa",
    "kollapsande": "kollapsa",
    "kollapsanden": "kollapsande",
    "kollapsandena": "kollapsande",
    "kollapsandenas": "kollapsande",
    "kollapsandens": "kollapsande",
    "kollapsandes": "kollapsande",
    "kollapsandet": "kollapsande",
    "kollapsandets": "kollapsande",
    "kollapsar": "kollapsa",
    "kollapsas": "kollapsa",
    "kollapsat": "kollapsa",
    "kollapsats": "kollapsa",
    "kollapsen": "kollaps",
    "kollapsens": "kollaps",
    "kollapser": "kollaps",
    "kollapserna": "kollaps",
    "kollapsernas": "kollaps",
    "kollapsers": "kollaps",
    "kollar": "kolla",
    "kollarna": "koll",
    "kollarnas": "koll",
    "kollars": "koll",
    "kollas": "kolla",
    "kollasten": "kollast",
    "kollastens": "kollast",
    "kollaster": "kollast",
    "kollasterna": "kollast",
    "kollasternas": "kollast",
    "kollasters": "kollast",
    "kollasts": "kollast",
    "kollat": "kolla",
    "kollationen": "kollation",
    "kollationens": "kollation",
    "kollationer": "kollation",
    "kollationerad": "kollationera",
    "kollationerade": "kollationera",
    "kollationerades": "kollationera",
    "kollationerads": "kollationera",
    "kollationerande": "kollationera",
    "kollationeranden": "kollationerande",
    "kollationerandena": "kollationerande",
    "kollationerandenas": "kollationerande",
    "kollationerandens": "kollationerande",
    "kollationerandes": "kollationerande",
    "kollationerandet": "kollationerande",
    "kollationerandets": "kollationerande",
    "kollationerar": "kollationera",
    "kollationeras": "kollationera",
    "kollationerat": "kollationera",
    "kollationerats": "kollationera",
    "kollationerbara": "kollationerbar",
    "kollationerbarare": "kollationerbar",
    "kollationerbarares": "kollationerbar",
    "kollationerbaras": "kollationerbar",
    "kollationerbarast": "kollationerbar",
    "kollationerbaraste": "kollationerbar",
    "kollationerbarastes": "kollationerbar",
    "kollationerbarasts": "kollationerbar",
    "kollationerbare": "kollationerbar",
    "kollationerbares": "kollationerbar",
    "kollationerbarheten": "kollationerbarhet",
    "kollationerbarhetens": "kollationerbarhet",
    "kollationerbarhets": "kollationerbarhet",
    "kollationerbars": "kollationerbar",
    "kollationerbart": "kollationerbar",
    "kollationerbarts": "kollationerbar",
    "kollationeringar": "kollationering",
    "kollationeringarna": "kollationering",
    "kollationeringarnas": "kollationering",
    "kollationeringars": "kollationering",
    "kollationeringen": "kollationering",
    "kollationeringens": "kollationering",
    "kollationerings": "kollationering",
    "kollationerna": "kollation",
    "kollationernas": "kollation",
    "kollationers": "kollation",
    "kollations": "kollation",
    "kollats": "kolla",
    "kollegan": "kollega",
    "kollegans": "kollega",
    "kollegas": "kollega",
    "kolleger": "kollega",
    "kollegerna": "kollega",
    "kollegernas": "kollega",
    "kollegers": "kollega",
    "kollegiala": "kollegial",
    "kollegialare": "kollegial",
    "kollegialares": "kollegial",
    "kollegialas": "kollegial",
    "kollegialast": "kollegial",
    "kollegialaste": "kollegial",
    "kollegialastes": "kollegial",
    "kollegialasts": "kollegial",
    "kollegiale": "kollegial",
    "kollegiales": "kollegial",
    "kollegialiteten": "kollegialitet",
    "kollegialitetens": "kollegialitet",
    "kollegialiteter": "kollegialitet",
    "kollegialiteterna": "kollegialitet",
    "kollegialiteternas": "kollegialitet",
    "kollegialiteters": "kollegialitet",
    "kollegialitets": "kollegialitet",
    "kollegials": "kollegial",
    "kollegialt": "kollegial",
    "kollegialts": "kollegial",
    "kollegie": "kollegium",
    "kollegieblocken": "kollegieblock",
    "kollegieblockens": "kollegieblock",
    "kollegieblocket": "kollegieblock",
    "kollegieblockets": "kollegieblock",
    "kollegieblocks": "kollegieblock",
    "kollegier": "kollegium",
    "kollegierna": "kollegium",
    "kollegiernas": "kollegium",
    "kollegiers": "kollegium",
    "kollegiet": "kollegium",
    "kollegiets": "kollegium",
    "kollegiums": "kollegium",
    "kollegor": "kollega",
    "kollegorna": "kollega",
    "kollegornas": "kollega",
    "kollegors": "kollega",
    "kollektan": "kollekta",
    "kollektans": "kollekta",
    "kollektas": "kollekta",
    "kollekten": "kollekt",
    "kollektens": "kollekt",
    "kollekter": "kollekt",
    "kollekterna": "kollekt",
    "kollekternas": "kollekt",
    "kollekters": "kollekt",
    "kollektionen": "kollektion",
    "kollektionens": "kollektion",
    "kollektioner": "kollektion",
    "kollektionerna": "kollektion",
    "kollektionernas": "kollektion",
    "kollektioners": "kollektion",
    "kollektions": "kollektion",
    "kollektiva": "kollektiv",
    "kollektivanslutningar": "kollektivanslutning",
    "kollektivanslutningarna": "kollektivanslutning",
    "kollektivanslutningarnas": "kollektivanslutning",
    "kollektivanslutningars": "kollektivanslutning",
    "kollektivanslutningen": "kollektivanslutning",
    "kollektivanslutningens": "kollektivanslutning",
    "kollektivanslutnings": "kollektivanslutning",
    "kollektivanställde": "kollektivanställd",
    "kollektivanställdes": "kollektivanställd",
    "kollektivanställds": "kollektivanställd",
    "kollektivanställningar": "kollektivanställning",
    "kollektivanställningarna": "kollektivanställning",
    "kollektivanställningarnas": "kollektivanställning",
    "kollektivanställningars": "kollektivanställning",
    "kollektivanställningen": "kollektivanställning",
    "kollektivanställningens": "kollektivanställning",
    "kollektivanställnings": "kollektivanställning",
    "kollektivanställt": "kollektivanställd",
    "kollektivanställts": "kollektivanställd",
    "kollektivare": "kollektiv",
    "kollektivares": "kollektiv",
    "kollektivas": "kollektiv",
    "kollektivast": "kollektiv",
    "kollektivaste": "kollektiv",
    "kollektivastes": "kollektiv",
    "kollektivasts": "kollektiv",
    "kollektivavtalen": "kollektivavtal",
    "kollektivavtalens": "kollektivavtal",
    "kollektivavtalet": "kollektivavtal",
    "kollektivavtalets": "kollektivavtal",
    "kollektivavtals": "kollektivavtal",
    "kollektive": "kollektiv",
    "kollektiven": "kollektiv",
    "kollektivens": "kollektiv",
    "kollektives": "kollektiv",
    "kollektivet": "kollektiv",
    "kollektivets": "kollektiv",
    "kollektivfilen": "kollektivfil",
    "kollektivfilens": "kollektivfil",
    "kollektivfiler": "kollektivfil",
    "kollektivfilerna": "kollektivfil",
    "kollektivfilernas": "kollektivfil",
    "kollektivfilers": "kollektivfil",
    "kollektivfils": "kollektivfil",
    "kollektivförsäkringar": "kollektivförsäkring",
    "kollektivförsäkringarna": "kollektivförsäkring",
    "kollektivförsäkringarnas": "kollektivförsäkring",
    "kollektivförsäkringars": "kollektivförsäkring",
    "kollektivförsäkringen": "kollektivförsäkring",
    "kollektivförsäkringens": "kollektivförsäkring",
    "kollektivförsäkrings": "kollektivförsäkring",
    "kollektivhusen": "kollektivhus",
    "kollektivhusens": "kollektivhus",
    "kollektivhuset": "kollektivhus",
    "kollektivhusets": "kollektivhus",
    "kollektiviserad": "kollektivisera",
    "kollektiviserade": "kollektivisera",
    "kollektiviserades": "kollektivisera",
    "kollektiviserads": "kollektivisera",
    "kollektiviserande": "kollektivisera",
    "kollektiviseranden": "kollektiviserande",
    "kollektiviserandena": "kollektiviserande",
    "kollektiviserandenas": "kollektiviserande",
    "kollektiviserandens": "kollektiviserande",
    "kollektiviserandes": "kollektiviserande",
    "kollektiviserandet": "kollektiviserande",
    "kollektiviserandets": "kollektiviserande",
    "kollektiviserar": "kollektivisera",
    "kollektiviseras": "kollektivisera",
    "kollektiviserat": "kollektivisera",
    "kollektiviserats": "kollektivisera",
    "kollektiviserbara": "kollektiviserbar",
    "kollektiviserbarare": "kollektiviserbar",
    "kollektiviserbarares": "kollektiviserbar",
    "kollektiviserbaras": "kollektiviserbar",
    "kollektiviserbarast": "kollektiviserbar",
    "kollektiviserbaraste": "kollektiviserbar",
    "kollektiviserbarastes": "kollektiviserbar",
    "kollektiviserbarasts": "kollektiviserbar",
    "kollektiviserbare": "kollektiviserbar",
    "kollektiviserbares": "kollektiviserbar",
    "kollektiviserbarheten": "kollektiviserbarhet",
    "kollektiviserbarhetens": "kollektiviserbarhet",
    "kollektiviserbarhets": "kollektiviserbarhet",
    "kollektiviserbars": "kollektiviserbar",
    "kollektiviserbart": "kollektiviserbar",
    "kollektiviserbarts": "kollektiviserbar",
    "kollektiviseringar": "kollektivisering",
    "kollektiviseringarna": "kollektivisering",
    "kollektiviseringarnas": "kollektivisering",
    "kollektiviseringars": "kollektivisering",
    "kollektiviseringen": "kollektivisering",
    "kollektiviseringens": "kollektivisering",
    "kollektiviserings": "kollektivisering",
    "kollektivismen": "kollektivism",
    "kollektivismens": "kollektivism",
    "kollektivismer": "kollektivism",
    "kollektivismerna": "kollektivism",
    "kollektivismernas": "kollektivism",
    "kollektivismers": "kollektivism",
    "kollektivisms": "kollektivism",
    "kollektivistiska": "kollektivistisk",
    "kollektivistiskas": "kollektivistisk",
    "kollektivistiske": "kollektivistisk",
    "kollektivistiskes": "kollektivistisk",
    "kollektivistisks": "kollektivistisk",
    "kollektivistiskt": "kollektivistisk",
    "kollektivistiskts": "kollektivistisk",
    "kollektivjordbruken": "kollektivjordbruk",
    "kollektivjordbrukens": "kollektivjordbruk",
    "kollektivjordbruket": "kollektivjordbruk",
    "kollektivjordbrukets": "kollektivjordbruk",
    "kollektivjordbruks": "kollektivjordbruk",
    "kollektivnoten": "kollektivnot",
    "kollektivnotens": "kollektivnot",
    "kollektivnoter": "kollektivnot",
    "kollektivnoterna": "kollektivnot",
    "kollektivnoternas": "kollektivnot",
    "kollektivnoters": "kollektivnot",
    "kollektivnots": "kollektivnot",
    "kollektivs": "kollektiv",
    "kollektivt": "kollektiv",
    "kollektivtrafiken": "kollektivtrafik",
    "kollektivtrafikens": "kollektivtrafik",
    "kollektivtrafiks": "kollektivtrafik",
    "kollektivts": "kollektiv",
    "kollektorer": "kollektor",
    "kollektorerna": "kollektor",
    "kollektorernas": "kollektor",
    "kollektorers": "kollektor",
    "kollektorn": "kollektor",
    "kollektorns": "kollektor",
    "kollektors": "kollektor",
    "kollekts": "kollekt",
    "kollen": "koll",
    "kollens": "koll",
    "kollern": "koller",
    "kollerns": "koller",
    "kollers": "koller",
    "kolliderade": "kollidera",
    "kolliderades": "kollidera",
    "kolliderande": "kollidera",
    "kollideranden": "kolliderande",
    "kolliderandena": "kolliderande",
    "kolliderandenas": "kolliderande",
    "kolliderandens": "kolliderande",
    "kolliderandes": "kolliderande",
    "kolliderandet": "kolliderande",
    "kolliderandets": "kolliderande",
    "kolliderar": "kollidera",
    "kollideras": "kollidera",
    "kolliderat": "kollidera",
    "kolliderats": "kollidera",
    "kollideringar": "kollidering",
    "kollideringarna": "kollidering",
    "kollideringarnas": "kollidering",
    "kollideringars": "kollidering",
    "kollideringen": "kollidering",
    "kollideringens": "kollidering",
    "kolliderings": "kollidering",
    "kollin": "kolli",
    "kollina": "kolli",
    "kollinas": "kolli",
    "kollins": "kolli",
    "kollis": "kolli",
    "kollisionen": "kollision",
    "kollisionens": "kollision",
    "kollisioner": "kollision",
    "kollisionerna": "kollision",
    "kollisionernas": "kollision",
    "kollisioners": "kollision",
    "kollisions": "kollision",
    "kollisionsenergien": "kollisionsenergi",
    "kollisionsenergiens": "kollisionsenergi",
    "kollisionsenergin": "kollisionsenergi",
    "kollisionsenergins": "kollisionsenergi",
    "kollisionsenergis": "kollisionsenergi",
    "kollisionskursen": "kollisionskurs",
    "kollisionskursens": "kollisionskurs",
    "kollisionskurser": "kollisionskurs",
    "kollisionskurserna": "kollisionskurs",
    "kollisionskursernas": "kollisionskurs",
    "kollisionskursers": "kollisionskurs",
    "kollisionsskotten": "kollisionsskott",
    "kollisionsskottens": "kollisionsskott",
    "kollisionsskottet": "kollisionsskott",
    "kollisionsskottets": "kollisionsskott",
    "kollisionsskotts": "kollisionsskott",
    "kollit": "kolli",
    "kollits": "kolli",
    "kolloidala": "kolloidal",
    "kolloidalare": "kolloidal",
    "kolloidalares": "kolloidal",
    "kolloidalas": "kolloidal",
    "kolloidalast": "kolloidal",
    "kolloidalaste": "kolloidal",
    "kolloidalastes": "kolloidal",
    "kolloidalasts": "kolloidal",
    "kolloidale": "kolloidal",
    "kolloidales": "kolloidal",
    "kolloidals": "kolloidal",
    "kolloidalt": "kolloidal",
    "kolloidalts": "kolloidal",
    "kolloiden": "kolloid",
    "kolloidens": "kolloid",
    "kolloider": "kolloid",
    "kolloiderna": "kolloid",
    "kolloidernas": "kolloid",
    "kolloiders": "kolloid",
    "kolloids": "kolloid",
    "kollokaten": "kollokat",
    "kollokatens": "kollokat",
    "kollokatet": "kollokat",
    "kollokatets": "kollokat",
    "kollokationen": "kollokation",
    "kollokationens": "kollokation",
    "kollokationer": "kollokation",
    "kollokationerna": "kollokation",
    "kollokationernas": "kollokation",
    "kollokationers": "kollokation",
    "kollokations": "kollokation",
    "kollokats": "kollokat",
    "kollokvie": "kollokvium",
    "kollokvier": "kollokvium",
    "kollokvierna": "kollokvium",
    "kollokviernas": "kollokvium",
    "kollokviers": "kollokvium",
    "kollokviet": "kollokvium",
    "kollokviets": "kollokvium",
    "kollokviums": "kollokvium",
    "kollon": "kollo",
    "kollona": "kollo",
    "kollonas": "kollo",
    "kollons": "kollo",
    "kollos": "kollo",
    "kollot": "kollo",
    "kollots": "kollo",
    "kollriga": "kollrig",
    "kollrigare": "kollrig",
    "kollrigares": "kollrig",
    "kollrigas": "kollrig",
    "kollrigast": "kollrig",
    "kollrigaste": "kollrig",
    "kollrigastes": "kollrig",
    "kollrigasts": "kollrig",
    "kollrige": "kollrig",
    "kollriges": "kollrig",
    "kollrigheten": "kollrighet",
    "kollrighetens": "kollrighet",
    "kollrighets": "kollrighet",
    "kollrigs": "kollrig",
    "kollrigt": "kollrig",
    "kollrigts": "kollrig",
    "kolls": "koll",
    "kollusionen": "kollusion",
    "kollusionens": "kollusion",
    "kollusioner": "kollusion",
    "kollusionerna": "kollusion",
    "kollusionernas": "kollusion",
    "kollusioners": "kollusion",
    "kollusions": "kollusion",
    "kolmen": "kolm",
    "kolmens": "kolm",
    "kolmil": "kolmila",
    "kolmilan": "kolmila",
    "kolmilans": "kolmila",
    "kolmilas": "kolmila",
    "kolmile": "kolmila",
    "kolmilor": "kolmila",
    "kolmilorna": "kolmila",
    "kolmilornas": "kolmila",
    "kolmilors": "kolmila",
    "kolmils": "kolmila",
    "kolmonoxiden": "kolmonoxid",
    "kolmonoxidens": "kolmonoxid",
    "kolmonoxids": "kolmonoxid",
    "kolms": "kolm",
    "kolmårdsmarmorn": "kolmårdsmarmor",
    "kolmårdsmarmorns": "kolmårdsmarmor",
    "kolmårdsmarmors": "kolmårdsmarmor",
    "kolmörka": "kolmörk",
    "kolmörkare": "kolmörk",
    "kolmörkares": "kolmörk",
    "kolmörkas": "kolmörk",
    "kolmörkast": "kolmörk",
    "kolmörkaste": "kolmörk",
    "kolmörkastes": "kolmörk",
    "kolmörkasts": "kolmörk",
    "kolmörke": "kolmörk",
    "kolmörkes": "kolmörk",
    "kolmörks": "kolmörk",
    "kolmörkt": "kolmörk",
    "kolmörkts": "kolmörk",
    "kolnanorören": "kolnanorör",
    "kolnanorörens": "kolnanorör",
    "kolnanoröret": "kolnanorör",
    "kolnanorörets": "kolnanorör",
    "kolnanorörs": "kolnanorör",
    "kolningar": "kolning",
    "kolningarna": "kolning",
    "kolningarnas": "kolning",
    "kolningars": "kolning",
    "kolningen": "kolning",
    "kolningens": "kolning",
    "kolnings": "kolning",
    "kolofonen": "kolofon",
    "kolofonens": "kolofon",
    "kolofoner": "kolofon",
    "kolofonerna": "kolofon",
    "kolofonernas": "kolofon",
    "kolofoners": "kolofon",
    "kolofons": "kolofon",
    "kolokvinten": "kolokvint",
    "kolokvintens": "kolokvint",
    "kolokvinter": "kolokvint",
    "kolokvinterna": "kolokvint",
    "kolokvinternas": "kolokvint",
    "kolokvinters": "kolokvint",
    "kolokvints": "kolokvint",
    "kolonaten": "kolonat",
    "kolonatens": "kolonat",
    "kolonatet": "kolonat",
    "kolonatets": "kolonat",
    "kolonats": "kolonat",
    "kolonen": "kolon",
    "kolonens": "kolon",
    "kolonet": "kolon",
    "kolonets": "kolon",
    "koloniala": "kolonial",
    "kolonialare": "kolonial",
    "kolonialares": "kolonial",
    "kolonialarméer": "kolonialarmé",
    "kolonialarméerna": "kolonialarmé",
    "kolonialarméernas": "kolonialarmé",
    "kolonialarméers": "kolonialarmé",
    "kolonialarmén": "kolonialarmé",
    "kolonialarméns": "kolonialarmé",
    "kolonialarmés": "kolonialarmé",
    "kolonialas": "kolonial",
    "kolonialast": "kolonial",
    "kolonialaste": "kolonial",
    "kolonialastes": "kolonial",
    "kolonialasts": "kolonial",
    "koloniale": "kolonial",
    "koloniales": "kolonial",
    "kolonialiseringsprocessen": "kolonialiseringsprocess",
    "kolonialiseringsprocessens": "kolonialiseringsprocess",
    "kolonialiseringsprocesser": "kolonialiseringsprocess",
    "kolonialiseringsprocesserna": "kolonialiseringsprocess",
    "kolonialiseringsprocessernas": "kolonialiseringsprocess",
    "kolonialiseringsprocessers": "kolonialiseringsprocess",
    "kolonialismen": "kolonialism",
    "kolonialismens": "kolonialism",
    "kolonialismer": "kolonialism",
    "kolonialismerna": "kolonialism",
    "kolonialismernas": "kolonialism",
    "kolonialismers": "kolonialism",
    "kolonialisms": "kolonialism",
    "kolonialistiska": "kolonialistisk",
    "kolonialistiskas": "kolonialistisk",
    "kolonialistiske": "kolonialistisk",
    "kolonialistiskes": "kolonialistisk",
    "kolonialistisks": "kolonialistisk",
    "kolonialistiskt": "kolonialistisk",
    "kolonialistiskts": "kolonialistisk",
    "kolonialkrigen": "kolonialkrig",
    "kolonialkrigens": "kolonialkrig",
    "kolonialkriget": "kolonialkrig",
    "kolonialkrigets": "kolonialkrig",
    "kolonialkrigs": "kolonialkrig",
    "kolonialmakten": "kolonialmakt",
    "kolonialmaktens": "kolonialmakt",
    "kolonialmakter": "kolonialmakt",
    "kolonialmakterna": "kolonialmakt",
    "kolonialmakternas": "kolonialmakt",
    "kolonialmakters": "kolonialmakt",
    "kolonialmakts": "kolonialmakt",
    "kolonialpolitiken": "kolonialpolitik",
    "kolonialpolitikens": "kolonialpolitik",
    "kolonialpolitiks": "kolonialpolitik",
    "kolonials": "kolonial",
    "kolonialt": "kolonial",
    "kolonialtiden": "kolonialtid",
    "kolonialtidens": "kolonialtid",
    "kolonialtids": "kolonialtid",
    "kolonialts": "kolonial",
    "kolonialvar": "kolonialvara",
    "kolonialvaran": "kolonialvara",
    "kolonialvarans": "kolonialvara",
    "kolonialvaras": "kolonialvara",
    "kolonialvare": "kolonialvara",
    "kolonialvaror": "kolonialvara",
    "kolonialvarorna": "kolonialvara",
    "kolonialvarornas": "kolonialvara",
    "kolonialvarors": "kolonialvara",
    "kolonialvars": "kolonialvara",
    "kolonialvälden": "kolonialvälde",
    "kolonialväldena": "kolonialvälde",
    "kolonialväldenas": "kolonialvälde",
    "kolonialväldens": "kolonialvälde",
    "kolonialväldes": "kolonialvälde",
    "kolonialväldet": "kolonialvälde",
    "kolonialväldets": "kolonialvälde",
    "kolonien": "koloni",
    "koloniens": "koloni",
    "kolonier": "koloni",
    "kolonierna": "koloni",
    "koloniernas": "koloni",
    "koloniers": "koloni",
    "kolonilotten": "kolonilott",
    "kolonilottens": "kolonilott",
    "kolonilotter": "kolonilott",
    "kolonilotterna": "kolonilott",
    "kolonilotternas": "kolonilott",
    "kolonilotters": "kolonilott",
    "kolonilotts": "kolonilott",
    "kolonin": "koloni",
    "kolonins": "koloni",
    "kolonis": "koloni",
    "kolonisationen": "kolonisation",
    "kolonisationens": "kolonisation",
    "kolonisationer": "kolonisation",
    "kolonisationerna": "kolonisation",
    "kolonisationernas": "kolonisation",
    "kolonisationers": "kolonisation",
    "kolonisations": "kolonisation",
    "kolonisationstiden": "kolonisationstid",
    "kolonisationstidens": "kolonisationstid",
    "kolonisationstider": "kolonisationstid",
    "kolonisationstiderna": "kolonisationstid",
    "kolonisationstidernas": "kolonisationstid",
    "kolonisationstiders": "kolonisationstid",
    "kolonisationstids": "kolonisationstid",
    "kolonisatören": "kolonisatör",
    "kolonisatörens": "kolonisatör",
    "kolonisatörer": "kolonisatör",
    "kolonisatörerna": "kolonisatör",
    "kolonisatörernas": "kolonisatör",
    "kolonisatörers": "kolonisatör",
    "kolonisatörs": "kolonisatör",
    "koloniserad": "kolonisera",
    "koloniserade": "kolonisera",
    "koloniserades": "kolonisera",
    "koloniserads": "kolonisera",
    "koloniserande": "kolonisera",
    "koloniseranden": "koloniserande",
    "koloniserandena": "koloniserande",
    "koloniserandenas": "koloniserande",
    "koloniserandens": "koloniserande",
    "koloniserandes": "koloniserande",
    "koloniserandet": "koloniserande",
    "koloniserandets": "koloniserande",
    "koloniserar": "kolonisera",
    "koloniseras": "kolonisera",
    "koloniserat": "kolonisera",
    "koloniserats": "kolonisera",
    "koloniserbara": "koloniserbar",
    "koloniserbarare": "koloniserbar",
    "koloniserbarares": "koloniserbar",
    "koloniserbaras": "koloniserbar",
    "koloniserbarast": "koloniserbar",
    "koloniserbaraste": "koloniserbar",
    "koloniserbarastes": "koloniserbar",
    "koloniserbarasts": "koloniserbar",
    "koloniserbare": "koloniserbar",
    "koloniserbares": "koloniserbar",
    "koloniserbarheten": "koloniserbarhet",
    "koloniserbarhetens": "koloniserbarhet",
    "koloniserbarhets": "koloniserbarhet",
    "koloniserbars": "koloniserbar",
    "koloniserbart": "koloniserbar",
    "koloniserbarts": "koloniserbar",
    "koloniseringar": "kolonisering",
    "koloniseringarna": "kolonisering",
    "koloniseringarnas": "kolonisering",
    "koloniseringars": "kolonisering",
    "koloniseringen": "kolonisering",
    "koloniseringens": "kolonisering",
    "koloniserings": "kolonisering",
    "kolonistugan": "kolonistuga",
    "kolonistugans": "kolonistuga",
    "kolonistugas": "kolonistuga",
    "kolonistuge": "kolonistuga",
    "kolonistugor": "kolonistuga",
    "kolonistugorna": "kolonistuga",
    "kolonistugornas": "kolonistuga",
    "kolonistugors": "kolonistuga",
    "kolonistugu": "kolonistuga",
    "kolonnaden": "kolonnad",
    "kolonnadens": "kolonnad",
    "kolonnader": "kolonnad",
    "kolonnaderna": "kolonnad",
    "kolonnadernas": "kolonnad",
    "kolonnaders": "kolonnad",
    "kolonnads": "kolonnad",
    "kolonnen": "kolonn",
    "kolonnens": "kolonn",
    "kolonner": "kolonn",
    "kolonnerna": "kolonn",
    "kolonnernas": "kolonn",
    "kolonners": "kolonn",
    "kolonnetten": "kolonnett",
    "kolonnettens": "kolonnett",
    "kolonnetter": "kolonnett",
    "kolonnetterna": "kolonnett",
    "kolonnetternas": "kolonnett",
    "kolonnetters": "kolonnett",
    "kolonnetts": "kolonnett",
    "kolonnomgärdade": "kolonnomgärdad",
    "kolonnomgärdades": "kolonnomgärdad",
    "kolonnomgärdads": "kolonnomgärdad",
    "kolonnomgärdat": "kolonnomgärdad",
    "kolonnomgärdats": "kolonnomgärdad",
    "kolonnordningar": "kolonnordning",
    "kolonnordningarna": "kolonnordning",
    "kolonnordningarnas": "kolonnordning",
    "kolonnordningars": "kolonnordning",
    "kolonnordningen": "kolonnordning",
    "kolonnordningens": "kolonnordning",
    "kolonnordnings": "kolonnordning",
    "kolonns": "kolonn",
    "kolons": "kolon",
    "kolor": "kola",
    "koloradoskalbagg": "koloradoskalbagge",
    "koloradoskalbaggar": "koloradoskalbagge",
    "koloradoskalbaggarna": "koloradoskalbagge",
    "koloradoskalbaggarnas": "koloradoskalbagge",
    "koloradoskalbaggars": "koloradoskalbagge",
    "koloradoskalbaggen": "koloradoskalbagge",
    "koloradoskalbaggens": "koloradoskalbagge",
    "koloradoskalbagges": "koloradoskalbagge",
    "koloradoskalbaggs": "koloradoskalbagge",
    "koloraturen": "koloratur",
    "koloraturens": "koloratur",
    "koloraturer": "koloratur",
    "koloraturerna": "koloratur",
    "koloraturernas": "koloratur",
    "koloraturers": "koloratur",
    "koloraturs": "koloratur",
    "koloratursopranen": "koloratursopran",
    "koloratursopranens": "koloratursopran",
    "koloratursopraner": "koloratursopran",
    "koloratursopranerna": "koloratursopran",
    "koloratursopranernas": "koloratursopran",
    "koloratursopraners": "koloratursopran",
    "koloratursoprans": "koloratursopran",
    "koloratursångerskan": "koloratursångerska",
    "koloratursångerskans": "koloratursångerska",
    "koloratursångerskas": "koloratursångerska",
    "koloratursångerske": "koloratursångerska",
    "koloratursångerskor": "koloratursångerska",
    "koloratursångerskorna": "koloratursångerska",
    "koloratursångerskornas": "koloratursångerska",
    "koloratursångerskors": "koloratursångerska",
    "kolorerad": "kolorera",
    "kolorerade": "kolorera",
    "kolorerades": "kolorera",
    "kolorerads": "kolorera",
    "kolorerande": "kolorera",
    "koloreranden": "kolorerande",
    "kolorerandena": "kolorerande",
    "kolorerandenas": "kolorerande",
    "kolorerandens": "kolorerande",
    "kolorerandes": "kolorerande",
    "kolorerandet": "kolorerande",
    "kolorerandets": "kolorerande",
    "kolorerar": "kolorera",
    "koloreras": "kolorera",
    "kolorerat": "kolorera",
    "kolorerats": "kolorera",
    "kolorerbara": "kolorerbar",
    "kolorerbarare": "kolorerbar",
    "kolorerbarares": "kolorerbar",
    "kolorerbaras": "kolorerbar",
    "kolorerbarast": "kolorerbar",
    "kolorerbaraste": "kolorerbar",
    "kolorerbarastes": "kolorerbar",
    "kolorerbarasts": "kolorerbar",
    "kolorerbare": "kolorerbar",
    "kolorerbares": "kolorerbar",
    "kolorerbarheten": "kolorerbarhet",
    "kolorerbarhetens": "kolorerbarhet",
    "kolorerbarhets": "kolorerbarhet",
    "kolorerbars": "kolorerbar",
    "kolorerbart": "kolorerbar",
    "kolorerbarts": "kolorerbar",
    "koloreringar": "kolorering",
    "koloreringarna": "kolorering",
    "koloreringarnas": "kolorering",
    "koloreringars": "kolorering",
    "koloreringen": "kolorering",
    "koloreringens": "kolorering",
    "kolorerings": "kolorering",
    "kolorismen": "kolorism",
    "kolorismens": "kolorism",
    "kolorismer": "kolorism",
    "kolorismerna": "kolorism",
    "kolorismernas": "kolorism",
    "kolorismers": "kolorism",
    "kolorisms": "kolorism",
    "koloristen": "kolorist",
    "koloristens": "kolorist",
    "kolorister": "kolorist",
    "koloristerna": "kolorist",
    "koloristernas": "kolorist",
    "koloristers": "kolorist",
    "koloristiska": "koloristisk",
    "koloristiskas": "koloristisk",
    "koloristiske": "koloristisk",
    "koloristiskes": "koloristisk",
    "koloristisks": "koloristisk",
    "koloristiskt": "koloristisk",
    "koloristiskts": "koloristisk",
    "kolorists": "kolorist",
    "koloriten": "kolorit",
    "koloritens": "kolorit",
    "koloriter": "kolorit",
    "koloriterna": "kolorit",
    "koloriternas": "kolorit",
    "koloriters": "kolorit",
    "kolorits": "kolorit",
    "kolorna": "kola",
    "kolornas": "kola",
    "kolors": "kola",
    "koloset": "kolos",
    "kolosets": "kolos",
    "kolossala": "kolossal",
    "kolossalare": "kolossal",
    "kolossalares": "kolossal",
    "kolossalas": "kolossal",
    "kolossalast": "kolossal",
    "kolossalaste": "kolossal",
    "kolossalastes": "kolossal",
    "kolossalasts": "kolossal",
    "kolossale": "kolossal",
    "kolossales": "kolossal",
    "kolossals": "kolossal",
    "kolossalt": "kolossal",
    "kolossalts": "kolossal",
    "kolossen": "koloss",
    "kolossens": "koloss",
    "kolosser": "koloss",
    "kolosserna": "koloss",
    "kolossernas": "koloss",
    "kolossers": "koloss",
    "koloxiden": "koloxid",
    "koloxidens": "koloxid",
    "koloxids": "koloxid",
    "kolportagehäften": "kolportagehäfte",
    "kolportagehäftena": "kolportagehäfte",
    "kolportagehäftenas": "kolportagehäfte",
    "kolportagehäftens": "kolportagehäfte",
    "kolportagehäftes": "kolportagehäfte",
    "kolportagehäftet": "kolportagehäfte",
    "kolportagehäftets": "kolportagehäfte",
    "kolportagemässiga": "kolportagemässig",
    "kolportagemässigare": "kolportagemässig",
    "kolportagemässigares": "kolportagemässig",
    "kolportagemässigas": "kolportagemässig",
    "kolportagemässigast": "kolportagemässig",
    "kolportagemässigaste": "kolportagemässig",
    "kolportagemässigastes": "kolportagemässig",
    "kolportagemässigasts": "kolportagemässig",
    "kolportagemässige": "kolportagemässig",
    "kolportagemässiges": "kolportagemässig",
    "kolportagemässigheten": "kolportagemässighet",
    "kolportagemässighetens": "kolportagemässighet",
    "kolportagemässighets": "kolportagemässighet",
    "kolportagemässigs": "kolportagemässig",
    "kolportagemässigt": "kolportagemässig",
    "kolportagemässigts": "kolportagemässig",
    "kolportages": "kolportage",
    "kolportaget": "kolportage",
    "kolportagets": "kolportage",
    "kolporterad": "kolportera",
    "kolporterade": "kolportera",
    "kolporterades": "kolportera",
    "kolporterads": "kolportera",
    "kolporterande": "kolportera",
    "kolporteranden": "kolporterande",
    "kolporterandena": "kolporterande",
    "kolporterandenas": "kolporterande",
    "kolporterandens": "kolporterande",
    "kolporterandes": "kolporterande",
    "kolporterandet": "kolporterande",
    "kolporterandets": "kolporterande",
    "kolporterar": "kolportera",
    "kolporteras": "kolportera",
    "kolporterat": "kolportera",
    "kolporterats": "kolportera",
    "kolporterbara": "kolporterbar",
    "kolporterbarare": "kolporterbar",
    "kolporterbarares": "kolporterbar",
    "kolporterbaras": "kolporterbar",
    "kolporterbarast": "kolporterbar",
    "kolporterbaraste": "kolporterbar",
    "kolporterbarastes": "kolporterbar",
    "kolporterbarasts": "kolporterbar",
    "kolporterbare": "kolporterbar",
    "kolporterbares": "kolporterbar",
    "kolporterbarheten": "kolporterbarhet",
    "kolporterbarhetens": "kolporterbarhet",
    "kolporterbarhets": "kolporterbarhet",
    "kolporterbars": "kolporterbar",
    "kolporterbart": "kolporterbar",
    "kolporterbarts": "kolporterbar",
    "kolporteringar": "kolportering",
    "kolporteringarna": "kolportering",
    "kolporteringarnas": "kolportering",
    "kolporteringars": "kolportering",
    "kolporteringen": "kolportering",
    "kolporteringens": "kolportering",
    "kolporterings": "kolportering",
    "kolportören": "kolportör",
    "kolportörens": "kolportör",
    "kolportörer": "kolportör",
    "kolportörerna": "kolportör",
    "kolportörernas": "kolportör",
    "kolportörers": "kolportör",
    "kolportörs": "kolportör",
    "kolryssar": "kolryss",
    "kolryssarna": "kolryss",
    "kolryssarnas": "kolryss",
    "kolryssars": "kolryss",
    "kolryssen": "kolryss",
    "kolryssens": "kolryss",
    "kolrören": "kolrör",
    "kolrörens": "kolrör",
    "kolröret": "kolrör",
    "kolrörets": "kolrör",
    "kolrörs": "kolrör",
    "kols": "kol",
    "kolskissen": "kolskiss",
    "kolskissens": "kolskiss",
    "kolskisser": "kolskiss",
    "kolskisserna": "kolskiss",
    "kolskissernas": "kolskiss",
    "kolskissers": "kolskiss",
    "kolstiften": "kolstift",
    "kolstiftens": "kolstift",
    "kolstiftet": "kolstift",
    "kolstiftets": "kolstift",
    "kolstifts": "kolstift",
    "kolstybben": "kolstybb",
    "kolstybbens": "kolstybb",
    "kolstybbs": "kolstybb",
    "kolstålen": "kolstål",
    "kolstålens": "kolstål",
    "kolstålet": "kolstål",
    "kolstålets": "kolstål",
    "kolståls": "kolstål",
    "kolsvarta": "kolsvart",
    "kolsvartare": "kolsvart",
    "kolsvartares": "kolsvart",
    "kolsvartas": "kolsvart",
    "kolsvartast": "kolsvart",
    "kolsvartaste": "kolsvart",
    "kolsvartastes": "kolsvart",
    "kolsvartasts": "kolsvart",
    "kolsvarte": "kolsvart",
    "kolsvartes": "kolsvart",
    "kolsvarts": "kolsvart",
    "kolsvavlan": "kolsvavla",
    "kolsvavlans": "kolsvavla",
    "kolsvavlas": "kolsvavla",
    "kolsyraassimilationen": "kolsyraassimilation",
    "kolsyraassimilationens": "kolsyraassimilation",
    "kolsyraassimilationer": "kolsyraassimilation",
    "kolsyraassimilationerna": "kolsyraassimilation",
    "kolsyraassimilationernas": "kolsyraassimilation",
    "kolsyraassimilationers": "kolsyraassimilation",
    "kolsyraassimilations": "kolsyraassimilation",
    "kolsyrade": "kolsyrad",
    "kolsyrades": "kolsyrad",
    "kolsyrads": "kolsyrad",
    "kolsyran": "kolsyra",
    "kolsyrans": "kolsyra",
    "kolsyras": "kolsyra",
    "kolsyrat": "kolsyrad",
    "kolsyrats": "kolsyrad",
    "kolsyre": "kolsyra",
    "kolsyregevären": "kolsyregevär",
    "kolsyregevärens": "kolsyregevär",
    "kolsyregeväret": "kolsyregevär",
    "kolsyregevärets": "kolsyregevär",
    "kolsyregevärs": "kolsyregevär",
    "kolsyremaskinen": "kolsyremaskin",
    "kolsyremaskinens": "kolsyremaskin",
    "kolsyremaskiner": "kolsyremaskin",
    "kolsyremaskinerna": "kolsyremaskin",
    "kolsyremaskinernas": "kolsyremaskin",
    "kolsyremaskiners": "kolsyremaskin",
    "kolsyremaskins": "kolsyremaskin",
    "kolsyrepatronen": "kolsyrepatron",
    "kolsyrepatronens": "kolsyrepatron",
    "kolsyrepatroner": "kolsyrepatron",
    "kolsyrepatronerna": "kolsyrepatron",
    "kolsyrepatronernas": "kolsyrepatron",
    "kolsyrepatroners": "kolsyrepatron",
    "kolsyrepatrons": "kolsyrepatron",
    "kolsyrepistolen": "kolsyrepistol",
    "kolsyrepistolens": "kolsyrepistol",
    "kolsyrepistoler": "kolsyrepistol",
    "kolsyrepistolerna": "kolsyrepistol",
    "kolsyrepistolernas": "kolsyrepistol",
    "kolsyrepistolers": "kolsyrepistol",
    "kolsyrepistols": "kolsyrepistol",
    "kolsyresnön": "kolsyresnö",
    "kolsyresnöns": "kolsyresnö",
    "kolsyresnös": "kolsyresnö",
    "koltabletten": "koltablett",
    "koltablettens": "koltablett",
    "koltabletter": "koltablett",
    "koltabletterna": "koltablett",
    "koltabletternas": "koltablett",
    "koltabletters": "koltablett",
    "koltabletts": "koltablett",
    "koltar": "kolt",
    "koltarna": "kolt",
    "koltarnas": "kolt",
    "koltars": "kolt",
    "koltavdelningar": "koltavdelning",
    "koltavdelningarna": "koltavdelning",
    "koltavdelningarnas": "koltavdelning",
    "koltavdelningars": "koltavdelning",
    "koltavdelningen": "koltavdelning",
    "koltavdelningens": "koltavdelning",
    "koltavdelnings": "koltavdelning",
    "koltbarnen": "koltbarn",
    "koltbarnens": "koltbarn",
    "koltbarnet": "koltbarn",
    "koltbarnets": "koltbarn",
    "koltbarns": "koltbarn",
    "kolteckningar": "kolteckning",
    "kolteckningarna": "kolteckning",
    "kolteckningarnas": "kolteckning",
    "kolteckningars": "kolteckning",
    "kolteckningen": "kolteckning",
    "kolteckningens": "kolteckning",
    "koltecknings": "kolteckning",
    "kolten": "kolt",
    "koltens": "kolt",
    "koltetrakloriden": "koltetraklorid",
    "koltetrakloridens": "koltetraklorid",
    "koltetraklorids": "koltetraklorid",
    "koltrastar": "koltrast",
    "koltrastarna": "koltrast",
    "koltrastarnas": "koltrast",
    "koltrastars": "koltrast",
    "koltrasten": "koltrast",
    "koltrastens": "koltrast",
    "koltrasts": "koltrast",
    "koltrådar": "koltråd",
    "koltrådarna": "koltråd",
    "koltrådarnas": "koltråd",
    "koltrådars": "koltråd",
    "koltråden": "koltråd",
    "koltrådens": "koltråd",
    "koltråds": "koltråd",
    "kolts": "kolt",
    "koltåldern": "koltålder",
    "koltålderns": "koltålder",
    "koltålders": "koltålder",
    "kolugna": "kolugn",
    "kolugnare": "kolugn",
    "kolugnares": "kolugn",
    "kolugnas": "kolugn",
    "kolugnast": "kolugn",
    "kolugnaste": "kolugn",
    "kolugnastes": "kolugn",
    "kolugnasts": "kolugn",
    "kolugne": "kolugn",
    "kolugnes": "kolugn",
    "kolugns": "kolugn",
    "kolugnt": "kolugn",
    "kolugnts": "kolugn",
    "kolumbarie": "kolumbarium",
    "kolumbarier": "kolumbarium",
    "kolumbarierna": "kolumbarium",
    "kolumbariernas": "kolumbarium",
    "kolumbariers": "kolumbarium",
    "kolumbariet": "kolumbarium",
    "kolumbariets": "kolumbarium",
    "kolumbariums": "kolumbarium",
    "kolumnen": "kolumn",
    "kolumnens": "kolumn",
    "kolumner": "kolumn",
    "kolumnerna": "kolumn",
    "kolumnernas": "kolumn",
    "kolumners": "kolumn",
    "kolumnisten": "kolumnist",
    "kolumnistens": "kolumnist",
    "kolumnister": "kolumnist",
    "kolumnisterna": "kolumnist",
    "kolumnisternas": "kolumnist",
    "kolumnisters": "kolumnist",
    "kolumnists": "kolumnist",
    "kolumns": "kolumn",
    "kolumntiteln": "kolumntitel",
    "kolumntitelns": "kolumntitel",
    "kolumntitels": "kolumntitel",
    "kolumntitlar": "kolumntitel",
    "kolumntitlarna": "kolumntitel",
    "kolumntitlarnas": "kolumntitel",
    "kolumntitlars": "kolumntitel",
    "kolumnutrymmen": "kolumnutrymme",
    "kolumnutrymmena": "kolumnutrymme",
    "kolumnutrymmenas": "kolumnutrymme",
    "kolumnutrymmens": "kolumnutrymme",
    "kolumnutrymmes": "kolumnutrymme",
    "kolumnutrymmet": "kolumnutrymme",
    "kolumnutrymmets": "kolumnutrymme",
    "kolvar": "kolv",
    "kolvarna": "kolv",
    "kolvarnas": "kolv",
    "kolvars": "kolv",
    "kolven": "kolv",
    "kolvens": "kolv",
    "kolvhalsar": "kolvhals",
    "kolvhalsarna": "kolvhals",
    "kolvhalsarnas": "kolvhals",
    "kolvhalsars": "kolvhals",
    "kolvhalsen": "kolvhals",
    "kolvhalsens": "kolvhals",
    "kolvmotorer": "kolvmotor",
    "kolvmotorerna": "kolvmotor",
    "kolvmotorernas": "kolvmotor",
    "kolvmotorers": "kolvmotor",
    "kolvmotorn": "kolvmotor",
    "kolvmotorns": "kolvmotor",
    "kolvmotors": "kolvmotor",
    "kolvs": "kolv",
    "kolväten": "kolväte",
    "kolvätena": "kolväte",
    "kolvätenas": "kolväte",
    "kolvätens": "kolväte",
    "kolvätes": "kolväte",
    "kolvätet": "kolväte",
    "kolvätets": "kolväte",
    "kolväts": "kolväte",
    "kom": "komma",
    "koman": "koma",
    "komans": "koma",
    "komas": "koma",
    "komat": "koma",
    "komats": "koma",
    "komatösa": "komatös",
    "komatösare": "komatös",
    "komatösares": "komatös",
    "komatösas": "komatös",
    "komatösast": "komatös",
    "komatösaste": "komatös",
    "komatösastes": "komatös",
    "komatösasts": "komatös",
    "komatöse": "komatös",
    "komatöses": "komatös",
    "komatöst": "komatös",
    "komatösts": "komatös",
    "kombattanten": "kombattant",
    "kombattantens": "kombattant",
    "kombattanter": "kombattant",
    "kombattanterna": "kombattant",
    "kombattanternas": "kombattant",
    "kombattanters": "kombattant",
    "kombattants": "kombattant",
    "kombin": "kombi",
    "kombinabiliteten": "kombinabilitet",
    "kombinabilitetens": "kombinabilitet",
    "kombinabilitets": "kombinabilitet",
    "kombinaten": "kombinat",
    "kombinatens": "kombinat",
    "kombinatet": "kombinat",
    "kombinatets": "kombinat",
    "kombinationen": "kombination",
    "kombinationens": "kombination",
    "kombinationer": "kombination",
    "kombinationerna": "kombination",
    "kombinationernas": "kombination",
    "kombinationers": "kombination",
    "kombinations": "kombination",
    "kombinationsförmågan": "kombinationsförmåga",
    "kombinationsförmågans": "kombinationsförmåga",
    "kombinationsförmågas": "kombinationsförmåga",
    "kombinationsförmåge": "kombinationsförmåga",
    "kombinationslåsen": "kombinationslås",
    "kombinationslåsens": "kombinationslås",
    "kombinationslåset": "kombinationslås",
    "kombinationslåsets": "kombinationslås",
    "kombinationsmåttsatsen": "kombinationsmåttsats",
    "kombinationsmåttsatsens": "kombinationsmåttsats",
    "kombinationsmåttsatser": "kombinationsmåttsats",
    "kombinationsmåttsatserna": "kombinationsmåttsats",
    "kombinationsmåttsatsernas": "kombinationsmåttsats",
    "kombinationsmåttsatsers": "kombinationsmåttsats",
    "kombinationsspelet": "kombinationsspel",
    "kombinationsspelets": "kombinationsspel",
    "kombinationsspels": "kombinationsspel",
    "kombinationstävlingar": "kombinationstävling",
    "kombinationstävlingarna": "kombinationstävling",
    "kombinationstävlingarnas": "kombinationstävling",
    "kombinationstävlingars": "kombinationstävling",
    "kombinationstävlingen": "kombinationstävling",
    "kombinationstävlingens": "kombinationstävling",
    "kombinationstävlings": "kombinationstävling",
    "kombinatoriska": "kombinatorisk",
    "kombinatoriskare": "kombinatorisk",
    "kombinatoriskares": "kombinatorisk",
    "kombinatoriskas": "kombinatorisk",
    "kombinatoriskast": "kombinatorisk",
    "kombinatoriskaste": "kombinatorisk",
    "kombinatoriskastes": "kombinatorisk",
    "kombinatoriskasts": "kombinatorisk",
    "kombinatoriske": "kombinatorisk",
    "kombinatoriskes": "kombinatorisk",
    "kombinatorisks": "kombinatorisk",
    "kombinatoriskt": "kombinatorisk",
    "kombinatoriskts": "kombinatorisk",
    "kombinats": "kombinat",
    "kombinerad": "kombinera",
    "kombinerade": "kombinera",
    "kombinerades": "kombinera",
    "kombinerads": "kombinera",
    "kombinerande": "kombinera",
    "kombineranden": "kombinerande",
    "kombinerandena": "kombinerande",
    "kombinerandenas": "kombinerande",
    "kombinerandens": "kombinerande",
    "kombinerandes": "kombinerande",
    "kombinerandet": "kombinerande",
    "kombinerandets": "kombinerande",
    "kombinerar": "kombinera",
    "kombineras": "kombinera",
    "kombinerat": "kombinera",
    "kombinerats": "kombinera",
    "kombinerbara": "kombinerbar",
    "kombinerbarare": "kombinerbar",
    "kombinerbarares": "kombinerbar",
    "kombinerbaras": "kombinerbar",
    "kombinerbarast": "kombinerbar",
    "kombinerbaraste": "kombinerbar",
    "kombinerbarastes": "kombinerbar",
    "kombinerbarasts": "kombinerbar",
    "kombinerbare": "kombinerbar",
    "kombinerbares": "kombinerbar",
    "kombinerbarheten": "kombinerbarhet",
    "kombinerbarhetens": "kombinerbarhet",
    "kombinerbarhets": "kombinerbarhet",
    "kombinerbars": "kombinerbar",
    "kombinerbart": "kombinerbar",
    "kombinerbarts": "kombinerbar",
    "kombineringar": "kombinering",
    "kombineringarna": "kombinering",
    "kombineringarnas": "kombinering",
    "kombineringars": "kombinering",
    "kombineringen": "kombinering",
    "kombineringens": "kombinering",
    "kombinerings": "kombinering",
    "kombins": "kombi",
    "kombis": "kombi",
    "komedianten": "komediant",
    "komediantens": "komediant",
    "komedianter": "komediant",
    "komedianterna": "komediant",
    "komedianternas": "komediant",
    "komedianters": "komediant",
    "komediants": "komediant",
    "komedien": "komedi",
    "komediennen": "komedienn",
    "komediennens": "komedienn",
    "komedienner": "komedienn",
    "komediennerna": "komedienn",
    "komediennernas": "komedienn",
    "komedienners": "komedienn",
    "komedienns": "komedienn",
    "komediens": "komedi",
    "komedier": "komedi",
    "komedierna": "komedi",
    "komediernas": "komedi",
    "komediers": "komedi",
    "komedin": "komedi",
    "komedins": "komedi",
    "komedis": "komedi",
    "komet": "komma",
    "kometen": "komet",
    "kometens": "komet",
    "kometer": "komet",
    "kometerna": "komet",
    "kometernas": "komet",
    "kometers": "komet",
    "kometmolnen": "kometmoln",
    "kometmolnens": "kometmoln",
    "kometmolnet": "kometmoln",
    "kometmolnets": "kometmoln",
    "kometmolns": "kometmoln",
    "komets": "komma",
    "komfortabels": "komfortabel",
    "komfortabelt": "komfortabel",
    "komfortabelts": "komfortabel",
    "komfortabla": "komfortabel",
    "komfortablare": "komfortabel",
    "komfortablares": "komfortabel",
    "komfortablas": "komfortabel",
    "komfortablast": "komfortabel",
    "komfortablaste": "komfortabel",
    "komfortablastes": "komfortabel",
    "komfortablasts": "komfortabel",
    "komfortable": "komfortabel",
    "komfortables": "komfortabel",
    "komforten": "komfort",
    "komfortens": "komfort",
    "komforts": "komfort",
    "komihåget": "komihåg",
    "komihågets": "komihåg",
    "komihågs": "komihåg",
    "komiken": "komik",
    "komikens": "komik",
    "komikern": "komiker",
    "komikerna": "komiker",
    "komikernas": "komiker",
    "komikerns": "komiker",
    "komikers": "komiker",
    "komiks": "komik",
    "komiska": "komisk",
    "komiskare": "komisk",
    "komiskares": "komisk",
    "komiskas": "komisk",
    "komiskast": "komisk",
    "komiskaste": "komisk",
    "komiskastes": "komisk",
    "komiskasts": "komisk",
    "komiske": "komisk",
    "komiskes": "komisk",
    "komisks": "komisk",
    "komiskt": "komisk",
    "komiskts": "komisk",
    "komitativen": "komitativ",
    "komitativens": "komitativ",
    "komitativer": "komitativ",
    "komitativerna": "komitativ",
    "komitativernas": "komitativ",
    "komitativers": "komitativ",
    "komitativs": "komitativ",
    "komjölken": "komjölk",
    "komjölkens": "komjölk",
    "komjölks": "komjölk",
    "kommabacillen": "kommabacill",
    "kommabacillens": "kommabacill",
    "kommabaciller": "kommabacill",
    "kommabacillerna": "kommabacill",
    "kommabacillernas": "kommabacill",
    "kommabacillers": "kommabacill",
    "kommabacills": "kommabacill",
    "komman": "komma",
    "kommana": "komma",
    "kommanas": "komma",
    "kommande": "komma",
    "kommanden": "kommande",
    "kommandena": "kommande",
    "kommandenas": "kommande",
    "kommandens": "kommande",
    "kommandes": "kommande",
    "kommandet": "kommande",
    "kommandets": "kommande",
    "kommanditbolagen": "kommanditbolag",
    "kommanditbolagens": "kommanditbolag",
    "kommanditbolaget": "kommanditbolag",
    "kommanditbolagets": "kommanditbolag",
    "kommanditbolags": "kommanditbolag",
    "kommanditdelägar": "kommanditdelägare",
    "kommanditdelägaren": "kommanditdelägare",
    "kommanditdelägarens": "kommanditdelägare",
    "kommanditdelägares": "kommanditdelägare",
    "kommanditdelägarna": "kommanditdelägare",
    "kommanditdelägarnas": "kommanditdelägare",
    "kommandobrygg": "kommandobrygga",
    "kommandobryggan": "kommandobrygga",
    "kommandobryggans": "kommandobrygga",
    "kommandobryggas": "kommandobrygga",
    "kommandobrygge": "kommandobrygga",
    "kommandobryggor": "kommandobrygga",
    "kommandobryggorna": "kommandobrygga",
    "kommandobryggornas": "kommandobrygga",
    "kommandobryggors": "kommandobrygga",
    "kommandobryggs": "kommandobrygga",
    "kommandomålen": "kommandomål",
    "kommandomålens": "kommandomål",
    "kommandomålet": "kommandomål",
    "kommandomålets": "kommandomål",
    "kommandomåls": "kommandomål",
    "kommandon": "kommando",
    "kommandona": "kommando",
    "kommandonas": "kommando",
    "kommandons": "kommando",
    "kommandoorden": "kommandoord",
    "kommandoordens": "kommandoord",
    "kommandoordet": "kommandoord",
    "kommandoordets": "kommandoord",
    "kommandoords": "kommandoord",
    "kommandorösten": "kommandoröst",
    "kommandoröstens": "kommandoröst",
    "kommandoröster": "kommandoröst",
    "kommandorösterna": "kommandoröst",
    "kommandorösternas": "kommandoröst",
    "kommandorösters": "kommandoröst",
    "kommandorösts": "kommandoröst",
    "kommandos": "kommando",
    "kommandot": "kommando",
    "kommandotonen": "kommandoton",
    "kommandotonens": "kommandoton",
    "kommandotons": "kommandoton",
    "kommandots": "kommando",
    "kommans": "komma",
    "kommas": "komma",
    "kommat": "komma",
    "kommaterad": "kommatera",
    "kommaterade": "kommatera",
    "kommaterades": "kommatera",
    "kommaterads": "kommatera",
    "kommaterande": "kommatera",
    "kommateranden": "kommaterande",
    "kommaterandena": "kommaterande",
    "kommaterandenas": "kommaterande",
    "kommaterandens": "kommaterande",
    "kommaterandes": "kommaterande",
    "kommaterandet": "kommaterande",
    "kommaterandets": "kommaterande",
    "kommaterar": "kommatera",
    "kommateras": "kommatera",
    "kommaterat": "kommatera",
    "kommaterats": "kommatera",
    "kommaterbara": "kommaterbar",
    "kommaterbarare": "kommaterbar",
    "kommaterbarares": "kommaterbar",
    "kommaterbaras": "kommaterbar",
    "kommaterbarast": "kommaterbar",
    "kommaterbaraste": "kommaterbar",
    "kommaterbarastes": "kommaterbar",
    "kommaterbarasts": "kommaterbar",
    "kommaterbare": "kommaterbar",
    "kommaterbares": "kommaterbar",
    "kommaterbarheten": "kommaterbarhet",
    "kommaterbarhetens": "kommaterbarhet",
    "kommaterbarhets": "kommaterbarhet",
    "kommaterbars": "kommaterbar",
    "kommaterbart": "kommaterbar",
    "kommaterbarts": "kommaterbar",
    "kommateringar": "kommatering",
    "kommateringarna": "kommatering",
    "kommateringarnas": "kommatering",
    "kommateringars": "kommatering",
    "kommateringen": "kommatering",
    "kommateringens": "kommatering",
    "kommaterings": "kommatering",
    "kommats": "komma",
    "komme": "komma",
    "kommen": "komma",
    "kommendanten": "kommendant",
    "kommendantens": "kommendant",
    "kommendanter": "kommendant",
    "kommendanterna": "kommendant",
    "kommendanternas": "kommendant",
    "kommendanters": "kommendant",
    "kommendants": "kommendant",
    "kommendanturen": "kommendantur",
    "kommendanturens": "kommendantur",
    "kommendanturer": "kommendantur",
    "kommendanturerna": "kommendantur",
    "kommendanturernas": "kommendantur",
    "kommendanturers": "kommendantur",
    "kommendanturs": "kommendantur",
    "kommenderad": "kommendera",
    "kommenderade": "kommendera",
    "kommenderades": "kommendera",
    "kommenderads": "kommendera",
    "kommenderande": "kommendera",
    "kommenderanden": "kommenderande",
    "kommenderandena": "kommenderande",
    "kommenderandenas": "kommenderande",
    "kommenderandens": "kommenderande",
    "kommenderandes": "kommenderande",
    "kommenderandet": "kommenderande",
    "kommenderandets": "kommenderande",
    "kommenderar": "kommendera",
    "kommenderas": "kommendera",
    "kommenderat": "kommendera",
    "kommenderats": "kommendera",
    "kommenderbara": "kommenderbar",
    "kommenderbarare": "kommenderbar",
    "kommenderbarares": "kommenderbar",
    "kommenderbaras": "kommenderbar",
    "kommenderbarast": "kommenderbar",
    "kommenderbaraste": "kommenderbar",
    "kommenderbarastes": "kommenderbar",
    "kommenderbarasts": "kommenderbar",
    "kommenderbare": "kommenderbar",
    "kommenderbares": "kommenderbar",
    "kommenderbarheten": "kommenderbarhet",
    "kommenderbarhetens": "kommenderbarhet",
    "kommenderbarhets": "kommenderbarhet",
    "kommenderbars": "kommenderbar",
    "kommenderbart": "kommenderbar",
    "kommenderbarts": "kommenderbar",
    "kommenderingar": "kommendering",
    "kommenderingarna": "kommendering",
    "kommenderingarnas": "kommendering",
    "kommenderingars": "kommendering",
    "kommenderingen": "kommendering",
    "kommenderingens": "kommendering",
    "kommenderings": "kommendering",
    "kommendören": "kommendör",
    "kommendörens": "kommendör",
    "kommendörer": "kommendör",
    "kommendörerna": "kommendör",
    "kommendörernas": "kommendör",
    "kommendörers": "kommendör",
    "kommendörkaptenen": "kommendörkapten",
    "kommendörkaptenens": "kommendörkapten",
    "kommendörkaptener": "kommendörkapten",
    "kommendörkaptenerna": "kommendörkapten",
    "kommendörkaptenernas": "kommendörkapten",
    "kommendörkapteners": "kommendörkapten",
    "kommendörkaptens": "kommendörkapten",
    "kommendörn": "kommendör",
    "kommendörns": "kommendör",
    "kommendörs": "kommendör",
    "kommens": "komma",
    "kommensurabels": "kommensurabel",
    "kommensurabelt": "kommensurabel",
    "kommensurabelts": "kommensurabel",
    "kommensurabla": "kommensurabel",
    "kommensurablare": "kommensurabel",
    "kommensurablares": "kommensurabel",
    "kommensurablas": "kommensurabel",
    "kommensurablast": "kommensurabel",
    "kommensurablaste": "kommensurabel",
    "kommensurablastes": "kommensurabel",
    "kommensurablasts": "kommensurabel",
    "kommensurable": "kommensurabel",
    "kommensurables": "kommensurabel",
    "kommentaren": "kommentar",
    "kommentarens": "kommentar",
    "kommentarer": "kommentar",
    "kommentarerna": "kommentar",
    "kommentarernas": "kommentar",
    "kommentarers": "kommentar",
    "kommentars": "kommentar",
    "kommentatorer": "kommentator",
    "kommentatorerna": "kommentator",
    "kommentatorernas": "kommentator",
    "kommentatorers": "kommentator",
    "kommentatorn": "kommentator",
    "kommentatorns": "kommentator",
    "kommentators": "kommentator",
    "kommentatorsfunktionen": "kommentatorsfunktion",
    "kommentatorsfunktionens": "kommentatorsfunktion",
    "kommentatorsfunktioner": "kommentatorsfunktion",
    "kommentatorsfunktionerna": "kommentatorsfunktion",
    "kommentatorsfunktionernas": "kommentatorsfunktion",
    "kommentatorsfunktioners": "kommentatorsfunktion",
    "kommentatorsfunktions": "kommentatorsfunktion",
    "kommenterad": "kommentera",
    "kommenterade": "kommentera",
    "kommenterades": "kommentera",
    "kommenterads": "kommentera",
    "kommenterande": "kommentera",
    "kommenteranden": "kommenterande",
    "kommenterandena": "kommenterande",
    "kommenterandenas": "kommenterande",
    "kommenterandens": "kommenterande",
    "kommenterandes": "kommenterande",
    "kommenterandet": "kommenterande",
    "kommenterandets": "kommenterande",
    "kommenterar": "kommentera",
    "kommenteras": "kommentera",
    "kommenterat": "kommentera",
    "kommenterats": "kommentera",
    "kommenterbara": "kommenterbar",
    "kommenterbarare": "kommenterbar",
    "kommenterbarares": "kommenterbar",
    "kommenterbaras": "kommenterbar",
    "kommenterbarast": "kommenterbar",
    "kommenterbaraste": "kommenterbar",
    "kommenterbarastes": "kommenterbar",
    "kommenterbarasts": "kommenterbar",
    "kommenterbare": "kommenterbar",
    "kommenterbares": "kommenterbar",
    "kommenterbarheten": "kommenterbarhet",
    "kommenterbarhetens": "kommenterbarhet",
    "kommenterbarhets": "kommenterbarhet",
    "kommenterbars": "kommenterbar",
    "kommenterbart": "kommenterbar",
    "kommenterbarts": "kommenterbar",
    "kommenteringar": "kommentering",
    "kommenteringarna": "kommentering",
    "kommenteringarnas": "kommentering",
    "kommenteringars": "kommentering",
    "kommenteringen": "kommentering",
    "kommenteringens": "kommentering",
    "kommenterings": "kommentering",
    "kommer": "komma",
    "kommers": "kommersa",
    "kommersad": "kommersa",
    "kommersade": "kommersa",
    "kommersades": "kommersa",
    "kommersads": "kommersa",
    "kommersande": "kommersa",
    "kommersanden": "kommersande",
    "kommersandena": "kommersande",
    "kommersandenas": "kommersande",
    "kommersandens": "kommersande",
    "kommersandes": "kommersande",
    "kommersandet": "kommersande",
    "kommersandets": "kommersande",
    "kommersar": "kommersa",
    "kommersas": "kommersa",
    "kommersat": "kommersa",
    "kommersats": "kommersa",
    "kommersen": "kommers",
    "kommersens": "kommers",
    "kommerser": "kommers",
    "kommerserna": "kommers",
    "kommersernas": "kommers",
    "kommersers": "kommers",
    "kommerseråden": "kommerseråd",
    "kommerserådens": "kommerseråd",
    "kommerserådet": "kommerseråd",
    "kommerserådets": "kommerseråd",
    "kommerseråds": "kommerseråd",
    "kommersialiserad": "kommersialisera",
    "kommersialiserade": "kommersialisera",
    "kommersialiserades": "kommersialisera",
    "kommersialiserads": "kommersialisera",
    "kommersialiserande": "kommersialisera",
    "kommersialiseranden": "kommersialiserande",
    "kommersialiserandena": "kommersialiserande",
    "kommersialiserandenas": "kommersialiserande",
    "kommersialiserandens": "kommersialiserande",
    "kommersialiserandes": "kommersialiserande",
    "kommersialiserandet": "kommersialiserande",
    "kommersialiserandets": "kommersialiserande",
    "kommersialiserar": "kommersialisera",
    "kommersialiseras": "kommersialisera",
    "kommersialiserat": "kommersialisera",
    "kommersialiserats": "kommersialisera",
    "kommersialiserbara": "kommersialiserbar",
    "kommersialiserbarare": "kommersialiserbar",
    "kommersialiserbarares": "kommersialiserbar",
    "kommersialiserbaras": "kommersialiserbar",
    "kommersialiserbarast": "kommersialiserbar",
    "kommersialiserbaraste": "kommersialiserbar",
    "kommersialiserbarastes": "kommersialiserbar",
    "kommersialiserbarasts": "kommersialiserbar",
    "kommersialiserbare": "kommersialiserbar",
    "kommersialiserbares": "kommersialiserbar",
    "kommersialiserbarheten": "kommersialiserbarhet",
    "kommersialiserbarhetens": "kommersialiserbarhet",
    "kommersialiserbarhets": "kommersialiserbarhet",
    "kommersialiserbars": "kommersialiserbar",
    "kommersialiserbart": "kommersialiserbar",
    "kommersialiserbarts": "kommersialiserbar",
    "kommersialiseringar": "kommersialisering",
    "kommersialiseringarna": "kommersialisering",
    "kommersialiseringarnas": "kommersialisering",
    "kommersialiseringars": "kommersialisering",
    "kommersialiseringen": "kommersialisering",
    "kommersialiseringens": "kommersialisering",
    "kommersialiserings": "kommersialisering",
    "kommersiella": "kommersiell",
    "kommersiellare": "kommersiell",
    "kommersiellares": "kommersiell",
    "kommersiellas": "kommersiell",
    "kommersiellast": "kommersiell",
    "kommersiellaste": "kommersiell",
    "kommersiellastes": "kommersiell",
    "kommersiellasts": "kommersiell",
    "kommersielle": "kommersiell",
    "kommersielles": "kommersiell",
    "kommersiells": "kommersiell",
    "kommersiellt": "kommersiell",
    "kommersiellts": "kommersiell",
    "kommerskollegie": "kommerskollegium",
    "kommerskollegier": "kommerskollegium",
    "kommerskollegierna": "kommerskollegium",
    "kommerskollegiernas": "kommerskollegium",
    "kommerskollegiers": "kommerskollegium",
    "kommerskollegiet": "kommerskollegium",
    "kommerskollegiets": "kommerskollegium",
    "kommerskollegiums": "kommerskollegium",
    "kommes": "komma",
    "komministern": "komminister",
    "komministerns": "komminister",
    "komministers": "komminister",
    "komministrar": "komminister",
    "komministrarna": "komminister",
    "komministrarnas": "komminister",
    "komministrars": "komminister",
    "kommissariaten": "kommissariat",
    "kommissariatens": "kommissariat",
    "kommissariatet": "kommissariat",
    "kommissariatets": "kommissariat",
    "kommissariats": "kommissariat",
    "kommissarien": "kommissarie",
    "kommissariens": "kommissarie",
    "kommissarier": "kommissarie",
    "kommissarierna": "kommissarie",
    "kommissariernas": "kommissarie",
    "kommissariers": "kommissarie",
    "kommissaries": "kommissarie",
    "kommissen": "kommiss",
    "kommissens": "kommiss",
    "kommissionen": "kommission",
    "kommissionens": "kommission",
    "kommissioner": "kommission",
    "kommissionerna": "kommission",
    "kommissionernas": "kommission",
    "kommissioners": "kommission",
    "kommissions": "kommission",
    "kommissionären": "kommissionär",
    "kommissionärens": "kommissionär",
    "kommissionärer": "kommissionär",
    "kommissionärerna": "kommissionär",
    "kommissionärernas": "kommissionär",
    "kommissionärers": "kommissionär",
    "kommissionärs": "kommissionär",
    "kommit": "komma",
    "kommits": "komma",
    "kommitterade": "kommitterad",
    "kommitterades": "kommitterad",
    "kommitterads": "kommitterad",
    "kommitterat": "kommitterad",
    "kommitterats": "kommitterad",
    "kommittéer": "kommitté",
    "kommittéerna": "kommitté",
    "kommittéernas": "kommitté",
    "kommittéers": "kommitté",
    "kommittéförordningar": "kommittéförordning",
    "kommittéförordningarna": "kommittéförordning",
    "kommittéförordningarnas": "kommittéförordning",
    "kommittéförordningars": "kommittéförordning",
    "kommittéförordningen": "kommittéförordning",
    "kommittéförordningens": "kommittéförordning",
    "kommittéförordnings": "kommittéförordning",
    "kommittén": "kommitté",
    "kommitténs": "kommitté",
    "kommittés": "kommitté",
    "kommoden": "kommod",
    "kommodens": "kommod",
    "kommoder": "kommod",
    "kommoderna": "kommod",
    "kommodernas": "kommod",
    "kommoders": "kommod",
    "kommods": "kommod",
    "kommunala": "kommunal",
    "kommunalare": "kommunal",
    "kommunalares": "kommunal",
    "kommunalas": "kommunal",
    "kommunalast": "kommunal",
    "kommunalaste": "kommunal",
    "kommunalastes": "kommunal",
    "kommunalasts": "kommunal",
    "kommunale": "kommunal",
    "kommunales": "kommunal",
    "kommunalfullmäktige": "kommunalfullmäktig",
    "kommunalfullmäktigen": "kommunalfullmäktig",
    "kommunalfullmäktigena": "kommunalfullmäktig",
    "kommunalfullmäktigenas": "kommunalfullmäktig",
    "kommunalfullmäktigens": "kommunalfullmäktig",
    "kommunalfullmäktiges": "kommunalfullmäktig",
    "kommunalfullmäktigs": "kommunalfullmäktig",
    "kommunalförvaltningar": "kommunalförvaltning",
    "kommunalförvaltningarna": "kommunalförvaltning",
    "kommunalförvaltningarnas": "kommunalförvaltning",
    "kommunalförvaltningars": "kommunalförvaltning",
    "kommunalförvaltningen": "kommunalförvaltning",
    "kommunalförvaltningens": "kommunalförvaltning",
    "kommunalförvaltnings": "kommunalförvaltning",
    "kommunalhusen": "kommunalhus",
    "kommunalhusens": "kommunalhus",
    "kommunalhuset": "kommunalhus",
    "kommunalhusets": "kommunalhus",
    "kommunaliserad": "kommunalisera",
    "kommunaliserade": "kommunalisera",
    "kommunaliserades": "kommunalisera",
    "kommunaliserads": "kommunalisera",
    "kommunaliserande": "kommunalisera",
    "kommunaliseranden": "kommunaliserande",
    "kommunaliserandena": "kommunaliserande",
    "kommunaliserandenas": "kommunaliserande",
    "kommunaliserandens": "kommunaliserande",
    "kommunaliserandes": "kommunaliserande",
    "kommunaliserandet": "kommunaliserande",
    "kommunaliserandets": "kommunaliserande",
    "kommunaliserar": "kommunalisera",
    "kommunaliseras": "kommunalisera",
    "kommunaliserat": "kommunalisera",
    "kommunaliserats": "kommunalisera",
    "kommunaliserbara": "kommunaliserbar",
    "kommunaliserbarare": "kommunaliserbar",
    "kommunaliserbarares": "kommunaliserbar",
    "kommunaliserbaras": "kommunaliserbar",
    "kommunaliserbarast": "kommunaliserbar",
    "kommunaliserbaraste": "kommunaliserbar",
    "kommunaliserbarastes": "kommunaliserbar",
    "kommunaliserbarasts": "kommunaliserbar",
    "kommunaliserbare": "kommunaliserbar",
    "kommunaliserbares": "kommunaliserbar",
    "kommunaliserbarheten": "kommunaliserbarhet",
    "kommunaliserbarhetens": "kommunaliserbarhet",
    "kommunaliserbarhets": "kommunaliserbarhet",
    "kommunaliserbars": "kommunaliserbar",
    "kommunaliserbart": "kommunaliserbar",
    "kommunaliserbarts": "kommunaliserbar",
    "kommunaliseringar": "kommunalisering",
    "kommunaliseringarna": "kommunalisering",
    "kommunaliseringarnas": "kommunalisering",
    "kommunaliseringars": "kommunalisering",
    "kommunaliseringen": "kommunalisering",
    "kommunaliseringens": "kommunalisering",
    "kommunaliserings": "kommunalisering",
    "kommunallagar": "kommunallag",
    "kommunallagarna": "kommunallag",
    "kommunallagarnas": "kommunallag",
    "kommunallagars": "kommunallag",
    "kommunallagen": "kommunallag",
    "kommunallagens": "kommunallag",
    "kommunallags": "kommunallag",
    "kommunalmannen": "kommunalman",
    "kommunalmannens": "kommunalman",
    "kommunalmans": "kommunalman",
    "kommunalmän": "kommunalman",
    "kommunalmännen": "kommunalman",
    "kommunalmännens": "kommunalman",
    "kommunalmäns": "kommunalman",
    "kommunalnämnden": "kommunalnämnd",
    "kommunalnämndens": "kommunalnämnd",
    "kommunalnämnder": "kommunalnämnd",
    "kommunalnämnderna": "kommunalnämnd",
    "kommunalnämndernas": "kommunalnämnd",
    "kommunalnämnders": "kommunalnämnd",
    "kommunalnämnds": "kommunalnämnd",
    "kommunalnämndsordföranden": "kommunalnämndsordförande",
    "kommunalnämndsordförandena": "kommunalnämndsordförande",
    "kommunalnämndsordförandenas": "kommunalnämndsordförande",
    "kommunalnämndsordförandens": "kommunalnämndsordförande",
    "kommunalnämndsordförandes": "kommunalnämndsordförande",
    "kommunalordföranden": "kommunalordförande",
    "kommunalordförandena": "kommunalordförande",
    "kommunalordförandenas": "kommunalordförande",
    "kommunalordförandens": "kommunalordförande",
    "kommunalordförandes": "kommunalordförande",
    "kommunalpolitikern": "kommunalpolitiker",
    "kommunalpolitikerna": "kommunalpolitiker",
    "kommunalpolitikernas": "kommunalpolitiker",
    "kommunalpolitikerns": "kommunalpolitiker",
    "kommunalpolitikers": "kommunalpolitiker",
    "kommunalpolitiska": "kommunalpolitisk",
    "kommunalpolitiskare": "kommunalpolitisk",
    "kommunalpolitiskares": "kommunalpolitisk",
    "kommunalpolitiskas": "kommunalpolitisk",
    "kommunalpolitiskast": "kommunalpolitisk",
    "kommunalpolitiskaste": "kommunalpolitisk",
    "kommunalpolitiskastes": "kommunalpolitisk",
    "kommunalpolitiskasts": "kommunalpolitisk",
    "kommunalpolitiske": "kommunalpolitisk",
    "kommunalpolitiskes": "kommunalpolitisk",
    "kommunalpolitisks": "kommunalpolitisk",
    "kommunalpolitiskt": "kommunalpolitisk",
    "kommunalpolitiskts": "kommunalpolitisk",
    "kommunalråden": "kommunalråd",
    "kommunalrådens": "kommunalråd",
    "kommunalrådet": "kommunalråd",
    "kommunalrådets": "kommunalråd",
    "kommunalråds": "kommunalråd",
    "kommunals": "kommunal",
    "kommunalskatten": "kommunalskatt",
    "kommunalskattens": "kommunalskatt",
    "kommunalskatter": "kommunalskatt",
    "kommunalskatterna": "kommunalskatt",
    "kommunalskatternas": "kommunalskatt",
    "kommunalskatters": "kommunalskatt",
    "kommunalskatts": "kommunalskatt",
    "kommunalstyrelsen": "kommunalstyrelse",
    "kommunalstyrelsens": "kommunalstyrelse",
    "kommunalstyrelser": "kommunalstyrelse",
    "kommunalstyrelserna": "kommunalstyrelse",
    "kommunalstyrelsernas": "kommunalstyrelse",
    "kommunalstyrelsers": "kommunalstyrelse",
    "kommunalstyrelses": "kommunalstyrelse",
    "kommunalt": "kommunal",
    "kommunalts": "kommunal",
    "kommunalvalen": "kommunalval",
    "kommunalvalens": "kommunalval",
    "kommunalvalet": "kommunalval",
    "kommunalvalets": "kommunalval",
    "kommunalvals": "kommunalval",
    "kommunarden": "kommunard",
    "kommunardens": "kommunard",
    "kommunarder": "kommunard",
    "kommunarderna": "kommunard",
    "kommunardernas": "kommunard",
    "kommunarders": "kommunard",
    "kommunards": "kommunard",
    "kommunblocken": "kommunblock",
    "kommunblockens": "kommunblock",
    "kommunblocket": "kommunblock",
    "kommunblockets": "kommunblock",
    "kommunblocks": "kommunblock",
    "kommundelar": "kommundel",
    "kommundelarna": "kommundel",
    "kommundelarnas": "kommundel",
    "kommundelars": "kommundel",
    "kommundelen": "kommundel",
    "kommundelens": "kommundel",
    "kommundels": "kommundel",
    "kommundelsråden": "kommundelsråd",
    "kommundelsrådens": "kommundelsråd",
    "kommundelsrådet": "kommundelsråd",
    "kommundelsrådets": "kommundelsråd",
    "kommundelsråds": "kommundelsråd",
    "kommunen": "kommun",
    "kommunens": "kommun",
    "kommuner": "kommun",
    "kommunerna": "kommun",
    "kommunernas": "kommun",
    "kommuners": "kommun",
    "kommunfullmäktige": "kommunfullmäktig",
    "kommunfullmäktigen": "kommunfullmäktige",
    "kommunfullmäktigena": "kommunfullmäktige",
    "kommunfullmäktigenas": "kommunfullmäktige",
    "kommunfullmäktigens": "kommunfullmäktige",
    "kommunfullmäktiges": "kommunfullmäktige",
    "kommunfullmäktiget": "kommunfullmäktige",
    "kommunfullmäktigets": "kommunfullmäktige",
    "kommunfullmäktigs": "kommunfullmäktige",
    "kommunförbunden": "kommunförbund",
    "kommunförbundens": "kommunförbund",
    "kommunförbundet": "kommunförbund",
    "kommunförbundets": "kommunförbund",
    "kommunförbunds": "kommunförbund",
    "kommunicerad": "kommunicera",
    "kommunicerade": "kommunicera",
    "kommunicerades": "kommunicera",
    "kommunicerads": "kommunicera",
    "kommunicerande": "kommunicera",
    "kommuniceranden": "kommunicerande",
    "kommunicerandena": "kommunicerande",
    "kommunicerandenas": "kommunicerande",
    "kommunicerandens": "kommunicerande",
    "kommunicerandes": "kommunicerande",
    "kommunicerandet": "kommunicerande",
    "kommunicerandets": "kommunicerande",
    "kommunicerar": "kommunicera",
    "kommuniceras": "kommunicera",
    "kommunicerat": "kommunicera",
    "kommunicerats": "kommunicera",
    "kommunicerbara": "kommunicerbar",
    "kommunicerbarare": "kommunicerbar",
    "kommunicerbarares": "kommunicerbar",
    "kommunicerbaras": "kommunicerbar",
    "kommunicerbarast": "kommunicerbar",
    "kommunicerbaraste": "kommunicerbar",
    "kommunicerbarastes": "kommunicerbar",
    "kommunicerbarasts": "kommunicerbar",
    "kommunicerbare": "kommunicerbar",
    "kommunicerbares": "kommunicerbar",
    "kommunicerbarheten": "kommunicerbarhet",
    "kommunicerbarhetens": "kommunicerbarhet",
    "kommunicerbarhets": "kommunicerbarhet",
    "kommunicerbars": "kommunicerbar",
    "kommunicerbart": "kommunicerbar",
    "kommunicerbarts": "kommunicerbar",
    "kommuniceringar": "kommunicering",
    "kommuniceringarna": "kommunicering",
    "kommuniceringarnas": "kommunicering",
    "kommuniceringars": "kommunicering",
    "kommuniceringen": "kommunicering",
    "kommuniceringens": "kommunicering",
    "kommunicerings": "kommunicering",
    "kommunikanten": "kommunikant",
    "kommunikantens": "kommunikant",
    "kommunikanter": "kommunikant",
    "kommunikanterna": "kommunikant",
    "kommunikanternas": "kommunikant",
    "kommunikanters": "kommunikant",
    "kommunikants": "kommunikant",
    "kommunikationen": "kommunikation",
    "kommunikationens": "kommunikation",
    "kommunikationer": "kommunikation",
    "kommunikationerna": "kommunikation",
    "kommunikationernas": "kommunikation",
    "kommunikationers": "kommunikation",
    "kommunikations": "kommunikation",
    "kommunikationsakten": "kommunikationsakt",
    "kommunikationsaktens": "kommunikationsakt",
    "kommunikationsakter": "kommunikationsakt",
    "kommunikationsakterna": "kommunikationsakt",
    "kommunikationsakternas": "kommunikationsakt",
    "kommunikationsakters": "kommunikationsakt",
    "kommunikationsakts": "kommunikationsakt",
    "kommunikationsdepartementen": "kommunikationsdepartement",
    "kommunikationsdepartementens": "kommunikationsdepartement",
    "kommunikationsdepartementet": "kommunikationsdepartement",
    "kommunikationsdepartementets": "kommunikationsdepartement",
    "kommunikationsdepartements": "kommunikationsdepartement",
    "kommunikationsmedels": "kommunikationsmedel",
    "kommunikationsmedlen": "kommunikationsmedel",
    "kommunikationsmedlens": "kommunikationsmedel",
    "kommunikationsmedlet": "kommunikationsmedel",
    "kommunikationsmedlets": "kommunikationsmedel",
    "kommunikationsministern": "kommunikationsminister",
    "kommunikationsministerns": "kommunikationsminister",
    "kommunikationsministers": "kommunikationsminister",
    "kommunikationsministrar": "kommunikationsminister",
    "kommunikationsministrarna": "kommunikationsminister",
    "kommunikationsministrarnas": "kommunikationsminister",
    "kommunikationsministrars": "kommunikationsminister",
    "kommunikationsmässiga": "kommunikationsmässig",
    "kommunikationsmässigare": "kommunikationsmässig",
    "kommunikationsmässigares": "kommunikationsmässig",
    "kommunikationsmässigas": "kommunikationsmässig",
    "kommunikationsmässigast": "kommunikationsmässig",
    "kommunikationsmässigaste": "kommunikationsmässig",
    "kommunikationsmässigastes": "kommunikationsmässig",
    "kommunikationsmässigasts": "kommunikationsmässig",
    "kommunikationsmässige": "kommunikationsmässig",
    "kommunikationsmässiges": "kommunikationsmässig",
    "kommunikationsmässigs": "kommunikationsmässig",
    "kommunikationsmässigt": "kommunikationsmässig",
    "kommunikationsmässigts": "kommunikationsmässig",
    "kommunikationsnäten": "kommunikationsnät",
    "kommunikationsnätens": "kommunikationsnät",
    "kommunikationsnätet": "kommunikationsnät",
    "kommunikationsnätets": "kommunikationsnät",
    "kommunikationsnäts": "kommunikationsnät",
    "kommunikationsradion": "kommunikationsradio",
    "kommunikationsradions": "kommunikationsradio",
    "kommunikationsradior": "kommunikationsradio",
    "kommunikationsradiorna": "kommunikationsradio",
    "kommunikationsradiornas": "kommunikationsradio",
    "kommunikationsradiors": "kommunikationsradio",
    "kommunikationsradios": "kommunikationsradio",
    "kommunikationssatelliten": "kommunikationssatellit",
    "kommunikationssatellitens": "kommunikationssatellit",
    "kommunikationssatelliter": "kommunikationssatellit",
    "kommunikationssatelliterna": "kommunikationssatellit",
    "kommunikationssatelliternas": "kommunikationssatellit",
    "kommunikationssatelliters": "kommunikationssatellit",
    "kommunikationssatellits": "kommunikationssatellit",
    "kommunikationstabellen": "kommunikationstabell",
    "kommunikationstabellens": "kommunikationstabell",
    "kommunikationstabeller": "kommunikationstabell",
    "kommunikationstabellerna": "kommunikationstabell",
    "kommunikationstabellernas": "kommunikationstabell",
    "kommunikationstabellers": "kommunikationstabell",
    "kommunikationstabells": "kommunikationstabell",
    "kommunikationsteorien": "kommunikationsteori",
    "kommunikationsteoriens": "kommunikationsteori",
    "kommunikationsteorin": "kommunikationsteori",
    "kommunikationsteorins": "kommunikationsteori",
    "kommunikationsteoris": "kommunikationsteori",
    "kommunikativa": "kommunikativ",
    "kommunikativare": "kommunikativ",
    "kommunikativares": "kommunikativ",
    "kommunikativas": "kommunikativ",
    "kommunikativast": "kommunikativ",
    "kommunikativaste": "kommunikativ",
    "kommunikativastes": "kommunikativ",
    "kommunikativasts": "kommunikativ",
    "kommunikative": "kommunikativ",
    "kommunikatives": "kommunikativ",
    "kommunikativs": "kommunikativ",
    "kommunikativt": "kommunikativ",
    "kommunikativts": "kommunikativ",
    "kommunikatorer": "kommunikator",
    "kommunikatorerna": "kommunikator",
    "kommunikatorernas": "kommunikator",
    "kommunikatorers": "kommunikator",
    "kommunikatorn": "kommunikator",
    "kommunikatorns": "kommunikator",
    "kommunikators": "kommunikator",
    "kommunikatören": "kommunikatör",
    "kommunikatörens": "kommunikatör",
    "kommunikatörer": "kommunikatör",
    "kommunikatörerna": "kommunikatör",
    "kommunikatörernas": "kommunikatör",
    "kommunikatörers": "kommunikatör",
    "kommunikatörs": "kommunikatör",
    "kommunikéer": "kommuniké",
    "kommunikéerna": "kommuniké",
    "kommunikéernas": "kommuniké",
    "kommunikéers": "kommuniké",
    "kommunikén": "kommuniké",
    "kommunikéns": "kommuniké",
    "kommunikés": "kommuniké",
    "kommuninnevånar": "kommuninnevånare",
    "kommuninnevånaren": "kommuninnevånare",
    "kommuninnevånarens": "kommuninnevånare",
    "kommuninnevånares": "kommuninnevånare",
    "kommuninnevånarna": "kommuninnevånare",
    "kommuninnevånarnas": "kommuninnevånare",
    "kommuninvånar": "kommuninvånare",
    "kommuninvånaren": "kommuninvånare",
    "kommuninvånarens": "kommuninvånare",
    "kommuninvånares": "kommuninvånare",
    "kommuninvånarna": "kommuninvånare",
    "kommuninvånarnas": "kommuninvånare",
    "kommunionen": "kommunion",
    "kommunionens": "kommunion",
    "kommunioner": "kommunion",
    "kommunionerna": "kommunion",
    "kommunionernas": "kommunion",
    "kommunioners": "kommunion",
    "kommunions": "kommunion",
    "kommunismen": "kommunism",
    "kommunismens": "kommunism",
    "kommunismer": "kommunism",
    "kommunismerna": "kommunism",
    "kommunismernas": "kommunism",
    "kommunismers": "kommunism",
    "kommunisms": "kommunism",
    "kommunistdiktaturen": "kommunistdiktatur",
    "kommunistdiktaturens": "kommunistdiktatur",
    "kommunistdiktaturer": "kommunistdiktatur",
    "kommunistdiktaturerna": "kommunistdiktatur",
    "kommunistdiktaturernas": "kommunistdiktatur",
    "kommunistdiktaturers": "kommunistdiktatur",
    "kommunistdiktaturs": "kommunistdiktatur",
    "kommunisten": "kommunist",
    "kommunistens": "kommunist",
    "kommunister": "kommunist",
    "kommunisterna": "kommunist",
    "kommunisternas": "kommunist",
    "kommunisters": "kommunist",
    "kommunistgerillan": "kommunistgerilla",
    "kommunistgerillans": "kommunistgerilla",
    "kommunistgerillas": "kommunistgerilla",
    "kommunistgerillor": "kommunistgerilla",
    "kommunistgerillorna": "kommunistgerilla",
    "kommunistgerillornas": "kommunistgerilla",
    "kommunistgerillors": "kommunistgerilla",
    "kommunistiska": "kommunistisk",
    "kommunistiskare": "kommunistisk",
    "kommunistiskares": "kommunistisk",
    "kommunistiskas": "kommunistisk",
    "kommunistiskast": "kommunistisk",
    "kommunistiskaste": "kommunistisk",
    "kommunistiskastes": "kommunistisk",
    "kommunistiskasts": "kommunistisk",
    "kommunistiske": "kommunistisk",
    "kommunistiskes": "kommunistisk",
    "kommunistisks": "kommunistisk",
    "kommunistiskt": "kommunistisk",
    "kommunistiskts": "kommunistisk",
    "kommunistlandet": "kommunistland",
    "kommunistlandets": "kommunistland",
    "kommunistlands": "kommunistland",
    "kommunistländer": "kommunistland",
    "kommunistländerna": "kommunistland",
    "kommunistländernas": "kommunistland",
    "kommunistländers": "kommunistland",
    "kommunistpartier": "kommunistparti",
    "kommunistpartierna": "kommunistparti",
    "kommunistpartiernas": "kommunistparti",
    "kommunistpartiers": "kommunistparti",
    "kommunistpartiet": "kommunistparti",
    "kommunistpartiets": "kommunistparti",
    "kommunistpartis": "kommunistparti",
    "kommunistpartit": "kommunistparti",
    "kommunistpartits": "kommunistparti",
    "kommunistregimen": "kommunistregim",
    "kommunistregimens": "kommunistregim",
    "kommunistregimer": "kommunistregim",
    "kommunistregimerna": "kommunistregim",
    "kommunistregimernas": "kommunistregim",
    "kommunistregimers": "kommunistregim",
    "kommunistregims": "kommunistregim",
    "kommunists": "kommunist",
    "kommunistsympatisören": "kommunistsympatisör",
    "kommunistsympatisörens": "kommunistsympatisör",
    "kommunistsympatisörer": "kommunistsympatisör",
    "kommunistsympatisörerna": "kommunistsympatisör",
    "kommunistsympatisörernas": "kommunistsympatisör",
    "kommunistsympatisörers": "kommunistsympatisör",
    "kommunistsympatisörs": "kommunistsympatisör",
    "kommunistvärldar": "kommunistvärld",
    "kommunistvärldarna": "kommunistvärld",
    "kommunistvärldarnas": "kommunistvärld",
    "kommunistvärldars": "kommunistvärld",
    "kommunistvärlden": "kommunistvärld",
    "kommunistvärldens": "kommunistvärld",
    "kommunistvärlds": "kommunistvärld",
    "kommunnivåer": "kommunnivå",
    "kommunnivåerna": "kommunnivå",
    "kommunnivåernas": "kommunnivå",
    "kommunnivåers": "kommunnivå",
    "kommunnivån": "kommunnivå",
    "kommunnivåns": "kommunnivå",
    "kommunnivås": "kommunnivå",
    "kommunpolitikern": "kommunpolitiker",
    "kommunpolitikerna": "kommunpolitiker",
    "kommunpolitikernas": "kommunpolitiker",
    "kommunpolitikerns": "kommunpolitiker",
    "kommunpolitikers": "kommunpolitiker",
    "kommuns": "kommun",
    "kommunsammanslagningar": "kommunsammanslagning",
    "kommunsammanslagningarna": "kommunsammanslagning",
    "kommunsammanslagningarnas": "kommunsammanslagning",
    "kommunsammanslagningars": "kommunsammanslagning",
    "kommunsammanslagningen": "kommunsammanslagning",
    "kommunsammanslagningens": "kommunsammanslagning",
    "kommunsammanslagnings": "kommunsammanslagning",
    "kommunstyrelsen": "kommunstyrelse",
    "kommunstyrelsens": "kommunstyrelse",
    "kommunstyrelser": "kommunstyrelse",
    "kommunstyrelserna": "kommunstyrelse",
    "kommunstyrelsernas": "kommunstyrelse",
    "kommunstyrelsers": "kommunstyrelse",
    "kommunstyrelses": "kommunstyrelse",
    "kommunägda": "kommunägd",
    "kommunägdare": "kommunägd",
    "kommunägdares": "kommunägd",
    "kommunägdas": "kommunägd",
    "kommunägdast": "kommunägd",
    "kommunägdaste": "kommunägd",
    "kommunägdastes": "kommunägd",
    "kommunägdasts": "kommunägd",
    "kommunägde": "kommunägd",
    "kommunägdes": "kommunägd",
    "kommunägds": "kommunägd",
    "kommunägt": "kommunägd",
    "kommunägts": "kommunägd",
    "kommutativa": "kommutativ",
    "kommutativare": "kommutativ",
    "kommutativares": "kommutativ",
    "kommutativas": "kommutativ",
    "kommutativast": "kommutativ",
    "kommutativaste": "kommutativ",
    "kommutativastes": "kommutativ",
    "kommutativasts": "kommutativ",
    "kommutative": "kommutativ",
    "kommutatives": "kommutativ",
    "kommutativs": "kommutativ",
    "kommutativt": "kommutativ",
    "kommutativts": "kommutativ",
    "kommutatorer": "kommutator",
    "kommutatorerna": "kommutator",
    "kommutatorernas": "kommutator",
    "kommutatorers": "kommutator",
    "kommutatorn": "kommutator",
    "kommutatorns": "kommutator",
    "kommutators": "kommutator",
    "kommuterad": "kommutera",
    "kommuterade": "kommutera",
    "kommuterades": "kommutera",
    "kommuterads": "kommutera",
    "kommuterande": "kommutera",
    "kommuteranden": "kommuterande",
    "kommuterandena": "kommuterande",
    "kommuterandenas": "kommuterande",
    "kommuterandens": "kommuterande",
    "kommuterandes": "kommuterande",
    "kommuterandet": "kommuterande",
    "kommuterandets": "kommuterande",
    "kommuterar": "kommutera",
    "kommuteras": "kommutera",
    "kommuterat": "kommutera",
    "kommuterats": "kommutera",
    "kommuterbara": "kommuterbar",
    "kommuterbarare": "kommuterbar",
    "kommuterbarares": "kommuterbar",
    "kommuterbaras": "kommuterbar",
    "kommuterbarast": "kommuterbar",
    "kommuterbaraste": "kommuterbar",
    "kommuterbarastes": "kommuterbar",
    "kommuterbarasts": "kommuterbar",
    "kommuterbare": "kommuterbar",
    "kommuterbares": "kommuterbar",
    "kommuterbarheten": "kommuterbarhet",
    "kommuterbarhetens": "kommuterbarhet",
    "kommuterbarhets": "kommuterbarhet",
    "kommuterbars": "kommuterbar",
    "kommuterbart": "kommuterbar",
    "kommuterbarts": "kommuterbar",
    "kommuteringar": "kommutering",
    "kommuteringarna": "kommutering",
    "kommuteringarnas": "kommutering",
    "kommuteringars": "kommutering",
    "kommuteringen": "kommutering",
    "kommuteringens": "kommutering",
    "kommuterings": "kommutering",
    "komna": "komma",
    "komnas": "komma",
    "komne": "komma",
    "komnes": "komma",
    "komock": "komocka",
    "komockan": "komocka",
    "komockans": "komocka",
    "komockas": "komocka",
    "komocke": "komocka",
    "komockor": "komocka",
    "komockorna": "komocka",
    "komockornas": "komocka",
    "komockors": "komocka",
    "komocks": "komocka",
    "komoriern": "komorier",
    "komorierna": "komorier",
    "komoriernas": "komorier",
    "komorierns": "komorier",
    "komoriers": "komorier",
    "komoriska": "komorisk",
    "komoriskan": "komoriska",
    "komoriskans": "komoriska",
    "komoriskare": "komorisk",
    "komoriskares": "komorisk",
    "komoriskas": "komoriska",
    "komoriskast": "komorisk",
    "komoriskaste": "komorisk",
    "komoriskastes": "komorisk",
    "komoriskasts": "komorisk",
    "komoriske": "komoriska",
    "komoriskes": "komorisk",
    "komoriskor": "komoriska",
    "komoriskorna": "komoriska",
    "komoriskornas": "komoriska",
    "komoriskors": "komoriska",
    "komorisks": "komorisk",
    "komoriskt": "komorisk",
    "komoriskts": "komorisk",
    "komp": "kompa",
    "kompad": "kompa",
    "kompade": "kompa",
    "kompades": "kompa",
    "kompads": "kompa",
    "kompakta": "kompakt",
    "kompaktare": "kompakt",
    "kompaktares": "kompakt",
    "kompaktas": "kompakt",
    "kompaktast": "kompakt",
    "kompaktaste": "kompakt",
    "kompaktastes": "kompakt",
    "kompaktasts": "kompakt",
    "kompakte": "kompakt",
    "kompaktes": "kompakt",
    "kompaktheten": "kompakthet",
    "kompakthetens": "kompakthet",
    "kompakthets": "kompakthet",
    "kompaktkameran": "kompaktkamera",
    "kompaktkamerans": "kompaktkamera",
    "kompaktkameras": "kompaktkamera",
    "kompaktkameror": "kompaktkamera",
    "kompaktkamerorna": "kompaktkamera",
    "kompaktkamerornas": "kompaktkamera",
    "kompaktkamerors": "kompaktkamera",
    "kompakts": "kompakt",
    "kompaktskivan": "kompaktskiva",
    "kompaktskivans": "kompaktskiva",
    "kompaktskivas": "kompaktskiva",
    "kompaktskive": "kompaktskiva",
    "kompaktskivor": "kompaktskiva",
    "kompaktskivorna": "kompaktskiva",
    "kompaktskivornas": "kompaktskiva",
    "kompaktskivors": "kompaktskiva",
    "kompande": "kompa",
    "kompanden": "kompande",
    "kompandena": "kompande",
    "kompandenas": "kompande",
    "kompandens": "kompande",
    "kompandes": "kompande",
    "kompandet": "kompande",
    "kompandets": "kompande",
    "kompaniadjutanten": "kompaniadjutant",
    "kompaniadjutantens": "kompaniadjutant",
    "kompaniadjutanter": "kompaniadjutant",
    "kompaniadjutanterna": "kompaniadjutant",
    "kompaniadjutanternas": "kompaniadjutant",
    "kompaniadjutanters": "kompaniadjutant",
    "kompaniadjutants": "kompaniadjutant",
    "kompanier": "kompani",
    "kompanierna": "kompani",
    "kompaniernas": "kompani",
    "kompaniers": "kompani",
    "kompaniet": "kompani",
    "kompaniets": "kompani",
    "kompaniofficerare": "kompaniofficer",
    "kompaniofficerares": "kompaniofficer",
    "kompaniofficerarna": "kompaniofficer",
    "kompaniofficerarnas": "kompaniofficer",
    "kompaniofficeren": "kompaniofficer",
    "kompaniofficerens": "kompaniofficer",
    "kompaniofficern": "kompaniofficer",
    "kompaniofficerns": "kompaniofficer",
    "kompaniofficers": "kompaniofficer",
    "kompaniordern": "kompaniorder",
    "kompaniorderna": "kompaniorder",
    "kompaniordernas": "kompaniorder",
    "kompaniorderns": "kompaniorder",
    "kompaniorders": "kompaniorder",
    "kompaniordrar": "kompaniorder",
    "kompaniordrarna": "kompaniorder",
    "kompaniordrarnas": "kompaniorder",
    "kompaniordrars": "kompaniorder",
    "kompanis": "kompani",
    "kompanit": "kompani",
    "kompanits": "kompani",
    "kompanjonen": "kompanjon",
    "kompanjonens": "kompanjon",
    "kompanjoner": "kompanjon",
    "kompanjonerna": "kompanjon",
    "kompanjonernas": "kompanjon",
    "kompanjoners": "kompanjon",
    "kompanjons": "kompanjon",
    "kompar": "kompa",
    "komparabels": "komparabel",
    "komparabelt": "komparabel",
    "komparabelts": "komparabel",
    "komparabla": "komparabel",
    "komparablare": "komparabel",
    "komparablares": "komparabel",
    "komparablas": "komparabel",
    "komparablast": "komparabel",
    "komparablaste": "komparabel",
    "komparablastes": "komparabel",
    "komparablasts": "komparabel",
    "komparable": "komparabel",
    "komparables": "komparabel",
    "komparationen": "komparation",
    "komparationens": "komparation",
    "komparationer": "komparation",
    "komparationerna": "komparation",
    "komparationernas": "komparation",
    "komparationers": "komparation",
    "komparations": "komparation",
    "komparativa": "komparativ",
    "komparativare": "komparativ",
    "komparativares": "komparativ",
    "komparativas": "komparativ",
    "komparativast": "komparativ",
    "komparativaste": "komparativ",
    "komparativastes": "komparativ",
    "komparativasts": "komparativ",
    "komparative": "komparativ",
    "komparativen": "komparativ",
    "komparativens": "komparativ",
    "komparativer": "komparativ",
    "komparativerna": "komparativ",
    "komparativernas": "komparativ",
    "komparativers": "komparativ",
    "komparatives": "komparativ",
    "komparativs": "komparativ",
    "komparativt": "komparativ",
    "komparativts": "komparativ",
    "komparerad": "komparera",
    "komparerade": "komparera",
    "komparerades": "komparera",
    "komparerads": "komparera",
    "komparerande": "komparera",
    "kompareranden": "komparerande",
    "komparerandena": "komparerande",
    "komparerandenas": "komparerande",
    "komparerandens": "komparerande",
    "komparerandes": "komparerande",
    "komparerandet": "komparerande",
    "komparerandets": "komparerande",
    "komparerar": "komparera",
    "kompareras": "komparera",
    "komparerat": "komparera",
    "komparerats": "komparera",
    "komparerbara": "komparerbar",
    "komparerbarare": "komparerbar",
    "komparerbarares": "komparerbar",
    "komparerbaras": "komparerbar",
    "komparerbarast": "komparerbar",
    "komparerbaraste": "komparerbar",
    "komparerbarastes": "komparerbar",
    "komparerbarasts": "komparerbar",
    "komparerbare": "komparerbar",
    "komparerbares": "komparerbar",
    "komparerbarheten": "komparerbarhet",
    "komparerbarhetens": "komparerbarhet",
    "komparerbarhets": "komparerbarhet",
    "komparerbars": "komparerbar",
    "komparerbart": "komparerbar",
    "komparerbarts": "komparerbar",
    "kompareringar": "komparering",
    "kompareringarna": "komparering",
    "kompareringarnas": "komparering",
    "kompareringars": "komparering",
    "kompareringen": "komparering",
    "kompareringens": "komparering",
    "komparerings": "komparering",
    "komparsen": "kompars",
    "komparsens": "kompars",
    "komparser": "kompars",
    "komparserna": "kompars",
    "komparsernas": "kompars",
    "komparsers": "kompars",
    "kompas": "kompa",
    "kompassen": "kompass",
    "kompassens": "kompass",
    "kompasser": "kompass",
    "kompasserna": "kompass",
    "kompassernas": "kompass",
    "kompassers": "kompass",
    "kompasshusen": "kompasshus",
    "kompasshusens": "kompasshus",
    "kompasshuset": "kompasshus",
    "kompasshusets": "kompasshus",
    "kompasskursen": "kompasskurs",
    "kompasskursens": "kompasskurs",
    "kompasskurser": "kompasskurs",
    "kompasskurserna": "kompasskurs",
    "kompasskursernas": "kompasskurs",
    "kompasskursers": "kompasskurs",
    "kompassnålar": "kompassnål",
    "kompassnålarna": "kompassnål",
    "kompassnålarnas": "kompassnål",
    "kompassnålars": "kompassnål",
    "kompassnålen": "kompassnål",
    "kompassnålens": "kompassnål",
    "kompassnåls": "kompassnål",
    "kompassriktningar": "kompassriktning",
    "kompassriktningarna": "kompassriktning",
    "kompassriktningarnas": "kompassriktning",
    "kompassriktningars": "kompassriktning",
    "kompassriktningen": "kompassriktning",
    "kompassriktningens": "kompassriktning",
    "kompassriktnings": "kompassriktning",
    "kompassrosen": "kompassros",
    "kompassrosens": "kompassros",
    "kompassrosor": "kompassros",
    "kompassrosorna": "kompassros",
    "kompassrosornas": "kompassros",
    "kompassrosors": "kompassros",
    "kompat": "kompa",
    "kompatibels": "kompatibel",
    "kompatibelt": "kompatibel",
    "kompatibelts": "kompatibel",
    "kompatibla": "kompatibel",
    "kompatiblare": "kompatibel",
    "kompatiblares": "kompatibel",
    "kompatiblas": "kompatibel",
    "kompatiblast": "kompatibel",
    "kompatiblaste": "kompatibel",
    "kompatiblastes": "kompatibel",
    "kompatiblasts": "kompatibel",
    "kompatible": "kompatibel",
    "kompatibles": "kompatibel",
    "kompats": "kompa",
    "kompendie": "kompendium",
    "kompendier": "kompendium",
    "kompendierna": "kompendium",
    "kompendiernas": "kompendium",
    "kompendiers": "kompendium",
    "kompendiet": "kompendium",
    "kompendiets": "kompendium",
    "kompendiums": "kompendium",
    "kompensationen": "kompensation",
    "kompensationens": "kompensation",
    "kompensationer": "kompensation",
    "kompensationerna": "kompensation",
    "kompensationernas": "kompensation",
    "kompensationers": "kompensation",
    "kompensations": "kompensation",
    "kompensatorer": "kompensator",
    "kompensatorerna": "kompensator",
    "kompensatorernas": "kompensator",
    "kompensatorers": "kompensator",
    "kompensatoriska": "kompensatorisk",
    "kompensatoriskare": "kompensatorisk",
    "kompensatoriskares": "kompensatorisk",
    "kompensatoriskas": "kompensatorisk",
    "kompensatoriskast": "kompensatorisk",
    "kompensatoriskaste": "kompensatorisk",
    "kompensatoriskastes": "kompensatorisk",
    "kompensatoriskasts": "kompensatorisk",
    "kompensatoriske": "kompensatorisk",
    "kompensatoriskes": "kompensatorisk",
    "kompensatorisks": "kompensatorisk",
    "kompensatoriskt": "kompensatorisk",
    "kompensatoriskts": "kompensatorisk",
    "kompensatorn": "kompensator",
    "kompensatorns": "kompensator",
    "kompensators": "kompensator",
    "kompenserad": "kompensera",
    "kompenserade": "kompensera",
    "kompenserades": "kompensera",
    "kompenserads": "kompensera",
    "kompenserande": "kompensera",
    "kompenseranden": "kompenserande",
    "kompenserandena": "kompenserande",
    "kompenserandenas": "kompenserande",
    "kompenserandens": "kompenserande",
    "kompenserandes": "kompenserande",
    "kompenserandet": "kompenserande",
    "kompenserandets": "kompenserande",
    "kompenserar": "kompensera",
    "kompenseras": "kompensera",
    "kompenserat": "kompensera",
    "kompenserats": "kompensera",
    "kompenserbara": "kompenserbar",
    "kompenserbarare": "kompenserbar",
    "kompenserbarares": "kompenserbar",
    "kompenserbaras": "kompenserbar",
    "kompenserbarast": "kompenserbar",
    "kompenserbaraste": "kompenserbar",
    "kompenserbarastes": "kompenserbar",
    "kompenserbarasts": "kompenserbar",
    "kompenserbare": "kompenserbar",
    "kompenserbares": "kompenserbar",
    "kompenserbarheten": "kompenserbarhet",
    "kompenserbarhetens": "kompenserbarhet",
    "kompenserbarhets": "kompenserbarhet",
    "kompenserbars": "kompenserbar",
    "kompenserbart": "kompenserbar",
    "kompenserbarts": "kompenserbar",
    "kompenseringar": "kompensering",
    "kompenseringarna": "kompensering",
    "kompenseringarnas": "kompensering",
    "kompenseringars": "kompensering",
    "kompenseringen": "kompensering",
    "kompenseringens": "kompensering",
    "kompenserings": "kompensering",
    "kompet": "komp",
    "kompetensen": "kompetens",
    "kompetensens": "kompetens",
    "kompetenser": "kompetens",
    "kompetenserna": "kompetens",
    "kompetensernas": "kompetens",
    "kompetensers": "kompetens",
    "kompetensförklarad": "kompetensförklara",
    "kompetensförklarade": "kompetensförklara",
    "kompetensförklarades": "kompetensförklara",
    "kompetensförklarads": "kompetensförklara",
    "kompetensförklarande": "kompetensförklara",
    "kompetensförklaranden": "kompetensförklarande",
    "kompetensförklarandena": "kompetensförklarande",
    "kompetensförklarandenas": "kompetensförklarande",
    "kompetensförklarandens": "kompetensförklarande",
    "kompetensförklarandes": "kompetensförklarande",
    "kompetensförklarandet": "kompetensförklarande",
    "kompetensförklarandets": "kompetensförklarande",
    "kompetensförklarar": "kompetensförklara",
    "kompetensförklaras": "kompetensförklara",
    "kompetensförklarat": "kompetensförklara",
    "kompetensförklarats": "kompetensförklara",
    "kompetensmässiga": "kompetensmässig",
    "kompetensmässigare": "kompetensmässig",
    "kompetensmässigares": "kompetensmässig",
    "kompetensmässigas": "kompetensmässig",
    "kompetensmässigast": "kompetensmässig",
    "kompetensmässigaste": "kompetensmässig",
    "kompetensmässigastes": "kompetensmässig",
    "kompetensmässigasts": "kompetensmässig",
    "kompetensmässige": "kompetensmässig",
    "kompetensmässiges": "kompetensmässig",
    "kompetensmässigs": "kompetensmässig",
    "kompetensmässigt": "kompetensmässig",
    "kompetensmässigts": "kompetensmässig",
    "kompetensområden": "kompetensområde",
    "kompetensområdena": "kompetensområde",
    "kompetensområdenas": "kompetensområde",
    "kompetensområdens": "kompetensområde",
    "kompetensområdes": "kompetensområde",
    "kompetensområdet": "kompetensområde",
    "kompetensområdets": "kompetensområde",
    "kompetensutvecklingen": "kompetensutveckling",
    "kompetensutvecklingens": "kompetensutveckling",
    "kompetensutvecklings": "kompetensutveckling",
    "kompetenta": "kompetent",
    "kompetentare": "kompetent",
    "kompetentares": "kompetent",
    "kompetentas": "kompetent",
    "kompetentast": "kompetent",
    "kompetentaste": "kompetent",
    "kompetentastes": "kompetent",
    "kompetentasts": "kompetent",
    "kompetente": "kompetent",
    "kompetentes": "kompetent",
    "kompetents": "kompetent",
    "kompets": "komp",
    "kompilaten": "kompilat",
    "kompilatens": "kompilat",
    "kompilatet": "kompilat",
    "kompilatets": "kompilat",
    "kompilationen": "kompilation",
    "kompilationens": "kompilation",
    "kompilationer": "kompilation",
    "kompilationerna": "kompilation",
    "kompilationernas": "kompilation",
    "kompilationers": "kompilation",
    "kompilations": "kompilation",
    "kompilatorer": "kompilator",
    "kompilatorerna": "kompilator",
    "kompilatorernas": "kompilator",
    "kompilatorers": "kompilator",
    "kompilatorn": "kompilator",
    "kompilatorns": "kompilator",
    "kompilators": "kompilator",
    "kompilats": "kompilat",
    "kompilerad": "kompilera",
    "kompilerade": "kompilera",
    "kompilerades": "kompilera",
    "kompilerads": "kompilera",
    "kompilerande": "kompilera",
    "kompileranden": "kompilerande",
    "kompilerandena": "kompilerande",
    "kompilerandenas": "kompilerande",
    "kompilerandens": "kompilerande",
    "kompilerandes": "kompilerande",
    "kompilerandet": "kompilerande",
    "kompilerandets": "kompilerande",
    "kompilerar": "kompilera",
    "kompileras": "kompilera",
    "kompilerat": "kompilera",
    "kompilerats": "kompilera",
    "kompilerbara": "kompilerbar",
    "kompilerbarare": "kompilerbar",
    "kompilerbarares": "kompilerbar",
    "kompilerbaras": "kompilerbar",
    "kompilerbarast": "kompilerbar",
    "kompilerbaraste": "kompilerbar",
    "kompilerbarastes": "kompilerbar",
    "kompilerbarasts": "kompilerbar",
    "kompilerbare": "kompilerbar",
    "kompilerbares": "kompilerbar",
    "kompilerbarheten": "kompilerbarhet",
    "kompilerbarhetens": "kompilerbarhet",
    "kompilerbarhets": "kompilerbarhet",
    "kompilerbars": "kompilerbar",
    "kompilerbart": "kompilerbar",
    "kompilerbarts": "kompilerbar",
    "kompileringar": "kompilering",
    "kompileringarna": "kompilering",
    "kompileringarnas": "kompilering",
    "kompileringars": "kompilering",
    "kompileringen": "kompilering",
    "kompileringens": "kompilering",
    "kompilerings": "kompilering",
    "kompisar": "kompis",
    "kompisarna": "kompis",
    "kompisarnas": "kompis",
    "kompisars": "kompis",
    "kompisen": "kompis",
    "kompisens": "kompis",
    "kompisgängen": "kompisgäng",
    "kompisgängens": "kompisgäng",
    "kompisgänget": "kompisgäng",
    "kompisgängets": "kompisgäng",
    "kompisgängs": "kompisgäng",
    "komplediga": "kompledig",
    "kompledigare": "kompledig",
    "kompledigares": "kompledig",
    "kompledigas": "kompledig",
    "kompledigast": "kompledig",
    "kompledigaste": "kompledig",
    "kompledigastes": "kompledig",
    "kompledigasts": "kompledig",
    "kompledige": "kompledig",
    "komplediges": "kompledig",
    "kompledigheten": "kompledighet",
    "kompledighetens": "kompledighet",
    "kompledighets": "kompledighet",
    "kompledigs": "kompledig",
    "kompledigt": "kompledig",
    "kompledigts": "kompledig",
    "komplementen": "komplement",
    "komplementens": "komplement",
    "komplementet": "komplement",
    "komplementets": "komplement",
    "komplementfärgen": "komplementfärg",
    "komplementfärgens": "komplementfärg",
    "komplementfärger": "komplementfärg",
    "komplementfärgerna": "komplementfärg",
    "komplementfärgernas": "komplementfärg",
    "komplementfärgers": "komplementfärg",
    "komplementfärgs": "komplementfärg",
    "komplementmängden": "komplementmängd",
    "komplementmängdens": "komplementmängd",
    "komplementmängder": "komplementmängd",
    "komplementmängderna": "komplementmängd",
    "komplementmängdernas": "komplementmängd",
    "komplementmängders": "komplementmängd",
    "komplementmängds": "komplementmängd",
    "komplements": "komplement",
    "komplementsystemen": "komplementsystem",
    "komplementsystemens": "komplementsystem",
    "komplementsystemet": "komplementsystem",
    "komplementsystemets": "komplementsystem",
    "komplementsystems": "komplementsystem",
    "komplementvinkeln": "komplementvinkel",
    "komplementvinkelns": "komplementvinkel",
    "komplementvinkels": "komplementvinkel",
    "komplementvinklar": "komplementvinkel",
    "komplementvinklarna": "komplementvinkel",
    "komplementvinklarnas": "komplementvinkel",
    "komplementvinklars": "komplementvinkel",
    "komplementära": "komplementär",
    "komplementärare": "komplementär",
    "komplementärares": "komplementär",
    "komplementäras": "komplementär",
    "komplementärast": "komplementär",
    "komplementäraste": "komplementär",
    "komplementärastes": "komplementär",
    "komplementärasts": "komplementär",
    "komplementäre": "komplementär",
    "komplementären": "komplementär",
    "komplementärens": "komplementär",
    "komplementärer": "komplementär",
    "komplementärerna": "komplementär",
    "komplementärernas": "komplementär",
    "komplementärers": "komplementär",
    "komplementäres": "komplementär",
    "komplementärs": "komplementär",
    "komplementärt": "komplementär",
    "komplementärts": "komplementär",
    "kompletta": "komplett",
    "komplettare": "komplett",
    "komplettares": "komplett",
    "komplettas": "komplett",
    "komplettast": "komplett",
    "komplettaste": "komplett",
    "komplettastes": "komplett",
    "komplettasts": "komplett",
    "komplette": "komplett",
    "kompletterad": "komplettera",
    "kompletterade": "komplettera",
    "kompletterades": "komplettera",
    "kompletterads": "komplettera",
    "kompletterande": "komplettera",
    "kompletteranden": "kompletterande",
    "kompletterandena": "kompletterande",
    "kompletterandenas": "kompletterande",
    "kompletterandens": "kompletterande",
    "kompletterandes": "kompletterande",
    "kompletterandet": "kompletterande",
    "kompletterandets": "kompletterande",
    "kompletterar": "komplettera",
    "kompletteras": "komplettera",
    "kompletterat": "komplettera",
    "kompletterats": "komplettera",
    "kompletterbara": "kompletterbar",
    "kompletterbarare": "kompletterbar",
    "kompletterbarares": "kompletterbar",
    "kompletterbaras": "kompletterbar",
    "kompletterbarast": "kompletterbar",
    "kompletterbaraste": "kompletterbar",
    "kompletterbarastes": "kompletterbar",
    "kompletterbarasts": "kompletterbar",
    "kompletterbare": "kompletterbar",
    "kompletterbares": "kompletterbar",
    "kompletterbarheten": "kompletterbarhet",
    "kompletterbarhetens": "kompletterbarhet",
    "kompletterbarhets": "kompletterbarhet",
    "kompletterbars": "kompletterbar",
    "kompletterbart": "kompletterbar",
    "kompletterbarts": "kompletterbar",
    "kompletteringar": "komplettering",
    "kompletteringarna": "komplettering",
    "kompletteringarnas": "komplettering",
    "kompletteringars": "komplettering",
    "kompletteringen": "komplettering",
    "kompletteringens": "komplettering",
    "kompletterings": "komplettering",
    "kompletteringspropositionen": "kompletteringsproposition",
    "kompletteringspropositionens": "kompletteringsproposition",
    "kompletteringspropositioner": "kompletteringsproposition",
    "kompletteringspropositionerna": "kompletteringsproposition",
    "kompletteringspropositionernas": "kompletteringsproposition",
    "kompletteringspropositioners": "kompletteringsproposition",
    "kompletteringspropositions": "kompletteringsproposition",
    "kompletteringstesten": "kompletteringstest",
    "kompletteringstestens": "kompletteringstest",
    "kompletteringstester": "kompletteringstest",
    "kompletteringstesterna": "kompletteringstest",
    "kompletteringstesternas": "kompletteringstest",
    "kompletteringstesters": "kompletteringstest",
    "kompletteringstestet": "kompletteringstest",
    "kompletteringstestets": "kompletteringstest",
    "kompletteringstests": "kompletteringstest",
    "komplettes": "komplett",
    "komplettheten": "kompletthet",
    "kompletthetens": "kompletthet",
    "kompletthets": "kompletthet",
    "kompletts": "komplett",
    "komplexa": "komplex",
    "komplexare": "komplex",
    "komplexares": "komplex",
    "komplexas": "komplex",
    "komplexast": "komplex",
    "komplexaste": "komplex",
    "komplexastes": "komplex",
    "komplexasts": "komplex",
    "komplexe": "komplex",
    "komplexen": "komplex",
    "komplexens": "komplex",
    "komplexes": "komplex",
    "komplexet": "komplex",
    "komplexets": "komplex",
    "komplexheten": "komplexhet",
    "komplexhetens": "komplexhet",
    "komplexhets": "komplexhet",
    "komplexiga": "komplexig",
    "komplexigare": "komplexig",
    "komplexigares": "komplexig",
    "komplexigas": "komplexig",
    "komplexigast": "komplexig",
    "komplexigaste": "komplexig",
    "komplexigastes": "komplexig",
    "komplexigasts": "komplexig",
    "komplexige": "komplexig",
    "komplexiges": "komplexig",
    "komplexigs": "komplexig",
    "komplexigt": "komplexig",
    "komplexigts": "komplexig",
    "komplexiteten": "komplexitet",
    "komplexitetens": "komplexitet",
    "komplexiteter": "komplexitet",
    "komplexiteterna": "komplexitet",
    "komplexiteternas": "komplexitet",
    "komplexiteters": "komplexitet",
    "komplexitets": "komplexitet",
    "komplext": "komplex",
    "komplexts": "komplex",
    "komplicerad": "komplicera",
    "komplicerade": "komplicerad",
    "komplicerades": "komplicerad",
    "komplicerads": "komplicerad",
    "komplicerande": "komplicera",
    "kompliceranden": "komplicerande",
    "komplicerandena": "komplicerande",
    "komplicerandenas": "komplicerande",
    "komplicerandens": "komplicerande",
    "komplicerandes": "komplicerande",
    "komplicerandet": "komplicerande",
    "komplicerandets": "komplicerande",
    "komplicerar": "komplicera",
    "kompliceras": "komplicera",
    "komplicerat": "komplicerad",
    "komplicerats": "komplicerad",
    "komplicerbara": "komplicerbar",
    "komplicerbarare": "komplicerbar",
    "komplicerbarares": "komplicerbar",
    "komplicerbaras": "komplicerbar",
    "komplicerbarast": "komplicerbar",
    "komplicerbaraste": "komplicerbar",
    "komplicerbarastes": "komplicerbar",
    "komplicerbarasts": "komplicerbar",
    "komplicerbare": "komplicerbar",
    "komplicerbares": "komplicerbar",
    "komplicerbarheten": "komplicerbarhet",
    "komplicerbarhetens": "komplicerbarhet",
    "komplicerbarhets": "komplicerbarhet",
    "komplicerbars": "komplicerbar",
    "komplicerbart": "komplicerbar",
    "komplicerbarts": "komplicerbar",
    "kompliceringar": "komplicering",
    "kompliceringarna": "komplicering",
    "kompliceringarnas": "komplicering",
    "kompliceringars": "komplicering",
    "kompliceringen": "komplicering",
    "kompliceringens": "komplicering",
    "komplicerings": "komplicering",
    "komplikationen": "komplikation",
    "komplikationens": "komplikation",
    "komplikationer": "komplikation",
    "komplikationerna": "komplikation",
    "komplikationernas": "komplikation",
    "komplikationers": "komplikation",
    "komplikations": "komplikation",
    "komplimangen": "komplimang",
    "komplimangens": "komplimang",
    "komplimanger": "komplimang",
    "komplimangerna": "komplimang",
    "komplimangernas": "komplimang",
    "komplimangers": "komplimang",
    "komplimangs": "komplimang",
    "komplimenterad": "komplimentera",
    "komplimenterade": "komplimentera",
    "komplimenterades": "komplimentera",
    "komplimenterads": "komplimentera",
    "komplimenterande": "komplimentera",
    "komplimenteranden": "komplimenterande",
    "komplimenterandena": "komplimenterande",
    "komplimenterandenas": "komplimenterande",
    "komplimenterandens": "komplimenterande",
    "komplimenterandes": "komplimenterande",
    "komplimenterandet": "komplimenterande",
    "komplimenterandets": "komplimenterande",
    "komplimenterar": "komplimentera",
    "komplimenteras": "komplimentera",
    "komplimenterat": "komplimentera",
    "komplimenterats": "komplimentera",
    "komplimenterbara": "komplimenterbar",
    "komplimenterbarare": "komplimenterbar",
    "komplimenterbarares": "komplimenterbar",
    "komplimenterbaras": "komplimenterbar",
    "komplimenterbarast": "komplimenterbar",
    "komplimenterbaraste": "komplimenterbar",
    "komplimenterbarastes": "komplimenterbar",
    "komplimenterbarasts": "komplimenterbar",
    "komplimenterbare": "komplimenterbar",
    "komplimenterbares": "komplimenterbar",
    "komplimenterbarheten": "komplimenterbarhet",
    "komplimenterbarhetens": "komplimenterbarhet",
    "komplimenterbarhets": "komplimenterbarhet",
    "komplimenterbars": "komplimenterbar",
    "komplimenterbart": "komplimenterbar",
    "komplimenterbarts": "komplimenterbar",
    "komplimenteringar": "komplimentering",
    "komplimenteringarna": "komplimentering",
    "komplimenteringarnas": "komplimentering",
    "komplimenteringars": "komplimentering",
    "komplimenteringen": "komplimentering",
    "komplimenteringens": "komplimentering",
    "komplimenterings": "komplimentering",
    "komplotten": "komplott",
    "komplottens": "komplott",
    "komplotter": "komplott",
    "komplotterna": "komplott",
    "komplotternas": "komplott",
    "komplotters": "komplott",
    "komplotts": "komplott",
    "komponenten": "komponent",
    "komponentens": "komponent",
    "komponenter": "komponent",
    "komponenterna": "komponent",
    "komponenternas": "komponent",
    "komponenters": "komponent",
    "komponents": "komponent",
    "komponerad": "komponera",
    "komponerade": "komponera",
    "komponerades": "komponera",
    "komponerads": "komponera",
    "komponerande": "komponera",
    "komponeranden": "komponerande",
    "komponerandena": "komponerande",
    "komponerandenas": "komponerande",
    "komponerandens": "komponerande",
    "komponerandes": "komponerande",
    "komponerandet": "komponerande",
    "komponerandets": "komponerande",
    "komponerar": "komponera",
    "komponeras": "komponera",
    "komponerat": "komponera",
    "komponerats": "komponera",
    "komponerbara": "komponerbar",
    "komponerbarare": "komponerbar",
    "komponerbarares": "komponerbar",
    "komponerbaras": "komponerbar",
    "komponerbarast": "komponerbar",
    "komponerbaraste": "komponerbar",
    "komponerbarastes": "komponerbar",
    "komponerbarasts": "komponerbar",
    "komponerbare": "komponerbar",
    "komponerbares": "komponerbar",
    "komponerbarheten": "komponerbarhet",
    "komponerbarhetens": "komponerbarhet",
    "komponerbarhets": "komponerbarhet",
    "komponerbars": "komponerbar",
    "komponerbart": "komponerbar",
    "komponerbarts": "komponerbar",
    "komponeringar": "komponering",
    "komponeringarna": "komponering",
    "komponeringarnas": "komponering",
    "komponeringars": "komponering",
    "komponeringen": "komponering",
    "komponeringens": "komponering",
    "komponerings": "komponering",
    "komponisten": "komponist",
    "komponistens": "komponist",
    "komponister": "komponist",
    "komponisterna": "komponist",
    "komponisternas": "komponist",
    "komponisters": "komponist",
    "komponists": "komponist",
    "komposanten": "komposant",
    "komposantens": "komposant",
    "komposanter": "komposant",
    "komposanterna": "komposant",
    "komposanternas": "komposant",
    "komposanters": "komposant",
    "komposants": "komposant",
    "komposita": "kompositum",
    "kompositas": "kompositum",
    "kompositen": "komposit",
    "kompositens": "komposit",
    "kompositer": "kompositum",
    "kompositerna": "kompositum",
    "kompositernas": "kompositum",
    "kompositers": "kompositum",
    "kompositet": "kompositum",
    "kompositets": "kompositum",
    "kompositionen": "komposition",
    "kompositionens": "komposition",
    "kompositioner": "komposition",
    "kompositionerna": "komposition",
    "kompositionernas": "komposition",
    "kompositioners": "komposition",
    "kompositions": "komposition",
    "kompositmaterialen": "kompositmaterial",
    "kompositmaterialens": "kompositmaterial",
    "kompositmaterialet": "kompositmaterial",
    "kompositmaterialets": "kompositmaterial",
    "kompositmaterials": "kompositmaterial",
    "komposits": "komposit",
    "kompositstockar": "kompositstock",
    "kompositstockarna": "kompositstock",
    "kompositstockarnas": "kompositstock",
    "kompositstockars": "kompositstock",
    "kompositstocken": "kompositstock",
    "kompositstockens": "kompositstock",
    "kompositstocks": "kompositstock",
    "kompositums": "kompositum",
    "kompositören": "kompositör",
    "kompositörens": "kompositör",
    "kompositörer": "kompositör",
    "kompositörerna": "kompositör",
    "kompositörernas": "kompositör",
    "kompositörers": "kompositör",
    "kompositörs": "kompositör",
    "komposten": "kompost",
    "kompostens": "kompost",
    "komposter": "kompost",
    "komposterad": "kompostera",
    "komposterade": "kompostera",
    "komposterades": "kompostera",
    "komposterads": "kompostera",
    "komposterande": "kompostera",
    "komposteranden": "komposterande",
    "komposterandena": "komposterande",
    "komposterandenas": "komposterande",
    "komposterandens": "komposterande",
    "komposterandes": "komposterande",
    "komposterandet": "komposterande",
    "komposterandets": "komposterande",
    "komposterar": "kompostera",
    "komposteras": "kompostera",
    "komposterat": "kompostera",
    "komposterats": "kompostera",
    "komposterbara": "komposterbar",
    "komposterbarare": "komposterbar",
    "komposterbarares": "komposterbar",
    "komposterbaras": "komposterbar",
    "komposterbarast": "komposterbar",
    "komposterbaraste": "komposterbar",
    "komposterbarastes": "komposterbar",
    "komposterbarasts": "komposterbar",
    "komposterbare": "komposterbar",
    "komposterbares": "komposterbar",
    "komposterbarheten": "komposterbarhet",
    "komposterbarhetens": "komposterbarhet",
    "komposterbarhets": "komposterbarhet",
    "komposterbars": "komposterbar",
    "komposterbart": "komposterbar",
    "komposterbarts": "komposterbar",
    "komposteringar": "kompostering",
    "komposteringarna": "kompostering",
    "komposteringarnas": "kompostering",
    "komposteringars": "kompostering",
    "komposteringen": "kompostering",
    "komposteringens": "kompostering",
    "komposterings": "kompostering",
    "komposteringsbara": "komposteringsbar",
    "komposteringsbarare": "komposteringsbar",
    "komposteringsbarares": "komposteringsbar",
    "komposteringsbaras": "komposteringsbar",
    "komposteringsbarast": "komposteringsbar",
    "komposteringsbaraste": "komposteringsbar",
    "komposteringsbarastes": "komposteringsbar",
    "komposteringsbarasts": "komposteringsbar",
    "komposteringsbare": "komposteringsbar",
    "komposteringsbares": "komposteringsbar",
    "komposteringsbarheten": "komposteringsbarhet",
    "komposteringsbarhetens": "komposteringsbarhet",
    "komposteringsbarhets": "komposteringsbarhet",
    "komposteringsbars": "komposteringsbar",
    "komposteringsbart": "komposteringsbar",
    "komposteringsbarts": "komposteringsbar",
    "komposterna": "kompost",
    "komposternas": "kompost",
    "komposters": "kompost",
    "kompostkvarnar": "kompostkvarn",
    "kompostkvarnarna": "kompostkvarn",
    "kompostkvarnarnas": "kompostkvarn",
    "kompostkvarnars": "kompostkvarn",
    "kompostkvarnen": "kompostkvarn",
    "kompostkvarnens": "kompostkvarn",
    "kompostkvarns": "kompostkvarn",
    "komposts": "kompost",
    "kompotten": "kompott",
    "kompottens": "kompott",
    "kompotter": "kompott",
    "kompotterna": "kompott",
    "kompotternas": "kompott",
    "kompotters": "kompott",
    "kompotts": "kompott",
    "kompoundkärn": "kompoundkärna",
    "kompoundkärnan": "kompoundkärna",
    "kompoundkärnans": "kompoundkärna",
    "kompoundkärnas": "kompoundkärna",
    "kompoundkärne": "kompoundkärna",
    "kompoundkärnor": "kompoundkärna",
    "kompoundkärnorna": "kompoundkärna",
    "kompoundkärnornas": "kompoundkärna",
    "kompoundkärnors": "kompoundkärna",
    "kompoundkärns": "kompoundkärna",
    "kompressen": "kompress",
    "kompressens": "kompress",
    "kompresser": "kompress",
    "kompresserna": "kompress",
    "kompressernas": "kompress",
    "kompressers": "kompress",
    "kompressionen": "kompression",
    "kompressionens": "kompression",
    "kompressioner": "kompression",
    "kompressionerna": "kompression",
    "kompressionernas": "kompression",
    "kompressioners": "kompression",
    "kompressions": "kompression",
    "kompressorer": "kompressor",
    "kompressorerna": "kompressor",
    "kompressorernas": "kompressor",
    "kompressorers": "kompressor",
    "kompressorn": "kompressor",
    "kompressorns": "kompressor",
    "kompressors": "kompressor",
    "komprimatorer": "komprimator",
    "komprimatorerna": "komprimator",
    "komprimatorernas": "komprimator",
    "komprimatorers": "komprimator",
    "komprimatorn": "komprimator",
    "komprimatorns": "komprimator",
    "komprimators": "komprimator",
    "komprimerad": "komprimera",
    "komprimerade": "komprimera",
    "komprimerades": "komprimera",
    "komprimerads": "komprimera",
    "komprimerande": "komprimera",
    "komprimeranden": "komprimerande",
    "komprimerandena": "komprimerande",
    "komprimerandenas": "komprimerande",
    "komprimerandens": "komprimerande",
    "komprimerandes": "komprimerande",
    "komprimerandet": "komprimerande",
    "komprimerandets": "komprimerande",
    "komprimerar": "komprimera",
    "komprimeras": "komprimera",
    "komprimerat": "komprimera",
    "komprimerats": "komprimera",
    "komprimerbara": "komprimerbar",
    "komprimerbarare": "komprimerbar",
    "komprimerbarares": "komprimerbar",
    "komprimerbaras": "komprimerbar",
    "komprimerbarast": "komprimerbar",
    "komprimerbaraste": "komprimerbar",
    "komprimerbarastes": "komprimerbar",
    "komprimerbarasts": "komprimerbar",
    "komprimerbare": "komprimerbar",
    "komprimerbares": "komprimerbar",
    "komprimerbarheten": "komprimerbarhet",
    "komprimerbarhetens": "komprimerbarhet",
    "komprimerbarhets": "komprimerbarhet",
    "komprimerbars": "komprimerbar",
    "komprimerbart": "komprimerbar",
    "komprimerbarts": "komprimerbar",
    "komprimeringar": "komprimering",
    "komprimeringarna": "komprimering",
    "komprimeringarnas": "komprimering",
    "komprimeringars": "komprimering",
    "komprimeringen": "komprimering",
    "komprimeringens": "komprimering",
    "komprimerings": "komprimering",
    "komprometterad": "kompromettera",
    "komprometterade": "kompromettera",
    "komprometterades": "kompromettera",
    "komprometterads": "kompromettera",
    "komprometterande": "kompromettera",
    "komprometteranden": "komprometterande",
    "komprometterandena": "komprometterande",
    "komprometterandenas": "komprometterande",
    "komprometterandens": "komprometterande",
    "komprometterandes": "komprometterande",
    "komprometterandet": "komprometterande",
    "komprometterandets": "komprometterande",
    "komprometterar": "kompromettera",
    "komprometteras": "kompromettera",
    "komprometterat": "kompromettera",
    "komprometterats": "kompromettera",
    "komprometterbara": "komprometterbar",
    "komprometterbarare": "komprometterbar",
    "komprometterbarares": "komprometterbar",
    "komprometterbaras": "komprometterbar",
    "komprometterbarast": "komprometterbar",
    "komprometterbaraste": "komprometterbar",
    "komprometterbarastes": "komprometterbar",
    "komprometterbarasts": "komprometterbar",
    "komprometterbare": "komprometterbar",
    "komprometterbares": "komprometterbar",
    "komprometterbarheten": "komprometterbarhet",
    "komprometterbarhetens": "komprometterbarhet",
    "komprometterbarhets": "komprometterbarhet",
    "komprometterbars": "komprometterbar",
    "komprometterbart": "komprometterbar",
    "komprometterbarts": "komprometterbar",
    "komprometteringar": "kompromettering",
    "komprometteringarna": "kompromettering",
    "komprometteringarnas": "kompromettering",
    "komprometteringars": "kompromettering",
    "komprometteringen": "kompromettering",
    "komprometteringens": "kompromettering",
    "komprometterings": "kompromettering",
    "kompromissade": "kompromissa",
    "kompromissades": "kompromissa",
    "kompromissande": "kompromissa",
    "kompromissanden": "kompromissande",
    "kompromissandena": "kompromissande",
    "kompromissandenas": "kompromissande",
    "kompromissandens": "kompromissande",
    "kompromissandes": "kompromissande",
    "kompromissandet": "kompromissande",
    "kompromissandets": "kompromissande",
    "kompromissar": "kompromissa",
    "kompromissas": "kompromissa",
    "kompromissat": "kompromissa",
    "kompromissats": "kompromissa",
    "kompromissen": "kompromiss",
    "kompromissens": "kompromiss",
    "kompromisser": "kompromiss",
    "kompromisserna": "kompromiss",
    "kompromissernas": "kompromiss",
    "kompromissers": "kompromiss",
    "kompromisslösa": "kompromisslös",
    "kompromisslösare": "kompromisslös",
    "kompromisslösares": "kompromisslös",
    "kompromisslösas": "kompromisslös",
    "kompromisslösast": "kompromisslös",
    "kompromisslösaste": "kompromisslös",
    "kompromisslösastes": "kompromisslös",
    "kompromisslösasts": "kompromisslös",
    "kompromisslöse": "kompromisslös",
    "kompromisslöses": "kompromisslös",
    "kompromisslöst": "kompromisslös",
    "kompromisslösts": "kompromisslös",
    "komps": "komp",
    "kompulsiva": "kompulsiv",
    "kompulsivare": "kompulsiv",
    "kompulsivares": "kompulsiv",
    "kompulsivas": "kompulsiv",
    "kompulsivast": "kompulsiv",
    "kompulsivaste": "kompulsiv",
    "kompulsivastes": "kompulsiv",
    "kompulsivasts": "kompulsiv",
    "kompulsive": "kompulsiv",
    "kompulsives": "kompulsiv",
    "kompulsivs": "kompulsiv",
    "kompulsivt": "kompulsiv",
    "kompulsivts": "kompulsiv",
    "komputationella": "komputationell",
    "komputationellare": "komputationell",
    "komputationellares": "komputationell",
    "komputationellas": "komputationell",
    "komputationellast": "komputationell",
    "komputationellaste": "komputationell",
    "komputationellastes": "komputationell",
    "komputationellasts": "komputationell",
    "komputationelle": "komputationell",
    "komputationelles": "komputationell",
    "komputationells": "komputationell",
    "komputationellt": "komputationell",
    "komputationellts": "komputationell",
    "koms": "komma",
    "kon": "kona",
    "konan": "kona",
    "konans": "kona",
    "konas": "kona",
    "koncentraten": "koncentrat",
    "koncentratens": "koncentrat",
    "koncentratet": "koncentrat",
    "koncentratets": "koncentrat",
    "koncentrationen": "koncentration",
    "koncentrationens": "koncentration",
    "koncentrationer": "koncentration",
    "koncentrationerna": "koncentration",
    "koncentrationernas": "koncentration",
    "koncentrationers": "koncentration",
    "koncentrations": "koncentration",
    "koncentrationsdagar": "koncentrationsdag",
    "koncentrationsdagarna": "koncentrationsdag",
    "koncentrationsdagarnas": "koncentrationsdag",
    "koncentrationsdagars": "koncentrationsdag",
    "koncentrationsdagen": "koncentrationsdag",
    "koncentrationsdagens": "koncentrationsdag",
    "koncentrationsdags": "koncentrationsdag",
    "koncentrationslägerna": "koncentrationsläger",
    "koncentrationslägernas": "koncentrationsläger",
    "koncentrationslägers": "koncentrationsläger",
    "koncentrationslägren": "koncentrationsläger",
    "koncentrationslägrens": "koncentrationsläger",
    "koncentrationslägret": "koncentrationsläger",
    "koncentrationslägrets": "koncentrationsläger",
    "koncentrationsläsningar": "koncentrationsläsning",
    "koncentrationsläsningarna": "koncentrationsläsning",
    "koncentrationsläsningarnas": "koncentrationsläsning",
    "koncentrationsläsningars": "koncentrationsläsning",
    "koncentrationsläsningen": "koncentrationsläsning",
    "koncentrationsläsningens": "koncentrationsläsning",
    "koncentrationsläsnings": "koncentrationsläsning",
    "koncentrationsstörningar": "koncentrationsstörning",
    "koncentrationsstörningarna": "koncentrationsstörning",
    "koncentrationsstörningarnas": "koncentrationsstörning",
    "koncentrationsstörningars": "koncentrationsstörning",
    "koncentrationsstörningen": "koncentrationsstörning",
    "koncentrationsstörningens": "koncentrationsstörning",
    "koncentrationsstörnings": "koncentrationsstörning",
    "koncentrats": "koncentrat",
    "koncentrerad": "koncentrera",
    "koncentrerade": "koncentrera",
    "koncentrerades": "koncentrera",
    "koncentrerads": "koncentrera",
    "koncentrerande": "koncentrera",
    "koncentreranden": "koncentrerande",
    "koncentrerandena": "koncentrerande",
    "koncentrerandenas": "koncentrerande",
    "koncentrerandens": "koncentrerande",
    "koncentrerandes": "koncentrerande",
    "koncentrerandet": "koncentrerande",
    "koncentrerandets": "koncentrerande",
    "koncentrerar": "koncentrera",
    "koncentreras": "koncentrera",
    "koncentrerat": "koncentrera",
    "koncentrerats": "koncentrera",
    "koncentrerbara": "koncentrerbar",
    "koncentrerbarare": "koncentrerbar",
    "koncentrerbarares": "koncentrerbar",
    "koncentrerbaras": "koncentrerbar",
    "koncentrerbarast": "koncentrerbar",
    "koncentrerbaraste": "koncentrerbar",
    "koncentrerbarastes": "koncentrerbar",
    "koncentrerbarasts": "koncentrerbar",
    "koncentrerbare": "koncentrerbar",
    "koncentrerbares": "koncentrerbar",
    "koncentrerbarheten": "koncentrerbarhet",
    "koncentrerbarhetens": "koncentrerbarhet",
    "koncentrerbarhets": "koncentrerbarhet",
    "koncentrerbars": "koncentrerbar",
    "koncentrerbart": "koncentrerbar",
    "koncentrerbarts": "koncentrerbar",
    "koncentreringar": "koncentrering",
    "koncentreringarna": "koncentrering",
    "koncentreringarnas": "koncentrering",
    "koncentreringars": "koncentrering",
    "koncentreringen": "koncentrering",
    "koncentreringens": "koncentrering",
    "koncentrerings": "koncentrering",
    "koncentriska": "koncentrisk",
    "koncentriskare": "koncentrisk",
    "koncentriskares": "koncentrisk",
    "koncentriskas": "koncentrisk",
    "koncentriskast": "koncentrisk",
    "koncentriskaste": "koncentrisk",
    "koncentriskastes": "koncentrisk",
    "koncentriskasts": "koncentrisk",
    "koncentriske": "koncentrisk",
    "koncentriskes": "koncentrisk",
    "koncentrisks": "koncentrisk",
    "koncentriskt": "koncentrisk",
    "koncentriskts": "koncentrisk",
    "koncepten": "koncept",
    "konceptens": "koncept",
    "koncepter": "koncept",
    "koncepterna": "koncept",
    "koncepternas": "koncept",
    "koncepters": "koncept",
    "konceptet": "koncept",
    "konceptets": "koncept",
    "konceptionen": "konception",
    "konceptionens": "konception",
    "konceptioner": "konception",
    "konceptionerna": "konception",
    "konceptionernas": "konception",
    "konceptioners": "konception",
    "konceptions": "konception",
    "konceptiva": "konceptiv",
    "konceptivare": "konceptiv",
    "konceptivares": "konceptiv",
    "konceptivas": "konceptiv",
    "konceptivast": "konceptiv",
    "konceptivaste": "konceptiv",
    "konceptivastes": "konceptiv",
    "konceptivasts": "konceptiv",
    "konceptive": "konceptiv",
    "konceptives": "konceptiv",
    "konceptivs": "konceptiv",
    "konceptivt": "konceptiv",
    "konceptivts": "konceptiv",
    "konceptpapperen": "konceptpapper",
    "konceptpapperens": "konceptpapper",
    "konceptpapperet": "konceptpapper",
    "konceptpapperets": "konceptpapper",
    "konceptpapperna": "konceptpapper",
    "konceptpappernas": "konceptpapper",
    "konceptpappers": "konceptpapper",
    "konceptpappren": "konceptpapper",
    "konceptpapprens": "konceptpapper",
    "konceptpappret": "konceptpapper",
    "konceptpapprets": "konceptpapper",
    "koncepts": "koncept",
    "konceptuella": "konceptuell",
    "konceptuellare": "konceptuell",
    "konceptuellares": "konceptuell",
    "konceptuellas": "konceptuell",
    "konceptuellast": "konceptuell",
    "konceptuellaste": "konceptuell",
    "konceptuellastes": "konceptuell",
    "konceptuellasts": "konceptuell",
    "konceptuelle": "konceptuell",
    "konceptuelles": "konceptuell",
    "konceptuells": "konceptuell",
    "konceptuellt": "konceptuell",
    "konceptuellts": "konceptuell",
    "koncernen": "koncern",
    "koncernens": "koncern",
    "koncerner": "koncern",
    "koncernerna": "koncern",
    "koncernernas": "koncern",
    "koncerners": "koncern",
    "koncernledningar": "koncernledning",
    "koncernledningarna": "koncernledning",
    "koncernledningarnas": "koncernledning",
    "koncernledningars": "koncernledning",
    "koncernledningen": "koncernledning",
    "koncernledningens": "koncernledning",
    "koncernlednings": "koncernledning",
    "koncernmässiga": "koncernmässig",
    "koncernmässigare": "koncernmässig",
    "koncernmässigares": "koncernmässig",
    "koncernmässigas": "koncernmässig",
    "koncernmässigast": "koncernmässig",
    "koncernmässigaste": "koncernmässig",
    "koncernmässigastes": "koncernmässig",
    "koncernmässigasts": "koncernmässig",
    "koncernmässige": "koncernmässig",
    "koncernmässiges": "koncernmässig",
    "koncernmässigs": "koncernmässig",
    "koncernmässigt": "koncernmässig",
    "koncernmässigts": "koncernmässig",
    "koncerns": "koncern",
    "koncessionen": "koncession",
    "koncessionens": "koncession",
    "koncessioner": "koncession",
    "koncessionerad": "koncessionera",
    "koncessionerade": "koncessionera",
    "koncessionerades": "koncessionera",
    "koncessionerads": "koncessionera",
    "koncessionerande": "koncessionera",
    "koncessioneranden": "koncessionerande",
    "koncessionerandena": "koncessionerande",
    "koncessionerandenas": "koncessionerande",
    "koncessionerandens": "koncessionerande",
    "koncessionerandes": "koncessionerande",
    "koncessionerandet": "koncessionerande",
    "koncessionerandets": "koncessionerande",
    "koncessionerar": "koncessionera",
    "koncessioneras": "koncessionera",
    "koncessionerat": "koncessionera",
    "koncessionerats": "koncessionera",
    "koncessionerbara": "koncessionerbar",
    "koncessionerbarare": "koncessionerbar",
    "koncessionerbarares": "koncessionerbar",
    "koncessionerbaras": "koncessionerbar",
    "koncessionerbarast": "koncessionerbar",
    "koncessionerbaraste": "koncessionerbar",
    "koncessionerbarastes": "koncessionerbar",
    "koncessionerbarasts": "koncessionerbar",
    "koncessionerbare": "koncessionerbar",
    "koncessionerbares": "koncessionerbar",
    "koncessionerbarheten": "koncessionerbarhet",
    "koncessionerbarhetens": "koncessionerbarhet",
    "koncessionerbarhets": "koncessionerbarhet",
    "koncessionerbars": "koncessionerbar",
    "koncessionerbart": "koncessionerbar",
    "koncessionerbarts": "koncessionerbar",
    "koncessioneringar": "koncessionering",
    "koncessioneringarna": "koncessionering",
    "koncessioneringarnas": "koncessionering",
    "koncessioneringars": "koncessionering",
    "koncessioneringen": "koncessionering",
    "koncessioneringens": "koncessionering",
    "koncessionerings": "koncessionering",
    "koncessionerna": "koncession",
    "koncessionernas": "koncession",
    "koncessioners": "koncession",
    "koncessions": "koncession",
    "koncessionsavgiften": "koncessionsavgift",
    "koncessionsavgiftens": "koncessionsavgift",
    "koncessionsavgifter": "koncessionsavgift",
    "koncessionsavgifterna": "koncessionsavgift",
    "koncessionsavgifternas": "koncessionsavgift",
    "koncessionsavgifters": "koncessionsavgift",
    "koncessionsavgifts": "koncessionsavgift",
    "koncessiva": "koncessiv",
    "koncessivare": "koncessiv",
    "koncessivares": "koncessiv",
    "koncessivas": "koncessiv",
    "koncessivast": "koncessiv",
    "koncessivaste": "koncessiv",
    "koncessivastes": "koncessiv",
    "koncessivasts": "koncessiv",
    "koncessive": "koncessiv",
    "koncessives": "koncessiv",
    "koncessivs": "koncessiv",
    "koncessivt": "koncessiv",
    "koncessivts": "koncessiv",
    "konciliansen": "koncilians",
    "konciliansens": "koncilians",
    "koncilianta": "konciliant",
    "konciliantare": "konciliant",
    "konciliantares": "konciliant",
    "konciliantas": "konciliant",
    "konciliantast": "konciliant",
    "konciliantaste": "konciliant",
    "konciliantastes": "konciliant",
    "konciliantasts": "konciliant",
    "konciliante": "konciliant",
    "konciliantes": "konciliant",
    "konciliants": "konciliant",
    "koncipierad": "koncipiera",
    "koncipierade": "koncipiera",
    "koncipierades": "koncipiera",
    "koncipierads": "koncipiera",
    "koncipierande": "koncipiera",
    "koncipieranden": "koncipierande",
    "koncipierandena": "koncipierande",
    "koncipierandenas": "koncipierande",
    "koncipierandens": "koncipierande",
    "koncipierandes": "koncipierande",
    "koncipierandet": "koncipierande",
    "koncipierandets": "koncipierande",
    "koncipierar": "koncipiera",
    "koncipieras": "koncipiera",
    "koncipierat": "koncipiera",
    "koncipierats": "koncipiera",
    "koncipierbara": "koncipierbar",
    "koncipierbarare": "koncipierbar",
    "koncipierbarares": "koncipierbar",
    "koncipierbaras": "koncipierbar",
    "koncipierbarast": "koncipierbar",
    "koncipierbaraste": "koncipierbar",
    "koncipierbarastes": "koncipierbar",
    "koncipierbarasts": "koncipierbar",
    "koncipierbare": "koncipierbar",
    "koncipierbares": "koncipierbar",
    "koncipierbarheten": "koncipierbarhet",
    "koncipierbarhetens": "koncipierbarhet",
    "koncipierbarhets": "koncipierbarhet",
    "koncipierbars": "koncipierbar",
    "koncipierbart": "koncipierbar",
    "koncipierbarts": "koncipierbar",
    "koncipieringar": "koncipiering",
    "koncipieringarna": "koncipiering",
    "koncipieringarnas": "koncipiering",
    "koncipieringars": "koncipiering",
    "koncipieringen": "koncipiering",
    "koncipieringens": "koncipiering",
    "koncipierings": "koncipiering",
    "koncisa": "koncis",
    "koncisare": "koncis",
    "koncisares": "koncis",
    "koncisas": "koncis",
    "koncisast": "koncis",
    "koncisaste": "koncis",
    "koncisastes": "koncis",
    "koncisasts": "koncis",
    "koncise": "koncis",
    "koncises": "koncis",
    "koncisheten": "koncishet",
    "koncishetens": "koncishet",
    "koncishets": "koncishet",
    "koncist": "koncis",
    "koncists": "koncis",
    "kondemnerad": "kondemnera",
    "kondemnerade": "kondemnera",
    "kondemnerades": "kondemnera",
    "kondemnerads": "kondemnera",
    "kondemnerande": "kondemnera",
    "kondemneranden": "kondemnerande",
    "kondemnerandena": "kondemnerande",
    "kondemnerandenas": "kondemnerande",
    "kondemnerandens": "kondemnerande",
    "kondemnerandes": "kondemnerande",
    "kondemnerandet": "kondemnerande",
    "kondemnerandets": "kondemnerande",
    "kondemnerar": "kondemnera",
    "kondemneras": "kondemnera",
    "kondemnerat": "kondemnera",
    "kondemnerats": "kondemnera",
    "kondemnerbara": "kondemnerbar",
    "kondemnerbarare": "kondemnerbar",
    "kondemnerbarares": "kondemnerbar",
    "kondemnerbaras": "kondemnerbar",
    "kondemnerbarast": "kondemnerbar",
    "kondemnerbaraste": "kondemnerbar",
    "kondemnerbarastes": "kondemnerbar",
    "kondemnerbarasts": "kondemnerbar",
    "kondemnerbare": "kondemnerbar",
    "kondemnerbares": "kondemnerbar",
    "kondemnerbarheten": "kondemnerbarhet",
    "kondemnerbarhetens": "kondemnerbarhet",
    "kondemnerbarhets": "kondemnerbarhet",
    "kondemnerbars": "kondemnerbar",
    "kondemnerbart": "kondemnerbar",
    "kondemnerbarts": "kondemnerbar",
    "kondemneringar": "kondemnering",
    "kondemneringarna": "kondemnering",
    "kondemneringarnas": "kondemnering",
    "kondemneringars": "kondemnering",
    "kondemneringen": "kondemnering",
    "kondemneringens": "kondemnering",
    "kondemnerings": "kondemnering",
    "kondensaten": "kondensat",
    "kondensatens": "kondensat",
    "kondensatet": "kondensat",
    "kondensatets": "kondensat",
    "kondensationen": "kondensation",
    "kondensationens": "kondensation",
    "kondensationer": "kondensation",
    "kondensationerna": "kondensation",
    "kondensationernas": "kondensation",
    "kondensationers": "kondensation",
    "kondensations": "kondensation",
    "kondensationskärn": "kondensationskärna",
    "kondensationskärnan": "kondensationskärna",
    "kondensationskärnans": "kondensationskärna",
    "kondensationskärnas": "kondensationskärna",
    "kondensationskärne": "kondensationskärna",
    "kondensationskärnor": "kondensationskärna",
    "kondensationskärnorna": "kondensationskärna",
    "kondensationskärnornas": "kondensationskärna",
    "kondensationskärnors": "kondensationskärna",
    "kondensationskärns": "kondensationskärna",
    "kondensatorer": "kondensator",
    "kondensatorerna": "kondensator",
    "kondensatorernas": "kondensator",
    "kondensatorers": "kondensator",
    "kondensatorn": "kondensator",
    "kondensatorns": "kondensator",
    "kondensators": "kondensator",
    "kondensats": "kondensat",
    "kondensen": "kondens",
    "kondensens": "kondens",
    "kondenserad": "kondensera",
    "kondenserade": "kondensera",
    "kondenserades": "kondensera",
    "kondenserads": "kondensera",
    "kondenserande": "kondensera",
    "kondenseranden": "kondenserande",
    "kondenserandena": "kondenserande",
    "kondenserandenas": "kondenserande",
    "kondenserandens": "kondenserande",
    "kondenserandes": "kondenserande",
    "kondenserandet": "kondenserande",
    "kondenserandets": "kondenserande",
    "kondenserar": "kondensera",
    "kondenseras": "kondensera",
    "kondenserat": "kondensera",
    "kondenserats": "kondensera",
    "kondenserbara": "kondenserbar",
    "kondenserbarare": "kondenserbar",
    "kondenserbarares": "kondenserbar",
    "kondenserbaras": "kondenserbar",
    "kondenserbarast": "kondenserbar",
    "kondenserbaraste": "kondenserbar",
    "kondenserbarastes": "kondenserbar",
    "kondenserbarasts": "kondenserbar",
    "kondenserbare": "kondenserbar",
    "kondenserbares": "kondenserbar",
    "kondenserbarheten": "kondenserbarhet",
    "kondenserbarhetens": "kondenserbarhet",
    "kondenserbarhets": "kondenserbarhet",
    "kondenserbars": "kondenserbar",
    "kondenserbart": "kondenserbar",
    "kondenserbarts": "kondenserbar",
    "kondenseringar": "kondensering",
    "kondenseringarna": "kondensering",
    "kondenseringarnas": "kondensering",
    "kondenseringars": "kondensering",
    "kondenseringen": "kondensering",
    "kondenseringens": "kondensering",
    "kondenserings": "kondensering",
    "kondenset": "kondens",
    "kondensets": "kondens",
    "kondensorer": "kondensor",
    "kondensorerna": "kondensor",
    "kondensorernas": "kondensor",
    "kondensorers": "kondensor",
    "kondensorn": "kondensor",
    "kondensorns": "kondensor",
    "kondensors": "kondensor",
    "kondensspåren": "kondensspår",
    "kondensspårens": "kondensspår",
    "kondensspåret": "kondensspår",
    "kondensspårets": "kondensspår",
    "kondensspårs": "kondensspår",
    "kondisen": "kondis",
    "kondisens": "kondis",
    "kondiset": "kondis",
    "kondisets": "kondis",
    "konditionala": "konditional",
    "konditionalare": "konditional",
    "konditionalares": "konditional",
    "konditionalas": "konditional",
    "konditionalast": "konditional",
    "konditionalaste": "konditional",
    "konditionalastes": "konditional",
    "konditionalasts": "konditional",
    "konditionale": "konditional",
    "konditionales": "konditional",
    "konditionals": "konditional",
    "konditionalt": "konditional",
    "konditionalts": "konditional",
    "konditionen": "kondition",
    "konditionens": "kondition",
    "konditioner": "kondition",
    "konditionerad": "konditionera",
    "konditionerade": "konditionerad",
    "konditionerades": "konditionerad",
    "konditionerads": "konditionerad",
    "konditionerande": "konditionera",
    "konditioneranden": "konditionerande",
    "konditionerandena": "konditionerande",
    "konditionerandenas": "konditionerande",
    "konditionerandens": "konditionerande",
    "konditionerandes": "konditionerande",
    "konditionerandet": "konditionerande",
    "konditionerandets": "konditionerande",
    "konditionerar": "konditionera",
    "konditioneras": "konditionera",
    "konditionerat": "konditionerad",
    "konditionerats": "konditionerad",
    "konditionerbara": "konditionerbar",
    "konditionerbarare": "konditionerbar",
    "konditionerbarares": "konditionerbar",
    "konditionerbaras": "konditionerbar",
    "konditionerbarast": "konditionerbar",
    "konditionerbaraste": "konditionerbar",
    "konditionerbarastes": "konditionerbar",
    "konditionerbarasts": "konditionerbar",
    "konditionerbare": "konditionerbar",
    "konditionerbares": "konditionerbar",
    "konditionerbarheten": "konditionerbarhet",
    "konditionerbarhetens": "konditionerbarhet",
    "konditionerbarhets": "konditionerbarhet",
    "konditionerbars": "konditionerbar",
    "konditionerbart": "konditionerbar",
    "konditionerbarts": "konditionerbar",
    "konditioneringar": "konditionering",
    "konditioneringarna": "konditionering",
    "konditioneringarnas": "konditionering",
    "konditioneringars": "konditionering",
    "konditioneringen": "konditionering",
    "konditioneringens": "konditionering",
    "konditionerings": "konditionering",
    "konditionerna": "kondition",
    "konditionernas": "kondition",
    "konditioners": "kondition",
    "konditions": "kondition",
    "konditionsmässiga": "konditionsmässig",
    "konditionsmässigare": "konditionsmässig",
    "konditionsmässigares": "konditionsmässig",
    "konditionsmässigas": "konditionsmässig",
    "konditionsmässigast": "konditionsmässig",
    "konditionsmässigaste": "konditionsmässig",
    "konditionsmässigastes": "konditionsmässig",
    "konditionsmässigasts": "konditionsmässig",
    "konditionsmässige": "konditionsmässig",
    "konditionsmässiges": "konditionsmässig",
    "konditionsmässigs": "konditionsmässig",
    "konditionsmässigt": "konditionsmässig",
    "konditionsmässigts": "konditionsmässig",
    "konditorer": "konditor",
    "konditorerna": "konditor",
    "konditorernas": "konditor",
    "konditorers": "konditor",
    "konditorier": "konditori",
    "konditorierna": "konditori",
    "konditoriernas": "konditori",
    "konditoriers": "konditori",
    "konditoriet": "konditori",
    "konditoriets": "konditori",
    "konditoris": "konditori",
    "konditorit": "konditori",
    "konditorits": "konditori",
    "konditorn": "konditor",
    "konditorns": "konditor",
    "konditors": "konditor",
    "kondoleansen": "kondoleans",
    "kondoleansens": "kondoleans",
    "kondoleanser": "kondoleans",
    "kondoleanserna": "kondoleans",
    "kondoleansernas": "kondoleans",
    "kondoleansers": "kondoleans",
    "kondolerad": "kondolera",
    "kondolerade": "kondolera",
    "kondolerades": "kondolera",
    "kondolerads": "kondolera",
    "kondolerande": "kondolera",
    "kondoleranden": "kondolerande",
    "kondolerandena": "kondolerande",
    "kondolerandenas": "kondolerande",
    "kondolerandens": "kondolerande",
    "kondolerandes": "kondolerande",
    "kondolerandet": "kondolerande",
    "kondolerandets": "kondolerande",
    "kondolerar": "kondolera",
    "kondoleras": "kondolera",
    "kondolerat": "kondolera",
    "kondolerats": "kondolera",
    "kondolerbara": "kondolerbar",
    "kondolerbarare": "kondolerbar",
    "kondolerbarares": "kondolerbar",
    "kondolerbaras": "kondolerbar",
    "kondolerbarast": "kondolerbar",
    "kondolerbaraste": "kondolerbar",
    "kondolerbarastes": "kondolerbar",
    "kondolerbarasts": "kondolerbar",
    "kondolerbare": "kondolerbar",
    "kondolerbares": "kondolerbar",
    "kondolerbarheten": "kondolerbarhet",
    "kondolerbarhetens": "kondolerbarhet",
    "kondolerbarhets": "kondolerbarhet",
    "kondolerbars": "kondolerbar",
    "kondolerbart": "kondolerbar",
    "kondolerbarts": "kondolerbar",
    "kondoleringar": "kondolering",
    "kondoleringarna": "kondolering",
    "kondoleringarnas": "kondolering",
    "kondoleringars": "kondolering",
    "kondoleringen": "kondolering",
    "kondoleringens": "kondolering",
    "kondolerings": "kondolering",
    "kondomen": "kondom",
    "kondomens": "kondom",
    "kondomer": "kondom",
    "kondomerna": "kondom",
    "kondomernas": "kondom",
    "kondomers": "kondom",
    "kondoms": "kondom",
    "kondoren": "kondor",
    "kondorens": "kondor",
    "kondorer": "kondor",
    "kondorerna": "kondor",
    "kondorernas": "kondor",
    "kondorers": "kondor",
    "kondors": "kondor",
    "kondottiären": "kondottiär",
    "kondottiärens": "kondottiär",
    "kondottiärer": "kondottiär",
    "kondottiärerna": "kondottiär",
    "kondottiärernas": "kondottiär",
    "kondottiärers": "kondottiär",
    "kondottiärs": "kondottiär",
    "konduktansen": "konduktans",
    "konduktansens": "konduktans",
    "konduktiviteten": "konduktivitet",
    "konduktivitetens": "konduktivitet",
    "konduktiviteter": "konduktivitet",
    "konduktiviteterna": "konduktivitet",
    "konduktiviteternas": "konduktivitet",
    "konduktiviteters": "konduktivitet",
    "konduktivitets": "konduktivitet",
    "konduktorer": "konduktor",
    "konduktorerna": "konduktor",
    "konduktorernas": "konduktor",
    "konduktorers": "konduktor",
    "konduktorn": "konduktor",
    "konduktorns": "konduktor",
    "konduktors": "konduktor",
    "konduktören": "konduktör",
    "konduktörens": "konduktör",
    "konduktörer": "konduktör",
    "konduktörerna": "konduktör",
    "konduktörernas": "konduktör",
    "konduktörers": "konduktör",
    "konduktörn": "konduktör",
    "konduktörns": "konduktör",
    "konduktörs": "konduktör",
    "kone": "kona",
    "konen": "kon",
    "konens": "kon",
    "koner": "kon",
    "konerna": "kon",
    "konernas": "kon",
    "koners": "kon",
    "konfederala": "konfederal",
    "konfederalare": "konfederal",
    "konfederalares": "konfederal",
    "konfederalas": "konfederal",
    "konfederalast": "konfederal",
    "konfederalaste": "konfederal",
    "konfederalastes": "konfederal",
    "konfederalasts": "konfederal",
    "konfederale": "konfederal",
    "konfederales": "konfederal",
    "konfederals": "konfederal",
    "konfederalt": "konfederal",
    "konfederalts": "konfederal",
    "konfederationen": "konfederation",
    "konfederationens": "konfederation",
    "konfederationer": "konfederation",
    "konfederationerna": "konfederation",
    "konfederationernas": "konfederation",
    "konfederationers": "konfederation",
    "konfederations": "konfederation",
    "konfedererade": "konfedererad",
    "konfedererades": "konfedererad",
    "konfedererads": "konfedererad",
    "konfedererat": "konfedererad",
    "konfedererats": "konfedererad",
    "konfekten": "konfekt",
    "konfektens": "konfekt",
    "konfektionen": "konfektion",
    "konfektionens": "konfektion",
    "konfektioner": "konfektion",
    "konfektionerna": "konfektion",
    "konfektionernas": "konfektion",
    "konfektioners": "konfektion",
    "konfektions": "konfektion",
    "konfektionsmässiga": "konfektionsmässig",
    "konfektionsmässigare": "konfektionsmässig",
    "konfektionsmässigares": "konfektionsmässig",
    "konfektionsmässigas": "konfektionsmässig",
    "konfektionsmässigast": "konfektionsmässig",
    "konfektionsmässigaste": "konfektionsmässig",
    "konfektionsmässigastes": "konfektionsmässig",
    "konfektionsmässigasts": "konfektionsmässig",
    "konfektionsmässige": "konfektionsmässig",
    "konfektionsmässiges": "konfektionsmässig",
    "konfektionsmässigs": "konfektionsmässig",
    "konfektionsmässigt": "konfektionsmässig",
    "konfektionsmässigts": "konfektionsmässig",
    "konfekts": "konfekt",
    "konfektskålar": "konfektskål",
    "konfektskålarna": "konfektskål",
    "konfektskålarnas": "konfektskål",
    "konfektskålars": "konfektskål",
    "konfektskålen": "konfektskål",
    "konfektskålens": "konfektskål",
    "konfektskåls": "konfektskål",
    "konfektyr": "konfektyrer",
    "konfektyrbutiken": "konfektyrbutik",
    "konfektyrbutikens": "konfektyrbutik",
    "konfektyrbutiker": "konfektyrbutik",
    "konfektyrbutikerna": "konfektyrbutik",
    "konfektyrbutikernas": "konfektyrbutik",
    "konfektyrbutikers": "konfektyrbutik",
    "konfektyrbutiks": "konfektyrbutik",
    "konfektyrerna": "konfektyrer",
    "konfektyrernas": "konfektyrer",
    "konfektyrers": "konfektyrer",
    "konfektyrs": "konfektyrer",
    "konferencieren": "konferencier",
    "konferencierens": "konferencier",
    "konferencierer": "konferencier",
    "konferenciererna": "konferencier",
    "konferencierernas": "konferencier",
    "konferencierers": "konferencier",
    "konferenciern": "konferencier",
    "konferencierns": "konferencier",
    "konferenciers": "konferencier",
    "konferenciären": "konferenciär",
    "konferenciärens": "konferenciär",
    "konferenciärer": "konferenciär",
    "konferenciärerna": "konferenciär",
    "konferenciärernas": "konferenciär",
    "konferenciärers": "konferenciär",
    "konferenciärn": "konferenciär",
    "konferenciärns": "konferenciär",
    "konferenciärs": "konferenciär",
    "konferensen": "konferens",
    "konferensens": "konferens",
    "konferenser": "konferens",
    "konferenserna": "konferens",
    "konferensernas": "konferens",
    "konferensers": "konferens",
    "konferensrummen": "konferensrum",
    "konferensrummens": "konferensrum",
    "konferensrummet": "konferensrum",
    "konferensrummets": "konferensrum",
    "konferensrums": "konferensrum",
    "konferenstolkar": "konferenstolk",
    "konferenstolkarna": "konferenstolk",
    "konferenstolkarnas": "konferenstolk",
    "konferenstolkars": "konferenstolk",
    "konferenstolken": "konferenstolk",
    "konferenstolkens": "konferenstolk",
    "konferenstolks": "konferenstolk",
    "konfererade": "konferera",
    "konfererades": "konferera",
    "konfererande": "konferera",
    "konfereranden": "konfererande",
    "konfererandena": "konfererande",
    "konfererandenas": "konfererande",
    "konfererandens": "konfererande",
    "konfererandes": "konfererande",
    "konfererandet": "konfererande",
    "konfererandets": "konfererande",
    "konfererar": "konferera",
    "konfereras": "konferera",
    "konfererat": "konferera",
    "konfererats": "konferera",
    "konfereringar": "konferering",
    "konfereringarna": "konferering",
    "konfereringarnas": "konferering",
    "konfereringars": "konferering",
    "konfereringen": "konferering",
    "konfereringens": "konferering",
    "konfererings": "konferering",
    "konfessionalismen": "konfessionalism",
    "konfessionalismens": "konfessionalism",
    "konfessionalismer": "konfessionalism",
    "konfessionalismerna": "konfessionalism",
    "konfessionalismernas": "konfessionalism",
    "konfessionalismers": "konfessionalism",
    "konfessionalisms": "konfessionalism",
    "konfessionarien": "konfessionarie",
    "konfessionariens": "konfessionarie",
    "konfessionarier": "konfessionarie",
    "konfessionarierna": "konfessionarie",
    "konfessionariernas": "konfessionarie",
    "konfessionariers": "konfessionarie",
    "konfessionaries": "konfessionarie",
    "konfessionella": "konfessionell",
    "konfessionellare": "konfessionell",
    "konfessionellares": "konfessionell",
    "konfessionellas": "konfessionell",
    "konfessionellast": "konfessionell",
    "konfessionellaste": "konfessionell",
    "konfessionellastes": "konfessionell",
    "konfessionellasts": "konfessionell",
    "konfessionelle": "konfessionell",
    "konfessionelles": "konfessionell",
    "konfessionells": "konfessionell",
    "konfessionellt": "konfessionell",
    "konfessionellts": "konfessionell",
    "konfessionen": "konfession",
    "konfessionens": "konfession",
    "konfessioner": "konfession",
    "konfessionerna": "konfession",
    "konfessionernas": "konfession",
    "konfessioners": "konfession",
    "konfessions": "konfession",
    "konfessionslösa": "konfessionslös",
    "konfessionslösare": "konfessionslös",
    "konfessionslösares": "konfessionslös",
    "konfessionslösas": "konfessionslös",
    "konfessionslösast": "konfessionslös",
    "konfessionslösaste": "konfessionslös",
    "konfessionslösastes": "konfessionslös",
    "konfessionslösasts": "konfessionslös",
    "konfessionslöse": "konfessionslös",
    "konfessionslöses": "konfessionslös",
    "konfessionslösheten": "konfessionslöshet",
    "konfessionslöshetens": "konfessionslöshet",
    "konfessionslöshets": "konfessionslöshet",
    "konfessionslöst": "konfessionslös",
    "konfessionslösts": "konfessionslös",
    "konfettin": "konfetti",
    "konfettins": "konfetti",
    "konfettis": "konfetti",
    "konfidentiella": "konfidentiell",
    "konfidentiellare": "konfidentiell",
    "konfidentiellares": "konfidentiell",
    "konfidentiellas": "konfidentiell",
    "konfidentiellast": "konfidentiell",
    "konfidentiellaste": "konfidentiell",
    "konfidentiellastes": "konfidentiell",
    "konfidentiellasts": "konfidentiell",
    "konfidentielle": "konfidentiell",
    "konfidentielles": "konfidentiell",
    "konfidentiells": "konfidentiell",
    "konfidentiellt": "konfidentiell",
    "konfidentiellts": "konfidentiell",
    "konfigurationen": "konfiguration",
    "konfigurationens": "konfiguration",
    "konfigurationer": "konfiguration",
    "konfigurationerna": "konfiguration",
    "konfigurationernas": "konfiguration",
    "konfigurationers": "konfiguration",
    "konfigurations": "konfiguration",
    "konfirmanden": "konfirmand",
    "konfirmandens": "konfirmand",
    "konfirmander": "konfirmand",
    "konfirmanderna": "konfirmand",
    "konfirmandernas": "konfirmand",
    "konfirmanders": "konfirmand",
    "konfirmandklassen": "konfirmandklass",
    "konfirmandklassens": "konfirmandklass",
    "konfirmandklasser": "konfirmandklass",
    "konfirmandklasserna": "konfirmandklass",
    "konfirmandklassernas": "konfirmandklass",
    "konfirmandklassers": "konfirmandklass",
    "konfirmandresan": "konfirmandresa",
    "konfirmandresans": "konfirmandresa",
    "konfirmandresas": "konfirmandresa",
    "konfirmandrese": "konfirmandresa",
    "konfirmandresor": "konfirmandresa",
    "konfirmandresorna": "konfirmandresa",
    "konfirmandresornas": "konfirmandresa",
    "konfirmandresors": "konfirmandresa",
    "konfirmands": "konfirmand",
    "konfirmationen": "konfirmation",
    "konfirmationens": "konfirmation",
    "konfirmationer": "konfirmation",
    "konfirmationerna": "konfirmation",
    "konfirmationernas": "konfirmation",
    "konfirmationers": "konfirmation",
    "konfirmations": "konfirmation",
    "konfirmationsbibeln": "konfirmationsbibel",
    "konfirmationsbibelns": "konfirmationsbibel",
    "konfirmationsbibels": "konfirmationsbibel",
    "konfirmationsbiblar": "konfirmationsbibel",
    "konfirmationsbiblarna": "konfirmationsbibel",
    "konfirmationsbiblarnas": "konfirmationsbibel",
    "konfirmationsbiblars": "konfirmationsbibel",
    "konfirmationsklänningar": "konfirmationsklänning",
    "konfirmationsklänningarna": "konfirmationsklänning",
    "konfirmationsklänningarnas": "konfirmationsklänning",
    "konfirmationsklänningars": "konfirmationsklänning",
    "konfirmationsklänningen": "konfirmationsklänning",
    "konfirmationsklänningens": "konfirmationsklänning",
    "konfirmationsklännings": "konfirmationsklänning",
    "konfirmationskostymen": "konfirmationskostym",
    "konfirmationskostymens": "konfirmationskostym",
    "konfirmationskostymer": "konfirmationskostym",
    "konfirmationskostymerna": "konfirmationskostym",
    "konfirmationskostymernas": "konfirmationskostym",
    "konfirmationskostymers": "konfirmationskostym",
    "konfirmationskostyms": "konfirmationskostym",
    "konfirmationsprästen": "konfirmationspräst",
    "konfirmationsprästens": "konfirmationspräst",
    "konfirmationspräster": "konfirmationspräst",
    "konfirmationsprästerna": "konfirmationspräst",
    "konfirmationsprästernas": "konfirmationspräst",
    "konfirmationsprästers": "konfirmationspräst",
    "konfirmationsprästs": "konfirmationspräst",
    "konfirmationsundervisningar": "konfirmationsundervisning",
    "konfirmationsundervisningarna": "konfirmationsundervisning",
    "konfirmationsundervisningarnas": "konfirmationsundervisning",
    "konfirmationsundervisningars": "konfirmationsundervisning",
    "konfirmationsundervisningen": "konfirmationsundervisning",
    "konfirmationsundervisningens": "konfirmationsundervisning",
    "konfirmationsundervisnings": "konfirmationsundervisning",
    "konfirmerad": "konfirmera",
    "konfirmerade": "konfirmera",
    "konfirmerades": "konfirmera",
    "konfirmerads": "konfirmera",
    "konfirmerande": "konfirmera",
    "konfirmeranden": "konfirmerande",
    "konfirmerandena": "konfirmerande",
    "konfirmerandenas": "konfirmerande",
    "konfirmerandens": "konfirmerande",
    "konfirmerandes": "konfirmerande",
    "konfirmerandet": "konfirmerande",
    "konfirmerandets": "konfirmerande",
    "konfirmerar": "konfirmera",
    "konfirmeras": "konfirmera",
    "konfirmerat": "konfirmera",
    "konfirmerats": "konfirmera",
    "konfirmerbara": "konfirmerbar",
    "konfirmerbarare": "konfirmerbar",
    "konfirmerbarares": "konfirmerbar",
    "konfirmerbaras": "konfirmerbar",
    "konfirmerbarast": "konfirmerbar",
    "konfirmerbaraste": "konfirmerbar",
    "konfirmerbarastes": "konfirmerbar",
    "konfirmerbarasts": "konfirmerbar",
    "konfirmerbare": "konfirmerbar",
    "konfirmerbares": "konfirmerbar",
    "konfirmerbarheten": "konfirmerbarhet",
    "konfirmerbarhetens": "konfirmerbarhet",
    "konfirmerbarhets": "konfirmerbarhet",
    "konfirmerbars": "konfirmerbar",
    "konfirmerbart": "konfirmerbar",
    "konfirmerbarts": "konfirmerbar",
    "konfirmeringar": "konfirmering",
    "konfirmeringarna": "konfirmering",
    "konfirmeringarnas": "konfirmering",
    "konfirmeringars": "konfirmering",
    "konfirmeringen": "konfirmering",
    "konfirmeringens": "konfirmering",
    "konfirmerings": "konfirmering",
    "konfiskationen": "konfiskation",
    "konfiskationens": "konfiskation",
    "konfiskationer": "konfiskation",
    "konfiskationerna": "konfiskation",
    "konfiskationernas": "konfiskation",
    "konfiskationers": "konfiskation",
    "konfiskations": "konfiskation",
    "konfiskatoriska": "konfiskatorisk",
    "konfiskatoriskare": "konfiskatorisk",
    "konfiskatoriskares": "konfiskatorisk",
    "konfiskatoriskas": "konfiskatorisk",
    "konfiskatoriskast": "konfiskatorisk",
    "konfiskatoriskaste": "konfiskatorisk",
    "konfiskatoriskastes": "konfiskatorisk",
    "konfiskatoriskasts": "konfiskatorisk",
    "konfiskatoriske": "konfiskatorisk",
    "konfiskatoriskes": "konfiskatorisk",
    "konfiskatorisks": "konfiskatorisk",
    "konfiskatoriskt": "konfiskatorisk",
    "konfiskatoriskts": "konfiskatorisk",
    "konfiskerad": "konfiskera",
    "konfiskerade": "konfiskera",
    "konfiskerades": "konfiskera",
    "konfiskerads": "konfiskera",
    "konfiskerande": "konfiskera",
    "konfiskeranden": "konfiskerande",
    "konfiskerandena": "konfiskerande",
    "konfiskerandenas": "konfiskerande",
    "konfiskerandens": "konfiskerande",
    "konfiskerandes": "konfiskerande",
    "konfiskerandet": "konfiskerande",
    "konfiskerandets": "konfiskerande",
    "konfiskerar": "konfiskera",
    "konfiskeras": "konfiskera",
    "konfiskerat": "konfiskera",
    "konfiskerats": "konfiskera",
    "konfiskerbara": "konfiskerbar",
    "konfiskerbarare": "konfiskerbar",
    "konfiskerbarares": "konfiskerbar",
    "konfiskerbaras": "konfiskerbar",
    "konfiskerbarast": "konfiskerbar",
    "konfiskerbaraste": "konfiskerbar",
    "konfiskerbarastes": "konfiskerbar",
    "konfiskerbarasts": "konfiskerbar",
    "konfiskerbare": "konfiskerbar",
    "konfiskerbares": "konfiskerbar",
    "konfiskerbarheten": "konfiskerbarhet",
    "konfiskerbarhetens": "konfiskerbarhet",
    "konfiskerbarhets": "konfiskerbarhet",
    "konfiskerbars": "konfiskerbar",
    "konfiskerbart": "konfiskerbar",
    "konfiskerbarts": "konfiskerbar",
    "konfiskeringar": "konfiskering",
    "konfiskeringarna": "konfiskering",
    "konfiskeringarnas": "konfiskering",
    "konfiskeringars": "konfiskering",
    "konfiskeringen": "konfiskering",
    "konfiskeringens": "konfiskering",
    "konfiskerings": "konfiskering",
    "konfityr": "konfityrer",
    "konfityrerna": "konfityrer",
    "konfityrernas": "konfityrer",
    "konfityrers": "konfityrer",
    "konfityrs": "konfityrer",
    "konfliktdiamanten": "konfliktdiamant",
    "konfliktdiamantens": "konfliktdiamant",
    "konfliktdiamanter": "konfliktdiamant",
    "konfliktdiamanterna": "konfliktdiamant",
    "konfliktdiamanternas": "konfliktdiamant",
    "konfliktdiamanters": "konfliktdiamant",
    "konfliktdiamants": "konfliktdiamant",
    "konfliktdrabbade": "konfliktdrabbad",
    "konfliktdrabbades": "konfliktdrabbad",
    "konfliktdrabbads": "konfliktdrabbad",
    "konfliktdrabbat": "konfliktdrabbad",
    "konfliktdrabbats": "konfliktdrabbad",
    "konflikten": "konflikt",
    "konfliktens": "konflikt",
    "konflikter": "konflikt",
    "konflikterna": "konflikt",
    "konflikternas": "konflikt",
    "konflikters": "konflikt",
    "konfliktkrädda": "konfliktkrädd",
    "konfliktkräddare": "konfliktkrädd",
    "konfliktkräddares": "konfliktkrädd",
    "konfliktkräddas": "konfliktkrädd",
    "konfliktkräddast": "konfliktkrädd",
    "konfliktkräddaste": "konfliktkrädd",
    "konfliktkräddastes": "konfliktkrädd",
    "konfliktkräddasts": "konfliktkrädd",
    "konfliktkrädde": "konfliktkrädd",
    "konfliktkräddes": "konfliktkrädd",
    "konfliktkrädds": "konfliktkrädd",
    "konfliktregionen": "konfliktregion",
    "konfliktregionens": "konfliktregion",
    "konfliktregioner": "konfliktregion",
    "konfliktregionerna": "konfliktregion",
    "konfliktregionernas": "konfliktregion",
    "konfliktregioners": "konfliktregion",
    "konfliktregions": "konfliktregion",
    "konflikträdslan": "konflikträdsla",
    "konflikträdslans": "konflikträdsla",
    "konflikträdslas": "konflikträdsla",
    "konflikträdsle": "konflikträdsla",
    "konflikträdslo": "konflikträdsla",
    "konflikts": "konflikt",
    "konfliktsituationen": "konfliktsituation",
    "konfliktsituationens": "konfliktsituation",
    "konfliktsituationer": "konfliktsituation",
    "konfliktsituationerna": "konfliktsituation",
    "konfliktsituationernas": "konfliktsituation",
    "konfliktsituationers": "konfliktsituation",
    "konfliktsituations": "konfliktsituation",
    "konfliktskyggheten": "konfliktskygghet",
    "konfliktskygghetens": "konfliktskygghet",
    "konfliktskygghets": "konfliktskygghet",
    "konfliktvarsels": "konfliktvarsel",
    "konfliktvarslen": "konfliktvarsel",
    "konfliktvarslens": "konfliktvarsel",
    "konfliktvarslet": "konfliktvarsel",
    "konfliktvarslets": "konfliktvarsel",
    "konforma": "konform",
    "konformare": "konform",
    "konformares": "konform",
    "konformas": "konform",
    "konformast": "konform",
    "konformaste": "konform",
    "konformastes": "konform",
    "konformasts": "konform",
    "konforme": "konform",
    "konformes": "konform",
    "konformiga": "konformig",
    "konformigare": "konformig",
    "konformigares": "konformig",
    "konformigas": "konformig",
    "konformigast": "konformig",
    "konformigaste": "konformig",
    "konformigastes": "konformig",
    "konformigasts": "konformig",
    "konformige": "konformig",
    "konformiges": "konformig",
    "konformigs": "konformig",
    "konformigt": "konformig",
    "konformigts": "konformig",
    "konformismen": "konformism",
    "konformismens": "konformism",
    "konformismer": "konformism",
    "konformismerna": "konformism",
    "konformismernas": "konformism",
    "konformismers": "konformism",
    "konformisms": "konformism",
    "konformistiska": "konformistisk",
    "konformistiskas": "konformistisk",
    "konformistiske": "konformistisk",
    "konformistiskes": "konformistisk",
    "konformistisks": "konformistisk",
    "konformistiskt": "konformistisk",
    "konformistiskts": "konformistisk",
    "konformiteten": "konformitet",
    "konformitetens": "konformitet",
    "konformiteter": "konformitet",
    "konformiteterna": "konformitet",
    "konformiteternas": "konformitet",
    "konformiteters": "konformitet",
    "konformitets": "konformitet",
    "konforms": "konform",
    "konformt": "konform",
    "konformts": "konform",
    "konfrontationen": "konfrontation",
    "konfrontationens": "konfrontation",
    "konfrontationer": "konfrontation",
    "konfrontationerna": "konfrontation",
    "konfrontationernas": "konfrontation",
    "konfrontationers": "konfrontation",
    "konfrontations": "konfrontation",
    "konfronterad": "konfrontera",
    "konfronterade": "konfrontera",
    "konfronterades": "konfrontera",
    "konfronterads": "konfrontera",
    "konfronterande": "konfrontera",
    "konfronteranden": "konfronterande",
    "konfronterandena": "konfronterande",
    "konfronterandenas": "konfronterande",
    "konfronterandens": "konfronterande",
    "konfronterandes": "konfronterande",
    "konfronterandet": "konfronterande",
    "konfronterandets": "konfronterande",
    "konfronterar": "konfrontera",
    "konfronteras": "konfrontera",
    "konfronterat": "konfrontera",
    "konfronterats": "konfrontera",
    "konfronterbara": "konfronterbar",
    "konfronterbarare": "konfronterbar",
    "konfronterbarares": "konfronterbar",
    "konfronterbaras": "konfronterbar",
    "konfronterbarast": "konfronterbar",
    "konfronterbaraste": "konfronterbar",
    "konfronterbarastes": "konfronterbar",
    "konfronterbarasts": "konfronterbar",
    "konfronterbare": "konfronterbar",
    "konfronterbares": "konfronterbar",
    "konfronterbarheten": "konfronterbarhet",
    "konfronterbarhetens": "konfronterbarhet",
    "konfronterbarhets": "konfronterbarhet",
    "konfronterbars": "konfronterbar",
    "konfronterbart": "konfronterbar",
    "konfronterbarts": "konfronterbar",
    "konfronteringar": "konfrontering",
    "konfronteringarna": "konfrontering",
    "konfronteringarnas": "konfrontering",
    "konfronteringars": "konfrontering",
    "konfronteringen": "konfrontering",
    "konfronteringens": "konfrontering",
    "konfronterings": "konfrontering",
    "konfucianismen": "konfucianism",
    "konfucianismens": "konfucianism",
    "konfucianismer": "konfucianism",
    "konfucianismerna": "konfucianism",
    "konfucianismernas": "konfucianism",
    "konfucianismers": "konfucianism",
    "konfucianisms": "konfucianism",
    "konfucianistiska": "konfucianistisk",
    "konfucianistiskas": "konfucianistisk",
    "konfucianistiske": "konfucianistisk",
    "konfucianistiskes": "konfucianistisk",
    "konfucianistisks": "konfucianistisk",
    "konfucianistiskt": "konfucianistisk",
    "konfucianistiskts": "konfucianistisk",
    "konfunderad": "konfundera",
    "konfunderade": "konfundera",
    "konfunderades": "konfundera",
    "konfunderads": "konfundera",
    "konfunderande": "konfundera",
    "konfunderanden": "konfunderande",
    "konfunderandena": "konfunderande",
    "konfunderandenas": "konfunderande",
    "konfunderandens": "konfunderande",
    "konfunderandes": "konfunderande",
    "konfunderandet": "konfunderande",
    "konfunderandets": "konfunderande",
    "konfunderar": "konfundera",
    "konfunderas": "konfundera",
    "konfunderat": "konfundera",
    "konfunderats": "konfundera",
    "konfunderbara": "konfunderbar",
    "konfunderbarare": "konfunderbar",
    "konfunderbarares": "konfunderbar",
    "konfunderbaras": "konfunderbar",
    "konfunderbarast": "konfunderbar",
    "konfunderbaraste": "konfunderbar",
    "konfunderbarastes": "konfunderbar",
    "konfunderbarasts": "konfunderbar",
    "konfunderbare": "konfunderbar",
    "konfunderbares": "konfunderbar",
    "konfunderbarheten": "konfunderbarhet",
    "konfunderbarhetens": "konfunderbarhet",
    "konfunderbarhets": "konfunderbarhet",
    "konfunderbars": "konfunderbar",
    "konfunderbart": "konfunderbar",
    "konfunderbarts": "konfunderbar",
    "konfunderingar": "konfundering",
    "konfunderingarna": "konfundering",
    "konfunderingarnas": "konfundering",
    "konfunderingars": "konfundering",
    "konfunderingen": "konfundering",
    "konfunderingens": "konfundering",
    "konfunderings": "konfundering",
    "konfusionen": "konfusion",
    "konfusionens": "konfusion",
    "konfusioner": "konfusion",
    "konfusionerna": "konfusion",
    "konfusionernas": "konfusion",
    "konfusioners": "konfusion",
    "konfusions": "konfusion",
    "konfysa": "konfys",
    "konfysare": "konfys",
    "konfysares": "konfys",
    "konfysas": "konfys",
    "konfysast": "konfys",
    "konfysaste": "konfys",
    "konfysastes": "konfys",
    "konfysasts": "konfys",
    "konfyse": "konfys",
    "konfyses": "konfys",
    "konfyst": "konfys",
    "konfysts": "konfys",
    "kongeniala": "kongenial",
    "kongenialare": "kongenial",
    "kongenialares": "kongenial",
    "kongenialas": "kongenial",
    "kongenialast": "kongenial",
    "kongenialaste": "kongenial",
    "kongenialastes": "kongenial",
    "kongenialasts": "kongenial",
    "kongeniale": "kongenial",
    "kongeniales": "kongenial",
    "kongenials": "kongenial",
    "kongenialt": "kongenial",
    "kongenialts": "kongenial",
    "kongenitala": "kongenital",
    "kongenitalare": "kongenital",
    "kongenitalares": "kongenital",
    "kongenitalas": "kongenital",
    "kongenitalast": "kongenital",
    "kongenitalaste": "kongenital",
    "kongenitalastes": "kongenital",
    "kongenitalasts": "kongenital",
    "kongenitale": "kongenital",
    "kongenitales": "kongenital",
    "kongenitals": "kongenital",
    "kongenitalt": "kongenital",
    "kongenitalts": "kongenital",
    "konglomeraten": "konglomerat",
    "konglomeratens": "konglomerat",
    "konglomeratet": "konglomerat",
    "konglomeratets": "konglomerat",
    "konglomerats": "konglomerat",
    "kongolesen": "kongoles",
    "kongolesens": "kongoles",
    "kongoleser": "kongoles",
    "kongoleserna": "kongoles",
    "kongolesernas": "kongoles",
    "kongolesers": "kongoles",
    "kongolesiska": "kongolesisk",
    "kongolesiskan": "kongolesiska",
    "kongolesiskans": "kongolesiska",
    "kongolesiskare": "kongolesisk",
    "kongolesiskares": "kongolesisk",
    "kongolesiskas": "kongolesiska",
    "kongolesiskast": "kongolesisk",
    "kongolesiskaste": "kongolesisk",
    "kongolesiskastes": "kongolesisk",
    "kongolesiskasts": "kongolesisk",
    "kongolesiske": "kongolesiska",
    "kongolesiskes": "kongolesisk",
    "kongolesiskor": "kongolesiska",
    "kongolesiskorna": "kongolesiska",
    "kongolesiskornas": "kongolesiska",
    "kongolesiskors": "kongolesiska",
    "kongolesisks": "kongolesisk",
    "kongolesiskt": "kongolesisk",
    "kongolesiskts": "kongolesisk",
    "kongregationen": "kongregation",
    "kongregationens": "kongregation",
    "kongregationer": "kongregation",
    "kongregationerna": "kongregation",
    "kongregationernas": "kongregation",
    "kongregationers": "kongregation",
    "kongregations": "kongregation",
    "kongressade": "kongressa",
    "kongressades": "kongressa",
    "kongressande": "kongressa",
    "kongressanden": "kongressande",
    "kongressandena": "kongressande",
    "kongressandenas": "kongressande",
    "kongressandens": "kongressande",
    "kongressandes": "kongressande",
    "kongressandet": "kongressande",
    "kongressandets": "kongressande",
    "kongressar": "kongressa",
    "kongressas": "kongressa",
    "kongressat": "kongressa",
    "kongressats": "kongressa",
    "kongressdeltagar": "kongressdeltagare",
    "kongressdeltagaren": "kongressdeltagare",
    "kongressdeltagarens": "kongressdeltagare",
    "kongressdeltagares": "kongressdeltagare",
    "kongressdeltagarna": "kongressdeltagare",
    "kongressdeltagarnas": "kongressdeltagare",
    "kongressen": "kongress",
    "kongressens": "kongress",
    "kongresser": "kongress",
    "kongresserna": "kongress",
    "kongressernas": "kongress",
    "kongressers": "kongress",
    "kongressmannen": "kongressman",
    "kongressmannens": "kongressman",
    "kongressmans": "kongressman",
    "kongressmän": "kongressman",
    "kongressmännen": "kongressman",
    "kongressmännens": "kongressman",
    "kongressmäns": "kongressman",
    "kongressplatsen": "kongressplats",
    "kongressplatsens": "kongressplats",
    "kongressplatser": "kongressplats",
    "kongressplatserna": "kongressplats",
    "kongressplatsernas": "kongressplats",
    "kongressplatsers": "kongressplats",
    "kongruensböjningar": "kongruensböjning",
    "kongruensböjningarna": "kongruensböjning",
    "kongruensböjningarnas": "kongruensböjning",
    "kongruensböjningars": "kongruensböjning",
    "kongruensböjningen": "kongruensböjning",
    "kongruensböjningens": "kongruensböjning",
    "kongruensböjnings": "kongruensböjning",
    "kongruensen": "kongruens",
    "kongruensens": "kongruens",
    "kongruenser": "kongruens",
    "kongruenserna": "kongruens",
    "kongruensernas": "kongruens",
    "kongruensers": "kongruens",
    "kongruensfallen": "kongruensfall",
    "kongruensfallens": "kongruensfall",
    "kongruensfallet": "kongruensfall",
    "kongruensfallets": "kongruensfall",
    "kongruensfalls": "kongruensfall",
    "kongruenta": "kongruent",
    "kongruentare": "kongruent",
    "kongruentares": "kongruent",
    "kongruentas": "kongruent",
    "kongruentast": "kongruent",
    "kongruentaste": "kongruent",
    "kongruentastes": "kongruent",
    "kongruentasts": "kongruent",
    "kongruente": "kongruent",
    "kongruentes": "kongruent",
    "kongruentheten": "kongruenthet",
    "kongruenthetens": "kongruenthet",
    "kongruenthets": "kongruenthet",
    "kongruents": "kongruent",
    "kongruerad": "kongruera",
    "kongruerade": "kongruera",
    "kongruerades": "kongruera",
    "kongruerads": "kongruera",
    "kongruerande": "kongruera",
    "kongrueranden": "kongruerande",
    "kongruerandena": "kongruerande",
    "kongruerandenas": "kongruerande",
    "kongruerandens": "kongruerande",
    "kongruerandes": "kongruerande",
    "kongruerandet": "kongruerande",
    "kongruerandets": "kongruerande",
    "kongruerar": "kongruera",
    "kongrueras": "kongruera",
    "kongruerat": "kongruera",
    "kongruerats": "kongruera",
    "kongruerbara": "kongruerbar",
    "kongruerbarare": "kongruerbar",
    "kongruerbarares": "kongruerbar",
    "kongruerbaras": "kongruerbar",
    "kongruerbarast": "kongruerbar",
    "kongruerbaraste": "kongruerbar",
    "kongruerbarastes": "kongruerbar",
    "kongruerbarasts": "kongruerbar",
    "kongruerbare": "kongruerbar",
    "kongruerbares": "kongruerbar",
    "kongruerbarheten": "kongruerbarhet",
    "kongruerbarhetens": "kongruerbarhet",
    "kongruerbarhets": "kongruerbarhet",
    "kongruerbars": "kongruerbar",
    "kongruerbart": "kongruerbar",
    "kongruerbarts": "kongruerbar",
    "kongrueringar": "kongruering",
    "kongrueringarna": "kongruering",
    "kongrueringarnas": "kongruering",
    "kongrueringars": "kongruering",
    "kongrueringen": "kongruering",
    "kongrueringens": "kongruering",
    "kongruerings": "kongruering",
    "koniciteten": "konicitet",
    "konicitetens": "konicitet",
    "koniciteter": "konicitet",
    "koniciteterna": "konicitet",
    "koniciteternas": "konicitet",
    "koniciteters": "konicitet",
    "konicitets": "konicitet",
    "koniska": "konisk",
    "koniskare": "konisk",
    "koniskares": "konisk",
    "koniskas": "konisk",
    "koniskast": "konisk",
    "koniskaste": "konisk",
    "koniskastes": "konisk",
    "koniskasts": "konisk",
    "koniske": "konisk",
    "koniskes": "konisk",
    "konisks": "konisk",
    "koniskt": "konisk",
    "koniskts": "konisk",
    "konjaken": "konjak",
    "konjakens": "konjak",
    "konjaker": "konjak",
    "konjakerna": "konjak",
    "konjakernas": "konjak",
    "konjakers": "konjak",
    "konjaks": "konjak",
    "konjakskransar": "konjakskrans",
    "konjakskransarna": "konjakskrans",
    "konjakskransarnas": "konjakskrans",
    "konjakskransars": "konjakskrans",
    "konjakskransen": "konjakskrans",
    "konjakskransens": "konjakskrans",
    "konjakskup": "konjakskupa",
    "konjakskupan": "konjakskupa",
    "konjakskupans": "konjakskupa",
    "konjakskupas": "konjakskupa",
    "konjakskupe": "konjakskupa",
    "konjakskupor": "konjakskupa",
    "konjakskuporna": "konjakskupa",
    "konjakskupornas": "konjakskupa",
    "konjakskupors": "konjakskupa",
    "konjakskups": "konjakskupa",
    "konjekturen": "konjektur",
    "konjekturens": "konjektur",
    "konjekturer": "konjektur",
    "konjekturerna": "konjektur",
    "konjekturernas": "konjektur",
    "konjekturers": "konjektur",
    "konjekturs": "konjektur",
    "konjugationen": "konjugation",
    "konjugationens": "konjugation",
    "konjugationer": "konjugation",
    "konjugationerna": "konjugation",
    "konjugationernas": "konjugation",
    "konjugationers": "konjugation",
    "konjugations": "konjugation",
    "konjugerad": "konjugera",
    "konjugerade": "konjugera",
    "konjugerades": "konjugera",
    "konjugerads": "konjugera",
    "konjugerande": "konjugera",
    "konjugeranden": "konjugerande",
    "konjugerandena": "konjugerande",
    "konjugerandenas": "konjugerande",
    "konjugerandens": "konjugerande",
    "konjugerandes": "konjugerande",
    "konjugerandet": "konjugerande",
    "konjugerandets": "konjugerande",
    "konjugerar": "konjugera",
    "konjugeras": "konjugera",
    "konjugerat": "konjugera",
    "konjugerats": "konjugera",
    "konjugerbara": "konjugerbar",
    "konjugerbarare": "konjugerbar",
    "konjugerbarares": "konjugerbar",
    "konjugerbaras": "konjugerbar",
    "konjugerbarast": "konjugerbar",
    "konjugerbaraste": "konjugerbar",
    "konjugerbarastes": "konjugerbar",
    "konjugerbarasts": "konjugerbar",
    "konjugerbare": "konjugerbar",
    "konjugerbares": "konjugerbar",
    "konjugerbarheten": "konjugerbarhet",
    "konjugerbarhetens": "konjugerbarhet",
    "konjugerbarhets": "konjugerbarhet",
    "konjugerbars": "konjugerbar",
    "konjugerbart": "konjugerbar",
    "konjugerbarts": "konjugerbar",
    "konjugeringar": "konjugering",
    "konjugeringarna": "konjugering",
    "konjugeringarnas": "konjugering",
    "konjugeringars": "konjugering",
    "konjugeringen": "konjugering",
    "konjugeringens": "konjugering",
    "konjugerings": "konjugering",
    "konjunktionen": "konjunktion",
    "konjunktionens": "konjunktion",
    "konjunktioner": "konjunktion",
    "konjunktionerna": "konjunktion",
    "konjunktionernas": "konjunktion",
    "konjunktioners": "konjunktion",
    "konjunktions": "konjunktion",
    "konjunktiven": "konjunktiv",
    "konjunktivens": "konjunktiv",
    "konjunktiver": "konjunktiv",
    "konjunktiverna": "konjunktiv",
    "konjunktivernas": "konjunktiv",
    "konjunktivers": "konjunktiv",
    "konjunktiviten": "konjunktivit",
    "konjunktivitens": "konjunktivit",
    "konjunktivits": "konjunktivit",
    "konjunktivs": "konjunktiv",
    "konjunkturen": "konjunktur",
    "konjunkturens": "konjunktur",
    "konjunkturer": "konjunktur",
    "konjunkturerna": "konjunktur",
    "konjunkturernas": "konjunktur",
    "konjunkturers": "konjunktur",
    "konjunkturförbättringar": "konjunkturförbättring",
    "konjunkturförbättringarna": "konjunkturförbättring",
    "konjunkturförbättringarnas": "konjunkturförbättring",
    "konjunkturförbättringars": "konjunkturförbättring",
    "konjunkturförbättringen": "konjunkturförbättring",
    "konjunkturförbättringens": "konjunkturförbättring",
    "konjunkturförbättrings": "konjunkturförbättring",
    "konjunkturinstituten": "konjunkturinstitut",
    "konjunkturinstitutens": "konjunkturinstitut",
    "konjunkturinstitutet": "konjunkturinstitut",
    "konjunkturinstitutets": "konjunkturinstitut",
    "konjunkturinstituts": "konjunkturinstitut",
    "konjunkturkurv": "konjunkturkurva",
    "konjunkturkurvan": "konjunkturkurva",
    "konjunkturkurvans": "konjunkturkurva",
    "konjunkturkurvas": "konjunkturkurva",
    "konjunkturkurve": "konjunkturkurva",
    "konjunkturkurvor": "konjunkturkurva",
    "konjunkturkurvorna": "konjunkturkurva",
    "konjunkturkurvornas": "konjunkturkurva",
    "konjunkturkurvors": "konjunkturkurva",
    "konjunkturkurvs": "konjunkturkurva",
    "konjunkturmässiga": "konjunkturmässig",
    "konjunkturmässigare": "konjunkturmässig",
    "konjunkturmässigares": "konjunkturmässig",
    "konjunkturmässigas": "konjunkturmässig",
    "konjunkturmässigast": "konjunkturmässig",
    "konjunkturmässigaste": "konjunkturmässig",
    "konjunkturmässigastes": "konjunkturmässig",
    "konjunkturmässigasts": "konjunkturmässig",
    "konjunkturmässige": "konjunkturmässig",
    "konjunkturmässiges": "konjunkturmässig",
    "konjunkturmässigs": "konjunkturmässig",
    "konjunkturmässigt": "konjunkturmässig",
    "konjunkturmässigts": "konjunkturmässig",
    "konjunkturomslagen": "konjunkturomslag",
    "konjunkturomslagens": "konjunkturomslag",
    "konjunkturomslaget": "konjunkturomslag",
    "konjunkturomslagets": "konjunkturomslag",
    "konjunkturomslags": "konjunkturomslag",
    "konjunkturpolitiken": "konjunkturpolitik",
    "konjunkturpolitikens": "konjunkturpolitik",
    "konjunkturpolitiks": "konjunkturpolitik",
    "konjunkturpolitiska": "konjunkturpolitisk",
    "konjunkturpolitiskas": "konjunkturpolitisk",
    "konjunkturpolitiske": "konjunkturpolitisk",
    "konjunkturpolitiskes": "konjunkturpolitisk",
    "konjunkturpolitisks": "konjunkturpolitisk",
    "konjunkturpolitiskt": "konjunkturpolitisk",
    "konjunkturpolitiskts": "konjunkturpolitisk",
    "konjunkturrapporten": "konjunkturrapport",
    "konjunkturrapportens": "konjunkturrapport",
    "konjunkturrapporter": "konjunkturrapport",
    "konjunkturrapporterna": "konjunkturrapport",
    "konjunkturrapporternas": "konjunkturrapport",
    "konjunkturrapporters": "konjunkturrapport",
    "konjunkturrapports": "konjunkturrapport",
    "konjunkturråden": "konjunkturråd",
    "konjunkturrådens": "konjunkturråd",
    "konjunkturrådet": "konjunkturråd",
    "konjunkturrådets": "konjunkturråd",
    "konjunkturråds": "konjunkturråd",
    "konjunkturs": "konjunktur",
    "konjunkturstöden": "konjunkturstöd",
    "konjunkturstödens": "konjunkturstöd",
    "konjunkturstödet": "konjunkturstöd",
    "konjunkturstödets": "konjunkturstöd",
    "konjunkturstöds": "konjunkturstöd",
    "konkava": "konkav",
    "konkavare": "konkav",
    "konkavares": "konkav",
    "konkavas": "konkav",
    "konkavast": "konkav",
    "konkavaste": "konkav",
    "konkavastes": "konkav",
    "konkavasts": "konkav",
    "konkave": "konkav",
    "konkaves": "konkav",
    "konkavkonvexa": "konkavkonvex",
    "konkavkonvexare": "konkavkonvex",
    "konkavkonvexares": "konkavkonvex",
    "konkavkonvexas": "konkavkonvex",
    "konkavkonvexast": "konkavkonvex",
    "konkavkonvexaste": "konkavkonvex",
    "konkavkonvexastes": "konkavkonvex",
    "konkavkonvexasts": "konkavkonvex",
    "konkavkonvexe": "konkavkonvex",
    "konkavkonvexes": "konkavkonvex",
    "konkavkonvext": "konkavkonvex",
    "konkavkonvexts": "konkavkonvex",
    "konkavs": "konkav",
    "konkavt": "konkav",
    "konkavts": "konkav",
    "konklaven": "konklav",
    "konklavens": "konklav",
    "konklaver": "konklav",
    "konklaverna": "konklav",
    "konklavernas": "konklav",
    "konklavers": "konklav",
    "konklavs": "konklav",
    "konkluderad": "konkludera",
    "konkluderade": "konkludera",
    "konkluderades": "konkludera",
    "konkluderads": "konkludera",
    "konkluderande": "konkludera",
    "konkluderanden": "konkluderande",
    "konkluderandena": "konkluderande",
    "konkluderandenas": "konkluderande",
    "konkluderandens": "konkluderande",
    "konkluderandes": "konkluderande",
    "konkluderandet": "konkluderande",
    "konkluderandets": "konkluderande",
    "konkluderar": "konkludera",
    "konkluderas": "konkludera",
    "konkluderat": "konkludera",
    "konkluderats": "konkludera",
    "konkluderbara": "konkluderbar",
    "konkluderbarare": "konkluderbar",
    "konkluderbarares": "konkluderbar",
    "konkluderbaras": "konkluderbar",
    "konkluderbarast": "konkluderbar",
    "konkluderbaraste": "konkluderbar",
    "konkluderbarastes": "konkluderbar",
    "konkluderbarasts": "konkluderbar",
    "konkluderbare": "konkluderbar",
    "konkluderbares": "konkluderbar",
    "konkluderbarheten": "konkluderbarhet",
    "konkluderbarhetens": "konkluderbarhet",
    "konkluderbarhets": "konkluderbarhet",
    "konkluderbars": "konkluderbar",
    "konkluderbart": "konkluderbar",
    "konkluderbarts": "konkluderbar",
    "konkluderingar": "konkludering",
    "konkluderingarna": "konkludering",
    "konkluderingarnas": "konkludering",
    "konkluderingars": "konkludering",
    "konkluderingen": "konkludering",
    "konkluderingens": "konkludering",
    "konkluderings": "konkludering",
    "konklusionen": "konklusion",
    "konklusionens": "konklusion",
    "konklusioner": "konklusion",
    "konklusionerna": "konklusion",
    "konklusionernas": "konklusion",
    "konklusioners": "konklusion",
    "konklusions": "konklusion",
    "konklusiva": "konklusiv",
    "konklusivare": "konklusiv",
    "konklusivares": "konklusiv",
    "konklusivas": "konklusiv",
    "konklusivast": "konklusiv",
    "konklusivaste": "konklusiv",
    "konklusivastes": "konklusiv",
    "konklusivasts": "konklusiv",
    "konklusive": "konklusiv",
    "konklusives": "konklusiv",
    "konklusivs": "konklusiv",
    "konklusivt": "konklusiv",
    "konklusivts": "konklusiv",
    "konkordansen": "konkordans",
    "konkordansens": "konkordans",
    "konkordanser": "konkordans",
    "konkordanserna": "konkordans",
    "konkordansernas": "konkordans",
    "konkordansers": "konkordans",
    "konkordaten": "konkordat",
    "konkordatens": "konkordat",
    "konkordatet": "konkordat",
    "konkordatets": "konkordat",
    "konkordats": "konkordat",
    "konkrementen": "konkrement",
    "konkrementens": "konkrement",
    "konkrementet": "konkrement",
    "konkrementets": "konkrement",
    "konkrements": "konkrement",
    "konkreta": "konkret",
    "konkretare": "konkret",
    "konkretares": "konkret",
    "konkretas": "konkret",
    "konkretast": "konkret",
    "konkretaste": "konkret",
    "konkretastes": "konkret",
    "konkretasts": "konkret",
    "konkrete": "konkret",
    "konkretes": "konkret",
    "konkretheten": "konkrethet",
    "konkrethetens": "konkrethet",
    "konkrethets": "konkrethet",
    "konkretionen": "konkretion",
    "konkretionens": "konkretion",
    "konkretioner": "konkretion",
    "konkretionerna": "konkretion",
    "konkretionernas": "konkretion",
    "konkretioners": "konkretion",
    "konkretions": "konkretion",
    "konkretiserad": "konkretisera",
    "konkretiserade": "konkretisera",
    "konkretiserades": "konkretisera",
    "konkretiserads": "konkretisera",
    "konkretiserande": "konkretisera",
    "konkretiseranden": "konkretiserande",
    "konkretiserandena": "konkretiserande",
    "konkretiserandenas": "konkretiserande",
    "konkretiserandens": "konkretiserande",
    "konkretiserandes": "konkretiserande",
    "konkretiserandet": "konkretiserande",
    "konkretiserandets": "konkretiserande",
    "konkretiserar": "konkretisera",
    "konkretiseras": "konkretisera",
    "konkretiserat": "konkretisera",
    "konkretiserats": "konkretisera",
    "konkretiserbara": "konkretiserbar",
    "konkretiserbarare": "konkretiserbar",
    "konkretiserbarares": "konkretiserbar",
    "konkretiserbaras": "konkretiserbar",
    "konkretiserbarast": "konkretiserbar",
    "konkretiserbaraste": "konkretiserbar",
    "konkretiserbarastes": "konkretiserbar",
    "konkretiserbarasts": "konkretiserbar",
    "konkretiserbare": "konkretiserbar",
    "konkretiserbares": "konkretiserbar",
    "konkretiserbarheten": "konkretiserbarhet",
    "konkretiserbarhetens": "konkretiserbarhet",
    "konkretiserbarhets": "konkretiserbarhet",
    "konkretiserbars": "konkretiserbar",
    "konkretiserbart": "konkretiserbar",
    "konkretiserbarts": "konkretiserbar",
    "konkretiseringar": "konkretisering",
    "konkretiseringarna": "konkretisering",
    "konkretiseringarnas": "konkretisering",
    "konkretiseringars": "konkretisering",
    "konkretiseringen": "konkretisering",
    "konkretiseringens": "konkretisering",
    "konkretiserings": "konkretisering",
    "konkretismen": "konkretism",
    "konkretismens": "konkretism",
    "konkretismer": "konkretism",
    "konkretismerna": "konkretism",
    "konkretismernas": "konkretism",
    "konkretismers": "konkretism",
    "konkretisms": "konkretism",
    "konkretistiska": "konkretistisk",
    "konkretistiskas": "konkretistisk",
    "konkretistiske": "konkretistisk",
    "konkretistiskes": "konkretistisk",
    "konkretistisks": "konkretistisk",
    "konkretistiskt": "konkretistisk",
    "konkretistiskts": "konkretistisk",
    "konkrets": "konkret",
    "konkubinen": "konkubin",
    "konkubinens": "konkubin",
    "konkubiner": "konkubin",
    "konkubinerna": "konkubin",
    "konkubinernas": "konkubin",
    "konkubiners": "konkubin",
    "konkubins": "konkubin",
    "konkurrensen": "konkurrens",
    "konkurrensens": "konkurrens",
    "konkurrenskraften": "konkurrenskraft",
    "konkurrenskraftens": "konkurrenskraft",
    "konkurrenskraftiga": "konkurrenskraftig",
    "konkurrenskraftigare": "konkurrenskraftig",
    "konkurrenskraftigares": "konkurrenskraftig",
    "konkurrenskraftigas": "konkurrenskraftig",
    "konkurrenskraftigast": "konkurrenskraftig",
    "konkurrenskraftigaste": "konkurrenskraftig",
    "konkurrenskraftigastes": "konkurrenskraftig",
    "konkurrenskraftigasts": "konkurrenskraftig",
    "konkurrenskraftige": "konkurrenskraftig",
    "konkurrenskraftiges": "konkurrenskraftig",
    "konkurrenskraftigs": "konkurrenskraftig",
    "konkurrenskraftigt": "konkurrenskraftig",
    "konkurrenskraftigts": "konkurrenskraftig",
    "konkurrenskrafts": "konkurrenskraft",
    "konkurrensmarknaden": "konkurrensmarknad",
    "konkurrensmarknadens": "konkurrensmarknad",
    "konkurrensmarknader": "konkurrensmarknad",
    "konkurrensmarknaderna": "konkurrensmarknad",
    "konkurrensmarknadernas": "konkurrensmarknad",
    "konkurrensmarknaders": "konkurrensmarknad",
    "konkurrensmarknads": "konkurrensmarknad",
    "konkurrensmedels": "konkurrensmedel",
    "konkurrensmedlen": "konkurrensmedel",
    "konkurrensmedlens": "konkurrensmedel",
    "konkurrensmedlet": "konkurrensmedel",
    "konkurrensmedlets": "konkurrensmedel",
    "konkurrensmässiga": "konkurrensmässig",
    "konkurrensmässigare": "konkurrensmässig",
    "konkurrensmässigares": "konkurrensmässig",
    "konkurrensmässigas": "konkurrensmässig",
    "konkurrensmässigast": "konkurrensmässig",
    "konkurrensmässigaste": "konkurrensmässig",
    "konkurrensmässigastes": "konkurrensmässig",
    "konkurrensmässigasts": "konkurrensmässig",
    "konkurrensmässige": "konkurrensmässig",
    "konkurrensmässiges": "konkurrensmässig",
    "konkurrensmässigs": "konkurrensmässig",
    "konkurrensmässigt": "konkurrensmässig",
    "konkurrensmässigts": "konkurrensmässig",
    "konkurrenssamhällen": "konkurrenssamhälle",
    "konkurrenssamhällena": "konkurrenssamhälle",
    "konkurrenssamhällenas": "konkurrenssamhälle",
    "konkurrenssamhällens": "konkurrenssamhälle",
    "konkurrenssamhälles": "konkurrenssamhälle",
    "konkurrenssamhället": "konkurrenssamhälle",
    "konkurrenssamhällets": "konkurrenssamhälle",
    "konkurrenssamhälls": "konkurrenssamhälle",
    "konkurrensutsatta": "konkurrensutsatt",
    "konkurrensutsattare": "konkurrensutsatt",
    "konkurrensutsattares": "konkurrensutsatt",
    "konkurrensutsattas": "konkurrensutsatt",
    "konkurrensutsattast": "konkurrensutsatt",
    "konkurrensutsattaste": "konkurrensutsatt",
    "konkurrensutsattastes": "konkurrensutsatt",
    "konkurrensutsattasts": "konkurrensutsatt",
    "konkurrensutsatte": "konkurrensutsatt",
    "konkurrensutsattes": "konkurrensutsatt",
    "konkurrensutsattheten": "konkurrensutsatthet",
    "konkurrensutsatthetens": "konkurrensutsatthet",
    "konkurrensutsatthets": "konkurrensutsatthet",
    "konkurrensutsatts": "konkurrensutsatt",
    "konkurrensverket": "konkurrensverk",
    "konkurrensverkets": "konkurrensverk",
    "konkurrensverks": "konkurrensverk",
    "konkurrenten": "konkurrent",
    "konkurrentens": "konkurrent",
    "konkurrenter": "konkurrent",
    "konkurrenterna": "konkurrent",
    "konkurrenternas": "konkurrent",
    "konkurrenters": "konkurrent",
    "konkurrents": "konkurrent",
    "konkurrerade": "konkurrera",
    "konkurrerades": "konkurrera",
    "konkurrerande": "konkurrera",
    "konkurreranden": "konkurrerande",
    "konkurrerandena": "konkurrerande",
    "konkurrerandenas": "konkurrerande",
    "konkurrerandens": "konkurrerande",
    "konkurrerandes": "konkurrerande",
    "konkurrerandet": "konkurrerande",
    "konkurrerandets": "konkurrerande",
    "konkurrerar": "konkurrera",
    "konkurreras": "konkurrera",
    "konkurrerat": "konkurrera",
    "konkurrerats": "konkurrera",
    "konkurreringar": "konkurrering",
    "konkurreringarna": "konkurrering",
    "konkurreringarnas": "konkurrering",
    "konkurreringars": "konkurrering",
    "konkurreringen": "konkurrering",
    "konkurreringens": "konkurrering",
    "konkurrerings": "konkurrering",
    "konkursbevakningar": "konkursbevakning",
    "konkursbevakningarna": "konkursbevakning",
    "konkursbevakningarnas": "konkursbevakning",
    "konkursbevakningars": "konkursbevakning",
    "konkursbevakningen": "konkursbevakning",
    "konkursbevakningens": "konkursbevakning",
    "konkursbevaknings": "konkursbevakning",
    "konkursboen": "konkursbo",
    "konkursboens": "konkursbo",
    "konkursboet": "konkursbo",
    "konkursboets": "konkursbo",
    "konkursbon": "konkursbo",
    "konkursbona": "konkursbo",
    "konkursbonas": "konkursbo",
    "konkursbons": "konkursbo",
    "konkursbos": "konkursbo",
    "konkursbot": "konkursbo",
    "konkursbots": "konkursbo",
    "konkursdividenden": "konkursdividend",
    "konkursdividendens": "konkursdividend",
    "konkursdividender": "konkursdividend",
    "konkursdividenderna": "konkursdividend",
    "konkursdividendernas": "konkursdividend",
    "konkursdividenders": "konkursdividend",
    "konkursdividends": "konkursdividend",
    "konkursen": "konkurs",
    "konkursens": "konkurs",
    "konkurser": "konkurs",
    "konkurserna": "konkurs",
    "konkursernas": "konkurs",
    "konkursers": "konkurs",
    "konkursförvaltar": "konkursförvaltare",
    "konkursförvaltaren": "konkursförvaltare",
    "konkursförvaltarens": "konkursförvaltare",
    "konkursförvaltares": "konkursförvaltare",
    "konkursförvaltarna": "konkursförvaltare",
    "konkursförvaltarnas": "konkursförvaltare",
    "konkursmassan": "konkursmassa",
    "konkursmassans": "konkursmassa",
    "konkursmassas": "konkursmassa",
    "konkursmasse": "konkursmassa",
    "konkursmässiga": "konkursmässig",
    "konkursmässigare": "konkursmässig",
    "konkursmässigares": "konkursmässig",
    "konkursmässigas": "konkursmässig",
    "konkursmässigast": "konkursmässig",
    "konkursmässigaste": "konkursmässig",
    "konkursmässigastes": "konkursmässig",
    "konkursmässigasts": "konkursmässig",
    "konkursmässige": "konkursmässig",
    "konkursmässiges": "konkursmässig",
    "konkursmässigheten": "konkursmässighet",
    "konkursmässighetens": "konkursmässighet",
    "konkursmässighets": "konkursmässighet",
    "konkursmässigs": "konkursmässig",
    "konkursmässigt": "konkursmässig",
    "konkursmässigts": "konkursmässig",
    "konkursrealisationen": "konkursrealisation",
    "konkursrealisationens": "konkursrealisation",
    "konkursrealisationer": "konkursrealisation",
    "konkursrealisationerna": "konkursrealisation",
    "konkursrealisationernas": "konkursrealisation",
    "konkursrealisationers": "konkursrealisation",
    "konkursrealisations": "konkursrealisation",
    "konnotationen": "konnotation",
    "konnotationens": "konnotation",
    "konnotationer": "konnotation",
    "konnotationerna": "konnotation",
    "konnotationernas": "konnotation",
    "konnotationers": "konnotation",
    "konnotations": "konnotation",
    "konnotativa": "konnotativ",
    "konnotativare": "konnotativ",
    "konnotativares": "konnotativ",
    "konnotativas": "konnotativ",
    "konnotativast": "konnotativ",
    "konnotativaste": "konnotativ",
    "konnotativastes": "konnotativ",
    "konnotativasts": "konnotativ",
    "konnotative": "konnotativ",
    "konnotatives": "konnotativ",
    "konnotativs": "konnotativ",
    "konnotativt": "konnotativ",
    "konnotativts": "konnotativ",
    "konnässansen": "konnässans",
    "konnässansens": "konnässans",
    "konnässanser": "konnässans",
    "konnässanserna": "konnässans",
    "konnässansernas": "konnässans",
    "konnässansers": "konnässans",
    "konnässören": "konnässör",
    "konnässörens": "konnässör",
    "konnässörer": "konnässör",
    "konnässörerna": "konnässör",
    "konnässörernas": "konnässör",
    "konnässörers": "konnässör",
    "konnässörs": "konnässör",
    "konor": "kona",
    "konorna": "kona",
    "konornas": "kona",
    "konors": "kona",
    "konossementen": "konossement",
    "konossementens": "konossement",
    "konossementet": "konossement",
    "konossementets": "konossement",
    "konossements": "konossement",
    "konprickar": "konprick",
    "konprickarna": "konprick",
    "konprickarnas": "konprick",
    "konprickars": "konprick",
    "konpricken": "konprick",
    "konprickens": "konprick",
    "konpricks": "konprick",
    "kons": "kona",
    "konsekutiva": "konsekutiv",
    "konsekutivare": "konsekutiv",
    "konsekutivares": "konsekutiv",
    "konsekutivas": "konsekutiv",
    "konsekutivast": "konsekutiv",
    "konsekutivaste": "konsekutiv",
    "konsekutivastes": "konsekutiv",
    "konsekutivasts": "konsekutiv",
    "konsekutive": "konsekutiv",
    "konsekutives": "konsekutiv",
    "konsekutivs": "konsekutiv",
    "konsekutivt": "konsekutiv",
    "konsekutivts": "konsekutiv",
    "konsekvensen": "konsekvens",
    "konsekvensens": "konsekvens",
    "konsekvenser": "konsekvens",
    "konsekvenserna": "konsekvens",
    "konsekvensernas": "konsekvens",
    "konsekvensers": "konsekvens",
    "konsekventa": "konsekvent",
    "konsekventare": "konsekvent",
    "konsekventares": "konsekvent",
    "konsekventas": "konsekvent",
    "konsekventast": "konsekvent",
    "konsekventaste": "konsekvent",
    "konsekventastes": "konsekvent",
    "konsekventasts": "konsekvent",
    "konsekvente": "konsekvent",
    "konsekventes": "konsekvent",
    "konsekventheten": "konsekventhet",
    "konsekventhetens": "konsekventhet",
    "konsekventhets": "konsekventhet",
    "konsekvents": "konsekvent",
    "konseljen": "konselj",
    "konseljens": "konselj",
    "konseljer": "konselj",
    "konseljerna": "konselj",
    "konseljernas": "konselj",
    "konseljers": "konselj",
    "konseljpresidenten": "konseljpresident",
    "konseljpresidentens": "konseljpresident",
    "konseljpresidenter": "konseljpresident",
    "konseljpresidenterna": "konseljpresident",
    "konseljpresidenternas": "konseljpresident",
    "konseljpresidenters": "konseljpresident",
    "konseljpresidents": "konseljpresident",
    "konseljs": "konselj",
    "konsensusen": "konsensus",
    "konsensusens": "konsensus",
    "konsertaffischen": "konsertaffisch",
    "konsertaffischens": "konsertaffisch",
    "konsertaffischer": "konsertaffisch",
    "konsertaffischerna": "konsertaffisch",
    "konsertaffischernas": "konsertaffisch",
    "konsertaffischers": "konsertaffisch",
    "konsertaffischs": "konsertaffisch",
    "konserten": "konsert",
    "konsertens": "konsert",
    "konserter": "konsert",
    "konserterade": "konsertera",
    "konserterades": "konsertera",
    "konserterande": "konsertera",
    "konserteranden": "konserterande",
    "konserterandena": "konserterande",
    "konserterandenas": "konserterande",
    "konserterandens": "konserterande",
    "konserterandes": "konserterande",
    "konserterandet": "konserterande",
    "konserterandets": "konserterande",
    "konserterar": "konsertera",
    "konserteras": "konsertera",
    "konserterat": "konsertera",
    "konserterats": "konsertera",
    "konserteringar": "konsertering",
    "konserteringarna": "konsertering",
    "konserteringarnas": "konsertering",
    "konserteringars": "konsertering",
    "konserteringen": "konsertering",
    "konserteringens": "konsertering",
    "konserterings": "konsertering",
    "konserterna": "konsert",
    "konserternas": "konsert",
    "konserters": "konsert",
    "konserthusen": "konserthus",
    "konserthusens": "konserthus",
    "konserthuset": "konserthus",
    "konserthusets": "konserthus",
    "konsertmästar": "konsertmästare",
    "konsertmästaren": "konsertmästare",
    "konsertmästarens": "konsertmästare",
    "konsertmästares": "konsertmästare",
    "konsertmästarna": "konsertmästare",
    "konsertmästarnas": "konsertmästare",
    "konserts": "konsert",
    "konsertstycken": "konsertstycke",
    "konsertstyckena": "konsertstycke",
    "konsertstyckenas": "konsertstycke",
    "konsertstyckens": "konsertstycke",
    "konsertstyckes": "konsertstycke",
    "konsertstycket": "konsertstycke",
    "konsertstyckets": "konsertstycke",
    "konsertstycks": "konsertstycke",
    "konservatismen": "konservatism",
    "konservatismens": "konservatism",
    "konservatismer": "konservatism",
    "konservatismerna": "konservatism",
    "konservatismernas": "konservatism",
    "konservatismers": "konservatism",
    "konservatisms": "konservatism",
    "konservativa": "konservativ",
    "konservativare": "konservativ",
    "konservativares": "konservativ",
    "konservativas": "konservativ",
    "konservativast": "konservativ",
    "konservativaste": "konservativ",
    "konservativastes": "konservativ",
    "konservativasts": "konservativ",
    "konservative": "konservativ",
    "konservatives": "konservativ",
    "konservativs": "konservativ",
    "konservativt": "konservativ",
    "konservativts": "konservativ",
    "konservatorer": "konservator",
    "konservatorerna": "konservator",
    "konservatorernas": "konservator",
    "konservatorers": "konservator",
    "konservatorie": "konservatorium",
    "konservatorier": "konservatorium",
    "konservatorierna": "konservatorium",
    "konservatoriernas": "konservatorium",
    "konservatoriers": "konservatorium",
    "konservatoriet": "konservatorium",
    "konservatoriets": "konservatorium",
    "konservatoriums": "konservatorium",
    "konservatorn": "konservator",
    "konservatorns": "konservator",
    "konservators": "konservator",
    "konservburkar": "konservburk",
    "konservburkarna": "konservburk",
    "konservburkarnas": "konservburk",
    "konservburkars": "konservburk",
    "konservburken": "konservburk",
    "konservburkens": "konservburk",
    "konservburks": "konservburk",
    "konserven": "konserv",
    "konservens": "konserv",
    "konserver": "konserv",
    "konserverad": "konservera",
    "konserverade": "konservera",
    "konserverades": "konservera",
    "konserverads": "konservera",
    "konserverande": "konservera",
    "konserveranden": "konserverande",
    "konserverandena": "konserverande",
    "konserverandenas": "konserverande",
    "konserverandens": "konserverande",
    "konserverandes": "konserverande",
    "konserverandet": "konserverande",
    "konserverandets": "konserverande",
    "konserverar": "konservera",
    "konserveras": "konservera",
    "konserverat": "konservera",
    "konserverats": "konservera",
    "konserverbara": "konserverbar",
    "konserverbarare": "konserverbar",
    "konserverbarares": "konserverbar",
    "konserverbaras": "konserverbar",
    "konserverbarast": "konserverbar",
    "konserverbaraste": "konserverbar",
    "konserverbarastes": "konserverbar",
    "konserverbarasts": "konserverbar",
    "konserverbare": "konserverbar",
    "konserverbares": "konserverbar",
    "konserverbarheten": "konserverbarhet",
    "konserverbarhetens": "konserverbarhet",
    "konserverbarhets": "konserverbarhet",
    "konserverbars": "konserverbar",
    "konserverbart": "konserverbar",
    "konserverbarts": "konserverbar",
    "konserveringar": "konservering",
    "konserveringarna": "konservering",
    "konserveringarnas": "konservering",
    "konserveringars": "konservering",
    "konserveringen": "konservering",
    "konserveringens": "konservering",
    "konserverings": "konservering",
    "konserveringsapparaten": "konserveringsapparat",
    "konserveringsapparatens": "konserveringsapparat",
    "konserveringsapparater": "konserveringsapparat",
    "konserveringsapparaterna": "konserveringsapparat",
    "konserveringsapparaternas": "konserveringsapparat",
    "konserveringsapparaters": "konserveringsapparat",
    "konserveringsapparats": "konserveringsapparat",
    "konserveringsmedels": "konserveringsmedel",
    "konserveringsmedlen": "konserveringsmedel",
    "konserveringsmedlens": "konserveringsmedel",
    "konserveringsmedlet": "konserveringsmedel",
    "konserveringsmedlets": "konserveringsmedel",
    "konserverna": "konserv",
    "konservernas": "konserv",
    "konservers": "konserv",
    "konservfabriken": "konservfabrik",
    "konservfabrikens": "konservfabrik",
    "konservfabriker": "konservfabrik",
    "konservfabrikerna": "konservfabrik",
    "konservfabrikernas": "konservfabrik",
    "konservfabrikers": "konservfabrik",
    "konservfabriks": "konservfabrik",
    "konservs": "konserv",
    "konservöppnar": "konservöppnare",
    "konservöppnaren": "konservöppnare",
    "konservöppnarens": "konservöppnare",
    "konservöppnares": "konservöppnare",
    "konservöppnarna": "konservöppnare",
    "konservöppnarnas": "konservöppnare",
    "konsiderationen": "konsideration",
    "konsiderationens": "konsideration",
    "konsiderationer": "konsideration",
    "konsiderationerna": "konsideration",
    "konsiderationernas": "konsideration",
    "konsiderationers": "konsideration",
    "konsiderations": "konsideration",
    "konsignationen": "konsignation",
    "konsignationens": "konsignation",
    "konsignationer": "konsignation",
    "konsignationerna": "konsignation",
    "konsignationernas": "konsignation",
    "konsignationers": "konsignation",
    "konsignations": "konsignation",
    "konsignerad": "konsignera",
    "konsignerade": "konsignera",
    "konsignerades": "konsignera",
    "konsignerads": "konsignera",
    "konsignerande": "konsignera",
    "konsigneranden": "konsignerande",
    "konsignerandena": "konsignerande",
    "konsignerandenas": "konsignerande",
    "konsignerandens": "konsignerande",
    "konsignerandes": "konsignerande",
    "konsignerandet": "konsignerande",
    "konsignerandets": "konsignerande",
    "konsignerar": "konsignera",
    "konsigneras": "konsignera",
    "konsignerat": "konsignera",
    "konsignerats": "konsignera",
    "konsignerbara": "konsignerbar",
    "konsignerbarare": "konsignerbar",
    "konsignerbarares": "konsignerbar",
    "konsignerbaras": "konsignerbar",
    "konsignerbarast": "konsignerbar",
    "konsignerbaraste": "konsignerbar",
    "konsignerbarastes": "konsignerbar",
    "konsignerbarasts": "konsignerbar",
    "konsignerbare": "konsignerbar",
    "konsignerbares": "konsignerbar",
    "konsignerbarheten": "konsignerbarhet",
    "konsignerbarhetens": "konsignerbarhet",
    "konsignerbarhets": "konsignerbarhet",
    "konsignerbars": "konsignerbar",
    "konsignerbart": "konsignerbar",
    "konsignerbarts": "konsignerbar",
    "konsigneringar": "konsignering",
    "konsigneringarna": "konsignering",
    "konsigneringarnas": "konsignering",
    "konsigneringars": "konsignering",
    "konsigneringen": "konsignering",
    "konsigneringens": "konsignering",
    "konsignerings": "konsignering",
    "konsiliansen": "konsilians",
    "konsiliansens": "konsilians",
    "konsilianser": "konsilians",
    "konsilianserna": "konsilians",
    "konsiliansernas": "konsilians",
    "konsiliansers": "konsilians",
    "konsilianta": "konsiliant",
    "konsiliantare": "konsiliant",
    "konsiliantares": "konsiliant",
    "konsiliantas": "konsiliant",
    "konsiliantast": "konsiliant",
    "konsiliantaste": "konsiliant",
    "konsiliantastes": "konsiliant",
    "konsiliantasts": "konsiliant",
    "konsiliante": "konsiliant",
    "konsiliantes": "konsiliant",
    "konsiliants": "konsiliant",
    "konsilie": "konsilium",
    "konsilier": "konsilium",
    "konsilierna": "konsilium",
    "konsiliernas": "konsilium",
    "konsiliers": "konsilium",
    "konsiliet": "konsilium",
    "konsiliets": "konsilium",
    "konsiliums": "konsilium",
    "konsistensen": "konsistens",
    "konsistensens": "konsistens",
    "konsistenser": "konsistens",
    "konsistenserna": "konsistens",
    "konsistensernas": "konsistens",
    "konsistensers": "konsistens",
    "konsistensfettet": "konsistensfett",
    "konsistensfettets": "konsistensfett",
    "konsistensfetts": "konsistensfett",
    "konsistensgivar": "konsistensgivare",
    "konsistensgivaren": "konsistensgivare",
    "konsistensgivarens": "konsistensgivare",
    "konsistensgivares": "konsistensgivare",
    "konsistensgivarna": "konsistensgivare",
    "konsistensgivarnas": "konsistensgivare",
    "konsistoriala": "konsistorial",
    "konsistorialare": "konsistorial",
    "konsistorialares": "konsistorial",
    "konsistorialas": "konsistorial",
    "konsistorialast": "konsistorial",
    "konsistorialaste": "konsistorial",
    "konsistorialastes": "konsistorial",
    "konsistorialasts": "konsistorial",
    "konsistoriale": "konsistorial",
    "konsistoriales": "konsistorial",
    "konsistorials": "konsistorial",
    "konsistorialt": "konsistorial",
    "konsistorialts": "konsistorial",
    "konsistorie": "konsistorium",
    "konsistorier": "konsistorium",
    "konsistorierna": "konsistorium",
    "konsistoriernas": "konsistorium",
    "konsistoriers": "konsistorium",
    "konsistoriet": "konsistorium",
    "konsistoriets": "konsistorium",
    "konsistoriums": "konsistorium",
    "konsolen": "konsol",
    "konsolens": "konsol",
    "konsoler": "konsol",
    "konsolerna": "konsol",
    "konsolernas": "konsol",
    "konsolers": "konsol",
    "konsoliderad": "konsolidera",
    "konsoliderade": "konsolidera",
    "konsoliderades": "konsolidera",
    "konsoliderads": "konsolidera",
    "konsoliderande": "konsolidera",
    "konsolideranden": "konsoliderande",
    "konsoliderandena": "konsoliderande",
    "konsoliderandenas": "konsoliderande",
    "konsoliderandens": "konsoliderande",
    "konsoliderandes": "konsoliderande",
    "konsoliderandet": "konsoliderande",
    "konsoliderandets": "konsoliderande",
    "konsoliderar": "konsolidera",
    "konsolideras": "konsolidera",
    "konsoliderat": "konsolidera",
    "konsoliderats": "konsolidera",
    "konsoliderbara": "konsoliderbar",
    "konsoliderbarare": "konsoliderbar",
    "konsoliderbarares": "konsoliderbar",
    "konsoliderbaras": "konsoliderbar",
    "konsoliderbarast": "konsoliderbar",
    "konsoliderbaraste": "konsoliderbar",
    "konsoliderbarastes": "konsoliderbar",
    "konsoliderbarasts": "konsoliderbar",
    "konsoliderbare": "konsoliderbar",
    "konsoliderbares": "konsoliderbar",
    "konsoliderbarheten": "konsoliderbarhet",
    "konsoliderbarhetens": "konsoliderbarhet",
    "konsoliderbarhets": "konsoliderbarhet",
    "konsoliderbars": "konsoliderbar",
    "konsoliderbart": "konsoliderbar",
    "konsoliderbarts": "konsoliderbar",
    "konsolideringar": "konsolidering",
    "konsolideringarna": "konsolidering",
    "konsolideringarnas": "konsolidering",
    "konsolideringars": "konsolidering",
    "konsolideringen": "konsolidering",
    "konsolideringens": "konsolidering",
    "konsoliderings": "konsolidering",
    "konsols": "konsol",
    "konsomméer": "konsommé",
    "konsomméerna": "konsommé",
    "konsomméernas": "konsommé",
    "konsomméers": "konsommé",
    "konsommén": "konsommé",
    "konsomméns": "konsommé",
    "konsommés": "konsommé",
    "konsonansen": "konsonans",
    "konsonansens": "konsonans",
    "konsonanser": "konsonans",
    "konsonanserna": "konsonans",
    "konsonansernas": "konsonans",
    "konsonansers": "konsonans",
    "konsonanta": "konsonant",
    "konsonantare": "konsonant",
    "konsonantares": "konsonant",
    "konsonantas": "konsonant",
    "konsonantast": "konsonant",
    "konsonantaste": "konsonant",
    "konsonantastes": "konsonant",
    "konsonantasts": "konsonant",
    "konsonante": "konsonant",
    "konsonanten": "konsonant",
    "konsonantens": "konsonant",
    "konsonanter": "konsonant",
    "konsonanterna": "konsonant",
    "konsonanternas": "konsonant",
    "konsonanters": "konsonant",
    "konsonantes": "konsonant",
    "konsonants": "konsonant",
    "konsonantstammar": "konsonantstam",
    "konsonantstammarna": "konsonantstam",
    "konsonantstammarnas": "konsonantstam",
    "konsonantstammars": "konsonantstam",
    "konsonantstammen": "konsonantstam",
    "konsonantstammens": "konsonantstam",
    "konsonantstams": "konsonantstam",
    "konsonantsystemen": "konsonantsystem",
    "konsonantsystemens": "konsonantsystem",
    "konsonantsystemet": "konsonantsystem",
    "konsonantsystemets": "konsonantsystem",
    "konsonantsystems": "konsonantsystem",
    "konsort": "konsorter",
    "konsorterna": "konsorter",
    "konsorternas": "konsorter",
    "konsorters": "konsorter",
    "konsortie": "konsortium",
    "konsortier": "konsortium",
    "konsortierna": "konsortium",
    "konsortiernas": "konsortium",
    "konsortiers": "konsortium",
    "konsortiet": "konsortium",
    "konsortiets": "konsortium",
    "konsortiums": "konsortium",
    "konsorts": "konsorter",
    "konspirationen": "konspiration",
    "konspirationens": "konspiration",
    "konspirationer": "konspiration",
    "konspirationerna": "konspiration",
    "konspirationernas": "konspiration",
    "konspirationers": "konspiration",
    "konspirations": "konspiration",
    "konspirationsteorien": "konspirationsteori",
    "konspirationsteoriens": "konspirationsteori",
    "konspirationsteorier": "konspirationsteori",
    "konspirationsteorierna": "konspirationsteori",
    "konspirationsteoriernas": "konspirationsteori",
    "konspirationsteoriers": "konspirationsteori",
    "konspirationsteorin": "konspirationsteori",
    "konspirationsteorins": "konspirationsteori",
    "konspirationsteoris": "konspirationsteori",
    "konspirativa": "konspirativ",
    "konspirativare": "konspirativ",
    "konspirativares": "konspirativ",
    "konspirativas": "konspirativ",
    "konspirativast": "konspirativ",
    "konspirativaste": "konspirativ",
    "konspirativastes": "konspirativ",
    "konspirativasts": "konspirativ",
    "konspirative": "konspirativ",
    "konspiratives": "konspirativ",
    "konspirativs": "konspirativ",
    "konspirativt": "konspirativ",
    "konspirativts": "konspirativ",
    "konspiratoriska": "konspiratorisk",
    "konspiratoriskare": "konspiratorisk",
    "konspiratoriskares": "konspiratorisk",
    "konspiratoriskas": "konspiratorisk",
    "konspiratoriskast": "konspiratorisk",
    "konspiratoriskaste": "konspiratorisk",
    "konspiratoriskastes": "konspiratorisk",
    "konspiratoriskasts": "konspiratorisk",
    "konspiratoriske": "konspiratorisk",
    "konspiratoriskes": "konspiratorisk",
    "konspiratorisks": "konspiratorisk",
    "konspiratoriskt": "konspiratorisk",
    "konspiratoriskts": "konspiratorisk",
    "konspiratören": "konspiratör",
    "konspiratörens": "konspiratör",
    "konspiratörer": "konspiratör",
    "konspiratörerna": "konspiratör",
    "konspiratörernas": "konspiratör",
    "konspiratörers": "konspiratör",
    "konspiratörs": "konspiratör",
    "konspirerade": "konspirera",
    "konspirerades": "konspirera",
    "konspirerande": "konspirera",
    "konspireranden": "konspirerande",
    "konspirerandena": "konspirerande",
    "konspirerandenas": "konspirerande",
    "konspirerandens": "konspirerande",
    "konspirerandes": "konspirerande",
    "konspirerandet": "konspirerande",
    "konspirerandets": "konspirerande",
    "konspirerar": "konspirera",
    "konspireras": "konspirera",
    "konspirerat": "konspirera",
    "konspirerats": "konspirera",
    "konspireringar": "konspirering",
    "konspireringarna": "konspirering",
    "konspireringarnas": "konspirering",
    "konspireringars": "konspirering",
    "konspireringen": "konspirering",
    "konspireringens": "konspirering",
    "konspirerings": "konspirering",
    "konstansen": "konstans",
    "konstansens": "konstans",
    "konstansfenomenen": "konstansfenomen",
    "konstansfenomenens": "konstansfenomen",
    "konstansfenomenet": "konstansfenomen",
    "konstansfenomenets": "konstansfenomen",
    "konstansfenomens": "konstansfenomen",
    "konstanta": "konstant",
    "konstantare": "konstant",
    "konstantares": "konstant",
    "konstantas": "konstant",
    "konstantast": "konstant",
    "konstantaste": "konstant",
    "konstantastes": "konstant",
    "konstantasts": "konstant",
    "konstante": "konstant",
    "konstanten": "konstant",
    "konstantens": "konstant",
    "konstanter": "konstant",
    "konstanterna": "konstant",
    "konstanternas": "konstant",
    "konstanters": "konstant",
    "konstantes": "konstant",
    "konstants": "konstant",
    "konstapeln": "konstapel",
    "konstapelns": "konstapel",
    "konstapels": "konstapel",
    "konstaplar": "konstapel",
    "konstaplarna": "konstapel",
    "konstaplarnas": "konstapel",
    "konstaplars": "konstapel",
    "konstarten": "konstart",
    "konstartens": "konstart",
    "konstarter": "konstart",
    "konstarterna": "konstart",
    "konstarternas": "konstart",
    "konstarters": "konstart",
    "konstarts": "konstart",
    "konstaterad": "konstatera",
    "konstaterade": "konstatera",
    "konstaterades": "konstatera",
    "konstaterads": "konstatera",
    "konstaterande": "konstatera",
    "konstateranden": "konstaterande",
    "konstaterandena": "konstaterande",
    "konstaterandenas": "konstaterande",
    "konstaterandens": "konstaterande",
    "konstaterandes": "konstaterande",
    "konstaterandet": "konstaterande",
    "konstaterandets": "konstaterande",
    "konstaterar": "konstatera",
    "konstateras": "konstatera",
    "konstaterat": "konstatera",
    "konstaterats": "konstatera",
    "konstaterbara": "konstaterbar",
    "konstaterbarare": "konstaterbar",
    "konstaterbarares": "konstaterbar",
    "konstaterbaras": "konstaterbar",
    "konstaterbarast": "konstaterbar",
    "konstaterbaraste": "konstaterbar",
    "konstaterbarastes": "konstaterbar",
    "konstaterbarasts": "konstaterbar",
    "konstaterbare": "konstaterbar",
    "konstaterbares": "konstaterbar",
    "konstaterbarheten": "konstaterbarhet",
    "konstaterbarhetens": "konstaterbarhet",
    "konstaterbarhets": "konstaterbarhet",
    "konstaterbars": "konstaterbar",
    "konstaterbart": "konstaterbar",
    "konstaterbarts": "konstaterbar",
    "konstateringar": "konstatering",
    "konstateringarna": "konstatering",
    "konstateringarnas": "konstatering",
    "konstateringars": "konstatering",
    "konstateringen": "konstatering",
    "konstateringens": "konstatering",
    "konstaterings": "konstatering",
    "konstbefrukt": "konstbefrukta",
    "konstbefruktad": "konstbefrukta",
    "konstbefruktade": "konstbefrukta",
    "konstbefruktades": "konstbefrukta",
    "konstbefruktads": "konstbefrukta",
    "konstbefruktande": "konstbefrukta",
    "konstbefruktanden": "konstbefruktande",
    "konstbefruktandena": "konstbefruktande",
    "konstbefruktandenas": "konstbefruktande",
    "konstbefruktandens": "konstbefruktande",
    "konstbefruktandes": "konstbefruktande",
    "konstbefruktandet": "konstbefruktande",
    "konstbefruktandets": "konstbefruktande",
    "konstbefruktar": "konstbefrukta",
    "konstbefruktas": "konstbefrukta",
    "konstbefruktat": "konstbefrukta",
    "konstbefruktats": "konstbefrukta",
    "konstberidar": "konstberidare",
    "konstberidaren": "konstberidare",
    "konstberidarens": "konstberidare",
    "konstberidares": "konstberidare",
    "konstberidarna": "konstberidare",
    "konstberidarnas": "konstberidare",
    "konstbevattn": "konstbevattna",
    "konstbevattnad": "konstbevattna",
    "konstbevattnade": "konstbevattna",
    "konstbevattnades": "konstbevattna",
    "konstbevattnads": "konstbevattna",
    "konstbevattnande": "konstbevattna",
    "konstbevattnanden": "konstbevattnande",
    "konstbevattnandena": "konstbevattnande",
    "konstbevattnandenas": "konstbevattnande",
    "konstbevattnandens": "konstbevattnande",
    "konstbevattnandes": "konstbevattnande",
    "konstbevattnandet": "konstbevattnande",
    "konstbevattnandets": "konstbevattnande",
    "konstbevattnar": "konstbevattna",
    "konstbevattnas": "konstbevattna",
    "konstbevattnat": "konstbevattna",
    "konstbevattnats": "konstbevattna",
    "konstbevattningar": "konstbevattning",
    "konstbevattningarna": "konstbevattning",
    "konstbevattningarnas": "konstbevattning",
    "konstbevattningars": "konstbevattning",
    "konstbevattningen": "konstbevattning",
    "konstbevattningens": "konstbevattning",
    "konstbevattnings": "konstbevattning",
    "konstellationen": "konstellation",
    "konstellationens": "konstellation",
    "konstellationer": "konstellation",
    "konstellationerna": "konstellation",
    "konstellationernas": "konstellation",
    "konstellationers": "konstellation",
    "konstellations": "konstellation",
    "konsten": "konst",
    "konstens": "konst",
    "konster": "konst",
    "konsterna": "konst",
    "konsternas": "konst",
    "konsternationen": "konsternation",
    "konsternationens": "konsternation",
    "konsternationer": "konsternation",
    "konsternationerna": "konsternation",
    "konsternationernas": "konsternation",
    "konsternationers": "konsternation",
    "konsternations": "konsternation",
    "konsternerad": "konsternera",
    "konsternerade": "konsternera",
    "konsternerades": "konsternera",
    "konsternerads": "konsternera",
    "konsternerande": "konsternera",
    "konsterneranden": "konsternerande",
    "konsternerandena": "konsternerande",
    "konsternerandenas": "konsternerande",
    "konsternerandens": "konsternerande",
    "konsternerandes": "konsternerande",
    "konsternerandet": "konsternerande",
    "konsternerandets": "konsternerande",
    "konsternerar": "konsternera",
    "konsterneras": "konsternera",
    "konsternerat": "konsternera",
    "konsternerats": "konsternera",
    "konsternerbara": "konsternerbar",
    "konsternerbarare": "konsternerbar",
    "konsternerbarares": "konsternerbar",
    "konsternerbaras": "konsternerbar",
    "konsternerbarast": "konsternerbar",
    "konsternerbaraste": "konsternerbar",
    "konsternerbarastes": "konsternerbar",
    "konsternerbarasts": "konsternerbar",
    "konsternerbare": "konsternerbar",
    "konsternerbares": "konsternerbar",
    "konsternerbarheten": "konsternerbarhet",
    "konsternerbarhetens": "konsternerbarhet",
    "konsternerbarhets": "konsternerbarhet",
    "konsternerbars": "konsternerbar",
    "konsternerbart": "konsternerbar",
    "konsternerbarts": "konsternerbar",
    "konsterneringar": "konsternering",
    "konsterneringarna": "konsternering",
    "konsterneringarnas": "konsternering",
    "konsterneringars": "konsternering",
    "konsterneringen": "konsternering",
    "konsterneringens": "konsternering",
    "konsternerings": "konsternering",
    "konsters": "konst",
    "konstfibermöbeln": "konstfibermöbel",
    "konstfibermöbelns": "konstfibermöbel",
    "konstfibermöbels": "konstfibermöbel",
    "konstfibermöbler": "konstfibermöbel",
    "konstfibermöblerna": "konstfibermöbel",
    "konstfibermöblernas": "konstfibermöbel",
    "konstfibermöblers": "konstfibermöbel",
    "konstfibern": "konstfiber",
    "konstfiberns": "konstfiber",
    "konstfibers": "konstfiber",
    "konstfibrer": "konstfiber",
    "konstfibrerna": "konstfiber",
    "konstfibrernas": "konstfiber",
    "konstfibrers": "konstfiber",
    "konstfliten": "konstflit",
    "konstflitens": "konstflit",
    "konstflits": "konstflit",
    "konstflygningar": "konstflygning",
    "konstflygningarna": "konstflygning",
    "konstflygningarnas": "konstflygning",
    "konstflygningars": "konstflygning",
    "konstflygningen": "konstflygning",
    "konstflygningens": "konstflygning",
    "konstflygnings": "konstflygning",
    "konstfrusens": "konstfrusen",
    "konstfruset": "konstfrusen",
    "konstfrusets": "konstfrusen",
    "konstfrusna": "konstfrusen",
    "konstfrusnare": "konstfrusen",
    "konstfrusnares": "konstfrusen",
    "konstfrusnas": "konstfrusen",
    "konstfrusnast": "konstfrusen",
    "konstfrusnaste": "konstfrusen",
    "konstfrusnastes": "konstfrusen",
    "konstfrusnasts": "konstfrusen",
    "konstfrusne": "konstfrusen",
    "konstfrusnes": "konstfrusen",
    "konstfulla": "konstfull",
    "konstfullare": "konstfull",
    "konstfullares": "konstfull",
    "konstfullas": "konstfull",
    "konstfullast": "konstfull",
    "konstfullaste": "konstfull",
    "konstfullastes": "konstfull",
    "konstfullasts": "konstfull",
    "konstfulle": "konstfull",
    "konstfulles": "konstfull",
    "konstfullheten": "konstfullhet",
    "konstfullhetens": "konstfullhet",
    "konstfullheter": "konstfullhet",
    "konstfullheterna": "konstfullhet",
    "konstfullheternas": "konstfullhet",
    "konstfullheters": "konstfullhet",
    "konstfullhets": "konstfullhet",
    "konstfulls": "konstfull",
    "konstfullt": "konstfull",
    "konstfullts": "konstfull",
    "konstfärdiga": "konstfärdig",
    "konstfärdigare": "konstfärdig",
    "konstfärdigares": "konstfärdig",
    "konstfärdigas": "konstfärdig",
    "konstfärdigast": "konstfärdig",
    "konstfärdigaste": "konstfärdig",
    "konstfärdigastes": "konstfärdig",
    "konstfärdigasts": "konstfärdig",
    "konstfärdige": "konstfärdig",
    "konstfärdiges": "konstfärdig",
    "konstfärdigheten": "konstfärdighet",
    "konstfärdighetens": "konstfärdighet",
    "konstfärdigheter": "konstfärdighet",
    "konstfärdigheterna": "konstfärdighet",
    "konstfärdigheternas": "konstfärdighet",
    "konstfärdigheters": "konstfärdighet",
    "konstfärdighets": "konstfärdighet",
    "konstfärdigs": "konstfärdig",
    "konstfärdigt": "konstfärdig",
    "konstfärdigts": "konstfärdig",
    "konstföreläsningar": "konstföreläsning",
    "konstföreläsningarna": "konstföreläsning",
    "konstföreläsningarnas": "konstföreläsning",
    "konstföreläsningars": "konstföreläsning",
    "konstföreläsningen": "konstföreläsning",
    "konstföreläsningens": "konstföreläsning",
    "konstföreläsnings": "konstföreläsning",
    "konstföreningar": "konstförening",
    "konstföreningarna": "konstförening",
    "konstföreningarnas": "konstförening",
    "konstföreningars": "konstförening",
    "konstföreningen": "konstförening",
    "konstföreningens": "konstförening",
    "konstförenings": "konstförening",
    "konstförfarenheten": "konstförfarenhet",
    "konstförfarenhetens": "konstförfarenhet",
    "konstförfarenhets": "konstförfarenhet",
    "konstförfarens": "konstförfaren",
    "konstförfaret": "konstförfaren",
    "konstförfarets": "konstförfaren",
    "konstförfarna": "konstförfaren",
    "konstförfarnare": "konstförfaren",
    "konstförfarnares": "konstförfaren",
    "konstförfarnas": "konstförfaren",
    "konstförfarnast": "konstförfaren",
    "konstförfarnaste": "konstförfaren",
    "konstförfarnastes": "konstförfaren",
    "konstförfarnasts": "konstförfaren",
    "konstförfarne": "konstförfaren",
    "konstförfarnes": "konstförfaren",
    "konstförvanten": "konstförvant",
    "konstförvantens": "konstförvant",
    "konstförvanter": "konstförvant",
    "konstförvanterna": "konstförvant",
    "konstförvanternas": "konstförvant",
    "konstförvanters": "konstförvant",
    "konstförvants": "konstförvant",
    "konstgallerier": "konstgalleri",
    "konstgallerierna": "konstgalleri",
    "konstgalleriernas": "konstgalleri",
    "konstgalleriers": "konstgalleri",
    "konstgalleriet": "konstgalleri",
    "konstgalleriets": "konstgalleri",
    "konstgalleris": "konstgalleri",
    "konstgallerit": "konstgalleri",
    "konstgallerits": "konstgalleri",
    "konstgjorda": "konstgjord",
    "konstgjordare": "konstgjord",
    "konstgjordares": "konstgjord",
    "konstgjordas": "konstgjord",
    "konstgjordast": "konstgjord",
    "konstgjordaste": "konstgjord",
    "konstgjordastes": "konstgjord",
    "konstgjordasts": "konstgjord",
    "konstgjorde": "konstgjord",
    "konstgjordes": "konstgjord",
    "konstgjordheten": "konstgjordhet",
    "konstgjordhetens": "konstgjordhet",
    "konstgjordhets": "konstgjordhet",
    "konstgjords": "konstgjord",
    "konstgjort": "konstgjord",
    "konstgjorts": "konstgjord",
    "konstglaset": "konstglas",
    "konstglasets": "konstglas",
    "konstgreppen": "konstgrepp",
    "konstgreppens": "konstgrepp",
    "konstgreppet": "konstgrepp",
    "konstgreppets": "konstgrepp",
    "konstgrepps": "konstgrepp",
    "konstgödseln": "konstgödsel",
    "konstgödselns": "konstgödsel",
    "konstgödsels": "konstgödsel",
    "konsthallar": "konsthall",
    "konsthallarna": "konsthall",
    "konsthallarnas": "konsthall",
    "konsthallars": "konsthall",
    "konsthallen": "konsthall",
    "konsthallens": "konsthall",
    "konsthalls": "konsthall",
    "konsthantverken": "konsthantverk",
    "konsthantverkens": "konsthantverk",
    "konsthantverket": "konsthantverk",
    "konsthantverkets": "konsthantverk",
    "konsthantverks": "konsthantverk",
    "konsthantverksmässiga": "konsthantverksmässig",
    "konsthantverksmässigare": "konsthantverksmässig",
    "konsthantverksmässigares": "konsthantverksmässig",
    "konsthantverksmässigas": "konsthantverksmässig",
    "konsthantverksmässigast": "konsthantverksmässig",
    "konsthantverksmässigaste": "konsthantverksmässig",
    "konsthantverksmässigastes": "konsthantverksmässig",
    "konsthantverksmässigasts": "konsthantverksmässig",
    "konsthantverksmässige": "konsthantverksmässig",
    "konsthantverksmässiges": "konsthantverksmässig",
    "konsthantverksmässigs": "konsthantverksmässig",
    "konsthantverksmässigt": "konsthantverksmässig",
    "konsthantverksmässigts": "konsthantverksmässig",
    "konsthartser": "konstharts",
    "konsthartserna": "konstharts",
    "konsthartsernas": "konstharts",
    "konsthartsers": "konstharts",
    "konsthartset": "konstharts",
    "konsthartsets": "konstharts",
    "konsthistorian": "konsthistoria",
    "konsthistorians": "konsthistoria",
    "konsthistorias": "konsthistoria",
    "konsthistorien": "konsthistoria",
    "konsthistoriens": "konsthistoria",
    "konsthistoriska": "konsthistorisk",
    "konsthistoriskare": "konsthistorisk",
    "konsthistoriskares": "konsthistorisk",
    "konsthistoriskas": "konsthistorisk",
    "konsthistoriskast": "konsthistorisk",
    "konsthistoriskaste": "konsthistorisk",
    "konsthistoriskastes": "konsthistorisk",
    "konsthistoriskasts": "konsthistorisk",
    "konsthistoriske": "konsthistorisk",
    "konsthistoriskes": "konsthistorisk",
    "konsthistorisks": "konsthistorisk",
    "konsthistoriskt": "konsthistorisk",
    "konsthistoriskts": "konsthistorisk",
    "konstifika": "konstifik",
    "konstifikare": "konstifik",
    "konstifikares": "konstifik",
    "konstifikas": "konstifik",
    "konstifikast": "konstifik",
    "konstifikaste": "konstifik",
    "konstifikastes": "konstifik",
    "konstifikasts": "konstifik",
    "konstifike": "konstifik",
    "konstifikes": "konstifik",
    "konstifiks": "konstifik",
    "konstifikt": "konstifik",
    "konstifikts": "konstifik",
    "konstiga": "konstig",
    "konstigare": "konstig",
    "konstigares": "konstig",
    "konstigas": "konstig",
    "konstigast": "konstig",
    "konstigaste": "konstig",
    "konstigastes": "konstig",
    "konstigasts": "konstig",
    "konstige": "konstig",
    "konstiges": "konstig",
    "konstigheten": "konstighet",
    "konstighetens": "konstighet",
    "konstigheter": "konstighet",
    "konstigheterna": "konstighet",
    "konstigheternas": "konstighet",
    "konstigheters": "konstighet",
    "konstighets": "konstighet",
    "konstigs": "konstig",
    "konstigt": "konstig",
    "konstigts": "konstig",
    "konstindustrien": "konstindustri",
    "konstindustriens": "konstindustri",
    "konstindustrier": "konstindustri",
    "konstindustrierna": "konstindustri",
    "konstindustriernas": "konstindustri",
    "konstindustriers": "konstindustri",
    "konstindustrin": "konstindustri",
    "konstindustrins": "konstindustri",
    "konstindustris": "konstindustri",
    "konstituenten": "konstituent",
    "konstituentens": "konstituent",
    "konstituenter": "konstituent",
    "konstituenterna": "konstituent",
    "konstituenternas": "konstituent",
    "konstituenters": "konstituent",
    "konstituents": "konstituent",
    "konstituerad": "konstituera",
    "konstituerade": "konstituera",
    "konstituerades": "konstituera",
    "konstituerads": "konstituera",
    "konstituerande": "konstituera",
    "konstitueranden": "konstituerande",
    "konstituerandena": "konstituerande",
    "konstituerandenas": "konstituerande",
    "konstituerandens": "konstituerande",
    "konstituerandes": "konstituerande",
    "konstituerandet": "konstituerande",
    "konstituerandets": "konstituerande",
    "konstituerar": "konstituera",
    "konstitueras": "konstituera",
    "konstituerat": "konstituera",
    "konstituerats": "konstituera",
    "konstituerbara": "konstituerbar",
    "konstituerbarare": "konstituerbar",
    "konstituerbarares": "konstituerbar",
    "konstituerbaras": "konstituerbar",
    "konstituerbarast": "konstituerbar",
    "konstituerbaraste": "konstituerbar",
    "konstituerbarastes": "konstituerbar",
    "konstituerbarasts": "konstituerbar",
    "konstituerbare": "konstituerbar",
    "konstituerbares": "konstituerbar",
    "konstituerbarheten": "konstituerbarhet",
    "konstituerbarhetens": "konstituerbarhet",
    "konstituerbarhets": "konstituerbarhet",
    "konstituerbars": "konstituerbar",
    "konstituerbart": "konstituerbar",
    "konstituerbarts": "konstituerbar",
    "konstitueringar": "konstituering",
    "konstitueringarna": "konstituering",
    "konstitueringarnas": "konstituering",
    "konstitueringars": "konstituering",
    "konstitueringen": "konstituering",
    "konstitueringens": "konstituering",
    "konstituerings": "konstituering",
    "konstitutionella": "konstitutionell",
    "konstitutionellare": "konstitutionell",
    "konstitutionellares": "konstitutionell",
    "konstitutionellas": "konstitutionell",
    "konstitutionellast": "konstitutionell",
    "konstitutionellaste": "konstitutionell",
    "konstitutionellastes": "konstitutionell",
    "konstitutionellasts": "konstitutionell",
    "konstitutionelle": "konstitutionell",
    "konstitutionelles": "konstitutionell",
    "konstitutionells": "konstitutionell",
    "konstitutionellt": "konstitutionell",
    "konstitutionellts": "konstitutionell",
    "konstitutionen": "konstitution",
    "konstitutionens": "konstitution",
    "konstitutioner": "konstitution",
    "konstitutionerna": "konstitution",
    "konstitutionernas": "konstitution",
    "konstitutioners": "konstitution",
    "konstitutions": "konstitution",
    "konstitutionsutskotten": "konstitutionsutskott",
    "konstitutionsutskottens": "konstitutionsutskott",
    "konstitutionsutskottet": "konstitutionsutskott",
    "konstitutionsutskottets": "konstitutionsutskott",
    "konstitutionsutskotts": "konstitutionsutskott",
    "konstitutiva": "konstitutiv",
    "konstitutivare": "konstitutiv",
    "konstitutivares": "konstitutiv",
    "konstitutivas": "konstitutiv",
    "konstitutivast": "konstitutiv",
    "konstitutivaste": "konstitutiv",
    "konstitutivastes": "konstitutiv",
    "konstitutivasts": "konstitutiv",
    "konstitutive": "konstitutiv",
    "konstitutives": "konstitutiv",
    "konstitutivs": "konstitutiv",
    "konstitutivt": "konstitutiv",
    "konstitutivts": "konstitutiv",
    "konstitutorialen": "konstitutorial",
    "konstitutorialens": "konstitutorial",
    "konstitutorialet": "konstitutorial",
    "konstitutorialets": "konstitutorial",
    "konstitutorials": "konstitutorial",
    "konstkritiken": "konstkritik",
    "konstkritikens": "konstkritik",
    "konstkritikern": "konstkritiker",
    "konstkritikerna": "konstkritiker",
    "konstkritikernas": "konstkritiker",
    "konstkritikerns": "konstkritiker",
    "konstkritikers": "konstkritiker",
    "konstkritiks": "konstkritik",
    "konstlade": "konstlad",
    "konstlades": "konstlad",
    "konstlads": "konstlad",
    "konstlat": "konstlad",
    "konstlats": "konstlad",
    "konstligan": "konstliga",
    "konstligans": "konstliga",
    "konstligas": "konstliga",
    "konstlige": "konstliga",
    "konstligor": "konstliga",
    "konstligorna": "konstliga",
    "konstligornas": "konstliga",
    "konstligors": "konstliga",
    "konstliven": "konstliv",
    "konstlivens": "konstliv",
    "konstlivet": "konstliv",
    "konstlivets": "konstliv",
    "konstlivs": "konstliv",
    "konstläderförstärkningar": "konstläderförstärkning",
    "konstläderförstärkningarna": "konstläderförstärkning",
    "konstläderförstärkningarnas": "konstläderförstärkning",
    "konstläderförstärkningars": "konstläderförstärkning",
    "konstläderförstärkningen": "konstläderförstärkning",
    "konstläderförstärkningens": "konstläderförstärkning",
    "konstläderförstärknings": "konstläderförstärkning",
    "konstläders": "konstläder",
    "konstlädret": "konstläder",
    "konstlädrets": "konstläder",
    "konstlösa": "konstlös",
    "konstlösare": "konstlös",
    "konstlösares": "konstlös",
    "konstlösas": "konstlös",
    "konstlösast": "konstlös",
    "konstlösaste": "konstlös",
    "konstlösastes": "konstlös",
    "konstlösasts": "konstlös",
    "konstlöse": "konstlös",
    "konstlöses": "konstlös",
    "konstlösheten": "konstlöshet",
    "konstlöshetens": "konstlöshet",
    "konstlösheter": "konstlöshet",
    "konstlösheterna": "konstlöshet",
    "konstlösheternas": "konstlöshet",
    "konstlösheters": "konstlöshet",
    "konstlöshets": "konstlöshet",
    "konstlöst": "konstlös",
    "konstlösts": "konstlös",
    "konstmassan": "konstmassa",
    "konstmassans": "konstmassa",
    "konstmassas": "konstmassa",
    "konstmasse": "konstmassa",
    "konstmuseer": "konstmuseum",
    "konstmuseerna": "konstmuseum",
    "konstmuseernas": "konstmuseum",
    "konstmuseers": "konstmuseum",
    "konstmuseet": "konstmuseum",
    "konstmuseets": "konstmuseum",
    "konstmusei": "konstmuseum",
    "konstmuseums": "konstmuseum",
    "konstmässiga": "konstmässig",
    "konstmässigare": "konstmässig",
    "konstmässigares": "konstmässig",
    "konstmässigas": "konstmässig",
    "konstmässigast": "konstmässig",
    "konstmässigaste": "konstmässig",
    "konstmässigastes": "konstmässig",
    "konstmässigasts": "konstmässig",
    "konstmässige": "konstmässig",
    "konstmässiges": "konstmässig",
    "konstmässigs": "konstmässig",
    "konstmässigt": "konstmässig",
    "konstmässigts": "konstmässig",
    "konstmålar": "konstmålare",
    "konstmålaren": "konstmålare",
    "konstmålarens": "konstmålare",
    "konstmålares": "konstmålare",
    "konstmålarna": "konstmålare",
    "konstmålarnas": "konstmålare",
    "konstmålningar": "konstmålning",
    "konstmålningarna": "konstmålning",
    "konstmålningarnas": "konstmålning",
    "konstmålningars": "konstmålning",
    "konstmålningen": "konstmålning",
    "konstmålningens": "konstmålning",
    "konstmålnings": "konstmålning",
    "konstnären": "konstnär",
    "konstnärens": "konstnär",
    "konstnärer": "konstnär",
    "konstnärerna": "konstnär",
    "konstnärernas": "konstnär",
    "konstnärers": "konstnär",
    "konstnärliga": "konstnärlig",
    "konstnärligare": "konstnärlig",
    "konstnärligares": "konstnärlig",
    "konstnärligas": "konstnärlig",
    "konstnärligast": "konstnärlig",
    "konstnärligaste": "konstnärlig",
    "konstnärligastes": "konstnärlig",
    "konstnärligasts": "konstnärlig",
    "konstnärlige": "konstnärlig",
    "konstnärliges": "konstnärlig",
    "konstnärligheten": "konstnärlighet",
    "konstnärlighetens": "konstnärlighet",
    "konstnärlighets": "konstnärlighet",
    "konstnärligs": "konstnärlig",
    "konstnärligt": "konstnärlig",
    "konstnärligts": "konstnärlig",
    "konstnärs": "konstnär",
    "konstnärsblicken": "konstnärsblick",
    "konstnärsblickens": "konstnärsblick",
    "konstnärsblicks": "konstnärsblick",
    "konstnärskapet": "konstnärskap",
    "konstnärskapets": "konstnärskap",
    "konstnärskaps": "konstnärskap",
    "konstnärskretsar": "konstnärskrets",
    "konstnärskretsarna": "konstnärskrets",
    "konstnärskretsarnas": "konstnärskrets",
    "konstnärskretsars": "konstnärskrets",
    "konstnärskretsen": "konstnärskrets",
    "konstnärskretsens": "konstnärskrets",
    "konstnärslägenheten": "konstnärslägenhet",
    "konstnärslägenhetens": "konstnärslägenhet",
    "konstnärslägenheter": "konstnärslägenhet",
    "konstnärslägenheterna": "konstnärslägenhet",
    "konstnärslägenheternas": "konstnärslägenhet",
    "konstnärslägenheters": "konstnärslägenhet",
    "konstnärslägenhets": "konstnärslägenhet",
    "konstnärssjälar": "konstnärssjäl",
    "konstnärssjälarna": "konstnärssjäl",
    "konstnärssjälarnas": "konstnärssjäl",
    "konstnärssjälars": "konstnärssjäl",
    "konstnärssjälen": "konstnärssjäl",
    "konstnärssjälens": "konstnärssjäl",
    "konstnärssjäls": "konstnärssjäl",
    "konstnärstäta": "konstnärstät",
    "konstnärstätare": "konstnärstät",
    "konstnärstätares": "konstnärstät",
    "konstnärstätas": "konstnärstät",
    "konstnärstätast": "konstnärstät",
    "konstnärstätaste": "konstnärstät",
    "konstnärstätastes": "konstnärstät",
    "konstnärstätasts": "konstnärstät",
    "konstnärstäte": "konstnärstät",
    "konstnärstätes": "konstnärstät",
    "konstnärstätheten": "konstnärstäthet",
    "konstnärstäthetens": "konstnärstäthet",
    "konstnärstäthets": "konstnärstäthet",
    "konstnärstäts": "konstnärstät",
    "konstnärstätt": "konstnärstät",
    "konstnärstätts": "konstnärstät",
    "konstpausen": "konstpaus",
    "konstpausens": "konstpaus",
    "konstpauser": "konstpaus",
    "konstpauserna": "konstpaus",
    "konstpausernas": "konstpaus",
    "konstpausers": "konstpaus",
    "konstrade": "konstra",
    "konstrades": "konstra",
    "konstrande": "konstra",
    "konstranden": "konstrande",
    "konstrandena": "konstrande",
    "konstrandenas": "konstrande",
    "konstrandens": "konstrande",
    "konstrandes": "konstrande",
    "konstrandet": "konstrande",
    "konstrandets": "konstrande",
    "konstrar": "konstra",
    "konstras": "konstra",
    "konstrat": "konstra",
    "konstrats": "konstra",
    "konstridningar": "konstridning",
    "konstridningarna": "konstridning",
    "konstridningarnas": "konstridning",
    "konstridningars": "konstridning",
    "konstridningen": "konstridning",
    "konstridningens": "konstridning",
    "konstridnings": "konstridning",
    "konstrika": "konstrik",
    "konstrikare": "konstrik",
    "konstrikares": "konstrik",
    "konstrikas": "konstrik",
    "konstrikast": "konstrik",
    "konstrikaste": "konstrik",
    "konstrikastes": "konstrik",
    "konstrikasts": "konstrik",
    "konstrike": "konstrik",
    "konstrikes": "konstrik",
    "konstrikheten": "konstrikhet",
    "konstrikhetens": "konstrikhet",
    "konstrikhets": "konstrikhet",
    "konstriks": "konstrik",
    "konstrikt": "konstrik",
    "konstriktningar": "konstriktning",
    "konstriktningarna": "konstriktning",
    "konstriktningarnas": "konstriktning",
    "konstriktningars": "konstriktning",
    "konstriktningen": "konstriktning",
    "konstriktningens": "konstriktning",
    "konstriktnings": "konstriktning",
    "konstrikts": "konstrik",
    "konstruerad": "konstruera",
    "konstruerade": "konstruerad",
    "konstruerades": "konstruerad",
    "konstruerads": "konstruerad",
    "konstruerande": "konstruera",
    "konstrueranden": "konstruerande",
    "konstruerandena": "konstruerande",
    "konstruerandenas": "konstruerande",
    "konstruerandens": "konstruerande",
    "konstruerandes": "konstruerande",
    "konstruerandet": "konstruerande",
    "konstruerandets": "konstruerande",
    "konstruerar": "konstruera",
    "konstrueras": "konstruera",
    "konstruerat": "konstruerad",
    "konstruerats": "konstruerad",
    "konstruerbara": "konstruerbar",
    "konstruerbarare": "konstruerbar",
    "konstruerbarares": "konstruerbar",
    "konstruerbaras": "konstruerbar",
    "konstruerbarast": "konstruerbar",
    "konstruerbaraste": "konstruerbar",
    "konstruerbarastes": "konstruerbar",
    "konstruerbarasts": "konstruerbar",
    "konstruerbare": "konstruerbar",
    "konstruerbares": "konstruerbar",
    "konstruerbarheten": "konstruerbarhet",
    "konstruerbarhetens": "konstruerbarhet",
    "konstruerbarhets": "konstruerbarhet",
    "konstruerbars": "konstruerbar",
    "konstruerbart": "konstruerbar",
    "konstruerbarts": "konstruerbar",
    "konstrueringar": "konstruering",
    "konstrueringarna": "konstruering",
    "konstrueringarnas": "konstruering",
    "konstrueringars": "konstruering",
    "konstrueringen": "konstruering",
    "konstrueringens": "konstruering",
    "konstruerings": "konstruering",
    "konstruktionen": "konstruktion",
    "konstruktionens": "konstruktion",
    "konstruktioner": "konstruktion",
    "konstruktionerna": "konstruktion",
    "konstruktionernas": "konstruktion",
    "konstruktioners": "konstruktion",
    "konstruktions": "konstruktion",
    "konstruktionsdetaljen": "konstruktionsdetalj",
    "konstruktionsdetaljens": "konstruktionsdetalj",
    "konstruktionsdetaljer": "konstruktionsdetalj",
    "konstruktionsdetaljerna": "konstruktionsdetalj",
    "konstruktionsdetaljernas": "konstruktionsdetalj",
    "konstruktionsdetaljers": "konstruktionsdetalj",
    "konstruktionsdetaljs": "konstruktionsdetalj",
    "konstruktionsgrammatiken": "konstruktionsgrammatik",
    "konstruktionsgrammatikens": "konstruktionsgrammatik",
    "konstruktionsgrammatiker": "konstruktionsgrammatik",
    "konstruktionsgrammatikerna": "konstruktionsgrammatik",
    "konstruktionsgrammatikernas": "konstruktionsgrammatik",
    "konstruktionsgrammatikers": "konstruktionsgrammatik",
    "konstruktionsgrammatiks": "konstruktionsgrammatik",
    "konstruktionslexika": "konstruktionslexikon",
    "konstruktionslexikas": "konstruktionslexikon",
    "konstruktionslexikonen": "konstruktionslexikon",
    "konstruktionslexikonens": "konstruktionslexikon",
    "konstruktionslexikonet": "konstruktionslexikon",
    "konstruktionslexikonets": "konstruktionslexikon",
    "konstruktionslexikons": "konstruktionslexikon",
    "konstruktionslimmen": "konstruktionslim",
    "konstruktionslimmens": "konstruktionslim",
    "konstruktionslimmer": "konstruktionslim",
    "konstruktionslimmerna": "konstruktionslim",
    "konstruktionslimmernas": "konstruktionslim",
    "konstruktionslimmers": "konstruktionslim",
    "konstruktionslimmet": "konstruktionslim",
    "konstruktionslimmets": "konstruktionslim",
    "konstruktionslims": "konstruktionslim",
    "konstruktionsmaterialen": "konstruktionsmaterial",
    "konstruktionsmaterialens": "konstruktionsmaterial",
    "konstruktionsmaterialet": "konstruktionsmaterial",
    "konstruktionsmaterialets": "konstruktionsmaterial",
    "konstruktionsmaterials": "konstruktionsmaterial",
    "konstruktionsmässiga": "konstruktionsmässig",
    "konstruktionsmässigare": "konstruktionsmässig",
    "konstruktionsmässigares": "konstruktionsmässig",
    "konstruktionsmässigas": "konstruktionsmässig",
    "konstruktionsmässigast": "konstruktionsmässig",
    "konstruktionsmässigaste": "konstruktionsmässig",
    "konstruktionsmässigastes": "konstruktionsmässig",
    "konstruktionsmässigasts": "konstruktionsmässig",
    "konstruktionsmässige": "konstruktionsmässig",
    "konstruktionsmässiges": "konstruktionsmässig",
    "konstruktionsmässigs": "konstruktionsmässig",
    "konstruktionsmässigt": "konstruktionsmässig",
    "konstruktionsmässigts": "konstruktionsmässig",
    "konstruktionsritningar": "konstruktionsritning",
    "konstruktionsritningarna": "konstruktionsritning",
    "konstruktionsritningarnas": "konstruktionsritning",
    "konstruktionsritningars": "konstruktionsritning",
    "konstruktionsritningen": "konstruktionsritning",
    "konstruktionsritningens": "konstruktionsritning",
    "konstruktionsritnings": "konstruktionsritning",
    "konstruktiva": "konstruktiv",
    "konstruktivare": "konstruktiv",
    "konstruktivares": "konstruktiv",
    "konstruktivas": "konstruktiv",
    "konstruktivast": "konstruktiv",
    "konstruktivaste": "konstruktiv",
    "konstruktivastes": "konstruktiv",
    "konstruktivasts": "konstruktiv",
    "konstruktive": "konstruktiv",
    "konstruktives": "konstruktiv",
    "konstruktivs": "konstruktiv",
    "konstruktivt": "konstruktiv",
    "konstruktivts": "konstruktiv",
    "konstruktören": "konstruktör",
    "konstruktörens": "konstruktör",
    "konstruktörer": "konstruktör",
    "konstruktörerna": "konstruktör",
    "konstruktörernas": "konstruktör",
    "konstruktörers": "konstruktör",
    "konstruktörs": "konstruktör",
    "konstryttar": "konstryttare",
    "konstryttaren": "konstryttare",
    "konstryttarens": "konstryttare",
    "konstryttares": "konstryttare",
    "konstryttarna": "konstryttare",
    "konstryttarnas": "konstryttare",
    "konsts": "konst",
    "konstsalongen": "konstsalong",
    "konstsalongens": "konstsalong",
    "konstsalonger": "konstsalong",
    "konstsalongerna": "konstsalong",
    "konstsalongernas": "konstsalong",
    "konstsalongers": "konstsalong",
    "konstsalongs": "konstsalong",
    "konstsamlar": "konstsamlare",
    "konstsamlaren": "konstsamlare",
    "konstsamlarens": "konstsamlare",
    "konstsamlares": "konstsamlare",
    "konstsamlarna": "konstsamlare",
    "konstsamlarnas": "konstsamlare",
    "konstsamlingar": "konstsamling",
    "konstsamlingarna": "konstsamling",
    "konstsamlingarnas": "konstsamling",
    "konstsamlingars": "konstsamling",
    "konstsamlingen": "konstsamling",
    "konstsamlingens": "konstsamling",
    "konstsamlings": "konstsamling",
    "konstsatsningar": "konstsatsning",
    "konstsatsningarna": "konstsatsning",
    "konstsatsningarnas": "konstsatsning",
    "konstsatsningars": "konstsatsning",
    "konstsatsningen": "konstsatsning",
    "konstsatsningens": "konstsatsning",
    "konstsatsnings": "konstsatsning",
    "konstsidenet": "konstsiden",
    "konstsidenets": "konstsiden",
    "konstsidens": "konstsiden",
    "konstsilkes": "konstsilke",
    "konstsilket": "konstsilke",
    "konstsilkets": "konstsilke",
    "konstskickliga": "konstskicklig",
    "konstskickligare": "konstskicklig",
    "konstskickligares": "konstskicklig",
    "konstskickligas": "konstskicklig",
    "konstskickligast": "konstskicklig",
    "konstskickligaste": "konstskicklig",
    "konstskickligastes": "konstskicklig",
    "konstskickligasts": "konstskicklig",
    "konstskicklige": "konstskicklig",
    "konstskickliges": "konstskicklig",
    "konstskickligheten": "konstskicklighet",
    "konstskicklighetens": "konstskicklighet",
    "konstskicklighets": "konstskicklighet",
    "konstskickligs": "konstskicklig",
    "konstskickligt": "konstskicklig",
    "konstskickligts": "konstskicklig",
    "konstskojar": "konstskojare",
    "konstskojaren": "konstskojare",
    "konstskojarens": "konstskojare",
    "konstskojares": "konstskojare",
    "konstskojarna": "konstskojare",
    "konstskojarnas": "konstskojare",
    "konstskolan": "konstskola",
    "konstskolans": "konstskola",
    "konstskolas": "konstskola",
    "konstskole": "konstskola",
    "konstskolor": "konstskola",
    "konstskolorna": "konstskola",
    "konstskolornas": "konstskola",
    "konstskolors": "konstskola",
    "konstslöjden": "konstslöjd",
    "konstslöjdens": "konstslöjd",
    "konstslöjds": "konstslöjd",
    "konstsmides": "konstsmide",
    "konstsmidet": "konstsmide",
    "konstsmidets": "konstsmide",
    "konststilar": "konststil",
    "konststilarna": "konststil",
    "konststilarnas": "konststil",
    "konststilars": "konststil",
    "konststilen": "konststil",
    "konststilens": "konststil",
    "konststils": "konststil",
    "konststopp": "konststoppa",
    "konststoppad": "konststoppa",
    "konststoppade": "konststoppa",
    "konststoppades": "konststoppa",
    "konststoppads": "konststoppa",
    "konststoppande": "konststoppa",
    "konststoppanden": "konststoppande",
    "konststoppandena": "konststoppande",
    "konststoppandenas": "konststoppande",
    "konststoppandens": "konststoppande",
    "konststoppandes": "konststoppande",
    "konststoppandet": "konststoppande",
    "konststoppandets": "konststoppande",
    "konststoppar": "konststoppa",
    "konststoppas": "konststoppa",
    "konststoppat": "konststoppa",
    "konststoppats": "konststoppa",
    "konststycken": "konststycke",
    "konststyckena": "konststycke",
    "konststyckenas": "konststycke",
    "konststyckens": "konststycke",
    "konststyckes": "konststycke",
    "konststycket": "konststycke",
    "konststyckets": "konststycke",
    "konststycks": "konststycke",
    "konstutställningar": "konstutställning",
    "konstutställningarna": "konstutställning",
    "konstutställningarnas": "konstutställning",
    "konstutställningars": "konstutställning",
    "konstutställningen": "konstutställning",
    "konstutställningens": "konstutställning",
    "konstutställnings": "konstutställning",
    "konstverken": "konstverk",
    "konstverkens": "konstverk",
    "konstverket": "konstverk",
    "konstverkets": "konstverk",
    "konstverks": "konstverk",
    "konstälskar": "konstälskare",
    "konstälskaren": "konstälskare",
    "konstälskarens": "konstälskare",
    "konstälskares": "konstälskare",
    "konstälskarna": "konstälskare",
    "konstälskarnas": "konstälskare",
    "konståkar": "konståkare",
    "konståkaren": "konståkare",
    "konståkarens": "konståkare",
    "konståkares": "konståkare",
    "konståkarna": "konståkare",
    "konståkarnas": "konståkare",
    "konståkningar": "konståkning",
    "konståkningarna": "konståkning",
    "konståkningarnas": "konståkning",
    "konståkningars": "konståkning",
    "konståkningen": "konståkning",
    "konståkningens": "konståkning",
    "konståknings": "konståkning",
    "konsularjurisdiktionen": "konsularjurisdiktion",
    "konsularjurisdiktionens": "konsularjurisdiktion",
    "konsularjurisdiktioner": "konsularjurisdiktion",
    "konsularjurisdiktionerna": "konsularjurisdiktion",
    "konsularjurisdiktionernas": "konsularjurisdiktion",
    "konsularjurisdiktioners": "konsularjurisdiktion",
    "konsularjurisdiktions": "konsularjurisdiktion",
    "konsulaten": "konsulat",
    "konsulatens": "konsulat",
    "konsulatet": "konsulat",
    "konsulatets": "konsulat",
    "konsulats": "konsulat",
    "konsulenten": "konsulent",
    "konsulentens": "konsulent",
    "konsulenter": "konsulent",
    "konsulenterna": "konsulent",
    "konsulenternas": "konsulent",
    "konsulenters": "konsulent",
    "konsulents": "konsulent",
    "konsuler": "konsul",
    "konsulerna": "konsul",
    "konsulernas": "konsul",
    "konsulers": "konsul",
    "konsulinnan": "konsulinna",
    "konsulinnans": "konsulinna",
    "konsulinnas": "konsulinna",
    "konsulinne": "konsulinna",
    "konsulinnor": "konsulinna",
    "konsulinnorna": "konsulinna",
    "konsulinnornas": "konsulinna",
    "konsulinnors": "konsulinna",
    "konsuln": "konsul",
    "konsulns": "konsul",
    "konsuls": "konsul",
    "konsulsvalen": "konsulsval",
    "konsulsvalens": "konsulsval",
    "konsulsvalet": "konsulsval",
    "konsulsvalets": "konsulsval",
    "konsulsvals": "konsulsval",
    "konsultationen": "konsultation",
    "konsultationens": "konsultation",
    "konsultationer": "konsultation",
    "konsultationerna": "konsultation",
    "konsultationernas": "konsultation",
    "konsultationers": "konsultation",
    "konsultations": "konsultation",
    "konsultativa": "konsultativ",
    "konsultativare": "konsultativ",
    "konsultativares": "konsultativ",
    "konsultativas": "konsultativ",
    "konsultativast": "konsultativ",
    "konsultativaste": "konsultativ",
    "konsultativastes": "konsultativ",
    "konsultativasts": "konsultativ",
    "konsultative": "konsultativ",
    "konsultatives": "konsultativ",
    "konsultativs": "konsultativ",
    "konsultativt": "konsultativ",
    "konsultativts": "konsultativ",
    "konsulten": "konsult",
    "konsultens": "konsult",
    "konsulter": "konsult",
    "konsulterad": "konsultera",
    "konsulterade": "konsultera",
    "konsulterades": "konsultera",
    "konsulterads": "konsultera",
    "konsulterande": "konsultera",
    "konsulteranden": "konsulterande",
    "konsulterandena": "konsulterande",
    "konsulterandenas": "konsulterande",
    "konsulterandens": "konsulterande",
    "konsulterandes": "konsulterande",
    "konsulterandet": "konsulterande",
    "konsulterandets": "konsulterande",
    "konsulterar": "konsultera",
    "konsulteras": "konsultera",
    "konsulterat": "konsultera",
    "konsulterats": "konsultera",
    "konsulterbara": "konsulterbar",
    "konsulterbarare": "konsulterbar",
    "konsulterbarares": "konsulterbar",
    "konsulterbaras": "konsulterbar",
    "konsulterbarast": "konsulterbar",
    "konsulterbaraste": "konsulterbar",
    "konsulterbarastes": "konsulterbar",
    "konsulterbarasts": "konsulterbar",
    "konsulterbare": "konsulterbar",
    "konsulterbares": "konsulterbar",
    "konsulterbarheten": "konsulterbarhet",
    "konsulterbarhetens": "konsulterbarhet",
    "konsulterbarhets": "konsulterbarhet",
    "konsulterbars": "konsulterbar",
    "konsulterbart": "konsulterbar",
    "konsulterbarts": "konsulterbar",
    "konsulteringar": "konsultering",
    "konsulteringarna": "konsultering",
    "konsulteringarnas": "konsultering",
    "konsulteringars": "konsultering",
    "konsulteringen": "konsultering",
    "konsulteringens": "konsultering",
    "konsulterings": "konsultering",
    "konsulterna": "konsult",
    "konsulternas": "konsult",
    "konsulters": "konsult",
    "konsultföretagen": "konsultföretag",
    "konsultföretagens": "konsultföretag",
    "konsultföretaget": "konsultföretag",
    "konsultföretagets": "konsultföretag",
    "konsultföretags": "konsultföretag",
    "konsults": "konsult",
    "konsulära": "konsulär",
    "konsulärare": "konsulär",
    "konsulärares": "konsulär",
    "konsuläras": "konsulär",
    "konsulärast": "konsulär",
    "konsuläraste": "konsulär",
    "konsulärastes": "konsulär",
    "konsulärasts": "konsulär",
    "konsuläre": "konsulär",
    "konsuläres": "konsulär",
    "konsulärs": "konsulär",
    "konsulärt": "konsulär",
    "konsulärts": "konsulär",
    "konsumenten": "konsument",
    "konsumentens": "konsument",
    "konsumenter": "konsument",
    "konsumenterna": "konsument",
    "konsumenternas": "konsument",
    "konsumenters": "konsument",
    "konsumentfrågan": "konsumentfråga",
    "konsumentfrågans": "konsumentfråga",
    "konsumentfrågas": "konsumentfråga",
    "konsumentfråge": "konsumentfråga",
    "konsumentfrågor": "konsumentfråga",
    "konsumentfrågorna": "konsumentfråga",
    "konsumentfrågornas": "konsumentfråga",
    "konsumentfrågors": "konsumentfråga",
    "konsumentföreningar": "konsumentförening",
    "konsumentföreningarna": "konsumentförening",
    "konsumentföreningarnas": "konsumentförening",
    "konsumentföreningars": "konsumentförening",
    "konsumentföreningen": "konsumentförening",
    "konsumentföreningens": "konsumentförening",
    "konsumentförenings": "konsumentförening",
    "konsumentkooperationen": "konsumentkooperation",
    "konsumentkooperationens": "konsumentkooperation",
    "konsumentkooperationer": "konsumentkooperation",
    "konsumentkooperationerna": "konsumentkooperation",
    "konsumentkooperationernas": "konsumentkooperation",
    "konsumentkooperationers": "konsumentkooperation",
    "konsumentkooperations": "konsumentkooperation",
    "konsumentombudsmannen": "konsumentombudsman",
    "konsumentombudsmannens": "konsumentombudsman",
    "konsumentombudsmans": "konsumentombudsman",
    "konsumentombudsmän": "konsumentombudsman",
    "konsumentombudsmännen": "konsumentombudsman",
    "konsumentombudsmännens": "konsumentombudsman",
    "konsumentombudsmäns": "konsumentombudsman",
    "konsumentpolitiken": "konsumentpolitik",
    "konsumentpolitikens": "konsumentpolitik",
    "konsumentpolitiks": "konsumentpolitik",
    "konsumentpolitiska": "konsumentpolitisk",
    "konsumentpolitiskas": "konsumentpolitisk",
    "konsumentpolitiske": "konsumentpolitisk",
    "konsumentpolitiskes": "konsumentpolitisk",
    "konsumentpolitisks": "konsumentpolitisk",
    "konsumentpolitiskt": "konsumentpolitisk",
    "konsumentpolitiskts": "konsumentpolitisk",
    "konsumentprisen": "konsumentpris",
    "konsumentprisens": "konsumentpris",
    "konsumentpriser": "konsumentpris",
    "konsumentpriserna": "konsumentpris",
    "konsumentprisernas": "konsumentpris",
    "konsumentprisers": "konsumentpris",
    "konsumentpriset": "konsumentpris",
    "konsumentprisets": "konsumentpris",
    "konsumentprisindexen": "konsumentprisindex",
    "konsumentprisindexens": "konsumentprisindex",
    "konsumentprisindexet": "konsumentprisindex",
    "konsumentprisindexets": "konsumentprisindex",
    "konsuments": "konsument",
    "konsumentupplysningar": "konsumentupplysning",
    "konsumentupplysningarna": "konsumentupplysning",
    "konsumentupplysningarnas": "konsumentupplysning",
    "konsumentupplysningars": "konsumentupplysning",
    "konsumentupplysningen": "konsumentupplysning",
    "konsumentupplysningens": "konsumentupplysning",
    "konsumentupplysnings": "konsumentupplysning",
    "konsumentverken": "konsumentverk",
    "konsumentverkens": "konsumentverk",
    "konsumentverket": "konsumentverk",
    "konsumentverkets": "konsumentverk",
    "konsumentverks": "konsumentverk",
    "konsumerad": "konsumera",
    "konsumerade": "konsumera",
    "konsumerades": "konsumera",
    "konsumerads": "konsumera",
    "konsumerande": "konsumera",
    "konsumeranden": "konsumerande",
    "konsumerandena": "konsumerande",
    "konsumerandenas": "konsumerande",
    "konsumerandens": "konsumerande",
    "konsumerandes": "konsumerande",
    "konsumerandet": "konsumerande",
    "konsumerandets": "konsumerande",
    "konsumerar": "konsumera",
    "konsumeras": "konsumera",
    "konsumerat": "konsumera",
    "konsumerats": "konsumera",
    "konsumerbara": "konsumerbar",
    "konsumerbarare": "konsumerbar",
    "konsumerbarares": "konsumerbar",
    "konsumerbaras": "konsumerbar",
    "konsumerbarast": "konsumerbar",
    "konsumerbaraste": "konsumerbar",
    "konsumerbarastes": "konsumerbar",
    "konsumerbarasts": "konsumerbar",
    "konsumerbare": "konsumerbar",
    "konsumerbares": "konsumerbar",
    "konsumerbarheten": "konsumerbarhet",
    "konsumerbarhetens": "konsumerbarhet",
    "konsumerbarhets": "konsumerbarhet",
    "konsumerbars": "konsumerbar",
    "konsumerbart": "konsumerbar",
    "konsumerbarts": "konsumerbar",
    "konsumeringar": "konsumering",
    "konsumeringarna": "konsumering",
    "konsumeringarnas": "konsumering",
    "konsumeringars": "konsumering",
    "konsumeringen": "konsumering",
    "konsumeringens": "konsumering",
    "konsumerings": "konsumering",
    "konsumet": "konsum",
    "konsumets": "konsum",
    "konsums": "konsum",
    "konsumtionen": "konsumtion",
    "konsumtionens": "konsumtion",
    "konsumtioner": "konsumtion",
    "konsumtionerna": "konsumtion",
    "konsumtionernas": "konsumtion",
    "konsumtioners": "konsumtion",
    "konsumtions": "konsumtion",
    "konsumtionsmöjligheten": "konsumtionsmöjlighet",
    "konsumtionsmöjlighetens": "konsumtionsmöjlighet",
    "konsumtionsmöjligheter": "konsumtionsmöjlighet",
    "konsumtionsmöjligheterna": "konsumtionsmöjlighet",
    "konsumtionsmöjligheternas": "konsumtionsmöjlighet",
    "konsumtionsmöjligheters": "konsumtionsmöjlighet",
    "konsumtionsmöjlighets": "konsumtionsmöjlighet",
    "konsumtionsmönsterna": "konsumtionsmönster",
    "konsumtionsmönsternas": "konsumtionsmönster",
    "konsumtionsmönsters": "konsumtionsmönster",
    "konsumtionsmönstren": "konsumtionsmönster",
    "konsumtionsmönstrens": "konsumtionsmönster",
    "konsumtionsmönstret": "konsumtionsmönster",
    "konsumtionsmönstrets": "konsumtionsmönster",
    "konsumtionssamhällen": "konsumtionssamhälle",
    "konsumtionssamhällena": "konsumtionssamhälle",
    "konsumtionssamhällenas": "konsumtionssamhälle",
    "konsumtionssamhällens": "konsumtionssamhälle",
    "konsumtionssamhälles": "konsumtionssamhälle",
    "konsumtionssamhället": "konsumtionssamhälle",
    "konsumtionssamhällets": "konsumtionssamhälle",
    "konsumtionssamhälls": "konsumtionssamhälle",
    "konsumtionsskatten": "konsumtionsskatt",
    "konsumtionsskattens": "konsumtionsskatt",
    "konsumtionsskatter": "konsumtionsskatt",
    "konsumtionsskatterna": "konsumtionsskatt",
    "konsumtionsskatternas": "konsumtionsskatt",
    "konsumtionsskatters": "konsumtionsskatt",
    "konsumtionsskatts": "konsumtionsskatt",
    "konsumtionsskillnaden": "konsumtionsskillnad",
    "konsumtionsskillnadens": "konsumtionsskillnad",
    "konsumtionsskillnader": "konsumtionsskillnad",
    "konsumtionsskillnaderna": "konsumtionsskillnad",
    "konsumtionsskillnadernas": "konsumtionsskillnad",
    "konsumtionsskillnaders": "konsumtionsskillnad",
    "konsumtionsskillnads": "konsumtionsskillnad",
    "konsumtionsvar": "konsumtionsvara",
    "konsumtionsvaran": "konsumtionsvara",
    "konsumtionsvarans": "konsumtionsvara",
    "konsumtionsvaras": "konsumtionsvara",
    "konsumtionsvare": "konsumtionsvara",
    "konsumtionsvaror": "konsumtionsvara",
    "konsumtionsvarorna": "konsumtionsvara",
    "konsumtionsvarornas": "konsumtionsvara",
    "konsumtionsvarors": "konsumtionsvara",
    "konsumtionsvars": "konsumtionsvara",
    "kontagiösa": "kontagiös",
    "kontagiösare": "kontagiös",
    "kontagiösares": "kontagiös",
    "kontagiösas": "kontagiös",
    "kontagiösast": "kontagiös",
    "kontagiösaste": "kontagiös",
    "kontagiösastes": "kontagiös",
    "kontagiösasts": "kontagiös",
    "kontagiöse": "kontagiös",
    "kontagiöses": "kontagiös",
    "kontagiöst": "kontagiös",
    "kontagiösts": "kontagiös",
    "kontakt": "kontakta",
    "kontaktad": "kontakta",
    "kontaktade": "kontakta",
    "kontaktades": "kontakta",
    "kontaktads": "kontakta",
    "kontaktande": "kontakta",
    "kontaktanden": "kontaktande",
    "kontaktandena": "kontaktande",
    "kontaktandenas": "kontaktande",
    "kontaktandens": "kontaktande",
    "kontaktandes": "kontaktande",
    "kontaktandet": "kontaktande",
    "kontaktandets": "kontaktande",
    "kontaktannonsen": "kontaktannons",
    "kontaktannonsens": "kontaktannons",
    "kontaktannonser": "kontaktannons",
    "kontaktannonserna": "kontaktannons",
    "kontaktannonsernas": "kontaktannons",
    "kontaktannonsers": "kontaktannons",
    "kontaktar": "kontakta",
    "kontaktas": "kontakta",
    "kontaktat": "kontakta",
    "kontaktats": "kontakta",
    "kontaktbehovet": "kontaktbehov",
    "kontaktbehovets": "kontaktbehov",
    "kontaktbehovs": "kontaktbehov",
    "kontaktborst": "kontaktborste",
    "kontaktborstar": "kontaktborste",
    "kontaktborstarna": "kontaktborste",
    "kontaktborstarnas": "kontaktborste",
    "kontaktborstars": "kontaktborste",
    "kontaktborsten": "kontaktborste",
    "kontaktborstens": "kontaktborste",
    "kontaktborstes": "kontaktborste",
    "kontakten": "kontakt",
    "kontaktens": "kontakt",
    "kontakter": "kontakt",
    "kontakterna": "kontakt",
    "kontakternas": "kontakt",
    "kontakters": "kontakt",
    "kontaktinfektionen": "kontaktinfektion",
    "kontaktinfektionens": "kontaktinfektion",
    "kontaktinfektioner": "kontaktinfektion",
    "kontaktinfektionerna": "kontaktinfektion",
    "kontaktinfektionernas": "kontaktinfektion",
    "kontaktinfektioners": "kontaktinfektion",
    "kontaktinfektions": "kontaktinfektion",
    "kontaktkopian": "kontaktkopia",
    "kontaktkopians": "kontaktkopia",
    "kontaktkopias": "kontaktkopia",
    "kontaktkopie": "kontaktkopia",
    "kontaktkopior": "kontaktkopia",
    "kontaktkopiorna": "kontaktkopia",
    "kontaktkopiornas": "kontaktkopia",
    "kontaktkopiors": "kontaktkopia",
    "kontaktledningar": "kontaktledning",
    "kontaktledningarna": "kontaktledning",
    "kontaktledningarnas": "kontaktledning",
    "kontaktledningars": "kontaktledning",
    "kontaktledningen": "kontaktledning",
    "kontaktledningens": "kontaktledning",
    "kontaktlednings": "kontaktledning",
    "kontaktlimmet": "kontaktlim",
    "kontaktlimmets": "kontaktlim",
    "kontaktlims": "kontaktlim",
    "kontaktlinsen": "kontaktlins",
    "kontaktlinsens": "kontaktlins",
    "kontaktlinser": "kontaktlins",
    "kontaktlinserna": "kontaktlins",
    "kontaktlinsernas": "kontaktlins",
    "kontaktlinsers": "kontaktlins",
    "kontaktmannen": "kontaktman",
    "kontaktmannens": "kontaktman",
    "kontaktmans": "kontaktman",
    "kontaktmän": "kontaktman",
    "kontaktmännen": "kontaktman",
    "kontaktmännens": "kontaktman",
    "kontaktmäns": "kontaktman",
    "kontaktpersonen": "kontaktperson",
    "kontaktpersonens": "kontaktperson",
    "kontaktpersoner": "kontaktperson",
    "kontaktpersonerna": "kontaktperson",
    "kontaktpersonernas": "kontaktperson",
    "kontaktpersoners": "kontaktperson",
    "kontaktpersons": "kontaktperson",
    "kontakts": "kontakt",
    "kontaminationen": "kontamination",
    "kontaminationens": "kontamination",
    "kontaminationer": "kontamination",
    "kontaminationerna": "kontamination",
    "kontaminationernas": "kontamination",
    "kontaminationers": "kontamination",
    "kontaminations": "kontamination",
    "kontaminationsögonblicken": "kontaminationsögonblick",
    "kontaminationsögonblickens": "kontaminationsögonblick",
    "kontaminationsögonblicket": "kontaminationsögonblick",
    "kontaminationsögonblickets": "kontaminationsögonblick",
    "kontaminationsögonblicks": "kontaminationsögonblick",
    "kontaminerad": "kontaminera",
    "kontaminerade": "kontaminera",
    "kontaminerades": "kontaminera",
    "kontaminerads": "kontaminera",
    "kontaminerande": "kontaminera",
    "kontamineranden": "kontaminerande",
    "kontaminerandena": "kontaminerande",
    "kontaminerandenas": "kontaminerande",
    "kontaminerandens": "kontaminerande",
    "kontaminerandes": "kontaminerande",
    "kontaminerandet": "kontaminerande",
    "kontaminerandets": "kontaminerande",
    "kontaminerar": "kontaminera",
    "kontamineras": "kontaminera",
    "kontaminerat": "kontaminera",
    "kontaminerats": "kontaminera",
    "kontaminerbara": "kontaminerbar",
    "kontaminerbarare": "kontaminerbar",
    "kontaminerbarares": "kontaminerbar",
    "kontaminerbaras": "kontaminerbar",
    "kontaminerbarast": "kontaminerbar",
    "kontaminerbaraste": "kontaminerbar",
    "kontaminerbarastes": "kontaminerbar",
    "kontaminerbarasts": "kontaminerbar",
    "kontaminerbare": "kontaminerbar",
    "kontaminerbares": "kontaminerbar",
    "kontaminerbarheten": "kontaminerbarhet",
    "kontaminerbarhetens": "kontaminerbarhet",
    "kontaminerbarhets": "kontaminerbarhet",
    "kontaminerbars": "kontaminerbar",
    "kontaminerbart": "kontaminerbar",
    "kontaminerbarts": "kontaminerbar",
    "kontamineringar": "kontaminering",
    "kontamineringarna": "kontaminering",
    "kontamineringarnas": "kontaminering",
    "kontamineringars": "kontaminering",
    "kontamineringen": "kontaminering",
    "kontamineringens": "kontaminering",
    "kontaminerings": "kontaminering",
    "kontant": "kontanter",
    "kontanta": "kontant",
    "kontantare": "kontant",
    "kontantares": "kontant",
    "kontantas": "kontant",
    "kontantast": "kontant",
    "kontantaste": "kontant",
    "kontantastes": "kontant",
    "kontantasts": "kontant",
    "kontante": "kontant",
    "kontanterna": "kontanter",
    "kontanternas": "kontanter",
    "kontanters": "kontanter",
    "kontantes": "kontant",
    "kontantkorten": "kontantkort",
    "kontantkortens": "kontantkort",
    "kontantkortet": "kontantkort",
    "kontantkortets": "kontantkort",
    "kontantkorts": "kontantkort",
    "kontants": "kontanter",
    "kontar": "kont",
    "kontarna": "kont",
    "kontarnas": "kont",
    "kontars": "kont",
    "kontemplationen": "kontemplation",
    "kontemplationens": "kontemplation",
    "kontemplationer": "kontemplation",
    "kontemplationerna": "kontemplation",
    "kontemplationernas": "kontemplation",
    "kontemplationers": "kontemplation",
    "kontemplations": "kontemplation",
    "kontemplativa": "kontemplativ",
    "kontemplativare": "kontemplativ",
    "kontemplativares": "kontemplativ",
    "kontemplativas": "kontemplativ",
    "kontemplativast": "kontemplativ",
    "kontemplativaste": "kontemplativ",
    "kontemplativastes": "kontemplativ",
    "kontemplativasts": "kontemplativ",
    "kontemplative": "kontemplativ",
    "kontemplatives": "kontemplativ",
    "kontemplativs": "kontemplativ",
    "kontemplativt": "kontemplativ",
    "kontemplativts": "kontemplativ",
    "konten": "kont",
    "kontenansen": "kontenans",
    "kontenansens": "kontenans",
    "kontens": "kont",
    "kontentan": "kontenta",
    "kontentans": "kontenta",
    "kontentas": "kontenta",
    "konter": "kont",
    "konterad": "kontera",
    "konterade": "kontera",
    "konterades": "kontera",
    "konterads": "kontera",
    "konteramiralen": "konteramiral",
    "konteramiralens": "konteramiral",
    "konteramiraler": "konteramiral",
    "konteramiralerna": "konteramiral",
    "konteramiralernas": "konteramiral",
    "konteramiralers": "konteramiral",
    "konteramirals": "konteramiral",
    "konterande": "kontera",
    "konteranden": "konterande",
    "konterandena": "konterande",
    "konterandenas": "konterande",
    "konterandens": "konterande",
    "konterandes": "konterande",
    "konterandet": "konterande",
    "konterandets": "konterande",
    "konterar": "kontera",
    "konteras": "kontera",
    "konterat": "kontera",
    "konterats": "kontera",
    "konterbara": "konterbar",
    "konterbarare": "konterbar",
    "konterbarares": "konterbar",
    "konterbaras": "konterbar",
    "konterbarast": "konterbar",
    "konterbaraste": "konterbar",
    "konterbarastes": "konterbar",
    "konterbarasts": "konterbar",
    "konterbare": "konterbar",
    "konterbares": "konterbar",
    "konterbarheten": "konterbarhet",
    "konterbarhetens": "konterbarhet",
    "konterbarhets": "konterbarhet",
    "konterbars": "konterbar",
    "konterbart": "konterbar",
    "konterbarts": "konterbar",
    "konterfejen": "konterfej",
    "konterfejens": "konterfej",
    "konterfejet": "konterfej",
    "konterfejets": "konterfej",
    "konterfejs": "konterfej",
    "konteringar": "kontering",
    "konteringarna": "kontering",
    "konteringarnas": "kontering",
    "konteringars": "kontering",
    "konteringen": "kontering",
    "konteringens": "kontering",
    "konterings": "kontering",
    "konterna": "kont",
    "konternas": "kont",
    "konters": "kont",
    "kontexten": "kontext",
    "kontextens": "kontext",
    "kontexter": "kontext",
    "kontexterna": "kontext",
    "kontexternas": "kontext",
    "kontexters": "kontext",
    "kontexts": "kontext",
    "kontinentala": "kontinental",
    "kontinentalare": "kontinental",
    "kontinentalares": "kontinental",
    "kontinentalas": "kontinental",
    "kontinentalast": "kontinental",
    "kontinentalaste": "kontinental",
    "kontinentalastes": "kontinental",
    "kontinentalasts": "kontinental",
    "kontinentaldriften": "kontinentaldrift",
    "kontinentaldriftens": "kontinentaldrift",
    "kontinentaldrifts": "kontinentaldrift",
    "kontinentale": "kontinental",
    "kontinentales": "kontinental",
    "kontinentalklimatet": "kontinentalklimat",
    "kontinentalklimatets": "kontinentalklimat",
    "kontinentalklimats": "kontinentalklimat",
    "kontinentalplatåer": "kontinentalplatå",
    "kontinentalplatåerna": "kontinentalplatå",
    "kontinentalplatåernas": "kontinentalplatå",
    "kontinentalplatåers": "kontinentalplatå",
    "kontinentalplatån": "kontinentalplatå",
    "kontinentalplatåns": "kontinentalplatå",
    "kontinentalplatås": "kontinentalplatå",
    "kontinentals": "kontinental",
    "kontinentalsockeln": "kontinentalsockel",
    "kontinentalsockelns": "kontinentalsockel",
    "kontinentalsockels": "kontinentalsockel",
    "kontinentalsocklar": "kontinentalsockel",
    "kontinentalsocklarna": "kontinentalsockel",
    "kontinentalsocklarnas": "kontinentalsockel",
    "kontinentalsocklars": "kontinentalsockel",
    "kontinentalt": "kontinental",
    "kontinentalts": "kontinental",
    "kontinenten": "kontinent",
    "kontinentens": "kontinent",
    "kontinenter": "kontinent",
    "kontinenterna": "kontinent",
    "kontinenternas": "kontinent",
    "kontinenters": "kontinent",
    "kontinents": "kontinent",
    "kontingenten": "kontingent",
    "kontingentens": "kontingent",
    "kontingenter": "kontingent",
    "kontingenterad": "kontingentera",
    "kontingenterade": "kontingentera",
    "kontingenterades": "kontingentera",
    "kontingenterads": "kontingentera",
    "kontingenterande": "kontingentera",
    "kontingenteranden": "kontingenterande",
    "kontingenterandena": "kontingenterande",
    "kontingenterandenas": "kontingenterande",
    "kontingenterandens": "kontingenterande",
    "kontingenterandes": "kontingenterande",
    "kontingenterandet": "kontingenterande",
    "kontingenterandets": "kontingenterande",
    "kontingenterar": "kontingentera",
    "kontingenteras": "kontingentera",
    "kontingenterat": "kontingentera",
    "kontingenterats": "kontingentera",
    "kontingenterbara": "kontingenterbar",
    "kontingenterbarare": "kontingenterbar",
    "kontingenterbarares": "kontingenterbar",
    "kontingenterbaras": "kontingenterbar",
    "kontingenterbarast": "kontingenterbar",
    "kontingenterbaraste": "kontingenterbar",
    "kontingenterbarastes": "kontingenterbar",
    "kontingenterbarasts": "kontingenterbar",
    "kontingenterbare": "kontingenterbar",
    "kontingenterbares": "kontingenterbar",
    "kontingenterbarheten": "kontingenterbarhet",
    "kontingenterbarhetens": "kontingenterbarhet",
    "kontingenterbarhets": "kontingenterbarhet",
    "kontingenterbars": "kontingenterbar",
    "kontingenterbart": "kontingenterbar",
    "kontingenterbarts": "kontingenterbar",
    "kontingenteringar": "kontingentering",
    "kontingenteringarna": "kontingentering",
    "kontingenteringarnas": "kontingentering",
    "kontingenteringars": "kontingentering",
    "kontingenteringen": "kontingentering",
    "kontingenteringens": "kontingentering",
    "kontingenterings": "kontingentering",
    "kontingenterna": "kontingent",
    "kontingenternas": "kontingent",
    "kontingenters": "kontingent",
    "kontingents": "kontingent",
    "kontinua": "kontinuum",
    "kontinuana": "kontinuum",
    "kontinuanas": "kontinuum",
    "kontinuas": "kontinuum",
    "kontinuerliga": "kontinuerlig",
    "kontinuerligare": "kontinuerlig",
    "kontinuerligares": "kontinuerlig",
    "kontinuerligas": "kontinuerlig",
    "kontinuerligast": "kontinuerlig",
    "kontinuerligaste": "kontinuerlig",
    "kontinuerligastes": "kontinuerlig",
    "kontinuerligasts": "kontinuerlig",
    "kontinuerlige": "kontinuerlig",
    "kontinuerliges": "kontinuerlig",
    "kontinuerligheten": "kontinuerlighet",
    "kontinuerlighetens": "kontinuerlighet",
    "kontinuerlighets": "kontinuerlighet",
    "kontinuerligs": "kontinuerlig",
    "kontinuerligt": "kontinuerlig",
    "kontinuerligts": "kontinuerlig",
    "kontinuet": "kontinuum",
    "kontinuets": "kontinuum",
    "kontinuiteten": "kontinuitet",
    "kontinuitetens": "kontinuitet",
    "kontinuiteter": "kontinuitet",
    "kontinuiteterna": "kontinuitet",
    "kontinuiteternas": "kontinuitet",
    "kontinuiteters": "kontinuitet",
    "kontinuitets": "kontinuitet",
    "kontinuumen": "kontinuum",
    "kontinuumens": "kontinuum",
    "kontinuumet": "kontinuum",
    "kontinuumets": "kontinuum",
    "kontinuums": "kontinuum",
    "kontoinnehavar": "kontoinnehavare",
    "kontoinnehavaren": "kontoinnehavare",
    "kontoinnehavarens": "kontoinnehavare",
    "kontoinnehavares": "kontoinnehavare",
    "kontoinnehavarna": "kontoinnehavare",
    "kontoinnehavarnas": "kontoinnehavare",
    "kontokorten": "kontokort",
    "kontokortens": "kontokort",
    "kontokortet": "kontokort",
    "kontokortets": "kontokort",
    "kontokorts": "kontokort",
    "kontokuranten": "kontokurant",
    "kontokurantens": "kontokurant",
    "kontokuranter": "kontokurant",
    "kontokuranterna": "kontokurant",
    "kontokuranternas": "kontokurant",
    "kontokuranters": "kontokurant",
    "kontokurants": "kontokurant",
    "konton": "konto",
    "kontona": "konto",
    "kontonas": "konto",
    "kontons": "konto",
    "kontonummerna": "kontonummer",
    "kontonummernas": "kontonummer",
    "kontonummers": "kontonummer",
    "kontonumren": "kontonummer",
    "kontonumrens": "kontonummer",
    "kontonumret": "kontonummer",
    "kontonumrets": "kontonummer",
    "kontoren": "kontor",
    "kontorens": "kontor",
    "kontoret": "kontor",
    "kontorets": "kontor",
    "kontoriserad": "kontorisera",
    "kontoriserade": "kontorisera",
    "kontoriserades": "kontorisera",
    "kontoriserads": "kontorisera",
    "kontoriserande": "kontorisera",
    "kontoriseranden": "kontoriserande",
    "kontoriserandena": "kontoriserande",
    "kontoriserandenas": "kontoriserande",
    "kontoriserandens": "kontoriserande",
    "kontoriserandes": "kontoriserande",
    "kontoriserandet": "kontoriserande",
    "kontoriserandets": "kontoriserande",
    "kontoriserar": "kontorisera",
    "kontoriseras": "kontorisera",
    "kontoriserat": "kontorisera",
    "kontoriserats": "kontorisera",
    "kontoriserbara": "kontoriserbar",
    "kontoriserbarare": "kontoriserbar",
    "kontoriserbarares": "kontoriserbar",
    "kontoriserbaras": "kontoriserbar",
    "kontoriserbarast": "kontoriserbar",
    "kontoriserbaraste": "kontoriserbar",
    "kontoriserbarastes": "kontoriserbar",
    "kontoriserbarasts": "kontoriserbar",
    "kontoriserbare": "kontoriserbar",
    "kontoriserbares": "kontoriserbar",
    "kontoriserbarheten": "kontoriserbarhet",
    "kontoriserbarhetens": "kontoriserbarhet",
    "kontoriserbarhets": "kontoriserbarhet",
    "kontoriserbars": "kontoriserbar",
    "kontoriserbart": "kontoriserbar",
    "kontoriserbarts": "kontoriserbar",
    "kontoriseringar": "kontorisering",
    "kontoriseringarna": "kontorisering",
    "kontoriseringarnas": "kontorisering",
    "kontoriseringars": "kontorisering",
    "kontoriseringen": "kontorisering",
    "kontoriseringens": "kontorisering",
    "kontoriserings": "kontorisering",
    "kontoristen": "kontorist",
    "kontoristens": "kontorist",
    "kontorister": "kontorist",
    "kontoristerna": "kontorist",
    "kontoristernas": "kontorist",
    "kontoristers": "kontorist",
    "kontorists": "kontorist",
    "kontors": "kontor",
    "kontorsarbeten": "kontorsarbete",
    "kontorsarbetena": "kontorsarbete",
    "kontorsarbetenas": "kontorsarbete",
    "kontorsarbetens": "kontorsarbete",
    "kontorsarbetes": "kontorsarbete",
    "kontorsarbetet": "kontorsarbete",
    "kontorsarbetets": "kontorsarbete",
    "kontorsarbets": "kontorsarbete",
    "kontorsbiträden": "kontorsbiträde",
    "kontorsbiträdena": "kontorsbiträde",
    "kontorsbiträdenas": "kontorsbiträde",
    "kontorsbiträdens": "kontorsbiträde",
    "kontorsbiträdes": "kontorsbiträde",
    "kontorsbiträdet": "kontorsbiträde",
    "kontorsbiträdets": "kontorsbiträde",
    "kontorsbuden": "kontorsbud",
    "kontorsbudens": "kontorsbud",
    "kontorsbudet": "kontorsbud",
    "kontorsbudets": "kontorsbud",
    "kontorsbuds": "kontorsbud",
    "kontorsbyggnaden": "kontorsbyggnad",
    "kontorsbyggnadens": "kontorsbyggnad",
    "kontorsbyggnader": "kontorsbyggnad",
    "kontorsbyggnaderna": "kontorsbyggnad",
    "kontorsbyggnadernas": "kontorsbyggnad",
    "kontorsbyggnaders": "kontorsbyggnad",
    "kontorsbyggnads": "kontorsbyggnad",
    "kontorschefen": "kontorschef",
    "kontorschefens": "kontorschef",
    "kontorschefer": "kontorschef",
    "kontorscheferna": "kontorschef",
    "kontorschefernas": "kontorschef",
    "kontorschefers": "kontorschef",
    "kontorschefs": "kontorschef",
    "kontorsdörrar": "kontorsdörr",
    "kontorsdörrarna": "kontorsdörr",
    "kontorsdörrarnas": "kontorsdörr",
    "kontorsdörrars": "kontorsdörr",
    "kontorsdörren": "kontorsdörr",
    "kontorsdörrens": "kontorsdörr",
    "kontorsdörrs": "kontorsdörr",
    "kontorshusen": "kontorshus",
    "kontorshusens": "kontorshus",
    "kontorshuset": "kontorshus",
    "kontorshusets": "kontorshus",
    "kontorslandskapen": "kontorslandskap",
    "kontorslandskapens": "kontorslandskap",
    "kontorslandskapet": "kontorslandskap",
    "kontorslandskapets": "kontorslandskap",
    "kontorslandskaps": "kontorslandskap",
    "kontorsmässiga": "kontorsmässig",
    "kontorsmässigare": "kontorsmässig",
    "kontorsmässigares": "kontorsmässig",
    "kontorsmässigas": "kontorsmässig",
    "kontorsmässigast": "kontorsmässig",
    "kontorsmässigaste": "kontorsmässig",
    "kontorsmässigastes": "kontorsmässig",
    "kontorsmässigasts": "kontorsmässig",
    "kontorsmässige": "kontorsmässig",
    "kontorsmässiges": "kontorsmässig",
    "kontorsmässigs": "kontorsmässig",
    "kontorsmässigt": "kontorsmässig",
    "kontorsmässigts": "kontorsmässig",
    "kontorsplatsen": "kontorsplats",
    "kontorsplatsens": "kontorsplats",
    "kontorsplatser": "kontorsplats",
    "kontorsplatserna": "kontorsplats",
    "kontorsplatsernas": "kontorsplats",
    "kontorsplatsers": "kontorsplats",
    "kontorspulpeten": "kontorspulpet",
    "kontorspulpetens": "kontorspulpet",
    "kontorspulpeter": "kontorspulpet",
    "kontorspulpeterna": "kontorspulpet",
    "kontorspulpeternas": "kontorspulpet",
    "kontorspulpeters": "kontorspulpet",
    "kontorspulpets": "kontorspulpet",
    "kontorsrummen": "kontorsrum",
    "kontorsrummens": "kontorsrum",
    "kontorsrummet": "kontorsrum",
    "kontorsrummets": "kontorsrum",
    "kontorsrums": "kontorsrum",
    "kontorsrått": "kontorsråtta",
    "kontorsråttan": "kontorsråtta",
    "kontorsråttans": "kontorsråtta",
    "kontorsråttas": "kontorsråtta",
    "kontorsråtte": "kontorsråtta",
    "kontorsråttor": "kontorsråtta",
    "kontorsråttorna": "kontorsråtta",
    "kontorsråttornas": "kontorsråtta",
    "kontorsråttors": "kontorsråtta",
    "kontorsråtts": "kontorsråtta",
    "kontorsslavar": "kontorsslav",
    "kontorsslavarna": "kontorsslav",
    "kontorsslavarnas": "kontorsslav",
    "kontorsslavars": "kontorsslav",
    "kontorsslaven": "kontorsslav",
    "kontorsslavens": "kontorsslav",
    "kontorsslavs": "kontorsslav",
    "kontorsstolar": "kontorsstol",
    "kontorsstolarna": "kontorsstol",
    "kontorsstolarnas": "kontorsstol",
    "kontorsstolars": "kontorsstol",
    "kontorsstolen": "kontorsstol",
    "kontorsstolens": "kontorsstol",
    "kontorsstols": "kontorsstol",
    "kontorstiden": "kontorstid",
    "kontorstidens": "kontorstid",
    "kontorstider": "kontorstid",
    "kontorstiderna": "kontorstid",
    "kontorstidernas": "kontorstid",
    "kontorstiders": "kontorstid",
    "kontorstids": "kontorstid",
    "kontorsutrymmen": "kontorsutrymme",
    "kontorsutrymmena": "kontorsutrymme",
    "kontorsutrymmenas": "kontorsutrymme",
    "kontorsutrymmens": "kontorsutrymme",
    "kontorsutrymmes": "kontorsutrymme",
    "kontorsutrymmet": "kontorsutrymme",
    "kontorsutrymmets": "kontorsutrymme",
    "kontorsvanan": "kontorsvana",
    "kontorsvanans": "kontorsvana",
    "kontorsvanas": "kontorsvana",
    "kontorsvane": "kontorsvana",
    "kontorsvanor": "kontorsvana",
    "kontorsvanorna": "kontorsvana",
    "kontorsvanornas": "kontorsvana",
    "kontorsvanors": "kontorsvana",
    "kontos": "konto",
    "kontostölden": "kontostöld",
    "kontostöldens": "kontostöld",
    "kontostölder": "kontostöld",
    "kontostölderna": "kontostöld",
    "kontostöldernas": "kontostöld",
    "kontostölders": "kontostöld",
    "kontostölds": "kontostöld",
    "kontot": "konto",
    "kontots": "konto",
    "kontoutdragen": "kontoutdrag",
    "kontoutdragens": "kontoutdrag",
    "kontoutdraget": "kontoutdrag",
    "kontoutdragets": "kontoutdrag",
    "kontoutdrags": "kontoutdrag",
    "kontraaltar": "kontraalt",
    "kontraaltarna": "kontraalt",
    "kontraaltarnas": "kontraalt",
    "kontraaltars": "kontraalt",
    "kontraalten": "kontraalt",
    "kontraaltens": "kontraalt",
    "kontraalts": "kontraalt",
    "kontrabandet": "kontraband",
    "kontrabandets": "kontraband",
    "kontrabands": "kontraband",
    "kontrabasar": "kontrabas",
    "kontrabasarna": "kontrabas",
    "kontrabasarnas": "kontrabas",
    "kontrabasars": "kontrabas",
    "kontrabasen": "kontrabas",
    "kontrabasens": "kontrabas",
    "kontraboken": "kontrabok",
    "kontrabokens": "kontrabok",
    "kontraboks": "kontrabok",
    "kontraböcker": "kontrabok",
    "kontraböckerna": "kontrabok",
    "kontraböckernas": "kontrabok",
    "kontraböckers": "kontrabok",
    "kontradansen": "kontradans",
    "kontradansens": "kontradans",
    "kontradanser": "kontradans",
    "kontradanserna": "kontradans",
    "kontradansernas": "kontradans",
    "kontradansers": "kontradans",
    "kontrade": "kontra",
    "kontrades": "kontra",
    "kontradiktionen": "kontradiktion",
    "kontradiktionens": "kontradiktion",
    "kontradiktioner": "kontradiktion",
    "kontradiktionerna": "kontradiktion",
    "kontradiktionernas": "kontradiktion",
    "kontradiktioners": "kontradiktion",
    "kontradiktions": "kontradiktion",
    "kontradiktoriska": "kontradiktorisk",
    "kontradiktoriskare": "kontradiktorisk",
    "kontradiktoriskares": "kontradiktorisk",
    "kontradiktoriskas": "kontradiktorisk",
    "kontradiktoriskast": "kontradiktorisk",
    "kontradiktoriskaste": "kontradiktorisk",
    "kontradiktoriskastes": "kontradiktorisk",
    "kontradiktoriskasts": "kontradiktorisk",
    "kontradiktoriske": "kontradiktorisk",
    "kontradiktoriskes": "kontradiktorisk",
    "kontradiktorisks": "kontradiktorisk",
    "kontradiktoriskt": "kontradiktorisk",
    "kontradiktoriskts": "kontradiktorisk",
    "kontrahenten": "kontrahent",
    "kontrahentens": "kontrahent",
    "kontrahenter": "kontrahent",
    "kontrahenterna": "kontrahent",
    "kontrahenternas": "kontrahent",
    "kontrahenters": "kontrahent",
    "kontrahents": "kontrahent",
    "kontraherad": "kontrahera",
    "kontraherade": "kontrahera",
    "kontraherades": "kontrahera",
    "kontraherads": "kontrahera",
    "kontraherande": "kontrahera",
    "kontraheranden": "kontraherande",
    "kontraherandena": "kontraherande",
    "kontraherandenas": "kontraherande",
    "kontraherandens": "kontraherande",
    "kontraherandes": "kontraherande",
    "kontraherandet": "kontraherande",
    "kontraherandets": "kontraherande",
    "kontraherar": "kontrahera",
    "kontraheras": "kontrahera",
    "kontraherat": "kontrahera",
    "kontraherats": "kontrahera",
    "kontraherbara": "kontraherbar",
    "kontraherbarare": "kontraherbar",
    "kontraherbarares": "kontraherbar",
    "kontraherbaras": "kontraherbar",
    "kontraherbarast": "kontraherbar",
    "kontraherbaraste": "kontraherbar",
    "kontraherbarastes": "kontraherbar",
    "kontraherbarasts": "kontraherbar",
    "kontraherbare": "kontraherbar",
    "kontraherbares": "kontraherbar",
    "kontraherbarheten": "kontraherbarhet",
    "kontraherbarhetens": "kontraherbarhet",
    "kontraherbarhets": "kontraherbarhet",
    "kontraherbars": "kontraherbar",
    "kontraherbart": "kontraherbar",
    "kontraherbarts": "kontraherbar",
    "kontraheringar": "kontrahering",
    "kontraheringarna": "kontrahering",
    "kontraheringarnas": "kontrahering",
    "kontraheringars": "kontrahering",
    "kontraheringen": "kontrahering",
    "kontraheringens": "kontrahering",
    "kontraherings": "kontrahering",
    "kontraindikationen": "kontraindikation",
    "kontraindikationens": "kontraindikation",
    "kontraindikationer": "kontraindikation",
    "kontraindikationerna": "kontraindikation",
    "kontraindikationernas": "kontraindikation",
    "kontraindikationers": "kontraindikation",
    "kontraindikations": "kontraindikation",
    "kontrakten": "kontrakt",
    "kontraktens": "kontrakt",
    "kontrakterad": "kontraktera",
    "kontrakterade": "kontraktera",
    "kontrakterades": "kontraktera",
    "kontrakterads": "kontraktera",
    "kontrakterande": "kontraktera",
    "kontrakteranden": "kontrakterande",
    "kontrakterandena": "kontrakterande",
    "kontrakterandenas": "kontrakterande",
    "kontrakterandens": "kontrakterande",
    "kontrakterandes": "kontrakterande",
    "kontrakterandet": "kontrakterande",
    "kontrakterandets": "kontrakterande",
    "kontrakterar": "kontraktera",
    "kontrakteras": "kontraktera",
    "kontrakterat": "kontraktera",
    "kontrakterats": "kontraktera",
    "kontrakterbara": "kontrakterbar",
    "kontrakterbarare": "kontrakterbar",
    "kontrakterbarares": "kontrakterbar",
    "kontrakterbaras": "kontrakterbar",
    "kontrakterbarast": "kontrakterbar",
    "kontrakterbaraste": "kontrakterbar",
    "kontrakterbarastes": "kontrakterbar",
    "kontrakterbarasts": "kontrakterbar",
    "kontrakterbare": "kontrakterbar",
    "kontrakterbares": "kontrakterbar",
    "kontrakterbarheten": "kontrakterbarhet",
    "kontrakterbarhetens": "kontrakterbarhet",
    "kontrakterbarhets": "kontrakterbarhet",
    "kontrakterbars": "kontrakterbar",
    "kontrakterbart": "kontrakterbar",
    "kontrakterbarts": "kontrakterbar",
    "kontrakteringar": "kontraktering",
    "kontrakteringarna": "kontraktering",
    "kontrakteringarnas": "kontraktering",
    "kontrakteringars": "kontraktering",
    "kontrakteringen": "kontraktering",
    "kontrakteringens": "kontraktering",
    "kontrakterings": "kontraktering",
    "kontraktet": "kontrakt",
    "kontraktets": "kontrakt",
    "kontraktila": "kontraktil",
    "kontraktilare": "kontraktil",
    "kontraktilares": "kontraktil",
    "kontraktilas": "kontraktil",
    "kontraktilast": "kontraktil",
    "kontraktilaste": "kontraktil",
    "kontraktilastes": "kontraktil",
    "kontraktilasts": "kontraktil",
    "kontraktile": "kontraktil",
    "kontraktiles": "kontraktil",
    "kontraktils": "kontraktil",
    "kontraktilt": "kontraktil",
    "kontraktilts": "kontraktil",
    "kontraktionen": "kontraktion",
    "kontraktionens": "kontraktion",
    "kontraktioner": "kontraktion",
    "kontraktionerna": "kontraktion",
    "kontraktionernas": "kontraktion",
    "kontraktioners": "kontraktion",
    "kontraktions": "kontraktion",
    "kontrakts": "kontrakt",
    "kontraktsbridgen": "kontraktsbridge",
    "kontraktsbridgens": "kontraktsbridge",
    "kontraktsbridges": "kontraktsbridge",
    "kontraktsbrotten": "kontraktsbrott",
    "kontraktsbrottens": "kontraktsbrott",
    "kontraktsbrottet": "kontraktsbrott",
    "kontraktsbrottets": "kontraktsbrott",
    "kontraktsbrotts": "kontraktsbrott",
    "kontraktsenliga": "kontraktsenlig",
    "kontraktsenligare": "kontraktsenlig",
    "kontraktsenligares": "kontraktsenlig",
    "kontraktsenligas": "kontraktsenlig",
    "kontraktsenligast": "kontraktsenlig",
    "kontraktsenligaste": "kontraktsenlig",
    "kontraktsenligastes": "kontraktsenlig",
    "kontraktsenligasts": "kontraktsenlig",
    "kontraktsenlige": "kontraktsenlig",
    "kontraktsenliges": "kontraktsenlig",
    "kontraktsenligheten": "kontraktsenlighet",
    "kontraktsenlighetens": "kontraktsenlighet",
    "kontraktsenlighets": "kontraktsenlighet",
    "kontraktsenligs": "kontraktsenlig",
    "kontraktsenligt": "kontraktsenlig",
    "kontraktsenligts": "kontraktsenlig",
    "kontraktsförhandlingar": "kontraktsförhandling",
    "kontraktsförhandlingarna": "kontraktsförhandling",
    "kontraktsförhandlingarnas": "kontraktsförhandling",
    "kontraktsförhandlingars": "kontraktsförhandling",
    "kontraktsförhandlingen": "kontraktsförhandling",
    "kontraktsförhandlingens": "kontraktsförhandling",
    "kontraktsförhandlings": "kontraktsförhandling",
    "kontraktsmässiga": "kontraktsmässig",
    "kontraktsmässigare": "kontraktsmässig",
    "kontraktsmässigares": "kontraktsmässig",
    "kontraktsmässigas": "kontraktsmässig",
    "kontraktsmässigast": "kontraktsmässig",
    "kontraktsmässigaste": "kontraktsmässig",
    "kontraktsmässigastes": "kontraktsmässig",
    "kontraktsmässigasts": "kontraktsmässig",
    "kontraktsmässige": "kontraktsmässig",
    "kontraktsmässiges": "kontraktsmässig",
    "kontraktsmässigs": "kontraktsmässig",
    "kontraktsmässigt": "kontraktsmässig",
    "kontraktsmässigts": "kontraktsmässig",
    "kontraktsprostar": "kontraktsprost",
    "kontraktsprostarna": "kontraktsprost",
    "kontraktsprostarnas": "kontraktsprost",
    "kontraktsprostars": "kontraktsprost",
    "kontraktsprosten": "kontraktsprost",
    "kontraktsprostens": "kontraktsprost",
    "kontraktsprosts": "kontraktsprost",
    "kontraktstiden": "kontraktstid",
    "kontraktstidens": "kontraktstid",
    "kontraktstider": "kontraktstid",
    "kontraktstiderna": "kontraktstid",
    "kontraktstidernas": "kontraktstid",
    "kontraktstiders": "kontraktstid",
    "kontraktstids": "kontraktstid",
    "kontraktsvidriga": "kontraktsvidrig",
    "kontraktsvidrigare": "kontraktsvidrig",
    "kontraktsvidrigares": "kontraktsvidrig",
    "kontraktsvidrigas": "kontraktsvidrig",
    "kontraktsvidrigast": "kontraktsvidrig",
    "kontraktsvidrigaste": "kontraktsvidrig",
    "kontraktsvidrigastes": "kontraktsvidrig",
    "kontraktsvidrigasts": "kontraktsvidrig",
    "kontraktsvidrige": "kontraktsvidrig",
    "kontraktsvidriges": "kontraktsvidrig",
    "kontraktsvidrigheten": "kontraktsvidrighet",
    "kontraktsvidrighetens": "kontraktsvidrighet",
    "kontraktsvidrighets": "kontraktsvidrighet",
    "kontraktsvidrigs": "kontraktsvidrig",
    "kontraktsvidrigt": "kontraktsvidrig",
    "kontraktsvidrigts": "kontraktsvidrig",
    "kontramanderad": "kontramandera",
    "kontramanderade": "kontramandera",
    "kontramanderades": "kontramandera",
    "kontramanderads": "kontramandera",
    "kontramanderande": "kontramandera",
    "kontramanderanden": "kontramanderande",
    "kontramanderandena": "kontramanderande",
    "kontramanderandenas": "kontramanderande",
    "kontramanderandens": "kontramanderande",
    "kontramanderandes": "kontramanderande",
    "kontramanderandet": "kontramanderande",
    "kontramanderandets": "kontramanderande",
    "kontramanderar": "kontramandera",
    "kontramanderas": "kontramandera",
    "kontramanderat": "kontramandera",
    "kontramanderats": "kontramandera",
    "kontramanderbara": "kontramanderbar",
    "kontramanderbarare": "kontramanderbar",
    "kontramanderbarares": "kontramanderbar",
    "kontramanderbaras": "kontramanderbar",
    "kontramanderbarast": "kontramanderbar",
    "kontramanderbaraste": "kontramanderbar",
    "kontramanderbarastes": "kontramanderbar",
    "kontramanderbarasts": "kontramanderbar",
    "kontramanderbare": "kontramanderbar",
    "kontramanderbares": "kontramanderbar",
    "kontramanderbarheten": "kontramanderbarhet",
    "kontramanderbarhetens": "kontramanderbarhet",
    "kontramanderbarhets": "kontramanderbarhet",
    "kontramanderbars": "kontramanderbar",
    "kontramanderbart": "kontramanderbar",
    "kontramanderbarts": "kontramanderbar",
    "kontramanderingar": "kontramandering",
    "kontramanderingarna": "kontramandering",
    "kontramanderingarnas": "kontramandering",
    "kontramanderingars": "kontramandering",
    "kontramanderingen": "kontramandering",
    "kontramanderingens": "kontramandering",
    "kontramanderings": "kontramandering",
    "kontramärken": "kontramärke",
    "kontramärkena": "kontramärke",
    "kontramärkenas": "kontramärke",
    "kontramärkens": "kontramärke",
    "kontramärkes": "kontramärke",
    "kontramärket": "kontramärke",
    "kontramärkets": "kontramärke",
    "kontrande": "kontra",
    "kontranden": "kontrande",
    "kontrandena": "kontrande",
    "kontrandenas": "kontrande",
    "kontrandens": "kontrande",
    "kontrandes": "kontrande",
    "kontrandet": "kontrande",
    "kontrandets": "kontrande",
    "kontraoktaven": "kontraoktav",
    "kontraoktavens": "kontraoktav",
    "kontraoktavs": "kontraoktav",
    "kontraordern": "kontraorder",
    "kontraorderna": "kontraorder",
    "kontraordernas": "kontraorder",
    "kontraorderns": "kontraorder",
    "kontraorders": "kontraorder",
    "kontraordrar": "kontraorder",
    "kontraordrarna": "kontraorder",
    "kontraordrarnas": "kontraorder",
    "kontraordrars": "kontraorder",
    "kontraproduktiva": "kontraproduktiv",
    "kontraproduktivare": "kontraproduktiv",
    "kontraproduktivares": "kontraproduktiv",
    "kontraproduktivas": "kontraproduktiv",
    "kontraproduktivast": "kontraproduktiv",
    "kontraproduktivaste": "kontraproduktiv",
    "kontraproduktivastes": "kontraproduktiv",
    "kontraproduktivasts": "kontraproduktiv",
    "kontraproduktive": "kontraproduktiv",
    "kontraproduktives": "kontraproduktiv",
    "kontraproduktivs": "kontraproduktiv",
    "kontraproduktivt": "kontraproduktiv",
    "kontraproduktivts": "kontraproduktiv",
    "kontrapropositionen": "kontraproposition",
    "kontrapropositionens": "kontraproposition",
    "kontrapropositioner": "kontraproposition",
    "kontrapropositionerna": "kontraproposition",
    "kontrapropositionernas": "kontraproposition",
    "kontrapropositioners": "kontraproposition",
    "kontrapropositions": "kontraproposition",
    "kontrapunkten": "kontrapunkt",
    "kontrapunktens": "kontrapunkt",
    "kontrapunkts": "kontrapunkt",
    "kontrar": "kontra",
    "kontrarevolutionen": "kontrarevolution",
    "kontrarevolutionens": "kontrarevolution",
    "kontrarevolutioner": "kontrarevolution",
    "kontrarevolutionerna": "kontrarevolution",
    "kontrarevolutionernas": "kontrarevolution",
    "kontrarevolutioners": "kontrarevolution",
    "kontrarevolutions": "kontrarevolution",
    "kontras": "kontra",
    "kontrasignerad": "kontrasignera",
    "kontrasignerade": "kontrasignera",
    "kontrasignerades": "kontrasignera",
    "kontrasignerads": "kontrasignera",
    "kontrasignerande": "kontrasignera",
    "kontrasigneranden": "kontrasignerande",
    "kontrasignerandena": "kontrasignerande",
    "kontrasignerandenas": "kontrasignerande",
    "kontrasignerandens": "kontrasignerande",
    "kontrasignerandes": "kontrasignerande",
    "kontrasignerandet": "kontrasignerande",
    "kontrasignerandets": "kontrasignerande",
    "kontrasignerar": "kontrasignera",
    "kontrasigneras": "kontrasignera",
    "kontrasignerat": "kontrasignera",
    "kontrasignerats": "kontrasignera",
    "kontrasignerbara": "kontrasignerbar",
    "kontrasignerbarare": "kontrasignerbar",
    "kontrasignerbarares": "kontrasignerbar",
    "kontrasignerbaras": "kontrasignerbar",
    "kontrasignerbarast": "kontrasignerbar",
    "kontrasignerbaraste": "kontrasignerbar",
    "kontrasignerbarastes": "kontrasignerbar",
    "kontrasignerbarasts": "kontrasignerbar",
    "kontrasignerbare": "kontrasignerbar",
    "kontrasignerbares": "kontrasignerbar",
    "kontrasignerbarheten": "kontrasignerbarhet",
    "kontrasignerbarhetens": "kontrasignerbarhet",
    "kontrasignerbarhets": "kontrasignerbarhet",
    "kontrasignerbars": "kontrasignerbar",
    "kontrasignerbart": "kontrasignerbar",
    "kontrasignerbarts": "kontrasignerbar",
    "kontrasigneringar": "kontrasignering",
    "kontrasigneringarna": "kontrasignering",
    "kontrasigneringarnas": "kontrasignering",
    "kontrasigneringars": "kontrasignering",
    "kontrasigneringen": "kontrasignering",
    "kontrasigneringens": "kontrasignering",
    "kontrasignerings": "kontrasignering",
    "kontraspionages": "kontraspionage",
    "kontraspionaget": "kontraspionage",
    "kontraspionagets": "kontraspionage",
    "kontrasten": "kontrast",
    "kontrastens": "kontrast",
    "kontraster": "kontrast",
    "kontrasterad": "kontrastera",
    "kontrasterade": "kontrastera",
    "kontrasterades": "kontrastera",
    "kontrasterads": "kontrastera",
    "kontrasterande": "kontrastera",
    "kontrasteranden": "kontrasterande",
    "kontrasterandena": "kontrasterande",
    "kontrasterandenas": "kontrasterande",
    "kontrasterandens": "kontrasterande",
    "kontrasterandes": "kontrasterande",
    "kontrasterandet": "kontrasterande",
    "kontrasterandets": "kontrasterande",
    "kontrasterar": "kontrastera",
    "kontrasteras": "kontrastera",
    "kontrasterat": "kontrastera",
    "kontrasterats": "kontrastera",
    "kontrasterbara": "kontrasterbar",
    "kontrasterbarare": "kontrasterbar",
    "kontrasterbarares": "kontrasterbar",
    "kontrasterbaras": "kontrasterbar",
    "kontrasterbarast": "kontrasterbar",
    "kontrasterbaraste": "kontrasterbar",
    "kontrasterbarastes": "kontrasterbar",
    "kontrasterbarasts": "kontrasterbar",
    "kontrasterbare": "kontrasterbar",
    "kontrasterbares": "kontrasterbar",
    "kontrasterbarheten": "kontrasterbarhet",
    "kontrasterbarhetens": "kontrasterbarhet",
    "kontrasterbarhets": "kontrasterbarhet",
    "kontrasterbars": "kontrasterbar",
    "kontrasterbart": "kontrasterbar",
    "kontrasterbarts": "kontrasterbar",
    "kontrasteringar": "kontrastering",
    "kontrasteringarna": "kontrastering",
    "kontrasteringarnas": "kontrastering",
    "kontrasteringars": "kontrastering",
    "kontrasteringen": "kontrastering",
    "kontrasteringens": "kontrastering",
    "kontrasterings": "kontrastering",
    "kontrasterna": "kontrast",
    "kontrasternas": "kontrast",
    "kontrasters": "kontrast",
    "kontrastmedels": "kontrastmedel",
    "kontrastmedlen": "kontrastmedel",
    "kontrastmedlens": "kontrastmedel",
    "kontrastmedlet": "kontrastmedel",
    "kontrastmedlets": "kontrastmedel",
    "kontraströntgenen": "kontraströntgen",
    "kontraströntgenens": "kontraströntgen",
    "kontraströntgens": "kontraströntgen",
    "kontrasts": "kontrast",
    "kontrat": "kontra",
    "kontrats": "kontra",
    "kontribuerad": "kontribuera",
    "kontribuerade": "kontribuera",
    "kontribuerades": "kontribuera",
    "kontribuerads": "kontribuera",
    "kontribuerande": "kontribuera",
    "kontribueranden": "kontribuerande",
    "kontribuerandena": "kontribuerande",
    "kontribuerandenas": "kontribuerande",
    "kontribuerandens": "kontribuerande",
    "kontribuerandes": "kontribuerande",
    "kontribuerandet": "kontribuerande",
    "kontribuerandets": "kontribuerande",
    "kontribuerar": "kontribuera",
    "kontribueras": "kontribuera",
    "kontribuerat": "kontribuera",
    "kontribuerats": "kontribuera",
    "kontribuerbara": "kontribuerbar",
    "kontribuerbarare": "kontribuerbar",
    "kontribuerbarares": "kontribuerbar",
    "kontribuerbaras": "kontribuerbar",
    "kontribuerbarast": "kontribuerbar",
    "kontribuerbaraste": "kontribuerbar",
    "kontribuerbarastes": "kontribuerbar",
    "kontribuerbarasts": "kontribuerbar",
    "kontribuerbare": "kontribuerbar",
    "kontribuerbares": "kontribuerbar",
    "kontribuerbarheten": "kontribuerbarhet",
    "kontribuerbarhetens": "kontribuerbarhet",
    "kontribuerbarhets": "kontribuerbarhet",
    "kontribuerbars": "kontribuerbar",
    "kontribuerbart": "kontribuerbar",
    "kontribuerbarts": "kontribuerbar",
    "kontribueringar": "kontribuering",
    "kontribueringarna": "kontribuering",
    "kontribueringarnas": "kontribuering",
    "kontribueringars": "kontribuering",
    "kontribueringen": "kontribuering",
    "kontribueringens": "kontribuering",
    "kontribuerings": "kontribuering",
    "kontributionen": "kontribution",
    "kontributionens": "kontribution",
    "kontributioner": "kontribution",
    "kontributionerna": "kontribution",
    "kontributionernas": "kontribution",
    "kontributioners": "kontribution",
    "kontributions": "kontribution",
    "kontringar": "kontring",
    "kontringarna": "kontring",
    "kontringarnas": "kontring",
    "kontringars": "kontring",
    "kontringen": "kontring",
    "kontringens": "kontring",
    "kontrings": "kontring",
    "kontrollanten": "kontrollant",
    "kontrollantens": "kontrollant",
    "kontrollanter": "kontrollant",
    "kontrollanterna": "kontrollant",
    "kontrollanternas": "kontrollant",
    "kontrollanters": "kontrollant",
    "kontrollants": "kontrollant",
    "kontrollavgiften": "kontrollavgift",
    "kontrollavgiftens": "kontrollavgift",
    "kontrollavgifter": "kontrollavgift",
    "kontrollavgifterna": "kontrollavgift",
    "kontrollavgifternas": "kontrollavgift",
    "kontrollavgifters": "kontrollavgift",
    "kontrollavgifts": "kontrollavgift",
    "kontrollbesiktningar": "kontrollbesiktning",
    "kontrollbesiktningarna": "kontrollbesiktning",
    "kontrollbesiktningarnas": "kontrollbesiktning",
    "kontrollbesiktningars": "kontrollbesiktning",
    "kontrollbesiktningen": "kontrollbesiktning",
    "kontrollbesiktningens": "kontrollbesiktning",
    "kontrollbesiktnings": "kontrollbesiktning",
    "kontrollborden": "kontrollbord",
    "kontrollbordens": "kontrollbord",
    "kontrollbordet": "kontrollbord",
    "kontrollbordets": "kontrollbord",
    "kontrollbords": "kontrollbord",
    "kontrollen": "kontroll",
    "kontrollens": "kontroll",
    "kontroller": "kontroll",
    "kontrollerad": "kontrollera",
    "kontrollerade": "kontrollera",
    "kontrollerades": "kontrollera",
    "kontrollerads": "kontrollera",
    "kontrollerande": "kontrollera",
    "kontrolleranden": "kontrollerande",
    "kontrollerandena": "kontrollerande",
    "kontrollerandenas": "kontrollerande",
    "kontrollerandens": "kontrollerande",
    "kontrollerandes": "kontrollerande",
    "kontrollerandet": "kontrollerande",
    "kontrollerandets": "kontrollerande",
    "kontrollerar": "kontrollera",
    "kontrolleras": "kontrollera",
    "kontrollerat": "kontrollera",
    "kontrollerats": "kontrollera",
    "kontrollerbara": "kontrollerbar",
    "kontrollerbarare": "kontrollerbar",
    "kontrollerbarares": "kontrollerbar",
    "kontrollerbaras": "kontrollerbar",
    "kontrollerbarast": "kontrollerbar",
    "kontrollerbaraste": "kontrollerbar",
    "kontrollerbarastes": "kontrollerbar",
    "kontrollerbarasts": "kontrollerbar",
    "kontrollerbare": "kontrollerbar",
    "kontrollerbares": "kontrollerbar",
    "kontrollerbarheten": "kontrollerbarhet",
    "kontrollerbarhetens": "kontrollerbarhet",
    "kontrollerbarhets": "kontrollerbarhet",
    "kontrollerbars": "kontrollerbar",
    "kontrollerbart": "kontrollerbar",
    "kontrollerbarts": "kontrollerbar",
    "kontrolleringar": "kontrollering",
    "kontrolleringarna": "kontrollering",
    "kontrolleringarnas": "kontrollering",
    "kontrolleringars": "kontrollering",
    "kontrolleringen": "kontrollering",
    "kontrolleringens": "kontrollering",
    "kontrollerings": "kontrollering",
    "kontrollerna": "kontroll",
    "kontrollernas": "kontroll",
    "kontrollers": "kontroll",
    "kontrollgenomsyrade": "kontrollgenomsyrad",
    "kontrollgenomsyrades": "kontrollgenomsyrad",
    "kontrollgenomsyrads": "kontrollgenomsyrad",
    "kontrollgenomsyrat": "kontrollgenomsyrad",
    "kontrollgenomsyrats": "kontrollgenomsyrad",
    "kontrollgruppen": "kontrollgrupp",
    "kontrollgruppens": "kontrollgrupp",
    "kontrollgrupper": "kontrollgrupp",
    "kontrollgrupperna": "kontrollgrupp",
    "kontrollgruppernas": "kontrollgrupp",
    "kontrollgruppers": "kontrollgrupp",
    "kontrollgrupps": "kontrollgrupp",
    "kontrollinstrumenten": "kontrollinstrument",
    "kontrollinstrumentens": "kontrollinstrument",
    "kontrollinstrumentet": "kontrollinstrument",
    "kontrollinstrumentets": "kontrollinstrument",
    "kontrollinstruments": "kontrollinstrument",
    "kontrollmekanismen": "kontrollmekanism",
    "kontrollmekanismens": "kontrollmekanism",
    "kontrollmekanismer": "kontrollmekanism",
    "kontrollmekanismerna": "kontrollmekanism",
    "kontrollmekanismernas": "kontrollmekanism",
    "kontrollmekanismers": "kontrollmekanism",
    "kontrollmekanisms": "kontrollmekanism",
    "kontrollmärken": "kontrollmärke",
    "kontrollmärkena": "kontrollmärke",
    "kontrollmärkenas": "kontrollmärke",
    "kontrollmärkens": "kontrollmärke",
    "kontrollmärkes": "kontrollmärke",
    "kontrollmärket": "kontrollmärke",
    "kontrollmärkets": "kontrollmärke",
    "kontrollnummerna": "kontrollnummer",
    "kontrollnummernas": "kontrollnummer",
    "kontrollnummers": "kontrollnummer",
    "kontrollnumren": "kontrollnummer",
    "kontrollnumrens": "kontrollnummer",
    "kontrollnumret": "kontrollnummer",
    "kontrollnumrets": "kontrollnummer",
    "kontrollorganen": "kontrollorgan",
    "kontrollorganens": "kontrollorgan",
    "kontrollorganet": "kontrollorgan",
    "kontrollorganets": "kontrollorgan",
    "kontrollorgans": "kontrollorgan",
    "kontrollrummen": "kontrollrum",
    "kontrollrummens": "kontrollrum",
    "kontrollrummet": "kontrollrum",
    "kontrollrummets": "kontrollrum",
    "kontrollrums": "kontrollrum",
    "kontrolls": "kontroll",
    "kontrollsamhällen": "kontrollsamhälle",
    "kontrollsamhällena": "kontrollsamhälle",
    "kontrollsamhällenas": "kontrollsamhälle",
    "kontrollsamhällens": "kontrollsamhälle",
    "kontrollsamhälles": "kontrollsamhälle",
    "kontrollsamhället": "kontrollsamhälle",
    "kontrollsamhällets": "kontrollsamhälle",
    "kontrollsamhälls": "kontrollsamhälle",
    "kontrollstationen": "kontrollstation",
    "kontrollstationens": "kontrollstation",
    "kontrollstationer": "kontrollstation",
    "kontrollstationerna": "kontrollstation",
    "kontrollstationernas": "kontrollstation",
    "kontrollstationers": "kontrollstation",
    "kontrollstations": "kontrollstation",
    "kontrollstämpeln": "kontrollstämpel",
    "kontrollstämpelns": "kontrollstämpel",
    "kontrollstämpels": "kontrollstämpel",
    "kontrollstämplad": "kontrollstämpla",
    "kontrollstämplade": "kontrollstämpla",
    "kontrollstämplades": "kontrollstämpla",
    "kontrollstämplads": "kontrollstämpla",
    "kontrollstämplande": "kontrollstämpla",
    "kontrollstämplanden": "kontrollstämplande",
    "kontrollstämplandena": "kontrollstämplande",
    "kontrollstämplandenas": "kontrollstämplande",
    "kontrollstämplandens": "kontrollstämplande",
    "kontrollstämplandes": "kontrollstämplande",
    "kontrollstämplandet": "kontrollstämplande",
    "kontrollstämplandets": "kontrollstämplande",
    "kontrollstämplar": "kontrollstämpla",
    "kontrollstämplarna": "kontrollstämpel",
    "kontrollstämplarnas": "kontrollstämpel",
    "kontrollstämplars": "kontrollstämpel",
    "kontrollstämplas": "kontrollstämpla",
    "kontrollstämplat": "kontrollstämpla",
    "kontrollstämplats": "kontrollstämpla",
    "kontrolltornen": "kontrolltorn",
    "kontrolltornens": "kontrolltorn",
    "kontrolltornet": "kontrolltorn",
    "kontrolltornets": "kontrolltorn",
    "kontrolltorns": "kontrolltorn",
    "kontrollundersökningar": "kontrollundersökning",
    "kontrollundersökningarna": "kontrollundersökning",
    "kontrollundersökningarnas": "kontrollundersökning",
    "kontrollundersökningars": "kontrollundersökning",
    "kontrollundersökningen": "kontrollundersökning",
    "kontrollundersökningens": "kontrollundersökning",
    "kontrollundersöknings": "kontrollundersökning",
    "kontrolluppgiften": "kontrolluppgift",
    "kontrolluppgiftens": "kontrolluppgift",
    "kontrolluppgifter": "kontrolluppgift",
    "kontrolluppgifterna": "kontrolluppgift",
    "kontrolluppgifternas": "kontrolluppgift",
    "kontrolluppgifters": "kontrolluppgift",
    "kontrolluppgifts": "kontrolluppgift",
    "kontrollväg": "kontrollväga",
    "kontrollvägande": "kontrollväga",
    "kontrollväganden": "kontrollvägande",
    "kontrollvägandena": "kontrollvägande",
    "kontrollvägandenas": "kontrollvägande",
    "kontrollvägandens": "kontrollvägande",
    "kontrollvägandes": "kontrollvägande",
    "kontrollvägandet": "kontrollvägande",
    "kontrollvägandets": "kontrollvägande",
    "kontrollvägas": "kontrollväga",
    "kontrollvägd": "kontrollväga",
    "kontrollvägda": "kontrollväga",
    "kontrollvägdas": "kontrollväga",
    "kontrollvägde": "kontrollväga",
    "kontrollvägdes": "kontrollväga",
    "kontrollvägds": "kontrollväga",
    "kontrollväger": "kontrollväga",
    "kontrollväges": "kontrollväga",
    "kontrollvägningar": "kontrollvägning",
    "kontrollvägningarna": "kontrollvägning",
    "kontrollvägningarnas": "kontrollvägning",
    "kontrollvägningars": "kontrollvägning",
    "kontrollvägningen": "kontrollvägning",
    "kontrollvägningens": "kontrollvägning",
    "kontrollvägnings": "kontrollvägning",
    "kontrollvägs": "kontrollväga",
    "kontrollvägt": "kontrollväga",
    "kontrollvägts": "kontrollväga",
    "kontrolläs": "kontrolläsa",
    "kontrolläsande": "kontrolläsa",
    "kontrolläsandes": "kontrolläsa",
    "kontrolläsas": "kontrolläsa",
    "kontrolläser": "kontrolläsa",
    "kontrolläses": "kontrolläsa",
    "kontrolläst": "kontrolläsa",
    "kontrollästa": "kontrolläsa",
    "kontrollästas": "kontrolläsa",
    "kontrolläste": "kontrolläsa",
    "kontrollästes": "kontrolläsa",
    "kontrollästs": "kontrolläsa",
    "kontrollören": "kontrollör",
    "kontrollörens": "kontrollör",
    "kontrollörer": "kontrollör",
    "kontrollörerna": "kontrollör",
    "kontrollörernas": "kontrollör",
    "kontrollörers": "kontrollör",
    "kontrollörn": "kontrollör",
    "kontrollörns": "kontrollör",
    "kontrollörs": "kontrollör",
    "kontroversen": "kontrovers",
    "kontroversens": "kontrovers",
    "kontroverser": "kontrovers",
    "kontroverserna": "kontrovers",
    "kontroversernas": "kontrovers",
    "kontroversers": "kontrovers",
    "kontroversiella": "kontroversiell",
    "kontroversiellare": "kontroversiell",
    "kontroversiellares": "kontroversiell",
    "kontroversiellas": "kontroversiell",
    "kontroversiellast": "kontroversiell",
    "kontroversiellaste": "kontroversiell",
    "kontroversiellastes": "kontroversiell",
    "kontroversiellasts": "kontroversiell",
    "kontroversielle": "kontroversiell",
    "kontroversielles": "kontroversiell",
    "kontroversiells": "kontroversiell",
    "kontroversiellt": "kontroversiell",
    "kontroversiellts": "kontroversiell",
    "konträra": "konträr",
    "konträrare": "konträr",
    "konträrares": "konträr",
    "konträras": "konträr",
    "konträrast": "konträr",
    "konträraste": "konträr",
    "konträrastes": "konträr",
    "konträrasts": "konträr",
    "konträre": "konträr",
    "konträres": "konträr",
    "konträrs": "konträr",
    "konträrt": "konträr",
    "konträrts": "konträr",
    "konts": "kont",
    "kontumaciedomar": "kontumaciedom",
    "kontumaciedomarna": "kontumaciedom",
    "kontumaciedomarnas": "kontumaciedom",
    "kontumaciedomars": "kontumaciedom",
    "kontumaciedomen": "kontumaciedom",
    "kontumaciedomens": "kontumaciedom",
    "kontumaciedoms": "kontumaciedom",
    "konturen": "kontur",
    "konturens": "kontur",
    "konturer": "kontur",
    "konturerad": "konturera",
    "konturerade": "konturera",
    "konturerades": "konturera",
    "konturerads": "konturera",
    "konturerande": "konturera",
    "kontureranden": "konturerande",
    "konturerandena": "konturerande",
    "konturerandenas": "konturerande",
    "konturerandens": "konturerande",
    "konturerandes": "konturerande",
    "konturerandet": "konturerande",
    "konturerandets": "konturerande",
    "konturerar": "konturera",
    "kontureras": "konturera",
    "konturerat": "konturera",
    "konturerats": "konturera",
    "konturerbara": "konturerbar",
    "konturerbarare": "konturerbar",
    "konturerbarares": "konturerbar",
    "konturerbaras": "konturerbar",
    "konturerbarast": "konturerbar",
    "konturerbaraste": "konturerbar",
    "konturerbarastes": "konturerbar",
    "konturerbarasts": "konturerbar",
    "konturerbare": "konturerbar",
    "konturerbares": "konturerbar",
    "konturerbarheten": "konturerbarhet",
    "konturerbarhetens": "konturerbarhet",
    "konturerbarhets": "konturerbarhet",
    "konturerbars": "konturerbar",
    "konturerbart": "konturerbar",
    "konturerbarts": "konturerbar",
    "kontureringar": "konturering",
    "kontureringarna": "konturering",
    "kontureringarnas": "konturering",
    "kontureringars": "konturering",
    "kontureringen": "konturering",
    "kontureringens": "konturering",
    "konturerings": "konturering",
    "konturerna": "kontur",
    "konturernas": "kontur",
    "konturers": "kontur",
    "konturlösa": "konturlös",
    "konturlösare": "konturlös",
    "konturlösares": "konturlös",
    "konturlösas": "konturlös",
    "konturlösast": "konturlös",
    "konturlösaste": "konturlös",
    "konturlösastes": "konturlös",
    "konturlösasts": "konturlös",
    "konturlöse": "konturlös",
    "konturlöses": "konturlös",
    "konturlösheten": "konturlöshet",
    "konturlöshetens": "konturlöshet",
    "konturlöshets": "konturlöshet",
    "konturlöst": "konturlös",
    "konturlösts": "konturlös",
    "konturs": "kontur",
    "konturskarpa": "konturskarp",
    "konturskarpare": "konturskarp",
    "konturskarpares": "konturskarp",
    "konturskarpas": "konturskarp",
    "konturskarpast": "konturskarp",
    "konturskarpaste": "konturskarp",
    "konturskarpastes": "konturskarp",
    "konturskarpasts": "konturskarp",
    "konturskarpe": "konturskarp",
    "konturskarpes": "konturskarp",
    "konturskarpheten": "konturskarphet",
    "konturskarphetens": "konturskarphet",
    "konturskarphets": "konturskarphet",
    "konturskarps": "konturskarp",
    "konturskarpt": "konturskarp",
    "konturskarpts": "konturskarp",
    "kontursågar": "kontursåg",
    "kontursågarna": "kontursåg",
    "kontursågarnas": "kontursåg",
    "kontursågars": "kontursåg",
    "kontursågen": "kontursåg",
    "kontursågens": "kontursåg",
    "kontursågs": "kontursåg",
    "kontusionen": "kontusion",
    "kontusionens": "kontusion",
    "kontusioner": "kontusion",
    "kontusionerna": "kontusion",
    "kontusionernas": "kontusion",
    "kontusioners": "kontusion",
    "kontusions": "kontusion",
    "konungaboken": "konungabok",
    "konungabokens": "konungabok",
    "konungaboks": "konungabok",
    "konungaböcker": "konungabok",
    "konungaböckerna": "konungabok",
    "konungaböckernas": "konungabok",
    "konungaböckers": "konungabok",
    "konungadömen": "konungadöme",
    "konungadömena": "konungadöme",
    "konungadömenas": "konungadöme",
    "konungadömens": "konungadöme",
    "konungadömes": "konungadöme",
    "konungadömet": "konungadöme",
    "konungadömets": "konungadöme",
    "konungaeden": "konungaed",
    "konungaedens": "konungaed",
    "konungaeder": "konungaed",
    "konungaederna": "konungaed",
    "konungaedernas": "konungaed",
    "konungaeders": "konungaed",
    "konungaeds": "konungaed",
    "konungaförsäkrans": "konungaförsäkran",
    "konungahusen": "konungahus",
    "konungahusens": "konungahus",
    "konungahuset": "konungahus",
    "konungahusets": "konungahus",
    "konungakron": "konungakrona",
    "konungakronan": "konungakrona",
    "konungakronans": "konungakrona",
    "konungakronas": "konungakrona",
    "konungakrone": "konungakrona",
    "konungakronor": "konungakrona",
    "konungakronorna": "konungakrona",
    "konungakronornas": "konungakrona",
    "konungakronors": "konungakrona",
    "konungakrons": "konungakrona",
    "konungalängden": "konungalängd",
    "konungalängdens": "konungalängd",
    "konungalängder": "konungalängd",
    "konungalängderna": "konungalängd",
    "konungalängdernas": "konungalängd",
    "konungalängders": "konungalängd",
    "konungalängds": "konungalängd",
    "konungar": "konung",
    "konungariken": "konungarike",
    "konungarikena": "konungarike",
    "konungarikenas": "konungarike",
    "konungarikens": "konungarike",
    "konungarikes": "konungarike",
    "konungariket": "konungarike",
    "konungarikets": "konungarike",
    "konungarna": "konung",
    "konungarnas": "konung",
    "konungars": "konung",
    "konungasäten": "konungasäte",
    "konungasätena": "konungasäte",
    "konungasätenas": "konungasäte",
    "konungasätens": "konungasäte",
    "konungasätes": "konungasäte",
    "konungasätet": "konungasäte",
    "konungasätets": "konungasäte",
    "konungaätten": "konungaätt",
    "konungaättens": "konungaätt",
    "konungaätter": "konungaätt",
    "konungaätterna": "konungaätt",
    "konungaätternas": "konungaätt",
    "konungaätters": "konungaätt",
    "konungaätts": "konungaätt",
    "konungen": "konung",
    "konungens": "konung",
    "konungs": "konung",
    "konungska": "konungsk",
    "konungskare": "konungsk",
    "konungskares": "konungsk",
    "konungskas": "konungsk",
    "konungskast": "konungsk",
    "konungskaste": "konungsk",
    "konungskastes": "konungsk",
    "konungskasts": "konungsk",
    "konungske": "konungsk",
    "konungskes": "konungsk",
    "konungsks": "konungsk",
    "konungskt": "konungsk",
    "konungskts": "konungsk",
    "konungsliga": "konungslig",
    "konungsligare": "konungslig",
    "konungsligares": "konungslig",
    "konungsligas": "konungslig",
    "konungsligast": "konungslig",
    "konungsligaste": "konungslig",
    "konungsligastes": "konungslig",
    "konungsligasts": "konungslig",
    "konungslige": "konungslig",
    "konungsliges": "konungslig",
    "konungsligheten": "konungslighet",
    "konungslighetens": "konungslighet",
    "konungslighets": "konungslighet",
    "konungsligs": "konungslig",
    "konungsligt": "konungslig",
    "konungsligts": "konungslig",
    "konvalescensen": "konvalescens",
    "konvalescensens": "konvalescens",
    "konvalescenta": "konvalescent",
    "konvalescentare": "konvalescent",
    "konvalescentares": "konvalescent",
    "konvalescentas": "konvalescent",
    "konvalescentast": "konvalescent",
    "konvalescentaste": "konvalescent",
    "konvalescentastes": "konvalescent",
    "konvalescentasts": "konvalescent",
    "konvalescente": "konvalescent",
    "konvalescenten": "konvalescent",
    "konvalescentens": "konvalescent",
    "konvalescenter": "konvalescent",
    "konvalescenterna": "konvalescent",
    "konvalescenternas": "konvalescent",
    "konvalescenters": "konvalescent",
    "konvalescentes": "konvalescent",
    "konvalescenthemmen": "konvalescenthem",
    "konvalescenthemmens": "konvalescenthem",
    "konvalescenthemmet": "konvalescenthem",
    "konvalescenthemmets": "konvalescenthem",
    "konvalescenthems": "konvalescenthem",
    "konvalescents": "konvalescent",
    "konvaljen": "konvalje",
    "konvaljens": "konvalje",
    "konvaljer": "konvalje",
    "konvaljerna": "konvalje",
    "konvaljernas": "konvalje",
    "konvaljers": "konvalje",
    "konvaljes": "konvalje",
    "konvaljs": "konvalj",
    "konvektionen": "konvektion",
    "konvektionens": "konvektion",
    "konvektioner": "konvektion",
    "konvektionerna": "konvektion",
    "konvektionernas": "konvektion",
    "konvektioners": "konvektion",
    "konvektions": "konvektion",
    "konvektionszonen": "konvektionszon",
    "konvektionszonens": "konvektionszon",
    "konvektionszoner": "konvektionszon",
    "konvektionszonerna": "konvektionszon",
    "konvektionszonernas": "konvektionszon",
    "konvektionszoners": "konvektionszon",
    "konvektionszons": "konvektionszon",
    "konvenansen": "konvenans",
    "konvenansens": "konvenans",
    "konvenanspartier": "konvenansparti",
    "konvenanspartierna": "konvenansparti",
    "konvenanspartiernas": "konvenansparti",
    "konvenanspartiers": "konvenansparti",
    "konvenanspartiet": "konvenansparti",
    "konvenanspartiets": "konvenansparti",
    "konvenanspartis": "konvenansparti",
    "konvenanspartit": "konvenansparti",
    "konvenanspartits": "konvenansparti",
    "konventen": "konvent",
    "konventens": "konvent",
    "konventet": "konvent",
    "konventets": "konvent",
    "konventikeln": "konventikel",
    "konventikelns": "konventikel",
    "konventikels": "konventikel",
    "konventiklar": "konventikel",
    "konventiklarna": "konventikel",
    "konventiklarnas": "konventikel",
    "konventiklars": "konventikel",
    "konventionalismen": "konventionalism",
    "konventionalismens": "konventionalism",
    "konventionalismer": "konventionalism",
    "konventionalismerna": "konventionalism",
    "konventionalismernas": "konventionalism",
    "konventionalismers": "konventionalism",
    "konventionalisms": "konventionalism",
    "konventionella": "konventionell",
    "konventionellare": "konventionell",
    "konventionellares": "konventionell",
    "konventionellas": "konventionell",
    "konventionellast": "konventionell",
    "konventionellaste": "konventionell",
    "konventionellastes": "konventionell",
    "konventionellasts": "konventionell",
    "konventionelle": "konventionell",
    "konventionelles": "konventionell",
    "konventionells": "konventionell",
    "konventionellt": "konventionell",
    "konventionellts": "konventionell",
    "konventionen": "konvention",
    "konventionens": "konvention",
    "konventioner": "konvention",
    "konventionerna": "konvention",
    "konventionernas": "konvention",
    "konventioners": "konvention",
    "konventions": "konvention",
    "konventionsbrotten": "konventionsbrott",
    "konventionsbrottens": "konventionsbrott",
    "konventionsbrottet": "konventionsbrott",
    "konventionsbrottets": "konventionsbrott",
    "konventionsbrotts": "konventionsbrott",
    "konvents": "konvent",
    "konvergensen": "konvergens",
    "konvergensens": "konvergens",
    "konvergenta": "konvergent",
    "konvergentare": "konvergent",
    "konvergentares": "konvergent",
    "konvergentas": "konvergent",
    "konvergentast": "konvergent",
    "konvergentaste": "konvergent",
    "konvergentastes": "konvergent",
    "konvergentasts": "konvergent",
    "konvergente": "konvergent",
    "konvergentes": "konvergent",
    "konvergents": "konvergent",
    "konvergerad": "konvergera",
    "konvergerade": "konvergera",
    "konvergerades": "konvergera",
    "konvergerads": "konvergera",
    "konvergerande": "konvergera",
    "konvergeranden": "konvergerande",
    "konvergerandena": "konvergerande",
    "konvergerandenas": "konvergerande",
    "konvergerandens": "konvergerande",
    "konvergerandes": "konvergerande",
    "konvergerandet": "konvergerande",
    "konvergerandets": "konvergerande",
    "konvergerar": "konvergera",
    "konvergeras": "konvergera",
    "konvergerat": "konvergera",
    "konvergerats": "konvergera",
    "konvergerbara": "konvergerbar",
    "konvergerbarare": "konvergerbar",
    "konvergerbarares": "konvergerbar",
    "konvergerbaras": "konvergerbar",
    "konvergerbarast": "konvergerbar",
    "konvergerbaraste": "konvergerbar",
    "konvergerbarastes": "konvergerbar",
    "konvergerbarasts": "konvergerbar",
    "konvergerbare": "konvergerbar",
    "konvergerbares": "konvergerbar",
    "konvergerbarheten": "konvergerbarhet",
    "konvergerbarhetens": "konvergerbarhet",
    "konvergerbarhets": "konvergerbarhet",
    "konvergerbars": "konvergerbar",
    "konvergerbart": "konvergerbar",
    "konvergerbarts": "konvergerbar",
    "konvergeringar": "konvergering",
    "konvergeringarna": "konvergering",
    "konvergeringarnas": "konvergering",
    "konvergeringars": "konvergering",
    "konvergeringen": "konvergering",
    "konvergeringens": "konvergering",
    "konvergerings": "konvergering",
    "konversabels": "konversabel",
    "konversabelt": "konversabel",
    "konversabelts": "konversabel",
    "konversabla": "konversabel",
    "konversablare": "konversabel",
    "konversablares": "konversabel",
    "konversablas": "konversabel",
    "konversablast": "konversabel",
    "konversablaste": "konversabel",
    "konversablastes": "konversabel",
    "konversablasts": "konversabel",
    "konversable": "konversabel",
    "konversables": "konversabel",
    "konversationen": "konversation",
    "konversationens": "konversation",
    "konversationer": "konversation",
    "konversationerna": "konversation",
    "konversationernas": "konversation",
    "konversationers": "konversation",
    "konversations": "konversation",
    "konversationslexika": "konversationslexikon",
    "konversationslexikas": "konversationslexikon",
    "konversationslexikonen": "konversationslexikon",
    "konversationslexikonens": "konversationslexikon",
    "konversationslexikonet": "konversationslexikon",
    "konversationslexikonets": "konversationslexikon",
    "konversationslexikons": "konversationslexikon",
    "konverserad": "konversera",
    "konverserade": "konversera",
    "konverserades": "konversera",
    "konverserads": "konversera",
    "konverserande": "konversera",
    "konverseranden": "konverserande",
    "konverserandena": "konverserande",
    "konverserandenas": "konverserande",
    "konverserandens": "konverserande",
    "konverserandes": "konverserande",
    "konverserandet": "konverserande",
    "konverserandets": "konverserande",
    "konverserar": "konversera",
    "konverseras": "konversera",
    "konverserat": "konversera",
    "konverserats": "konversera",
    "konverserbara": "konverserbar",
    "konverserbarare": "konverserbar",
    "konverserbarares": "konverserbar",
    "konverserbaras": "konverserbar",
    "konverserbarast": "konverserbar",
    "konverserbaraste": "konverserbar",
    "konverserbarastes": "konverserbar",
    "konverserbarasts": "konverserbar",
    "konverserbare": "konverserbar",
    "konverserbares": "konverserbar",
    "konverserbarheten": "konverserbarhet",
    "konverserbarhetens": "konverserbarhet",
    "konverserbarhets": "konverserbarhet",
    "konverserbars": "konverserbar",
    "konverserbart": "konverserbar",
    "konverserbarts": "konverserbar",
    "konverseringar": "konversering",
    "konverseringarna": "konversering",
    "konverseringarnas": "konversering",
    "konverseringars": "konversering",
    "konverseringen": "konversering",
    "konverseringens": "konversering",
    "konverserings": "konversering",
    "konversionen": "konversion",
    "konversionens": "konversion",
    "konversioner": "konversion",
    "konversionerna": "konversion",
    "konversionernas": "konversion",
    "konversioners": "konversion",
    "konversions": "konversion",
    "konversiva": "konversiv",
    "konversivare": "konversiv",
    "konversivares": "konversiv",
    "konversivas": "konversiv",
    "konversivast": "konversiv",
    "konversivaste": "konversiv",
    "konversivastes": "konversiv",
    "konversivasts": "konversiv",
    "konversive": "konversiv",
    "konversives": "konversiv",
    "konversivs": "konversiv",
    "konversivt": "konversiv",
    "konversivts": "konversiv",
    "konverterad": "konvertera",
    "konverterade": "konvertera",
    "konverterades": "konvertera",
    "konverterads": "konvertera",
    "konverterande": "konvertera",
    "konverteranden": "konverterande",
    "konverterandena": "konverterande",
    "konverterandenas": "konverterande",
    "konverterandens": "konverterande",
    "konverterandes": "konverterande",
    "konverterandet": "konverterande",
    "konverterandets": "konverterande",
    "konverterar": "konvertera",
    "konverteras": "konvertera",
    "konverterat": "konvertera",
    "konverterats": "konvertera",
    "konverterbara": "konverterbar",
    "konverterbarare": "konverterbar",
    "konverterbarares": "konverterbar",
    "konverterbaras": "konverterbar",
    "konverterbarast": "konverterbar",
    "konverterbaraste": "konverterbar",
    "konverterbarastes": "konverterbar",
    "konverterbarasts": "konverterbar",
    "konverterbare": "konverterbar",
    "konverterbares": "konverterbar",
    "konverterbarheten": "konverterbarhet",
    "konverterbarhetens": "konverterbarhet",
    "konverterbarhets": "konverterbarhet",
    "konverterbars": "konverterbar",
    "konverterbart": "konverterbar",
    "konverterbarts": "konverterbar",
    "konverteringar": "konvertering",
    "konverteringarna": "konvertering",
    "konverteringarnas": "konvertering",
    "konverteringars": "konvertering",
    "konverteringen": "konvertering",
    "konverteringens": "konvertering",
    "konverterings": "konvertering",
    "konverteringskiten": "konverteringskit",
    "konverteringskitens": "konverteringskit",
    "konverteringskitet": "konverteringskit",
    "konverteringskitets": "konverteringskit",
    "konverteringskits": "konverteringskit",
    "konvertern": "konverter",
    "konverterns": "konverter",
    "konverters": "konverter",
    "konvertibels": "konvertibel",
    "konvertibelt": "konvertibel",
    "konvertibelts": "konvertibel",
    "konvertibla": "konvertibel",
    "konvertiblare": "konvertibel",
    "konvertiblares": "konvertibel",
    "konvertiblas": "konvertibel",
    "konvertiblast": "konvertibel",
    "konvertiblaste": "konvertibel",
    "konvertiblastes": "konvertibel",
    "konvertiblasts": "konvertibel",
    "konvertible": "konvertibel",
    "konvertibles": "konvertibel",
    "konvertiten": "konvertit",
    "konvertitens": "konvertit",
    "konvertiter": "konvertit",
    "konvertiterna": "konvertit",
    "konvertiternas": "konvertit",
    "konvertiters": "konvertit",
    "konvertits": "konvertit",
    "konvertrar": "konverter",
    "konvertrarna": "konverter",
    "konvertrarnas": "konverter",
    "konvertrars": "konverter",
    "konvexa": "konvex",
    "konvexare": "konvex",
    "konvexares": "konvex",
    "konvexas": "konvex",
    "konvexast": "konvex",
    "konvexaste": "konvex",
    "konvexastes": "konvex",
    "konvexasts": "konvex",
    "konvexe": "konvex",
    "konvexes": "konvex",
    "konvexkonkava": "konvexkonkav",
    "konvexkonkavare": "konvexkonkav",
    "konvexkonkavares": "konvexkonkav",
    "konvexkonkavas": "konvexkonkav",
    "konvexkonkavast": "konvexkonkav",
    "konvexkonkavaste": "konvexkonkav",
    "konvexkonkavastes": "konvexkonkav",
    "konvexkonkavasts": "konvexkonkav",
    "konvexkonkave": "konvexkonkav",
    "konvexkonkaves": "konvexkonkav",
    "konvexkonkavs": "konvexkonkav",
    "konvexkonkavt": "konvexkonkav",
    "konvexkonkavts": "konvexkonkav",
    "konvext": "konvex",
    "konvexts": "konvex",
    "konviktorie": "konviktorium",
    "konviktorier": "konviktorium",
    "konviktorierna": "konviktorium",
    "konviktoriernas": "konviktorium",
    "konviktoriers": "konviktorium",
    "konviktoriet": "konviktorium",
    "konviktoriets": "konviktorium",
    "konviktoriums": "konviktorium",
    "konvojattacken": "konvojattack",
    "konvojattackens": "konvojattack",
    "konvojattacker": "konvojattack",
    "konvojattackerna": "konvojattack",
    "konvojattackernas": "konvojattack",
    "konvojattackers": "konvojattack",
    "konvojattacks": "konvojattack",
    "konvojen": "konvoj",
    "konvojens": "konvoj",
    "konvojer": "konvoj",
    "konvojerad": "konvojera",
    "konvojerade": "konvojera",
    "konvojerades": "konvojera",
    "konvojerads": "konvojera",
    "konvojerande": "konvojera",
    "konvojeranden": "konvojerande",
    "konvojerandena": "konvojerande",
    "konvojerandenas": "konvojerande",
    "konvojerandens": "konvojerande",
    "konvojerandes": "konvojerande",
    "konvojerandet": "konvojerande",
    "konvojerandets": "konvojerande",
    "konvojerar": "konvojera",
    "konvojeras": "konvojera",
    "konvojerat": "konvojera",
    "konvojerats": "konvojera",
    "konvojerbara": "konvojerbar",
    "konvojerbarare": "konvojerbar",
    "konvojerbarares": "konvojerbar",
    "konvojerbaras": "konvojerbar",
    "konvojerbarast": "konvojerbar",
    "konvojerbaraste": "konvojerbar",
    "konvojerbarastes": "konvojerbar",
    "konvojerbarasts": "konvojerbar",
    "konvojerbare": "konvojerbar",
    "konvojerbares": "konvojerbar",
    "konvojerbarheten": "konvojerbarhet",
    "konvojerbarhetens": "konvojerbarhet",
    "konvojerbarhets": "konvojerbarhet",
    "konvojerbars": "konvojerbar",
    "konvojerbart": "konvojerbar",
    "konvojerbarts": "konvojerbar",
    "konvojeringar": "konvojering",
    "konvojeringarna": "konvojering",
    "konvojeringarnas": "konvojering",
    "konvojeringars": "konvojering",
    "konvojeringen": "konvojering",
    "konvojeringens": "konvojering",
    "konvojerings": "konvojering",
    "konvojerna": "konvoj",
    "konvojernas": "konvoj",
    "konvojers": "konvoj",
    "konvojs": "konvoj",
    "konvoluten": "konvolut",
    "konvolutens": "konvolut",
    "konvolutet": "konvolut",
    "konvolutets": "konvolut",
    "konvoluts": "konvolut",
    "konvulsionen": "konvulsion",
    "konvulsionens": "konvulsion",
    "konvulsioner": "konvulsion",
    "konvulsionerna": "konvulsion",
    "konvulsionernas": "konvulsion",
    "konvulsioners": "konvulsion",
    "konvulsions": "konvulsion",
    "konvulsiviska": "konvulsivisk",
    "konvulsiviskare": "konvulsivisk",
    "konvulsiviskares": "konvulsivisk",
    "konvulsiviskas": "konvulsivisk",
    "konvulsiviskast": "konvulsivisk",
    "konvulsiviskaste": "konvulsivisk",
    "konvulsiviskastes": "konvulsivisk",
    "konvulsiviskasts": "konvulsivisk",
    "konvulsiviske": "konvulsivisk",
    "konvulsiviskes": "konvulsivisk",
    "konvulsivisks": "konvulsivisk",
    "konvulsiviskt": "konvulsivisk",
    "konvulsiviskts": "konvulsivisk",
    "kooperationen": "kooperation",
    "kooperationens": "kooperation",
    "kooperationer": "kooperation",
    "kooperationerna": "kooperation",
    "kooperationernas": "kooperation",
    "kooperationers": "kooperation",
    "kooperations": "kooperation",
    "kooperativa": "kooperativ",
    "kooperativare": "kooperativ",
    "kooperativares": "kooperativ",
    "kooperativas": "kooperativ",
    "kooperativast": "kooperativ",
    "kooperativaste": "kooperativ",
    "kooperativastes": "kooperativ",
    "kooperativasts": "kooperativ",
    "kooperative": "kooperativ",
    "kooperativen": "kooperativ",
    "kooperativens": "kooperativ",
    "kooperatives": "kooperativ",
    "kooperativet": "kooperativ",
    "kooperativets": "kooperativ",
    "kooperativs": "kooperativ",
    "kooperativt": "kooperativ",
    "kooperativts": "kooperativ",
    "kooperatören": "kooperatör",
    "kooperatörens": "kooperatör",
    "kooperatörer": "kooperatör",
    "kooperatörerna": "kooperatör",
    "kooperatörernas": "kooperatör",
    "kooperatörers": "kooperatör",
    "kooperatörs": "kooperatör",
    "koopererade": "kooperera",
    "koopererades": "kooperera",
    "koopererande": "kooperera",
    "koopereranden": "koopererande",
    "koopererandena": "koopererande",
    "koopererandenas": "koopererande",
    "koopererandens": "koopererande",
    "koopererandes": "koopererande",
    "koopererandet": "koopererande",
    "koopererandets": "koopererande",
    "koopererar": "kooperera",
    "koopereras": "kooperera",
    "koopererat": "kooperera",
    "koopererats": "kooperera",
    "koopereringar": "kooperering",
    "koopereringarna": "kooperering",
    "koopereringarnas": "kooperering",
    "koopereringars": "kooperering",
    "koopereringen": "kooperering",
    "koopereringens": "kooperering",
    "koopererings": "kooperering",
    "koordinataxeln": "koordinataxel",
    "koordinataxelns": "koordinataxel",
    "koordinataxels": "koordinataxel",
    "koordinataxlar": "koordinataxel",
    "koordinataxlarna": "koordinataxel",
    "koordinataxlarnas": "koordinataxel",
    "koordinataxlars": "koordinataxel",
    "koordinaten": "koordinat",
    "koordinatens": "koordinat",
    "koordinater": "koordinat",
    "koordinaterna": "koordinat",
    "koordinaternas": "koordinat",
    "koordinaters": "koordinat",
    "koordinationen": "koordination",
    "koordinationens": "koordination",
    "koordinationer": "koordination",
    "koordinationerna": "koordination",
    "koordinationernas": "koordination",
    "koordinationers": "koordination",
    "koordinations": "koordination",
    "koordinatorer": "koordinator",
    "koordinatorerna": "koordinator",
    "koordinatorernas": "koordinator",
    "koordinatorers": "koordinator",
    "koordinatorn": "koordinator",
    "koordinatorns": "koordinator",
    "koordinators": "koordinator",
    "koordinats": "koordinat",
    "koordinatsystemen": "koordinatsystem",
    "koordinatsystemens": "koordinatsystem",
    "koordinatsystemet": "koordinatsystem",
    "koordinatsystemets": "koordinatsystem",
    "koordinatsystems": "koordinatsystem",
    "koordinerad": "koordinera",
    "koordinerade": "koordinera",
    "koordinerades": "koordinera",
    "koordinerads": "koordinera",
    "koordinerande": "koordinera",
    "koordineranden": "koordinerande",
    "koordinerandena": "koordinerande",
    "koordinerandenas": "koordinerande",
    "koordinerandens": "koordinerande",
    "koordinerandes": "koordinerande",
    "koordinerandet": "koordinerande",
    "koordinerandets": "koordinerande",
    "koordinerar": "koordinera",
    "koordineras": "koordinera",
    "koordinerat": "koordinera",
    "koordinerats": "koordinera",
    "koordinerbara": "koordinerbar",
    "koordinerbarare": "koordinerbar",
    "koordinerbarares": "koordinerbar",
    "koordinerbaras": "koordinerbar",
    "koordinerbarast": "koordinerbar",
    "koordinerbaraste": "koordinerbar",
    "koordinerbarastes": "koordinerbar",
    "koordinerbarasts": "koordinerbar",
    "koordinerbare": "koordinerbar",
    "koordinerbares": "koordinerbar",
    "koordinerbarheten": "koordinerbarhet",
    "koordinerbarhetens": "koordinerbarhet",
    "koordinerbarhets": "koordinerbarhet",
    "koordinerbars": "koordinerbar",
    "koordinerbart": "koordinerbar",
    "koordinerbarts": "koordinerbar",
    "koordineringar": "koordinering",
    "koordineringarna": "koordinering",
    "koordineringarnas": "koordinering",
    "koordineringars": "koordinering",
    "koordineringen": "koordinering",
    "koordineringens": "koordinering",
    "koordinerings": "koordinering",
    "kopeken": "kopek",
    "kopekens": "kopek",
    "kopeks": "kopek",
    "kopernikanska": "kopernikansk",
    "kopernikanskare": "kopernikansk",
    "kopernikanskares": "kopernikansk",
    "kopernikanskas": "kopernikansk",
    "kopernikanskast": "kopernikansk",
    "kopernikanskaste": "kopernikansk",
    "kopernikanskastes": "kopernikansk",
    "kopernikanskasts": "kopernikansk",
    "kopernikanske": "kopernikansk",
    "kopernikanskes": "kopernikansk",
    "kopernikansks": "kopernikansk",
    "kopernikanskt": "kopernikansk",
    "kopernikanskts": "kopernikansk",
    "kopian": "kopia",
    "kopians": "kopia",
    "kopias": "kopia",
    "kopiatorer": "kopiator",
    "kopiatorerna": "kopiator",
    "kopiatorernas": "kopiator",
    "kopiatorers": "kopiator",
    "kopiatorn": "kopiator",
    "kopiatorns": "kopiator",
    "kopiators": "kopiator",
    "kopie": "kopia",
    "kopiepapperen": "kopiepapper",
    "kopiepapperens": "kopiepapper",
    "kopiepapperet": "kopiepapper",
    "kopiepapperets": "kopiepapper",
    "kopiepapperna": "kopiepapper",
    "kopiepappernas": "kopiepapper",
    "kopiepappers": "kopiepapper",
    "kopiepappren": "kopiepapper",
    "kopiepapprens": "kopiepapper",
    "kopiepappret": "kopiepapper",
    "kopiepapprets": "kopiepapper",
    "kopierad": "kopiera",
    "kopierade": "kopiera",
    "kopierades": "kopiera",
    "kopierads": "kopiera",
    "kopierande": "kopiera",
    "kopieranden": "kopierande",
    "kopierandena": "kopierande",
    "kopierandenas": "kopierande",
    "kopierandens": "kopierande",
    "kopierandes": "kopierande",
    "kopierandet": "kopierande",
    "kopierandets": "kopierande",
    "kopierar": "kopiera",
    "kopieras": "kopiera",
    "kopierat": "kopiera",
    "kopierats": "kopiera",
    "kopierbara": "kopierbar",
    "kopierbarare": "kopierbar",
    "kopierbarares": "kopierbar",
    "kopierbaras": "kopierbar",
    "kopierbarast": "kopierbar",
    "kopierbaraste": "kopierbar",
    "kopierbarastes": "kopierbar",
    "kopierbarasts": "kopierbar",
    "kopierbare": "kopierbar",
    "kopierbares": "kopierbar",
    "kopierbarheten": "kopierbarhet",
    "kopierbarhetens": "kopierbarhet",
    "kopierbarhets": "kopierbarhet",
    "kopierbars": "kopierbar",
    "kopierbart": "kopierbar",
    "kopierbarts": "kopierbar",
    "kopieringar": "kopiering",
    "kopieringarna": "kopiering",
    "kopieringarnas": "kopiering",
    "kopieringars": "kopiering",
    "kopieringen": "kopiering",
    "kopieringens": "kopiering",
    "kopierings": "kopiering",
    "kopieringsapparaten": "kopieringsapparat",
    "kopieringsapparatens": "kopieringsapparat",
    "kopieringsapparater": "kopieringsapparat",
    "kopieringsapparaterna": "kopieringsapparat",
    "kopieringsapparaternas": "kopieringsapparat",
    "kopieringsapparaters": "kopieringsapparat",
    "kopieringsapparats": "kopieringsapparat",
    "kopieringsmaskinen": "kopieringsmaskin",
    "kopieringsmaskinens": "kopieringsmaskin",
    "kopieringsmaskiner": "kopieringsmaskin",
    "kopieringsmaskinerna": "kopieringsmaskin",
    "kopieringsmaskinernas": "kopieringsmaskin",
    "kopieringsmaskiners": "kopieringsmaskin",
    "kopieringsmaskins": "kopieringsmaskin",
    "kopiesvarvar": "kopiesvarv",
    "kopiesvarvarna": "kopiesvarv",
    "kopiesvarvarnas": "kopiesvarv",
    "kopiesvarvars": "kopiesvarv",
    "kopiesvarven": "kopiesvarv",
    "kopiesvarvens": "kopiesvarv",
    "kopiesvarvs": "kopiesvarv",
    "kopior": "kopia",
    "kopiorna": "kopia",
    "kopiornas": "kopia",
    "kopiors": "kopia",
    "kopisten": "kopist",
    "kopistens": "kopist",
    "kopister": "kopist",
    "kopisterna": "kopist",
    "kopisternas": "kopist",
    "kopisters": "kopist",
    "kopists": "kopist",
    "kopiösa": "kopiös",
    "kopiösare": "kopiös",
    "kopiösares": "kopiös",
    "kopiösas": "kopiös",
    "kopiösast": "kopiös",
    "kopiösaste": "kopiös",
    "kopiösastes": "kopiös",
    "kopiösasts": "kopiös",
    "kopiöse": "kopiös",
    "kopiöses": "kopiös",
    "kopiöst": "kopiös",
    "kopiösts": "kopiös",
    "kopp": "koppa",
    "koppad": "koppa",
    "koppade": "koppa",
    "koppades": "koppa",
    "koppads": "koppa",
    "koppan": "koppa",
    "koppande": "koppa",
    "koppanden": "koppande",
    "koppandena": "koppande",
    "koppandenas": "koppande",
    "koppandens": "koppande",
    "koppandes": "koppande",
    "koppandet": "koppande",
    "koppandets": "koppande",
    "koppans": "koppa",
    "koppar": "koppa",
    "kopparbruna": "kopparbrun",
    "kopparbrunare": "kopparbrun",
    "kopparbrunares": "kopparbrun",
    "kopparbrunas": "kopparbrun",
    "kopparbrunast": "kopparbrun",
    "kopparbrunaste": "kopparbrun",
    "kopparbrunastes": "kopparbrun",
    "kopparbrunasts": "kopparbrun",
    "kopparbrune": "kopparbrun",
    "kopparbrunes": "kopparbrun",
    "kopparbruns": "kopparbrun",
    "kopparbrunt": "kopparbrun",
    "kopparbrunts": "kopparbrun",
    "kopparen": "koppar",
    "kopparens": "koppar",
    "kopparfärgade": "kopparfärgad",
    "kopparfärgades": "kopparfärgad",
    "kopparfärgads": "kopparfärgad",
    "kopparfärgat": "kopparfärgad",
    "kopparfärgats": "kopparfärgad",
    "kopparförlust": "kopparförluster",
    "kopparförlusterna": "kopparförluster",
    "kopparförlusternas": "kopparförluster",
    "kopparförlusters": "kopparförluster",
    "kopparglansen": "kopparglans",
    "kopparglansens": "kopparglans",
    "koppargruv": "koppargruva",
    "koppargruvan": "koppargruva",
    "koppargruvans": "koppargruva",
    "koppargruvas": "koppargruva",
    "koppargruve": "koppargruva",
    "koppargruvor": "koppargruva",
    "koppargruvorna": "koppargruva",
    "koppargruvornas": "koppargruva",
    "koppargruvors": "koppargruva",
    "koppargruvs": "koppargruva",
    "kopparkisen": "kopparkis",
    "kopparkisens": "kopparkis",
    "kopparledningar": "kopparledning",
    "kopparledningarna": "kopparledning",
    "kopparledningarnas": "kopparledning",
    "kopparledningars": "kopparledning",
    "kopparledningen": "kopparledning",
    "kopparledningens": "kopparledning",
    "kopparlednings": "kopparledning",
    "kopparmynten": "kopparmynt",
    "kopparmyntens": "kopparmynt",
    "kopparmyntet": "kopparmynt",
    "kopparmyntets": "kopparmynt",
    "kopparmynts": "kopparmynt",
    "kopparn": "koppar",
    "kopparna": "kopp",
    "kopparnas": "kopp",
    "kopparns": "koppar",
    "kopparormar": "kopparorm",
    "kopparormarna": "kopparorm",
    "kopparormarnas": "kopparorm",
    "kopparormars": "kopparorm",
    "kopparormen": "kopparorm",
    "kopparormens": "kopparorm",
    "kopparorms": "kopparorm",
    "kopparplåtar": "kopparplåt",
    "kopparplåtarna": "kopparplåt",
    "kopparplåtarnas": "kopparplåt",
    "kopparplåtars": "kopparplåt",
    "kopparplåten": "kopparplåt",
    "kopparplåtens": "kopparplåt",
    "kopparplåts": "kopparplåt",
    "kopparröda": "kopparröd",
    "kopparrödare": "kopparröd",
    "kopparrödares": "kopparröd",
    "kopparrödas": "kopparröd",
    "kopparrödast": "kopparröd",
    "kopparrödaste": "kopparröd",
    "kopparrödastes": "kopparröd",
    "kopparrödasts": "kopparröd",
    "kopparröde": "kopparröd",
    "kopparrödes": "kopparröd",
    "kopparröds": "kopparröd",
    "kopparrött": "kopparröd",
    "kopparrötts": "kopparröd",
    "koppars": "koppar",
    "kopparslagar": "kopparslagare",
    "kopparslagaren": "kopparslagare",
    "kopparslagarens": "kopparslagare",
    "kopparslagares": "kopparslagare",
    "kopparslagarna": "kopparslagare",
    "kopparslagarnas": "kopparslagare",
    "kopparspiralen": "kopparspiral",
    "kopparspiralens": "kopparspiral",
    "kopparspiraler": "kopparspiral",
    "kopparspiralerna": "kopparspiral",
    "kopparspiralernas": "kopparspiral",
    "kopparspiralers": "kopparspiral",
    "kopparspirals": "kopparspiral",
    "kopparsticken": "kopparstick",
    "kopparstickens": "kopparstick",
    "kopparsticket": "kopparstick",
    "kopparstickets": "kopparstick",
    "kopparsticks": "kopparstick",
    "kopparsulfaten": "kopparsulfat",
    "kopparsulfatens": "kopparsulfat",
    "kopparsulfater": "kopparsulfat",
    "kopparsulfaterna": "kopparsulfat",
    "kopparsulfaternas": "kopparsulfat",
    "kopparsulfaters": "kopparsulfat",
    "kopparsulfatet": "kopparsulfat",
    "kopparsulfatets": "kopparsulfat",
    "kopparsulfats": "kopparsulfat",
    "koppartaken": "koppartak",
    "koppartakens": "koppartak",
    "koppartaket": "koppartak",
    "koppartakets": "koppartak",
    "koppartaks": "koppartak",
    "kopparärgen": "kopparärg",
    "kopparärgens": "kopparärg",
    "kopparärgs": "kopparärg",
    "kopparåldern": "kopparålder",
    "kopparålderns": "kopparålder",
    "kopparålders": "kopparålder",
    "kopparödlan": "kopparödla",
    "kopparödlans": "kopparödla",
    "kopparödlas": "kopparödla",
    "kopparödle": "kopparödla",
    "kopparödlor": "kopparödla",
    "kopparödlorna": "kopparödla",
    "kopparödlornas": "kopparödla",
    "kopparödlors": "kopparödla",
    "koppas": "koppa",
    "koppat": "koppa",
    "koppats": "koppa",
    "koppe": "koppa",
    "koppel": "koppla",
    "koppels": "koppel",
    "koppelvana": "koppelvan",
    "koppelvanare": "koppelvan",
    "koppelvanares": "koppelvan",
    "koppelvanas": "koppelvan",
    "koppelvanast": "koppelvan",
    "koppelvanaste": "koppelvan",
    "koppelvanastes": "koppelvan",
    "koppelvanasts": "koppelvan",
    "koppelvane": "koppelvan",
    "koppelvanes": "koppelvan",
    "koppelvans": "koppelvan",
    "koppelvant": "koppelvan",
    "koppelvants": "koppelvan",
    "koppen": "kopp",
    "koppens": "kopp",
    "kopplad": "koppla",
    "kopplade": "koppla",
    "kopplades": "koppla",
    "kopplads": "koppla",
    "kopplande": "koppla",
    "kopplanden": "kopplande",
    "kopplandena": "kopplande",
    "kopplandenas": "kopplande",
    "kopplandens": "kopplande",
    "kopplandes": "kopplande",
    "kopplandet": "kopplande",
    "kopplandets": "kopplande",
    "kopplar": "kopplare",
    "kopplaren": "kopplare",
    "kopplarens": "kopplare",
    "kopplares": "kopplare",
    "kopplarna": "kopplare",
    "kopplarnas": "kopplare",
    "kopplas": "koppla",
    "kopplat": "koppla",
    "kopplats": "koppla",
    "kopplen": "koppel",
    "kopplens": "koppel",
    "kopplerianklagade": "kopplerianklagad",
    "kopplerianklagades": "kopplerianklagad",
    "kopplerianklagads": "kopplerianklagad",
    "kopplerianklagat": "kopplerianklagad",
    "kopplerianklagats": "kopplerianklagad",
    "kopplerier": "koppleri",
    "kopplerierna": "koppleri",
    "koppleriernas": "koppleri",
    "koppleriers": "koppleri",
    "koppleriet": "koppleri",
    "koppleriets": "koppleri",
    "kopplerimisstänkta": "kopplerimisstänkt",
    "kopplerimisstänktas": "kopplerimisstänkt",
    "kopplerimisstänkte": "kopplerimisstänkt",
    "kopplerimisstänktes": "kopplerimisstänkt",
    "kopplerimisstänkts": "kopplerimisstänkt",
    "kopplerimålen": "kopplerimål",
    "kopplerimålens": "kopplerimål",
    "kopplerimålet": "kopplerimål",
    "kopplerimålets": "kopplerimål",
    "kopplerimåls": "kopplerimål",
    "koppleris": "koppleri",
    "kopplerit": "koppleri",
    "kopplerits": "koppleri",
    "koppleriåtalade": "koppleriåtalad",
    "koppleriåtalades": "koppleriåtalad",
    "koppleriåtalads": "koppleriåtalad",
    "koppleriåtalat": "koppleriåtalad",
    "koppleriåtalats": "koppleriåtalad",
    "kopplet": "koppel",
    "kopplets": "koppel",
    "kopplingar": "koppling",
    "kopplingarna": "koppling",
    "kopplingarnas": "koppling",
    "kopplingars": "koppling",
    "kopplingen": "koppling",
    "kopplingens": "koppling",
    "kopplings": "koppling",
    "kopplingspedalen": "kopplingspedal",
    "kopplingspedalens": "kopplingspedal",
    "kopplingspedaler": "kopplingspedal",
    "kopplingspedalerna": "kopplingspedal",
    "kopplingspedalernas": "kopplingspedal",
    "kopplingspedalers": "kopplingspedal",
    "kopplingspedals": "kopplingspedal",
    "kopplingsscheman": "kopplingsschema",
    "kopplingsschemana": "kopplingsschema",
    "kopplingsschemanas": "kopplingsschema",
    "kopplingsschemans": "kopplingsschema",
    "kopplingsschemas": "kopplingsschema",
    "kopplingsschemat": "kopplingsschema",
    "kopplingsschemats": "kopplingsschema",
    "kopplingsstycken": "kopplingsstycke",
    "kopplingsstyckena": "kopplingsstycke",
    "kopplingsstyckenas": "kopplingsstycke",
    "kopplingsstyckens": "kopplingsstycke",
    "kopplingsstyckes": "kopplingsstycke",
    "kopplingsstycket": "kopplingsstycke",
    "kopplingsstyckets": "kopplingsstycke",
    "kopplingsstycks": "kopplingsstycke",
    "kopplingstonen": "kopplingston",
    "kopplingstonens": "kopplingston",
    "kopplingstoner": "kopplingston",
    "kopplingstonerna": "kopplingston",
    "kopplingstonernas": "kopplingston",
    "kopplingstoners": "kopplingston",
    "kopplingstons": "kopplingston",
    "koppor": "koppa",
    "kopporna": "koppa",
    "koppornas": "koppa",
    "koppors": "koppa",
    "kopps": "koppa",
    "koppympningar": "koppympning",
    "koppympningarna": "koppympning",
    "koppympningarnas": "koppympning",
    "koppympningars": "koppympning",
    "koppympningen": "koppympning",
    "koppympningens": "koppympning",
    "koppympnings": "koppympning",
    "koppärren": "koppärr",
    "koppärrens": "koppärr",
    "koppärret": "koppärr",
    "koppärrets": "koppärr",
    "koppärriga": "koppärrig",
    "koppärrigare": "koppärrig",
    "koppärrigares": "koppärrig",
    "koppärrigas": "koppärrig",
    "koppärrigast": "koppärrig",
    "koppärrigaste": "koppärrig",
    "koppärrigastes": "koppärrig",
    "koppärrigasts": "koppärrig",
    "koppärrige": "koppärrig",
    "koppärriges": "koppärrig",
    "koppärrigheten": "koppärrighet",
    "koppärrighetens": "koppärrighet",
    "koppärrighets": "koppärrighet",
    "koppärrigs": "koppärrig",
    "koppärrigt": "koppärrig",
    "koppärrigts": "koppärrig",
    "koppärrs": "koppärr",
    "kopran": "kopra",
    "koprans": "kopra",
    "kopras": "kopra",
    "kopten": "kopt",
    "koptens": "kopt",
    "kopter": "kopt",
    "koptern": "kopter",
    "kopterna": "kopter",
    "kopternas": "kopter",
    "kopterns": "kopter",
    "kopters": "kopter",
    "koptisk": "koptiska",
    "koptiska": "koptisk",
    "koptiskan": "koptiska",
    "koptiskans": "koptiska",
    "koptiskare": "koptisk",
    "koptiskares": "koptisk",
    "koptiskas": "koptiska",
    "koptiskast": "koptisk",
    "koptiskaste": "koptisk",
    "koptiskastes": "koptisk",
    "koptiskasts": "koptisk",
    "koptiske": "koptisk",
    "koptiskes": "koptisk",
    "koptisks": "koptisk",
    "koptiskt": "koptisk",
    "koptiskts": "koptisk",
    "kopts": "kopt",
    "kopul": "kopula",
    "kopulan": "kopula",
    "kopulans": "kopula",
    "kopulas": "kopula",
    "kopulationen": "kopulation",
    "kopulationens": "kopulation",
    "kopulationer": "kopulation",
    "kopulationerna": "kopulation",
    "kopulationernas": "kopulation",
    "kopulationers": "kopulation",
    "kopulations": "kopulation",
    "kopulativa": "kopulativ",
    "kopulativare": "kopulativ",
    "kopulativares": "kopulativ",
    "kopulativas": "kopulativ",
    "kopulativast": "kopulativ",
    "kopulativaste": "kopulativ",
    "kopulativastes": "kopulativ",
    "kopulativasts": "kopulativ",
    "kopulative": "kopulativ",
    "kopulatives": "kopulativ",
    "kopulativs": "kopulativ",
    "kopulativt": "kopulativ",
    "kopulativts": "kopulativ",
    "kopule": "kopula",
    "kopulerade": "kopulera",
    "kopulerades": "kopulera",
    "kopulerande": "kopulera",
    "kopuleranden": "kopulerande",
    "kopulerandena": "kopulerande",
    "kopulerandenas": "kopulerande",
    "kopulerandens": "kopulerande",
    "kopulerandes": "kopulerande",
    "kopulerandet": "kopulerande",
    "kopulerandets": "kopulerande",
    "kopulerar": "kopulera",
    "kopuleras": "kopulera",
    "kopulerat": "kopulera",
    "kopulerats": "kopulera",
    "kopuleringar": "kopulering",
    "kopuleringarna": "kopulering",
    "kopuleringarnas": "kopulering",
    "kopuleringars": "kopulering",
    "kopuleringen": "kopulering",
    "kopuleringens": "kopulering",
    "kopulerings": "kopulering",
    "kopulor": "kopula",
    "kopulorna": "kopula",
    "kopulornas": "kopula",
    "kopulors": "kopula",
    "kopuls": "kopula",
    "kor": "kora",
    "korad": "kora",
    "korade": "kora",
    "korades": "kora",
    "korads": "kora",
    "koralboken": "koralbok",
    "koralbokens": "koralbok",
    "koralboks": "koralbok",
    "koralböcker": "koralbok",
    "koralböckerna": "koralbok",
    "koralböckernas": "koralbok",
    "koralböckers": "koralbok",
    "koralen": "koral",
    "koralens": "koral",
    "koraler": "koral",
    "koralerna": "koral",
    "koralernas": "koral",
    "koralers": "koral",
    "koralldjuren": "koralldjur",
    "koralldjurens": "koralldjur",
    "koralldjuret": "koralldjur",
    "koralldjurets": "koralldjur",
    "koralldjurs": "koralldjur",
    "korallen": "korall",
    "korallens": "korall",
    "koraller": "korall",
    "korallerna": "korall",
    "korallernas": "korall",
    "korallers": "korall",
    "korallhalsbanden": "korallhalsband",
    "korallhalsbandens": "korallhalsband",
    "korallhalsbandet": "korallhalsband",
    "korallhalsbandets": "korallhalsband",
    "korallhalsbands": "korallhalsband",
    "korallormar": "korallorm",
    "korallormarna": "korallorm",
    "korallormarnas": "korallorm",
    "korallormars": "korallorm",
    "korallormen": "korallorm",
    "korallormens": "korallorm",
    "korallorms": "korallorm",
    "korallreven": "korallrev",
    "korallrevens": "korallrev",
    "korallrevet": "korallrev",
    "korallrevets": "korallrev",
    "korallrevs": "korallrev",
    "korallröda": "korallröd",
    "korallrödare": "korallröd",
    "korallrödares": "korallröd",
    "korallrödas": "korallröd",
    "korallrödast": "korallröd",
    "korallrödaste": "korallröd",
    "korallrödastes": "korallröd",
    "korallrödasts": "korallröd",
    "korallröde": "korallröd",
    "korallrödes": "korallröd",
    "korallröds": "korallröd",
    "korallrött": "korallröd",
    "korallrötts": "korallröd",
    "koralls": "korall",
    "korallöar": "korallö",
    "korallöarna": "korallö",
    "korallöarnas": "korallö",
    "korallöars": "korallö",
    "korallön": "korallö",
    "korallöns": "korallö",
    "korallös": "korallö",
    "korals": "koral",
    "korande": "kora",
    "koranden": "korande",
    "korandena": "korande",
    "korandenas": "korande",
    "korandens": "korande",
    "korandes": "korande",
    "korandet": "korande",
    "korandets": "korande",
    "koranen": "koran",
    "koranens": "koran",
    "korans": "koran",
    "korar": "kora",
    "koras": "kora",
    "korat": "kora",
    "korats": "kora",
    "kord": "korda",
    "kordan": "korda",
    "kordans": "korda",
    "kordas": "korda",
    "korde": "korda",
    "korden": "kord",
    "kordens": "kord",
    "korderojen": "korderoj",
    "korderojens": "korderoj",
    "korderojs": "korderoj",
    "kordiala": "kordial",
    "kordialare": "kordial",
    "kordialares": "kordial",
    "kordialas": "kordial",
    "kordialast": "kordial",
    "kordialaste": "kordial",
    "kordialastes": "kordial",
    "kordialasts": "kordial",
    "kordiale": "kordial",
    "kordiales": "kordial",
    "kordials": "kordial",
    "kordialt": "kordial",
    "kordialts": "kordial",
    "kordongen": "kordong",
    "kordongens": "kordong",
    "kordonger": "kordong",
    "kordongerna": "kordong",
    "kordongernas": "kordong",
    "kordongers": "kordong",
    "kordongs": "kordong",
    "kordongskruvar": "kordongskruv",
    "kordongskruvarna": "kordongskruv",
    "kordongskruvarnas": "kordongskruv",
    "kordongskruvars": "kordongskruv",
    "kordongskruven": "kordongskruv",
    "kordongskruvens": "kordongskruv",
    "kordongskruvs": "kordongskruv",
    "kordor": "korda",
    "kordorna": "korda",
    "kordornas": "korda",
    "kordors": "korda",
    "kords": "korda",
    "koreanen": "korean",
    "koreanens": "korean",
    "koreaner": "korean",
    "koreanerna": "korean",
    "koreanernas": "korean",
    "koreaners": "korean",
    "koreans": "korean",
    "koreansk": "koreanska",
    "koreanska": "koreansk",
    "koreanskan": "koreanska",
    "koreanskans": "koreanska",
    "koreanskare": "koreansk",
    "koreanskares": "koreansk",
    "koreanskas": "koreanska",
    "koreanskast": "koreansk",
    "koreanskaste": "koreansk",
    "koreanskastes": "koreansk",
    "koreanskasts": "koreansk",
    "koreanske": "koreanska",
    "koreanskes": "koreansk",
    "koreanskor": "koreanska",
    "koreanskorna": "koreanska",
    "koreanskornas": "koreanska",
    "koreanskors": "koreanska",
    "koreansks": "koreansk",
    "koreanskt": "koreansk",
    "koreanskts": "koreansk",
    "koren": "kor",
    "korens": "kor",
    "koreografen": "koreograf",
    "koreografens": "koreograf",
    "koreografer": "koreograf",
    "koreograferna": "koreograf",
    "koreografernas": "koreograf",
    "koreografers": "koreograf",
    "koreografien": "koreografi",
    "koreografiens": "koreografi",
    "koreografin": "koreografi",
    "koreografins": "koreografi",
    "koreografis": "koreografi",
    "koreografiska": "koreografisk",
    "koreografiskare": "koreografisk",
    "koreografiskares": "koreografisk",
    "koreografiskas": "koreografisk",
    "koreografiskast": "koreografisk",
    "koreografiskaste": "koreografisk",
    "koreografiskastes": "koreografisk",
    "koreografiskasts": "koreografisk",
    "koreografiske": "koreografisk",
    "koreografiskes": "koreografisk",
    "koreografisks": "koreografisk",
    "koreografiskt": "koreografisk",
    "koreografiskts": "koreografisk",
    "koreografs": "koreograf",
    "koret": "kor",
    "korets": "kor",
    "korgar": "korg",
    "korgarna": "korg",
    "korgarnas": "korg",
    "korgars": "korg",
    "korgblommiga": "korgblommig",
    "korgblommigare": "korgblommig",
    "korgblommigares": "korgblommig",
    "korgblommigas": "korgblommig",
    "korgblommigast": "korgblommig",
    "korgblommigaste": "korgblommig",
    "korgblommigastes": "korgblommig",
    "korgblommigasts": "korgblommig",
    "korgblommige": "korgblommig",
    "korgblommiges": "korgblommig",
    "korgblommigs": "korgblommig",
    "korgblommigt": "korgblommig",
    "korgblommigts": "korgblommig",
    "korgbollar": "korgboll",
    "korgbollarna": "korgboll",
    "korgbollarnas": "korgboll",
    "korgbollars": "korgboll",
    "korgbollen": "korgboll",
    "korgbollens": "korgboll",
    "korgbolls": "korgboll",
    "korgen": "korg",
    "korgens": "korg",
    "korgoss": "korgosse",
    "korgossar": "korgosse",
    "korgossarna": "korgosse",
    "korgossarnas": "korgosse",
    "korgossars": "korgosse",
    "korgossen": "korgosse",
    "korgossens": "korgosse",
    "korgosses": "korgosse",
    "korgs": "korg",
    "korgstolar": "korgstol",
    "korgstolarna": "korgstol",
    "korgstolarnas": "korgstol",
    "korgstolars": "korgstol",
    "korgstolen": "korgstol",
    "korgstolens": "korgstol",
    "korgstols": "korgstol",
    "koriandern": "koriander",
    "korianderns": "koriander",
    "korianders": "koriander",
    "korinten": "korint",
    "korintens": "korint",
    "korinter": "korint",
    "korintern": "korinter",
    "korinterna": "korinter",
    "korinternas": "korinter",
    "korinterns": "korinter",
    "korinters": "korinter",
    "korintiska": "korintisk",
    "korintiskare": "korintisk",
    "korintiskares": "korintisk",
    "korintiskas": "korintisk",
    "korintiskast": "korintisk",
    "korintiskaste": "korintisk",
    "korintiskastes": "korintisk",
    "korintiskasts": "korintisk",
    "korintiske": "korintisk",
    "korintiskes": "korintisk",
    "korintisks": "korintisk",
    "korintiskt": "korintisk",
    "korintiskts": "korintisk",
    "korints": "korint",
    "koristen": "korist",
    "koristens": "korist",
    "korister": "korist",
    "koristerna": "korist",
    "koristernas": "korist",
    "koristers": "korist",
    "korists": "korist",
    "kork": "korka",
    "korkad": "korka",
    "korkade": "korkad",
    "korkades": "korkad",
    "korkads": "korkad",
    "korkande": "korka",
    "korkanden": "korkande",
    "korkandena": "korkande",
    "korkandenas": "korkande",
    "korkandens": "korkande",
    "korkandes": "korkande",
    "korkandet": "korkande",
    "korkandets": "korkande",
    "korkapparaten": "korkapparat",
    "korkapparatens": "korkapparat",
    "korkapparater": "korkapparat",
    "korkapparaterna": "korkapparat",
    "korkapparaternas": "korkapparat",
    "korkapparaters": "korkapparat",
    "korkapparats": "korkapparat",
    "korkar": "korka",
    "korkarna": "kork",
    "korkarnas": "kork",
    "korkars": "kork",
    "korkas": "korka",
    "korkat": "korkad",
    "korkats": "korkad",
    "korkböss": "korkbössa",
    "korkbössan": "korkbössa",
    "korkbössans": "korkbössa",
    "korkbössas": "korkbössa",
    "korkbösse": "korkbössa",
    "korkbössor": "korkbössa",
    "korkbössorna": "korkbössa",
    "korkbössornas": "korkbössa",
    "korkbössors": "korkbössa",
    "korkcellen": "korkcell",
    "korkcellens": "korkcell",
    "korkceller": "korkcell",
    "korkcellerna": "korkcell",
    "korkcellernas": "korkcell",
    "korkcellers": "korkcell",
    "korkcells": "korkcell",
    "korkekar": "korkek",
    "korkekarna": "korkek",
    "korkekarnas": "korkek",
    "korkekars": "korkek",
    "korkeken": "korkek",
    "korkekens": "korkek",
    "korkeks": "korkek",
    "korken": "kork",
    "korkens": "kork",
    "korkgolven": "korkgolv",
    "korkgolvens": "korkgolv",
    "korkgolvet": "korkgolv",
    "korkgolvets": "korkgolv",
    "korkgolvs": "korkgolv",
    "korklagerna": "korklager",
    "korklagernas": "korklager",
    "korklagers": "korklager",
    "korklagren": "korklager",
    "korklagrens": "korklager",
    "korklagret": "korklager",
    "korklagrets": "korklager",
    "korkmaskinen": "korkmaskin",
    "korkmaskinens": "korkmaskin",
    "korkmaskiner": "korkmaskin",
    "korkmaskinerna": "korkmaskin",
    "korkmaskinernas": "korkmaskin",
    "korkmaskiners": "korkmaskin",
    "korkmaskins": "korkmaskin",
    "korkmassan": "korkmassa",
    "korkmassans": "korkmassa",
    "korkmassas": "korkmassa",
    "korkmasse": "korkmassa",
    "korkmassor": "korkmassa",
    "korkmassorna": "korkmassa",
    "korkmassornas": "korkmassa",
    "korkmassors": "korkmassa",
    "korkmatt": "korkmatta",
    "korkmattan": "korkmatta",
    "korkmattans": "korkmatta",
    "korkmattas": "korkmatta",
    "korkmatte": "korkmatta",
    "korkmattor": "korkmatta",
    "korkmattorna": "korkmatta",
    "korkmattornas": "korkmatta",
    "korkmattors": "korkmatta",
    "korkmatts": "korkmatta",
    "korkpistolen": "korkpistol",
    "korkpistolens": "korkpistol",
    "korkpistoler": "korkpistol",
    "korkpistolerna": "korkpistol",
    "korkpistolernas": "korkpistol",
    "korkpistolers": "korkpistol",
    "korkpistols": "korkpistol",
    "korks": "kork",
    "korkskruvar": "korkskruv",
    "korkskruvarna": "korkskruv",
    "korkskruvarnas": "korkskruv",
    "korkskruvars": "korkskruv",
    "korkskruven": "korkskruv",
    "korkskruvens": "korkskruv",
    "korkskruvs": "korkskruv",
    "korkskruvslockar": "korkskruvslock",
    "korkskruvslockarna": "korkskruvslock",
    "korkskruvslockarnas": "korkskruvslock",
    "korkskruvslockars": "korkskruvslock",
    "korkskruvslocken": "korkskruvslock",
    "korkskruvslockens": "korkskruvslock",
    "korkskruvslocks": "korkskruvslock",
    "korkskördar": "korkskörd",
    "korkskördarna": "korkskörd",
    "korkskördarnas": "korkskörd",
    "korkskördars": "korkskörd",
    "korkskörden": "korkskörd",
    "korkskördens": "korkskörd",
    "korkskörds": "korkskörd",
    "korksmaken": "korksmak",
    "korksmakens": "korksmak",
    "korksmaker": "korksmak",
    "korksmakerna": "korksmak",
    "korksmakernas": "korksmak",
    "korksmakers": "korksmak",
    "korksmaks": "korksmak",
    "korksul": "korksula",
    "korksulan": "korksula",
    "korksulans": "korksula",
    "korksulas": "korksula",
    "korksule": "korksula",
    "korksulor": "korksula",
    "korksulorna": "korksula",
    "korksulornas": "korksula",
    "korksulors": "korksula",
    "korksuls": "korksula",
    "korkvävnaden": "korkvävnad",
    "korkvävnadens": "korkvävnad",
    "korkvävnader": "korkvävnad",
    "korkvävnaderna": "korkvävnad",
    "korkvävnadernas": "korkvävnad",
    "korkvävnaders": "korkvävnad",
    "korkvävnads": "korkvävnad",
    "kormoranen": "kormoran",
    "kormoranens": "kormoran",
    "kormoraner": "kormoran",
    "kormoranerna": "kormoran",
    "kormoranernas": "kormoran",
    "kormoraners": "kormoran",
    "kormorans": "kormoran",
    "kormästar": "kormästare",
    "kormästaren": "kormästare",
    "kormästarens": "kormästare",
    "kormästares": "kormästare",
    "kormästarna": "kormästare",
    "kormästarnas": "kormästare",
    "korna": "ko",
    "kornas": "ko",
    "kornblixtar": "kornblixt",
    "kornblixtarna": "kornblixt",
    "kornblixtarnas": "kornblixt",
    "kornblixtars": "kornblixt",
    "kornblixten": "kornblixt",
    "kornblixtens": "kornblixt",
    "kornblixts": "kornblixt",
    "kornblåa": "kornblå",
    "kornblåare": "kornblå",
    "kornblåares": "kornblå",
    "kornblåas": "kornblå",
    "kornblåast": "kornblå",
    "kornblåaste": "kornblå",
    "kornblåastes": "kornblå",
    "kornblåasts": "kornblå",
    "kornblåe": "kornblå",
    "kornblåes": "kornblå",
    "kornblås": "kornblå",
    "kornblått": "kornblå",
    "kornblåtts": "kornblå",
    "kornbodar": "kornbod",
    "kornbodarna": "kornbod",
    "kornbodarnas": "kornbod",
    "kornbodars": "kornbod",
    "kornboden": "kornbod",
    "kornbodens": "kornbod",
    "kornbods": "kornbod",
    "kornbröden": "kornbröd",
    "kornbrödens": "kornbröd",
    "kornbrödet": "kornbröd",
    "kornbrödets": "kornbröd",
    "kornbröds": "kornbröd",
    "korndrällen": "korndräll",
    "korndrällens": "korndräll",
    "korndrälls": "korndräll",
    "kornen": "korn",
    "kornens": "korn",
    "kornet": "korn",
    "kornets": "korn",
    "kornetten": "kornett",
    "kornettens": "kornett",
    "kornetter": "kornett",
    "kornetterna": "kornett",
    "kornetternas": "kornett",
    "kornetters": "kornett",
    "kornettisten": "kornettist",
    "kornettistens": "kornettist",
    "kornettister": "kornettist",
    "kornettisterna": "kornettist",
    "kornettisternas": "kornettist",
    "kornettisters": "kornettist",
    "kornettists": "kornettist",
    "kornetts": "kornett",
    "korngrynen": "korngryn",
    "korngrynens": "korngryn",
    "korngrynet": "korngryn",
    "korngrynets": "korngryn",
    "korngryns": "korngryn",
    "korngrynsvällingar": "korngrynsvälling",
    "korngrynsvällingarna": "korngrynsvälling",
    "korngrynsvällingarnas": "korngrynsvälling",
    "korngrynsvällingars": "korngrynsvälling",
    "korngrynsvällingen": "korngrynsvälling",
    "korngrynsvällingens": "korngrynsvälling",
    "korngrynsvällings": "korngrynsvälling",
    "korngula": "korngul",
    "korngulare": "korngul",
    "korngulares": "korngul",
    "korngulas": "korngul",
    "korngulast": "korngul",
    "korngulaste": "korngul",
    "korngulastes": "korngul",
    "korngulasts": "korngul",
    "korngule": "korngul",
    "korngules": "korngul",
    "kornguls": "korngul",
    "korngult": "korngul",
    "korngults": "korngul",
    "korniga": "kornig",
    "kornigare": "kornig",
    "kornigares": "kornig",
    "kornigas": "kornig",
    "kornigast": "kornig",
    "kornigaste": "kornig",
    "kornigastes": "kornig",
    "kornigasts": "kornig",
    "kornige": "kornig",
    "korniges": "kornig",
    "kornigheten": "kornighet",
    "kornighetens": "kornighet",
    "kornighets": "kornighet",
    "kornigs": "kornig",
    "kornigt": "kornig",
    "kornigts": "kornig",
    "kornischen": "kornisch",
    "kornischens": "kornisch",
    "kornischer": "kornisch",
    "kornischerna": "kornisch",
    "kornischernas": "kornisch",
    "kornischers": "kornisch",
    "kornischs": "kornisch",
    "kornknarrar": "kornknarr",
    "kornknarrarna": "kornknarr",
    "kornknarrarnas": "kornknarr",
    "kornknarrars": "kornknarr",
    "kornknarren": "kornknarr",
    "kornknarrens": "kornknarr",
    "kornknarrs": "kornknarr",
    "korns": "korn",
    "kornsnön": "kornsnö",
    "kornsnöns": "kornsnö",
    "kornsnös": "kornsnö",
    "kornåkern": "kornåker",
    "kornåkerns": "kornåker",
    "kornåkers": "kornåker",
    "kornåkrar": "kornåker",
    "kornåkrarna": "kornåker",
    "kornåkrarnas": "kornåker",
    "kornåkrars": "kornåker",
    "korollarie": "korollarium",
    "korollarier": "korollarium",
    "korollarierna": "korollarium",
    "korollariernas": "korollarium",
    "korollariers": "korollarium",
    "korollariet": "korollarium",
    "korollariets": "korollarium",
    "korollariums": "korollarium",
    "koron": "korona",
    "koronan": "korona",
    "koronans": "korona",
    "koronarsklerosen": "koronarskleros",
    "koronarsklerosens": "koronarskleros",
    "koronas": "korona",
    "korone": "korona",
    "koronor": "korona",
    "koronorna": "korona",
    "koronornas": "korona",
    "koronors": "korona",
    "korons": "korona",
    "korpad": "korpa",
    "korpade": "korpa",
    "korpades": "korpa",
    "korpads": "korpa",
    "korpande": "korpa",
    "korpanden": "korpande",
    "korpandena": "korpande",
    "korpandenas": "korpande",
    "korpandens": "korpande",
    "korpandes": "korpande",
    "korpandet": "korpande",
    "korpandets": "korpande",
    "korpar": "korpa",
    "korparna": "korp",
    "korparnas": "korp",
    "korpars": "korp",
    "korpas": "korpa",
    "korpat": "korpa",
    "korpats": "korpa",
    "korpen": "korp",
    "korpens": "korp",
    "korpgluggar": "korpglugg",
    "korpgluggarna": "korpgluggar",
    "korpgluggarnas": "korpgluggar",
    "korpgluggars": "korpgluggar",
    "korpgluggen": "korpglugg",
    "korpgluggens": "korpglugg",
    "korpgluggs": "korpgluggar",
    "korplåten": "korplåt",
    "korplåtens": "korplåt",
    "korplåts": "korplåt",
    "korporationen": "korporation",
    "korporationens": "korporation",
    "korporationer": "korporation",
    "korporationerna": "korporation",
    "korporationernas": "korporation",
    "korporationers": "korporation",
    "korporations": "korporation",
    "korporationsidrotten": "korporationsidrott",
    "korporationsidrottens": "korporationsidrott",
    "korporationsidrotts": "korporationsidrott",
    "korporatismen": "korporatism",
    "korporatismens": "korporatism",
    "korporatismer": "korporatism",
    "korporatismerna": "korporatism",
    "korporatismernas": "korporatism",
    "korporatismers": "korporatism",
    "korporatisms": "korporatism",
    "korporatistiska": "korporatistisk",
    "korporatistiskas": "korporatistisk",
    "korporatistiske": "korporatistisk",
    "korporatistiskes": "korporatistisk",
    "korporatistisks": "korporatistisk",
    "korporatistiskt": "korporatistisk",
    "korporatistiskts": "korporatistisk",
    "korporativa": "korporativ",
    "korporativare": "korporativ",
    "korporativares": "korporativ",
    "korporativas": "korporativ",
    "korporativast": "korporativ",
    "korporativaste": "korporativ",
    "korporativastes": "korporativ",
    "korporativasts": "korporativ",
    "korporative": "korporativ",
    "korporatives": "korporativ",
    "korporativismen": "korporativism",
    "korporativismens": "korporativism",
    "korporativismer": "korporativism",
    "korporativismerna": "korporativism",
    "korporativismernas": "korporativism",
    "korporativismers": "korporativism",
    "korporativisms": "korporativism",
    "korporativistiska": "korporativistisk",
    "korporativistiskas": "korporativistisk",
    "korporativistiske": "korporativistisk",
    "korporativistiskes": "korporativistisk",
    "korporativistisks": "korporativistisk",
    "korporativistiskt": "korporativistisk",
    "korporativistiskts": "korporativistisk",
    "korporativs": "korporativ",
    "korporativt": "korporativ",
    "korporativts": "korporativ",
    "korpralen": "korpral",
    "korpralens": "korpral",
    "korpraler": "korpral",
    "korpralerna": "korpral",
    "korpralernas": "korpral",
    "korpralers": "korpral",
    "korprals": "korpral",
    "korps": "korp",
    "korpsvarta": "korpsvart",
    "korpsvartare": "korpsvart",
    "korpsvartares": "korpsvart",
    "korpsvartas": "korpsvart",
    "korpsvartast": "korpsvart",
    "korpsvartaste": "korpsvart",
    "korpsvartastes": "korpsvart",
    "korpsvartasts": "korpsvart",
    "korpsvarte": "korpsvart",
    "korpsvartes": "korpsvart",
    "korpsvarts": "korpsvart",
    "korpulensen": "korpulens",
    "korpulensens": "korpulens",
    "korpulenta": "korpulent",
    "korpulentare": "korpulent",
    "korpulentares": "korpulent",
    "korpulentas": "korpulent",
    "korpulentast": "korpulent",
    "korpulentaste": "korpulent",
    "korpulentastes": "korpulent",
    "korpulentasts": "korpulent",
    "korpulente": "korpulent",
    "korpulentes": "korpulent",
    "korpulents": "korpulent",
    "korpusar": "korpus",
    "korpusarna": "korpus",
    "korpusarnas": "korpus",
    "korpusars": "korpus",
    "korpusen": "korpus",
    "korpusens": "korpus",
    "korpuset": "korpus",
    "korpusets": "korpus",
    "korpuskeln": "korpuskel",
    "korpuskelns": "korpuskel",
    "korpuskels": "korpuskel",
    "korpuskler": "korpuskel",
    "korpusklerna": "korpuskel",
    "korpusklernas": "korpuskel",
    "korpusklers": "korpuskel",
    "korpuslingvistiken": "korpuslingvistik",
    "korpuslingvistikens": "korpuslingvistik",
    "korpuslingvistiks": "korpuslingvistik",
    "korpving": "korpvinge",
    "korpvingar": "korpvinge",
    "korpvingarna": "korpvinge",
    "korpvingarnas": "korpvinge",
    "korpvingars": "korpvinge",
    "korpvingen": "korpvinge",
    "korpvingens": "korpvinge",
    "korpvinges": "korpvinge",
    "korpvings": "korpvinge",
    "korrar": "korre",
    "korrarna": "korre",
    "korrarnas": "korre",
    "korrars": "korre",
    "korrasionen": "korrasion",
    "korrasionens": "korrasion",
    "korrasioner": "korrasion",
    "korrasionerna": "korrasion",
    "korrasionernas": "korrasion",
    "korrasioners": "korrasion",
    "korrasions": "korrasion",
    "korrekta": "korrekt",
    "korrektare": "korrekt",
    "korrektares": "korrekt",
    "korrektas": "korrekt",
    "korrektast": "korrekt",
    "korrektaste": "korrekt",
    "korrektastes": "korrekt",
    "korrektasts": "korrekt",
    "korrekte": "korrekt",
    "korrektes": "korrekt",
    "korrektheten": "korrekthet",
    "korrekthetens": "korrekthet",
    "korrekthets": "korrekthet",
    "korrektionen": "korrektion",
    "korrektionens": "korrektion",
    "korrektioner": "korrektion",
    "korrektionerna": "korrektion",
    "korrektionernas": "korrektion",
    "korrektioners": "korrektion",
    "korrektions": "korrektion",
    "korrektionsanstalten": "korrektionsanstalt",
    "korrektionsanstaltens": "korrektionsanstalt",
    "korrektionsanstalter": "korrektionsanstalt",
    "korrektionsanstalterna": "korrektionsanstalt",
    "korrektionsanstalternas": "korrektionsanstalt",
    "korrektionsanstalters": "korrektionsanstalt",
    "korrektionsanstalts": "korrektionsanstalt",
    "korrektiven": "korrektiv",
    "korrektivens": "korrektiv",
    "korrektivet": "korrektiv",
    "korrektivets": "korrektiv",
    "korrektivs": "korrektiv",
    "korrekts": "korrekt",
    "korrekturen": "korrektur",
    "korrekturens": "korrektur",
    "korrekturet": "korrektur",
    "korrekturets": "korrektur",
    "korrekturfelen": "korrekturfel",
    "korrekturfelens": "korrekturfel",
    "korrekturfelet": "korrekturfel",
    "korrekturfelets": "korrekturfel",
    "korrekturfels": "korrekturfel",
    "korrekturläs": "korrekturläsa",
    "korrekturläsande": "korrekturläsa",
    "korrekturläsanden": "korrekturläsande",
    "korrekturläsandena": "korrekturläsande",
    "korrekturläsandenas": "korrekturläsande",
    "korrekturläsandens": "korrekturläsande",
    "korrekturläsandes": "korrekturläsande",
    "korrekturläsandet": "korrekturläsande",
    "korrekturläsandets": "korrekturläsande",
    "korrekturläsas": "korrekturläsa",
    "korrekturläser": "korrekturläsa",
    "korrekturläses": "korrekturläsa",
    "korrekturläst": "korrekturläsa",
    "korrekturlästa": "korrekturläsa",
    "korrekturlästas": "korrekturläsa",
    "korrekturläste": "korrekturläsa",
    "korrekturlästes": "korrekturläsa",
    "korrekturlästs": "korrekturläsa",
    "korrekturs": "korrektur",
    "korrekturteckens": "korrekturtecken",
    "korrekturtecknen": "korrekturtecken",
    "korrekturtecknens": "korrekturtecken",
    "korrekturtecknet": "korrekturtecken",
    "korrekturtecknets": "korrekturtecken",
    "korrelaten": "korrelat",
    "korrelatens": "korrelat",
    "korrelatet": "korrelat",
    "korrelatets": "korrelat",
    "korrelationen": "korrelation",
    "korrelationens": "korrelation",
    "korrelationer": "korrelation",
    "korrelationerna": "korrelation",
    "korrelationernas": "korrelation",
    "korrelationers": "korrelation",
    "korrelations": "korrelation",
    "korrelats": "korrelat",
    "korrelerad": "korrelera",
    "korrelerade": "korrelera",
    "korrelerades": "korrelera",
    "korrelerads": "korrelera",
    "korrelerande": "korrelera",
    "korreleranden": "korrelerande",
    "korrelerandena": "korrelerande",
    "korrelerandenas": "korrelerande",
    "korrelerandens": "korrelerande",
    "korrelerandes": "korrelerande",
    "korrelerandet": "korrelerande",
    "korrelerandets": "korrelerande",
    "korrelerar": "korrelera",
    "korreleras": "korrelera",
    "korrelerat": "korrelera",
    "korrelerats": "korrelera",
    "korrelerbara": "korrelerbar",
    "korrelerbarare": "korrelerbar",
    "korrelerbarares": "korrelerbar",
    "korrelerbaras": "korrelerbar",
    "korrelerbarast": "korrelerbar",
    "korrelerbaraste": "korrelerbar",
    "korrelerbarastes": "korrelerbar",
    "korrelerbarasts": "korrelerbar",
    "korrelerbare": "korrelerbar",
    "korrelerbares": "korrelerbar",
    "korrelerbarheten": "korrelerbarhet",
    "korrelerbarhetens": "korrelerbarhet",
    "korrelerbarhets": "korrelerbarhet",
    "korrelerbars": "korrelerbar",
    "korrelerbart": "korrelerbar",
    "korrelerbarts": "korrelerbar",
    "korreleringar": "korrelering",
    "korreleringarna": "korrelering",
    "korreleringarnas": "korrelering",
    "korreleringars": "korrelering",
    "korreleringen": "korrelering",
    "korreleringens": "korrelering",
    "korrelerings": "korrelering",
    "korren": "korre",
    "korrens": "korre",
    "korres": "korre",
    "korrespondensen": "korrespondens",
    "korrespondensens": "korrespondens",
    "korrespondenser": "korrespondens",
    "korrespondenserna": "korrespondens",
    "korrespondensernas": "korrespondens",
    "korrespondensers": "korrespondens",
    "korrespondenskorten": "korrespondenskort",
    "korrespondenskortens": "korrespondenskort",
    "korrespondenskortet": "korrespondenskort",
    "korrespondenskortets": "korrespondenskort",
    "korrespondenskorts": "korrespondenskort",
    "korrespondenskursen": "korrespondenskurs",
    "korrespondenskursens": "korrespondenskurs",
    "korrespondenskurser": "korrespondenskurs",
    "korrespondenskurserna": "korrespondenskurs",
    "korrespondenskursernas": "korrespondenskurs",
    "korrespondenskursers": "korrespondenskurs",
    "korrespondensundervisningar": "korrespondensundervisning",
    "korrespondensundervisningarna": "korrespondensundervisning",
    "korrespondensundervisningarnas": "korrespondensundervisning",
    "korrespondensundervisningars": "korrespondensundervisning",
    "korrespondensundervisningen": "korrespondensundervisning",
    "korrespondensundervisningens": "korrespondensundervisning",
    "korrespondensundervisnings": "korrespondensundervisning",
    "korrespondenten": "korrespondent",
    "korrespondentens": "korrespondent",
    "korrespondenter": "korrespondent",
    "korrespondenterna": "korrespondent",
    "korrespondenternas": "korrespondent",
    "korrespondenters": "korrespondent",
    "korrespondents": "korrespondent",
    "korresponderade": "korrespondera",
    "korresponderades": "korrespondera",
    "korresponderande": "korrespondera",
    "korresponderanden": "korresponderande",
    "korresponderandena": "korresponderande",
    "korresponderandenas": "korresponderande",
    "korresponderandens": "korresponderande",
    "korresponderandes": "korresponderande",
    "korresponderandet": "korresponderande",
    "korresponderandets": "korresponderande",
    "korresponderar": "korrespondera",
    "korresponderas": "korrespondera",
    "korresponderat": "korrespondera",
    "korresponderats": "korrespondera",
    "korresponderingar": "korrespondering",
    "korresponderingarna": "korrespondering",
    "korresponderingarnas": "korrespondering",
    "korresponderingars": "korrespondering",
    "korresponderingen": "korrespondering",
    "korresponderingens": "korrespondering",
    "korresponderings": "korrespondering",
    "korret": "korr",
    "korrets": "korr",
    "korridoren": "korridor",
    "korridorens": "korridor",
    "korridorer": "korridor",
    "korridorerna": "korridor",
    "korridorernas": "korridor",
    "korridorers": "korridor",
    "korridorpolitiken": "korridorpolitik",
    "korridorpolitikens": "korridorpolitik",
    "korridorpolitiks": "korridorpolitik",
    "korridors": "korridor",
    "korridorsystemen": "korridorsystem",
    "korridorsystemens": "korridorsystem",
    "korridorsystemet": "korridorsystem",
    "korridorsystemets": "korridorsystem",
    "korridorsystems": "korridorsystem",
    "korrigerad": "korrigera",
    "korrigerade": "korrigera",
    "korrigerades": "korrigera",
    "korrigerads": "korrigera",
    "korrigerande": "korrigera",
    "korrigeranden": "korrigerande",
    "korrigerandena": "korrigerande",
    "korrigerandenas": "korrigerande",
    "korrigerandens": "korrigerande",
    "korrigerandes": "korrigerande",
    "korrigerandet": "korrigerande",
    "korrigerandets": "korrigerande",
    "korrigerar": "korrigera",
    "korrigeras": "korrigera",
    "korrigerat": "korrigera",
    "korrigerats": "korrigera",
    "korrigerbara": "korrigerbar",
    "korrigerbarare": "korrigerbar",
    "korrigerbarares": "korrigerbar",
    "korrigerbaras": "korrigerbar",
    "korrigerbarast": "korrigerbar",
    "korrigerbaraste": "korrigerbar",
    "korrigerbarastes": "korrigerbar",
    "korrigerbarasts": "korrigerbar",
    "korrigerbare": "korrigerbar",
    "korrigerbares": "korrigerbar",
    "korrigerbarheten": "korrigerbarhet",
    "korrigerbarhetens": "korrigerbarhet",
    "korrigerbarhets": "korrigerbarhet",
    "korrigerbars": "korrigerbar",
    "korrigerbart": "korrigerbar",
    "korrigerbarts": "korrigerbar",
    "korrigeringar": "korrigering",
    "korrigeringarna": "korrigering",
    "korrigeringarnas": "korrigering",
    "korrigeringars": "korrigering",
    "korrigeringen": "korrigering",
    "korrigeringens": "korrigering",
    "korrigerings": "korrigering",
    "korroderad": "korrodera",
    "korroderade": "korrodera",
    "korroderades": "korrodera",
    "korroderads": "korrodera",
    "korroderande": "korrodera",
    "korroderanden": "korroderande",
    "korroderandena": "korroderande",
    "korroderandenas": "korroderande",
    "korroderandens": "korroderande",
    "korroderandes": "korroderande",
    "korroderandet": "korroderande",
    "korroderandets": "korroderande",
    "korroderar": "korrodera",
    "korroderas": "korrodera",
    "korroderat": "korrodera",
    "korroderats": "korrodera",
    "korroderbara": "korroderbar",
    "korroderbarare": "korroderbar",
    "korroderbarares": "korroderbar",
    "korroderbaras": "korroderbar",
    "korroderbarast": "korroderbar",
    "korroderbaraste": "korroderbar",
    "korroderbarastes": "korroderbar",
    "korroderbarasts": "korroderbar",
    "korroderbare": "korroderbar",
    "korroderbares": "korroderbar",
    "korroderbarheten": "korroderbarhet",
    "korroderbarhetens": "korroderbarhet",
    "korroderbarhets": "korroderbarhet",
    "korroderbars": "korroderbar",
    "korroderbart": "korroderbar",
    "korroderbarts": "korroderbar",
    "korroderingar": "korrodering",
    "korroderingarna": "korrodering",
    "korroderingarnas": "korrodering",
    "korroderingars": "korrodering",
    "korroderingen": "korrodering",
    "korroderingens": "korrodering",
    "korroderings": "korrodering",
    "korrosionen": "korrosion",
    "korrosionens": "korrosion",
    "korrosioner": "korrosion",
    "korrosionerna": "korrosion",
    "korrosionernas": "korrosion",
    "korrosioners": "korrosion",
    "korrosions": "korrosion",
    "korrosionsinhibitorer": "korrosionsinhibitor",
    "korrosionsinhibitorerna": "korrosionsinhibitor",
    "korrosionsinhibitorernas": "korrosionsinhibitor",
    "korrosionsinhibitorers": "korrosionsinhibitor",
    "korrosionsinhibitorn": "korrosionsinhibitor",
    "korrosionsinhibitorns": "korrosionsinhibitor",
    "korrosionsinhibitors": "korrosionsinhibitor",
    "korrosionsskydden": "korrosionsskydd",
    "korrosionsskyddens": "korrosionsskydd",
    "korrosionsskyddet": "korrosionsskydd",
    "korrosionsskyddets": "korrosionsskydd",
    "korrosionsskydds": "korrosionsskydd",
    "korrs": "korr",
    "korrugerad": "korrugera",
    "korrugerade": "korrugera",
    "korrugerades": "korrugera",
    "korrugerads": "korrugera",
    "korrugerande": "korrugera",
    "korrugeranden": "korrugerande",
    "korrugerandena": "korrugerande",
    "korrugerandenas": "korrugerande",
    "korrugerandens": "korrugerande",
    "korrugerandes": "korrugerande",
    "korrugerandet": "korrugerande",
    "korrugerandets": "korrugerande",
    "korrugerar": "korrugera",
    "korrugeras": "korrugera",
    "korrugerat": "korrugera",
    "korrugerats": "korrugera",
    "korrugerbara": "korrugerbar",
    "korrugerbarare": "korrugerbar",
    "korrugerbarares": "korrugerbar",
    "korrugerbaras": "korrugerbar",
    "korrugerbarast": "korrugerbar",
    "korrugerbaraste": "korrugerbar",
    "korrugerbarastes": "korrugerbar",
    "korrugerbarasts": "korrugerbar",
    "korrugerbare": "korrugerbar",
    "korrugerbares": "korrugerbar",
    "korrugerbarheten": "korrugerbarhet",
    "korrugerbarhetens": "korrugerbarhet",
    "korrugerbarhets": "korrugerbarhet",
    "korrugerbars": "korrugerbar",
    "korrugerbart": "korrugerbar",
    "korrugerbarts": "korrugerbar",
    "korrugeringar": "korrugering",
    "korrugeringarna": "korrugering",
    "korrugeringarnas": "korrugering",
    "korrugeringars": "korrugering",
    "korrugeringen": "korrugering",
    "korrugeringens": "korrugering",
    "korrugerings": "korrugering",
    "korrumperad": "korrumpera",
    "korrumperade": "korrumpera",
    "korrumperades": "korrumpera",
    "korrumperads": "korrumpera",
    "korrumperande": "korrumpera",
    "korrumperanden": "korrumperande",
    "korrumperandena": "korrumperande",
    "korrumperandenas": "korrumperande",
    "korrumperandens": "korrumperande",
    "korrumperandes": "korrumperande",
    "korrumperandet": "korrumperande",
    "korrumperandets": "korrumperande",
    "korrumperar": "korrumpera",
    "korrumperas": "korrumpera",
    "korrumperat": "korrumpera",
    "korrumperats": "korrumpera",
    "korrumperbara": "korrumperbar",
    "korrumperbarare": "korrumperbar",
    "korrumperbarares": "korrumperbar",
    "korrumperbaras": "korrumperbar",
    "korrumperbarast": "korrumperbar",
    "korrumperbaraste": "korrumperbar",
    "korrumperbarastes": "korrumperbar",
    "korrumperbarasts": "korrumperbar",
    "korrumperbare": "korrumperbar",
    "korrumperbares": "korrumperbar",
    "korrumperbarheten": "korrumperbarhet",
    "korrumperbarhetens": "korrumperbarhet",
    "korrumperbarhets": "korrumperbarhet",
    "korrumperbars": "korrumperbar",
    "korrumperbart": "korrumperbar",
    "korrumperbarts": "korrumperbar",
    "korrumperingar": "korrumpering",
    "korrumperingarna": "korrumpering",
    "korrumperingarnas": "korrumpering",
    "korrumperingars": "korrumpering",
    "korrumperingen": "korrumpering",
    "korrumperingens": "korrumpering",
    "korrumperings": "korrumpering",
    "korrupta": "korrupt",
    "korruptare": "korrupt",
    "korruptares": "korrupt",
    "korruptas": "korrupt",
    "korruptast": "korrupt",
    "korruptaste": "korrupt",
    "korruptastes": "korrupt",
    "korruptasts": "korrupt",
    "korrupte": "korrupt",
    "korruptes": "korrupt",
    "korruptheten": "korrupthet",
    "korrupthetens": "korrupthet",
    "korrupthets": "korrupthet",
    "korruptionen": "korruption",
    "korruptionens": "korruption",
    "korruptioner": "korruption",
    "korruptionerna": "korruption",
    "korruptionernas": "korruption",
    "korruptioners": "korruption",
    "korruptions": "korruption",
    "korruptionsanklagade": "korruptionsanklagad",
    "korruptionsanklagades": "korruptionsanklagad",
    "korruptionsanklagads": "korruptionsanklagad",
    "korruptionsanklagat": "korruptionsanklagad",
    "korruptionsanklagats": "korruptionsanklagad",
    "korruptionsbekämpningen": "korruptionsbekämpning",
    "korruptionsbekämpningens": "korruptionsbekämpning",
    "korruptionsbekämpnings": "korruptionsbekämpning",
    "korruptionshärvan": "korruptionshärva",
    "korruptionshärvans": "korruptionshärva",
    "korruptionshärvas": "korruptionshärva",
    "korruptionshärve": "korruptionshärva",
    "korruptionshärvor": "korruptionshärva",
    "korruptionshärvorna": "korruptionshärva",
    "korruptionshärvornas": "korruptionshärva",
    "korruptionshärvors": "korruptionshärva",
    "korruptionsnivåer": "korruptionsnivå",
    "korruptionsnivåerna": "korruptionsnivå",
    "korruptionsnivåernas": "korruptionsnivå",
    "korruptionsnivåers": "korruptionsnivå",
    "korruptionsnivån": "korruptionsnivå",
    "korruptionsnivåns": "korruptionsnivå",
    "korruptionsnivås": "korruptionsnivå",
    "korruptionsrättegångar": "korruptionsrättegång",
    "korruptionsrättegångarna": "korruptionsrättegång",
    "korruptionsrättegångarnas": "korruptionsrättegång",
    "korruptionsrättegångars": "korruptionsrättegång",
    "korruptionsrättegången": "korruptionsrättegång",
    "korruptionsrättegångens": "korruptionsrättegång",
    "korruptionsrättegångs": "korruptionsrättegång",
    "korruptionsskandalen": "korruptionsskandal",
    "korruptionsskandalens": "korruptionsskandal",
    "korruptionsskandaler": "korruptionsskandal",
    "korruptionsskandalerna": "korruptionsskandal",
    "korruptionsskandalernas": "korruptionsskandal",
    "korruptionsskandalers": "korruptionsskandal",
    "korruptionsskandals": "korruptionsskandal",
    "korruptionsåtalen": "korruptionsåtal",
    "korruptionsåtalens": "korruptionsåtal",
    "korruptionsåtalet": "korruptionsåtal",
    "korruptionsåtalets": "korruptionsåtal",
    "korruptionsåtals": "korruptionsåtal",
    "korrupts": "korrupt",
    "kors": "korsa",
    "korsad": "korsa",
    "korsade": "korsa",
    "korsades": "korsa",
    "korsads": "korsa",
    "korsande": "korsa",
    "korsanden": "korsande",
    "korsandena": "korsande",
    "korsandenas": "korsande",
    "korsandens": "korsande",
    "korsandes": "korsande",
    "korsandet": "korsande",
    "korsandets": "korsande",
    "korsar": "korsa",
    "korsaren": "korsar",
    "korsarens": "korsar",
    "korsarer": "korsar",
    "korsarerna": "korsar",
    "korsarernas": "korsar",
    "korsarers": "korsar",
    "korsars": "korsar",
    "korsas": "korsa",
    "korsat": "korsa",
    "korsats": "korsa",
    "korsbanden": "korsband",
    "korsbandens": "korsband",
    "korsbandet": "korsband",
    "korsbandets": "korsband",
    "korsbands": "korsband",
    "korsbefrukt": "korsbefrukta",
    "korsbefruktad": "korsbefrukta",
    "korsbefruktade": "korsbefrukta",
    "korsbefruktades": "korsbefrukta",
    "korsbefruktads": "korsbefrukta",
    "korsbefruktande": "korsbefrukta",
    "korsbefruktanden": "korsbefruktande",
    "korsbefruktandena": "korsbefruktande",
    "korsbefruktandenas": "korsbefruktande",
    "korsbefruktandens": "korsbefruktande",
    "korsbefruktandes": "korsbefruktande",
    "korsbefruktandet": "korsbefruktande",
    "korsbefruktandets": "korsbefruktande",
    "korsbefruktar": "korsbefrukta",
    "korsbefruktas": "korsbefrukta",
    "korsbefruktat": "korsbefrukta",
    "korsbefruktats": "korsbefrukta",
    "korsbefruktningar": "korsbefruktning",
    "korsbefruktningarna": "korsbefruktning",
    "korsbefruktningarnas": "korsbefruktning",
    "korsbefruktningars": "korsbefruktning",
    "korsbefruktningen": "korsbefruktning",
    "korsbefruktningens": "korsbefruktning",
    "korsbefruktnings": "korsbefruktning",
    "korsbenen": "korsben",
    "korsbenens": "korsben",
    "korsbenet": "korsben",
    "korsbenets": "korsben",
    "korsbens": "korsben",
    "korsblommiga": "korsblommig",
    "korsblommigare": "korsblommig",
    "korsblommigares": "korsblommig",
    "korsblommigas": "korsblommig",
    "korsblommigast": "korsblommig",
    "korsblommigaste": "korsblommig",
    "korsblommigastes": "korsblommig",
    "korsblommigasts": "korsblommig",
    "korsblommige": "korsblommig",
    "korsblommiges": "korsblommig",
    "korsblommigs": "korsblommig",
    "korsblommigt": "korsblommig",
    "korsblommigts": "korsblommig",
    "korsdraget": "korsdrag",
    "korsdragets": "korsdrag",
    "korsdrags": "korsdrag",
    "korseldar": "korseld",
    "korseldarna": "korseld",
    "korseldarnas": "korseld",
    "korseldars": "korseld",
    "korselden": "korseld",
    "korseldens": "korseld",
    "korselds": "korseld",
    "korseletten": "korselett",
    "korselettens": "korselett",
    "korseletter": "korselett",
    "korseletterna": "korselett",
    "korseletternas": "korselett",
    "korseletters": "korselett",
    "korseletts": "korselett",
    "korsen": "kors",
    "korsens": "kors",
    "korset": "kors",
    "korsets": "kors",
    "korsetten": "korsett",
    "korsettens": "korsett",
    "korsetter": "korsett",
    "korsetterad": "korsettera",
    "korsetterade": "korsettera",
    "korsetterades": "korsettera",
    "korsetterads": "korsettera",
    "korsetterande": "korsettera",
    "korsetteranden": "korsetterande",
    "korsetterandena": "korsetterande",
    "korsetterandenas": "korsetterande",
    "korsetterandens": "korsetterande",
    "korsetterandes": "korsetterande",
    "korsetterandet": "korsetterande",
    "korsetterandets": "korsetterande",
    "korsetterar": "korsettera",
    "korsetteras": "korsettera",
    "korsetterat": "korsettera",
    "korsetterats": "korsettera",
    "korsetterbara": "korsetterbar",
    "korsetterbarare": "korsetterbar",
    "korsetterbarares": "korsetterbar",
    "korsetterbaras": "korsetterbar",
    "korsetterbarast": "korsetterbar",
    "korsetterbaraste": "korsetterbar",
    "korsetterbarastes": "korsetterbar",
    "korsetterbarasts": "korsetterbar",
    "korsetterbare": "korsetterbar",
    "korsetterbares": "korsetterbar",
    "korsetterbarheten": "korsetterbarhet",
    "korsetterbarhetens": "korsetterbarhet",
    "korsetterbarhets": "korsetterbarhet",
    "korsetterbars": "korsetterbar",
    "korsetterbart": "korsetterbar",
    "korsetterbarts": "korsetterbar",
    "korsetteringar": "korsettering",
    "korsetteringarna": "korsettering",
    "korsetteringarnas": "korsettering",
    "korsetteringars": "korsettering",
    "korsetteringen": "korsettering",
    "korsetteringens": "korsettering",
    "korsetterings": "korsettering",
    "korsetterna": "korsett",
    "korsetternas": "korsett",
    "korsetters": "korsett",
    "korsettfjädern": "korsettfjäder",
    "korsettfjäderns": "korsettfjäder",
    "korsettfjäders": "korsettfjäder",
    "korsettfjädrar": "korsettfjäder",
    "korsettfjädrarna": "korsettfjäder",
    "korsettfjädrarnas": "korsettfjäder",
    "korsettfjädrars": "korsettfjäder",
    "korsetts": "korsett",
    "korsfarar": "korsfarare",
    "korsfarararméer": "korsfarararmé",
    "korsfarararméerna": "korsfarararmé",
    "korsfarararméernas": "korsfarararmé",
    "korsfarararméers": "korsfarararmé",
    "korsfarararmén": "korsfarararmé",
    "korsfarararméns": "korsfarararmé",
    "korsfarararmés": "korsfarararmé",
    "korsfararen": "korsfarare",
    "korsfararens": "korsfarare",
    "korsfarares": "korsfarare",
    "korsfararna": "korsfarare",
    "korsfararnas": "korsfarare",
    "korsfararstaten": "korsfararstat",
    "korsfararstatens": "korsfararstat",
    "korsfararstater": "korsfararstat",
    "korsfararstaterna": "korsfararstat",
    "korsfararstaternas": "korsfararstat",
    "korsfararstaters": "korsfararstat",
    "korsfararstats": "korsfararstat",
    "korsfäst": "korsfästa",
    "korsfästande": "korsfästa",
    "korsfästanden": "korsfästande",
    "korsfästandena": "korsfästande",
    "korsfästandenas": "korsfästande",
    "korsfästandens": "korsfästande",
    "korsfästandes": "korsfästande",
    "korsfästandet": "korsfästande",
    "korsfästandets": "korsfästande",
    "korsfästas": "korsfästa",
    "korsfäste": "korsfästa",
    "korsfästelsen": "korsfästelse",
    "korsfästelsens": "korsfästelse",
    "korsfästelser": "korsfästelse",
    "korsfästelserna": "korsfästelse",
    "korsfästelsernas": "korsfästelse",
    "korsfästelsers": "korsfästelse",
    "korsfästelses": "korsfästelse",
    "korsfäster": "korsfästa",
    "korsfästes": "korsfästa",
    "korsfästs": "korsfästa",
    "korsförhör": "korsförhöra",
    "korsförhörande": "korsförhöra",
    "korsförhöranden": "korsförhörande",
    "korsförhörandena": "korsförhörande",
    "korsförhörandenas": "korsförhörande",
    "korsförhörandens": "korsförhörande",
    "korsförhörandes": "korsförhörande",
    "korsförhörandet": "korsförhörande",
    "korsförhörandets": "korsförhörande",
    "korsförhöras": "korsförhöra",
    "korsförhörd": "korsförhöra",
    "korsförhörda": "korsförhöra",
    "korsförhördas": "korsförhöra",
    "korsförhörde": "korsförhöra",
    "korsförhördes": "korsförhöra",
    "korsförhörds": "korsförhöra",
    "korsförhören": "korsförhör",
    "korsförhörens": "korsförhör",
    "korsförhöres": "korsförhöra",
    "korsförhöret": "korsförhör",
    "korsförhörets": "korsförhör",
    "korsförhörs": "korsförhöra",
    "korsförhört": "korsförhöra",
    "korsförhörts": "korsförhöra",
    "korsgångar": "korsgång",
    "korsgångarna": "korsgång",
    "korsgångarnas": "korsgång",
    "korsgångars": "korsgång",
    "korsgången": "korsgång",
    "korsgångens": "korsgång",
    "korsgångs": "korsgång",
    "korshänvisningar": "korshänvisning",
    "korshänvisningarna": "korshänvisning",
    "korshänvisningarnas": "korshänvisning",
    "korshänvisningars": "korshänvisning",
    "korshänvisningen": "korshänvisning",
    "korshänvisningens": "korshänvisning",
    "korshänvisnings": "korshänvisning",
    "korsikanar": "korsikanare",
    "korsikanaren": "korsikanare",
    "korsikanarens": "korsikanare",
    "korsikanares": "korsikanare",
    "korsikanarna": "korsikanare",
    "korsikanarnas": "korsikanare",
    "korsikanen": "korsikan",
    "korsikanens": "korsikan",
    "korsikaner": "korsikan",
    "korsikanerna": "korsikan",
    "korsikanernas": "korsikan",
    "korsikaners": "korsikan",
    "korsikans": "korsikan",
    "korsikansk": "korsikanska",
    "korsikanska": "korsikansk",
    "korsikanskan": "korsikanska",
    "korsikanskans": "korsikanska",
    "korsikanskare": "korsikansk",
    "korsikanskares": "korsikansk",
    "korsikanskas": "korsikanska",
    "korsikanskast": "korsikansk",
    "korsikanskaste": "korsikansk",
    "korsikanskastes": "korsikansk",
    "korsikanskasts": "korsikansk",
    "korsikanske": "korsikanska",
    "korsikanskes": "korsikansk",
    "korsikanskor": "korsikanska",
    "korsikanskorna": "korsikanska",
    "korsikanskornas": "korsikanska",
    "korsikanskors": "korsikanska",
    "korsikansks": "korsikansk",
    "korsikanskt": "korsikansk",
    "korsikanskts": "korsikansk",
    "korskot": "korskota",
    "korskotan": "korskota",
    "korskotans": "korskota",
    "korskotas": "korskota",
    "korskote": "korskota",
    "korskotor": "korskota",
    "korskotorna": "korskota",
    "korskotornas": "korskota",
    "korskotors": "korskota",
    "korskots": "korskota",
    "korskranken": "korskrank",
    "korskrankens": "korskrank",
    "korskranket": "korskrank",
    "korskrankets": "korskrank",
    "korskranks": "korskrank",
    "korskyrk": "korskyrka",
    "korskyrkan": "korskyrka",
    "korskyrkans": "korskyrka",
    "korskyrkas": "korskyrka",
    "korskyrke": "korskyrka",
    "korskyrko": "korskyrka",
    "korskyrkor": "korskyrka",
    "korskyrkorna": "korskyrka",
    "korskyrkornas": "korskyrka",
    "korskyrkors": "korskyrka",
    "korskyrks": "korskyrka",
    "korsla": "korslägga",
    "korslade": "korslägga",
    "korslades": "korslägga",
    "korslagd": "korslägga",
    "korslagda": "korslägga",
    "korslagdas": "korslägga",
    "korslagde": "korslägga",
    "korslagdes": "korslägga",
    "korslagds": "korslägga",
    "korslagt": "korslägga",
    "korslagts": "korslägga",
    "korslas": "korslägga",
    "korslägg": "korslägga",
    "korsläggande": "korslägga",
    "korsläggandes": "korslägga",
    "korsläggas": "korslägga",
    "korslägger": "korslägga",
    "korslägges": "korslägga",
    "korsläggs": "korslägga",
    "korsningar": "korsning",
    "korsningarna": "korsning",
    "korsningarnas": "korsning",
    "korsningars": "korsning",
    "korsningen": "korsning",
    "korsningens": "korsning",
    "korsnings": "korsning",
    "korsnäbbar": "korsnäbb",
    "korsnäbbarna": "korsnäbb",
    "korsnäbbarnas": "korsnäbb",
    "korsnäbbars": "korsnäbb",
    "korsnäbben": "korsnäbb",
    "korsnäbbens": "korsnäbb",
    "korsnäbbs": "korsnäbb",
    "korsoer": "korso",
    "korsoerna": "korso",
    "korsoernas": "korso",
    "korsoers": "korso",
    "korson": "korso",
    "korsons": "korso",
    "korsor": "korso",
    "korsorden": "korsord",
    "korsordens": "korsord",
    "korsordet": "korsord",
    "korsordets": "korsord",
    "korsords": "korsord",
    "korsordskonstruktören": "korsordskonstruktör",
    "korsordskonstruktörens": "korsordskonstruktör",
    "korsordskonstruktörer": "korsordskonstruktör",
    "korsordskonstruktörerna": "korsordskonstruktör",
    "korsordskonstruktörernas": "korsordskonstruktör",
    "korsordskonstruktörers": "korsordskonstruktör",
    "korsordskonstruktörs": "korsordskonstruktör",
    "korsordsmässiga": "korsordsmässig",
    "korsordsmässigare": "korsordsmässig",
    "korsordsmässigares": "korsordsmässig",
    "korsordsmässigas": "korsordsmässig",
    "korsordsmässigast": "korsordsmässig",
    "korsordsmässigaste": "korsordsmässig",
    "korsordsmässigastes": "korsordsmässig",
    "korsordsmässigasts": "korsordsmässig",
    "korsordsmässige": "korsordsmässig",
    "korsordsmässiges": "korsordsmässig",
    "korsordsmässigs": "korsordsmässig",
    "korsordsmässigt": "korsordsmässig",
    "korsordsmässigts": "korsordsmässig",
    "korsordstidningar": "korsordstidning",
    "korsordstidningarna": "korsordstidning",
    "korsordstidningarnas": "korsordstidning",
    "korsordstidningars": "korsordstidning",
    "korsordstidningen": "korsordstidning",
    "korsordstidningens": "korsordstidning",
    "korsordstidnings": "korsordstidning",
    "korsorna": "korso",
    "korsornas": "korso",
    "korsors": "korso",
    "korsos": "korso",
    "korspollinationen": "korspollination",
    "korspollinationens": "korspollination",
    "korspollinationer": "korspollination",
    "korspollinationerna": "korspollination",
    "korspollinationernas": "korspollination",
    "korspollinationers": "korspollination",
    "korspollinations": "korspollination",
    "korsreferensen": "korsreferens",
    "korsreferensens": "korsreferens",
    "korsreferenser": "korsreferens",
    "korsreferenserna": "korsreferens",
    "korsreferensernas": "korsreferens",
    "korsreferensers": "korsreferens",
    "korsriddar": "korsriddare",
    "korsriddaren": "korsriddare",
    "korsriddarens": "korsriddare",
    "korsriddares": "korsriddare",
    "korsriddarna": "korsriddare",
    "korsriddarnas": "korsriddare",
    "korsryggar": "korsrygg",
    "korsryggarna": "korsrygg",
    "korsryggarnas": "korsrygg",
    "korsryggars": "korsrygg",
    "korsryggen": "korsrygg",
    "korsryggens": "korsrygg",
    "korsryggs": "korsrygg",
    "korsspindeln": "korsspindel",
    "korsspindelns": "korsspindel",
    "korsspindels": "korsspindel",
    "korsspindlar": "korsspindel",
    "korsspindlarna": "korsspindel",
    "korsspindlarnas": "korsspindel",
    "korsspindlars": "korsspindel",
    "korsstygnen": "korsstygn",
    "korsstygnens": "korsstygn",
    "korsstygnet": "korsstygn",
    "korsstygnets": "korsstygn",
    "korsstygns": "korsstygn",
    "korsteckens": "korstecken",
    "korstecknen": "korstecken",
    "korstecknens": "korstecken",
    "korstecknet": "korstecken",
    "korstecknets": "korstecken",
    "korstågen": "korståg",
    "korstågens": "korståg",
    "korståget": "korståg",
    "korstågets": "korståg",
    "korstågs": "korståg",
    "korstågskrönikören": "korstågskrönikör",
    "korstågskrönikörens": "korstågskrönikör",
    "korstågskrönikörer": "korstågskrönikör",
    "korstågskrönikörerna": "korstågskrönikör",
    "korstågskrönikörernas": "korstågskrönikör",
    "korstågskrönikörers": "korstågskrönikör",
    "korstågskrönikörs": "korstågskrönikör",
    "korsvalven": "korsvalv",
    "korsvalvens": "korsvalv",
    "korsvalvet": "korsvalv",
    "korsvalvets": "korsvalv",
    "korsvalvs": "korsvalv",
    "korsvirkeshusen": "korsvirkeshus",
    "korsvirkeshusens": "korsvirkeshus",
    "korsvirkeshuset": "korsvirkeshus",
    "korsvirkeshusets": "korsvirkeshus",
    "korsvisa": "korsvis",
    "korsvisar": "korsvisare",
    "korsvisaren": "korsvisare",
    "korsvisarens": "korsvisare",
    "korsvisares": "korsvisare",
    "korsvisarna": "korsvisare",
    "korsvisarnas": "korsvisare",
    "korsvisas": "korsvis",
    "korsvise": "korsvis",
    "korsvises": "korsvis",
    "korsvist": "korsvis",
    "korsvists": "korsvis",
    "korsvägar": "korsväg",
    "korsvägarna": "korsväg",
    "korsvägarnas": "korsväg",
    "korsvägars": "korsväg",
    "korsvägen": "korsväg",
    "korsvägens": "korsväg",
    "korsvägs": "korsväg",
    "korsägandes": "korsägande",
    "korsägandet": "korsägande",
    "korsägandets": "korsägande",
    "kort": "korta",
    "korta": "kort",
    "kortad": "korta",
    "kortade": "korta",
    "kortades": "korta",
    "kortads": "korta",
    "kortande": "korta",
    "kortanden": "kortande",
    "kortandena": "kortande",
    "kortandenas": "kortande",
    "kortandens": "kortande",
    "kortandes": "kortande",
    "kortandet": "kortande",
    "kortandets": "kortande",
    "kortar": "korta",
    "kortare": "kort",
    "kortares": "kort",
    "kortas": "korta",
    "kortast": "kort",
    "kortaste": "kort",
    "kortastes": "kort",
    "kortasts": "kort",
    "kortat": "korta",
    "kortats": "korta",
    "kortbedrägerier": "kortbedrägeri",
    "kortbedrägerierna": "kortbedrägeri",
    "kortbedrägeriernas": "kortbedrägeri",
    "kortbedrägeriers": "kortbedrägeri",
    "kortbedrägeriet": "kortbedrägeri",
    "kortbedrägeriets": "kortbedrägeri",
    "kortbedrägeris": "kortbedrägeri",
    "kortbedrägerit": "kortbedrägeri",
    "kortbedrägerits": "kortbedrägeri",
    "kortbenta": "kortbent",
    "kortbentare": "kortbent",
    "kortbentares": "kortbent",
    "kortbentas": "kortbent",
    "kortbentast": "kortbent",
    "kortbentaste": "kortbent",
    "kortbentastes": "kortbent",
    "kortbentasts": "kortbent",
    "kortbente": "kortbent",
    "kortbentes": "kortbent",
    "kortbentheten": "kortbenthet",
    "kortbenthetens": "kortbenthet",
    "kortbenthets": "kortbenthet",
    "kortbents": "kortbent",
    "kortbyx": "kortbyxa",
    "kortbyxan": "kortbyxa",
    "kortbyxans": "kortbyxa",
    "kortbyxas": "kortbyxa",
    "kortbyxe": "kortbyxa",
    "kortbyxor": "kortbyxa",
    "kortbyxorna": "kortbyxa",
    "kortbyxornas": "kortbyxa",
    "kortbyxors": "kortbyxa",
    "kortdistansen": "kortdistans",
    "kortdistansens": "kortdistans",
    "kortdistanser": "kortdistans",
    "kortdistanserna": "kortdistans",
    "kortdistansernas": "kortdistans",
    "kortdistansers": "kortdistans",
    "kortdistanslöpar": "kortdistanslöpare",
    "kortdistanslöparen": "kortdistanslöpare",
    "kortdistanslöparens": "kortdistanslöpare",
    "kortdistanslöpares": "kortdistanslöpare",
    "kortdistanslöparna": "kortdistanslöpare",
    "kortdistanslöparnas": "kortdistanslöpare",
    "korte": "kort",
    "kortegen": "kortege",
    "kortegens": "kortege",
    "korteger": "kortege",
    "kortegerna": "kortege",
    "kortegernas": "kortege",
    "kortegers": "kortege",
    "korteges": "kortege",
    "kortegevägar": "kortegeväg",
    "kortegevägarna": "kortegeväg",
    "kortegevägarnas": "kortegeväg",
    "kortegevägars": "kortegeväg",
    "kortegevägen": "kortegeväg",
    "kortegevägens": "kortegeväg",
    "kortegevägs": "kortegeväg",
    "korten": "kort",
    "kortens": "kort",
    "kortes": "kort",
    "kortet": "kort",
    "kortets": "kort",
    "kortfattade": "kortfattad",
    "kortfattades": "kortfattad",
    "kortfattads": "kortfattad",
    "kortfattat": "kortfattad",
    "kortfattats": "kortfattad",
    "kortfilmen": "kortfilm",
    "kortfilmens": "kortfilm",
    "kortfilmer": "kortfilm",
    "kortfilmerna": "kortfilm",
    "kortfilmernas": "kortfilm",
    "kortfilmers": "kortfilm",
    "kortfilms": "kortfilm",
    "kortformen": "kortform",
    "kortformens": "kortform",
    "kortformer": "kortform",
    "kortformerna": "kortform",
    "kortformernas": "kortform",
    "kortformers": "kortform",
    "kortforms": "kortform",
    "kortfristiga": "kortfristig",
    "kortfristigare": "kortfristig",
    "kortfristigares": "kortfristig",
    "kortfristigas": "kortfristig",
    "kortfristigast": "kortfristig",
    "kortfristigaste": "kortfristig",
    "kortfristigastes": "kortfristig",
    "kortfristigasts": "kortfristig",
    "kortfristige": "kortfristig",
    "kortfristiges": "kortfristig",
    "kortfristigheten": "kortfristighet",
    "kortfristighetens": "kortfristighet",
    "kortfristighets": "kortfristighet",
    "kortfristigs": "kortfristig",
    "kortfristigt": "kortfristig",
    "kortfristigts": "kortfristig",
    "kortheten": "korthet",
    "korthetens": "korthet",
    "kortheter": "korthet",
    "kortheterna": "korthet",
    "kortheternas": "korthet",
    "kortheters": "korthet",
    "korthets": "korthet",
    "korthuggenheten": "korthuggenhet",
    "korthuggenhetens": "korthuggenhet",
    "korthuggenhets": "korthuggenhet",
    "korthuggens": "korthuggen",
    "korthugget": "korthuggen",
    "korthuggets": "korthuggen",
    "korthuggna": "korthuggen",
    "korthuggnare": "korthuggen",
    "korthuggnares": "korthuggen",
    "korthuggnas": "korthuggen",
    "korthuggnast": "korthuggen",
    "korthuggnaste": "korthuggen",
    "korthuggnastes": "korthuggen",
    "korthuggnasts": "korthuggen",
    "korthuggne": "korthuggen",
    "korthuggnes": "korthuggen",
    "korthusen": "korthus",
    "korthusens": "korthus",
    "korthuset": "korthus",
    "korthusets": "korthus",
    "kortisonbehandlingar": "kortisonbehandling",
    "kortisonbehandlingarna": "kortisonbehandling",
    "kortisonbehandlingarnas": "kortisonbehandling",
    "kortisonbehandlingars": "kortisonbehandling",
    "kortisonbehandlingen": "kortisonbehandling",
    "kortisonbehandlingens": "kortisonbehandling",
    "kortisonbehandlings": "kortisonbehandling",
    "kortisonen": "kortison",
    "kortisonens": "kortison",
    "kortisoner": "kortison",
    "kortisonerna": "kortison",
    "kortisonernas": "kortison",
    "kortisoners": "kortison",
    "kortisonet": "kortison",
    "kortisonets": "kortison",
    "kortisons": "kortison",
    "kortkatalogen": "kortkatalog",
    "kortkatalogens": "kortkatalog",
    "kortkataloger": "kortkatalog",
    "kortkatalogerna": "kortkatalog",
    "kortkatalogernas": "kortkatalog",
    "kortkatalogers": "kortkatalog",
    "kortkatalogs": "kortkatalog",
    "kortklippta": "kortklippt",
    "kortklipptare": "kortklippt",
    "kortklipptares": "kortklippt",
    "kortklipptas": "kortklippt",
    "kortklipptast": "kortklippt",
    "kortklipptaste": "kortklippt",
    "kortklipptastes": "kortklippt",
    "kortklipptasts": "kortklippt",
    "kortklippte": "kortklippt",
    "kortklipptes": "kortklippt",
    "kortklipptheten": "kortklippthet",
    "kortklippthetens": "kortklippthet",
    "kortklippthets": "kortklippthet",
    "kortklippts": "kortklippt",
    "kortkonsten": "kortkonst",
    "kortkonstens": "kortkonst",
    "kortkonster": "kortkonst",
    "kortkonsterna": "kortkonst",
    "kortkonsternas": "kortkonst",
    "kortkonsters": "kortkonst",
    "kortkonsts": "kortkonst",
    "kortkorta": "kortkort",
    "kortkortare": "kortkort",
    "kortkortares": "kortkort",
    "kortkortas": "kortkort",
    "kortkortast": "kortkort",
    "kortkortaste": "kortkort",
    "kortkortastes": "kortkort",
    "kortkortasts": "kortkort",
    "kortkorte": "kortkort",
    "kortkortes": "kortkort",
    "kortkorts": "kortkort",
    "kortlekar": "kortlek",
    "kortlekarna": "kortlek",
    "kortlekarnas": "kortlek",
    "kortlekars": "kortlek",
    "kortleken": "kortlek",
    "kortlekens": "kortlek",
    "kortleks": "kortlek",
    "kortlivade": "kortlivad",
    "kortlivades": "kortlivad",
    "kortlivads": "kortlivad",
    "kortlivat": "kortlivad",
    "kortlivats": "kortlivad",
    "kortläsar": "kortläsare",
    "kortläsaren": "kortläsare",
    "kortläsarens": "kortläsare",
    "kortläsares": "kortläsare",
    "kortläsarna": "kortläsare",
    "kortläsarnas": "kortläsare",
    "kortlåd": "kortlåda",
    "kortlådan": "kortlåda",
    "kortlådans": "kortlåda",
    "kortlådas": "kortlåda",
    "kortlåde": "kortlåda",
    "kortlådor": "kortlåda",
    "kortlådorna": "kortlåda",
    "kortlådornas": "kortlåda",
    "kortlådors": "kortlåda",
    "kortlåds": "kortlåda",
    "kortox": "kortoxe",
    "kortoxar": "kortoxe",
    "kortoxarna": "kortoxe",
    "kortoxarnas": "kortoxe",
    "kortoxars": "kortoxe",
    "kortoxen": "kortoxe",
    "kortoxens": "kortoxe",
    "kortoxes": "kortoxe",
    "kortpassad": "kortpassa",
    "kortpassade": "kortpassa",
    "kortpassades": "kortpassa",
    "kortpassads": "kortpassa",
    "kortpassande": "kortpassa",
    "kortpassanden": "kortpassande",
    "kortpassandena": "kortpassande",
    "kortpassandenas": "kortpassande",
    "kortpassandens": "kortpassande",
    "kortpassandes": "kortpassande",
    "kortpassandet": "kortpassande",
    "kortpassandets": "kortpassande",
    "kortpassar": "kortpassa",
    "kortpassas": "kortpassa",
    "kortpassat": "kortpassa",
    "kortpassats": "kortpassa",
    "kortpassningar": "kortpassning",
    "kortpassningarna": "kortpassning",
    "kortpassningarnas": "kortpassning",
    "kortpassningars": "kortpassning",
    "kortpassningen": "kortpassning",
    "kortpassningens": "kortpassning",
    "kortpassnings": "kortpassning",
    "kortpipiga": "kortpipig",
    "kortpipigare": "kortpipig",
    "kortpipigares": "kortpipig",
    "kortpipigas": "kortpipig",
    "kortpipigast": "kortpipig",
    "kortpipigaste": "kortpipig",
    "kortpipigastes": "kortpipig",
    "kortpipigasts": "kortpipig",
    "kortpipige": "kortpipig",
    "kortpipiges": "kortpipig",
    "kortpipigs": "kortpipig",
    "kortpipigt": "kortpipig",
    "kortpipigts": "kortpipig",
    "kortregisterna": "kortregister",
    "kortregisternas": "kortregister",
    "kortregisters": "kortregister",
    "kortregistren": "kortregister",
    "kortregistrens": "kortregister",
    "kortregistret": "kortregister",
    "kortregistrets": "kortregister",
    "kortromanen": "kortroman",
    "kortromanens": "kortroman",
    "kortromaner": "kortroman",
    "kortromanerna": "kortroman",
    "kortromanernas": "kortroman",
    "kortromaners": "kortroman",
    "kortromans": "kortroman",
    "korts": "kort",
    "kortsidan": "kortsida",
    "kortsidans": "kortsida",
    "kortsidas": "kortsida",
    "kortside": "kortsida",
    "kortsides": "kortsida",
    "kortsidor": "kortsida",
    "kortsidorna": "kortsida",
    "kortsidornas": "kortsida",
    "kortsidors": "kortsida",
    "kortsiktiga": "kortsiktig",
    "kortsiktigare": "kortsiktig",
    "kortsiktigares": "kortsiktig",
    "kortsiktigas": "kortsiktig",
    "kortsiktigast": "kortsiktig",
    "kortsiktigaste": "kortsiktig",
    "kortsiktigastes": "kortsiktig",
    "kortsiktigasts": "kortsiktig",
    "kortsiktige": "kortsiktig",
    "kortsiktiges": "kortsiktig",
    "kortsiktigheten": "kortsiktighet",
    "kortsiktighetens": "kortsiktighet",
    "kortsiktighets": "kortsiktighet",
    "kortsiktigs": "kortsiktig",
    "kortsiktigt": "kortsiktig",
    "kortsiktigts": "kortsiktig",
    "kortskalliga": "kortskallig",
    "kortskalligare": "kortskallig",
    "kortskalligares": "kortskallig",
    "kortskalligas": "kortskallig",
    "kortskalligast": "kortskallig",
    "kortskalligaste": "kortskallig",
    "kortskalligastes": "kortskallig",
    "kortskalligasts": "kortskallig",
    "kortskallige": "kortskallig",
    "kortskalliges": "kortskallig",
    "kortskalligheten": "kortskallighet",
    "kortskallighetens": "kortskallighet",
    "kortskallighets": "kortskallighet",
    "kortskalligs": "kortskallig",
    "kortskalligt": "kortskallig",
    "kortskalligts": "kortskallig",
    "kortslut": "kortsluta",
    "kortslutande": "kortsluta",
    "kortslutanden": "kortslutande",
    "kortslutandena": "kortslutande",
    "kortslutandenas": "kortslutande",
    "kortslutandens": "kortslutande",
    "kortslutandes": "kortslutande",
    "kortslutandet": "kortslutande",
    "kortslutandets": "kortslutande",
    "kortslutas": "kortsluta",
    "kortslute": "kortsluta",
    "kortsluten": "kortsluta",
    "kortslutens": "kortsluta",
    "kortsluter": "kortsluta",
    "kortslutes": "kortsluta",
    "kortslutet": "kortsluta",
    "kortslutets": "kortsluta",
    "kortslutit": "kortsluta",
    "kortslutits": "kortsluta",
    "kortslutna": "kortsluta",
    "kortslutnas": "kortsluta",
    "kortslutne": "kortsluta",
    "kortslutnes": "kortsluta",
    "kortslutningar": "kortslutning",
    "kortslutningarna": "kortslutning",
    "kortslutningarnas": "kortslutning",
    "kortslutningars": "kortslutning",
    "kortslutningen": "kortslutning",
    "kortslutningens": "kortslutning",
    "kortslutnings": "kortslutning",
    "kortslutningsskydden": "kortslutningsskydd",
    "kortslutningsskyddens": "kortslutningsskydd",
    "kortslutningsskyddet": "kortslutningsskydd",
    "kortslutningsskyddets": "kortslutningsskydd",
    "kortslutningsskydds": "kortslutningsskydd",
    "kortsluts": "kortsluta",
    "kortslöt": "kortsluta",
    "kortslöte": "kortsluta",
    "kortslötes": "kortsluta",
    "kortslöts": "kortsluta",
    "kortsnaggade": "kortsnaggad",
    "kortsnaggades": "kortsnaggad",
    "kortsnaggads": "kortsnaggad",
    "kortsnaggat": "kortsnaggad",
    "kortsnaggats": "kortsnaggad",
    "kortspelar": "kortspelare",
    "kortspelaren": "kortspelare",
    "kortspelarens": "kortspelare",
    "kortspelares": "kortspelare",
    "kortspelarna": "kortspelare",
    "kortspelarnas": "kortspelare",
    "kortspelen": "kortspel",
    "kortspelens": "kortspel",
    "kortspelet": "kortspel",
    "kortspelets": "kortspel",
    "kortspels": "kortspel",
    "kortstölden": "kortstöld",
    "kortstöldens": "kortstöld",
    "kortstölder": "kortstöld",
    "kortstölderna": "kortstöld",
    "kortstöldernas": "kortstöld",
    "kortstölders": "kortstöld",
    "kortstölds": "kortstöld",
    "kortsynta": "kortsynt",
    "kortsyntare": "kortsynt",
    "kortsyntares": "kortsynt",
    "kortsyntas": "kortsynt",
    "kortsyntast": "kortsynt",
    "kortsyntaste": "kortsynt",
    "kortsyntastes": "kortsynt",
    "kortsyntasts": "kortsynt",
    "kortsynte": "kortsynt",
    "kortsyntes": "kortsynt",
    "kortsyntheten": "kortsynthet",
    "kortsynthetens": "kortsynthet",
    "kortsynthets": "kortsynthet",
    "kortsynts": "kortsynt",
    "korttidsförvaringen": "korttidsförvaring",
    "korttidsförvaringens": "korttidsförvaring",
    "korttidsförvarings": "korttidsförvaring",
    "korttidsminnes": "korttidsminne",
    "korttidsminnet": "korttidsminne",
    "korttidsminnets": "korttidsminne",
    "korttidsparkeringar": "korttidsparkering",
    "korttidsparkeringarna": "korttidsparkering",
    "korttidsparkeringarnas": "korttidsparkering",
    "korttidsparkeringars": "korttidsparkering",
    "korttidsparkeringen": "korttidsparkering",
    "korttidsparkeringens": "korttidsparkering",
    "korttidsparkerings": "korttidsparkering",
    "korttidsvikarien": "korttidsvikarie",
    "korttidsvikariens": "korttidsvikarie",
    "korttidsvikarier": "korttidsvikarie",
    "korttidsvikarierna": "korttidsvikarie",
    "korttidsvikariernas": "korttidsvikarie",
    "korttidsvikariers": "korttidsvikarie",
    "korttidsvikaries": "korttidsvikarie",
    "korttänkta": "korttänkt",
    "korttänktare": "korttänkt",
    "korttänktares": "korttänkt",
    "korttänktas": "korttänkt",
    "korttänktast": "korttänkt",
    "korttänktaste": "korttänkt",
    "korttänktastes": "korttänkt",
    "korttänktasts": "korttänkt",
    "korttänkte": "korttänkt",
    "korttänktes": "korttänkt",
    "korttänktheten": "korttänkthet",
    "korttänkthetens": "korttänkthet",
    "korttänkthets": "korttänkthet",
    "korttänkts": "korttänkt",
    "kortvar": "kortvara",
    "kortvaran": "kortvara",
    "kortvarans": "kortvara",
    "kortvaras": "kortvara",
    "kortvariga": "kortvarig",
    "kortvarigare": "kortvarig",
    "kortvarigares": "kortvarig",
    "kortvarigas": "kortvarig",
    "kortvarigast": "kortvarig",
    "kortvarigaste": "kortvarig",
    "kortvarigastes": "kortvarig",
    "kortvarigasts": "kortvarig",
    "kortvarige": "kortvarig",
    "kortvariges": "kortvarig",
    "kortvarigheten": "kortvarighet",
    "kortvarighetens": "kortvarighet",
    "kortvarighets": "kortvarighet",
    "kortvarigs": "kortvarig",
    "kortvarigt": "kortvarig",
    "kortvarigts": "kortvarig",
    "kortvaror": "kortvara",
    "kortvarorna": "kortvara",
    "kortvarornas": "kortvara",
    "kortvarors": "kortvara",
    "kortvaru": "kortvara",
    "kortvuxenheten": "kortvuxenhet",
    "kortvuxenhetens": "kortvuxenhet",
    "kortvuxenhets": "kortvuxenhet",
    "kortvuxens": "kortvuxen",
    "kortvuxet": "kortvuxen",
    "kortvuxets": "kortvuxen",
    "kortvuxna": "kortvuxen",
    "kortvuxnare": "kortvuxen",
    "kortvuxnares": "kortvuxen",
    "kortvuxnas": "kortvuxen",
    "kortvuxnast": "kortvuxen",
    "kortvuxnaste": "kortvuxen",
    "kortvuxnastes": "kortvuxen",
    "kortvuxnasts": "kortvuxen",
    "kortvuxne": "kortvuxen",
    "kortvuxnes": "kortvuxen",
    "kortväggar": "kortvägg",
    "kortväggarna": "kortvägg",
    "kortväggarnas": "kortvägg",
    "kortväggars": "kortvägg",
    "kortväggen": "kortvägg",
    "kortväggens": "kortvägg",
    "kortväggs": "kortvägg",
    "kortväxta": "kortväxt",
    "kortväxtare": "kortväxt",
    "kortväxtares": "kortväxt",
    "kortväxtas": "kortväxt",
    "kortväxtast": "kortväxt",
    "kortväxtaste": "kortväxt",
    "kortväxtastes": "kortväxt",
    "kortväxtasts": "kortväxt",
    "kortväxte": "kortväxt",
    "kortväxtes": "kortväxt",
    "kortväxtheten": "kortväxthet",
    "kortväxthetens": "kortväxthet",
    "kortväxthets": "kortväxthet",
    "kortväxts": "kortväxt",
    "kortvågen": "kortvåg",
    "kortvågens": "kortvåg",
    "kortvågor": "kortvåg",
    "kortvågorna": "kortvåg",
    "kortvågornas": "kortvåg",
    "kortvågors": "kortvåg",
    "kortvågs": "kortvåg",
    "kortvågsbehandlingar": "kortvågsbehandling",
    "kortvågsbehandlingarna": "kortvågsbehandling",
    "kortvågsbehandlingarnas": "kortvågsbehandling",
    "kortvågsbehandlingars": "kortvågsbehandling",
    "kortvågsbehandlingen": "kortvågsbehandling",
    "kortvågsbehandlingens": "kortvågsbehandling",
    "kortvågsbehandlings": "kortvågsbehandling",
    "kortvågsradion": "kortvågsradio",
    "kortvågsradions": "kortvågsradio",
    "kortvågsradior": "kortvågsradio",
    "kortvågsradiorna": "kortvågsradio",
    "kortvågsradiornas": "kortvågsradio",
    "kortvågsradiors": "kortvågsradio",
    "kortvågsradios": "kortvågsradio",
    "kortänd": "kortända",
    "kortändan": "kortända",
    "kortändans": "kortända",
    "kortändar": "kortände",
    "kortändarna": "kortände",
    "kortändarnas": "kortände",
    "kortändars": "kortände",
    "kortändas": "kortända",
    "kortände": "kortända",
    "kortänden": "kortände",
    "kortändens": "kortände",
    "kortändes": "kortände",
    "kortändor": "kortända",
    "kortändorna": "kortända",
    "kortändornas": "kortända",
    "kortändors": "kortända",
    "kortänds": "kortända",
    "kortärmade": "kortärmad",
    "kortärmades": "kortärmad",
    "kortärmads": "kortärmad",
    "kortärmat": "kortärmad",
    "kortärmats": "kortärmad",
    "korumen": "korum",
    "korumens": "korum",
    "korumet": "korum",
    "korumets": "korum",
    "korums": "korum",
    "korunden": "korund",
    "korundens": "korund",
    "korunder": "korund",
    "korunderna": "korund",
    "korundernas": "korund",
    "korunders": "korund",
    "korunds": "korund",
    "korusen": "korus",
    "korusens": "korus",
    "koruset": "korus",
    "korusets": "korus",
    "korvar": "korv",
    "korvarna": "korv",
    "korvarnas": "korv",
    "korvars": "korv",
    "korven": "korv",
    "korvens": "korv",
    "korvetten": "korvett",
    "korvettens": "korvett",
    "korvetter": "korvett",
    "korvetterna": "korvett",
    "korvetternas": "korvett",
    "korvetters": "korvett",
    "korvetts": "korvett",
    "korvfabriken": "korvfabrik",
    "korvfabrikens": "korvfabrik",
    "korvfabriker": "korvfabrik",
    "korvfabrikerna": "korvfabrik",
    "korvfabrikernas": "korvfabrik",
    "korvfabrikers": "korvfabrik",
    "korvfabriks": "korvfabrik",
    "korvgryt": "korvgryta",
    "korvgrytan": "korvgryta",
    "korvgrytans": "korvgryta",
    "korvgrytas": "korvgryta",
    "korvgryte": "korvgryta",
    "korvgrytor": "korvgryta",
    "korvgrytorna": "korvgryta",
    "korvgrytornas": "korvgryta",
    "korvgrytors": "korvgryta",
    "korvgryts": "korvgryta",
    "korvgubb": "korvgubbe",
    "korvgubbar": "korvgubbe",
    "korvgubbarna": "korvgubbe",
    "korvgubbarnas": "korvgubbe",
    "korvgubbars": "korvgubbe",
    "korvgubben": "korvgubbe",
    "korvgubbens": "korvgubbe",
    "korvgubbes": "korvgubbe",
    "korvgubbs": "korvgubbe",
    "korviga": "korvig",
    "korvigare": "korvig",
    "korvigares": "korvig",
    "korvigas": "korvig",
    "korvigast": "korvig",
    "korvigaste": "korvig",
    "korvigastes": "korvig",
    "korvigasts": "korvig",
    "korvige": "korvig",
    "korviges": "korvig",
    "korvigheten": "korvighet",
    "korvighetens": "korvighet",
    "korvighets": "korvighet",
    "korvigs": "korvig",
    "korvigt": "korvig",
    "korvigts": "korvig",
    "korvjobben": "korvjobb",
    "korvjobbens": "korvjobb",
    "korvjobbet": "korvjobb",
    "korvjobbets": "korvjobb",
    "korvjobbs": "korvjobb",
    "korvkak": "korvkaka",
    "korvkakan": "korvkaka",
    "korvkakans": "korvkaka",
    "korvkakas": "korvkaka",
    "korvkake": "korvkaka",
    "korvkakor": "korvkaka",
    "korvkakorna": "korvkaka",
    "korvkakornas": "korvkaka",
    "korvkakors": "korvkaka",
    "korvkaks": "korvkaka",
    "korvkiosken": "korvkiosk",
    "korvkioskens": "korvkiosk",
    "korvkiosker": "korvkiosk",
    "korvkioskerna": "korvkiosk",
    "korvkioskernas": "korvkiosk",
    "korvkioskers": "korvkiosk",
    "korvkiosks": "korvkiosk",
    "korvmaskinen": "korvmaskin",
    "korvmaskinens": "korvmaskin",
    "korvmaskiner": "korvmaskin",
    "korvmaskinerna": "korvmaskin",
    "korvmaskinernas": "korvmaskin",
    "korvmaskiners": "korvmaskin",
    "korvmaskins": "korvmaskin",
    "korvmojar": "korvmoj",
    "korvmojarna": "korvmoj",
    "korvmojarnas": "korvmoj",
    "korvmojars": "korvmoj",
    "korvmojen": "korvmoj",
    "korvmojens": "korvmoj",
    "korvmojs": "korvmoj",
    "korvs": "korv",
    "korvsjöar": "korvsjö",
    "korvsjöarna": "korvsjö",
    "korvsjöarnas": "korvsjö",
    "korvsjöars": "korvsjö",
    "korvsjön": "korvsjö",
    "korvsjöns": "korvsjö",
    "korvsjös": "korvsjö",
    "korvskinnen": "korvskinn",
    "korvskinnens": "korvskinn",
    "korvskinnet": "korvskinn",
    "korvskinnets": "korvskinn",
    "korvskinns": "korvskinn",
    "korvskivan": "korvskiva",
    "korvskivans": "korvskiva",
    "korvskivas": "korvskiva",
    "korvskive": "korvskiva",
    "korvskivor": "korvskiva",
    "korvskivorna": "korvskiva",
    "korvskivornas": "korvskiva",
    "korvskivors": "korvskiva",
    "korvsmörgåsar": "korvsmörgås",
    "korvsmörgåsarna": "korvsmörgås",
    "korvsmörgåsarnas": "korvsmörgås",
    "korvsmörgåsars": "korvsmörgås",
    "korvsmörgåsen": "korvsmörgås",
    "korvsmörgåsens": "korvsmörgås",
    "korvstoppningar": "korvstoppning",
    "korvstoppningarna": "korvstoppning",
    "korvstoppningarnas": "korvstoppning",
    "korvstoppningars": "korvstoppning",
    "korvstoppningen": "korvstoppning",
    "korvstoppningens": "korvstoppning",
    "korvstoppnings": "korvstoppning",
    "korvstånden": "korvstånd",
    "korvståndens": "korvstånd",
    "korvståndet": "korvstånd",
    "korvståndets": "korvstånd",
    "korvstånds": "korvstånd",
    "korvtillverkningar": "korvtillverkning",
    "korvtillverkningarna": "korvtillverkning",
    "korvtillverkningarnas": "korvtillverkning",
    "korvtillverkningars": "korvtillverkning",
    "korvtillverkningen": "korvtillverkning",
    "korvtillverkningens": "korvtillverkning",
    "korvtillverknings": "korvtillverkning",
    "korvälskar": "korvälskare",
    "korvälskaren": "korvälskare",
    "korvälskarens": "korvälskare",
    "korvälskares": "korvälskare",
    "korvälskarna": "korvälskare",
    "korvälskarnas": "korvälskare",
    "koryféen": "koryfé",
    "koryféens": "koryfé",
    "koryféer": "koryfé",
    "koryféerna": "koryfé",
    "koryféernas": "koryfé",
    "koryféers": "koryfé",
    "koryfén": "koryfé",
    "koryféns": "koryfé",
    "koryfés": "koryfé",
    "kos": "kosa",
    "kosackdansen": "kosackdans",
    "kosackdansens": "kosackdans",
    "kosackdanser": "kosackdans",
    "kosackdanserna": "kosackdans",
    "kosackdansernas": "kosackdans",
    "kosackdansers": "kosackdans",
    "kosacken": "kosack",
    "kosackens": "kosack",
    "kosacker": "kosack",
    "kosackerna": "kosack",
    "kosackernas": "kosack",
    "kosackers": "kosack",
    "kosacks": "kosack",
    "kosan": "kosa",
    "kosans": "kosa",
    "kosas": "kosa",
    "koschenillen": "koschenill",
    "koschenillens": "koschenill",
    "koschenills": "koschenill",
    "kose": "kosa",
    "kosingar": "kosing",
    "kosingarna": "kosing",
    "kosingarnas": "kosing",
    "kosingars": "kosing",
    "kosingen": "kosing",
    "kosingens": "kosing",
    "kosings": "kosing",
    "koskiten": "koskit",
    "koskitens": "koskit",
    "koskits": "koskit",
    "koskäll": "koskälla",
    "koskällan": "koskälla",
    "koskällans": "koskälla",
    "koskällas": "koskälla",
    "koskälle": "koskälla",
    "koskällor": "koskälla",
    "koskällorna": "koskälla",
    "koskällornas": "koskälla",
    "koskällors": "koskälla",
    "koskälls": "koskälla",
    "kosmetikan": "kosmetika",
    "kosmetikans": "kosmetika",
    "kosmetikas": "kosmetika",
    "kosmetiken": "kosmetik",
    "kosmetikens": "kosmetik",
    "kosmetiks": "kosmetik",
    "kosmetiska": "kosmetisk",
    "kosmetiskare": "kosmetisk",
    "kosmetiskares": "kosmetisk",
    "kosmetiskas": "kosmetisk",
    "kosmetiskast": "kosmetisk",
    "kosmetiskaste": "kosmetisk",
    "kosmetiskastes": "kosmetisk",
    "kosmetiskasts": "kosmetisk",
    "kosmetiske": "kosmetisk",
    "kosmetiskes": "kosmetisk",
    "kosmetisks": "kosmetisk",
    "kosmetiskt": "kosmetisk",
    "kosmetiskts": "kosmetisk",
    "kosmetologen": "kosmetolog",
    "kosmetologens": "kosmetolog",
    "kosmetologer": "kosmetolog",
    "kosmetologerna": "kosmetolog",
    "kosmetologernas": "kosmetolog",
    "kosmetologers": "kosmetolog",
    "kosmetologs": "kosmetolog",
    "kosmiska": "kosmisk",
    "kosmiskare": "kosmisk",
    "kosmiskares": "kosmisk",
    "kosmiskas": "kosmisk",
    "kosmiskast": "kosmisk",
    "kosmiskaste": "kosmisk",
    "kosmiskastes": "kosmisk",
    "kosmiskasts": "kosmisk",
    "kosmiske": "kosmisk",
    "kosmiskes": "kosmisk",
    "kosmisks": "kosmisk",
    "kosmiskt": "kosmisk",
    "kosmiskts": "kosmisk",
    "kosmodromen": "kosmodrom",
    "kosmodromens": "kosmodrom",
    "kosmodromer": "kosmodrom",
    "kosmodromerna": "kosmodrom",
    "kosmodromernas": "kosmodrom",
    "kosmodromers": "kosmodrom",
    "kosmodroms": "kosmodrom",
    "kosmogonien": "kosmogoni",
    "kosmogoniens": "kosmogoni",
    "kosmogonier": "kosmogoni",
    "kosmogonierna": "kosmogoni",
    "kosmogoniernas": "kosmogoni",
    "kosmogoniers": "kosmogoni",
    "kosmogonin": "kosmogoni",
    "kosmogonins": "kosmogoni",
    "kosmogonis": "kosmogoni",
    "kosmologen": "kosmolog",
    "kosmologens": "kosmolog",
    "kosmologer": "kosmolog",
    "kosmologerna": "kosmolog",
    "kosmologernas": "kosmolog",
    "kosmologers": "kosmolog",
    "kosmologien": "kosmologi",
    "kosmologiens": "kosmologi",
    "kosmologier": "kosmologi",
    "kosmologierna": "kosmologi",
    "kosmologiernas": "kosmologi",
    "kosmologiers": "kosmologi",
    "kosmologin": "kosmologi",
    "kosmologins": "kosmologi",
    "kosmologis": "kosmologi",
    "kosmologiska": "kosmologisk",
    "kosmologiskare": "kosmologisk",
    "kosmologiskares": "kosmologisk",
    "kosmologiskas": "kosmologisk",
    "kosmologiskast": "kosmologisk",
    "kosmologiskaste": "kosmologisk",
    "kosmologiskastes": "kosmologisk",
    "kosmologiskasts": "kosmologisk",
    "kosmologiske": "kosmologisk",
    "kosmologiskes": "kosmologisk",
    "kosmologisks": "kosmologisk",
    "kosmologiskt": "kosmologisk",
    "kosmologiskts": "kosmologisk",
    "kosmologs": "kosmolog",
    "kosmonauten": "kosmonaut",
    "kosmonautens": "kosmonaut",
    "kosmonauter": "kosmonaut",
    "kosmonauterna": "kosmonaut",
    "kosmonauternas": "kosmonaut",
    "kosmonauters": "kosmonaut",
    "kosmonauts": "kosmonaut",
    "kosmopoliten": "kosmopolit",
    "kosmopolitens": "kosmopolit",
    "kosmopoliter": "kosmopolit",
    "kosmopoliterna": "kosmopolit",
    "kosmopoliternas": "kosmopolit",
    "kosmopoliters": "kosmopolit",
    "kosmopolitiska": "kosmopolitisk",
    "kosmopolitiskare": "kosmopolitisk",
    "kosmopolitiskares": "kosmopolitisk",
    "kosmopolitiskas": "kosmopolitisk",
    "kosmopolitiskast": "kosmopolitisk",
    "kosmopolitiskaste": "kosmopolitisk",
    "kosmopolitiskastes": "kosmopolitisk",
    "kosmopolitiskasts": "kosmopolitisk",
    "kosmopolitiske": "kosmopolitisk",
    "kosmopolitiskes": "kosmopolitisk",
    "kosmopolitisks": "kosmopolitisk",
    "kosmopolitiskt": "kosmopolitisk",
    "kosmopolitiskts": "kosmopolitisk",
    "kosmopolits": "kosmopolit",
    "kosmosen": "kosmos",
    "kosmosens": "kosmos",
    "kosmoset": "kosmos",
    "kosmosets": "kosmos",
    "kosor": "kosa",
    "kosorna": "kosa",
    "kosornas": "kosa",
    "kosors": "kosa",
    "kosovanska": "kosovansk",
    "kosovanskan": "kosovanska",
    "kosovanskans": "kosovanska",
    "kosovanskare": "kosovansk",
    "kosovanskares": "kosovansk",
    "kosovanskas": "kosovanska",
    "kosovanskast": "kosovansk",
    "kosovanskaste": "kosovansk",
    "kosovanskastes": "kosovansk",
    "kosovanskasts": "kosovansk",
    "kosovanske": "kosovanska",
    "kosovanskes": "kosovansk",
    "kosovanskor": "kosovanska",
    "kosovanskorna": "kosovanska",
    "kosovanskornas": "kosovanska",
    "kosovanskors": "kosovanska",
    "kosovansks": "kosovansk",
    "kosovanskt": "kosovansk",
    "kosovanskts": "kosovansk",
    "kosovaren": "kosovar",
    "kosovarens": "kosovar",
    "kosovarer": "kosovar",
    "kosovarerna": "kosovar",
    "kosovarernas": "kosovar",
    "kosovarers": "kosovar",
    "kosovars": "kosovar",
    "koss": "kossa",
    "kossan": "kossa",
    "kossans": "kossa",
    "kossas": "kossa",
    "kosse": "kossa",
    "kossor": "kossa",
    "kossorna": "kossa",
    "kossornas": "kossa",
    "kossors": "kossa",
    "kost": "kosta",
    "kostade": "kosta",
    "kostades": "kosta",
    "kostande": "kosta",
    "kostanden": "kostande",
    "kostandena": "kostande",
    "kostandenas": "kostande",
    "kostandens": "kostande",
    "kostandes": "kostande",
    "kostandet": "kostande",
    "kostandets": "kostande",
    "kostar": "kosta",
    "kostas": "kosta",
    "kostat": "kosta",
    "kostats": "kosta",
    "kostbara": "kostbar",
    "kostbarare": "kostbar",
    "kostbarares": "kostbar",
    "kostbaras": "kostbar",
    "kostbarast": "kostbar",
    "kostbaraste": "kostbar",
    "kostbarastes": "kostbar",
    "kostbarasts": "kostbar",
    "kostbare": "kostbar",
    "kostbares": "kostbar",
    "kostbarheten": "kostbarhet",
    "kostbarhetens": "kostbarhet",
    "kostbarheter": "kostbarhet",
    "kostbarheterna": "kostbarhet",
    "kostbarheternas": "kostbarhet",
    "kostbarheters": "kostbarhet",
    "kostbarhets": "kostbarhet",
    "kostbars": "kostbar",
    "kostbart": "kostbar",
    "kostbarts": "kostbar",
    "kosten": "kost",
    "kostens": "kost",
    "kostern": "koster",
    "kosterns": "koster",
    "kosters": "koster",
    "kostfibern": "kostfiber",
    "kostfiberns": "kostfiber",
    "kostfibers": "kostfiber",
    "kostfibrer": "kostfiber",
    "kostfibrerna": "kostfiber",
    "kostfibrernas": "kostfiber",
    "kostfibrers": "kostfiber",
    "kosthållningar": "kosthållning",
    "kosthållningarna": "kosthållning",
    "kosthållningarnas": "kosthållning",
    "kosthållningars": "kosthållning",
    "kosthållningen": "kosthållning",
    "kosthållningens": "kosthållning",
    "kosthållnings": "kosthållning",
    "kostigar": "kostig",
    "kostigarna": "kostig",
    "kostigarnas": "kostig",
    "kostigars": "kostig",
    "kostigen": "kostig",
    "kostigens": "kostig",
    "kostigs": "kostig",
    "kostliga": "kostlig",
    "kostligare": "kostlig",
    "kostligares": "kostlig",
    "kostligas": "kostlig",
    "kostligast": "kostlig",
    "kostligaste": "kostlig",
    "kostligastes": "kostlig",
    "kostligasts": "kostlig",
    "kostlige": "kostlig",
    "kostliges": "kostlig",
    "kostligheten": "kostlighet",
    "kostlighetens": "kostlighet",
    "kostlighets": "kostlighet",
    "kostligs": "kostlig",
    "kostligt": "kostlig",
    "kostligts": "kostlig",
    "kostnaden": "kostnad",
    "kostnadens": "kostnad",
    "kostnader": "kostnad",
    "kostnaderna": "kostnad",
    "kostnadernas": "kostnad",
    "kostnaders": "kostnad",
    "kostnads": "kostnad",
    "kostnadseffektiva": "kostnadseffektiv",
    "kostnadseffektivare": "kostnadseffektiv",
    "kostnadseffektivares": "kostnadseffektiv",
    "kostnadseffektivas": "kostnadseffektiv",
    "kostnadseffektivast": "kostnadseffektiv",
    "kostnadseffektivaste": "kostnadseffektiv",
    "kostnadseffektivastes": "kostnadseffektiv",
    "kostnadseffektivasts": "kostnadseffektiv",
    "kostnadseffektive": "kostnadseffektiv",
    "kostnadseffektives": "kostnadseffektiv",
    "kostnadseffektivs": "kostnadseffektiv",
    "kostnadseffektivt": "kostnadseffektiv",
    "kostnadseffektivts": "kostnadseffektiv",
    "kostnadsersättningar": "kostnadsersättning",
    "kostnadsersättningarna": "kostnadsersättning",
    "kostnadsersättningarnas": "kostnadsersättning",
    "kostnadsersättningars": "kostnadsersättning",
    "kostnadsersättningen": "kostnadsersättning",
    "kostnadsersättningens": "kostnadsersättning",
    "kostnadsersättnings": "kostnadsersättning",
    "kostnadsfria": "kostnadsfri",
    "kostnadsfriare": "kostnadsfri",
    "kostnadsfriares": "kostnadsfri",
    "kostnadsfrias": "kostnadsfri",
    "kostnadsfriast": "kostnadsfri",
    "kostnadsfriaste": "kostnadsfri",
    "kostnadsfriastes": "kostnadsfri",
    "kostnadsfriasts": "kostnadsfri",
    "kostnadsfrie": "kostnadsfri",
    "kostnadsfries": "kostnadsfri",
    "kostnadsfris": "kostnadsfri",
    "kostnadsfritt": "kostnadsfri",
    "kostnadsfritts": "kostnadsfri",
    "kostnadsmässiga": "kostnadsmässig",
    "kostnadsmässigare": "kostnadsmässig",
    "kostnadsmässigares": "kostnadsmässig",
    "kostnadsmässigas": "kostnadsmässig",
    "kostnadsmässigast": "kostnadsmässig",
    "kostnadsmässigaste": "kostnadsmässig",
    "kostnadsmässigastes": "kostnadsmässig",
    "kostnadsmässigasts": "kostnadsmässig",
    "kostnadsmässige": "kostnadsmässig",
    "kostnadsmässiges": "kostnadsmässig",
    "kostnadsmässigs": "kostnadsmässig",
    "kostnadsmässigt": "kostnadsmässig",
    "kostnadsmässigts": "kostnadsmässig",
    "kostnadsramar": "kostnadsram",
    "kostnadsramarna": "kostnadsram",
    "kostnadsramarnas": "kostnadsram",
    "kostnadsramars": "kostnadsram",
    "kostnadsramen": "kostnadsram",
    "kostnadsramens": "kostnadsram",
    "kostnadsrams": "kostnadsram",
    "kostnadsskälen": "kostnadsskäl",
    "kostnadsskälens": "kostnadsskäl",
    "kostnadsskälet": "kostnadsskäl",
    "kostnadsskälets": "kostnadsskäl",
    "kostnadsskäls": "kostnadsskäl",
    "kostnadsökningar": "kostnadsökning",
    "kostnadsökningarna": "kostnadsökning",
    "kostnadsökningarnas": "kostnadsökning",
    "kostnadsökningars": "kostnadsökning",
    "kostnadsökningen": "kostnadsökning",
    "kostnadsökningens": "kostnadsökning",
    "kostnadsöknings": "kostnadsökning",
    "kostrar": "koster",
    "kostrarna": "koster",
    "kostrarnas": "koster",
    "kostrars": "koster",
    "kostråden": "kostråd",
    "kostrådens": "kostråd",
    "kostrådet": "kostråd",
    "kostrådets": "kostråd",
    "kostråds": "kostråd",
    "kosts": "kost",
    "kostsamheten": "kostsamhet",
    "kostsamhetens": "kostsamhet",
    "kostsamhets": "kostsamhet",
    "kostsamma": "kostsam",
    "kostsammare": "kostsam",
    "kostsammares": "kostsam",
    "kostsammas": "kostsam",
    "kostsammast": "kostsam",
    "kostsammaste": "kostsam",
    "kostsammastes": "kostsam",
    "kostsammasts": "kostsam",
    "kostsamme": "kostsam",
    "kostsammes": "kostsam",
    "kostsams": "kostsam",
    "kostsamt": "kostsam",
    "kostsamts": "kostsam",
    "kostscheman": "kostschema",
    "kostschemana": "kostschema",
    "kostschemanas": "kostschema",
    "kostschemans": "kostschema",
    "kostschemas": "kostschema",
    "kostschemat": "kostschema",
    "kostschemats": "kostschema",
    "kosttillskotten": "kosttillskott",
    "kosttillskottens": "kosttillskott",
    "kosttillskottet": "kosttillskott",
    "kosttillskottets": "kosttillskott",
    "kosttillskotts": "kosttillskott",
    "kostvanan": "kostvana",
    "kostvanans": "kostvana",
    "kostvanas": "kostvana",
    "kostvane": "kostvana",
    "kostvanor": "kostvana",
    "kostvanorna": "kostvana",
    "kostvanornas": "kostvana",
    "kostvanors": "kostvana",
    "kostymbalen": "kostymbal",
    "kostymbalens": "kostymbal",
    "kostymbaler": "kostymbal",
    "kostymbalerna": "kostymbal",
    "kostymbalernas": "kostymbal",
    "kostymbalers": "kostymbal",
    "kostymbals": "kostymbal",
    "kostymen": "kostym",
    "kostymens": "kostym",
    "kostymer": "kostym",
    "kostymerad": "kostymera",
    "kostymerade": "kostymera",
    "kostymerades": "kostymera",
    "kostymerads": "kostymera",
    "kostymerande": "kostymera",
    "kostymeranden": "kostymerande",
    "kostymerandena": "kostymerande",
    "kostymerandenas": "kostymerande",
    "kostymerandens": "kostymerande",
    "kostymerandes": "kostymerande",
    "kostymerandet": "kostymerande",
    "kostymerandets": "kostymerande",
    "kostymerar": "kostymera",
    "kostymeras": "kostymera",
    "kostymerat": "kostymera",
    "kostymerats": "kostymera",
    "kostymerbara": "kostymerbar",
    "kostymerbarare": "kostymerbar",
    "kostymerbarares": "kostymerbar",
    "kostymerbaras": "kostymerbar",
    "kostymerbarast": "kostymerbar",
    "kostymerbaraste": "kostymerbar",
    "kostymerbarastes": "kostymerbar",
    "kostymerbarasts": "kostymerbar",
    "kostymerbare": "kostymerbar",
    "kostymerbares": "kostymerbar",
    "kostymerbarheten": "kostymerbarhet",
    "kostymerbarhetens": "kostymerbarhet",
    "kostymerbarhets": "kostymerbarhet",
    "kostymerbars": "kostymerbar",
    "kostymerbart": "kostymerbar",
    "kostymerbarts": "kostymerbar",
    "kostymeringar": "kostymering",
    "kostymeringarna": "kostymering",
    "kostymeringarnas": "kostymering",
    "kostymeringars": "kostymering",
    "kostymeringen": "kostymering",
    "kostymeringens": "kostymering",
    "kostymerings": "kostymering",
    "kostymerna": "kostym",
    "kostymernas": "kostym",
    "kostymers": "kostym",
    "kostympjäsen": "kostympjäs",
    "kostympjäsens": "kostympjäs",
    "kostympjäser": "kostympjäs",
    "kostympjäserna": "kostympjäs",
    "kostympjäsernas": "kostympjäs",
    "kostympjäsers": "kostympjäs",
    "kostyms": "kostym",
    "kot": "kota",
    "kotan": "kota",
    "kotans": "kota",
    "kotas": "kota",
    "kotbenen": "kotben",
    "kotbenens": "kotben",
    "kotbenet": "kotben",
    "kotbenets": "kotben",
    "kotbens": "kotben",
    "kote": "kota",
    "kotiljongen": "kotiljong",
    "kotiljongens": "kotiljong",
    "kotiljonger": "kotiljong",
    "kotiljongerna": "kotiljong",
    "kotiljongernas": "kotiljong",
    "kotiljongers": "kotiljong",
    "kotiljongs": "kotiljong",
    "kotknackar": "kotknackare",
    "kotknackaren": "kotknackare",
    "kotknackarens": "kotknackare",
    "kotknackares": "kotknackare",
    "kotknackarna": "kotknackare",
    "kotknackarnas": "kotknackare",
    "kotknackningar": "kotknackning",
    "kotknackningarna": "kotknackning",
    "kotknackningarnas": "kotknackning",
    "kotknackningars": "kotknackning",
    "kotknackningen": "kotknackning",
    "kotknackningens": "kotknackning",
    "kotknacknings": "kotknackning",
    "kotleden": "kotled",
    "kotledens": "kotled",
    "kotleder": "kotled",
    "kotlederna": "kotled",
    "kotledernas": "kotled",
    "kotleders": "kotled",
    "kotleds": "kotled",
    "kotletten": "kotlett",
    "kotlettens": "kotlett",
    "kotletter": "kotlett",
    "kotletterna": "kotlett",
    "kotletternas": "kotlett",
    "kotletters": "kotlett",
    "kotlettfiskar": "kotlettfisk",
    "kotlettfiskarna": "kotlettfisk",
    "kotlettfiskarnas": "kotlettfisk",
    "kotlettfiskars": "kotlettfisk",
    "kotlettfisken": "kotlettfisk",
    "kotlettfiskens": "kotlettfisk",
    "kotlettfisks": "kotlettfisk",
    "kotlettraden": "kotlettrad",
    "kotlettradens": "kotlettrad",
    "kotlettrader": "kotlettrad",
    "kotlettraderna": "kotlettrad",
    "kotlettradernas": "kotlettrad",
    "kotlettraders": "kotlettrad",
    "kotlettrads": "kotlettrad",
    "kotletts": "kotlett",
    "kotor": "kota",
    "kotorna": "kota",
    "kotornas": "kota",
    "kotors": "kota",
    "kotpelar": "kotpelare",
    "kotpelaren": "kotpelare",
    "kotpelarens": "kotpelare",
    "kotpelares": "kotpelare",
    "kotpelarna": "kotpelare",
    "kotpelarnas": "kotpelare",
    "kots": "kota",
    "kott": "kotte",
    "kottar": "kotte",
    "kottarna": "kotte",
    "kottarnas": "kotte",
    "kottars": "kotte",
    "kotten": "kotte",
    "kottens": "kotte",
    "kotterier": "kotteri",
    "kotterierna": "kotteri",
    "kotteriernas": "kotteri",
    "kotteriers": "kotteri",
    "kotteriet": "kotteri",
    "kotteriets": "kotteri",
    "kotteris": "kotteri",
    "kotterit": "kotteri",
    "kotterits": "kotteri",
    "kottes": "kotte",
    "kotts": "kotte",
    "koturnen": "koturn",
    "koturnens": "koturn",
    "koturner": "koturn",
    "koturnerna": "koturn",
    "koturnernas": "koturn",
    "koturners": "koturn",
    "koturns": "koturn",
    "kovalenta": "kovalent",
    "kovalentare": "kovalent",
    "kovalentares": "kovalent",
    "kovalentas": "kovalent",
    "kovalentast": "kovalent",
    "kovalentaste": "kovalent",
    "kovalentastes": "kovalent",
    "kovalentasts": "kovalent",
    "kovalente": "kovalent",
    "kovalentes": "kovalent",
    "kovalents": "kovalent",
    "kovallen": "kovall",
    "kovallens": "kovall",
    "kovaller": "kovall",
    "kovallerna": "kovall",
    "kovallernas": "kovall",
    "kovallers": "kovall",
    "kovalls": "kovall",
    "kovan": "kova",
    "kovans": "kova",
    "kovas": "kova",
    "koverta": "kovert",
    "kovertare": "kovert",
    "kovertares": "kovert",
    "kovertas": "kovert",
    "kovertast": "kovert",
    "kovertaste": "kovert",
    "kovertastes": "kovert",
    "kovertasts": "kovert",
    "koverte": "kovert",
    "kovertes": "kovert",
    "koverts": "kovert",
    "kovänd": "kovända",
    "kovändande": "kovända",
    "kovändanden": "kovändande",
    "kovändandena": "kovändande",
    "kovändandenas": "kovändande",
    "kovändandens": "kovändande",
    "kovändandes": "kovändande",
    "kovändandet": "kovändande",
    "kovändandets": "kovändande",
    "kovändas": "kovända",
    "kovände": "kovända",
    "kovänder": "kovända",
    "kovändes": "kovända",
    "kovändningar": "kovändning",
    "kovändningarna": "kovändning",
    "kovändningarnas": "kovändning",
    "kovändningars": "kovändning",
    "kovändningen": "kovändning",
    "kovändningens": "kovändning",
    "kovändnings": "kovändning",
    "kovänds": "kovända",
    "kovänt": "kovända",
    "kovänts": "kovända",
    "koxade": "koxa",
    "koxades": "koxa",
    "koxande": "koxa",
    "koxanden": "koxande",
    "koxandena": "koxande",
    "koxandenas": "koxande",
    "koxandens": "koxande",
    "koxandes": "koxande",
    "koxandet": "koxande",
    "koxandets": "koxande",
    "koxar": "koxa",
    "koxas": "koxa",
    "koxat": "koxa",
    "koxats": "koxa",
    "koxen": "kox",
    "koxens": "kox",
    "koyoten": "koyot",
    "koyotens": "koyot",
    "koyoter": "koyot",
    "koyoterna": "koyot",
    "koyoternas": "koyot",
    "koyoters": "koyot",
    "koyots": "koyot",
    "koögas": "koöga",
    "koögat": "koöga",
    "koögats": "koöga",
    "koögda": "koögd",
    "koögdare": "koögd",
    "koögdares": "koögd",
    "koögdas": "koögd",
    "koögdast": "koögd",
    "koögdaste": "koögd",
    "koögdastes": "koögd",
    "koögdasts": "koögd",
    "koögde": "koögd",
    "koögdes": "koögd",
    "koögdheten": "koögdhet",
    "koögdhetens": "koögdhet",
    "koögdhets": "koögdhet",
    "koögds": "koögd",
    "koögon": "koöga",
    "koögonen": "koöga",
    "koögonens": "koöga",
    "koögons": "koöga",
    "koögt": "koögd",
    "koögts": "koögd",
    "kpistar": "kpist",
    "kpistarna": "kpist",
    "kpistarnas": "kpist",
    "kpistars": "kpist",
    "kpisten": "kpist",
    "kpistens": "kpist",
    "kpists": "kpist",
    "kraalen": "kraal",
    "kraalens": "kraal",
    "kraaler": "kraal",
    "kraalerna": "kraal",
    "kraalernas": "kraal",
    "kraalers": "kraal",
    "kraals": "kraal",
    "krabaten": "krabat",
    "krabatens": "krabat",
    "krabater": "krabat",
    "krabaterna": "krabat",
    "krabaternas": "krabat",
    "krabaters": "krabat",
    "krabats": "krabat",
    "krabb": "krabba",
    "krabba": "krabb",
    "krabban": "krabba",
    "krabbans": "krabba",
    "krabbare": "krabb",
    "krabbares": "krabb",
    "krabbas": "krabba",
    "krabbasnåret": "krabbasnår",
    "krabbasnårets": "krabbasnår",
    "krabbasnårs": "krabbasnår",
    "krabbast": "krabb",
    "krabbaste": "krabb",
    "krabbastes": "krabb",
    "krabbasts": "krabb",
    "krabbe": "krabba",
    "krabbes": "krabb",
    "krabbheten": "krabbhet",
    "krabbhetens": "krabbhet",
    "krabbhets": "krabbhet",
    "krabbor": "krabba",
    "krabborna": "krabba",
    "krabbornas": "krabba",
    "krabbors": "krabba",
    "krabbs": "krabba",
    "krabbtask": "krabbtaska",
    "krabbtaskan": "krabbtaska",
    "krabbtaskans": "krabbtaska",
    "krabbtaskas": "krabbtaska",
    "krabbtaske": "krabbtaska",
    "krabbtaskor": "krabbtaska",
    "krabbtaskorna": "krabbtaska",
    "krabbtaskornas": "krabbtaska",
    "krabbtaskors": "krabbtaska",
    "krackad": "kracka",
    "krackade": "kracka",
    "krackades": "kracka",
    "krackads": "kracka",
    "krackande": "kracka",
    "krackanden": "krackande",
    "krackandena": "krackande",
    "krackandenas": "krackande",
    "krackandens": "krackande",
    "krackandes": "krackande",
    "krackandet": "krackande",
    "krackandets": "krackande",
    "krackar": "kracka",
    "krackas": "kracka",
    "krackat": "kracka",
    "krackats": "kracka",
    "krackelerad": "krackelera",
    "krackelerade": "krackelera",
    "krackelerades": "krackelera",
    "krackelerads": "krackelera",
    "krackelerande": "krackelera",
    "krackeleranden": "krackelerande",
    "krackelerandena": "krackelerande",
    "krackelerandenas": "krackelerande",
    "krackelerandens": "krackelerande",
    "krackelerandes": "krackelerande",
    "krackelerandet": "krackelerande",
    "krackelerandets": "krackelerande",
    "krackelerar": "krackelera",
    "krackeleras": "krackelera",
    "krackelerat": "krackelera",
    "krackelerats": "krackelera",
    "krackelerbara": "krackelerbar",
    "krackelerbarare": "krackelerbar",
    "krackelerbarares": "krackelerbar",
    "krackelerbaras": "krackelerbar",
    "krackelerbarast": "krackelerbar",
    "krackelerbaraste": "krackelerbar",
    "krackelerbarastes": "krackelerbar",
    "krackelerbarasts": "krackelerbar",
    "krackelerbare": "krackelerbar",
    "krackelerbares": "krackelerbar",
    "krackelerbarheten": "krackelerbarhet",
    "krackelerbarhetens": "krackelerbarhet",
    "krackelerbarhets": "krackelerbarhet",
    "krackelerbars": "krackelerbar",
    "krackelerbart": "krackelerbar",
    "krackelerbarts": "krackelerbar",
    "krackeleringar": "krackelering",
    "krackeleringarna": "krackelering",
    "krackeleringarnas": "krackelering",
    "krackeleringars": "krackelering",
    "krackeleringen": "krackelering",
    "krackeleringens": "krackelering",
    "krackelerings": "krackelering",
    "krackelyren": "krackelyr",
    "krackelyrens": "krackelyr",
    "krackelyrs": "krackelyr",
    "krackningar": "krackning",
    "krackningarna": "krackning",
    "krackningarnas": "krackning",
    "krackningars": "krackning",
    "krackningen": "krackning",
    "krackningens": "krackning",
    "kracknings": "krackning",
    "krafs": "krafsa",
    "krafsad": "krafsa",
    "krafsade": "krafsa",
    "krafsades": "krafsa",
    "krafsads": "krafsa",
    "krafsande": "krafsa",
    "krafsanden": "krafsande",
    "krafsandena": "krafsande",
    "krafsandenas": "krafsande",
    "krafsandens": "krafsande",
    "krafsandes": "krafsande",
    "krafsandet": "krafsande",
    "krafsandets": "krafsande",
    "krafsar": "krafsa",
    "krafsas": "krafsa",
    "krafsat": "krafsa",
    "krafsats": "krafsa",
    "krafset": "krafs",
    "krafsets": "krafs",
    "krafsiga": "krafsig",
    "krafsigare": "krafsig",
    "krafsigares": "krafsig",
    "krafsigas": "krafsig",
    "krafsigast": "krafsig",
    "krafsigaste": "krafsig",
    "krafsigastes": "krafsig",
    "krafsigasts": "krafsig",
    "krafsige": "krafsig",
    "krafsiges": "krafsig",
    "krafsigheten": "krafsighet",
    "krafsighetens": "krafsighet",
    "krafsighets": "krafsighet",
    "krafsigs": "krafsig",
    "krafsigt": "krafsig",
    "krafsigts": "krafsig",
    "kraftaggregaten": "kraftaggregat",
    "kraftaggregatens": "kraftaggregat",
    "kraftaggregatet": "kraftaggregat",
    "kraftaggregatets": "kraftaggregat",
    "kraftaggregats": "kraftaggregat",
    "kraftansträngningar": "kraftansträngning",
    "kraftansträngningarna": "kraftansträngning",
    "kraftansträngningarnas": "kraftansträngning",
    "kraftansträngningars": "kraftansträngning",
    "kraftansträngningen": "kraftansträngning",
    "kraftansträngningens": "kraftansträngning",
    "kraftansträngnings": "kraftansträngning",
    "kraftbehoven": "kraftbehov",
    "kraftbehovens": "kraftbehov",
    "kraftbehovet": "kraftbehov",
    "kraftbehovets": "kraftbehov",
    "kraftbehovs": "kraftbehov",
    "kraftbolagen": "kraftbolag",
    "kraftbolagens": "kraftbolag",
    "kraftbolaget": "kraftbolag",
    "kraftbolagets": "kraftbolag",
    "kraftbolags": "kraftbolag",
    "kraftbärar": "kraftbärare",
    "kraftbäraren": "kraftbärare",
    "kraftbärarens": "kraftbärare",
    "kraftbärares": "kraftbärare",
    "kraftbärarna": "kraftbärare",
    "kraftbärarnas": "kraftbärare",
    "kraftcentra": "kraftcentrum",
    "kraftcentralen": "kraftcentral",
    "kraftcentralens": "kraftcentral",
    "kraftcentraler": "kraftcentral",
    "kraftcentralerna": "kraftcentral",
    "kraftcentralernas": "kraftcentral",
    "kraftcentralers": "kraftcentral",
    "kraftcentrals": "kraftcentral",
    "kraftcentrana": "kraftcentrum",
    "kraftcentranas": "kraftcentrum",
    "kraftcentras": "kraftcentrum",
    "kraftcentrumen": "kraftcentrum",
    "kraftcentrumens": "kraftcentrum",
    "kraftcentrumet": "kraftcentrum",
    "kraftcentrumets": "kraftcentrum",
    "kraftcentrums": "kraftcentrum",
    "kraftekvationen": "kraftekvation",
    "kraftekvationens": "kraftekvation",
    "kraftekvationer": "kraftekvation",
    "kraftekvationerna": "kraftekvation",
    "kraftekvationernas": "kraftekvation",
    "kraftekvationers": "kraftekvation",
    "kraftekvations": "kraftekvation",
    "kraften": "kraft",
    "kraftens": "kraft",
    "krafter": "kraft",
    "krafterna": "kraft",
    "krafternas": "kraft",
    "krafters": "kraft",
    "kraftfoderna": "kraftfoder",
    "kraftfodernas": "kraftfoder",
    "kraftfoders": "kraftfoder",
    "kraftfodren": "kraftfoder",
    "kraftfodrens": "kraftfoder",
    "kraftfodret": "kraftfoder",
    "kraftfodrets": "kraftfoder",
    "kraftfulla": "kraftfull",
    "kraftfullare": "kraftfull",
    "kraftfullares": "kraftfull",
    "kraftfullas": "kraftfull",
    "kraftfullast": "kraftfull",
    "kraftfullaste": "kraftfull",
    "kraftfullastes": "kraftfull",
    "kraftfullasts": "kraftfull",
    "kraftfulle": "kraftfull",
    "kraftfulles": "kraftfull",
    "kraftfullheten": "kraftfullhet",
    "kraftfullhetens": "kraftfullhet",
    "kraftfullhets": "kraftfullhet",
    "kraftfulls": "kraftfull",
    "kraftfullt": "kraftfull",
    "kraftfullts": "kraftfull",
    "kraftfälten": "kraftfält",
    "kraftfältens": "kraftfält",
    "kraftfältet": "kraftfält",
    "kraftfältets": "kraftfält",
    "kraftfälts": "kraftfält",
    "kraftförbrukningar": "kraftförbrukning",
    "kraftförbrukningarna": "kraftförbrukning",
    "kraftförbrukningarnas": "kraftförbrukning",
    "kraftförbrukningars": "kraftförbrukning",
    "kraftförbrukningen": "kraftförbrukning",
    "kraftförbrukningens": "kraftförbrukning",
    "kraftförbruknings": "kraftförbrukning",
    "kraftföretagen": "kraftföretag",
    "kraftföretagens": "kraftföretag",
    "kraftföretaget": "kraftföretag",
    "kraftföretagets": "kraftföretag",
    "kraftföretags": "kraftföretag",
    "kraftförsörjningar": "kraftförsörjning",
    "kraftförsörjningarna": "kraftförsörjning",
    "kraftförsörjningarnas": "kraftförsörjning",
    "kraftförsörjningars": "kraftförsörjning",
    "kraftförsörjningen": "kraftförsörjning",
    "kraftförsörjningens": "kraftförsörjning",
    "kraftförsörjnings": "kraftförsörjning",
    "kraftiga": "kraftig",
    "kraftigare": "kraftig",
    "kraftigares": "kraftig",
    "kraftigas": "kraftig",
    "kraftigast": "kraftig",
    "kraftigaste": "kraftig",
    "kraftigastes": "kraftig",
    "kraftigasts": "kraftig",
    "kraftige": "kraftig",
    "kraftiges": "kraftig",
    "kraftigheten": "kraftighet",
    "kraftighetens": "kraftighet",
    "kraftighets": "kraftighet",
    "kraftigs": "kraftig",
    "kraftigt": "kraftig",
    "kraftigts": "kraftig",
    "kraftkarlar": "kraftkarl",
    "kraftkarlarna": "kraftkarl",
    "kraftkarlarnas": "kraftkarl",
    "kraftkarlars": "kraftkarl",
    "kraftkarlen": "kraftkarl",
    "kraftkarlens": "kraftkarl",
    "kraftkarls": "kraftkarl",
    "kraftkonsumenten": "kraftkonsument",
    "kraftkonsumentens": "kraftkonsument",
    "kraftkonsumenter": "kraftkonsument",
    "kraftkonsumenterna": "kraftkonsument",
    "kraftkonsumenternas": "kraftkonsument",
    "kraftkonsumenters": "kraftkonsument",
    "kraftkonsuments": "kraftkonsument",
    "kraftledningar": "kraftledning",
    "kraftledningarna": "kraftledning",
    "kraftledningarnas": "kraftledning",
    "kraftledningars": "kraftledning",
    "kraftledningen": "kraftledning",
    "kraftledningens": "kraftledning",
    "kraftlednings": "kraftledning",
    "kraftlinjen": "kraftlinje",
    "kraftlinjens": "kraftlinje",
    "kraftlinjer": "kraftlinje",
    "kraftlinjerna": "kraftlinje",
    "kraftlinjernas": "kraftlinje",
    "kraftlinjers": "kraftlinje",
    "kraftlinjes": "kraftlinje",
    "kraftlösa": "kraftlös",
    "kraftlösare": "kraftlös",
    "kraftlösares": "kraftlös",
    "kraftlösas": "kraftlös",
    "kraftlösast": "kraftlös",
    "kraftlösaste": "kraftlös",
    "kraftlösastes": "kraftlös",
    "kraftlösasts": "kraftlös",
    "kraftlöse": "kraftlös",
    "kraftlöses": "kraftlös",
    "kraftlösheten": "kraftlöshet",
    "kraftlöshetens": "kraftlöshet",
    "kraftlösheter": "kraftlöshet",
    "kraftlösheterna": "kraftlöshet",
    "kraftlösheternas": "kraftlöshet",
    "kraftlösheters": "kraftlöshet",
    "kraftlöshets": "kraftlöshet",
    "kraftlöst": "kraftlös",
    "kraftlösts": "kraftlös",
    "kraftmejseln": "kraftmejsel",
    "kraftmejselns": "kraftmejsel",
    "kraftmejsels": "kraftmejsel",
    "kraftmejslar": "kraftmejsel",
    "kraftmejslarna": "kraftmejsel",
    "kraftmejslarnas": "kraftmejsel",
    "kraftmejslars": "kraftmejsel",
    "kraftmätningar": "kraftmätning",
    "kraftmätningarna": "kraftmätning",
    "kraftmätningarnas": "kraftmätning",
    "kraftmätningars": "kraftmätning",
    "kraftmätningen": "kraftmätning",
    "kraftmätningens": "kraftmätning",
    "kraftmätnings": "kraftmätning",
    "kraftnäten": "kraftnät",
    "kraftnätens": "kraftnät",
    "kraftnätet": "kraftnät",
    "kraftnätets": "kraftnät",
    "kraftnäts": "kraftnät",
    "kraftorden": "kraftord",
    "kraftordens": "kraftord",
    "kraftordet": "kraftord",
    "kraftordets": "kraftord",
    "kraftords": "kraftord",
    "kraftpaketen": "kraftpaket",
    "kraftpaketens": "kraftpaket",
    "kraftpaketet": "kraftpaket",
    "kraftpaketets": "kraftpaket",
    "kraftpakets": "kraftpaket",
    "kraftpapperet": "kraftpapper",
    "kraftpapperets": "kraftpapper",
    "kraftpappers": "kraftpapper",
    "kraftpappret": "kraftpapper",
    "kraftpapprets": "kraftpapper",
    "kraftparallellogrammen": "kraftparallellogram",
    "kraftparallellogrammens": "kraftparallellogram",
    "kraftparallellogrammer": "kraftparallellogram",
    "kraftparallellogrammerna": "kraftparallellogram",
    "kraftparallellogrammernas": "kraftparallellogram",
    "kraftparallellogrammers": "kraftparallellogram",
    "kraftparallellograms": "kraftparallellogram",
    "kraftpartikeln": "kraftpartikel",
    "kraftpartikelns": "kraftpartikel",
    "kraftpartikels": "kraftpartikel",
    "kraftpartiklar": "kraftpartikel",
    "kraftpartiklarna": "kraftpartikel",
    "kraftpartiklarnas": "kraftpartikel",
    "kraftpartiklars": "kraftpartikel",
    "kraftproven": "kraftprov",
    "kraftprovens": "kraftprov",
    "kraftprovet": "kraftprov",
    "kraftprovets": "kraftprov",
    "kraftprovs": "kraftprov",
    "krafts": "kraft",
    "kraftsamlad": "kraftsamla",
    "kraftsamlade": "kraftsamla",
    "kraftsamlades": "kraftsamla",
    "kraftsamlads": "kraftsamla",
    "kraftsamlande": "kraftsamla",
    "kraftsamlandes": "kraftsamla",
    "kraftsamlar": "kraftsamla",
    "kraftsamlas": "kraftsamla",
    "kraftsamlat": "kraftsamla",
    "kraftsamlats": "kraftsamla",
    "kraftsporten": "kraftsport",
    "kraftsportens": "kraftsport",
    "kraftsporter": "kraftsport",
    "kraftsporterna": "kraftsport",
    "kraftsporternas": "kraftsport",
    "kraftsporters": "kraftsport",
    "kraftsports": "kraftsport",
    "kraftspråket": "kraftspråk",
    "kraftspråkets": "kraftspråk",
    "kraftspråks": "kraftspråk",
    "kraftstationen": "kraftstation",
    "kraftstationens": "kraftstation",
    "kraftstationer": "kraftstation",
    "kraftstationerna": "kraftstation",
    "kraftstationernas": "kraftstation",
    "kraftstationers": "kraftstation",
    "kraftstations": "kraftstation",
    "krafttagen": "krafttag",
    "krafttagens": "krafttag",
    "krafttaget": "krafttag",
    "krafttagets": "krafttag",
    "krafttags": "krafttag",
    "kraftuttrycken": "kraftuttryck",
    "kraftuttryckens": "kraftuttryck",
    "kraftuttrycket": "kraftuttryck",
    "kraftuttryckets": "kraftuttryck",
    "kraftuttrycks": "kraftuttryck",
    "kraftverken": "kraftverk",
    "kraftverkens": "kraftverk",
    "kraftverket": "kraftverk",
    "kraftverkets": "kraftverk",
    "kraftverks": "kraftverk",
    "kraftverksbyggen": "kraftverksbygge",
    "kraftverksbyggena": "kraftverksbygge",
    "kraftverksbyggenas": "kraftverksbygge",
    "kraftverksbyggens": "kraftverksbygge",
    "kraftverksbygges": "kraftverksbygge",
    "kraftverksbygget": "kraftverksbygge",
    "kraftverksbyggets": "kraftverksbygge",
    "kraftverksdammar": "kraftverksdamm",
    "kraftverksdammarna": "kraftverksdamm",
    "kraftverksdammarnas": "kraftverksdamm",
    "kraftverksdammars": "kraftverksdamm",
    "kraftverksdammen": "kraftverksdamm",
    "kraftverksdammens": "kraftverksdamm",
    "kraftverksdamms": "kraftverksdamm",
    "kraftvunna": "kraftvunnen",
    "kraftvunnare": "kraftvunnen",
    "kraftvunnares": "kraftvunnen",
    "kraftvunnas": "kraftvunnen",
    "kraftvunnast": "kraftvunnen",
    "kraftvunnaste": "kraftvunnen",
    "kraftvunnastes": "kraftvunnen",
    "kraftvunnasts": "kraftvunnen",
    "kraftvunne": "kraftvunnen",
    "kraftvunnens": "kraftvunnen",
    "kraftvunnes": "kraftvunnen",
    "kraftvunnet": "kraftvunnen",
    "kraftvunnets": "kraftvunnen",
    "kraftvärmeverken": "kraftvärmeverk",
    "kraftvärmeverkens": "kraftvärmeverk",
    "kraftvärmeverket": "kraftvärmeverk",
    "kraftvärmeverkets": "kraftvärmeverk",
    "kraftvärmeverks": "kraftvärmeverk",
    "kraftåtgärden": "kraftåtgärd",
    "kraftåtgärdens": "kraftåtgärd",
    "kraftåtgärder": "kraftåtgärd",
    "kraftåtgärderna": "kraftåtgärd",
    "kraftåtgärdernas": "kraftåtgärd",
    "kraftåtgärders": "kraftåtgärd",
    "kraftåtgärds": "kraftåtgärd",
    "kraftöverföringar": "kraftöverföring",
    "kraftöverföringarna": "kraftöverföring",
    "kraftöverföringarnas": "kraftöverföring",
    "kraftöverföringars": "kraftöverföring",
    "kraftöverföringen": "kraftöverföring",
    "kraftöverföringens": "kraftöverföring",
    "kraftöverförings": "kraftöverföring",
    "krag": "krage",
    "kragar": "krage",
    "kragarna": "krage",
    "kragarnas": "krage",
    "kragars": "krage",
    "kragen": "krage",
    "kragens": "krage",
    "krages": "krage",
    "kraghandsk": "kraghandske",
    "kraghandskar": "kraghandske",
    "kraghandskarna": "kraghandske",
    "kraghandskarnas": "kraghandske",
    "kraghandskars": "kraghandske",
    "kraghandsken": "kraghandske",
    "kraghandskens": "kraghandske",
    "kraghandskes": "kraghandske",
    "kragknappar": "kragknapp",
    "kragknapparna": "kragknapp",
    "kragknapparnas": "kragknapp",
    "kragknappars": "kragknapp",
    "kragknappen": "kragknapp",
    "kragknappens": "kragknapp",
    "kragknapps": "kragknapp",
    "kraglösa": "kraglös",
    "kraglösare": "kraglös",
    "kraglösares": "kraglös",
    "kraglösas": "kraglös",
    "kraglösast": "kraglös",
    "kraglösaste": "kraglös",
    "kraglösastes": "kraglös",
    "kraglösasts": "kraglös",
    "kraglöse": "kraglös",
    "kraglöses": "kraglös",
    "kraglösheten": "kraglöshet",
    "kraglöshetens": "kraglöshet",
    "kraglöshets": "kraglöshet",
    "kraglöst": "kraglös",
    "kraglösts": "kraglös",
    "krags": "krage",
    "kragsnibbar": "kragsnibb",
    "kragsnibbarna": "kragsnibb",
    "kragsnibbarnas": "kragsnibb",
    "kragsnibbars": "kragsnibb",
    "kragsnibben": "kragsnibb",
    "kragsnibbens": "kragsnibb",
    "kragsnibbs": "kragsnibb",
    "kragstenar": "kragsten",
    "kragstenarna": "kragsten",
    "kragstenarnas": "kragsten",
    "kragstenars": "kragsten",
    "kragstenen": "kragsten",
    "kragstenens": "kragsten",
    "kragstens": "kragsten",
    "kragstöveln": "kragstövel",
    "kragstövelns": "kragstövel",
    "kragstövels": "kragstövel",
    "kragstövlar": "kragstövel",
    "kragstövlarna": "kragstövel",
    "kragstövlarnas": "kragstövel",
    "kragstövlars": "kragstövel",
    "krak": "krake",
    "krakar": "krake",
    "krakarna": "krake",
    "krakarnas": "krake",
    "krakars": "krake",
    "krakels": "krakel",
    "kraken": "krake",
    "krakens": "krake",
    "krakes": "krake",
    "kraklen": "krakel",
    "kraklens": "krakel",
    "kraklet": "krakel",
    "kraklets": "krakel",
    "krakmandeln": "krakmandel",
    "krakmandelns": "krakmandel",
    "krakmandels": "krakmandel",
    "krakmandlar": "krakmandel",
    "krakmandlarna": "krakmandel",
    "krakmandlarnas": "krakmandel",
    "krakmandlars": "krakmandel",
    "kraks": "krake",
    "kralen": "kral",
    "kralens": "kral",
    "kraler": "kral",
    "kralerna": "kral",
    "kralernas": "kral",
    "kralers": "kral",
    "krals": "kral",
    "kram": "krama",
    "krama": "kram",
    "kramad": "krama",
    "kramade": "krama",
    "kramades": "krama",
    "kramads": "krama",
    "kramande": "krama",
    "kramanden": "kramande",
    "kramandena": "kramande",
    "kramandenas": "kramande",
    "kramandens": "kramande",
    "kramandes": "kramande",
    "kramandet": "kramande",
    "kramandets": "kramande",
    "kramar": "krama",
    "kramare": "kram",
    "kramares": "kram",
    "kramarna": "kram",
    "kramarnas": "kram",
    "kramars": "kram",
    "kramas": "krama",
    "kramast": "kram",
    "kramaste": "kram",
    "kramastes": "kram",
    "kramasts": "kram",
    "kramat": "krama",
    "kramats": "krama",
    "krame": "kram",
    "kramen": "kram",
    "kramens": "kram",
    "krames": "kram",
    "kramet": "kram",
    "kramets": "kram",
    "kramheten": "kramhet",
    "kramhetens": "kramhet",
    "kramhets": "kramhet",
    "kraml": "kramla",
    "kramlan": "kramla",
    "kramlans": "kramla",
    "kramlas": "kramla",
    "kramle": "kramla",
    "kramlor": "kramla",
    "kramlorna": "kramla",
    "kramlornas": "kramla",
    "kramlors": "kramla",
    "kramls": "kramla",
    "kramp": "krampa",
    "krampaktiga": "krampaktig",
    "krampaktigare": "krampaktig",
    "krampaktigares": "krampaktig",
    "krampaktigas": "krampaktig",
    "krampaktigast": "krampaktig",
    "krampaktigaste": "krampaktig",
    "krampaktigastes": "krampaktig",
    "krampaktigasts": "krampaktig",
    "krampaktige": "krampaktig",
    "krampaktiges": "krampaktig",
    "krampaktigheten": "krampaktighet",
    "krampaktighetens": "krampaktighet",
    "krampaktighets": "krampaktighet",
    "krampaktigs": "krampaktig",
    "krampaktigt": "krampaktig",
    "krampaktigts": "krampaktig",
    "krampan": "krampa",
    "krampans": "krampa",
    "krampas": "krampa",
    "krampe": "krampa",
    "krampen": "kramp",
    "krampens": "kramp",
    "kramper": "kramp",
    "kramperna": "kramp",
    "krampernas": "kramp",
    "krampers": "kramp",
    "krampor": "krampa",
    "kramporna": "krampa",
    "krampornas": "krampa",
    "krampors": "krampa",
    "kramps": "krampa",
    "krams": "kram",
    "kramset": "krams",
    "kramsets": "krams",
    "kramsfågeln": "kramsfågel",
    "kramsfågelns": "kramsfågel",
    "kramsfågels": "kramsfågel",
    "kramsfåglar": "kramsfågel",
    "kramsfåglarna": "kramsfågel",
    "kramsfåglarnas": "kramsfågel",
    "kramsfåglars": "kramsfågel",
    "kramsnön": "kramsnö",
    "kramsnöns": "kramsnö",
    "kramsnös": "kramsnö",
    "kramt": "kram",
    "kramts": "kram",
    "kranar": "kran",
    "kranarna": "kran",
    "kranarnas": "kran",
    "kranars": "kran",
    "kranbalkar": "kranbalk",
    "kranbalkarna": "kranbalk",
    "kranbalkarnas": "kranbalk",
    "kranbalkars": "kranbalk",
    "kranbalken": "kranbalk",
    "kranbalkens": "kranbalk",
    "kranbalks": "kranbalk",
    "kranen": "kran",
    "kranens": "kran",
    "kranie": "kranium",
    "kranier": "kranium",
    "kranierna": "kranium",
    "kraniernas": "kranium",
    "kraniers": "kranium",
    "kraniet": "kranium",
    "kraniets": "kranium",
    "kraniums": "kranium",
    "kranka": "krank",
    "krankare": "krank",
    "krankares": "krank",
    "krankas": "krank",
    "krankast": "krank",
    "krankaste": "krank",
    "krankastes": "krank",
    "krankasts": "krank",
    "kranke": "krank",
    "krankes": "krank",
    "krankheten": "krankhet",
    "krankhetens": "krankhet",
    "krankhets": "krankhet",
    "krankikar": "krankik",
    "krankikarna": "krankik",
    "krankikarnas": "krankik",
    "krankikars": "krankik",
    "krankiken": "krankik",
    "krankikens": "krankik",
    "krankiks": "krankik",
    "kranks": "krank",
    "krankt": "krank",
    "krankts": "krank",
    "krans": "kransa",
    "kransad": "kransa",
    "kransade": "kransa",
    "kransades": "kransa",
    "kransads": "kransa",
    "kransande": "kransa",
    "kransanden": "kransande",
    "kransandena": "kransande",
    "kransandenas": "kransande",
    "kransandens": "kransande",
    "kransandes": "kransande",
    "kransandet": "kransande",
    "kransandets": "kransande",
    "kransar": "kransa",
    "kransarna": "krans",
    "kransarnas": "krans",
    "kransars": "krans",
    "kransartären": "kransartär",
    "kransartärens": "kransartär",
    "kransartärer": "kransartär",
    "kransartärerna": "kransartär",
    "kransartärernas": "kransartär",
    "kransartärers": "kransartär",
    "kransartärs": "kransartär",
    "kransas": "kransa",
    "kransat": "kransa",
    "kransats": "kransa",
    "kransbanden": "kransband",
    "kransbandens": "kransband",
    "kransbandet": "kransband",
    "kransbandets": "kransband",
    "kransbands": "kransband",
    "kransen": "krans",
    "kransens": "krans",
    "kranskommunen": "kranskommun",
    "kranskommunens": "kranskommun",
    "kranskommuner": "kranskommun",
    "kranskommunerna": "kranskommun",
    "kranskommunernas": "kranskommun",
    "kranskommuners": "kranskommun",
    "kranskommuns": "kranskommun",
    "kranskull": "kranskulla",
    "kranskullan": "kranskulla",
    "kranskullans": "kranskulla",
    "kranskullas": "kranskulla",
    "kranskulle": "kranskulla",
    "kranskullor": "kranskulla",
    "kranskullorna": "kranskulla",
    "kranskullornas": "kranskulla",
    "kranskullors": "kranskulla",
    "kranskulls": "kranskulla",
    "kranskärlen": "kranskärl",
    "kranskärlens": "kranskärl",
    "kranskärlet": "kranskärl",
    "kranskärlets": "kranskärl",
    "kranskärls": "kranskärl",
    "kransnedläggningar": "kransnedläggning",
    "kransnedläggningarna": "kransnedläggning",
    "kransnedläggningarnas": "kransnedläggning",
    "kransnedläggningars": "kransnedläggning",
    "kransnedläggningen": "kransnedläggning",
    "kransnedläggningens": "kransnedläggning",
    "kransnedläggnings": "kransnedläggning",
    "kranvattens": "kranvatten",
    "kranvattnen": "kranvatten",
    "kranvattnens": "kranvatten",
    "kranvattnet": "kranvatten",
    "kranvattnets": "kranvatten",
    "krappen": "krapp",
    "krappens": "krapp",
    "krapps": "krapp",
    "krasade": "krasa",
    "krasades": "krasa",
    "krasande": "krasa",
    "krasanden": "krasande",
    "krasandena": "krasande",
    "krasandenas": "krasande",
    "krasandens": "krasande",
    "krasandes": "krasande",
    "krasandet": "krasande",
    "krasandets": "krasande",
    "krasar": "krasa",
    "krasas": "krasa",
    "krasat": "krasa",
    "krasats": "krasa",
    "krasch": "krascha",
    "kraschad": "krascha",
    "kraschade": "krascha",
    "kraschades": "krascha",
    "kraschads": "krascha",
    "kraschande": "krascha",
    "kraschanden": "kraschande",
    "kraschandena": "kraschande",
    "kraschandenas": "kraschande",
    "kraschandens": "kraschande",
    "kraschandes": "kraschande",
    "kraschandet": "kraschande",
    "kraschandets": "kraschande",
    "kraschanen": "kraschan",
    "kraschanens": "kraschan",
    "kraschaner": "kraschan",
    "kraschanerna": "kraschan",
    "kraschanernas": "kraschan",
    "kraschaners": "kraschan",
    "kraschans": "kraschan",
    "kraschar": "krascha",
    "kraschas": "krascha",
    "kraschat": "krascha",
    "kraschats": "krascha",
    "kraschen": "krasch",
    "kraschens": "krasch",
    "krascher": "krasch",
    "krascherna": "krasch",
    "kraschernas": "krasch",
    "kraschers": "krasch",
    "kraschet": "krasch",
    "kraschets": "krasch",
    "kraschland": "kraschlanda",
    "kraschlandad": "kraschlanda",
    "kraschlandade": "kraschlanda",
    "kraschlandades": "kraschlanda",
    "kraschlandads": "kraschlanda",
    "kraschlandande": "kraschlanda",
    "kraschlandanden": "kraschlandande",
    "kraschlandandena": "kraschlandande",
    "kraschlandandenas": "kraschlandande",
    "kraschlandandens": "kraschlandande",
    "kraschlandandes": "kraschlandande",
    "kraschlandandet": "kraschlandande",
    "kraschlandandets": "kraschlandande",
    "kraschlandar": "kraschlanda",
    "kraschlandas": "kraschlanda",
    "kraschlandat": "kraschlanda",
    "kraschlandats": "kraschlanda",
    "kraschs": "krasch",
    "kraset": "kras",
    "krasets": "kras",
    "krassa": "krass",
    "krassare": "krass",
    "krassares": "krass",
    "krassas": "krass",
    "krassast": "krass",
    "krassaste": "krass",
    "krassastes": "krass",
    "krassasts": "krass",
    "krasse": "krass",
    "krassen": "krasse",
    "krassens": "krasse",
    "krasses": "krasse",
    "krassheten": "krasshet",
    "krasshetens": "krasshet",
    "krasshets": "krasshet",
    "krassliga": "krasslig",
    "krassligare": "krasslig",
    "krassligares": "krasslig",
    "krassligas": "krasslig",
    "krassligast": "krasslig",
    "krassligaste": "krasslig",
    "krassligastes": "krasslig",
    "krassligasts": "krasslig",
    "krasslige": "krasslig",
    "krassliges": "krasslig",
    "krassligheten": "krasslighet",
    "krasslighetens": "krasslighet",
    "krassligheter": "krasslighet",
    "krassligheterna": "krasslighet",
    "krassligheternas": "krasslighet",
    "krassligheters": "krasslighet",
    "krasslighets": "krasslighet",
    "krassligs": "krasslig",
    "krassligt": "krasslig",
    "krassligts": "krasslig",
    "krasst": "krass",
    "krassts": "krass",
    "kraterbergen": "kraterberg",
    "kraterbergens": "kraterberg",
    "kraterberget": "kraterberg",
    "kraterbergets": "kraterberg",
    "kraterbergs": "kraterberg",
    "kraterbottens": "kraterbotten",
    "kraterbottnar": "kraterbotten",
    "kraterbottnarna": "kraterbotten",
    "kraterbottnarnas": "kraterbotten",
    "kraterbottnars": "kraterbotten",
    "kraterbottnen": "kraterbotten",
    "kraterbottnens": "kraterbotten",
    "kratern": "krater",
    "kraterns": "krater",
    "kraters": "krater",
    "kratersjöar": "kratersjö",
    "kratersjöarna": "kratersjö",
    "kratersjöarnas": "kratersjö",
    "kratersjöars": "kratersjö",
    "kratersjön": "kratersjö",
    "kratersjöns": "kratersjö",
    "kratersjös": "kratersjö",
    "kraterväggar": "kratervägg",
    "kraterväggarna": "kratervägg",
    "kraterväggarnas": "kratervägg",
    "kraterväggars": "kratervägg",
    "kraterväggen": "kratervägg",
    "kraterväggens": "kratervägg",
    "kraterväggs": "kratervägg",
    "krateröppningar": "krateröppning",
    "krateröppningarna": "krateröppning",
    "krateröppningarnas": "krateröppning",
    "krateröppningars": "krateröppning",
    "krateröppningen": "krateröppning",
    "krateröppningens": "krateröppning",
    "krateröppnings": "krateröppning",
    "kratrar": "krater",
    "kratrarna": "krater",
    "kratrarnas": "krater",
    "kratrars": "krater",
    "krats": "kratsa",
    "kratsad": "kratsa",
    "kratsade": "kratsa",
    "kratsades": "kratsa",
    "kratsads": "kratsa",
    "kratsande": "kratsa",
    "kratsanden": "kratsande",
    "kratsandena": "kratsande",
    "kratsandenas": "kratsande",
    "kratsandens": "kratsande",
    "kratsandes": "kratsande",
    "kratsandet": "kratsande",
    "kratsandets": "kratsande",
    "kratsar": "kratsa",
    "kratsarna": "krats",
    "kratsarnas": "krats",
    "kratsars": "krats",
    "kratsas": "kratsa",
    "kratsat": "kratsa",
    "kratsats": "kratsa",
    "kratsen": "krats",
    "kratsens": "krats",
    "kratt": "kratta",
    "krattad": "kratta",
    "krattade": "kratta",
    "krattades": "kratta",
    "krattads": "kratta",
    "krattan": "kratta",
    "krattande": "kratta",
    "krattanden": "krattande",
    "krattandena": "krattande",
    "krattandenas": "krattande",
    "krattandens": "krattande",
    "krattandes": "krattande",
    "krattandet": "krattande",
    "krattandets": "krattande",
    "krattans": "kratta",
    "krattar": "kratta",
    "krattas": "kratta",
    "krattat": "kratta",
    "krattats": "kratta",
    "kratte": "kratta",
    "krattor": "kratta",
    "krattorna": "kratta",
    "krattornas": "kratta",
    "krattors": "kratta",
    "kratts": "kratta",
    "kravallen": "kravall",
    "kravallens": "kravall",
    "kravaller": "kravall",
    "kravallerna": "kravall",
    "kravallernas": "kravall",
    "kravallers": "kravall",
    "kravallpolisen": "kravallpolis",
    "kravallpolisens": "kravallpolis",
    "kravallpoliser": "kravallpolis",
    "kravallpoliserna": "kravallpolis",
    "kravallpolisernas": "kravallpolis",
    "kravallpolisers": "kravallpolis",
    "kravalls": "kravall",
    "kravallsköldar": "kravallsköld",
    "kravallsköldarna": "kravallsköld",
    "kravallsköldarnas": "kravallsköld",
    "kravallsköldars": "kravallsköld",
    "kravallskölden": "kravallsköld",
    "kravallsköldens": "kravallsköld",
    "kravallskölds": "kravallsköld",
    "kravallstaketen": "kravallstaket",
    "kravallstaketens": "kravallstaket",
    "kravallstaketet": "kravallstaket",
    "kravallstaketets": "kravallstaket",
    "kravallstakets": "kravallstaket",
    "kravatten": "kravatt",
    "kravattens": "kravatt",
    "kravatter": "kravatt",
    "kravatterna": "kravatt",
    "kravatternas": "kravatt",
    "kravatters": "kravatt",
    "kravattnålar": "kravattnål",
    "kravattnålarna": "kravattnål",
    "kravattnålarnas": "kravattnål",
    "kravattnålars": "kravattnål",
    "kravattnålen": "kravattnål",
    "kravattnålens": "kravattnål",
    "kravattnåls": "kravattnål",
    "kravatts": "kravatt",
    "kravbreven": "kravbrev",
    "kravbrevens": "kravbrev",
    "kravbrevet": "kravbrev",
    "kravbrevets": "kravbrev",
    "kravbrevs": "kravbrev",
    "kravel": "kravla",
    "kravellen": "kravell",
    "kravellens": "kravell",
    "kraveller": "kravell",
    "kravellerna": "kravell",
    "kravellernas": "kravell",
    "kravellers": "kravell",
    "kravells": "kravell",
    "kraven": "krav",
    "kravens": "krav",
    "kravet": "krav",
    "kravets": "krav",
    "kravlade": "kravla",
    "kravlades": "kravla",
    "kravlande": "kravla",
    "kravlanden": "kravlande",
    "kravlandena": "kravlande",
    "kravlandenas": "kravlande",
    "kravlandens": "kravlande",
    "kravlandes": "kravlande",
    "kravlandet": "kravlande",
    "kravlandets": "kravlande",
    "kravlar": "kravla",
    "kravlas": "kravla",
    "kravlat": "kravla",
    "kravlats": "kravla",
    "kravlösa": "kravlös",
    "kravlösare": "kravlös",
    "kravlösares": "kravlös",
    "kravlösas": "kravlös",
    "kravlösast": "kravlös",
    "kravlösaste": "kravlös",
    "kravlösastes": "kravlös",
    "kravlösasts": "kravlös",
    "kravlöse": "kravlös",
    "kravlöses": "kravlös",
    "kravlösheten": "kravlöshet",
    "kravlöshetens": "kravlöshet",
    "kravlöshets": "kravlöshet",
    "kravlöst": "kravlös",
    "kravlösts": "kravlös",
    "kravmaskinen": "kravmaskin",
    "kravmaskinens": "kravmaskin",
    "kravmaskiner": "kravmaskin",
    "kravmaskinerna": "kravmaskin",
    "kravmaskinernas": "kravmaskin",
    "kravmaskiners": "kravmaskin",
    "kravmaskins": "kravmaskin",
    "kravs": "krav",
    "kraxade": "kraxa",
    "kraxades": "kraxa",
    "kraxande": "kraxa",
    "kraxanden": "kraxande",
    "kraxandena": "kraxande",
    "kraxandenas": "kraxande",
    "kraxandens": "kraxande",
    "kraxandes": "kraxande",
    "kraxandet": "kraxande",
    "kraxandets": "kraxande",
    "kraxar": "kraxa",
    "kraxas": "kraxa",
    "kraxat": "kraxa",
    "kraxats": "kraxa",
    "kraxen": "krax",
    "kraxens": "krax",
    "kraxet": "krax",
    "kraxets": "krax",
    "kreationen": "kreation",
    "kreationens": "kreation",
    "kreationer": "kreation",
    "kreationerna": "kreation",
    "kreationernas": "kreation",
    "kreationers": "kreation",
    "kreationismen": "kreationism",
    "kreationismens": "kreationism",
    "kreationisms": "kreationism",
    "kreationistiska": "kreationistisk",
    "kreationistiskas": "kreationistisk",
    "kreationistiske": "kreationistisk",
    "kreationistiskes": "kreationistisk",
    "kreationistisks": "kreationistisk",
    "kreationistiskt": "kreationistisk",
    "kreationistiskts": "kreationistisk",
    "kreations": "kreation",
    "kreativa": "kreativ",
    "kreativare": "kreativ",
    "kreativares": "kreativ",
    "kreativas": "kreativ",
    "kreativast": "kreativ",
    "kreativaste": "kreativ",
    "kreativastes": "kreativ",
    "kreativasts": "kreativ",
    "kreative": "kreativ",
    "kreatives": "kreativ",
    "kreativiteten": "kreativitet",
    "kreativitetens": "kreativitet",
    "kreativiteter": "kreativitet",
    "kreativiteterna": "kreativitet",
    "kreativiteternas": "kreativitet",
    "kreativiteters": "kreativitet",
    "kreativitets": "kreativitet",
    "kreativs": "kreativ",
    "kreativt": "kreativ",
    "kreativts": "kreativ",
    "kreaturen": "kreatur",
    "kreaturens": "kreatur",
    "kreaturet": "kreatur",
    "kreaturets": "kreatur",
    "kreaturs": "kreatur",
    "kreatursbesättningar": "kreatursbesättning",
    "kreatursbesättningarna": "kreatursbesättning",
    "kreatursbesättningarnas": "kreatursbesättning",
    "kreatursbesättningars": "kreatursbesättning",
    "kreatursbesättningen": "kreatursbesättning",
    "kreatursbesättningens": "kreatursbesättning",
    "kreatursbesättnings": "kreatursbesättning",
    "kreaturslösa": "kreaturslös",
    "kreaturslösare": "kreaturslös",
    "kreaturslösares": "kreaturslös",
    "kreaturslösas": "kreaturslös",
    "kreaturslösast": "kreaturslös",
    "kreaturslösaste": "kreaturslös",
    "kreaturslösastes": "kreaturslös",
    "kreaturslösasts": "kreaturslös",
    "kreaturslöse": "kreaturslös",
    "kreaturslöses": "kreaturslös",
    "kreaturslösheten": "kreaturslöshet",
    "kreaturslöshetens": "kreaturslöshet",
    "kreaturslöshets": "kreaturslöshet",
    "kreaturslöst": "kreaturslös",
    "kreaturslösts": "kreaturslös",
    "kredden": "kredd",
    "kreddens": "kredd",
    "kreddiga": "kreddig",
    "kreddigare": "kreddig",
    "kreddigares": "kreddig",
    "kreddigas": "kreddig",
    "kreddigast": "kreddig",
    "kreddigaste": "kreddig",
    "kreddigastes": "kreddig",
    "kreddigasts": "kreddig",
    "kreddige": "kreddig",
    "kreddiges": "kreddig",
    "kreddigheten": "kreddighet",
    "kreddighetens": "kreddighet",
    "kreddighets": "kreddighet",
    "kreddigs": "kreddig",
    "kreddigt": "kreddig",
    "kreddigts": "kreddig",
    "kredds": "kredd",
    "kredens": "kredensa",
    "kredensad": "kredensa",
    "kredensade": "kredensa",
    "kredensades": "kredensa",
    "kredensads": "kredensa",
    "kredensande": "kredensa",
    "kredensanden": "kredensande",
    "kredensandena": "kredensande",
    "kredensandenas": "kredensande",
    "kredensandens": "kredensande",
    "kredensandes": "kredensande",
    "kredensandet": "kredensande",
    "kredensandets": "kredensande",
    "kredensar": "kredensa",
    "kredensas": "kredensa",
    "kredensat": "kredensa",
    "kredensats": "kredensa",
    "krediten": "kredit",
    "kreditens": "kredit",
    "krediter": "kredit",
    "krediterad": "kreditera",
    "krediterade": "kreditera",
    "krediterades": "kreditera",
    "krediterads": "kreditera",
    "krediterande": "kreditera",
    "krediteranden": "krediterande",
    "krediterandena": "krediterande",
    "krediterandenas": "krediterande",
    "krediterandens": "krediterande",
    "krediterandes": "krediterande",
    "krediterandet": "krediterande",
    "krediterandets": "krediterande",
    "krediterar": "kreditera",
    "krediteras": "kreditera",
    "krediterat": "kreditera",
    "krediterats": "kreditera",
    "krediterbara": "krediterbar",
    "krediterbarare": "krediterbar",
    "krediterbarares": "krediterbar",
    "krediterbaras": "krediterbar",
    "krediterbarast": "krediterbar",
    "krediterbaraste": "krediterbar",
    "krediterbarastes": "krediterbar",
    "krediterbarasts": "krediterbar",
    "krediterbare": "krediterbar",
    "krediterbares": "krediterbar",
    "krediterbarheten": "krediterbarhet",
    "krediterbarhetens": "krediterbarhet",
    "krediterbarhets": "krediterbarhet",
    "krediterbars": "krediterbar",
    "krediterbart": "krediterbar",
    "krediterbarts": "krediterbar",
    "krediteringar": "kreditering",
    "krediteringarna": "kreditering",
    "krediteringarnas": "kreditering",
    "krediteringars": "kreditering",
    "krediteringen": "kreditering",
    "krediteringens": "kreditering",
    "krediterings": "kreditering",
    "krediterna": "kredit",
    "krediternas": "kredit",
    "krediters": "kredit",
    "kreditförlusten": "kreditförlust",
    "kreditförlustens": "kreditförlust",
    "kreditförluster": "kreditförlust",
    "kreditförlusterna": "kreditförlust",
    "kreditförlusternas": "kreditförlust",
    "kreditförlusters": "kreditförlust",
    "kreditförlusts": "kreditförlust",
    "kreditgivningar": "kreditgivning",
    "kreditgivningarna": "kreditgivning",
    "kreditgivningarnas": "kreditgivning",
    "kreditgivningars": "kreditgivning",
    "kreditgivningen": "kreditgivning",
    "kreditgivningens": "kreditgivning",
    "kreditgivnings": "kreditgivning",
    "kreditinstituten": "kreditinstitut",
    "kreditinstitutens": "kreditinstitut",
    "kreditinstitutet": "kreditinstitut",
    "kreditinstitutets": "kreditinstitut",
    "kreditinstituts": "kreditinstitut",
    "kreditiven": "kreditiv",
    "kreditivens": "kreditiv",
    "kreditivet": "kreditiv",
    "kreditivets": "kreditiv",
    "kreditivs": "kreditiv",
    "kreditkorten": "kreditkort",
    "kreditkortens": "kreditkort",
    "kreditkortet": "kreditkort",
    "kreditkortets": "kreditkort",
    "kreditkorts": "kreditkort",
    "kreditmarknaden": "kreditmarknad",
    "kreditmarknadens": "kreditmarknad",
    "kreditmarknader": "kreditmarknad",
    "kreditmarknaderna": "kreditmarknad",
    "kreditmarknadernas": "kreditmarknad",
    "kreditmarknaders": "kreditmarknad",
    "kreditmarknads": "kreditmarknad",
    "kreditorer": "kreditor",
    "kreditorerna": "kreditor",
    "kreditorernas": "kreditor",
    "kreditorers": "kreditor",
    "kreditorn": "kreditor",
    "kreditorns": "kreditor",
    "kreditors": "kreditor",
    "kredits": "kredit",
    "kreditupplysningar": "kreditupplysning",
    "kreditupplysningarna": "kreditupplysning",
    "kreditupplysningarnas": "kreditupplysning",
    "kreditupplysningars": "kreditupplysning",
    "kreditupplysningen": "kreditupplysning",
    "kreditupplysningens": "kreditupplysning",
    "kreditupplysnings": "kreditupplysning",
    "kreditvillkoren": "kreditvillkor",
    "kreditvillkorens": "kreditvillkor",
    "kreditvillkoret": "kreditvillkor",
    "kreditvillkorets": "kreditvillkor",
    "kreditvillkors": "kreditvillkor",
    "kreditvärderingar": "kreditvärdering",
    "kreditvärderingarna": "kreditvärdering",
    "kreditvärderingarnas": "kreditvärdering",
    "kreditvärderingars": "kreditvärdering",
    "kreditvärderingen": "kreditvärdering",
    "kreditvärderingens": "kreditvärdering",
    "kreditvärderings": "kreditvärdering",
    "kreditvärderingsinstituten": "kreditvärderingsinstitut",
    "kreditvärderingsinstitutens": "kreditvärderingsinstitut",
    "kreditvärderingsinstitutet": "kreditvärderingsinstitut",
    "kreditvärderingsinstitutets": "kreditvärderingsinstitut",
    "kreditvärderingsinstituts": "kreditvärderingsinstitut",
    "kreditåtstramningar": "kreditåtstramning",
    "kreditåtstramningarna": "kreditåtstramning",
    "kreditåtstramningarnas": "kreditåtstramning",
    "kreditåtstramningars": "kreditåtstramning",
    "kreditåtstramningen": "kreditåtstramning",
    "kreditåtstramningens": "kreditåtstramning",
    "kreditåtstramnings": "kreditåtstramning",
    "kreerad": "kreera",
    "kreerade": "kreera",
    "kreerades": "kreera",
    "kreerads": "kreera",
    "kreerande": "kreera",
    "kreeranden": "kreerande",
    "kreerandena": "kreerande",
    "kreerandenas": "kreerande",
    "kreerandens": "kreerande",
    "kreerandes": "kreerande",
    "kreerandet": "kreerande",
    "kreerandets": "kreerande",
    "kreerar": "kreera",
    "kreeras": "kreera",
    "kreerat": "kreera",
    "kreerats": "kreera",
    "kreerbara": "kreerbar",
    "kreerbarare": "kreerbar",
    "kreerbarares": "kreerbar",
    "kreerbaras": "kreerbar",
    "kreerbarast": "kreerbar",
    "kreerbaraste": "kreerbar",
    "kreerbarastes": "kreerbar",
    "kreerbarasts": "kreerbar",
    "kreerbare": "kreerbar",
    "kreerbares": "kreerbar",
    "kreerbarheten": "kreerbarhet",
    "kreerbarhetens": "kreerbarhet",
    "kreerbarhets": "kreerbarhet",
    "kreerbars": "kreerbar",
    "kreerbart": "kreerbar",
    "kreerbarts": "kreerbar",
    "kreeringar": "kreering",
    "kreeringarna": "kreering",
    "kreeringarnas": "kreering",
    "kreeringars": "kreering",
    "kreeringen": "kreering",
    "kreeringens": "kreering",
    "kreerings": "kreering",
    "krematorie": "krematorium",
    "krematorier": "krematorium",
    "krematorierna": "krematorium",
    "krematoriernas": "krematorium",
    "krematoriers": "krematorium",
    "krematoriet": "krematorium",
    "krematoriets": "krematorium",
    "krematoriums": "krematorium",
    "kremerad": "kremera",
    "kremerade": "kremera",
    "kremerades": "kremera",
    "kremerads": "kremera",
    "kremerande": "kremera",
    "kremeranden": "kremerande",
    "kremerandena": "kremerande",
    "kremerandenas": "kremerande",
    "kremerandens": "kremerande",
    "kremerandes": "kremerande",
    "kremerandet": "kremerande",
    "kremerandets": "kremerande",
    "kremerar": "kremera",
    "kremeras": "kremera",
    "kremerat": "kremera",
    "kremerats": "kremera",
    "kremerbara": "kremerbar",
    "kremerbarare": "kremerbar",
    "kremerbarares": "kremerbar",
    "kremerbaras": "kremerbar",
    "kremerbarast": "kremerbar",
    "kremerbaraste": "kremerbar",
    "kremerbarastes": "kremerbar",
    "kremerbarasts": "kremerbar",
    "kremerbare": "kremerbar",
    "kremerbares": "kremerbar",
    "kremerbarheten": "kremerbarhet",
    "kremerbarhetens": "kremerbarhet",
    "kremerbarhets": "kremerbarhet",
    "kremerbars": "kremerbar",
    "kremerbart": "kremerbar",
    "kremerbarts": "kremerbar",
    "kremeringar": "kremering",
    "kremeringarna": "kremering",
    "kremeringarnas": "kremering",
    "kremeringars": "kremering",
    "kremeringen": "kremering",
    "kremeringens": "kremering",
    "kremerings": "kremering",
    "kreml": "kremla",
    "kremlan": "kremla",
    "kremlans": "kremla",
    "kremlas": "kremla",
    "kremle": "kremla",
    "kremlologen": "kremlolog",
    "kremlologens": "kremlolog",
    "kremlologer": "kremlolog",
    "kremlologerna": "kremlolog",
    "kremlologernas": "kremlolog",
    "kremlologers": "kremlolog",
    "kremlologs": "kremlolog",
    "kremlor": "kremla",
    "kremlorna": "kremla",
    "kremlornas": "kremla",
    "kremlors": "kremla",
    "kremls": "kremla",
    "kremservitts": "kremservitt",
    "krenelerade": "krenelerad",
    "krenelerades": "krenelerad",
    "krenelerads": "krenelerad",
    "krenelerat": "krenelerad",
    "krenelerats": "krenelerad",
    "kreneleringar": "krenelering",
    "kreneleringarna": "krenelering",
    "kreneleringarnas": "krenelering",
    "kreneleringars": "krenelering",
    "kreneleringen": "krenelering",
    "kreneleringens": "krenelering",
    "krenelerings": "krenelering",
    "kreolen": "kreol",
    "kreolens": "kreol",
    "kreoler": "kreol",
    "kreolerna": "kreol",
    "kreolernas": "kreol",
    "kreolers": "kreol",
    "kreolinslagen": "kreolinslag",
    "kreolinslagens": "kreolinslag",
    "kreolinslaget": "kreolinslag",
    "kreolinslagets": "kreolinslag",
    "kreolinslags": "kreolinslag",
    "kreols": "kreol",
    "kreolsk": "kreolska",
    "kreolskan": "kreolska",
    "kreolskans": "kreolska",
    "kreolskas": "kreolska",
    "kreolske": "kreolska",
    "kreolskor": "kreolska",
    "kreolskorna": "kreolska",
    "kreolskornas": "kreolska",
    "kreolskors": "kreolska",
    "kreolspråken": "kreolspråk",
    "kreolspråkens": "kreolspråk",
    "kreolspråket": "kreolspråk",
    "kreolspråkets": "kreolspråk",
    "kreolspråks": "kreolspråk",
    "kreosotoljan": "kreosotolja",
    "kreosotoljans": "kreosotolja",
    "kreosotoljas": "kreosotolja",
    "kreosotolje": "kreosotolja",
    "kreosotoljor": "kreosotolja",
    "kreosotoljorna": "kreosotolja",
    "kreosotoljornas": "kreosotolja",
    "kreosotoljors": "kreosotolja",
    "kreperad": "krepera",
    "kreperade": "krepera",
    "kreperades": "krepera",
    "kreperads": "krepera",
    "kreperande": "krepera",
    "kreperanden": "kreperande",
    "kreperandena": "kreperande",
    "kreperandenas": "kreperande",
    "kreperandens": "kreperande",
    "kreperandes": "kreperande",
    "kreperandet": "kreperande",
    "kreperandets": "kreperande",
    "kreperar": "krepera",
    "kreperas": "krepera",
    "kreperat": "krepera",
    "kreperats": "krepera",
    "kreperbara": "kreperbar",
    "kreperbarare": "kreperbar",
    "kreperbarares": "kreperbar",
    "kreperbaras": "kreperbar",
    "kreperbarast": "kreperbar",
    "kreperbaraste": "kreperbar",
    "kreperbarastes": "kreperbar",
    "kreperbarasts": "kreperbar",
    "kreperbare": "kreperbar",
    "kreperbares": "kreperbar",
    "kreperbarheten": "kreperbarhet",
    "kreperbarhetens": "kreperbarhet",
    "kreperbarhets": "kreperbarhet",
    "kreperbars": "kreperbar",
    "kreperbart": "kreperbar",
    "kreperbarts": "kreperbar",
    "kreperingar": "krepering",
    "kreperingarna": "krepering",
    "kreperingarnas": "krepering",
    "kreperingars": "krepering",
    "kreperingen": "krepering",
    "kreperingens": "krepering",
    "kreperings": "krepering",
    "krestomatien": "krestomati",
    "krestomatiens": "krestomati",
    "krestomatier": "krestomati",
    "krestomatierna": "krestomati",
    "krestomatiernas": "krestomati",
    "krestomatiers": "krestomati",
    "krestomatin": "krestomati",
    "krestomatins": "krestomati",
    "krestomatis": "krestomati",
    "kret": "kreta",
    "kretad": "kreta",
    "kretade": "kreta",
    "kretades": "kreta",
    "kretads": "kreta",
    "kretande": "kreta",
    "kretanden": "kretande",
    "kretandena": "kretande",
    "kretandenas": "kretande",
    "kretandens": "kretande",
    "kretandes": "kretande",
    "kretandet": "kretande",
    "kretandets": "kretande",
    "kretar": "kreta",
    "kretas": "kreta",
    "kretat": "kreta",
    "kretats": "kreta",
    "kretensar": "kretensare",
    "kretensaren": "kretensare",
    "kretensarens": "kretensare",
    "kretensares": "kretensare",
    "kretensarna": "kretensare",
    "kretensarnas": "kretensare",
    "kretensiska": "kretensisk",
    "kretensiskare": "kretensisk",
    "kretensiskares": "kretensisk",
    "kretensiskas": "kretensisk",
    "kretensiskast": "kretensisk",
    "kretensiskaste": "kretensisk",
    "kretensiskastes": "kretensisk",
    "kretensiskasts": "kretensisk",
    "kretensiske": "kretensisk",
    "kretensiskes": "kretensisk",
    "kretensisks": "kretensisk",
    "kretensiskt": "kretensisk",
    "kretensiskts": "kretensisk",
    "kretern": "kreter",
    "kreterna": "kreter",
    "kreternas": "kreter",
    "kreterns": "kreter",
    "kreters": "kreter",
    "kretinen": "kretin",
    "kretinens": "kretin",
    "kretiner": "kretin",
    "kretinerna": "kretin",
    "kretinernas": "kretin",
    "kretiners": "kretin",
    "kretinismen": "kretinism",
    "kretinismens": "kretinism",
    "kretinismer": "kretinism",
    "kretinismerna": "kretinism",
    "kretinismernas": "kretinism",
    "kretinismers": "kretinism",
    "kretinisms": "kretinism",
    "kretins": "kretin",
    "kretiska": "kretisk",
    "kretiskare": "kretisk",
    "kretiskares": "kretisk",
    "kretiskas": "kretisk",
    "kretiskast": "kretisk",
    "kretiskaste": "kretisk",
    "kretiskastes": "kretisk",
    "kretiskasts": "kretisk",
    "kretiske": "kretisk",
    "kretiskes": "kretisk",
    "kretisks": "kretisk",
    "kretiskt": "kretisk",
    "kretiskts": "kretisk",
    "kretongen": "kretong",
    "kretongens": "kretong",
    "kretonger": "kretong",
    "kretongerna": "kretong",
    "kretongernas": "kretong",
    "kretongers": "kretong",
    "kretongs": "kretong",
    "krets": "kretsa",
    "kretsade": "kretsa",
    "kretsades": "kretsa",
    "kretsande": "kretsa",
    "kretsanden": "kretsande",
    "kretsandena": "kretsande",
    "kretsandenas": "kretsande",
    "kretsandens": "kretsande",
    "kretsandes": "kretsande",
    "kretsandet": "kretsande",
    "kretsandets": "kretsande",
    "kretsar": "kretsa",
    "kretsarna": "krets",
    "kretsarnas": "krets",
    "kretsars": "krets",
    "kretsas": "kretsa",
    "kretsat": "kretsa",
    "kretsats": "kretsa",
    "kretsen": "krets",
    "kretsens": "krets",
    "kretsgångar": "kretsgång",
    "kretsgångarna": "kretsgång",
    "kretsgångarnas": "kretsgång",
    "kretsgångars": "kretsgång",
    "kretsgången": "kretsgång",
    "kretsgångens": "kretsgång",
    "kretsgångs": "kretsgång",
    "kretskorten": "kretskort",
    "kretskortens": "kretskort",
    "kretskortet": "kretskort",
    "kretskortets": "kretskort",
    "kretskorts": "kretskort",
    "kretsloppen": "kretslopp",
    "kretsloppens": "kretslopp",
    "kretsloppet": "kretslopp",
    "kretsloppets": "kretslopp",
    "kretslopps": "kretslopp",
    "kretsloppssamhällen": "kretsloppssamhälle",
    "kretsloppssamhällena": "kretsloppssamhälle",
    "kretsloppssamhällenas": "kretsloppssamhälle",
    "kretsloppssamhällens": "kretsloppssamhälle",
    "kretsloppssamhälles": "kretsloppssamhälle",
    "kretsloppssamhället": "kretsloppssamhälle",
    "kretsloppssamhällets": "kretsloppssamhälle",
    "kretsloppssamhälls": "kretsloppssamhälle",
    "krevadblixtar": "krevadblixt",
    "krevadblixtarna": "krevadblixt",
    "krevadblixtarnas": "krevadblixt",
    "krevadblixtars": "krevadblixt",
    "krevadblixten": "krevadblixt",
    "krevadblixtens": "krevadblixt",
    "krevadblixts": "krevadblixt",
    "krevaden": "krevad",
    "krevadens": "krevad",
    "krevader": "krevad",
    "krevaderna": "krevad",
    "krevadernas": "krevad",
    "krevaders": "krevad",
    "krevadmolnen": "krevadmoln",
    "krevadmolnens": "krevadmoln",
    "krevadmolnet": "krevadmoln",
    "krevadmolnets": "krevadmoln",
    "krevadmolns": "krevadmoln",
    "krevads": "krevad",
    "kreverad": "krevera",
    "kreverade": "krevera",
    "kreverades": "krevera",
    "kreverads": "krevera",
    "kreverande": "krevera",
    "kreveranden": "kreverande",
    "kreverandena": "kreverande",
    "kreverandenas": "kreverande",
    "kreverandens": "kreverande",
    "kreverandes": "kreverande",
    "kreverandet": "kreverande",
    "kreverandets": "kreverande",
    "kreverar": "krevera",
    "kreveras": "krevera",
    "kreverat": "krevera",
    "kreverats": "krevera",
    "kreverbara": "kreverbar",
    "kreverbarare": "kreverbar",
    "kreverbarares": "kreverbar",
    "kreverbaras": "kreverbar",
    "kreverbarast": "kreverbar",
    "kreverbaraste": "kreverbar",
    "kreverbarastes": "kreverbar",
    "kreverbarasts": "kreverbar",
    "kreverbare": "kreverbar",
    "kreverbares": "kreverbar",
    "kreverbarheten": "kreverbarhet",
    "kreverbarhetens": "kreverbarhet",
    "kreverbarhets": "kreverbarhet",
    "kreverbars": "kreverbar",
    "kreverbart": "kreverbar",
    "kreverbarts": "kreverbar",
    "kreveringar": "krevering",
    "kreveringarna": "krevering",
    "kreveringarnas": "krevering",
    "kreveringars": "krevering",
    "kreveringen": "krevering",
    "kreveringens": "krevering",
    "kreverings": "krevering",
    "kri": "kria",
    "krian": "kria",
    "krians": "kria",
    "krias": "kria",
    "krick": "kricka",
    "krickan": "kricka",
    "krickans": "kricka",
    "krickas": "kricka",
    "kricke": "kricka",
    "kricketen": "kricket",
    "kricketens": "kricket",
    "krickets": "kricket",
    "krickor": "kricka",
    "krickorna": "kricka",
    "krickornas": "kricka",
    "krickors": "kricka",
    "kricks": "kricka",
    "krie": "kria",
    "krig": "kriga",
    "krigade": "kriga",
    "krigades": "kriga",
    "krigande": "kriga",
    "kriganden": "krigande",
    "krigandena": "krigande",
    "krigandenas": "krigande",
    "krigandens": "krigande",
    "krigandes": "krigande",
    "krigandet": "krigande",
    "krigandets": "krigande",
    "krigar": "krigare",
    "krigaradeln": "krigaradel",
    "krigaradelns": "krigaradel",
    "krigaradels": "krigaradel",
    "krigaren": "krigare",
    "krigarens": "krigare",
    "krigares": "krigare",
    "krigargravar": "krigargrav",
    "krigargravarna": "krigargrav",
    "krigargravarnas": "krigargrav",
    "krigargravars": "krigargrav",
    "krigargraven": "krigargrav",
    "krigargravens": "krigargrav",
    "krigargravs": "krigargrav",
    "krigarkasten": "krigarkast",
    "krigarkastens": "krigarkast",
    "krigarkasts": "krigarkast",
    "krigarna": "krigare",
    "krigarnas": "krigare",
    "krigas": "kriga",
    "krigat": "kriga",
    "krigats": "kriga",
    "krigen": "krig",
    "krigens": "krig",
    "kriget": "krig",
    "krigets": "krig",
    "krigföringar": "krigföring",
    "krigföringarna": "krigföring",
    "krigföringarnas": "krigföring",
    "krigföringars": "krigföring",
    "krigföringen": "krigföring",
    "krigföringens": "krigföring",
    "krigförings": "krigföring",
    "krigiska": "krigisk",
    "krigiskare": "krigisk",
    "krigiskares": "krigisk",
    "krigiskas": "krigisk",
    "krigiskast": "krigisk",
    "krigiskaste": "krigisk",
    "krigiskastes": "krigisk",
    "krigiskasts": "krigisk",
    "krigiske": "krigisk",
    "krigiskes": "krigisk",
    "krigisks": "krigisk",
    "krigiskt": "krigisk",
    "krigiskts": "krigisk",
    "krigs": "krig",
    "krigsbarnen": "krigsbarn",
    "krigsbarnens": "krigsbarn",
    "krigsbarnet": "krigsbarn",
    "krigsbarnets": "krigsbarn",
    "krigsbarns": "krigsbarn",
    "krigsberedskapen": "krigsberedskap",
    "krigsberedskapens": "krigsberedskap",
    "krigsberedskaper": "krigsberedskap",
    "krigsberedskaperna": "krigsberedskap",
    "krigsberedskapernas": "krigsberedskap",
    "krigsberedskapers": "krigsberedskap",
    "krigsberedskaps": "krigsberedskap",
    "krigsbrotten": "krigsbrott",
    "krigsbrottens": "krigsbrott",
    "krigsbrottet": "krigsbrott",
    "krigsbrottets": "krigsbrott",
    "krigsbrotts": "krigsbrott",
    "krigsbrottstribunalen": "krigsbrottstribunal",
    "krigsbrottstribunalens": "krigsbrottstribunal",
    "krigsbrottstribunaler": "krigsbrottstribunal",
    "krigsbrottstribunalerna": "krigsbrottstribunal",
    "krigsbrottstribunalernas": "krigsbrottstribunal",
    "krigsbrottstribunalers": "krigsbrottstribunal",
    "krigsbrottstribunals": "krigsbrottstribunal",
    "krigsbussar": "krigsbuss",
    "krigsbussarna": "krigsbuss",
    "krigsbussarnas": "krigsbuss",
    "krigsbussars": "krigsbuss",
    "krigsbussen": "krigsbuss",
    "krigsbussens": "krigsbuss",
    "krigsbyten": "krigsbyte",
    "krigsbytena": "krigsbyte",
    "krigsbytenas": "krigsbyte",
    "krigsbytens": "krigsbyte",
    "krigsbytes": "krigsbyte",
    "krigsbytet": "krigsbyte",
    "krigsbytets": "krigsbyte",
    "krigsdagboken": "krigsdagbok",
    "krigsdagbokens": "krigsdagbok",
    "krigsdagboks": "krigsdagbok",
    "krigsdagböcker": "krigsdagbok",
    "krigsdagböckerna": "krigsdagbok",
    "krigsdagböckernas": "krigsdagbok",
    "krigsdagböckers": "krigsdagbok",
    "krigsdansen": "krigsdans",
    "krigsdansens": "krigsdans",
    "krigsdanser": "krigsdans",
    "krigsdanserna": "krigsdans",
    "krigsdansernas": "krigsdans",
    "krigsdansers": "krigsdans",
    "krigsdekorationen": "krigsdekoration",
    "krigsdekorationens": "krigsdekoration",
    "krigsdekorationer": "krigsdekoration",
    "krigsdekorationerna": "krigsdekoration",
    "krigsdekorationernas": "krigsdekoration",
    "krigsdekorationers": "krigsdekoration",
    "krigsdekorations": "krigsdekoration",
    "krigsdiamanten": "krigsdiamant",
    "krigsdiamantens": "krigsdiamant",
    "krigsdiamanter": "krigsdiamant",
    "krigsdiamanterna": "krigsdiamant",
    "krigsdiamanternas": "krigsdiamant",
    "krigsdiamanters": "krigsdiamant",
    "krigsdiamants": "krigsdiamant",
    "krigsfartygen": "krigsfartyg",
    "krigsfartygens": "krigsfartyg",
    "krigsfartyget": "krigsfartyg",
    "krigsfartygets": "krigsfartyg",
    "krigsfartygs": "krigsfartyg",
    "krigsflott": "krigsflotta",
    "krigsflottan": "krigsflotta",
    "krigsflottans": "krigsflotta",
    "krigsflottas": "krigsflotta",
    "krigsflotte": "krigsflotta",
    "krigsflottor": "krigsflotta",
    "krigsflottorna": "krigsflotta",
    "krigsflottornas": "krigsflotta",
    "krigsflottors": "krigsflotta",
    "krigsflotts": "krigsflotta",
    "krigsfots": "krigsfot",
    "krigsfångar": "krigsfånge",
    "krigsfångarna": "krigsfånge",
    "krigsfångarnas": "krigsfånge",
    "krigsfångars": "krigsfånge",
    "krigsfången": "krigsfånge",
    "krigsfångens": "krigsfånge",
    "krigsfånges": "krigsfånge",
    "krigsförbrytar": "krigsförbrytare",
    "krigsförbrytaren": "krigsförbrytare",
    "krigsförbrytarens": "krigsförbrytare",
    "krigsförbrytares": "krigsförbrytare",
    "krigsförbrytarna": "krigsförbrytare",
    "krigsförbrytarnas": "krigsförbrytare",
    "krigsförbrytartribunalen": "krigsförbrytartribunal",
    "krigsförbrytartribunalens": "krigsförbrytartribunal",
    "krigsförbrytartribunaler": "krigsförbrytartribunal",
    "krigsförbrytartribunalerna": "krigsförbrytartribunal",
    "krigsförbrytartribunalernas": "krigsförbrytartribunal",
    "krigsförbrytartribunalers": "krigsförbrytartribunal",
    "krigsförbrytartribunals": "krigsförbrytartribunal",
    "krigsförbrytelsen": "krigsförbrytelse",
    "krigsförbrytelsens": "krigsförbrytelse",
    "krigsförbrytelser": "krigsförbrytelse",
    "krigsförbrytelserna": "krigsförbrytelse",
    "krigsförbrytelsernas": "krigsförbrytelse",
    "krigsförbrytelsers": "krigsförbrytelse",
    "krigsförbrytelses": "krigsförbrytelse",
    "krigsförklaringar": "krigsförklaring",
    "krigsförklaringarna": "krigsförklaring",
    "krigsförklaringarnas": "krigsförklaring",
    "krigsförklaringars": "krigsförklaring",
    "krigsförklaringen": "krigsförklaring",
    "krigsförklaringens": "krigsförklaring",
    "krigsförklarings": "krigsförklaring",
    "krigsgudar": "krigsgud",
    "krigsgudarna": "krigsgud",
    "krigsgudarnas": "krigsgud",
    "krigsgudars": "krigsgud",
    "krigsguden": "krigsgud",
    "krigsgudens": "krigsgud",
    "krigsgudinnan": "krigsgudinna",
    "krigsgudinnans": "krigsgudinna",
    "krigsgudinnas": "krigsgudinna",
    "krigsgudinne": "krigsgudinna",
    "krigsgudinnor": "krigsgudinna",
    "krigsgudinnorna": "krigsgudinna",
    "krigsgudinnornas": "krigsgudinna",
    "krigsgudinnors": "krigsgudinna",
    "krigsguds": "krigsgud",
    "krigsherrar": "krigsherre",
    "krigsherrarna": "krigsherre",
    "krigsherrarnas": "krigsherre",
    "krigsherrars": "krigsherre",
    "krigsherren": "krigsherre",
    "krigsherrens": "krigsherre",
    "krigsherres": "krigsherre",
    "krigshetsar": "krigshetsare",
    "krigshetsaren": "krigshetsare",
    "krigshetsarens": "krigshetsare",
    "krigshetsares": "krigshetsare",
    "krigshetsarna": "krigshetsare",
    "krigshetsarnas": "krigshetsare",
    "krigshierarkien": "krigshierarki",
    "krigshierarkiens": "krigshierarki",
    "krigshierarkier": "krigshierarki",
    "krigshierarkierna": "krigshierarki",
    "krigshierarkiernas": "krigshierarki",
    "krigshierarkiers": "krigshierarki",
    "krigshierarkin": "krigshierarki",
    "krigshierarkins": "krigshierarki",
    "krigshierarkis": "krigshierarki",
    "krigshjältar": "krigshjälte",
    "krigshjältarna": "krigshjälte",
    "krigshjältarnas": "krigshjälte",
    "krigshjältars": "krigshjälte",
    "krigshjälten": "krigshjälte",
    "krigshjältens": "krigshjälte",
    "krigshjältes": "krigshjälte",
    "krigshärjade": "krigshärjad",
    "krigshärjades": "krigshärjad",
    "krigshärjads": "krigshärjad",
    "krigshärjat": "krigshärjad",
    "krigshärjats": "krigshärjad",
    "krigsindustrien": "krigsindustri",
    "krigsindustriens": "krigsindustri",
    "krigsindustrier": "krigsindustri",
    "krigsindustrierna": "krigsindustri",
    "krigsindustriernas": "krigsindustri",
    "krigsindustriers": "krigsindustri",
    "krigsindustrin": "krigsindustri",
    "krigsindustrins": "krigsindustri",
    "krigsindustris": "krigsindustri",
    "krigsinkallade": "krigsinkallad",
    "krigsinkallades": "krigsinkallad",
    "krigsinkallads": "krigsinkallad",
    "krigsinkallat": "krigsinkallad",
    "krigsinkallats": "krigsinkallad",
    "krigsinsatsen": "krigsinsats",
    "krigsinsatsens": "krigsinsats",
    "krigsinsatser": "krigsinsats",
    "krigsinsatserna": "krigsinsats",
    "krigsinsatsernas": "krigsinsats",
    "krigsinsatsers": "krigsinsats",
    "krigsivern": "krigsiver",
    "krigsiverns": "krigsiver",
    "krigsivers": "krigsiver",
    "krigskonsten": "krigskonst",
    "krigskonstens": "krigskonst",
    "krigskonsts": "krigskonst",
    "krigskontrabandet": "krigskontraband",
    "krigskontrabandets": "krigskontraband",
    "krigskontrabands": "krigskontraband",
    "krigskorrespondenten": "krigskorrespondent",
    "krigskorrespondentens": "krigskorrespondent",
    "krigskorrespondenter": "krigskorrespondent",
    "krigskorrespondenterna": "krigskorrespondent",
    "krigskorrespondenternas": "krigskorrespondent",
    "krigskorrespondenters": "krigskorrespondent",
    "krigskorrespondents": "krigskorrespondent",
    "krigskrediten": "krigskredit",
    "krigskreditens": "krigskredit",
    "krigskrediter": "krigskredit",
    "krigskrediterna": "krigskredit",
    "krigskrediternas": "krigskredit",
    "krigskrediters": "krigskredit",
    "krigskredits": "krigskredit",
    "krigslisten": "krigslist",
    "krigslistens": "krigslist",
    "krigslists": "krigslist",
    "krigslyckan": "krigslycka",
    "krigslyckans": "krigslycka",
    "krigslyckas": "krigslycka",
    "krigsmakten": "krigsmakt",
    "krigsmaktens": "krigsmakt",
    "krigsmakter": "krigsmakt",
    "krigsmakterna": "krigsmakt",
    "krigsmakternas": "krigsmakt",
    "krigsmakters": "krigsmakt",
    "krigsmakts": "krigsmakt",
    "krigsmannen": "krigsman",
    "krigsmannens": "krigsman",
    "krigsmans": "krigsman",
    "krigsmaterielen": "krigsmateriel",
    "krigsmaterielens": "krigsmateriel",
    "krigsmateriels": "krigsmateriel",
    "krigsmiljöer": "krigsmiljö",
    "krigsmiljöerna": "krigsmiljö",
    "krigsmiljöernas": "krigsmiljö",
    "krigsmiljöers": "krigsmiljö",
    "krigsmiljön": "krigsmiljö",
    "krigsmiljöns": "krigsmiljö",
    "krigsmiljös": "krigsmiljö",
    "krigsmonumenten": "krigsmonument",
    "krigsmonumentens": "krigsmonument",
    "krigsmonumentet": "krigsmonument",
    "krigsmonumentets": "krigsmonument",
    "krigsmonuments": "krigsmonument",
    "krigsmän": "krigsman",
    "krigsmännen": "krigsman",
    "krigsmännens": "krigsman",
    "krigsmäns": "krigsman",
    "krigsmässiga": "krigsmässig",
    "krigsmässigare": "krigsmässig",
    "krigsmässigares": "krigsmässig",
    "krigsmässigas": "krigsmässig",
    "krigsmässigast": "krigsmässig",
    "krigsmässigaste": "krigsmässig",
    "krigsmässigastes": "krigsmässig",
    "krigsmässigasts": "krigsmässig",
    "krigsmässige": "krigsmässig",
    "krigsmässiges": "krigsmässig",
    "krigsmässigs": "krigsmässig",
    "krigsmässigt": "krigsmässig",
    "krigsmässigts": "krigsmässig",
    "krigsmålningar": "krigsmålning",
    "krigsmålningarna": "krigsmålning",
    "krigsmålningarnas": "krigsmålning",
    "krigsmålningars": "krigsmålning",
    "krigsmålningen": "krigsmålning",
    "krigsmålningens": "krigsmålning",
    "krigsmålnings": "krigsmålning",
    "krigsplacerad": "krigsplacera",
    "krigsplacerade": "krigsplacera",
    "krigsplacerades": "krigsplacera",
    "krigsplacerads": "krigsplacera",
    "krigsplacerande": "krigsplacera",
    "krigsplaceranden": "krigsplacerande",
    "krigsplacerandena": "krigsplacerande",
    "krigsplacerandenas": "krigsplacerande",
    "krigsplacerandens": "krigsplacerande",
    "krigsplacerandes": "krigsplacerande",
    "krigsplacerandet": "krigsplacerande",
    "krigsplacerandets": "krigsplacerande",
    "krigsplacerar": "krigsplacera",
    "krigsplaceras": "krigsplacera",
    "krigsplacerat": "krigsplacera",
    "krigsplacerats": "krigsplacera",
    "krigsplacerbara": "krigsplacerbar",
    "krigsplacerbarare": "krigsplacerbar",
    "krigsplacerbarares": "krigsplacerbar",
    "krigsplacerbaras": "krigsplacerbar",
    "krigsplacerbarast": "krigsplacerbar",
    "krigsplacerbaraste": "krigsplacerbar",
    "krigsplacerbarastes": "krigsplacerbar",
    "krigsplacerbarasts": "krigsplacerbar",
    "krigsplacerbare": "krigsplacerbar",
    "krigsplacerbares": "krigsplacerbar",
    "krigsplacerbarheten": "krigsplacerbarhet",
    "krigsplacerbarhetens": "krigsplacerbarhet",
    "krigsplacerbarhets": "krigsplacerbarhet",
    "krigsplacerbars": "krigsplacerbar",
    "krigsplacerbart": "krigsplacerbar",
    "krigsplacerbarts": "krigsplacerbar",
    "krigsplaceringar": "krigsplacering",
    "krigsplaceringarna": "krigsplacering",
    "krigsplaceringarnas": "krigsplacering",
    "krigsplaceringars": "krigsplacering",
    "krigsplaceringen": "krigsplacering",
    "krigsplaceringens": "krigsplacering",
    "krigsplacerings": "krigsplacering",
    "krigsreportagen": "krigsreportage",
    "krigsreportagens": "krigsreportage",
    "krigsreportages": "krigsreportage",
    "krigsreportaget": "krigsreportage",
    "krigsreportagets": "krigsreportage",
    "krigsrisken": "krigsrisk",
    "krigsriskens": "krigsrisk",
    "krigsrisker": "krigsrisk",
    "krigsriskerna": "krigsrisk",
    "krigsriskernas": "krigsrisk",
    "krigsriskers": "krigsrisk",
    "krigsrisks": "krigsrisk",
    "krigsromanen": "krigsroman",
    "krigsromanens": "krigsroman",
    "krigsromaner": "krigsroman",
    "krigsromanerna": "krigsroman",
    "krigsromanernas": "krigsroman",
    "krigsromaners": "krigsroman",
    "krigsromans": "krigsroman",
    "krigsrädda": "krigsrädd",
    "krigsräddare": "krigsrädd",
    "krigsräddares": "krigsrädd",
    "krigsräddas": "krigsrädd",
    "krigsräddast": "krigsrädd",
    "krigsräddaste": "krigsrädd",
    "krigsräddastes": "krigsrädd",
    "krigsräddasts": "krigsrädd",
    "krigsrädde": "krigsrädd",
    "krigsräddes": "krigsrädd",
    "krigsrädds": "krigsrädd",
    "krigsrätten": "krigsrätt",
    "krigsrättens": "krigsrätt",
    "krigsrätts": "krigsrätt",
    "krigsråden": "krigsråd",
    "krigsrådens": "krigsråd",
    "krigsrådet": "krigsråd",
    "krigsrådets": "krigsråd",
    "krigsråds": "krigsråd",
    "krigssjuksköterskan": "krigssjuksköterska",
    "krigssjuksköterskans": "krigssjuksköterska",
    "krigssjuksköterskas": "krigssjuksköterska",
    "krigssjuksköterske": "krigssjuksköterska",
    "krigssjuksköterskor": "krigssjuksköterska",
    "krigssjuksköterskorna": "krigssjuksköterska",
    "krigssjuksköterskornas": "krigssjuksköterska",
    "krigssjuksköterskors": "krigssjuksköterska",
    "krigsskadan": "krigsskada",
    "krigsskadans": "krigsskada",
    "krigsskadas": "krigsskada",
    "krigsskade": "krigsskada",
    "krigsskadestånden": "krigsskadestånd",
    "krigsskadeståndens": "krigsskadestånd",
    "krigsskadeståndet": "krigsskadestånd",
    "krigsskadeståndets": "krigsskadestånd",
    "krigsskadestånds": "krigsskadestånd",
    "krigsskador": "krigsskada",
    "krigsskadorna": "krigsskada",
    "krigsskadornas": "krigsskada",
    "krigsskadors": "krigsskada",
    "krigsskeppen": "krigsskepp",
    "krigsskeppens": "krigsskepp",
    "krigsskeppet": "krigsskepp",
    "krigsskeppets": "krigsskepp",
    "krigsskepps": "krigsskepp",
    "krigsskådeplatsen": "krigsskådeplats",
    "krigsskådeplatsens": "krigsskådeplats",
    "krigsskådeplatser": "krigsskådeplats",
    "krigsskådeplatserna": "krigsskådeplats",
    "krigsskådeplatsernas": "krigsskådeplats",
    "krigsskådeplatsers": "krigsskådeplats",
    "krigssluten": "krigsslut",
    "krigsslutens": "krigsslut",
    "krigsslutet": "krigsslut",
    "krigsslutets": "krigsslut",
    "krigssluts": "krigsslut",
    "krigsspelen": "krigsspel",
    "krigsspelens": "krigsspel",
    "krigsspelet": "krigsspel",
    "krigsspelets": "krigsspel",
    "krigsspels": "krigsspel",
    "krigsterrorn": "krigsterror",
    "krigsterrorns": "krigsterror",
    "krigsterrors": "krigsterror",
    "krigstillstånden": "krigstillstånd",
    "krigstillståndens": "krigstillstånd",
    "krigstillståndet": "krigstillstånd",
    "krigstillståndets": "krigstillstånd",
    "krigstillstånds": "krigstillstånd",
    "krigstjänsten": "krigstjänst",
    "krigstjänstens": "krigstjänst",
    "krigstjänstgöringar": "krigstjänstgöring",
    "krigstjänstgöringarna": "krigstjänstgöring",
    "krigstjänstgöringarnas": "krigstjänstgöring",
    "krigstjänstgöringars": "krigstjänstgöring",
    "krigstjänstgöringen": "krigstjänstgöring",
    "krigstjänstgöringens": "krigstjänstgöring",
    "krigstjänstgörings": "krigstjänstgöring",
    "krigstjänsts": "krigstjänst",
    "krigströtta": "krigstrött",
    "krigströttare": "krigstrött",
    "krigströttares": "krigstrött",
    "krigströttas": "krigstrött",
    "krigströttast": "krigstrött",
    "krigströttaste": "krigstrött",
    "krigströttastes": "krigstrött",
    "krigströttasts": "krigstrött",
    "krigströtte": "krigstrött",
    "krigströttes": "krigstrött",
    "krigströttheten": "krigströtthet",
    "krigströtthetens": "krigströtthet",
    "krigströtthets": "krigströtthet",
    "krigströtts": "krigstrött",
    "krigstågen": "krigståg",
    "krigstågens": "krigståg",
    "krigståget": "krigståg",
    "krigstågets": "krigståg",
    "krigstågs": "krigståg",
    "krigsutbrotten": "krigsutbrott",
    "krigsutbrottens": "krigsutbrott",
    "krigsutbrottet": "krigsutbrott",
    "krigsutbrottets": "krigsutbrott",
    "krigsutbrotts": "krigsutbrott",
    "krigsväsendet": "krigsväsen",
    "krigsväsendets": "krigsväsen",
    "krigsväsenet": "krigsväsen",
    "krigsväsenets": "krigsväsen",
    "krigsväsens": "krigsväsen",
    "krigszonen": "krigszon",
    "krigszonens": "krigszon",
    "krigszoner": "krigszon",
    "krigszonerna": "krigszon",
    "krigszonernas": "krigszon",
    "krigszoners": "krigszon",
    "krigszons": "krigszon",
    "krigsäventyren": "krigsäventyr",
    "krigsäventyrens": "krigsäventyr",
    "krigsäventyret": "krigsäventyr",
    "krigsäventyrets": "krigsäventyr",
    "krigsäventyrs": "krigsäventyr",
    "krigsåren": "krigsår",
    "krigsårens": "krigsår",
    "krigsåret": "krigsår",
    "krigsårets": "krigsår",
    "krigsårs": "krigsår",
    "krikonen": "krikon",
    "krikonens": "krikon",
    "krikonet": "krikon",
    "krikonets": "krikon",
    "krikons": "krikon",
    "krillen": "krill",
    "krillens": "krill",
    "krillfiskes": "krillfiske",
    "krillfisket": "krillfiske",
    "krillfiskets": "krillfiske",
    "krills": "krill",
    "krillstimmen": "krillstim",
    "krillstimmens": "krillstim",
    "krillstimmet": "krillstim",
    "krillstimmets": "krillstim",
    "krillstims": "krillstim",
    "krillätar": "krillätare",
    "krillätaren": "krillätare",
    "krillätarens": "krillätare",
    "krillätares": "krillätare",
    "krillätarna": "krillätare",
    "krillätarnas": "krillätare",
    "kriminalar": "kriminalare",
    "kriminalaren": "kriminalare",
    "kriminalarens": "kriminalare",
    "kriminalares": "kriminalare",
    "kriminalarna": "kriminalare",
    "kriminalarnas": "kriminalare",
    "kriminaldår": "kriminaldåre",
    "kriminaldårar": "kriminaldåre",
    "kriminaldårarna": "kriminaldåre",
    "kriminaldårarnas": "kriminaldåre",
    "kriminaldårars": "kriminaldåre",
    "kriminaldåren": "kriminaldåre",
    "kriminaldårens": "kriminaldåre",
    "kriminaldåres": "kriminaldåre",
    "kriminaldårs": "kriminaldåre",
    "kriminalens": "kriminalen",
    "kriminalfallen": "kriminalfall",
    "kriminalfallens": "kriminalfall",
    "kriminalfallet": "kriminalfall",
    "kriminalfallets": "kriminalfall",
    "kriminalfalls": "kriminalfall",
    "kriminaliserad": "kriminalisera",
    "kriminaliserade": "kriminalisera",
    "kriminaliserades": "kriminalisera",
    "kriminaliserads": "kriminalisera",
    "kriminaliserande": "kriminalisera",
    "kriminaliseranden": "kriminaliserande",
    "kriminaliserandena": "kriminaliserande",
    "kriminaliserandenas": "kriminaliserande",
    "kriminaliserandens": "kriminaliserande",
    "kriminaliserandes": "kriminaliserande",
    "kriminaliserandet": "kriminaliserande",
    "kriminaliserandets": "kriminaliserande",
    "kriminaliserar": "kriminalisera",
    "kriminaliseras": "kriminalisera",
    "kriminaliserat": "kriminalisera",
    "kriminaliserats": "kriminalisera",
    "kriminaliserbara": "kriminaliserbar",
    "kriminaliserbarare": "kriminaliserbar",
    "kriminaliserbarares": "kriminaliserbar",
    "kriminaliserbaras": "kriminaliserbar",
    "kriminaliserbarast": "kriminaliserbar",
    "kriminaliserbaraste": "kriminaliserbar",
    "kriminaliserbarastes": "kriminaliserbar",
    "kriminaliserbarasts": "kriminaliserbar",
    "kriminaliserbare": "kriminaliserbar",
    "kriminaliserbares": "kriminaliserbar",
    "kriminaliserbarheten": "kriminaliserbarhet",
    "kriminaliserbarhetens": "kriminaliserbarhet",
    "kriminaliserbarhets": "kriminaliserbarhet",
    "kriminaliserbars": "kriminaliserbar",
    "kriminaliserbart": "kriminaliserbar",
    "kriminaliserbarts": "kriminaliserbar",
    "kriminaliseringar": "kriminalisering",
    "kriminaliseringarna": "kriminalisering",
    "kriminaliseringarnas": "kriminalisering",
    "kriminaliseringars": "kriminalisering",
    "kriminaliseringen": "kriminalisering",
    "kriminaliseringens": "kriminalisering",
    "kriminaliserings": "kriminalisering",
    "kriminalistiken": "kriminalistik",
    "kriminalistikens": "kriminalistik",
    "kriminalistiks": "kriminalistik",
    "kriminaliteten": "kriminalitet",
    "kriminalitetens": "kriminalitet",
    "kriminaliteter": "kriminalitet",
    "kriminaliteterna": "kriminalitet",
    "kriminaliteternas": "kriminalitet",
    "kriminaliteters": "kriminalitet",
    "kriminalitets": "kriminalitet",
    "kriminalpolisen": "kriminalpolis",
    "kriminalpolisens": "kriminalpolis",
    "kriminalpoliser": "kriminalpolis",
    "kriminalpoliserna": "kriminalpolis",
    "kriminalpolisernas": "kriminalpolis",
    "kriminalpolisers": "kriminalpolis",
    "kriminalpolitiken": "kriminalpolitik",
    "kriminalpolitikens": "kriminalpolitik",
    "kriminalpolitiks": "kriminalpolitik",
    "kriminalpolitiska": "kriminalpolitisk",
    "kriminalpolitiskas": "kriminalpolitisk",
    "kriminalpolitiske": "kriminalpolitisk",
    "kriminalpolitiskes": "kriminalpolitisk",
    "kriminalpolitisks": "kriminalpolitisk",
    "kriminalpolitiskt": "kriminalpolitisk",
    "kriminalpolitiskts": "kriminalpolitisk",
    "kriminalregisterna": "kriminalregister",
    "kriminalregisternas": "kriminalregister",
    "kriminalregisters": "kriminalregister",
    "kriminalregistren": "kriminalregister",
    "kriminalregistrens": "kriminalregister",
    "kriminalregistret": "kriminalregister",
    "kriminalregistrets": "kriminalregister",
    "kriminalromanen": "kriminalroman",
    "kriminalromanens": "kriminalroman",
    "kriminalromaner": "kriminalroman",
    "kriminalromanerna": "kriminalroman",
    "kriminalromanernas": "kriminalroman",
    "kriminalromaners": "kriminalroman",
    "kriminalromans": "kriminalroman",
    "kriminaltekniken": "kriminalteknik",
    "kriminalteknikens": "kriminalteknik",
    "kriminaltekniks": "kriminalteknik",
    "kriminaltekniska": "kriminalteknisk",
    "kriminaltekniskas": "kriminalteknisk",
    "kriminaltekniske": "kriminalteknisk",
    "kriminaltekniskes": "kriminalteknisk",
    "kriminalteknisks": "kriminalteknisk",
    "kriminaltekniskt": "kriminalteknisk",
    "kriminaltekniskts": "kriminalteknisk",
    "kriminalvården": "kriminalvård",
    "kriminalvårdens": "kriminalvård",
    "kriminalvårds": "kriminalvård",
    "kriminella": "kriminell",
    "kriminellare": "kriminell",
    "kriminellares": "kriminell",
    "kriminellas": "kriminell",
    "kriminellast": "kriminell",
    "kriminellaste": "kriminell",
    "kriminellastes": "kriminell",
    "kriminellasts": "kriminell",
    "kriminelle": "kriminell",
    "kriminelles": "kriminell",
    "kriminells": "kriminell",
    "kriminellt": "kriminell",
    "kriminellts": "kriminell",
    "kriminologien": "kriminologi",
    "kriminologiens": "kriminologi",
    "kriminologin": "kriminologi",
    "kriminologins": "kriminologi",
    "kriminologis": "kriminologi",
    "kriminologiska": "kriminologisk",
    "kriminologiskare": "kriminologisk",
    "kriminologiskares": "kriminologisk",
    "kriminologiskas": "kriminologisk",
    "kriminologiskast": "kriminologisk",
    "kriminologiskaste": "kriminologisk",
    "kriminologiskastes": "kriminologisk",
    "kriminologiskasts": "kriminologisk",
    "kriminologiske": "kriminologisk",
    "kriminologiskes": "kriminologisk",
    "kriminologisks": "kriminologisk",
    "kriminologiskt": "kriminologisk",
    "kriminologiskts": "kriminologisk",
    "krimmern": "krimmer",
    "krimmerns": "krimmer",
    "krimmers": "krimmer",
    "krimskramset": "krimskrams",
    "krimskramsets": "krimskrams",
    "kringbyggda": "kringbyggd",
    "kringbyggdare": "kringbyggd",
    "kringbyggdares": "kringbyggd",
    "kringbyggdas": "kringbyggd",
    "kringbyggdast": "kringbyggd",
    "kringbyggdaste": "kringbyggd",
    "kringbyggdastes": "kringbyggd",
    "kringbyggdasts": "kringbyggd",
    "kringbyggde": "kringbyggd",
    "kringbyggdes": "kringbyggd",
    "kringbyggds": "kringbyggd",
    "kringbyggt": "kringbyggd",
    "kringbyggts": "kringbyggd",
    "kringel": "kringla",
    "kringelikrokarna": "kringelikrokar",
    "kringelikrokarnas": "kringelikrokar",
    "kringelikrokars": "kringelikrokar",
    "kringelikroks": "kringelikrokar",
    "kringgick": "kringgå",
    "kringgicks": "kringgå",
    "kringginge": "kringgå",
    "kringginges": "kringgå",
    "kringgärd": "kringgärda",
    "kringgärdad": "kringgärda",
    "kringgärdade": "kringgärda",
    "kringgärdades": "kringgärda",
    "kringgärdads": "kringgärda",
    "kringgärdande": "kringgärda",
    "kringgärdanden": "kringgärdande",
    "kringgärdandena": "kringgärdande",
    "kringgärdandenas": "kringgärdande",
    "kringgärdandens": "kringgärdande",
    "kringgärdandes": "kringgärdande",
    "kringgärdandet": "kringgärdande",
    "kringgärdandets": "kringgärdande",
    "kringgärdar": "kringgärda",
    "kringgärdas": "kringgärda",
    "kringgärdat": "kringgärda",
    "kringgärdats": "kringgärda",
    "kringgående": "kringgå",
    "kringgåenden": "kringgående",
    "kringgåendena": "kringgående",
    "kringgåendenas": "kringgående",
    "kringgåendens": "kringgående",
    "kringgåendes": "kringgående",
    "kringgåendet": "kringgående",
    "kringgåendets": "kringgående",
    "kringgånge": "kringgå",
    "kringgången": "kringgå",
    "kringgångens": "kringgå",
    "kringgånges": "kringgå",
    "kringgånget": "kringgå",
    "kringgångets": "kringgå",
    "kringgångna": "kringgå",
    "kringgångnas": "kringgå",
    "kringgångne": "kringgå",
    "kringgångnes": "kringgå",
    "kringgår": "kringgå",
    "kringgås": "kringgå",
    "kringgått": "kringgå",
    "kringgåtts": "kringgå",
    "kringinformationen": "kringinformation",
    "kringinformationens": "kringinformation",
    "kringinformationer": "kringinformation",
    "kringinformationerna": "kringinformation",
    "kringinformationernas": "kringinformation",
    "kringinformationers": "kringinformation",
    "kringinformations": "kringinformation",
    "kringkuskandes": "kringkuskande",
    "kringkuskandet": "kringkuskande",
    "kringkuskandets": "kringkuskande",
    "kringlan": "kringla",
    "kringlans": "kringla",
    "kringlas": "kringla",
    "kringle": "kringla",
    "kringlor": "kringla",
    "kringlorna": "kringla",
    "kringlornas": "kringla",
    "kringlors": "kringla",
    "kringränd": "kringränna",
    "kringrända": "kringränna",
    "kringrändas": "kringränna",
    "kringrände": "kringränna",
    "kringrändes": "kringränna",
    "kringränds": "kringränna",
    "kringränn": "kringränna",
    "kringrännande": "kringränna",
    "kringrännanden": "kringrännande",
    "kringrännandena": "kringrännande",
    "kringrännandenas": "kringrännande",
    "kringrännandens": "kringrännande",
    "kringrännandes": "kringrännande",
    "kringrännandet": "kringrännande",
    "kringrännandets": "kringrännande",
    "kringrännas": "kringränna",
    "kringränner": "kringränna",
    "kringrännes": "kringränna",
    "kringränns": "kringränna",
    "kringränt": "kringränna",
    "kringränts": "kringränna",
    "kringsjuka": "kringsjuk",
    "kringsjukan": "kringsjuka",
    "kringsjukans": "kringsjuka",
    "kringsjukare": "kringsjuk",
    "kringsjukares": "kringsjuk",
    "kringsjukas": "kringsjuka",
    "kringsjukast": "kringsjuk",
    "kringsjukaste": "kringsjuk",
    "kringsjukastes": "kringsjuk",
    "kringsjukasts": "kringsjuk",
    "kringsjuke": "kringsjuka",
    "kringsjukes": "kringsjuk",
    "kringsjuks": "kringsjuka",
    "kringsjukt": "kringsjuk",
    "kringsjukts": "kringsjuk",
    "kringskans": "kringskansa",
    "kringskansad": "kringskansa",
    "kringskansade": "kringskansa",
    "kringskansades": "kringskansa",
    "kringskansads": "kringskansa",
    "kringskansande": "kringskansa",
    "kringskansanden": "kringskansande",
    "kringskansandena": "kringskansande",
    "kringskansandenas": "kringskansande",
    "kringskansandens": "kringskansande",
    "kringskansandes": "kringskansande",
    "kringskansandet": "kringskansande",
    "kringskansandets": "kringskansande",
    "kringskansar": "kringskansa",
    "kringskansas": "kringskansa",
    "kringskansat": "kringskansa",
    "kringskansats": "kringskansa",
    "kringskar": "kringskära",
    "kringskars": "kringskära",
    "kringskure": "kringskära",
    "kringskuren": "kringskära",
    "kringskurens": "kringskära",
    "kringskures": "kringskära",
    "kringskuret": "kringskära",
    "kringskurets": "kringskära",
    "kringskurit": "kringskära",
    "kringskurits": "kringskära",
    "kringskurna": "kringskära",
    "kringskurnas": "kringskära",
    "kringskurne": "kringskära",
    "kringskurnes": "kringskära",
    "kringskär": "kringskära",
    "kringskärande": "kringskära",
    "kringskäranden": "kringskärande",
    "kringskärandena": "kringskärande",
    "kringskärandenas": "kringskärande",
    "kringskärandens": "kringskärande",
    "kringskärandes": "kringskärande",
    "kringskärandet": "kringskärande",
    "kringskärandets": "kringskärande",
    "kringskäras": "kringskära",
    "kringskäre": "kringskära",
    "kringskäres": "kringskära",
    "kringskärs": "kringskära",
    "kringsnacket": "kringsnack",
    "kringsnackets": "kringsnack",
    "kringsnacks": "kringsnack",
    "kringströdd": "kringströ",
    "kringströdda": "kringströ",
    "kringströddas": "kringströ",
    "kringströdde": "kringströ",
    "kringströddes": "kringströ",
    "kringströdds": "kringströ",
    "kringströende": "kringströ",
    "kringströendes": "kringströ",
    "kringströr": "kringströ",
    "kringströs": "kringströ",
    "kringstrött": "kringströ",
    "kringströtts": "kringströ",
    "kringsynen": "kringsyn",
    "kringsynens": "kringsyn",
    "kringsyns": "kringsyn",
    "kringsynta": "kringsynt",
    "kringsyntare": "kringsynt",
    "kringsyntares": "kringsynt",
    "kringsyntas": "kringsynt",
    "kringsyntast": "kringsynt",
    "kringsyntaste": "kringsynt",
    "kringsyntastes": "kringsynt",
    "kringsyntasts": "kringsynt",
    "kringsynte": "kringsynt",
    "kringsyntes": "kringsynt",
    "kringsyntheten": "kringsynthet",
    "kringsynthetens": "kringsynthet",
    "kringsynthets": "kringsynthet",
    "kringsynts": "kringsynt",
    "kringutrustningar": "kringutrustning",
    "kringutrustningarna": "kringutrustning",
    "kringutrustningarnas": "kringutrustning",
    "kringutrustningars": "kringutrustning",
    "kringutrustningen": "kringutrustning",
    "kringutrustningens": "kringutrustning",
    "kringutrustnings": "kringutrustning",
    "kringvägar": "kringväg",
    "kringvägarna": "kringväg",
    "kringvägarnas": "kringväg",
    "kringvägars": "kringväg",
    "kringvägen": "kringväg",
    "kringvägens": "kringväg",
    "kringvägs": "kringväg",
    "kringvärvda": "kringvärvd",
    "kringvärvdare": "kringvärvd",
    "kringvärvdares": "kringvärvd",
    "kringvärvdas": "kringvärvd",
    "kringvärvdast": "kringvärvd",
    "kringvärvdaste": "kringvärvd",
    "kringvärvdastes": "kringvärvd",
    "kringvärvdasts": "kringvärvd",
    "kringvärvde": "kringvärvd",
    "kringvärvdes": "kringvärvd",
    "kringvärvds": "kringvärvd",
    "kringvärvt": "kringvärvd",
    "kringvärvts": "kringvärvd",
    "krinolinen": "krinolin",
    "krinolinens": "krinolin",
    "krinoliner": "krinolin",
    "krinolinerna": "krinolin",
    "krinolinernas": "krinolin",
    "krinoliners": "krinolin",
    "krinolins": "krinolin",
    "krior": "kria",
    "kriorna": "kria",
    "kriornas": "kria",
    "kriors": "kria",
    "kris": "kria",
    "krisade": "krisa",
    "krisades": "krisa",
    "krisande": "krisa",
    "krisanden": "krisande",
    "krisandena": "krisande",
    "krisandenas": "krisande",
    "krisandens": "krisande",
    "krisandes": "krisande",
    "krisandet": "krisande",
    "krisandets": "krisande",
    "krisar": "krisa",
    "krisarna": "kris",
    "krisarnas": "kris",
    "krisars": "kris",
    "krisas": "krisa",
    "krisat": "krisa",
    "krisats": "krisa",
    "krisdrabbade": "krisdrabbad",
    "krisdrabbades": "krisdrabbad",
    "krisdrabbads": "krisdrabbad",
    "krisdrabbat": "krisdrabbad",
    "krisdrabbats": "krisdrabbad",
    "krisen": "kris",
    "krisens": "kris",
    "kriser": "kris",
    "kriserna": "kris",
    "krisernas": "kris",
    "krisers": "kris",
    "krisfonden": "krisfond",
    "krisfondens": "krisfond",
    "krisfonder": "krisfond",
    "krisfonderna": "krisfond",
    "krisfondernas": "krisfond",
    "krisfonders": "krisfond",
    "krisfonds": "krisfond",
    "krisgruppen": "krisgrupp",
    "krisgruppens": "krisgrupp",
    "krisgrupper": "krisgrupp",
    "krisgrupperna": "krisgrupp",
    "krisgruppernas": "krisgrupp",
    "krisgruppers": "krisgrupp",
    "krisgrupps": "krisgrupp",
    "krisgråa": "krisgrå",
    "krisgråare": "krisgrå",
    "krisgråares": "krisgrå",
    "krisgråas": "krisgrå",
    "krisgråast": "krisgrå",
    "krisgråaste": "krisgrå",
    "krisgråastes": "krisgrå",
    "krisgråasts": "krisgrå",
    "krisgråe": "krisgrå",
    "krisgråes": "krisgrå",
    "krisgrås": "krisgrå",
    "krisgrått": "krisgrå",
    "krisgråtts": "krisgrå",
    "krishanteringen": "krishantering",
    "krishanteringens": "krishantering",
    "krishanterings": "krishantering",
    "krishushållningar": "krishushållning",
    "krishushållningarna": "krishushållning",
    "krishushållningarnas": "krishushållning",
    "krishushållningars": "krishushållning",
    "krishushållningen": "krishushållning",
    "krishushållningens": "krishushållning",
    "krishushållnings": "krishushållning",
    "krismedels": "krismedel",
    "krismedlen": "krismedel",
    "krismedlens": "krismedel",
    "krismedlet": "krismedel",
    "krismedlets": "krismedel",
    "krismedvetenheten": "krismedvetenhet",
    "krismedvetenhetens": "krismedvetenhet",
    "krismedvetenhets": "krismedvetenhet",
    "krismedvetens": "krismedveten",
    "krismedvetet": "krismedveten",
    "krismedvetets": "krismedveten",
    "krismedvetna": "krismedveten",
    "krismedvetnare": "krismedveten",
    "krismedvetnares": "krismedveten",
    "krismedvetnas": "krismedveten",
    "krismedvetnast": "krismedveten",
    "krismedvetnaste": "krismedveten",
    "krismedvetnastes": "krismedveten",
    "krismedvetnasts": "krismedveten",
    "krismedvetne": "krismedveten",
    "krismedvetnes": "krismedveten",
    "krismöten": "krismöte",
    "krismötena": "krismöte",
    "krismötenas": "krismöte",
    "krismötens": "krismöte",
    "krismötes": "krismöte",
    "krismötet": "krismöte",
    "krismötets": "krismöte",
    "krispaketen": "krispaket",
    "krispaketens": "krispaket",
    "krispaketet": "krispaket",
    "krispaketets": "krispaket",
    "krispakets": "krispaket",
    "krispiga": "krispig",
    "krispigare": "krispig",
    "krispigares": "krispig",
    "krispigas": "krispig",
    "krispigast": "krispig",
    "krispigaste": "krispig",
    "krispigastes": "krispig",
    "krispigasts": "krispig",
    "krispige": "krispig",
    "krispiges": "krispig",
    "krispigheten": "krispighet",
    "krispighetens": "krispighet",
    "krispighets": "krispighet",
    "krispigs": "krispig",
    "krispigt": "krispig",
    "krispigts": "krispig",
    "krispolitiken": "krispolitik",
    "krispolitikens": "krispolitik",
    "krispolitiks": "krispolitik",
    "krissituationen": "krissituation",
    "krissituationens": "krissituation",
    "krissituationer": "krissituation",
    "krissituationerna": "krissituation",
    "krissituationernas": "krissituation",
    "krissituationers": "krissituation",
    "krissituations": "krissituation",
    "kristallaxeln": "kristallaxel",
    "kristallaxelns": "kristallaxel",
    "kristallaxels": "kristallaxel",
    "kristallaxlar": "kristallaxel",
    "kristallaxlarna": "kristallaxel",
    "kristallaxlarnas": "kristallaxel",
    "kristallaxlars": "kristallaxel",
    "kristallen": "kristall",
    "kristallens": "kristall",
    "kristaller": "kristall",
    "kristallerna": "kristall",
    "kristallernas": "kristall",
    "kristallers": "kristall",
    "kristallformen": "kristallform",
    "kristallformens": "kristallform",
    "kristallformer": "kristallform",
    "kristallformerna": "kristallform",
    "kristallformernas": "kristallform",
    "kristallformers": "kristallform",
    "kristallforms": "kristallform",
    "kristallglasen": "kristallglas",
    "kristallglasens": "kristallglas",
    "kristallglaset": "kristallglas",
    "kristallglasets": "kristallglas",
    "kristallina": "kristallin",
    "kristallinare": "kristallin",
    "kristallinares": "kristallin",
    "kristallinas": "kristallin",
    "kristallinast": "kristallin",
    "kristallinaste": "kristallin",
    "kristallinastes": "kristallin",
    "kristallinasts": "kristallin",
    "kristalline": "kristallin",
    "kristallines": "kristallin",
    "kristalliniska": "kristallinisk",
    "kristalliniskare": "kristallinisk",
    "kristalliniskares": "kristallinisk",
    "kristalliniskas": "kristallinisk",
    "kristalliniskast": "kristallinisk",
    "kristalliniskaste": "kristallinisk",
    "kristalliniskastes": "kristallinisk",
    "kristalliniskasts": "kristallinisk",
    "kristalliniske": "kristallinisk",
    "kristalliniskes": "kristallinisk",
    "kristallinisks": "kristallinisk",
    "kristalliniskt": "kristallinisk",
    "kristalliniskts": "kristallinisk",
    "kristallins": "kristallin",
    "kristallinsen": "kristallins",
    "kristallinsens": "kristallins",
    "kristallinser": "kristallins",
    "kristallinserna": "kristallins",
    "kristallinsernas": "kristallins",
    "kristallinsers": "kristallins",
    "kristallint": "kristallin",
    "kristallints": "kristallin",
    "kristallisationen": "kristallisation",
    "kristallisationens": "kristallisation",
    "kristallisationer": "kristallisation",
    "kristallisationerna": "kristallisation",
    "kristallisationernas": "kristallisation",
    "kristallisationers": "kristallisation",
    "kristallisations": "kristallisation",
    "kristalliserad": "kristallisera",
    "kristalliserade": "kristallisera",
    "kristalliserades": "kristallisera",
    "kristalliserads": "kristallisera",
    "kristalliserande": "kristallisera",
    "kristalliseranden": "kristalliserande",
    "kristalliserandena": "kristalliserande",
    "kristalliserandenas": "kristalliserande",
    "kristalliserandens": "kristalliserande",
    "kristalliserandes": "kristalliserande",
    "kristalliserandet": "kristalliserande",
    "kristalliserandets": "kristalliserande",
    "kristalliserar": "kristallisera",
    "kristalliseras": "kristallisera",
    "kristalliserat": "kristallisera",
    "kristalliserats": "kristallisera",
    "kristalliserbara": "kristalliserbar",
    "kristalliserbarare": "kristalliserbar",
    "kristalliserbarares": "kristalliserbar",
    "kristalliserbaras": "kristalliserbar",
    "kristalliserbarast": "kristalliserbar",
    "kristalliserbaraste": "kristalliserbar",
    "kristalliserbarastes": "kristalliserbar",
    "kristalliserbarasts": "kristalliserbar",
    "kristalliserbare": "kristalliserbar",
    "kristalliserbares": "kristalliserbar",
    "kristalliserbarheten": "kristalliserbarhet",
    "kristalliserbarhetens": "kristalliserbarhet",
    "kristalliserbarhets": "kristalliserbarhet",
    "kristalliserbars": "kristalliserbar",
    "kristalliserbart": "kristalliserbar",
    "kristalliserbarts": "kristalliserbar",
    "kristalliseringar": "kristallisering",
    "kristalliseringarna": "kristallisering",
    "kristalliseringarnas": "kristallisering",
    "kristalliseringars": "kristallisering",
    "kristalliseringen": "kristallisering",
    "kristalliseringens": "kristallisering",
    "kristalliserings": "kristallisering",
    "kristalliska": "kristallisk",
    "kristalliskare": "kristallisk",
    "kristalliskares": "kristallisk",
    "kristalliskas": "kristallisk",
    "kristalliskast": "kristallisk",
    "kristalliskaste": "kristallisk",
    "kristalliskastes": "kristallisk",
    "kristalliskasts": "kristallisk",
    "kristalliske": "kristallisk",
    "kristalliskes": "kristallisk",
    "kristallisks": "kristallisk",
    "kristalliskt": "kristallisk",
    "kristalliskts": "kristallisk",
    "kristallklara": "kristallklar",
    "kristallklarare": "kristallklar",
    "kristallklarares": "kristallklar",
    "kristallklaras": "kristallklar",
    "kristallklarast": "kristallklar",
    "kristallklaraste": "kristallklar",
    "kristallklarastes": "kristallklar",
    "kristallklarasts": "kristallklar",
    "kristallklare": "kristallklar",
    "kristallklares": "kristallklar",
    "kristallklars": "kristallklar",
    "kristallklart": "kristallklar",
    "kristallklarts": "kristallklar",
    "kristallkron": "kristallkrona",
    "kristallkronan": "kristallkrona",
    "kristallkronans": "kristallkrona",
    "kristallkronas": "kristallkrona",
    "kristallkrone": "kristallkrona",
    "kristallkronor": "kristallkrona",
    "kristallkronorna": "kristallkrona",
    "kristallkronornas": "kristallkrona",
    "kristallkronors": "kristallkrona",
    "kristallkrons": "kristallkrona",
    "kristallkul": "kristallkula",
    "kristallkulan": "kristallkula",
    "kristallkulans": "kristallkula",
    "kristallkulas": "kristallkula",
    "kristallkule": "kristallkula",
    "kristallkulor": "kristallkula",
    "kristallkulorna": "kristallkula",
    "kristallkulornas": "kristallkula",
    "kristallkulors": "kristallkula",
    "kristallkuls": "kristallkula",
    "kristallmottagar": "kristallmottagare",
    "kristallmottagaren": "kristallmottagare",
    "kristallmottagarens": "kristallmottagare",
    "kristallmottagares": "kristallmottagare",
    "kristallmottagarna": "kristallmottagare",
    "kristallmottagarnas": "kristallmottagare",
    "kristallmönsterna": "kristallmönster",
    "kristallmönsternas": "kristallmönster",
    "kristallmönsters": "kristallmönster",
    "kristallmönstren": "kristallmönster",
    "kristallmönstrens": "kristallmönster",
    "kristallmönstret": "kristallmönster",
    "kristallmönstrets": "kristallmönster",
    "kristallografien": "kristallografi",
    "kristallografiens": "kristallografi",
    "kristallografin": "kristallografi",
    "kristallografins": "kristallografi",
    "kristallografis": "kristallografi",
    "kristallografiska": "kristallografisk",
    "kristallografiskare": "kristallografisk",
    "kristallografiskares": "kristallografisk",
    "kristallografiskas": "kristallografisk",
    "kristallografiskast": "kristallografisk",
    "kristallografiskaste": "kristallografisk",
    "kristallografiskastes": "kristallografisk",
    "kristallografiskasts": "kristallografisk",
    "kristallografiske": "kristallografisk",
    "kristallografiskes": "kristallografisk",
    "kristallografisks": "kristallografisk",
    "kristallografiskt": "kristallografisk",
    "kristallografiskts": "kristallografisk",
    "kristalloljan": "kristallolja",
    "kristalloljans": "kristallolja",
    "kristalloljas": "kristallolja",
    "kristallolje": "kristallolja",
    "kristallosen": "kristallos",
    "kristallosens": "kristallos",
    "kristalls": "kristall",
    "kristallskålar": "kristallskål",
    "kristallskålarna": "kristallskål",
    "kristallskålarnas": "kristallskål",
    "kristallskålars": "kristallskål",
    "kristallskålen": "kristallskål",
    "kristallskålens": "kristallskål",
    "kristallskåls": "kristallskål",
    "kristallsystemen": "kristallsystem",
    "kristallsystemens": "kristallsystem",
    "kristallsystemet": "kristallsystem",
    "kristallsystemets": "kristallsystem",
    "kristallsystems": "kristallsystem",
    "kristallvattens": "kristallvatten",
    "kristallvattnet": "kristallvatten",
    "kristallvattnets": "kristallvatten",
    "kristdemokratiska": "kristdemokratisk",
    "kristdemokratiskas": "kristdemokratisk",
    "kristdemokratiske": "kristdemokratisk",
    "kristdemokratiskes": "kristdemokratisk",
    "kristdemokratisks": "kristdemokratisk",
    "kristdemokratiskt": "kristdemokratisk",
    "kristdemokratiskts": "kristdemokratisk",
    "kristendomar": "kristendom",
    "kristendomarna": "kristendom",
    "kristendomarnas": "kristendom",
    "kristendomars": "kristendom",
    "kristendomen": "kristendom",
    "kristendomens": "kristendom",
    "kristendoms": "kristendom",
    "kristendomsundervisningar": "kristendomsundervisning",
    "kristendomsundervisningarna": "kristendomsundervisning",
    "kristendomsundervisningarnas": "kristendomsundervisning",
    "kristendomsundervisningars": "kristendomsundervisning",
    "kristendomsundervisningen": "kristendomsundervisning",
    "kristendomsundervisningens": "kristendomsundervisning",
    "kristendomsundervisnings": "kristendomsundervisning",
    "kristenheten": "kristenhet",
    "kristenhetens": "kristenhet",
    "kristenheter": "kristenhet",
    "kristenheterna": "kristenhet",
    "kristenheternas": "kristenhet",
    "kristenheters": "kristenhet",
    "kristenhets": "kristenhet",
    "kristens": "kristen",
    "kristet": "kristen",
    "kristets": "kristen",
    "kristiden": "kristid",
    "kristidens": "kristid",
    "kristider": "kristid",
    "kristiderna": "kristid",
    "kristidernas": "kristid",
    "kristiders": "kristid",
    "kristids": "kristid",
    "kristidsföretagen": "kristidsföretag",
    "kristidsföretagens": "kristidsföretag",
    "kristidsföretaget": "kristidsföretag",
    "kristidsföretagets": "kristidsföretag",
    "kristidsföretags": "kristidsföretag",
    "kristliga": "kristlig",
    "kristligare": "kristlig",
    "kristligares": "kristlig",
    "kristligas": "kristlig",
    "kristligast": "kristlig",
    "kristligaste": "kristlig",
    "kristligastes": "kristlig",
    "kristligasts": "kristlig",
    "kristlige": "kristlig",
    "kristliges": "kristlig",
    "kristligheten": "kristlighet",
    "kristlighetens": "kristlighet",
    "kristlighets": "kristlighet",
    "kristligs": "kristlig",
    "kristligt": "kristlig",
    "kristligts": "kristlig",
    "kristn": "kristna",
    "kristna": "kristen",
    "kristnad": "kristna",
    "kristnade": "kristna",
    "kristnades": "kristna",
    "kristnads": "kristna",
    "kristnande": "kristna",
    "kristnanden": "kristnande",
    "kristnandena": "kristnande",
    "kristnandenas": "kristnande",
    "kristnandens": "kristnande",
    "kristnandes": "kristnande",
    "kristnandet": "kristnande",
    "kristnandets": "kristnande",
    "kristnar": "kristna",
    "kristnare": "kristen",
    "kristnares": "kristen",
    "kristnas": "kristna",
    "kristnast": "kristen",
    "kristnaste": "kristen",
    "kristnastes": "kristen",
    "kristnasts": "kristen",
    "kristnat": "kristna",
    "kristnats": "kristna",
    "kristne": "kristen",
    "kristnes": "kristen",
    "kristologien": "kristologi",
    "kristologiens": "kristologi",
    "kristologin": "kristologi",
    "kristologins": "kristologi",
    "kristologis": "kristologi",
    "kristtornar": "kristtorn",
    "kristtornarna": "kristtorn",
    "kristtornarnas": "kristtorn",
    "kristtornars": "kristtorn",
    "kristtornen": "kristtorn",
    "kristtornens": "kristtorn",
    "kristtorns": "kristtorn",
    "kristtrogenheten": "kristtrogenhet",
    "kristtrogenhetens": "kristtrogenhet",
    "kristtrogenhets": "kristtrogenhet",
    "kristtrogens": "kristtrogen",
    "kristtroget": "kristtrogen",
    "kristtrogets": "kristtrogen",
    "kristtrogna": "kristtrogen",
    "kristtrognare": "kristtrogen",
    "kristtrognares": "kristtrogen",
    "kristtrognas": "kristtrogen",
    "kristtrognast": "kristtrogen",
    "kristtrognaste": "kristtrogen",
    "kristtrognastes": "kristtrogen",
    "kristtrognasts": "kristtrogen",
    "kristtrogne": "kristtrogen",
    "kristtrognes": "kristtrogen",
    "kristusmonogrammen": "kristusmonogram",
    "kristusmonogrammens": "kristusmonogram",
    "kristusmonogrammet": "kristusmonogram",
    "kristusmonogrammets": "kristusmonogram",
    "kristusmonograms": "kristusmonogram",
    "kristyren": "kristyr",
    "kristyrens": "kristyr",
    "kristyrs": "kristyr",
    "krisåtgärden": "krisåtgärd",
    "krisåtgärdens": "krisåtgärd",
    "krisåtgärder": "krisåtgärd",
    "krisåtgärderna": "krisåtgärd",
    "krisåtgärdernas": "krisåtgärd",
    "krisåtgärders": "krisåtgärd",
    "krisåtgärds": "krisåtgärd",
    "krit": "krita",
    "kritad": "krita",
    "kritade": "krita",
    "kritades": "krita",
    "kritads": "krita",
    "kritan": "krita",
    "kritande": "krita",
    "kritanden": "kritande",
    "kritandena": "kritande",
    "kritandenas": "kritande",
    "kritandens": "kritande",
    "kritandes": "kritande",
    "kritandet": "kritande",
    "kritandets": "kritande",
    "kritans": "krita",
    "kritar": "krita",
    "kritas": "krita",
    "kritat": "krita",
    "kritats": "krita",
    "krite": "krita",
    "kriterie": "kriterium",
    "kriterier": "kriterium",
    "kriterierna": "kriterium",
    "kriteriernas": "kriterium",
    "kriteriers": "kriterium",
    "kriteriet": "kriterium",
    "kriteriets": "kriterium",
    "kriteriums": "kriterium",
    "kriticina": "kritici",
    "kriticinas": "kritici",
    "kriticis": "kritici",
    "kriticismen": "kriticism",
    "kriticismens": "kriticism",
    "kriticismer": "kriticism",
    "kriticismerna": "kriticism",
    "kriticismernas": "kriticism",
    "kriticismers": "kriticism",
    "kriticisms": "kriticism",
    "kritiga": "kritig",
    "kritigare": "kritig",
    "kritigares": "kritig",
    "kritigas": "kritig",
    "kritigast": "kritig",
    "kritigaste": "kritig",
    "kritigastes": "kritig",
    "kritigasts": "kritig",
    "kritige": "kritig",
    "kritiges": "kritig",
    "kritigs": "kritig",
    "kritigt": "kritig",
    "kritigts": "kritig",
    "kritiken": "kritik",
    "kritikens": "kritik",
    "kritiker": "kritik",
    "kritikermässiga": "kritikermässig",
    "kritikermässigare": "kritikermässig",
    "kritikermässigares": "kritikermässig",
    "kritikermässigas": "kritikermässig",
    "kritikermässigast": "kritikermässig",
    "kritikermässigaste": "kritikermässig",
    "kritikermässigastes": "kritikermässig",
    "kritikermässigasts": "kritikermässig",
    "kritikermässige": "kritikermässig",
    "kritikermässiges": "kritikermässig",
    "kritikermässigs": "kritikermässig",
    "kritikermässigt": "kritikermässig",
    "kritikermässigts": "kritikermässig",
    "kritikern": "kritiker",
    "kritikerna": "kritiker",
    "kritikernas": "kritiker",
    "kritikerns": "kritiker",
    "kritikers": "kritiker",
    "kritiklusten": "kritiklust",
    "kritiklustens": "kritiklust",
    "kritiklusts": "kritiklust",
    "kritiklösa": "kritiklös",
    "kritiklösare": "kritiklös",
    "kritiklösares": "kritiklös",
    "kritiklösas": "kritiklös",
    "kritiklösast": "kritiklös",
    "kritiklösaste": "kritiklös",
    "kritiklösastes": "kritiklös",
    "kritiklösasts": "kritiklös",
    "kritiklöse": "kritiklös",
    "kritiklöses": "kritiklös",
    "kritiklösheten": "kritiklöshet",
    "kritiklöshetens": "kritiklöshet",
    "kritiklöshets": "kritiklöshet",
    "kritiklöst": "kritiklös",
    "kritiklösts": "kritiklös",
    "kritiks": "kritik",
    "kritikstormar": "kritikstorm",
    "kritikstormarna": "kritikstorm",
    "kritikstormarnas": "kritikstorm",
    "kritikstormars": "kritikstorm",
    "kritikstormen": "kritikstorm",
    "kritikstormens": "kritikstorm",
    "kritikstorms": "kritikstorm",
    "kritiserad": "kritisera",
    "kritiserade": "kritisera",
    "kritiserades": "kritisera",
    "kritiserads": "kritisera",
    "kritiserande": "kritisera",
    "kritiseranden": "kritiserande",
    "kritiserandena": "kritiserande",
    "kritiserandenas": "kritiserande",
    "kritiserandens": "kritiserande",
    "kritiserandes": "kritiserande",
    "kritiserandet": "kritiserande",
    "kritiserandets": "kritiserande",
    "kritiserar": "kritisera",
    "kritiseras": "kritisera",
    "kritiserat": "kritisera",
    "kritiserats": "kritisera",
    "kritiserbara": "kritiserbar",
    "kritiserbarare": "kritiserbar",
    "kritiserbarares": "kritiserbar",
    "kritiserbaras": "kritiserbar",
    "kritiserbarast": "kritiserbar",
    "kritiserbaraste": "kritiserbar",
    "kritiserbarastes": "kritiserbar",
    "kritiserbarasts": "kritiserbar",
    "kritiserbare": "kritiserbar",
    "kritiserbares": "kritiserbar",
    "kritiserbarheten": "kritiserbarhet",
    "kritiserbarhetens": "kritiserbarhet",
    "kritiserbarhets": "kritiserbarhet",
    "kritiserbars": "kritiserbar",
    "kritiserbart": "kritiserbar",
    "kritiserbarts": "kritiserbar",
    "kritiseringar": "kritisering",
    "kritiseringarna": "kritisering",
    "kritiseringarnas": "kritisering",
    "kritiseringars": "kritisering",
    "kritiseringen": "kritisering",
    "kritiseringens": "kritisering",
    "kritiserings": "kritisering",
    "kritiska": "kritisk",
    "kritiskare": "kritisk",
    "kritiskares": "kritisk",
    "kritiskas": "kritisk",
    "kritiskast": "kritisk",
    "kritiskaste": "kritisk",
    "kritiskastes": "kritisk",
    "kritiskasts": "kritisk",
    "kritiske": "kritisk",
    "kritiskes": "kritisk",
    "kritisks": "kritisk",
    "kritiskt": "kritisk",
    "kritiskts": "kritisk",
    "kritor": "krita",
    "kritorna": "krita",
    "kritornas": "krita",
    "kritors": "krita",
    "kritpip": "kritpipa",
    "kritpipan": "kritpipa",
    "kritpipans": "kritpipa",
    "kritpipas": "kritpipa",
    "kritpipe": "kritpipa",
    "kritpipor": "kritpipa",
    "kritpiporna": "kritpipa",
    "kritpipornas": "kritpipa",
    "kritpipors": "kritpipa",
    "kritpips": "kritpipa",
    "krits": "krita",
    "kritstrecken": "kritstreck",
    "kritstreckens": "kritstreck",
    "kritstrecket": "kritstreck",
    "kritstreckets": "kritstreck",
    "kritstrecks": "kritstreck",
    "kritstrecksrandiga": "kritstrecksrandig",
    "kritstrecksrandigare": "kritstrecksrandig",
    "kritstrecksrandigares": "kritstrecksrandig",
    "kritstrecksrandigas": "kritstrecksrandig",
    "kritstrecksrandigast": "kritstrecksrandig",
    "kritstrecksrandigaste": "kritstrecksrandig",
    "kritstrecksrandigastes": "kritstrecksrandig",
    "kritstrecksrandigasts": "kritstrecksrandig",
    "kritstrecksrandige": "kritstrecksrandig",
    "kritstrecksrandiges": "kritstrecksrandig",
    "kritstrecksrandigs": "kritstrecksrandig",
    "kritstrecksrandigt": "kritstrecksrandig",
    "kritstrecksrandigts": "kritstrecksrandig",
    "kritterna": "kritter",
    "kritternas": "kritter",
    "kritters": "kritter",
    "krittiden": "krittid",
    "krittidens": "krittid",
    "krittids": "krittid",
    "krittren": "kritter",
    "krittrens": "kritter",
    "krittret": "kritter",
    "krittrets": "kritter",
    "kritvita": "kritvit",
    "kritvitare": "kritvit",
    "kritvitares": "kritvit",
    "kritvitas": "kritvit",
    "kritvitast": "kritvit",
    "kritvitaste": "kritvit",
    "kritvitastes": "kritvit",
    "kritvitasts": "kritvit",
    "kritvite": "kritvit",
    "kritvites": "kritvit",
    "kritvits": "kritvit",
    "kritvitt": "kritvit",
    "kritvitts": "kritvit",
    "kroaten": "kroat",
    "kroatens": "kroat",
    "kroater": "kroat",
    "kroaterna": "kroat",
    "kroaternas": "kroat",
    "kroaters": "kroat",
    "kroatisk": "kroatiska",
    "kroatiska": "kroatisk",
    "kroatiskan": "kroatiska",
    "kroatiskans": "kroatiska",
    "kroatiskare": "kroatisk",
    "kroatiskares": "kroatisk",
    "kroatiskas": "kroatiska",
    "kroatiskast": "kroatisk",
    "kroatiskaste": "kroatisk",
    "kroatiskastes": "kroatisk",
    "kroatiskasts": "kroatisk",
    "kroatiske": "kroatiska",
    "kroatiskes": "kroatisk",
    "kroatiskor": "kroatiska",
    "kroatiskorna": "kroatiska",
    "kroatiskornas": "kroatiska",
    "kroatiskors": "kroatiska",
    "kroatisks": "kroatisk",
    "kroatiskt": "kroatisk",
    "kroatiskts": "kroatisk",
    "kroats": "kroat",
    "krock": "krocka",
    "krockad": "krocka",
    "krockade": "krocka",
    "krockades": "krocka",
    "krockads": "krocka",
    "krockande": "krocka",
    "krockanden": "krockande",
    "krockandena": "krockande",
    "krockandenas": "krockande",
    "krockandens": "krockande",
    "krockandes": "krockande",
    "krockandet": "krockande",
    "krockandets": "krockande",
    "krockar": "krocka",
    "krockarna": "krock",
    "krockarnas": "krock",
    "krockars": "krock",
    "krockas": "krocka",
    "krockat": "krocka",
    "krockats": "krocka",
    "krocken": "krock",
    "krockens": "krock",
    "krocketen": "krocket",
    "krocketens": "krocket",
    "krockets": "krocket",
    "krockkuddar": "krockkudde",
    "krockkuddarna": "krockkudde",
    "krockkuddarnas": "krockkudde",
    "krockkuddars": "krockkudde",
    "krockkudden": "krockkudde",
    "krockkuddens": "krockkudde",
    "krockkuddes": "krockkudde",
    "krocks": "krock",
    "krockskadade": "krockskadad",
    "krockskadades": "krockskadad",
    "krockskadads": "krockskadad",
    "krockskadat": "krockskadad",
    "krockskadats": "krockskadad",
    "krogar": "krog",
    "krogarna": "krog",
    "krogarnas": "krog",
    "krogars": "krog",
    "krogen": "krog",
    "krogens": "krog",
    "krogkunden": "krogkund",
    "krogkundens": "krogkund",
    "krogkunder": "krogkund",
    "krogkunderna": "krogkund",
    "krogkundernas": "krogkund",
    "krogkunders": "krogkund",
    "krogkunds": "krogkund",
    "krogrecensionen": "krogrecension",
    "krogrecensionens": "krogrecension",
    "krogrecensioner": "krogrecension",
    "krogrecensionerna": "krogrecension",
    "krogrecensionernas": "krogrecension",
    "krogrecensioners": "krogrecension",
    "krogrecensions": "krogrecension",
    "krogrondan": "krogronda",
    "krogrondans": "krogronda",
    "krogrondas": "krogronda",
    "krogronde": "krogronda",
    "krogronden": "krogrond",
    "krogrondens": "krogrond",
    "krogronder": "krogrond",
    "krogronderna": "krogrond",
    "krogrondernas": "krogrond",
    "krogronders": "krogrond",
    "krogrondor": "krogronda",
    "krogrondorna": "krogronda",
    "krogrondornas": "krogronda",
    "krogrondors": "krogronda",
    "krogronds": "krogrond",
    "krogrundan": "krogrunda",
    "krogrundans": "krogrunda",
    "krogrundas": "krogrunda",
    "krogrunde": "krogrunda",
    "krogrundor": "krogrunda",
    "krogrundorna": "krogrunda",
    "krogrundornas": "krogrunda",
    "krogrundors": "krogrunda",
    "krogs": "krog",
    "krogsamtalen": "krogsamtal",
    "krogsamtalens": "krogsamtal",
    "krogsamtalet": "krogsamtal",
    "krogsamtalets": "krogsamtal",
    "krogsamtals": "krogsamtal",
    "krogshowen": "krogshow",
    "krogshowens": "krogshow",
    "krogshower": "krogshow",
    "krogshowerna": "krogshow",
    "krogshowernas": "krogshow",
    "krogshowers": "krogshow",
    "krogshows": "krogshow",
    "krogsvängar": "krogsväng",
    "krogsvängarna": "krogsväng",
    "krogsvängarnas": "krogsväng",
    "krogsvängars": "krogsväng",
    "krogsvängen": "krogsväng",
    "krogsvängens": "krogsväng",
    "krogsvängs": "krogsväng",
    "krok": "kroka",
    "krokad": "kroka",
    "krokade": "kroka",
    "krokades": "kroka",
    "krokads": "kroka",
    "krokande": "kroka",
    "krokanden": "krokande",
    "krokandena": "krokande",
    "krokandenas": "krokande",
    "krokandens": "krokande",
    "krokandes": "krokande",
    "krokandet": "krokande",
    "krokandets": "krokande",
    "krokanen": "krokan",
    "krokanens": "krokan",
    "krokaner": "krokan",
    "krokanerna": "krokan",
    "krokanernas": "krokan",
    "krokaners": "krokan",
    "krokans": "krokan",
    "krokanten": "krokant",
    "krokantens": "krokant",
    "krokants": "krokant",
    "krokanutsirade": "krokanutsirad",
    "krokanutsirades": "krokanutsirad",
    "krokanutsirads": "krokanutsirad",
    "krokanutsirat": "krokanutsirad",
    "krokanutsirats": "krokanutsirad",
    "krokar": "kroka",
    "krokarna": "krok",
    "krokarnas": "krok",
    "krokars": "krok",
    "krokas": "kroka",
    "krokat": "kroka",
    "krokats": "kroka",
    "kroken": "krok",
    "krokens": "krok",
    "kroketten": "krokett",
    "krokettens": "krokett",
    "kroketter": "krokett",
    "kroketterna": "krokett",
    "kroketternas": "krokett",
    "kroketters": "krokett",
    "kroketts": "krokett",
    "krokien": "kroki",
    "krokiens": "kroki",
    "krokier": "kroki",
    "krokierna": "kroki",
    "krokiernas": "kroki",
    "krokiers": "kroki",
    "krokiga": "krokig",
    "krokigare": "krokig",
    "krokigares": "krokig",
    "krokigas": "krokig",
    "krokigast": "krokig",
    "krokigaste": "krokig",
    "krokigastes": "krokig",
    "krokigasts": "krokig",
    "krokige": "krokig",
    "krokiges": "krokig",
    "krokigheten": "krokighet",
    "krokighetens": "krokighet",
    "krokigheter": "krokighet",
    "krokigheterna": "krokighet",
    "krokigheternas": "krokighet",
    "krokigheters": "krokighet",
    "krokighets": "krokighet",
    "krokigs": "krokig",
    "krokigt": "krokig",
    "krokigts": "krokig",
    "krokin": "kroki",
    "krokins": "kroki",
    "krokis": "kroki",
    "krokn": "krokna",
    "kroknad": "krokna",
    "kroknade": "krokna",
    "kroknades": "krokna",
    "kroknads": "krokna",
    "kroknande": "krokna",
    "kroknanden": "kroknande",
    "kroknandena": "kroknande",
    "kroknandenas": "kroknande",
    "kroknandens": "kroknande",
    "kroknandes": "kroknande",
    "kroknandet": "kroknande",
    "kroknandets": "kroknande",
    "kroknar": "krokna",
    "kroknas": "krokna",
    "kroknat": "krokna",
    "kroknats": "krokna",
    "kroknäs": "kroknäsa",
    "kroknäsan": "kroknäsa",
    "kroknäsans": "kroknäsa",
    "kroknäsas": "kroknäsa",
    "kroknäse": "kroknäsa",
    "kroknäsor": "kroknäsa",
    "kroknäsorna": "kroknäsa",
    "kroknäsornas": "kroknäsa",
    "kroknäsors": "kroknäsa",
    "kroknästa": "kroknäst",
    "kroknästare": "kroknäst",
    "kroknästares": "kroknäst",
    "kroknästas": "kroknäst",
    "kroknästast": "kroknäst",
    "kroknästaste": "kroknäst",
    "kroknästastes": "kroknäst",
    "kroknästasts": "kroknäst",
    "kroknäste": "kroknäst",
    "kroknästes": "kroknäst",
    "kroknästheten": "kroknästhet",
    "kroknästhetens": "kroknästhet",
    "kroknästhets": "kroknästhet",
    "kroknästs": "kroknäst",
    "krokodilen": "krokodil",
    "krokodilens": "krokodil",
    "krokodiler": "krokodil",
    "krokodilerna": "krokodil",
    "krokodilernas": "krokodil",
    "krokodilers": "krokodil",
    "krokodils": "krokodil",
    "krokodilskinnen": "krokodilskinn",
    "krokodilskinnens": "krokodilskinn",
    "krokodilskinnet": "krokodilskinn",
    "krokodilskinnets": "krokodilskinn",
    "krokodilskinns": "krokodilskinn",
    "krokodiltårarna": "krokodiltårar",
    "krokodiltårarnas": "krokodiltårar",
    "krokodiltårars": "krokodiltårar",
    "krokodiltårs": "krokodiltårar",
    "krokryggiga": "krokryggig",
    "krokryggigare": "krokryggig",
    "krokryggigares": "krokryggig",
    "krokryggigas": "krokryggig",
    "krokryggigast": "krokryggig",
    "krokryggigaste": "krokryggig",
    "krokryggigastes": "krokryggig",
    "krokryggigasts": "krokryggig",
    "krokryggige": "krokryggig",
    "krokryggiges": "krokryggig",
    "krokryggigheten": "krokryggighet",
    "krokryggighetens": "krokryggighet",
    "krokryggighets": "krokryggighet",
    "krokryggigs": "krokryggig",
    "krokryggigt": "krokryggig",
    "krokryggigts": "krokryggig",
    "kroksabeln": "kroksabel",
    "kroksabelns": "kroksabel",
    "kroksabels": "kroksabel",
    "kroksablar": "kroksabel",
    "kroksablarna": "kroksabel",
    "kroksablarnas": "kroksabel",
    "kroksablars": "kroksabel",
    "krokusar": "krokus",
    "krokusarna": "krokus",
    "krokusarnas": "krokus",
    "krokusars": "krokus",
    "krokusen": "krokus",
    "krokusens": "krokus",
    "krokvuxenheten": "krokvuxenhet",
    "krokvuxenhetens": "krokvuxenhet",
    "krokvuxenhets": "krokvuxenhet",
    "krokvuxens": "krokvuxen",
    "krokvuxet": "krokvuxen",
    "krokvuxets": "krokvuxen",
    "krokvuxna": "krokvuxen",
    "krokvuxnare": "krokvuxen",
    "krokvuxnares": "krokvuxen",
    "krokvuxnas": "krokvuxen",
    "krokvuxnast": "krokvuxen",
    "krokvuxnaste": "krokvuxen",
    "krokvuxnastes": "krokvuxen",
    "krokvuxnasts": "krokvuxen",
    "krokvuxne": "krokvuxen",
    "krokvuxnes": "krokvuxen",
    "krokvägar": "krokväg",
    "krokvägarna": "krokväg",
    "krokvägarnas": "krokväg",
    "krokvägars": "krokväg",
    "krokvägen": "krokväg",
    "krokvägens": "krokväg",
    "krokvägs": "krokväg",
    "krollsplinten": "krollsplint",
    "krollsplintens": "krollsplint",
    "krollsplints": "krollsplint",
    "kromad": "kroma",
    "kromade": "kroma",
    "kromades": "kroma",
    "kromads": "kroma",
    "kromande": "kroma",
    "kromanden": "kromande",
    "kromandena": "kromande",
    "kromandenas": "kromande",
    "kromandens": "kromande",
    "kromandes": "kromande",
    "kromandet": "kromande",
    "kromandets": "kromande",
    "kromar": "kroma",
    "kromas": "kroma",
    "kromat": "kroma",
    "kromaten": "kromat",
    "kromatens": "kromat",
    "kromater": "kromat",
    "kromaterna": "kromat",
    "kromaternas": "kromat",
    "kromaters": "kromat",
    "kromatet": "kromat",
    "kromatets": "kromat",
    "kromatiska": "kromatisk",
    "kromatiskare": "kromatisk",
    "kromatiskares": "kromatisk",
    "kromatiskas": "kromatisk",
    "kromatiskast": "kromatisk",
    "kromatiskaste": "kromatisk",
    "kromatiskastes": "kromatisk",
    "kromatiskasts": "kromatisk",
    "kromatiske": "kromatisk",
    "kromatiskes": "kromatisk",
    "kromatisks": "kromatisk",
    "kromatiskt": "kromatisk",
    "kromatiskts": "kromatisk",
    "kromats": "kromat",
    "kromdetaljen": "kromdetalj",
    "kromdetaljens": "kromdetalj",
    "kromdetaljer": "kromdetalj",
    "kromdetaljerna": "kromdetalj",
    "kromdetaljernas": "kromdetalj",
    "kromdetaljers": "kromdetalj",
    "kromdetaljs": "kromdetalj",
    "kromen": "krom",
    "kromens": "krom",
    "kromet": "krom",
    "kromets": "krom",
    "kromgarv": "kromgarva",
    "kromgarvad": "kromgarva",
    "kromgarvade": "kromgarva",
    "kromgarvades": "kromgarva",
    "kromgarvads": "kromgarva",
    "kromgarvande": "kromgarva",
    "kromgarvanden": "kromgarvande",
    "kromgarvandena": "kromgarvande",
    "kromgarvandenas": "kromgarvande",
    "kromgarvandens": "kromgarvande",
    "kromgarvandes": "kromgarvande",
    "kromgarvandet": "kromgarvande",
    "kromgarvandets": "kromgarvande",
    "kromgarvar": "kromgarva",
    "kromgarvas": "kromgarva",
    "kromgarvat": "kromgarva",
    "kromgarvats": "kromgarva",
    "kromgults": "kromgult",
    "kromlisten": "kromlist",
    "kromlistens": "kromlist",
    "kromlister": "kromlist",
    "kromlisterna": "kromlist",
    "kromlisternas": "kromlist",
    "kromlisters": "kromlist",
    "kromlists": "kromlist",
    "kromläders": "kromläder",
    "kromlädret": "kromläder",
    "kromlädrets": "kromläder",
    "kromningen": "kromning",
    "kromningens": "kromning",
    "kromnings": "kromning",
    "kromolitografien": "kromolitografi",
    "kromolitografiens": "kromolitografi",
    "kromolitografier": "kromolitografi",
    "kromolitografierna": "kromolitografi",
    "kromolitografiernas": "kromolitografi",
    "kromolitografiers": "kromolitografi",
    "kromolitografin": "kromolitografi",
    "kromolitografins": "kromolitografi",
    "kromolitografis": "kromolitografi",
    "kromosomavvikelsen": "kromosomavvikelse",
    "kromosomavvikelsens": "kromosomavvikelse",
    "kromosomavvikelser": "kromosomavvikelse",
    "kromosomavvikelserna": "kromosomavvikelse",
    "kromosomavvikelsernas": "kromosomavvikelse",
    "kromosomavvikelsers": "kromosomavvikelse",
    "kromosomavvikelses": "kromosomavvikelse",
    "kromosomen": "kromosom",
    "kromosomens": "kromosom",
    "kromosomer": "kromosom",
    "kromosomerna": "kromosom",
    "kromosomernas": "kromosom",
    "kromosomers": "kromosom",
    "kromosomparen": "kromosompar",
    "kromosomparens": "kromosompar",
    "kromosomparet": "kromosompar",
    "kromosomparets": "kromosompar",
    "kromosompars": "kromosompar",
    "kromosoms": "kromosom",
    "kromosomuppsättningar": "kromosomuppsättning",
    "kromosomuppsättningarna": "kromosomuppsättning",
    "kromosomuppsättningarnas": "kromosomuppsättning",
    "kromosomuppsättningars": "kromosomuppsättning",
    "kromosomuppsättningen": "kromosomuppsättning",
    "kromosomuppsättningens": "kromosomuppsättning",
    "kromosomuppsättnings": "kromosomuppsättning",
    "kroms": "krom",
    "kromsyran": "kromsyra",
    "kromsyrans": "kromsyra",
    "kromsyras": "kromsyra",
    "kromsyre": "kromsyra",
    "kromsyror": "kromsyra",
    "kromsyrorna": "kromsyra",
    "kromsyrornas": "kromsyra",
    "kromsyrors": "kromsyra",
    "kron": "krona",
    "kronan": "krona",
    "kronans": "kronan",
    "kronas": "krona",
    "kronbjudningar": "kronbjudning",
    "kronbjudningarna": "kronbjudning",
    "kronbjudningarnas": "kronbjudning",
    "kronbjudningars": "kronbjudning",
    "kronbjudningen": "kronbjudning",
    "kronbjudningens": "kronbjudning",
    "kronbjudnings": "kronbjudning",
    "kronbladen": "kronblad",
    "kronbladens": "kronblad",
    "kronbladet": "kronblad",
    "kronbladets": "kronblad",
    "kronblads": "kronblad",
    "kronbrudar": "kronbrud",
    "kronbrudarna": "kronbrud",
    "kronbrudarnas": "kronbrud",
    "kronbrudars": "kronbrud",
    "kronbruden": "kronbrud",
    "kronbrudens": "kronbrud",
    "kronbruds": "kronbrud",
    "krondiken": "krondike",
    "krondikena": "krondike",
    "krondikenas": "krondike",
    "krondikens": "krondike",
    "krondikes": "krondike",
    "krondiket": "krondike",
    "krondikets": "krondike",
    "krone": "krona",
    "kronhjortar": "kronhjort",
    "kronhjortarna": "kronhjort",
    "kronhjortarnas": "kronhjort",
    "kronhjortars": "kronhjort",
    "kronhjorten": "kronhjort",
    "kronhjortens": "kronhjort",
    "kronhjorts": "kronhjort",
    "kronhästar": "kronhäst",
    "kronhästarna": "kronhäst",
    "kronhästarnas": "kronhäst",
    "kronhästars": "kronhäst",
    "kronhästen": "kronhäst",
    "kronhästens": "kronhäst",
    "kronhästs": "kronhäst",
    "kronikerhemmen": "kronikerhem",
    "kronikerhemmens": "kronikerhem",
    "kronikerhemmet": "kronikerhem",
    "kronikerhemmets": "kronikerhem",
    "kronikerhems": "kronikerhem",
    "kronikern": "kroniker",
    "kronikerna": "kroniker",
    "kronikernas": "kroniker",
    "kronikerns": "kroniker",
    "kronikers": "kroniker",
    "kroniska": "kronisk",
    "kroniskare": "kronisk",
    "kroniskares": "kronisk",
    "kroniskas": "kronisk",
    "kroniskast": "kronisk",
    "kroniskaste": "kronisk",
    "kroniskastes": "kronisk",
    "kroniskasts": "kronisk",
    "kroniske": "kronisk",
    "kroniskes": "kronisk",
    "kronisks": "kronisk",
    "kroniskt": "kronisk",
    "kroniskts": "kronisk",
    "kronjuristen": "kronjurist",
    "kronjuristens": "kronjurist",
    "kronjurister": "kronjurist",
    "kronjuristerna": "kronjurist",
    "kronjuristernas": "kronjurist",
    "kronjuristers": "kronjurist",
    "kronjurists": "kronjurist",
    "kronjuvelen": "kronjuvel",
    "kronjuvelens": "kronjuvel",
    "kronjuveler": "kronjuvel",
    "kronjuvelerna": "kronjuvel",
    "kronjuvelernas": "kronjuvel",
    "kronjuvelers": "kronjuvel",
    "kronjuvels": "kronjuvel",
    "kronkolonien": "kronkoloni",
    "kronkoloniens": "kronkoloni",
    "kronkolonier": "kronkoloni",
    "kronkolonierna": "kronkoloni",
    "kronkoloniernas": "kronkoloni",
    "kronkoloniers": "kronkoloni",
    "kronkolonin": "kronkoloni",
    "kronkolonins": "kronkoloni",
    "kronkolonis": "kronkoloni",
    "kronmuttern": "kronmutter",
    "kronmutterns": "kronmutter",
    "kronmutters": "kronmutter",
    "kronmuttrar": "kronmutter",
    "kronmuttrarna": "kronmutter",
    "kronmuttrarnas": "kronmutter",
    "kronmuttrars": "kronmutter",
    "kronofogd": "kronofogde",
    "kronofogdar": "kronofogde",
    "kronofogdarna": "kronofogde",
    "kronofogdarnas": "kronofogde",
    "kronofogdars": "kronofogde",
    "kronofogden": "kronofogde",
    "kronofogdens": "kronofogde",
    "kronofogdes": "kronofogde",
    "kronofogds": "kronofogde",
    "kronojordar": "kronojord",
    "kronojordarna": "kronojord",
    "kronojordarnas": "kronojord",
    "kronojordars": "kronojord",
    "kronojorden": "kronojord",
    "kronojordens": "kronojord",
    "kronojords": "kronojord",
    "kronojägar": "kronojägare",
    "kronojägaren": "kronojägare",
    "kronojägarens": "kronojägare",
    "kronojägares": "kronojägare",
    "kronojägarna": "kronojägare",
    "kronojägarnas": "kronojägare",
    "kronologien": "kronologi",
    "kronologiens": "kronologi",
    "kronologier": "kronologi",
    "kronologierna": "kronologi",
    "kronologiernas": "kronologi",
    "kronologiers": "kronologi",
    "kronologin": "kronologi",
    "kronologins": "kronologi",
    "kronologis": "kronologi",
    "kronologiska": "kronologisk",
    "kronologiskare": "kronologisk",
    "kronologiskares": "kronologisk",
    "kronologiskas": "kronologisk",
    "kronologiskast": "kronologisk",
    "kronologiskaste": "kronologisk",
    "kronologiskastes": "kronologisk",
    "kronologiskasts": "kronologisk",
    "kronologiske": "kronologisk",
    "kronologiskes": "kronologisk",
    "kronologisks": "kronologisk",
    "kronologiskt": "kronologisk",
    "kronologiskts": "kronologisk",
    "kronometern": "kronometer",
    "kronometerns": "kronometer",
    "kronometers": "kronometer",
    "kronometrar": "kronometer",
    "kronometrarna": "kronometer",
    "kronometrarnas": "kronometer",
    "kronometrars": "kronometer",
    "kronoparken": "kronopark",
    "kronoparkens": "kronopark",
    "kronoparker": "kronopark",
    "kronoparkerna": "kronopark",
    "kronoparkernas": "kronopark",
    "kronoparkers": "kronopark",
    "kronoparks": "kronopark",
    "kronor": "krona",
    "kronorna": "krona",
    "kronornas": "krona",
    "kronors": "krona",
    "kronoutskylden": "kronoutskyld",
    "kronoutskyldens": "kronoutskyld",
    "kronoutskylder": "kronoutskyld",
    "kronoutskylderna": "kronoutskyld",
    "kronoutskyldernas": "kronoutskyld",
    "kronoutskylders": "kronoutskyld",
    "kronoutskylds": "kronoutskyld",
    "kronprinsar": "kronprins",
    "kronprinsarna": "kronprins",
    "kronprinsarnas": "kronprins",
    "kronprinsars": "kronprins",
    "kronprinsen": "kronprins",
    "kronprinsens": "kronprins",
    "kronprinsess": "kronprinsessa",
    "kronprinsessan": "kronprinsessa",
    "kronprinsessans": "kronprinsessa",
    "kronprinsessas": "kronprinsessa",
    "kronprinsessbröllopen": "kronprinsessbröllop",
    "kronprinsessbröllopens": "kronprinsessbröllop",
    "kronprinsessbröllopet": "kronprinsessbröllop",
    "kronprinsessbröllopets": "kronprinsessbröllop",
    "kronprinsessbröllops": "kronprinsessbröllop",
    "kronprinsesse": "kronprinsessa",
    "kronprinsessor": "kronprinsessa",
    "kronprinsessorna": "kronprinsessa",
    "kronprinsessornas": "kronprinsessa",
    "kronprinsessors": "kronprinsessa",
    "krons": "krona",
    "krontalen": "krontal",
    "krontalens": "krontal",
    "krontalet": "krontal",
    "krontalets": "krontal",
    "krontals": "krontal",
    "kronvittnen": "kronvittne",
    "kronvittnena": "kronvittne",
    "kronvittnenas": "kronvittne",
    "kronvittnens": "kronvittne",
    "kronvittnes": "kronvittne",
    "kronvittnet": "kronvittne",
    "kronvittnets": "kronvittne",
    "kronvraken": "kronvrak",
    "kronvrakens": "kronvrak",
    "kronvraket": "kronvrak",
    "kronvrakets": "kronvrak",
    "kronvraks": "kronvrak",
    "kronärtskock": "kronärtskocka",
    "kronärtskockan": "kronärtskocka",
    "kronärtskockans": "kronärtskocka",
    "kronärtskockas": "kronärtskocka",
    "kronärtskocke": "kronärtskocka",
    "kronärtskockor": "kronärtskocka",
    "kronärtskockorna": "kronärtskocka",
    "kronärtskockornas": "kronärtskocka",
    "kronärtskockors": "kronärtskocka",
    "kronärtskocks": "kronärtskocka",
    "kroppar": "kropp",
    "kropparna": "kropp",
    "kropparnas": "kropp",
    "kroppars": "kropp",
    "kroppen": "kropp",
    "kroppens": "kropp",
    "kroppkak": "kroppkaka",
    "kroppkakan": "kroppkaka",
    "kroppkakans": "kroppkaka",
    "kroppkakas": "kroppkaka",
    "kroppkake": "kroppkaka",
    "kroppkakor": "kroppkaka",
    "kroppkakorna": "kroppkaka",
    "kroppkakornas": "kroppkaka",
    "kroppkakors": "kroppkaka",
    "kroppkaks": "kroppkaka",
    "kropps": "kropp",
    "kroppsagan": "kroppsaga",
    "kroppsagans": "kroppsaga",
    "kroppsagas": "kroppsaga",
    "kroppsarbetade": "kroppsarbeta",
    "kroppsarbetades": "kroppsarbeta",
    "kroppsarbetande": "kroppsarbeta",
    "kroppsarbetanden": "kroppsarbetande",
    "kroppsarbetandena": "kroppsarbetande",
    "kroppsarbetandenas": "kroppsarbetande",
    "kroppsarbetandens": "kroppsarbetande",
    "kroppsarbetandes": "kroppsarbetande",
    "kroppsarbetandet": "kroppsarbetande",
    "kroppsarbetandets": "kroppsarbetande",
    "kroppsarbetar": "kroppsarbetare",
    "kroppsarbetaren": "kroppsarbetare",
    "kroppsarbetarens": "kroppsarbetare",
    "kroppsarbetares": "kroppsarbetare",
    "kroppsarbetarna": "kroppsarbetare",
    "kroppsarbetarnas": "kroppsarbetare",
    "kroppsarbetas": "kroppsarbeta",
    "kroppsarbetat": "kroppsarbeta",
    "kroppsarbetats": "kroppsarbeta",
    "kroppsarbeten": "kroppsarbete",
    "kroppsarbetena": "kroppsarbete",
    "kroppsarbetenas": "kroppsarbete",
    "kroppsarbetens": "kroppsarbete",
    "kroppsarbetes": "kroppsarbete",
    "kroppsarbetet": "kroppsarbete",
    "kroppsarbetets": "kroppsarbete",
    "kroppsarbets": "kroppsarbete",
    "kroppsbehåringen": "kroppsbehåring",
    "kroppsbehåringens": "kroppsbehåring",
    "kroppsbehårings": "kroppsbehåring",
    "kroppsbilden": "kroppsbild",
    "kroppsbildens": "kroppsbild",
    "kroppsbilder": "kroppsbild",
    "kroppsbilderna": "kroppsbild",
    "kroppsbildernas": "kroppsbild",
    "kroppsbilders": "kroppsbild",
    "kroppsbilds": "kroppsbild",
    "kroppsbyggandes": "kroppsbyggande",
    "kroppsbyggandet": "kroppsbyggande",
    "kroppsbyggandets": "kroppsbyggande",
    "kroppsbyggar": "kroppsbyggare",
    "kroppsbyggaren": "kroppsbyggare",
    "kroppsbyggarens": "kroppsbyggare",
    "kroppsbyggares": "kroppsbyggare",
    "kroppsbyggarna": "kroppsbyggare",
    "kroppsbyggarnas": "kroppsbyggare",
    "kroppsbyggnaden": "kroppsbyggnad",
    "kroppsbyggnadens": "kroppsbyggnad",
    "kroppsbyggnader": "kroppsbyggnad",
    "kroppsbyggnaderna": "kroppsbyggnad",
    "kroppsbyggnadernas": "kroppsbyggnad",
    "kroppsbyggnaders": "kroppsbyggnad",
    "kroppsbyggnads": "kroppsbyggnad",
    "kroppscellen": "kroppscell",
    "kroppscellens": "kroppscell",
    "kroppsceller": "kroppscell",
    "kroppscellerna": "kroppscell",
    "kroppscellernas": "kroppscell",
    "kroppscellers": "kroppscell",
    "kroppscells": "kroppscell",
    "kroppsdelar": "kroppsdel",
    "kroppsdelarna": "kroppsdel",
    "kroppsdelarnas": "kroppsdel",
    "kroppsdelars": "kroppsdel",
    "kroppsdelen": "kroppsdel",
    "kroppsdelens": "kroppsdel",
    "kroppsdels": "kroppsdel",
    "kroppsfetter": "kroppsfett",
    "kroppsfetterna": "kroppsfett",
    "kroppsfetternas": "kroppsfett",
    "kroppsfetters": "kroppsfett",
    "kroppsfettet": "kroppsfett",
    "kroppsfettets": "kroppsfett",
    "kroppsfetts": "kroppsfett",
    "kroppsfixeringar": "kroppsfixering",
    "kroppsfixeringarna": "kroppsfixering",
    "kroppsfixeringarnas": "kroppsfixering",
    "kroppsfixeringars": "kroppsfixering",
    "kroppsfixeringen": "kroppsfixering",
    "kroppsfixeringens": "kroppsfixering",
    "kroppsfixerings": "kroppsfixering",
    "kroppsformen": "kroppsform",
    "kroppsformens": "kroppsform",
    "kroppsformer": "kroppsform",
    "kroppsformerna": "kroppsform",
    "kroppsformernas": "kroppsform",
    "kroppsformers": "kroppsform",
    "kroppsforms": "kroppsform",
    "kroppsfunktionen": "kroppsfunktion",
    "kroppsfunktionens": "kroppsfunktion",
    "kroppsfunktioner": "kroppsfunktion",
    "kroppsfunktionerna": "kroppsfunktion",
    "kroppsfunktionernas": "kroppsfunktion",
    "kroppsfunktioners": "kroppsfunktion",
    "kroppsfunktions": "kroppsfunktion",
    "kroppsfynden": "kroppsfynd",
    "kroppsfyndens": "kroppsfynd",
    "kroppsfyndet": "kroppsfynd",
    "kroppsfyndets": "kroppsfynd",
    "kroppsfynds": "kroppsfynd",
    "kroppsföraktet": "kroppsförakt",
    "kroppsföraktets": "kroppsförakt",
    "kroppsförakts": "kroppsförakt",
    "kroppshydd": "kroppshydda",
    "kroppshyddan": "kroppshydda",
    "kroppshyddans": "kroppshydda",
    "kroppshyddas": "kroppshydda",
    "kroppshydde": "kroppshydda",
    "kroppshyddor": "kroppshydda",
    "kroppshyddorna": "kroppshydda",
    "kroppshyddornas": "kroppshydda",
    "kroppshyddors": "kroppshydda",
    "kroppshydds": "kroppshydda",
    "kroppshåren": "kroppshår",
    "kroppshårens": "kroppshår",
    "kroppshåret": "kroppshår",
    "kroppshårets": "kroppshår",
    "kroppshårs": "kroppshår",
    "kroppskanalen": "kroppskanal",
    "kroppskanalens": "kroppskanal",
    "kroppskanaler": "kroppskanal",
    "kroppskanalerna": "kroppskanal",
    "kroppskanalernas": "kroppskanal",
    "kroppskanalers": "kroppskanal",
    "kroppskanals": "kroppskanal",
    "kroppskontrollen": "kroppskontroll",
    "kroppskontrollens": "kroppskontroll",
    "kroppskontrolls": "kroppskontroll",
    "kroppskulturen": "kroppskultur",
    "kroppskulturens": "kroppskultur",
    "kroppskulturs": "kroppskultur",
    "kroppsliga": "kroppslig",
    "kroppsligare": "kroppslig",
    "kroppsligares": "kroppslig",
    "kroppsligas": "kroppslig",
    "kroppsligast": "kroppslig",
    "kroppsligaste": "kroppslig",
    "kroppsligastes": "kroppslig",
    "kroppsligasts": "kroppslig",
    "kroppslige": "kroppslig",
    "kroppsliges": "kroppslig",
    "kroppsligheten": "kroppslighet",
    "kroppslighetens": "kroppslighet",
    "kroppsligheter": "kroppslighet",
    "kroppsligheterna": "kroppslighet",
    "kroppsligheternas": "kroppslighet",
    "kroppsligheters": "kroppslighet",
    "kroppslighets": "kroppslighet",
    "kroppsligs": "kroppslig",
    "kroppsligt": "kroppslig",
    "kroppsligts": "kroppslig",
    "kroppsorganen": "kroppsorgan",
    "kroppsorganens": "kroppsorgan",
    "kroppsorganet": "kroppsorgan",
    "kroppsorganets": "kroppsorgan",
    "kroppsorgans": "kroppsorgan",
    "kroppspulsådern": "kroppspulsåder",
    "kroppspulsåderns": "kroppspulsåder",
    "kroppspulsåders": "kroppspulsåder",
    "kroppsrörelsen": "kroppsrörelse",
    "kroppsrörelsens": "kroppsrörelse",
    "kroppsrörelser": "kroppsrörelse",
    "kroppsrörelserna": "kroppsrörelse",
    "kroppsrörelsernas": "kroppsrörelse",
    "kroppsrörelsers": "kroppsrörelse",
    "kroppsrörelses": "kroppsrörelse",
    "kroppsskadan": "kroppsskada",
    "kroppsskadans": "kroppsskada",
    "kroppsskadas": "kroppsskada",
    "kroppsskade": "kroppsskada",
    "kroppsskador": "kroppsskada",
    "kroppsskadorna": "kroppsskada",
    "kroppsskadornas": "kroppsskada",
    "kroppsskadors": "kroppsskada",
    "kroppsspråket": "kroppsspråk",
    "kroppsspråkets": "kroppsspråk",
    "kroppsspråks": "kroppsspråk",
    "kroppsstorlekar": "kroppsstorlek",
    "kroppsstorlekarna": "kroppsstorlek",
    "kroppsstorlekarnas": "kroppsstorlek",
    "kroppsstorlekars": "kroppsstorlek",
    "kroppsstorleken": "kroppsstorlek",
    "kroppsstorlekens": "kroppsstorlek",
    "kroppsstorleks": "kroppsstorlek",
    "kroppsstyrkan": "kroppsstyrka",
    "kroppsstyrkans": "kroppsstyrka",
    "kroppsstyrkas": "kroppsstyrka",
    "kroppsstyrke": "kroppsstyrka",
    "kroppsstyrkor": "kroppsstyrka",
    "kroppsstyrkorna": "kroppsstyrka",
    "kroppsstyrkornas": "kroppsstyrka",
    "kroppsstyrkors": "kroppsstyrka",
    "kroppsställningar": "kroppsställning",
    "kroppsställningarna": "kroppsställning",
    "kroppsställningarnas": "kroppsställning",
    "kroppsställningars": "kroppsställning",
    "kroppsställningen": "kroppsställning",
    "kroppsställningens": "kroppsställning",
    "kroppsställnings": "kroppsställning",
    "kroppstemperaturen": "kroppstemperatur",
    "kroppstemperaturens": "kroppstemperatur",
    "kroppstemperaturer": "kroppstemperatur",
    "kroppstemperaturerna": "kroppstemperatur",
    "kroppstemperaturernas": "kroppstemperatur",
    "kroppstemperaturers": "kroppstemperatur",
    "kroppstemperaturs": "kroppstemperatur",
    "kroppstyngden": "kroppstyngd",
    "kroppstyngdens": "kroppstyngd",
    "kroppstyngds": "kroppstyngd",
    "kroppsvikten": "kroppsvikt",
    "kroppsviktens": "kroppsvikt",
    "kroppsvikter": "kroppsvikt",
    "kroppsvikterna": "kroppsvikt",
    "kroppsvikternas": "kroppsvikt",
    "kroppsvikters": "kroppsvikt",
    "kroppsvikts": "kroppsvikt",
    "kroppsvisitationen": "kroppsvisitation",
    "kroppsvisitationens": "kroppsvisitation",
    "kroppsvisitationer": "kroppsvisitation",
    "kroppsvisitationerna": "kroppsvisitation",
    "kroppsvisitationernas": "kroppsvisitation",
    "kroppsvisitationers": "kroppsvisitation",
    "kroppsvisitations": "kroppsvisitation",
    "kroppsvisiterad": "kroppsvisitera",
    "kroppsvisiterade": "kroppsvisitera",
    "kroppsvisiterades": "kroppsvisitera",
    "kroppsvisiterads": "kroppsvisitera",
    "kroppsvisiterande": "kroppsvisitera",
    "kroppsvisiteranden": "kroppsvisiterande",
    "kroppsvisiterandena": "kroppsvisiterande",
    "kroppsvisiterandenas": "kroppsvisiterande",
    "kroppsvisiterandens": "kroppsvisiterande",
    "kroppsvisiterandes": "kroppsvisiterande",
    "kroppsvisiterandet": "kroppsvisiterande",
    "kroppsvisiterandets": "kroppsvisiterande",
    "kroppsvisiterar": "kroppsvisitera",
    "kroppsvisiteras": "kroppsvisitera",
    "kroppsvisiterat": "kroppsvisitera",
    "kroppsvisiterats": "kroppsvisitera",
    "kroppsvisiterbara": "kroppsvisiterbar",
    "kroppsvisiterbarare": "kroppsvisiterbar",
    "kroppsvisiterbarares": "kroppsvisiterbar",
    "kroppsvisiterbaras": "kroppsvisiterbar",
    "kroppsvisiterbarast": "kroppsvisiterbar",
    "kroppsvisiterbaraste": "kroppsvisiterbar",
    "kroppsvisiterbarastes": "kroppsvisiterbar",
    "kroppsvisiterbarasts": "kroppsvisiterbar",
    "kroppsvisiterbare": "kroppsvisiterbar",
    "kroppsvisiterbares": "kroppsvisiterbar",
    "kroppsvisiterbarheten": "kroppsvisiterbarhet",
    "kroppsvisiterbarhetens": "kroppsvisiterbarhet",
    "kroppsvisiterbarhets": "kroppsvisiterbarhet",
    "kroppsvisiterbars": "kroppsvisiterbar",
    "kroppsvisiterbart": "kroppsvisiterbar",
    "kroppsvisiterbarts": "kroppsvisiterbar",
    "kroppsvisiteringar": "kroppsvisitering",
    "kroppsvisiteringarna": "kroppsvisitering",
    "kroppsvisiteringarnas": "kroppsvisitering",
    "kroppsvisiteringars": "kroppsvisitering",
    "kroppsvisiteringen": "kroppsvisitering",
    "kroppsvisiteringens": "kroppsvisitering",
    "kroppsvisiterings": "kroppsvisitering",
    "kroppsvätskan": "kroppsvätska",
    "kroppsvätskans": "kroppsvätska",
    "kroppsvätskas": "kroppsvätska",
    "kroppsvätske": "kroppsvätska",
    "kroppsvätskor": "kroppsvätska",
    "kroppsvätskorna": "kroppsvätska",
    "kroppsvätskornas": "kroppsvätska",
    "kroppsvätskors": "kroppsvätska",
    "kroppsvävnaden": "kroppsvävnad",
    "kroppsvävnadens": "kroppsvävnad",
    "kroppsvävnader": "kroppsvävnad",
    "kroppsvävnaderna": "kroppsvävnad",
    "kroppsvävnadernas": "kroppsvävnad",
    "kroppsvävnaders": "kroppsvävnad",
    "kroppsvävnads": "kroppsvävnad",
    "kroppsöppningar": "kroppsöppning",
    "kroppsöppningarna": "kroppsöppning",
    "kroppsöppningarnas": "kroppsöppning",
    "kroppsöppningars": "kroppsöppning",
    "kroppsöppningen": "kroppsöppning",
    "kroppsöppningens": "kroppsöppning",
    "kroppsöppnings": "kroppsöppning",
    "kroppsövningar": "kroppsövning",
    "kroppsövningarna": "kroppsövning",
    "kroppsövningarnas": "kroppsövning",
    "kroppsövningars": "kroppsövning",
    "kroppsövningen": "kroppsövning",
    "kroppsövningens": "kroppsövning",
    "kroppsövnings": "kroppsövning",
    "kroppåsar": "kroppås",
    "kroppåsarna": "kroppås",
    "kroppåsarnas": "kroppås",
    "kroppåsars": "kroppås",
    "kroppåsen": "kroppås",
    "kroppåsens": "kroppås",
    "kross": "krossa",
    "krossad": "krossa",
    "krossade": "krossa",
    "krossades": "krossa",
    "krossads": "krossa",
    "krossande": "krossa",
    "krossanden": "krossande",
    "krossandena": "krossande",
    "krossandenas": "krossande",
    "krossandens": "krossande",
    "krossandes": "krossande",
    "krossandet": "krossande",
    "krossandets": "krossande",
    "krossar": "krossa",
    "krossarna": "kross",
    "krossarnas": "kross",
    "krossars": "kross",
    "krossas": "krossa",
    "krossat": "krossa",
    "krossats": "krossa",
    "krossen": "kross",
    "krossens": "kross",
    "krosset": "kross",
    "krossets": "kross",
    "krossfria": "krossfri",
    "krossfriare": "krossfri",
    "krossfriares": "krossfri",
    "krossfrias": "krossfri",
    "krossfriast": "krossfri",
    "krossfriaste": "krossfri",
    "krossfriastes": "krossfri",
    "krossfriasts": "krossfri",
    "krossfrie": "krossfri",
    "krossfries": "krossfri",
    "krossfris": "krossfri",
    "krossfritt": "krossfri",
    "krossfritts": "krossfri",
    "krosskadan": "krosskada",
    "krosskadans": "krosskada",
    "krosskadas": "krosskada",
    "krosskade": "krosskada",
    "krosskador": "krosskada",
    "krosskadorna": "krosskada",
    "krosskadornas": "krosskada",
    "krosskadors": "krosskada",
    "krossmaskinen": "krossmaskin",
    "krossmaskinens": "krossmaskin",
    "krossmaskiner": "krossmaskin",
    "krossmaskinerna": "krossmaskin",
    "krossmaskinernas": "krossmaskin",
    "krossmaskiners": "krossmaskin",
    "krossmaskins": "krossmaskin",
    "krossåren": "krossår",
    "krossårens": "krossår",
    "krossåret": "krossår",
    "krossårets": "krossår",
    "krossårs": "krossår",
    "krubb": "krubba",
    "krubbade": "krubba",
    "krubbades": "krubba",
    "krubban": "krubba",
    "krubbande": "krubba",
    "krubbanden": "krubbande",
    "krubbandena": "krubbande",
    "krubbandenas": "krubbande",
    "krubbandens": "krubbande",
    "krubbandes": "krubbande",
    "krubbandet": "krubbande",
    "krubbandets": "krubbande",
    "krubbans": "krubba",
    "krubbar": "krubba",
    "krubbas": "krubba",
    "krubbat": "krubba",
    "krubbats": "krubba",
    "krubbe": "krubba",
    "krubbet": "krubb",
    "krubbets": "krubb",
    "krubbitar": "krubbitare",
    "krubbitaren": "krubbitare",
    "krubbitarens": "krubbitare",
    "krubbitares": "krubbitare",
    "krubbitarna": "krubbitare",
    "krubbitarnas": "krubbitare",
    "krubbor": "krubba",
    "krubborna": "krubba",
    "krubbornas": "krubba",
    "krubbors": "krubba",
    "krubbs": "krubba",
    "krucifixen": "krucifix",
    "krucifixens": "krucifix",
    "krucifixet": "krucifix",
    "krucifixets": "krucifix",
    "kruk": "kruka",
    "krukan": "kruka",
    "krukans": "kruka",
    "krukas": "kruka",
    "kruke": "kruka",
    "krukgodsen": "krukgods",
    "krukgodsens": "krukgods",
    "krukgodset": "krukgods",
    "krukgodsets": "krukgods",
    "krukmakar": "krukmakare",
    "krukmakaren": "krukmakare",
    "krukmakarens": "krukmakare",
    "krukmakares": "krukmakare",
    "krukmakarna": "krukmakare",
    "krukmakarnas": "krukmakare",
    "krukmakerier": "krukmakeri",
    "krukmakerierna": "krukmakeri",
    "krukmakeriernas": "krukmakeri",
    "krukmakeriers": "krukmakeri",
    "krukmakeriet": "krukmakeri",
    "krukmakeriets": "krukmakeri",
    "krukmakeris": "krukmakeri",
    "krukmakerit": "krukmakeri",
    "krukmakerits": "krukmakeri",
    "krukor": "kruka",
    "krukorna": "kruka",
    "krukornas": "kruka",
    "krukors": "kruka",
    "kruks": "kruka",
    "krukskärv": "krukskärva",
    "krukskärvan": "krukskärva",
    "krukskärvans": "krukskärva",
    "krukskärvas": "krukskärva",
    "krukskärve": "krukskärva",
    "krukskärvor": "krukskärva",
    "krukskärvorna": "krukskärva",
    "krukskärvornas": "krukskärva",
    "krukskärvors": "krukskärva",
    "krukskärvs": "krukskärva",
    "krukväxten": "krukväxt",
    "krukväxtens": "krukväxt",
    "krukväxter": "krukväxt",
    "krukväxterna": "krukväxt",
    "krukväxternas": "krukväxt",
    "krukväxters": "krukväxt",
    "krukväxts": "krukväxt",
    "krull": "krulla",
    "krullad": "krulla",
    "krullade": "krulla",
    "krullades": "krulla",
    "krullads": "krulla",
    "krullande": "krulla",
    "krullanden": "krullande",
    "krullandena": "krullande",
    "krullandenas": "krullande",
    "krullandens": "krullande",
    "krullandes": "krullande",
    "krullandet": "krullande",
    "krullandets": "krullande",
    "krullar": "krulla",
    "krullas": "krulla",
    "krullat": "krulla",
    "krullats": "krulla",
    "krullet": "krull",
    "krullets": "krull",
    "krullhåret": "krullhår",
    "krullhårets": "krullhår",
    "krullhåriga": "krullhårig",
    "krullhårigare": "krullhårig",
    "krullhårigares": "krullhårig",
    "krullhårigas": "krullhårig",
    "krullhårigast": "krullhårig",
    "krullhårigaste": "krullhårig",
    "krullhårigastes": "krullhårig",
    "krullhårigasts": "krullhårig",
    "krullhårige": "krullhårig",
    "krullhåriges": "krullhårig",
    "krullhårigheten": "krullhårighet",
    "krullhårighetens": "krullhårighet",
    "krullhårighets": "krullhårighet",
    "krullhårigs": "krullhårig",
    "krullhårigt": "krullhårig",
    "krullhårigts": "krullhårig",
    "krullhårs": "krullhår",
    "krulliga": "krullig",
    "krulligare": "krullig",
    "krulligares": "krullig",
    "krulligas": "krullig",
    "krulligast": "krullig",
    "krulligaste": "krullig",
    "krulligastes": "krullig",
    "krulligasts": "krullig",
    "krullige": "krullig",
    "krulliges": "krullig",
    "krulligheten": "krullighet",
    "krullighetens": "krullighet",
    "krullighets": "krullighet",
    "krulligs": "krullig",
    "krulligt": "krullig",
    "krulligts": "krullig",
    "krulls": "krull",
    "krumbukt": "krumbukter",
    "krumbuktade": "krumbukta",
    "krumbuktades": "krumbukta",
    "krumbuktande": "krumbukta",
    "krumbuktanden": "krumbuktande",
    "krumbuktandena": "krumbuktande",
    "krumbuktandenas": "krumbuktande",
    "krumbuktandens": "krumbuktande",
    "krumbuktandes": "krumbuktande",
    "krumbuktandet": "krumbuktande",
    "krumbuktandets": "krumbuktande",
    "krumbuktar": "krumbukta",
    "krumbuktas": "krumbukta",
    "krumbuktat": "krumbukta",
    "krumbuktats": "krumbukta",
    "krumbukten": "krumbukt",
    "krumbuktens": "krumbukt",
    "krumbukter": "krumbukt",
    "krumbukterna": "krumbukter",
    "krumbukternas": "krumbukter",
    "krumbukters": "krumbukter",
    "krumbukts": "krumbukter",
    "krumeluren": "krumelur",
    "krumelurens": "krumelur",
    "krumelurer": "krumelur",
    "krumelurerna": "krumelur",
    "krumelurernas": "krumelur",
    "krumelurers": "krumelur",
    "krumelurs": "krumelur",
    "krumheten": "krumhet",
    "krumhetens": "krumhet",
    "krumhets": "krumhet",
    "krumhornen": "krumhorn",
    "krumhornens": "krumhorn",
    "krumhornet": "krumhorn",
    "krumhornets": "krumhorn",
    "krumhorns": "krumhorn",
    "krumma": "krum",
    "krummare": "krum",
    "krummares": "krum",
    "krummas": "krum",
    "krummast": "krum",
    "krummaste": "krum",
    "krummastes": "krum",
    "krummasts": "krum",
    "krumme": "krum",
    "krummes": "krum",
    "krumpenheten": "krumpenhet",
    "krumpenhetens": "krumpenhet",
    "krumpenhets": "krumpenhet",
    "krumpens": "krumpen",
    "krumpet": "krumpen",
    "krumpets": "krumpen",
    "krumpna": "krumpen",
    "krumpnare": "krumpen",
    "krumpnares": "krumpen",
    "krumpnas": "krumpen",
    "krumpnast": "krumpen",
    "krumpnaste": "krumpen",
    "krumpnastes": "krumpen",
    "krumpnasts": "krumpen",
    "krumpne": "krumpen",
    "krumpnes": "krumpen",
    "krums": "krum",
    "krumsprången": "krumsprång",
    "krumsprångens": "krumsprång",
    "krumsprånget": "krumsprång",
    "krumsprångets": "krumsprång",
    "krumsprångs": "krumsprång",
    "krumstavar": "krumstav",
    "krumstavarna": "krumstav",
    "krumstavarnas": "krumstav",
    "krumstavars": "krumstav",
    "krumstaven": "krumstav",
    "krumstavens": "krumstav",
    "krumstavs": "krumstav",
    "krumt": "krum",
    "krumts": "krum",
    "krupe": "krypa",
    "krupes": "krypa",
    "krupit": "krypa",
    "krupits": "krypa",
    "kruppen": "krupp",
    "kruppens": "krupp",
    "krupps": "krupp",
    "krusad": "krusa",
    "krusade": "krusa",
    "krusades": "krusa",
    "krusads": "krusa",
    "krusande": "krusa",
    "krusanden": "krusande",
    "krusandena": "krusande",
    "krusandenas": "krusande",
    "krusandens": "krusande",
    "krusandes": "krusande",
    "krusandet": "krusande",
    "krusandets": "krusande",
    "krusar": "krusa",
    "krusas": "krusa",
    "krusat": "krusa",
    "krusats": "krusa",
    "krusbären": "krusbär",
    "krusbärens": "krusbär",
    "krusbäret": "krusbär",
    "krusbärets": "krusbär",
    "krusbärs": "krusbär",
    "krusbärsbusk": "krusbärsbuske",
    "krusbärsbuskar": "krusbärsbuske",
    "krusbärsbuskarna": "krusbärsbuske",
    "krusbärsbuskarnas": "krusbärsbuske",
    "krusbärsbuskars": "krusbärsbuske",
    "krusbärsbusken": "krusbärsbuske",
    "krusbärsbuskens": "krusbärsbuske",
    "krusbärsbuskes": "krusbärsbuske",
    "krusen": "krus",
    "krusens": "krus",
    "kruserliga": "kruserlig",
    "kruserligare": "kruserlig",
    "kruserligares": "kruserlig",
    "kruserligas": "kruserlig",
    "kruserligast": "kruserlig",
    "kruserligaste": "kruserlig",
    "kruserligastes": "kruserlig",
    "kruserligasts": "kruserlig",
    "kruserlige": "kruserlig",
    "kruserliges": "kruserlig",
    "kruserligheten": "kruserlighet",
    "kruserlighetens": "kruserlighet",
    "kruserlighets": "kruserlighet",
    "kruserligs": "kruserlig",
    "kruserligt": "kruserlig",
    "kruserligts": "kruserlig",
    "kruset": "krus",
    "krusets": "krus",
    "krushåriga": "krushårig",
    "krushårigare": "krushårig",
    "krushårigares": "krushårig",
    "krushårigas": "krushårig",
    "krushårigast": "krushårig",
    "krushårigaste": "krushårig",
    "krushårigastes": "krushårig",
    "krushårigasts": "krushårig",
    "krushårige": "krushårig",
    "krushåriges": "krushårig",
    "krushårigheten": "krushårighet",
    "krushårighetens": "krushårighet",
    "krushårighets": "krushårighet",
    "krushårigs": "krushårig",
    "krushårigt": "krushårig",
    "krushårigts": "krushårig",
    "krusidull": "krusiduller",
    "krusidullen": "krusidull",
    "krusidullens": "krusidull",
    "krusiduller": "krusidull",
    "krusidullerna": "krusiduller",
    "krusidullernas": "krusiduller",
    "krusidullers": "krusiduller",
    "krusidulliga": "krusidullig",
    "krusidulligare": "krusidullig",
    "krusidulligares": "krusidullig",
    "krusidulligas": "krusidullig",
    "krusidulligast": "krusidullig",
    "krusidulligaste": "krusidullig",
    "krusidulligastes": "krusidullig",
    "krusidulligasts": "krusidullig",
    "krusidullige": "krusidullig",
    "krusidulliges": "krusidullig",
    "krusidulligheten": "krusidullighet",
    "krusidullighetens": "krusidullighet",
    "krusidullighets": "krusidullighet",
    "krusidulligs": "krusidullig",
    "krusidulligt": "krusidullig",
    "krusidulligts": "krusidullig",
    "krusidulls": "krusiduller",
    "krusiga": "krusig",
    "krusigare": "krusig",
    "krusigares": "krusig",
    "krusigas": "krusig",
    "krusigast": "krusig",
    "krusigaste": "krusig",
    "krusigastes": "krusig",
    "krusigasts": "krusig",
    "krusige": "krusig",
    "krusiges": "krusig",
    "krusigs": "krusig",
    "krusigt": "krusig",
    "krusigts": "krusig",
    "kruskan": "kruska",
    "kruskans": "kruska",
    "kruskas": "kruska",
    "kruskålen": "kruskål",
    "kruskålens": "kruskål",
    "kruskåls": "kruskål",
    "krusmyntan": "krusmynta",
    "krusmyntans": "krusmynta",
    "krusmyntas": "krusmynta",
    "kruspersiljan": "kruspersilja",
    "kruspersiljans": "kruspersilja",
    "kruspersiljas": "kruspersilja",
    "krust": "krusta",
    "krustaden": "krustad",
    "krustadens": "krustad",
    "krustader": "krustad",
    "krustaderna": "krustad",
    "krustadernas": "krustad",
    "krustaders": "krustad",
    "krustads": "krustad",
    "krustan": "krusta",
    "krustans": "krusta",
    "krustas": "krusta",
    "kruste": "krusta",
    "krustor": "krusta",
    "krustorna": "krusta",
    "krustornas": "krusta",
    "krustors": "krusta",
    "krustänger": "krustång",
    "krustängerna": "krustång",
    "krustängernas": "krustång",
    "krustängers": "krustång",
    "krustången": "krustång",
    "krustångens": "krustång",
    "krustångs": "krustång",
    "kruståteln": "kruståtel",
    "kruståtelns": "kruståtel",
    "kruståtels": "kruståtel",
    "kruståtlar": "kruståtel",
    "kruståtlarna": "kruståtel",
    "kruståtlarnas": "kruståtel",
    "kruståtlars": "kruståtel",
    "krutdurkar": "krutdurk",
    "krutdurkarna": "krutdurk",
    "krutdurkarnas": "krutdurk",
    "krutdurkars": "krutdurk",
    "krutdurken": "krutdurk",
    "krutdurkens": "krutdurk",
    "krutdurks": "krutdurk",
    "krutet": "krut",
    "krutets": "krut",
    "krutgasen": "krutgas",
    "krutgasens": "krutgas",
    "krutgaser": "krutgas",
    "krutgaserna": "krutgas",
    "krutgasernas": "krutgas",
    "krutgasers": "krutgas",
    "krutgubb": "krutgubbe",
    "krutgubbar": "krutgubbe",
    "krutgubbarna": "krutgubbe",
    "krutgubbarnas": "krutgubbe",
    "krutgubbars": "krutgubbe",
    "krutgubben": "krutgubbe",
    "krutgubbens": "krutgubbe",
    "krutgubbes": "krutgubbe",
    "krutgubbs": "krutgubbe",
    "kruthornen": "kruthorn",
    "kruthornens": "kruthorn",
    "kruthornet": "kruthorn",
    "kruthornets": "kruthorn",
    "kruthorns": "kruthorn",
    "krutkornen": "krutkorn",
    "krutkornens": "krutkorn",
    "krutkornet": "krutkorn",
    "krutkornets": "krutkorn",
    "krutkorns": "krutkorn",
    "krutmotorer": "krutmotor",
    "krutmotorerna": "krutmotor",
    "krutmotorernas": "krutmotor",
    "krutmotorers": "krutmotor",
    "krutmotorn": "krutmotor",
    "krutmotorns": "krutmotor",
    "krutmotors": "krutmotor",
    "krutongen": "krutong",
    "krutongens": "krutong",
    "krutonger": "krutong",
    "krutongerna": "krutong",
    "krutongernas": "krutong",
    "krutongers": "krutong",
    "krutongs": "krutong",
    "krutröken": "krutrök",
    "krutrökens": "krutrök",
    "krutröks": "krutrök",
    "kruts": "krut",
    "krutsorten": "krutsort",
    "krutsortens": "krutsort",
    "krutsorter": "krutsort",
    "krutsorterna": "krutsort",
    "krutsorternas": "krutsort",
    "krutsorters": "krutsort",
    "krutsorts": "krutsort",
    "krutsvärtade": "krutsvärtad",
    "krutsvärtades": "krutsvärtad",
    "krutsvärtads": "krutsvärtad",
    "krutsvärtat": "krutsvärtad",
    "krutsvärtats": "krutsvärtad",
    "kruttorra": "kruttorr",
    "kruttorrare": "kruttorr",
    "kruttorrares": "kruttorr",
    "kruttorras": "kruttorr",
    "kruttorrast": "kruttorr",
    "kruttorraste": "kruttorr",
    "kruttorrastes": "kruttorr",
    "kruttorrasts": "kruttorr",
    "kruttorre": "kruttorr",
    "kruttorres": "kruttorr",
    "kruttorrheten": "kruttorrhet",
    "kruttorrhetens": "kruttorrhet",
    "kruttorrhets": "kruttorrhet",
    "kruttorrs": "kruttorr",
    "kruttorrt": "kruttorr",
    "kruttorrts": "kruttorr",
    "kruxen": "krux",
    "kruxens": "krux",
    "kruxet": "krux",
    "kruxets": "krux",
    "krya": "kry",
    "kryare": "kry",
    "kryares": "kry",
    "kryas": "kry",
    "kryast": "kry",
    "kryaste": "kry",
    "kryastes": "kry",
    "kryasts": "kry",
    "kryck": "krycka",
    "kryckan": "krycka",
    "kryckans": "krycka",
    "kryckas": "krycka",
    "krycke": "krycka",
    "kryckeståten": "kryckeståt",
    "kryckeståtens": "kryckeståt",
    "kryckeståts": "kryckeståt",
    "kryckiga": "kryckig",
    "kryckigare": "kryckig",
    "kryckigares": "kryckig",
    "kryckigas": "kryckig",
    "kryckigast": "kryckig",
    "kryckigaste": "kryckig",
    "kryckigastes": "kryckig",
    "kryckigasts": "kryckig",
    "kryckige": "kryckig",
    "kryckiges": "kryckig",
    "kryckigheten": "kryckighet",
    "kryckighetens": "kryckighet",
    "kryckighets": "kryckighet",
    "kryckigs": "kryckig",
    "kryckigt": "kryckig",
    "kryckigts": "kryckig",
    "kryckor": "krycka",
    "kryckorna": "krycka",
    "kryckornas": "krycka",
    "kryckors": "krycka",
    "krycks": "krycka",
    "krydd": "krydda",
    "kryddad": "krydda",
    "kryddade": "krydda",
    "kryddades": "krydda",
    "kryddads": "krydda",
    "kryddan": "krydda",
    "kryddande": "krydda",
    "kryddanden": "kryddande",
    "kryddandena": "kryddande",
    "kryddandenas": "kryddande",
    "kryddandens": "kryddande",
    "kryddandes": "kryddande",
    "kryddandet": "kryddande",
    "kryddandets": "kryddande",
    "kryddans": "krydda",
    "kryddar": "krydda",
    "kryddas": "krydda",
    "kryddat": "krydda",
    "kryddats": "krydda",
    "kryddbodar": "kryddbod",
    "kryddbodarna": "kryddbod",
    "kryddbodarnas": "kryddbod",
    "kryddbodars": "kryddbod",
    "kryddboden": "kryddbod",
    "kryddbodens": "kryddbod",
    "kryddbods": "kryddbod",
    "kryddbruna": "kryddbrun",
    "kryddbrunare": "kryddbrun",
    "kryddbrunares": "kryddbrun",
    "kryddbrunas": "kryddbrun",
    "kryddbrunast": "kryddbrun",
    "kryddbrunaste": "kryddbrun",
    "kryddbrunastes": "kryddbrun",
    "kryddbrunasts": "kryddbrun",
    "kryddbrune": "kryddbrun",
    "kryddbrunes": "kryddbrun",
    "kryddbruns": "kryddbrun",
    "kryddbrunt": "kryddbrun",
    "kryddbrunts": "kryddbrun",
    "krydde": "krydda",
    "kryddgrönsaken": "kryddgrönsak",
    "kryddgrönsakens": "kryddgrönsak",
    "kryddgrönsaker": "kryddgrönsak",
    "kryddgrönsakerna": "kryddgrönsak",
    "kryddgrönsakernas": "kryddgrönsak",
    "kryddgrönsakers": "kryddgrönsak",
    "kryddgrönsaks": "kryddgrönsak",
    "kryddgrönts": "kryddgrönt",
    "kryddiga": "kryddig",
    "kryddigare": "kryddig",
    "kryddigares": "kryddig",
    "kryddigas": "kryddig",
    "kryddigast": "kryddig",
    "kryddigaste": "kryddig",
    "kryddigastes": "kryddig",
    "kryddigasts": "kryddig",
    "kryddige": "kryddig",
    "kryddiges": "kryddig",
    "kryddigs": "kryddig",
    "kryddigt": "kryddig",
    "kryddigts": "kryddig",
    "kryddkrassen": "kryddkrasse",
    "kryddkrassens": "kryddkrasse",
    "kryddkrasses": "kryddkrasse",
    "kryddnejlik": "kryddnejlika",
    "kryddnejlikan": "kryddnejlika",
    "kryddnejlikans": "kryddnejlika",
    "kryddnejlikas": "kryddnejlika",
    "kryddnejlike": "kryddnejlika",
    "kryddnejlikor": "kryddnejlika",
    "kryddnejlikorna": "kryddnejlika",
    "kryddnejlikornas": "kryddnejlika",
    "kryddnejlikors": "kryddnejlika",
    "kryddnejliks": "kryddnejlika",
    "kryddor": "krydda",
    "kryddorna": "krydda",
    "kryddornas": "krydda",
    "kryddors": "krydda",
    "kryddpepparn": "kryddpeppar",
    "kryddpepparns": "kryddpeppar",
    "kryddpeppars": "kryddpeppar",
    "krydds": "krydda",
    "kryddsaltet": "kryddsalt",
    "kryddsaltets": "kryddsalt",
    "kryddsalts": "kryddsalt",
    "kryddstarka": "kryddstark",
    "kryddstarkare": "kryddstark",
    "kryddstarkares": "kryddstark",
    "kryddstarkas": "kryddstark",
    "kryddstarkast": "kryddstark",
    "kryddstarkaste": "kryddstark",
    "kryddstarkastes": "kryddstark",
    "kryddstarkasts": "kryddstark",
    "kryddstarke": "kryddstark",
    "kryddstarkes": "kryddstark",
    "kryddstarks": "kryddstark",
    "kryddstarkt": "kryddstark",
    "kryddstarkts": "kryddstark",
    "kryddsåsen": "kryddsås",
    "kryddsåsens": "kryddsås",
    "kryddsåser": "kryddsås",
    "kryddsåserna": "kryddsås",
    "kryddsåsernas": "kryddsås",
    "kryddsåsers": "kryddsås",
    "kryddväxten": "kryddväxt",
    "kryddväxtens": "kryddväxt",
    "kryddväxter": "kryddväxt",
    "kryddväxterna": "kryddväxt",
    "kryddväxternas": "kryddväxt",
    "kryddväxters": "kryddväxt",
    "kryddväxts": "kryddväxt",
    "kryddörten": "kryddört",
    "kryddörtens": "kryddört",
    "kryddörter": "kryddört",
    "kryddörterna": "kryddört",
    "kryddörternas": "kryddört",
    "kryddörters": "kryddört",
    "kryddörts": "kryddört",
    "krye": "kry",
    "kryes": "kry",
    "kryll": "krylla",
    "kryllade": "krylla",
    "kryllades": "krylla",
    "kryllande": "krylla",
    "kryllanden": "kryllande",
    "kryllandena": "kryllande",
    "kryllandenas": "kryllande",
    "kryllandens": "kryllande",
    "kryllandes": "kryllande",
    "kryllandet": "kryllande",
    "kryllandets": "kryllande",
    "kryllar": "krylla",
    "kryllas": "krylla",
    "kryllat": "krylla",
    "kryllats": "krylla",
    "krymp": "krympa",
    "krympande": "krympa",
    "krympanden": "krympande",
    "krympandena": "krympande",
    "krympandenas": "krympande",
    "krympandens": "krympande",
    "krympandes": "krympande",
    "krympandet": "krympande",
    "krympandets": "krympande",
    "krympas": "krympa",
    "krympbehandlade": "krympbehandlad",
    "krympbehandlades": "krympbehandlad",
    "krympbehandlads": "krympbehandlad",
    "krympbehandlat": "krympbehandlad",
    "krympbehandlats": "krympbehandlad",
    "krymper": "krympa",
    "krympes": "krympa",
    "krympfilmen": "krympfilm",
    "krympfilmens": "krympfilm",
    "krympfilmer": "krympfilm",
    "krympfilmerna": "krympfilm",
    "krympfilmernas": "krympfilm",
    "krympfilmers": "krympfilm",
    "krympfilms": "krympfilm",
    "krympfria": "krympfri",
    "krympfriare": "krympfri",
    "krympfriares": "krympfri",
    "krympfrias": "krympfri",
    "krympfriast": "krympfri",
    "krympfriaste": "krympfri",
    "krympfriastes": "krympfri",
    "krympfriasts": "krympfri",
    "krympfrie": "krympfri",
    "krympfries": "krympfri",
    "krympfris": "krympfri",
    "krympfritt": "krympfri",
    "krympfritts": "krympfri",
    "krymplingar": "krympling",
    "krymplingarna": "krympling",
    "krymplingarnas": "krympling",
    "krymplingars": "krympling",
    "krymplingen": "krympling",
    "krymplingens": "krympling",
    "krymplings": "krympling",
    "krympmånen": "krympmån",
    "krympmånens": "krympmån",
    "krympmåner": "krympmån",
    "krympmånerna": "krympmån",
    "krympmånernas": "krympmån",
    "krympmåners": "krympmån",
    "krympmåns": "krympmån",
    "krymps": "krympa",
    "krympt": "krympa",
    "krympta": "krympa",
    "krymptas": "krympa",
    "krympte": "krympa",
    "krymptes": "krympa",
    "krympts": "krympa",
    "kryogena": "kryogen",
    "kryogenare": "kryogen",
    "kryogenares": "kryogen",
    "kryogenas": "kryogen",
    "kryogenast": "kryogen",
    "kryogenaste": "kryogen",
    "kryogenastes": "kryogen",
    "kryogenasts": "kryogen",
    "kryogene": "kryogen",
    "kryogenes": "kryogen",
    "kryogens": "kryogen",
    "kryogent": "kryogen",
    "kryogents": "kryogen",
    "kryoliten": "kryolit",
    "kryolitens": "kryolit",
    "kryolits": "kryolit",
    "kryostaten": "kryostat",
    "kryostatens": "kryostat",
    "kryostater": "kryostat",
    "kryostaterna": "kryostat",
    "kryostaternas": "kryostat",
    "kryostaters": "kryostat",
    "kryostats": "kryostat",
    "kryotekniken": "kryoteknik",
    "kryoteknikens": "kryoteknik",
    "kryotekniker": "kryoteknik",
    "kryoteknikerna": "kryoteknik",
    "kryoteknikernas": "kryoteknik",
    "kryoteknikers": "kryoteknik",
    "kryotekniks": "kryoteknik",
    "kryp": "krypa",
    "krypande": "krypa",
    "krypanden": "krypande",
    "krypandena": "krypande",
    "krypandenas": "krypande",
    "krypandens": "krypande",
    "krypandes": "krypande",
    "krypandet": "krypande",
    "krypandets": "krypande",
    "krypas": "krypa",
    "krype": "krypa",
    "krypen": "kryp",
    "krypens": "kryp",
    "kryper": "krypa",
    "kryperier": "kryperi",
    "kryperierna": "kryperi",
    "kryperiernas": "kryperi",
    "kryperiers": "kryperi",
    "kryperiet": "kryperi",
    "kryperiets": "kryperi",
    "kryperis": "kryperi",
    "kryperit": "kryperi",
    "kryperits": "kryperi",
    "krypes": "krypa",
    "krypet": "kryp",
    "krypets": "kryp",
    "krypfilen": "krypfil",
    "krypfilens": "krypfil",
    "krypfiler": "krypfil",
    "krypfilerna": "krypfil",
    "krypfilernas": "krypfil",
    "krypfilers": "krypfil",
    "krypfils": "krypfil",
    "kryphålen": "kryphål",
    "kryphålens": "kryphål",
    "kryphålet": "kryphål",
    "kryphålets": "kryphål",
    "kryphållfastheten": "kryphållfasthet",
    "kryphållfasthetens": "kryphållfasthet",
    "kryphållfastheter": "kryphållfasthet",
    "kryphållfastheterna": "kryphållfasthet",
    "kryphållfastheternas": "kryphållfasthet",
    "kryphållfastheters": "kryphållfasthet",
    "kryphållfasthets": "kryphållfasthet",
    "kryphåls": "kryphål",
    "krypinen": "krypin",
    "krypinens": "krypin",
    "krypinet": "krypin",
    "krypinets": "krypin",
    "krypins": "krypin",
    "krypkör": "krypköra",
    "krypkörande": "krypköra",
    "krypköranden": "krypkörande",
    "krypkörandena": "krypkörande",
    "krypkörandenas": "krypkörande",
    "krypkörandens": "krypkörande",
    "krypkörandes": "krypkörande",
    "krypkörandet": "krypkörande",
    "krypkörandets": "krypkörande",
    "krypköras": "krypköra",
    "krypkörd": "krypköra",
    "krypkörda": "krypköra",
    "krypkördas": "krypköra",
    "krypkörde": "krypköra",
    "krypkördes": "krypköra",
    "krypkörds": "krypköra",
    "krypköres": "krypköra",
    "krypkörs": "krypköra",
    "krypkört": "krypköra",
    "krypkörts": "krypköra",
    "kryps": "krypa",
    "krypskyttar": "krypskytt",
    "krypskyttarna": "krypskytt",
    "krypskyttarnas": "krypskytt",
    "krypskyttars": "krypskytt",
    "krypskytten": "krypskytt",
    "krypskyttens": "krypskytt",
    "krypskyttes": "krypskytte",
    "krypskyttet": "krypskytte",
    "krypskyttets": "krypskytte",
    "krypskytts": "krypskytt",
    "krypt": "krypta",
    "kryptan": "krypta",
    "kryptans": "krypta",
    "kryptas": "krypta",
    "krypte": "krypta",
    "krypterad": "kryptera",
    "krypterade": "kryptera",
    "krypterades": "kryptera",
    "krypterads": "kryptera",
    "krypterande": "kryptera",
    "krypteranden": "krypterande",
    "krypterandena": "krypterande",
    "krypterandenas": "krypterande",
    "krypterandens": "krypterande",
    "krypterandes": "krypterande",
    "krypterandet": "krypterande",
    "krypterandets": "krypterande",
    "krypterar": "kryptera",
    "krypteras": "kryptera",
    "krypterat": "kryptera",
    "krypterats": "kryptera",
    "krypterbara": "krypterbar",
    "krypterbarare": "krypterbar",
    "krypterbarares": "krypterbar",
    "krypterbaras": "krypterbar",
    "krypterbarast": "krypterbar",
    "krypterbaraste": "krypterbar",
    "krypterbarastes": "krypterbar",
    "krypterbarasts": "krypterbar",
    "krypterbare": "krypterbar",
    "krypterbares": "krypterbar",
    "krypterbarheten": "krypterbarhet",
    "krypterbarhetens": "krypterbarhet",
    "krypterbarhets": "krypterbarhet",
    "krypterbars": "krypterbar",
    "krypterbart": "krypterbar",
    "krypterbarts": "krypterbar",
    "krypteringar": "kryptering",
    "krypteringarna": "kryptering",
    "krypteringarnas": "kryptering",
    "krypteringars": "kryptering",
    "krypteringen": "kryptering",
    "krypteringens": "kryptering",
    "krypterings": "kryptering",
    "kryptiska": "kryptisk",
    "kryptiskare": "kryptisk",
    "kryptiskares": "kryptisk",
    "kryptiskas": "kryptisk",
    "kryptiskast": "kryptisk",
    "kryptiskaste": "kryptisk",
    "kryptiskastes": "kryptisk",
    "kryptiskasts": "kryptisk",
    "kryptiske": "kryptisk",
    "kryptiskes": "kryptisk",
    "kryptisks": "kryptisk",
    "kryptiskt": "kryptisk",
    "kryptiskts": "kryptisk",
    "kryptofascisten": "kryptofascist",
    "kryptofascistens": "kryptofascist",
    "kryptofascister": "kryptofascist",
    "kryptofascisterna": "kryptofascist",
    "kryptofascisternas": "kryptofascist",
    "kryptofascisters": "kryptofascist",
    "kryptofascists": "kryptofascist",
    "kryptogama": "kryptogam",
    "kryptogamare": "kryptogam",
    "kryptogamares": "kryptogam",
    "kryptogamas": "kryptogam",
    "kryptogamast": "kryptogam",
    "kryptogamaste": "kryptogam",
    "kryptogamastes": "kryptogam",
    "kryptogamasts": "kryptogam",
    "kryptogame": "kryptogam",
    "kryptogamen": "kryptogam",
    "kryptogamens": "kryptogam",
    "kryptogamer": "kryptogam",
    "kryptogamerna": "kryptogam",
    "kryptogamernas": "kryptogam",
    "kryptogamers": "kryptogam",
    "kryptogames": "kryptogam",
    "kryptogams": "kryptogam",
    "kryptogamt": "kryptogam",
    "kryptogamts": "kryptogam",
    "krypton": "krypto",
    "kryptona": "krypto",
    "kryptonas": "krypto",
    "kryptonazisten": "kryptonazist",
    "kryptonazistens": "kryptonazist",
    "kryptonazister": "kryptonazist",
    "kryptonazisterna": "kryptonazist",
    "kryptonazisternas": "kryptonazist",
    "kryptonazisters": "kryptonazist",
    "kryptonazists": "kryptonazist",
    "kryptonen": "krypton",
    "kryptonens": "krypton",
    "kryptonet": "krypton",
    "kryptonets": "krypton",
    "kryptons": "krypton",
    "kryptor": "krypta",
    "kryptorna": "krypta",
    "kryptornas": "krypta",
    "kryptors": "krypta",
    "kryptos": "krypto",
    "kryptot": "krypto",
    "kryptots": "krypto",
    "krypts": "krypta",
    "krys": "kry",
    "krysantemen": "krysantem",
    "krysantemens": "krysantem",
    "krysantemer": "krysantem",
    "krysantemerna": "krysantem",
    "krysantemernas": "krysantem",
    "krysantemers": "krysantem",
    "krysantems": "krysantem",
    "krysantemumar": "krysantemum",
    "krysantemumarna": "krysantemum",
    "krysantemumarnas": "krysantemum",
    "krysantemumars": "krysantemum",
    "krysantemumen": "krysantemum",
    "krysantemumens": "krysantemum",
    "krysantemumplant": "krysantemumplanta",
    "krysantemumplantan": "krysantemumplanta",
    "krysantemumplantans": "krysantemumplanta",
    "krysantemumplantas": "krysantemumplanta",
    "krysantemumplante": "krysantemumplanta",
    "krysantemumplantor": "krysantemumplanta",
    "krysantemumplantorna": "krysantemumplanta",
    "krysantemumplantornas": "krysantemumplanta",
    "krysantemumplantors": "krysantemumplanta",
    "krysantemumplants": "krysantemumplanta",
    "krysantemums": "krysantemum",
    "krysoliten": "krysolit",
    "krysolitens": "krysolit",
    "krysoliter": "krysolit",
    "krysoliterna": "krysolit",
    "krysoliternas": "krysolit",
    "krysoliters": "krysolit",
    "krysolits": "krysolit",
    "krysoprasen": "krysopras",
    "krysoprasens": "krysopras",
    "krysopraser": "krysopras",
    "krysopraserna": "krysopras",
    "krysoprasernas": "krysopras",
    "krysoprasers": "krysopras",
    "kryss": "kryssa",
    "kryssad": "kryssa",
    "kryssade": "kryssa",
    "kryssades": "kryssa",
    "kryssads": "kryssa",
    "kryssande": "kryssa",
    "kryssanden": "kryssande",
    "kryssandena": "kryssande",
    "kryssandenas": "kryssande",
    "kryssandens": "kryssande",
    "kryssandes": "kryssande",
    "kryssandet": "kryssande",
    "kryssandets": "kryssande",
    "kryssar": "kryssare",
    "kryssaren": "kryssare",
    "kryssarens": "kryssare",
    "kryssares": "kryssare",
    "kryssarna": "kryssare",
    "kryssarnas": "kryssare",
    "kryssas": "kryssa",
    "kryssat": "kryssa",
    "kryssats": "kryssa",
    "kryssen": "kryss",
    "kryssens": "kryss",
    "krysset": "kryss",
    "kryssets": "kryss",
    "kryssfaneret": "kryssfaner",
    "kryssfanerets": "kryssfaner",
    "kryssfaners": "kryssfaner",
    "kryssförbanden": "kryssförband",
    "kryssförbandens": "kryssförband",
    "kryssförbandet": "kryssförband",
    "kryssförbandets": "kryssförband",
    "kryssförbands": "kryssförband",
    "krysshultar": "krysshult",
    "krysshultarna": "krysshult",
    "krysshultarnas": "krysshult",
    "krysshultars": "krysshult",
    "krysshulten": "krysshult",
    "krysshultens": "krysshult",
    "krysshulter": "krysshult",
    "krysshulterna": "krysshult",
    "krysshulternas": "krysshult",
    "krysshulters": "krysshult",
    "krysshultet": "krysshult",
    "krysshultets": "krysshult",
    "krysshults": "krysshult",
    "kryssmasten": "kryssmast",
    "kryssmastens": "kryssmast",
    "kryssmaster": "kryssmast",
    "kryssmasterna": "kryssmast",
    "kryssmasternas": "kryssmast",
    "kryssmasters": "kryssmast",
    "kryssmasts": "kryssmast",
    "kryssmejseln": "kryssmejsel",
    "kryssmejselns": "kryssmejsel",
    "kryssmejsels": "kryssmejsel",
    "kryssmejslar": "kryssmejsel",
    "kryssmejslarna": "kryssmejsel",
    "kryssmejslarnas": "kryssmejsel",
    "kryssmejslars": "kryssmejsel",
    "kryssmässiga": "kryssmässig",
    "kryssmässigare": "kryssmässig",
    "kryssmässigares": "kryssmässig",
    "kryssmässigas": "kryssmässig",
    "kryssmässigast": "kryssmässig",
    "kryssmässigaste": "kryssmässig",
    "kryssmässigastes": "kryssmässig",
    "kryssmässigasts": "kryssmässig",
    "kryssmässige": "kryssmässig",
    "kryssmässiges": "kryssmässig",
    "kryssmässigs": "kryssmässig",
    "kryssmässigt": "kryssmässig",
    "kryssmässigts": "kryssmässig",
    "kryssningar": "kryssning",
    "kryssningarna": "kryssning",
    "kryssningarnas": "kryssning",
    "kryssningars": "kryssning",
    "kryssningen": "kryssning",
    "kryssningens": "kryssning",
    "kryssnings": "kryssning",
    "kryssningsfartygen": "kryssningsfartyg",
    "kryssningsfartygens": "kryssningsfartyg",
    "kryssningsfartyget": "kryssningsfartyg",
    "kryssningsfartygets": "kryssningsfartyg",
    "kryssningsfartygs": "kryssningsfartyg",
    "kryssningsmissilen": "kryssningsmissil",
    "kryssningsmissilens": "kryssningsmissil",
    "kryssningsmissiler": "kryssningsmissil",
    "kryssningsmissilerna": "kryssningsmissil",
    "kryssningsmissilernas": "kryssningsmissil",
    "kryssningsmissilers": "kryssningsmissil",
    "kryssningsmissils": "kryssningsmissil",
    "kryssningsraketen": "kryssningsraket",
    "kryssningsraketens": "kryssningsraket",
    "kryssningsraketer": "kryssningsraket",
    "kryssningsraketerna": "kryssningsraket",
    "kryssningsraketernas": "kryssningsraket",
    "kryssningsraketers": "kryssningsraket",
    "kryssningsrakets": "kryssningsraket",
    "kryssningsrobotar": "kryssningsrobot",
    "kryssningsrobotarna": "kryssningsrobot",
    "kryssningsrobotarnas": "kryssningsrobot",
    "kryssningsrobotars": "kryssningsrobot",
    "kryssningsroboten": "kryssningsrobot",
    "kryssningsrobotens": "kryssningsrobot",
    "kryssningsrobots": "kryssningsrobot",
    "kryssrösten": "kryssröst",
    "kryssröstens": "kryssröst",
    "kryssröster": "kryssröst",
    "kryssrösterna": "kryssröst",
    "kryssrösternas": "kryssröst",
    "kryssrösters": "kryssröst",
    "kryssröstningar": "kryssröstning",
    "kryssröstningarna": "kryssröstning",
    "kryssröstningarnas": "kryssröstning",
    "kryssröstningars": "kryssröstning",
    "kryssröstningen": "kryssröstning",
    "kryssröstningens": "kryssröstning",
    "kryssröstnings": "kryssröstning",
    "kryssrösts": "kryssröst",
    "krysstagen": "krysstag",
    "krysstagens": "krysstag",
    "krysstaget": "krysstag",
    "krysstagets": "krysstag",
    "krysstags": "krysstag",
    "kryssvalven": "kryssvalv",
    "kryssvalvens": "kryssvalv",
    "kryssvalvet": "kryssvalv",
    "kryssvalvets": "kryssvalv",
    "kryssvalvs": "kryssvalv",
    "kryst": "krysta",
    "krystade": "krystad",
    "krystades": "krystad",
    "krystads": "krystad",
    "krystande": "krysta",
    "krystanden": "krystande",
    "krystandena": "krystande",
    "krystandenas": "krystande",
    "krystandens": "krystande",
    "krystandes": "krystande",
    "krystandet": "krystande",
    "krystandets": "krystande",
    "krystar": "krysta",
    "krystas": "krysta",
    "krystat": "krystad",
    "krystats": "krystad",
    "krystvärkar": "krystvärk",
    "krystvärkarna": "krystvärk",
    "krystvärkarnas": "krystvärk",
    "krystvärkars": "krystvärk",
    "krystvärken": "krystvärk",
    "krystvärkens": "krystvärk",
    "krystvärks": "krystvärk",
    "krytt": "kry",
    "krytts": "kry",
    "kräcklan": "kräckla",
    "kräcklans": "kräckla",
    "kräcklas": "kräckla",
    "kräckle": "kräckla",
    "kräcklor": "kräckla",
    "kräcklorna": "kräckla",
    "kräcklornas": "kräckla",
    "kräcklors": "kräckla",
    "kräft": "kräfta",
    "kräftan": "kräfta",
    "kräftans": "kräfta",
    "kräftas": "kräfta",
    "kräftburar": "kräftbur",
    "kräftburarna": "kräftbur",
    "kräftburarnas": "kräftbur",
    "kräftburars": "kräftbur",
    "kräftburen": "kräftbur",
    "kräftburens": "kräftbur",
    "kräftburs": "kräftbur",
    "kräftdjuren": "kräftdjur",
    "kräftdjurens": "kräftdjur",
    "kräftdjuret": "kräftdjur",
    "kräftdjurets": "kräftdjur",
    "kräftdjurs": "kräftdjur",
    "kräfte": "kräfta",
    "kräftfångsten": "kräftfångst",
    "kräftfångstens": "kräftfångst",
    "kräftfångster": "kräftfångst",
    "kräftfångsterna": "kräftfångst",
    "kräftfångsternas": "kräftfångst",
    "kräftfångsters": "kräftfångst",
    "kräftfångsts": "kräftfångst",
    "kräftgången": "kräftgång",
    "kräftgångens": "kräftgång",
    "kräftgångs": "kräftgång",
    "kräftor": "kräfta",
    "kräftorna": "kräfta",
    "kräftornas": "kräfta",
    "kräftors": "kräfta",
    "kräftpesten": "kräftpest",
    "kräftpestens": "kräftpest",
    "kräftpests": "kräftpest",
    "kräftpremiären": "kräftpremiär",
    "kräftpremiärens": "kräftpremiär",
    "kräftpremiärer": "kräftpremiär",
    "kräftpremiärerna": "kräftpremiär",
    "kräftpremiärernas": "kräftpremiär",
    "kräftpremiärers": "kräftpremiär",
    "kräftpremiärs": "kräftpremiär",
    "kräfts": "kräfta",
    "kräftskivan": "kräftskiva",
    "kräftskivans": "kräftskiva",
    "kräftskivas": "kräftskiva",
    "kräftskive": "kräftskiva",
    "kräftskivor": "kräftskiva",
    "kräftskivorna": "kräftskiva",
    "kräftskivornas": "kräftskiva",
    "kräftskivors": "kräftskiva",
    "kräftsmöret": "kräftsmör",
    "kräftsmörets": "kräftsmör",
    "kräftsmörs": "kräftsmör",
    "kräftsvulsten": "kräftsvulst",
    "kräftsvulstens": "kräftsvulst",
    "kräftsvulster": "kräftsvulst",
    "kräftsvulsterna": "kräftsvulst",
    "kräftsvulsternas": "kräftsvulst",
    "kräftsvulsters": "kräftsvulst",
    "kräftsvulsts": "kräftsvulst",
    "kräftsäsongen": "kräftsäsong",
    "kräftsäsongens": "kräftsäsong",
    "kräftsäsonger": "kräftsäsong",
    "kräftsäsongerna": "kräftsäsong",
    "kräftsäsongernas": "kräftsäsong",
    "kräftsäsongers": "kräftsäsong",
    "kräftsäsongs": "kräftsäsong",
    "kräken": "kräk",
    "kräkens": "kräk",
    "kräket": "kräk",
    "kräkets": "kräk",
    "kräkfärdiga": "kräkfärdig",
    "kräkfärdigare": "kräkfärdig",
    "kräkfärdigares": "kräkfärdig",
    "kräkfärdigas": "kräkfärdig",
    "kräkfärdigast": "kräkfärdig",
    "kräkfärdigaste": "kräkfärdig",
    "kräkfärdigastes": "kräkfärdig",
    "kräkfärdigasts": "kräkfärdig",
    "kräkfärdige": "kräkfärdig",
    "kräkfärdiges": "kräkfärdig",
    "kräkfärdigheten": "kräkfärdighet",
    "kräkfärdighetens": "kräkfärdighet",
    "kräkfärdighets": "kräkfärdighet",
    "kräkfärdigs": "kräkfärdig",
    "kräkfärdigt": "kräkfärdig",
    "kräkfärdigts": "kräkfärdig",
    "kräklan": "kräkla",
    "kräklans": "kräkla",
    "kräklas": "kräkla",
    "kräklatjuvar": "kräklatjuv",
    "kräklatjuvarna": "kräklatjuv",
    "kräklatjuvarnas": "kräklatjuv",
    "kräklatjuvars": "kräklatjuv",
    "kräklatjuven": "kräklatjuv",
    "kräklatjuvens": "kräklatjuv",
    "kräklatjuvs": "kräklatjuv",
    "kräkle": "kräkla",
    "kräklor": "kräkla",
    "kräklorna": "kräkla",
    "kräklornas": "kräkla",
    "kräklors": "kräkla",
    "kräkmedels": "kräkmedel",
    "kräkmedlen": "kräkmedel",
    "kräkmedlens": "kräkmedel",
    "kräkmedlet": "kräkmedel",
    "kräkmedlets": "kräkmedel",
    "kräkningar": "kräkning",
    "kräkningarna": "kräkning",
    "kräkningarnas": "kräkning",
    "kräkningars": "kräkning",
    "kräkningen": "kräkning",
    "kräkningens": "kräkning",
    "kräknings": "kräkning",
    "kräks": "kräk",
    "kräkset": "kräks",
    "kräksets": "kräks",
    "kräktes": "kräkas",
    "kräkts": "kräkas",
    "kräl": "kräla",
    "krälade": "kräla",
    "krälades": "kräla",
    "krälande": "kräla",
    "krälanden": "krälande",
    "krälandena": "krälande",
    "krälandenas": "krälande",
    "krälandens": "krälande",
    "krälandes": "krälande",
    "krälandet": "krälande",
    "krälandets": "krälande",
    "krälar": "kräla",
    "krälas": "kräla",
    "krälat": "kräla",
    "krälats": "kräla",
    "kräldjuren": "kräldjur",
    "kräldjurens": "kräldjur",
    "kräldjuret": "kräldjur",
    "kräldjurets": "kräldjur",
    "kräldjurs": "kräldjur",
    "kräldjurstypen": "kräldjurstyp",
    "kräldjurstypens": "kräldjurstyp",
    "kräldjurstyper": "kräldjurstyp",
    "kräldjurstyperna": "kräldjurstyp",
    "kräldjurstypernas": "kräldjurstyp",
    "kräldjurstypers": "kräldjurstyp",
    "kräldjurstyps": "kräldjurstyp",
    "krämar": "krämare",
    "krämaren": "krämare",
    "krämarens": "krämare",
    "krämares": "krämare",
    "krämarna": "krämare",
    "krämarnas": "krämare",
    "krämen": "kräm",
    "krämens": "kräm",
    "krämer": "kräm",
    "krämerna": "kräm",
    "krämernas": "kräm",
    "krämers": "kräm",
    "krämfärgade": "krämfärgad",
    "krämfärgades": "krämfärgad",
    "krämfärgads": "krämfärgad",
    "krämfärgat": "krämfärgad",
    "krämfärgats": "krämfärgad",
    "krämiga": "krämig",
    "krämigare": "krämig",
    "krämigares": "krämig",
    "krämigas": "krämig",
    "krämigast": "krämig",
    "krämigaste": "krämig",
    "krämigastes": "krämig",
    "krämigasts": "krämig",
    "krämige": "krämig",
    "krämiges": "krämig",
    "krämigs": "krämig",
    "krämigt": "krämig",
    "krämigts": "krämig",
    "kräml": "krämla",
    "krämlan": "krämla",
    "krämlans": "krämla",
    "krämlas": "krämla",
    "krämle": "krämla",
    "krämlor": "krämla",
    "krämlorna": "krämla",
    "krämlornas": "krämla",
    "krämlors": "krämla",
    "krämls": "krämla",
    "krämp": "krämpa",
    "krämpan": "krämpa",
    "krämpans": "krämpa",
    "krämpas": "krämpa",
    "krämpe": "krämpa",
    "krämpor": "krämpa",
    "krämporna": "krämpa",
    "krämpornas": "krämpa",
    "krämpors": "krämpa",
    "krämps": "krämpa",
    "kräms": "kräm",
    "krämt": "krämta",
    "krämtade": "krämta",
    "krämtades": "krämta",
    "krämtande": "krämta",
    "krämtanden": "krämtande",
    "krämtandena": "krämtande",
    "krämtandenas": "krämtande",
    "krämtandens": "krämtande",
    "krämtandes": "krämtande",
    "krämtandet": "krämtande",
    "krämtandets": "krämtande",
    "krämtar": "krämta",
    "krämtas": "krämta",
    "krämtat": "krämta",
    "krämtats": "krämta",
    "kräng": "kränga",
    "krängande": "kränga",
    "kränganden": "krängande",
    "krängandena": "krängande",
    "krängandenas": "krängande",
    "krängandens": "krängande",
    "krängandes": "krängande",
    "krängandet": "krängande",
    "krängandets": "krängande",
    "krängas": "kränga",
    "krängd": "kränga",
    "krängda": "kränga",
    "krängdas": "kränga",
    "krängde": "kränga",
    "krängdes": "kränga",
    "krängds": "kränga",
    "kränger": "kränga",
    "kränges": "kränga",
    "krängningar": "krängning",
    "krängningarna": "krängning",
    "krängningarnas": "krängning",
    "krängningars": "krängning",
    "krängningen": "krängning",
    "krängningens": "krängning",
    "krängnings": "krängning",
    "krängningshämmar": "krängningshämmare",
    "krängningshämmaren": "krängningshämmare",
    "krängningshämmarens": "krängningshämmare",
    "krängningshämmares": "krängningshämmare",
    "krängningshämmarna": "krängningshämmare",
    "krängningshämmarnas": "krängningshämmare",
    "krängningsproven": "krängningsprov",
    "krängningsprovens": "krängningsprov",
    "krängningsprovet": "krängningsprov",
    "krängningsprovets": "krängningsprov",
    "krängningsprovs": "krängningsprov",
    "krängs": "kränga",
    "krängt": "kränga",
    "krängts": "kränga",
    "kränk": "kränka",
    "kränkande": "kränka",
    "kränkanden": "kränkande",
    "kränkandena": "kränkande",
    "kränkandenas": "kränkande",
    "kränkandens": "kränkande",
    "kränkandes": "kränkande",
    "kränkandet": "kränkande",
    "kränkandets": "kränkande",
    "kränkas": "kränka",
    "kränker": "kränka",
    "kränkes": "kränka",
    "kränkningar": "kränkning",
    "kränkningarna": "kränkning",
    "kränkningarnas": "kränkning",
    "kränkningars": "kränkning",
    "kränkningen": "kränkning",
    "kränkningens": "kränkning",
    "kränknings": "kränkning",
    "kränks": "kränka",
    "kränkt": "kränka",
    "kränkta": "kränka",
    "kränktas": "kränka",
    "kränkte": "kränka",
    "kränktes": "kränka",
    "kränkts": "kränka",
    "kräpp": "kräppa",
    "kräppad": "kräppa",
    "kräppade": "kräppa",
    "kräppades": "kräppa",
    "kräppads": "kräppa",
    "kräppande": "kräppa",
    "kräppanden": "kräppande",
    "kräppandena": "kräppande",
    "kräppandenas": "kräppande",
    "kräppandens": "kräppande",
    "kräppandes": "kräppande",
    "kräppandet": "kräppande",
    "kräppandets": "kräppande",
    "kräppar": "kräppa",
    "kräppas": "kräppa",
    "kräppat": "kräppa",
    "kräppats": "kräppa",
    "kräppen": "kräpp",
    "kräppens": "kräpp",
    "kräppnylonen": "kräppnylon",
    "kräppnylonens": "kräppnylon",
    "kräppnylonet": "kräppnylon",
    "kräppnylonets": "kräppnylon",
    "kräppnylons": "kräppnylon",
    "kräpps": "kräpp",
    "kräsenheten": "kräsenhet",
    "kräsenhetens": "kräsenhet",
    "kräsenhets": "kräsenhet",
    "kräsens": "kräsen",
    "kräset": "kräsen",
    "kräsets": "kräsen",
    "kräsliga": "kräslig",
    "kräsligare": "kräslig",
    "kräsligares": "kräslig",
    "kräsligas": "kräslig",
    "kräsligast": "kräslig",
    "kräsligaste": "kräslig",
    "kräsligastes": "kräslig",
    "kräsligasts": "kräslig",
    "kräslige": "kräslig",
    "kräsliges": "kräslig",
    "kräsligheten": "kräslighet",
    "kräslighetens": "kräslighet",
    "kräslighets": "kräslighet",
    "kräsligs": "kräslig",
    "kräsligt": "kräslig",
    "kräsligts": "kräslig",
    "kräsmagade": "kräsmagad",
    "kräsmagades": "kräsmagad",
    "kräsmagads": "kräsmagad",
    "kräsmagat": "kräsmagad",
    "kräsmagats": "kräsmagad",
    "kräsna": "kräsen",
    "kräsnare": "kräsen",
    "kräsnares": "kräsen",
    "kräsnas": "kräsen",
    "kräsnast": "kräsen",
    "kräsnaste": "kräsen",
    "kräsnastes": "kräsen",
    "kräsnasts": "kräsen",
    "kräsne": "kräsen",
    "kräsnes": "kräsen",
    "kräv": "kräva",
    "krävan": "kräva",
    "krävande": "kräva",
    "krävanden": "krävande",
    "krävandena": "krävande",
    "krävandenas": "krävande",
    "krävandens": "krävande",
    "krävandes": "krävande",
    "krävandet": "krävande",
    "krävandets": "krävande",
    "krävans": "kräva",
    "krävas": "kräva",
    "krävd": "kräva",
    "krävda": "kräva",
    "krävdas": "kräva",
    "krävde": "kräva",
    "krävdes": "krävas",
    "krävds": "kräva",
    "kräve": "kräva",
    "kräver": "kräva",
    "kräves": "krävas",
    "krävor": "kräva",
    "krävorna": "kräva",
    "krävornas": "kräva",
    "krävors": "kräva",
    "krävs": "krävas",
    "krävt": "kräva",
    "krävts": "krävas",
    "kråk": "kråka",
    "kråkan": "kråka",
    "kråkans": "kråka",
    "kråkas": "kråka",
    "kråkbären": "kråkbär",
    "kråkbärens": "kråkbär",
    "kråkbäret": "kråkbär",
    "kråkbärets": "kråkbär",
    "kråkbärs": "kråkbär",
    "kråke": "kråka",
    "kråkfots": "kråkfötter",
    "kråkfågeln": "kråkfågel",
    "kråkfågelns": "kråkfågel",
    "kråkfågels": "kråkfågel",
    "kråkfåglar": "kråkfågel",
    "kråkfåglarna": "kråkfågel",
    "kråkfåglarnas": "kråkfågel",
    "kråkfåglars": "kråkfågel",
    "kråkfötterna": "kråkfötter",
    "kråkfötternas": "kråkfötter",
    "kråkfötters": "kråkfötter",
    "kråkor": "kråka",
    "kråkorna": "kråka",
    "kråkornas": "kråka",
    "kråkors": "kråka",
    "kråks": "kråka",
    "kråkslotten": "kråkslott",
    "kråkslottens": "kråkslott",
    "kråkslottet": "kråkslott",
    "kråkslottets": "kråkslott",
    "kråkslotts": "kråkslott",
    "kråksparken": "kråkspark",
    "kråksparkens": "kråkspark",
    "kråksparks": "kråkspark",
    "kråksyran": "kråksyra",
    "kråksyrans": "kråksyra",
    "kråksyras": "kråksyra",
    "kråksyre": "kråksyra",
    "kråksyror": "kråksyra",
    "kråksyrorna": "kråksyra",
    "kråksyrornas": "kråksyra",
    "kråksyrors": "kråksyra",
    "kråksången": "kråksång",
    "kråksångens": "kråksång",
    "kråksångs": "kråksång",
    "kråkvickern": "kråkvicker",
    "kråkvickerns": "kråkvicker",
    "kråkvickers": "kråkvicker",
    "kråkvinkeln": "kråkvinkel",
    "kråkvinkelns": "kråkvinkel",
    "kråkvinkels": "kråkvinkel",
    "kråm": "kråma",
    "kråmad": "kråma",
    "kråmade": "kråma",
    "kråmades": "kråma",
    "kråmads": "kråma",
    "kråmande": "kråma",
    "kråmanden": "kråmande",
    "kråmandena": "kråmande",
    "kråmandenas": "kråmande",
    "kråmandens": "kråmande",
    "kråmandes": "kråmande",
    "kråmandet": "kråmande",
    "kråmandets": "kråmande",
    "kråmar": "kråma",
    "kråmas": "kråma",
    "kråmat": "kråma",
    "kråmats": "kråma",
    "kråmningen": "kråmning",
    "kråmningens": "kråmning",
    "kråmnings": "kråmning",
    "krångel": "krångla",
    "krångelmakar": "krångelmakare",
    "krångelmakaren": "krångelmakare",
    "krångelmakarens": "krångelmakare",
    "krångelmakares": "krångelmakare",
    "krångelmakarna": "krångelmakare",
    "krångelmakarnas": "krångelmakare",
    "krångels": "krångel",
    "krånglade": "krångla",
    "krånglades": "krångla",
    "krånglande": "krångla",
    "krånglanden": "krånglande",
    "krånglandena": "krånglande",
    "krånglandenas": "krånglande",
    "krånglandens": "krånglande",
    "krånglandes": "krånglande",
    "krånglandet": "krånglande",
    "krånglandets": "krånglande",
    "krånglar": "krångla",
    "krånglas": "krångla",
    "krånglat": "krångla",
    "krånglats": "krångla",
    "krånglet": "krångel",
    "krånglets": "krångel",
    "krångliga": "krånglig",
    "krångligare": "krånglig",
    "krångligares": "krånglig",
    "krångligas": "krånglig",
    "krångligast": "krånglig",
    "krångligaste": "krånglig",
    "krångligastes": "krånglig",
    "krångligasts": "krånglig",
    "krånglige": "krånglig",
    "krångliges": "krånglig",
    "krångligheten": "krånglighet",
    "krånglighetens": "krånglighet",
    "krångligheter": "krånglighet",
    "krångligheterna": "krånglighet",
    "krångligheternas": "krånglighet",
    "krångligheters": "krånglighet",
    "krånglighets": "krånglighet",
    "krångligs": "krånglig",
    "krångligt": "krånglig",
    "krångligts": "krånglig",
    "kråsen": "krås",
    "kråsens": "krås",
    "kråset": "krås",
    "kråsets": "krås",
    "kråsnålar": "kråsnål",
    "kråsnålarna": "kråsnål",
    "kråsnålarnas": "kråsnål",
    "kråsnålars": "kråsnål",
    "kråsnålen": "kråsnål",
    "kråsnålens": "kråsnål",
    "kråsnåls": "kråsnål",
    "krögar": "krögare",
    "krögaren": "krögare",
    "krögarens": "krögare",
    "krögares": "krögare",
    "krögarna": "krögare",
    "krögarnas": "krögare",
    "krök": "kröka",
    "krökade": "kröka",
    "krökades": "kröka",
    "krökande": "kröka",
    "krökanden": "krökande",
    "krökandena": "krökande",
    "krökandenas": "krökande",
    "krökandens": "krökande",
    "krökandes": "krökande",
    "krökandet": "krökande",
    "krökandets": "krökande",
    "krökar": "kröka",
    "krökarna": "krök",
    "krökarnas": "krök",
    "krökars": "krök",
    "krökas": "kröka",
    "krökat": "kröka",
    "krökats": "kröka",
    "kröken": "krök",
    "krökens": "krök",
    "kröker": "kröka",
    "krökes": "kröka",
    "krökningar": "krökning",
    "krökningarna": "krökning",
    "krökningarnas": "krökning",
    "krökningars": "krökning",
    "krökningen": "krökning",
    "krökningens": "krökning",
    "kröknings": "krökning",
    "kröks": "kröka",
    "krökt": "kröka",
    "krökta": "krökt",
    "kröktare": "krökt",
    "kröktares": "krökt",
    "kröktas": "krökt",
    "kröktast": "krökt",
    "kröktaste": "krökt",
    "kröktastes": "krökt",
    "kröktasts": "krökt",
    "krökte": "krökt",
    "kröktes": "krökt",
    "kröktheten": "krökthet",
    "krökthetens": "krökthet",
    "krökthets": "krökthet",
    "krökts": "krökt",
    "krön": "kröna",
    "krönande": "kröna",
    "krönanden": "krönande",
    "krönandena": "krönande",
    "krönandenas": "krönande",
    "krönandens": "krönande",
    "krönandes": "krönande",
    "krönandet": "krönande",
    "krönandets": "krönande",
    "krönas": "kröna",
    "krönen": "krön",
    "krönens": "krön",
    "kröner": "kröna",
    "krönes": "kröna",
    "krönet": "krön",
    "krönets": "krön",
    "krönikan": "krönika",
    "krönikans": "krönika",
    "krönikas": "krönika",
    "krönike": "krönika",
    "krönikeboken": "krönikebok",
    "krönikebokens": "krönikebok",
    "krönikeboks": "krönikebok",
    "krönikeböcker": "krönikebok",
    "krönikeböckerna": "krönikebok",
    "krönikeböckernas": "krönikebok",
    "krönikeböckers": "krönikebok",
    "krönikespelen": "krönikespel",
    "krönikespelens": "krönikespel",
    "krönikespelet": "krönikespel",
    "krönikespelets": "krönikespel",
    "krönikespels": "krönikespel",
    "krönikor": "krönika",
    "krönikorna": "krönika",
    "krönikornas": "krönika",
    "krönikors": "krönika",
    "krönikören": "krönikör",
    "krönikörens": "krönikör",
    "krönikörer": "krönikör",
    "krönikörerna": "krönikör",
    "krönikörernas": "krönikör",
    "krönikörers": "krönikör",
    "krönikörs": "krönikör",
    "kröningar": "kröning",
    "kröningarna": "kröning",
    "kröningarnas": "kröning",
    "kröningars": "kröning",
    "kröningen": "kröning",
    "kröningens": "kröning",
    "krönings": "kröning",
    "kröns": "kröna",
    "krönt": "kröna",
    "krönta": "kröna",
    "kröntas": "kröna",
    "krönte": "kröna",
    "kröntes": "kröna",
    "krönts": "kröna",
    "kröp": "krypa",
    "kröps": "krypa",
    "krösamoset": "krösamos",
    "krösamosets": "krösamos",
    "krösonen": "kröson",
    "krösonens": "kröson",
    "krösonet": "kröson",
    "krösonets": "kröson",
    "krösons": "kröson",
    "krösusar": "krösus",
    "krösusarna": "krösus",
    "krösusarnas": "krösus",
    "krösusars": "krösus",
    "krösusen": "krösus",
    "krösusens": "krösus",
    "kubanen": "kuban",
    "kubanens": "kuban",
    "kubaner": "kuban",
    "kubanerna": "kuban",
    "kubanernas": "kuban",
    "kubaners": "kuban",
    "kubans": "kuban",
    "kubanska": "kubansk",
    "kubanskan": "kubanska",
    "kubanskans": "kubanska",
    "kubanskare": "kubansk",
    "kubanskares": "kubansk",
    "kubanskas": "kubanska",
    "kubanskast": "kubansk",
    "kubanskaste": "kubansk",
    "kubanskastes": "kubansk",
    "kubanskasts": "kubansk",
    "kubanske": "kubanska",
    "kubanskes": "kubansk",
    "kubanskor": "kubanska",
    "kubanskorna": "kubanska",
    "kubanskornas": "kubanska",
    "kubanskors": "kubanska",
    "kubansks": "kubansk",
    "kubanskt": "kubansk",
    "kubanskts": "kubansk",
    "kubb": "kubbe",
    "kubbades": "kubbas",
    "kubbar": "kubbe",
    "kubbarna": "kubbe",
    "kubbarnas": "kubbe",
    "kubbars": "kubbe",
    "kubbats": "kubbas",
    "kubben": "kubbe",
    "kubbens": "kubbe",
    "kubbes": "kubbe",
    "kubbs": "kubbe",
    "kuben": "kub",
    "kubens": "kub",
    "kuber": "kub",
    "kuberad": "kubera",
    "kuberade": "kubera",
    "kuberades": "kubera",
    "kuberads": "kubera",
    "kuberande": "kubera",
    "kuberanden": "kuberande",
    "kuberandena": "kuberande",
    "kuberandenas": "kuberande",
    "kuberandens": "kuberande",
    "kuberandes": "kuberande",
    "kuberandet": "kuberande",
    "kuberandets": "kuberande",
    "kuberar": "kubera",
    "kuberas": "kubera",
    "kuberat": "kubera",
    "kuberats": "kubera",
    "kuberbara": "kuberbar",
    "kuberbarare": "kuberbar",
    "kuberbarares": "kuberbar",
    "kuberbaras": "kuberbar",
    "kuberbarast": "kuberbar",
    "kuberbaraste": "kuberbar",
    "kuberbarastes": "kuberbar",
    "kuberbarasts": "kuberbar",
    "kuberbare": "kuberbar",
    "kuberbares": "kuberbar",
    "kuberbarheten": "kuberbarhet",
    "kuberbarhetens": "kuberbarhet",
    "kuberbarhets": "kuberbarhet",
    "kuberbars": "kuberbar",
    "kuberbart": "kuberbar",
    "kuberbarts": "kuberbar",
    "kuberingar": "kubering",
    "kuberingarna": "kubering",
    "kuberingarnas": "kubering",
    "kuberingars": "kubering",
    "kuberingen": "kubering",
    "kuberingens": "kubering",
    "kuberings": "kubering",
    "kuberna": "kub",
    "kubernas": "kub",
    "kubers": "kub",
    "kubikdecimetern": "kubikdecimeter",
    "kubikdecimeterna": "kubikdecimeter",
    "kubikdecimeternas": "kubikdecimeter",
    "kubikdecimeterns": "kubikdecimeter",
    "kubikdecimeters": "kubikdecimeter",
    "kubikdecimetrar": "kubikdecimeter",
    "kubikdecimetrarna": "kubikdecimeter",
    "kubikdecimetrarnas": "kubikdecimeter",
    "kubikdecimetrars": "kubikdecimeter",
    "kubiken": "kubik",
    "kubikens": "kubik",
    "kubikmetern": "kubikmeter",
    "kubikmeterna": "kubikmeter",
    "kubikmeternas": "kubikmeter",
    "kubikmeterns": "kubikmeter",
    "kubikmeters": "kubikmeter",
    "kubikmetrar": "kubikmeter",
    "kubikmetrarna": "kubikmeter",
    "kubikmetrarnas": "kubikmeter",
    "kubikmetrars": "kubikmeter",
    "kubikmillimetern": "kubikmillimeter",
    "kubikmillimeterna": "kubikmillimeter",
    "kubikmillimeternas": "kubikmillimeter",
    "kubikmillimeterns": "kubikmillimeter",
    "kubikmillimeters": "kubikmillimeter",
    "kubikmillimetrar": "kubikmillimeter",
    "kubikmillimetrarna": "kubikmillimeter",
    "kubikmillimetrarnas": "kubikmillimeter",
    "kubikmillimetrars": "kubikmillimeter",
    "kubikmåttet": "kubikmått",
    "kubikmåttets": "kubikmått",
    "kubikmåtts": "kubikmått",
    "kubikroten": "kubikrot",
    "kubikrotens": "kubikrot",
    "kubikrots": "kubikrot",
    "kubikrötter": "kubikrot",
    "kubikrötterna": "kubikrot",
    "kubikrötternas": "kubikrot",
    "kubikrötters": "kubikrot",
    "kubiks": "kubik",
    "kubiska": "kubisk",
    "kubiskare": "kubisk",
    "kubiskares": "kubisk",
    "kubiskas": "kubisk",
    "kubiskast": "kubisk",
    "kubiskaste": "kubisk",
    "kubiskastes": "kubisk",
    "kubiskasts": "kubisk",
    "kubiske": "kubisk",
    "kubiskes": "kubisk",
    "kubisks": "kubisk",
    "kubiskt": "kubisk",
    "kubiskts": "kubisk",
    "kubismen": "kubism",
    "kubismens": "kubism",
    "kubismer": "kubism",
    "kubismerna": "kubism",
    "kubismernas": "kubism",
    "kubismers": "kubism",
    "kubisms": "kubism",
    "kubisten": "kubist",
    "kubistens": "kubist",
    "kubister": "kubist",
    "kubisterna": "kubist",
    "kubisternas": "kubist",
    "kubisters": "kubist",
    "kubistiska": "kubistisk",
    "kubistiskare": "kubistisk",
    "kubistiskares": "kubistisk",
    "kubistiskas": "kubistisk",
    "kubistiskast": "kubistisk",
    "kubistiskaste": "kubistisk",
    "kubistiskastes": "kubistisk",
    "kubistiskasts": "kubistisk",
    "kubistiske": "kubistisk",
    "kubistiskes": "kubistisk",
    "kubistisks": "kubistisk",
    "kubistiskt": "kubistisk",
    "kubistiskts": "kubistisk",
    "kubists": "kubist",
    "kubs": "kub",
    "kuckel": "kuckla",
    "kuckelikuet": "kuckeliku",
    "kuckelikuets": "kuckeliku",
    "kuckelikus": "kuckeliku",
    "kuckelikut": "kuckeliku",
    "kuckelikuts": "kuckeliku",
    "kuckels": "kuckel",
    "kucklade": "kuckla",
    "kucklades": "kuckla",
    "kucklande": "kuckla",
    "kucklanden": "kucklande",
    "kucklandena": "kucklande",
    "kucklandenas": "kucklande",
    "kucklandens": "kucklande",
    "kucklandes": "kucklande",
    "kucklandet": "kucklande",
    "kucklandets": "kucklande",
    "kucklar": "kuckla",
    "kucklas": "kuckla",
    "kucklat": "kuckla",
    "kucklats": "kuckla",
    "kucklet": "kuckel",
    "kucklets": "kuckel",
    "kuckuet": "kucku",
    "kuckuets": "kucku",
    "kuckus": "kucku",
    "kuckut": "kucku",
    "kuckuts": "kucku",
    "kudd": "kudde",
    "kuddar": "kudde",
    "kuddarna": "kudde",
    "kuddarnas": "kudde",
    "kuddars": "kudde",
    "kudden": "kudde",
    "kuddens": "kudde",
    "kuddes": "kudde",
    "kuddkrigen": "kuddkrig",
    "kuddkrigens": "kuddkrig",
    "kuddkriget": "kuddkrig",
    "kuddkrigets": "kuddkrig",
    "kuddkrigs": "kuddkrig",
    "kudds": "kudde",
    "kuddvaren": "kuddvar",
    "kuddvarens": "kuddvar",
    "kuddvaret": "kuddvar",
    "kuddvarets": "kuddvar",
    "kuddvars": "kuddvar",
    "kufar": "kuf",
    "kufarna": "kuf",
    "kufarnas": "kuf",
    "kufars": "kuf",
    "kufen": "kuf",
    "kufens": "kuf",
    "kufiska": "kufisk",
    "kufiskare": "kufisk",
    "kufiskares": "kufisk",
    "kufiskas": "kufisk",
    "kufiskast": "kufisk",
    "kufiskaste": "kufisk",
    "kufiskastes": "kufisk",
    "kufiskasts": "kufisk",
    "kufiske": "kufisk",
    "kufiskes": "kufisk",
    "kufisks": "kufisk",
    "kufiskt": "kufisk",
    "kufiskts": "kufisk",
    "kufs": "kuf",
    "kugg": "kugge",
    "kuggad": "kugga",
    "kuggade": "kugga",
    "kuggades": "kugga",
    "kuggads": "kugga",
    "kuggande": "kugga",
    "kugganden": "kuggande",
    "kuggandena": "kuggande",
    "kuggandenas": "kuggande",
    "kuggandens": "kuggande",
    "kuggandes": "kuggande",
    "kuggandet": "kuggande",
    "kuggandets": "kuggande",
    "kuggar": "kugge",
    "kuggarna": "kugge",
    "kuggarnas": "kugge",
    "kuggars": "kugge",
    "kuggas": "kugga",
    "kuggat": "kugga",
    "kuggats": "kugga",
    "kuggen": "kugge",
    "kuggens": "kugge",
    "kugges": "kugge",
    "kuggfrågan": "kuggfråga",
    "kuggfrågans": "kuggfråga",
    "kuggfrågas": "kuggfråga",
    "kuggfråge": "kuggfråga",
    "kuggfrågor": "kuggfråga",
    "kuggfrågorna": "kuggfråga",
    "kuggfrågornas": "kuggfråga",
    "kuggfrågors": "kuggfråga",
    "kugghjulen": "kugghjul",
    "kugghjulens": "kugghjul",
    "kugghjulet": "kugghjul",
    "kugghjulets": "kugghjul",
    "kugghjuls": "kugghjul",
    "kuggs": "kugge",
    "kuggstänger": "kuggstång",
    "kuggstängerna": "kuggstång",
    "kuggstängernas": "kuggstång",
    "kuggstängers": "kuggstång",
    "kuggstången": "kuggstång",
    "kuggstångens": "kuggstång",
    "kuggstångs": "kuggstång",
    "kuggväxeln": "kuggväxel",
    "kuggväxelns": "kuggväxel",
    "kuggväxels": "kuggväxel",
    "kuggväxlar": "kuggväxel",
    "kuggväxlarna": "kuggväxel",
    "kuggväxlarnas": "kuggväxel",
    "kuggväxlars": "kuggväxel",
    "kujonen": "kujon",
    "kujonens": "kujon",
    "kujoner": "kujon",
    "kujonerad": "kujonera",
    "kujonerade": "kujonera",
    "kujonerades": "kujonera",
    "kujonerads": "kujonera",
    "kujonerande": "kujonera",
    "kujoneranden": "kujonerande",
    "kujonerandena": "kujonerande",
    "kujonerandenas": "kujonerande",
    "kujonerandens": "kujonerande",
    "kujonerandes": "kujonerande",
    "kujonerandet": "kujonerande",
    "kujonerandets": "kujonerande",
    "kujonerar": "kujonera",
    "kujoneras": "kujonera",
    "kujonerat": "kujonera",
    "kujonerats": "kujonera",
    "kujonerbara": "kujonerbar",
    "kujonerbarare": "kujonerbar",
    "kujonerbarares": "kujonerbar",
    "kujonerbaras": "kujonerbar",
    "kujonerbarast": "kujonerbar",
    "kujonerbaraste": "kujonerbar",
    "kujonerbarastes": "kujonerbar",
    "kujonerbarasts": "kujonerbar",
    "kujonerbare": "kujonerbar",
    "kujonerbares": "kujonerbar",
    "kujonerbarheten": "kujonerbarhet",
    "kujonerbarhetens": "kujonerbarhet",
    "kujonerbarhets": "kujonerbarhet",
    "kujonerbars": "kujonerbar",
    "kujonerbart": "kujonerbar",
    "kujonerbarts": "kujonerbar",
    "kujoneringar": "kujonering",
    "kujoneringarna": "kujonering",
    "kujoneringarnas": "kujonering",
    "kujoneringars": "kujonering",
    "kujoneringen": "kujonering",
    "kujoneringens": "kujonering",
    "kujonerings": "kujonering",
    "kujonerna": "kujon",
    "kujonernas": "kujon",
    "kujoners": "kujon",
    "kujons": "kujon",
    "kukar": "kuk",
    "kukarna": "kuk",
    "kukarnas": "kuk",
    "kukars": "kuk",
    "kuken": "kuk",
    "kukens": "kuk",
    "kukringar": "kukring",
    "kukringarna": "kukring",
    "kukringarnas": "kukring",
    "kukringars": "kukring",
    "kukringen": "kukring",
    "kukringens": "kukring",
    "kukrings": "kukring",
    "kuks": "kuk",
    "kuktrakten": "kuktrakt",
    "kuktraktens": "kuktrakt",
    "kuktrakter": "kuktrakt",
    "kuktrakterna": "kuktrakt",
    "kuktrakternas": "kuktrakt",
    "kuktrakters": "kuktrakt",
    "kuktrakts": "kuktrakt",
    "kul": "kula",
    "kulaken": "kulak",
    "kulakens": "kulak",
    "kulaker": "kulak",
    "kulakerna": "kulak",
    "kulakernas": "kulak",
    "kulakers": "kulak",
    "kulaks": "kulak",
    "kulan": "kula",
    "kulans": "kula",
    "kulas": "kula",
    "kulbanan": "kulbana",
    "kulbanans": "kulbana",
    "kulbanas": "kulbana",
    "kulbane": "kulbana",
    "kulbanor": "kulbana",
    "kulbanorna": "kulbana",
    "kulbanornas": "kulbana",
    "kulbanors": "kulbana",
    "kule": "kula",
    "kulenheten": "kulenhet",
    "kulenhetens": "kulenhet",
    "kulenhets": "kulenhet",
    "kulens": "kulen",
    "kulet": "kulen",
    "kulets": "kulen",
    "kulfången": "kulfång",
    "kulfångens": "kulfång",
    "kulfånget": "kulfång",
    "kulfångets": "kulfång",
    "kulfångs": "kulfång",
    "kulgevären": "kulgevär",
    "kulgevärens": "kulgevär",
    "kulgeväret": "kulgevär",
    "kulgevärets": "kulgevär",
    "kulgevärs": "kulgevär",
    "kulhålen": "kulhål",
    "kulhålens": "kulhål",
    "kulhålet": "kulhål",
    "kulhålets": "kulhål",
    "kulhåls": "kulhål",
    "kulier": "kuli",
    "kulierna": "kuli",
    "kuliernas": "kuli",
    "kuliers": "kuli",
    "kuliga": "kulig",
    "kuligare": "kulig",
    "kuligares": "kulig",
    "kuligas": "kulig",
    "kuligast": "kulig",
    "kuligaste": "kulig",
    "kuligastes": "kulig",
    "kuligasts": "kulig",
    "kulige": "kulig",
    "kuliges": "kulig",
    "kuligheten": "kulighet",
    "kulighetens": "kulighet",
    "kuligheter": "kulighet",
    "kuligheterna": "kulighet",
    "kuligheternas": "kulighet",
    "kuligheters": "kulighet",
    "kulighets": "kulighet",
    "kuligs": "kulig",
    "kuligt": "kulig",
    "kuligts": "kulig",
    "kulin": "kuli",
    "kulinariska": "kulinarisk",
    "kulinariskare": "kulinarisk",
    "kulinariskares": "kulinarisk",
    "kulinariskas": "kulinarisk",
    "kulinariskast": "kulinarisk",
    "kulinariskaste": "kulinarisk",
    "kulinariskastes": "kulinarisk",
    "kulinariskasts": "kulinarisk",
    "kulinariske": "kulinarisk",
    "kulinariskes": "kulinarisk",
    "kulinarisks": "kulinarisk",
    "kulinariskt": "kulinarisk",
    "kulinariskts": "kulinarisk",
    "kulingar": "kuling",
    "kulingarna": "kuling",
    "kulingarnas": "kuling",
    "kulingars": "kuling",
    "kulingen": "kuling",
    "kulingens": "kuling",
    "kulings": "kuling",
    "kulins": "kuli",
    "kulis": "kuli",
    "kulissen": "kuliss",
    "kulissens": "kuliss",
    "kulisser": "kuliss",
    "kulisserna": "kuliss",
    "kulissernas": "kuliss",
    "kulissers": "kuliss",
    "kulknappar": "kulknapp",
    "kulknapparna": "kulknapp",
    "kulknapparnas": "kulknapp",
    "kulknappars": "kulknapp",
    "kulknappen": "kulknapp",
    "kulknappens": "kulknapp",
    "kulknapps": "kulknapp",
    "kulkvarnar": "kulkvarn",
    "kulkvarnarna": "kulkvarn",
    "kulkvarnarnas": "kulkvarn",
    "kulkvarnars": "kulkvarn",
    "kulkvarnen": "kulkvarn",
    "kulkvarnens": "kulkvarn",
    "kulkvarns": "kulkvarn",
    "kulkärv": "kulkärve",
    "kulkärvar": "kulkärve",
    "kulkärvarna": "kulkärve",
    "kulkärvarnas": "kulkärve",
    "kulkärvars": "kulkärve",
    "kulkärven": "kulkärve",
    "kulkärvens": "kulkärve",
    "kulkärves": "kulkärve",
    "kulkärvs": "kulkärve",
    "kull": "kulle",
    "kullad": "kulla",
    "kullade": "kulla",
    "kullades": "kulla",
    "kullads": "kulla",
    "kullagerna": "kullager",
    "kullagernas": "kullager",
    "kullagers": "kullager",
    "kullagrade": "kullagrad",
    "kullagrades": "kullagrad",
    "kullagrads": "kullagrad",
    "kullagrat": "kullagrad",
    "kullagrats": "kullagrad",
    "kullagren": "kullager",
    "kullagrens": "kullager",
    "kullagret": "kullager",
    "kullagrets": "kullager",
    "kullan": "kulla",
    "kullande": "kulla",
    "kullanden": "kullande",
    "kullandena": "kullande",
    "kullandenas": "kullande",
    "kullandens": "kullande",
    "kullandes": "kullande",
    "kullandet": "kullande",
    "kullandets": "kullande",
    "kullans": "kulla",
    "kullar": "kulle",
    "kullarna": "kulle",
    "kullarnas": "kulle",
    "kullars": "kulle",
    "kullas": "kulla",
    "kullat": "kulla",
    "kullats": "kulla",
    "kullbytterade": "kullbyttera",
    "kullbytterades": "kullbyttera",
    "kullbytterande": "kullbyttera",
    "kullbytteranden": "kullbytterande",
    "kullbytterandena": "kullbytterande",
    "kullbytterandenas": "kullbytterande",
    "kullbytterandens": "kullbytterande",
    "kullbytterandes": "kullbytterande",
    "kullbytterandet": "kullbytterande",
    "kullbytterandets": "kullbytterande",
    "kullbytterar": "kullbyttera",
    "kullbytteras": "kullbyttera",
    "kullbytterat": "kullbyttera",
    "kullbytterats": "kullbyttera",
    "kullbytteringar": "kullbyttering",
    "kullbytteringarna": "kullbyttering",
    "kullbytteringarnas": "kullbyttering",
    "kullbytteringars": "kullbyttering",
    "kullbytteringen": "kullbyttering",
    "kullbytteringens": "kullbyttering",
    "kullbytterings": "kullbyttering",
    "kulle": "kulla",
    "kulleden": "kulled",
    "kulledens": "kulled",
    "kulleder": "kulled",
    "kullederna": "kulled",
    "kulledernas": "kulled",
    "kulleders": "kulled",
    "kulleds": "kulled",
    "kullen": "kulle",
    "kullens": "kulle",
    "kuller": "kullra",
    "kullerbytt": "kullerbytta",
    "kullerbyttan": "kullerbytta",
    "kullerbyttans": "kullerbytta",
    "kullerbyttas": "kullerbytta",
    "kullerbytte": "kullerbytta",
    "kullerbyttor": "kullerbytta",
    "kullerbyttorna": "kullerbytta",
    "kullerbyttornas": "kullerbytta",
    "kullerbyttors": "kullerbytta",
    "kullerbytts": "kullerbytta",
    "kullerstenar": "kullersten",
    "kullerstenarna": "kullersten",
    "kullerstenarnas": "kullersten",
    "kullerstenars": "kullersten",
    "kullerstenen": "kullersten",
    "kullerstenens": "kullersten",
    "kullerstens": "kullersten",
    "kullerstenspassagen": "kullerstenspassage",
    "kullerstenspassagens": "kullerstenspassage",
    "kullerstenspassager": "kullerstenspassage",
    "kullerstenspassagerna": "kullerstenspassage",
    "kullerstenspassagernas": "kullerstenspassage",
    "kullerstenspassagers": "kullerstenspassage",
    "kullerstenspassages": "kullerstenspassage",
    "kullerstenstorgen": "kullerstenstorg",
    "kullerstenstorgens": "kullerstenstorg",
    "kullerstenstorget": "kullerstenstorg",
    "kullerstenstorgets": "kullerstenstorg",
    "kullerstenstorgs": "kullerstenstorg",
    "kulliga": "kullig",
    "kulligare": "kullig",
    "kulligares": "kullig",
    "kulligas": "kullig",
    "kulligast": "kullig",
    "kulligaste": "kullig",
    "kulligastes": "kullig",
    "kulligasts": "kullig",
    "kullige": "kullig",
    "kulliges": "kullig",
    "kulligheten": "kullighet",
    "kullighetens": "kullighet",
    "kullighets": "kullighet",
    "kulligs": "kullig",
    "kulligt": "kullig",
    "kulligts": "kullig",
    "kullkamraten": "kullkamrat",
    "kullkamratens": "kullkamrat",
    "kullkamrater": "kullkamrat",
    "kullkamraterna": "kullkamrat",
    "kullkamraternas": "kullkamrat",
    "kullkamraters": "kullkamrat",
    "kullkamrats": "kullkamrat",
    "kullkast": "kullkasta",
    "kullkastad": "kullkasta",
    "kullkastade": "kullkasta",
    "kullkastades": "kullkasta",
    "kullkastads": "kullkasta",
    "kullkastande": "kullkasta",
    "kullkastanden": "kullkastande",
    "kullkastandena": "kullkastande",
    "kullkastandenas": "kullkastande",
    "kullkastandens": "kullkastande",
    "kullkastandes": "kullkastande",
    "kullkastandet": "kullkastande",
    "kullkastandets": "kullkastande",
    "kullkastar": "kullkasta",
    "kullkastas": "kullkasta",
    "kullkastat": "kullkasta",
    "kullkastats": "kullkasta",
    "kullkon": "kullko",
    "kullkons": "kullko",
    "kullkor": "kullko",
    "kullkorna": "kullko",
    "kullkornas": "kullko",
    "kullkors": "kullko",
    "kullkos": "kullko",
    "kullor": "kulla",
    "kullorna": "kulla",
    "kullornas": "kulla",
    "kullors": "kulla",
    "kullprat": "kullprata",
    "kullpratad": "kullprata",
    "kullpratade": "kullprata",
    "kullpratades": "kullprata",
    "kullpratads": "kullprata",
    "kullpratande": "kullprata",
    "kullpratanden": "kullpratande",
    "kullpratandena": "kullpratande",
    "kullpratandenas": "kullpratande",
    "kullpratandens": "kullpratande",
    "kullpratandes": "kullpratande",
    "kullpratandet": "kullpratande",
    "kullpratandets": "kullpratande",
    "kullpratar": "kullprata",
    "kullpratas": "kullprata",
    "kullpratat": "kullprata",
    "kullpratats": "kullprata",
    "kullrade": "kullra",
    "kullrades": "kullra",
    "kullrande": "kullra",
    "kullranden": "kullrande",
    "kullrandena": "kullrande",
    "kullrandenas": "kullrande",
    "kullrandens": "kullrande",
    "kullrandes": "kullrande",
    "kullrandet": "kullrande",
    "kullrandets": "kullrande",
    "kullrar": "kullra",
    "kullras": "kullra",
    "kullrat": "kullra",
    "kullrats": "kullra",
    "kullriga": "kullrig",
    "kullrigare": "kullrig",
    "kullrigares": "kullrig",
    "kullrigas": "kullrig",
    "kullrigast": "kullrig",
    "kullrigaste": "kullrig",
    "kullrigastes": "kullrig",
    "kullrigasts": "kullrig",
    "kullrige": "kullrig",
    "kullriges": "kullrig",
    "kullrigheten": "kullrighet",
    "kullrighetens": "kullrighet",
    "kullrighets": "kullrighet",
    "kullrigs": "kullrig",
    "kullrigt": "kullrig",
    "kullrigts": "kullrig",
    "kulls": "kulle",
    "kullsyskonen": "kullsyskon",
    "kullsyskonens": "kullsyskon",
    "kullsyskonet": "kullsyskon",
    "kullsyskonets": "kullsyskon",
    "kullsyskons": "kullsyskon",
    "kulmag": "kulmage",
    "kulmagar": "kulmage",
    "kulmagarna": "kulmage",
    "kulmagarnas": "kulmage",
    "kulmagars": "kulmage",
    "kulmagen": "kulmage",
    "kulmagens": "kulmage",
    "kulmages": "kulmage",
    "kulmags": "kulmage",
    "kulmens": "kulmen",
    "kulminationen": "kulmination",
    "kulminationens": "kulmination",
    "kulminationer": "kulmination",
    "kulminationerna": "kulmination",
    "kulminationernas": "kulmination",
    "kulminationers": "kulmination",
    "kulminations": "kulmination",
    "kulminerade": "kulminera",
    "kulminerades": "kulminera",
    "kulminerande": "kulminera",
    "kulmineranden": "kulminerande",
    "kulminerandena": "kulminerande",
    "kulminerandenas": "kulminerande",
    "kulminerandens": "kulminerande",
    "kulminerandes": "kulminerande",
    "kulminerandet": "kulminerande",
    "kulminerandets": "kulminerande",
    "kulminerar": "kulminera",
    "kulmineras": "kulminera",
    "kulminerat": "kulminera",
    "kulminerats": "kulminera",
    "kulmineringar": "kulminering",
    "kulmineringarna": "kulminering",
    "kulmineringarnas": "kulminering",
    "kulmineringars": "kulminering",
    "kulmineringen": "kulminering",
    "kulmineringens": "kulminering",
    "kulminerings": "kulminering",
    "kulna": "kulen",
    "kulnade": "kulna",
    "kulnades": "kulna",
    "kulnande": "kulna",
    "kulnanden": "kulnande",
    "kulnandena": "kulnande",
    "kulnandenas": "kulnande",
    "kulnandens": "kulnande",
    "kulnandes": "kulnande",
    "kulnandet": "kulnande",
    "kulnandets": "kulnande",
    "kulnar": "kulna",
    "kulnare": "kulen",
    "kulnares": "kulen",
    "kulnas": "kulna",
    "kulnast": "kulen",
    "kulnaste": "kulen",
    "kulnastes": "kulen",
    "kulnasts": "kulen",
    "kulnat": "kulna",
    "kulnats": "kulna",
    "kulne": "kulen",
    "kulnes": "kulen",
    "kulor": "kula",
    "kulorna": "kula",
    "kulornas": "kula",
    "kulors": "kula",
    "kulpenn": "kulpenna",
    "kulpennan": "kulpenna",
    "kulpennans": "kulpenna",
    "kulpennas": "kulpenna",
    "kulpenne": "kulpenna",
    "kulpennor": "kulpenna",
    "kulpennorna": "kulpenna",
    "kulpennornas": "kulpenna",
    "kulpennors": "kulpenna",
    "kulpenns": "kulpenna",
    "kulramar": "kulram",
    "kulramarna": "kulram",
    "kulramarnas": "kulram",
    "kulramars": "kulram",
    "kulramen": "kulram",
    "kulramens": "kulram",
    "kulrams": "kulram",
    "kuls": "kula",
    "kulsintern": "kulsinter",
    "kulsinterns": "kulsinter",
    "kulsinters": "kulsinter",
    "kulskrivmaskinen": "kulskrivmaskin",
    "kulskrivmaskinens": "kulskrivmaskin",
    "kulskrivmaskiner": "kulskrivmaskin",
    "kulskrivmaskinerna": "kulskrivmaskin",
    "kulskrivmaskinernas": "kulskrivmaskin",
    "kulskrivmaskiners": "kulskrivmaskin",
    "kulskrivmaskins": "kulskrivmaskin",
    "kulspelen": "kulspel",
    "kulspelens": "kulspel",
    "kulspelet": "kulspel",
    "kulspelets": "kulspel",
    "kulspels": "kulspel",
    "kulspetspenn": "kulspetspenna",
    "kulspetspennan": "kulspetspenna",
    "kulspetspennans": "kulspetspenna",
    "kulspetspennas": "kulspetspenna",
    "kulspetspenne": "kulspetspenna",
    "kulspetspennor": "kulspetspenna",
    "kulspetspennorna": "kulspetspenna",
    "kulspetspennornas": "kulspetspenna",
    "kulspetspennors": "kulspetspenna",
    "kulspetspenns": "kulspetspenna",
    "kulsprut": "kulspruta",
    "kulsprutan": "kulspruta",
    "kulsprutans": "kulspruta",
    "kulsprutas": "kulspruta",
    "kulsprutavdelningar": "kulsprutavdelning",
    "kulsprutavdelningarna": "kulsprutavdelning",
    "kulsprutavdelningarnas": "kulsprutavdelning",
    "kulsprutavdelningars": "kulsprutavdelning",
    "kulsprutavdelningen": "kulsprutavdelning",
    "kulsprutavdelningens": "kulsprutavdelning",
    "kulsprutavdelnings": "kulsprutavdelning",
    "kulsprute": "kulspruta",
    "kulsprutegevären": "kulsprutegevär",
    "kulsprutegevärens": "kulsprutegevär",
    "kulsprutegeväret": "kulsprutegevär",
    "kulsprutegevärets": "kulsprutegevär",
    "kulsprutegevärs": "kulsprutegevär",
    "kulsprutenäst": "kulsprutenäste",
    "kulsprutenästen": "kulsprutenäste",
    "kulsprutenästena": "kulsprutenäste",
    "kulsprutenästenas": "kulsprutenäste",
    "kulsprutenästens": "kulsprutenäste",
    "kulsprutenästes": "kulsprutenäste",
    "kulsprutenästet": "kulsprutenäste",
    "kulsprutenästets": "kulsprutenäste",
    "kulsprutepistolen": "kulsprutepistol",
    "kulsprutepistolens": "kulsprutepistol",
    "kulsprutepistoler": "kulsprutepistol",
    "kulsprutepistolerna": "kulsprutepistol",
    "kulsprutepistolernas": "kulsprutepistol",
    "kulsprutepistolers": "kulsprutepistol",
    "kulsprutepistols": "kulsprutepistol",
    "kulspruteskyttar": "kulspruteskytt",
    "kulspruteskyttarna": "kulspruteskytt",
    "kulspruteskyttarnas": "kulspruteskytt",
    "kulspruteskyttars": "kulspruteskytt",
    "kulspruteskytten": "kulspruteskytt",
    "kulspruteskyttens": "kulspruteskytt",
    "kulspruteskytts": "kulspruteskytt",
    "kulsprutor": "kulspruta",
    "kulsprutorna": "kulspruta",
    "kulsprutornas": "kulspruta",
    "kulsprutors": "kulspruta",
    "kulspruts": "kulspruta",
    "kulspåren": "kulspår",
    "kulspårens": "kulspår",
    "kulspåret": "kulspår",
    "kulspårets": "kulspår",
    "kulspårs": "kulspår",
    "kulstötar": "kulstötare",
    "kulstötaren": "kulstötare",
    "kulstötarens": "kulstötare",
    "kulstötares": "kulstötare",
    "kulstötarna": "kulstötare",
    "kulstötarnas": "kulstötare",
    "kulstötningar": "kulstötning",
    "kulstötningarna": "kulstötning",
    "kulstötningarnas": "kulstötning",
    "kulstötningars": "kulstötning",
    "kulstötningen": "kulstötning",
    "kulstötningens": "kulstötning",
    "kulstötnings": "kulstötning",
    "kultar": "kult",
    "kultarna": "kult",
    "kultarnas": "kult",
    "kultars": "kult",
    "kulten": "kult",
    "kultens": "kult",
    "kulter": "kult",
    "kulterna": "kult",
    "kulternas": "kult",
    "kulters": "kult",
    "kultföremålen": "kultföremål",
    "kultföremålens": "kultföremål",
    "kultföremålet": "kultföremål",
    "kultföremålets": "kultföremål",
    "kultföremåls": "kultföremål",
    "kultförklarade": "kultförklarad",
    "kultförklarades": "kultförklarad",
    "kultförklarads": "kultförklarad",
    "kultförklarat": "kultförklarad",
    "kultförklarats": "kultförklarad",
    "kulthandlingar": "kulthandling",
    "kulthandlingarna": "kulthandling",
    "kulthandlingarnas": "kulthandling",
    "kulthandlingars": "kulthandling",
    "kulthandlingen": "kulthandling",
    "kulthandlingens": "kulthandling",
    "kulthandlings": "kulthandling",
    "kultingar": "kulting",
    "kultingarna": "kulting",
    "kultingarnas": "kulting",
    "kultingars": "kulting",
    "kultingen": "kulting",
    "kultingens": "kulting",
    "kultings": "kulting",
    "kultisen": "kultis",
    "kultisens": "kultis",
    "kultiska": "kultisk",
    "kultiskare": "kultisk",
    "kultiskares": "kultisk",
    "kultiskas": "kultisk",
    "kultiskast": "kultisk",
    "kultiskaste": "kultisk",
    "kultiskastes": "kultisk",
    "kultiskasts": "kultisk",
    "kultiske": "kultisk",
    "kultiskes": "kultisk",
    "kultisks": "kultisk",
    "kultiskt": "kultisk",
    "kultiskts": "kultisk",
    "kultivatorer": "kultivator",
    "kultivatorerna": "kultivator",
    "kultivatorernas": "kultivator",
    "kultivatorers": "kultivator",
    "kultivatorn": "kultivator",
    "kultivatorns": "kultivator",
    "kultivators": "kultivator",
    "kultiverad": "kultivera",
    "kultiverade": "kultiverad",
    "kultiverades": "kultiverad",
    "kultiverads": "kultiverad",
    "kultiverande": "kultivera",
    "kultiveranden": "kultiverande",
    "kultiverandena": "kultiverande",
    "kultiverandenas": "kultiverande",
    "kultiverandens": "kultiverande",
    "kultiverandes": "kultiverande",
    "kultiverandet": "kultiverande",
    "kultiverandets": "kultiverande",
    "kultiverar": "kultivera",
    "kultiveras": "kultivera",
    "kultiverat": "kultiverad",
    "kultiverats": "kultiverad",
    "kultiverbara": "kultiverbar",
    "kultiverbarare": "kultiverbar",
    "kultiverbarares": "kultiverbar",
    "kultiverbaras": "kultiverbar",
    "kultiverbarast": "kultiverbar",
    "kultiverbaraste": "kultiverbar",
    "kultiverbarastes": "kultiverbar",
    "kultiverbarasts": "kultiverbar",
    "kultiverbare": "kultiverbar",
    "kultiverbares": "kultiverbar",
    "kultiverbarheten": "kultiverbarhet",
    "kultiverbarhetens": "kultiverbarhet",
    "kultiverbarhets": "kultiverbarhet",
    "kultiverbars": "kultiverbar",
    "kultiverbart": "kultiverbar",
    "kultiverbarts": "kultiverbar",
    "kultiveringar": "kultivering",
    "kultiveringarna": "kultivering",
    "kultiveringarnas": "kultivering",
    "kultiveringars": "kultivering",
    "kultiveringen": "kultivering",
    "kultiveringens": "kultivering",
    "kultiverings": "kultivering",
    "kultjen": "kultje",
    "kultjens": "kultje",
    "kultjes": "kultje",
    "kultplatsen": "kultplats",
    "kultplatsens": "kultplats",
    "kultplatser": "kultplats",
    "kultplatserna": "kultplats",
    "kultplatsernas": "kultplats",
    "kultplatsers": "kultplats",
    "kultrycken": "kultryck",
    "kultryckens": "kultryck",
    "kultrycket": "kultryck",
    "kultryckets": "kultryck",
    "kultrycks": "kultryck",
    "kults": "kult",
    "kulturaktiviteten": "kulturaktivitet",
    "kulturaktivitetens": "kulturaktivitet",
    "kulturaktiviteter": "kulturaktivitet",
    "kulturaktiviteterna": "kulturaktivitet",
    "kulturaktiviteternas": "kulturaktivitet",
    "kulturaktiviteters": "kulturaktivitet",
    "kulturaktivitets": "kulturaktivitet",
    "kulturarbetar": "kulturarbetare",
    "kulturarbetaren": "kulturarbetare",
    "kulturarbetarens": "kulturarbetare",
    "kulturarbetares": "kulturarbetare",
    "kulturarbetarna": "kulturarbetare",
    "kulturarbetarnas": "kulturarbetare",
    "kulturartikeln": "kulturartikel",
    "kulturartikelns": "kulturartikel",
    "kulturartikels": "kulturartikel",
    "kulturartiklar": "kulturartikel",
    "kulturartiklarna": "kulturartikel",
    "kulturartiklarnas": "kulturartikel",
    "kulturartiklars": "kulturartikel",
    "kulturarven": "kulturarv",
    "kulturarvens": "kulturarv",
    "kulturarvet": "kulturarv",
    "kulturarvets": "kulturarv",
    "kulturarvs": "kulturarv",
    "kulturattachéer": "kulturattaché",
    "kulturattachéerna": "kulturattaché",
    "kulturattachéernas": "kulturattaché",
    "kulturattachéers": "kulturattaché",
    "kulturattachén": "kulturattaché",
    "kulturattachéns": "kulturattaché",
    "kulturattachés": "kulturattaché",
    "kulturbygden": "kulturbygd",
    "kulturbygdens": "kulturbygd",
    "kulturbygder": "kulturbygd",
    "kulturbygderna": "kulturbygd",
    "kulturbygdernas": "kulturbygd",
    "kulturbygders": "kulturbygd",
    "kulturbygds": "kulturbygd",
    "kulturbärar": "kulturbärare",
    "kulturbäraren": "kulturbärare",
    "kulturbärarens": "kulturbärare",
    "kulturbärares": "kulturbärare",
    "kulturbärarna": "kulturbärare",
    "kulturbärarnas": "kulturbärare",
    "kulturcentra": "kulturcentrum",
    "kulturcentrana": "kulturcentrum",
    "kulturcentranas": "kulturcentrum",
    "kulturcentras": "kulturcentrum",
    "kulturcentrer": "kulturcentrum",
    "kulturcentrerna": "kulturcentrum",
    "kulturcentrernas": "kulturcentrum",
    "kulturcentrers": "kulturcentrum",
    "kulturcentret": "kulturcentrum",
    "kulturcentrets": "kulturcentrum",
    "kulturcentrumen": "kulturcentrum",
    "kulturcentrumens": "kulturcentrum",
    "kulturcentrumet": "kulturcentrum",
    "kulturcentrumets": "kulturcentrum",
    "kulturcentrums": "kulturcentrum",
    "kulturchocken": "kulturchock",
    "kulturchockens": "kulturchock",
    "kulturchocker": "kulturchock",
    "kulturchockerna": "kulturchock",
    "kulturchockernas": "kulturchock",
    "kulturchockers": "kulturchock",
    "kulturchocks": "kulturchock",
    "kulturdebatten": "kulturdebatt",
    "kulturdebattens": "kulturdebatt",
    "kulturdebatter": "kulturdebatt",
    "kulturdebatterna": "kulturdebatt",
    "kulturdebatternas": "kulturdebatt",
    "kulturdebatters": "kulturdebatt",
    "kulturdebatts": "kulturdebatt",
    "kulturdelar": "kulturdel",
    "kulturdelarna": "kulturdel",
    "kulturdelarnas": "kulturdel",
    "kulturdelars": "kulturdel",
    "kulturdelen": "kulturdel",
    "kulturdelens": "kulturdel",
    "kulturdels": "kulturdel",
    "kulturekonomen": "kulturekonom",
    "kulturekonomens": "kulturekonom",
    "kulturekonomer": "kulturekonom",
    "kulturekonomerna": "kulturekonom",
    "kulturekonomernas": "kulturekonom",
    "kulturekonomers": "kulturekonom",
    "kulturekonoms": "kulturekonom",
    "kulturella": "kulturell",
    "kulturellare": "kulturell",
    "kulturellares": "kulturell",
    "kulturellas": "kulturell",
    "kulturellast": "kulturell",
    "kulturellaste": "kulturell",
    "kulturellastes": "kulturell",
    "kulturellasts": "kulturell",
    "kulturelle": "kulturell",
    "kulturelles": "kulturell",
    "kulturells": "kulturell",
    "kulturellt": "kulturell",
    "kulturellts": "kulturell",
    "kulturen": "kultur",
    "kulturens": "kultur",
    "kulturer": "kultur",
    "kulturerna": "kultur",
    "kulturernas": "kultur",
    "kulturers": "kultur",
    "kulturevenemangen": "kulturevenemang",
    "kulturevenemangens": "kulturevenemang",
    "kulturevenemanget": "kulturevenemang",
    "kulturevenemangets": "kulturevenemang",
    "kulturevenemangs": "kulturevenemang",
    "kulturfientliga": "kulturfientlig",
    "kulturfientligare": "kulturfientlig",
    "kulturfientligares": "kulturfientlig",
    "kulturfientligas": "kulturfientlig",
    "kulturfientligast": "kulturfientlig",
    "kulturfientligaste": "kulturfientlig",
    "kulturfientligastes": "kulturfientlig",
    "kulturfientligasts": "kulturfientlig",
    "kulturfientlige": "kulturfientlig",
    "kulturfientliges": "kulturfientlig",
    "kulturfientligheten": "kulturfientlighet",
    "kulturfientlighetens": "kulturfientlighet",
    "kulturfientlighets": "kulturfientlighet",
    "kulturfientligs": "kulturfientlig",
    "kulturfientligt": "kulturfientlig",
    "kulturfientligts": "kulturfientlig",
    "kulturfolken": "kulturfolk",
    "kulturfolkens": "kulturfolk",
    "kulturfolket": "kulturfolk",
    "kulturfolkets": "kulturfolk",
    "kulturfolks": "kulturfolk",
    "kulturformen": "kulturform",
    "kulturformens": "kulturform",
    "kulturformer": "kulturform",
    "kulturformerna": "kulturform",
    "kulturformernas": "kulturform",
    "kulturformers": "kulturform",
    "kulturforms": "kulturform",
    "kulturföraktet": "kulturförakt",
    "kulturföraktets": "kulturförakt",
    "kulturförakts": "kulturförakt",
    "kulturgeografien": "kulturgeografi",
    "kulturgeografiens": "kulturgeografi",
    "kulturgeografin": "kulturgeografi",
    "kulturgeografins": "kulturgeografi",
    "kulturgeografis": "kulturgeografi",
    "kulturgärningar": "kulturgärning",
    "kulturgärningarna": "kulturgärning",
    "kulturgärningarnas": "kulturgärning",
    "kulturgärningars": "kulturgärning",
    "kulturgärningen": "kulturgärning",
    "kulturgärningens": "kulturgärning",
    "kulturgärnings": "kulturgärning",
    "kulturhistorian": "kulturhistoria",
    "kulturhistorians": "kulturhistoria",
    "kulturhistorias": "kulturhistoria",
    "kulturhistorien": "kulturhistoria",
    "kulturhistoriens": "kulturhistoria",
    "kulturhistoriska": "kulturhistorisk",
    "kulturhistoriskare": "kulturhistorisk",
    "kulturhistoriskares": "kulturhistorisk",
    "kulturhistoriskas": "kulturhistorisk",
    "kulturhistoriskast": "kulturhistorisk",
    "kulturhistoriskaste": "kulturhistorisk",
    "kulturhistoriskastes": "kulturhistorisk",
    "kulturhistoriskasts": "kulturhistorisk",
    "kulturhistoriske": "kulturhistorisk",
    "kulturhistoriskes": "kulturhistorisk",
    "kulturhistorisks": "kulturhistorisk",
    "kulturhistoriskt": "kulturhistorisk",
    "kulturhistoriskts": "kulturhistorisk",
    "kulturhusen": "kulturhus",
    "kulturhusens": "kulturhus",
    "kulturhuset": "kulturhus",
    "kulturhusets": "kulturhus",
    "kulturinstituten": "kulturinstitut",
    "kulturinstitutens": "kulturinstitut",
    "kulturinstitutet": "kulturinstitut",
    "kulturinstitutets": "kulturinstitut",
    "kulturinstituts": "kulturinstitut",
    "kulturintresserade": "kulturintresserad",
    "kulturintresserades": "kulturintresserad",
    "kulturintresserads": "kulturintresserad",
    "kulturintresserat": "kulturintresserad",
    "kulturintresserats": "kulturintresserad",
    "kulturknutt": "kulturknutte",
    "kulturknuttar": "kulturknutte",
    "kulturknuttarna": "kulturknutte",
    "kulturknuttarnas": "kulturknutte",
    "kulturknuttars": "kulturknutte",
    "kulturknutten": "kulturknutte",
    "kulturknuttens": "kulturknutte",
    "kulturknuttes": "kulturknutte",
    "kulturknutts": "kulturknutte",
    "kulturkollisionen": "kulturkollision",
    "kulturkollisionens": "kulturkollision",
    "kulturkollisioner": "kulturkollision",
    "kulturkollisionerna": "kulturkollision",
    "kulturkollisionernas": "kulturkollision",
    "kulturkollisioners": "kulturkollision",
    "kulturkollisions": "kulturkollision",
    "kulturkretsar": "kulturkrets",
    "kulturkretsarna": "kulturkrets",
    "kulturkretsarnas": "kulturkrets",
    "kulturkretsars": "kulturkrets",
    "kulturkretsen": "kulturkrets",
    "kulturkretsens": "kulturkrets",
    "kulturkrockar": "kulturkrock",
    "kulturkrockarna": "kulturkrock",
    "kulturkrockarnas": "kulturkrock",
    "kulturkrockars": "kulturkrock",
    "kulturkrocken": "kulturkrock",
    "kulturkrockens": "kulturkrock",
    "kulturkrocks": "kulturkrock",
    "kulturlagerna": "kulturlager",
    "kulturlagernas": "kulturlager",
    "kulturlagers": "kulturlager",
    "kulturlagren": "kulturlager",
    "kulturlagrens": "kulturlager",
    "kulturlagret": "kulturlager",
    "kulturlagrets": "kulturlager",
    "kulturlandet": "kulturland",
    "kulturlandets": "kulturland",
    "kulturlands": "kulturland",
    "kulturlandskapen": "kulturlandskap",
    "kulturlandskapens": "kulturlandskap",
    "kulturlandskapet": "kulturlandskap",
    "kulturlandskapets": "kulturlandskap",
    "kulturlandskaps": "kulturlandskap",
    "kulturlivet": "kulturliv",
    "kulturlivets": "kulturliv",
    "kulturlivs": "kulturliv",
    "kulturländer": "kulturland",
    "kulturländerna": "kulturland",
    "kulturländernas": "kulturland",
    "kulturländers": "kulturland",
    "kulturminnen": "kulturminne",
    "kulturminnena": "kulturminne",
    "kulturminnenas": "kulturminne",
    "kulturminnens": "kulturminne",
    "kulturminnes": "kulturminne",
    "kulturminnesmärk": "kulturminnesmärka",
    "kulturminnesmärkande": "kulturminnesmärka",
    "kulturminnesmärkanden": "kulturminnesmärkande",
    "kulturminnesmärkandena": "kulturminnesmärkande",
    "kulturminnesmärkandenas": "kulturminnesmärkande",
    "kulturminnesmärkandens": "kulturminnesmärkande",
    "kulturminnesmärkandes": "kulturminnesmärkande",
    "kulturminnesmärkandet": "kulturminnesmärkande",
    "kulturminnesmärkandets": "kulturminnesmärkande",
    "kulturminnesmärkas": "kulturminnesmärka",
    "kulturminnesmärken": "kulturminnesmärke",
    "kulturminnesmärkena": "kulturminnesmärke",
    "kulturminnesmärkenas": "kulturminnesmärke",
    "kulturminnesmärkens": "kulturminnesmärke",
    "kulturminnesmärker": "kulturminnesmärka",
    "kulturminnesmärkes": "kulturminnesmärke",
    "kulturminnesmärket": "kulturminnesmärke",
    "kulturminnesmärkets": "kulturminnesmärke",
    "kulturminnesmärks": "kulturminnesmärka",
    "kulturminnesmärkt": "kulturminnesmärka",
    "kulturminnesmärkta": "kulturminnesmärka",
    "kulturminnesmärktas": "kulturminnesmärka",
    "kulturminnesmärkte": "kulturminnesmärka",
    "kulturminnesmärktes": "kulturminnesmärka",
    "kulturminnesmärkts": "kulturminnesmärka",
    "kulturminnesvårdar": "kulturminnesvård",
    "kulturminnesvårdarna": "kulturminnesvård",
    "kulturminnesvårdarnas": "kulturminnesvård",
    "kulturminnesvårdars": "kulturminnesvård",
    "kulturminnesvården": "kulturminnesvård",
    "kulturminnesvårdens": "kulturminnesvård",
    "kulturminnesvårds": "kulturminnesvård",
    "kulturminnet": "kulturminne",
    "kulturminnets": "kulturminne",
    "kulturmönsterna": "kulturmönster",
    "kulturmönsternas": "kulturmönster",
    "kulturmönsters": "kulturmönster",
    "kulturmönstren": "kulturmönster",
    "kulturmönstrens": "kulturmönster",
    "kulturmönstret": "kulturmönster",
    "kulturmönstrets": "kulturmönster",
    "kulturpersonen": "kulturperson",
    "kulturpersonens": "kulturperson",
    "kulturpersoner": "kulturperson",
    "kulturpersonerna": "kulturperson",
    "kulturpersonernas": "kulturperson",
    "kulturpersoners": "kulturperson",
    "kulturpersonligheten": "kulturpersonlighet",
    "kulturpersonlighetens": "kulturpersonlighet",
    "kulturpersonligheter": "kulturpersonlighet",
    "kulturpersonligheterna": "kulturpersonlighet",
    "kulturpersonligheternas": "kulturpersonlighet",
    "kulturpersonligheters": "kulturpersonlighet",
    "kulturpersonlighets": "kulturpersonlighet",
    "kulturpersons": "kulturperson",
    "kulturpolitiken": "kulturpolitik",
    "kulturpolitikens": "kulturpolitik",
    "kulturpolitiks": "kulturpolitik",
    "kulturpolitiska": "kulturpolitisk",
    "kulturpolitiskas": "kulturpolitisk",
    "kulturpolitiske": "kulturpolitisk",
    "kulturpolitiskes": "kulturpolitisk",
    "kulturpolitisks": "kulturpolitisk",
    "kulturpolitiskt": "kulturpolitisk",
    "kulturpolitiskts": "kulturpolitisk",
    "kulturradikalen": "kulturradikal",
    "kulturradikalens": "kulturradikal",
    "kulturradikaler": "kulturradikal",
    "kulturradikalerna": "kulturradikal",
    "kulturradikalernas": "kulturradikal",
    "kulturradikalers": "kulturradikal",
    "kulturradikals": "kulturradikal",
    "kulturredaktionen": "kulturredaktion",
    "kulturredaktionens": "kulturredaktion",
    "kulturredaktioner": "kulturredaktion",
    "kulturredaktionerna": "kulturredaktion",
    "kulturredaktionernas": "kulturredaktion",
    "kulturredaktioners": "kulturredaktion",
    "kulturredaktions": "kulturredaktion",
    "kulturreservaten": "kulturreservat",
    "kulturreservatens": "kulturreservat",
    "kulturreservatet": "kulturreservat",
    "kulturreservatets": "kulturreservat",
    "kulturreservats": "kulturreservat",
    "kulturrevolutionen": "kulturrevolution",
    "kulturrevolutionens": "kulturrevolution",
    "kulturrevolutioner": "kulturrevolution",
    "kulturrevolutionerna": "kulturrevolution",
    "kulturrevolutionernas": "kulturrevolution",
    "kulturrevolutioners": "kulturrevolution",
    "kulturrevolutions": "kulturrevolution",
    "kulturråden": "kulturråd",
    "kulturrådens": "kulturråd",
    "kulturrådet": "kulturråd",
    "kulturrådets": "kulturråd",
    "kulturråds": "kulturråd",
    "kulturs": "kultur",
    "kultursidan": "kultursida",
    "kultursidans": "kultursida",
    "kultursidas": "kultursida",
    "kulturside": "kultursida",
    "kultursides": "kultursida",
    "kultursidor": "kultursida",
    "kultursidorna": "kultursida",
    "kultursidornas": "kultursida",
    "kultursidors": "kultursida",
    "kulturskillnaden": "kulturskillnad",
    "kulturskillnadens": "kulturskillnad",
    "kulturskillnader": "kulturskillnad",
    "kulturskillnaderna": "kulturskillnad",
    "kulturskillnadernas": "kulturskillnad",
    "kulturskillnaders": "kulturskillnad",
    "kulturskillnads": "kulturskillnad",
    "kulturskribenten": "kulturskribent",
    "kulturskribentens": "kulturskribent",
    "kulturskribenter": "kulturskribent",
    "kulturskribenterna": "kulturskribent",
    "kulturskribenternas": "kulturskribent",
    "kulturskribenters": "kulturskribent",
    "kulturskribents": "kulturskribent",
    "kulturskymningar": "kulturskymning",
    "kulturskymningarna": "kulturskymning",
    "kulturskymningarnas": "kulturskymning",
    "kulturskymningars": "kulturskymning",
    "kulturskymningen": "kulturskymning",
    "kulturskymningens": "kulturskymning",
    "kulturskymnings": "kulturskymning",
    "kultursvängen": "kultursväng",
    "kultursvängens": "kultursväng",
    "kultursvängs": "kultursväng",
    "kulturtänkar": "kulturtänkare",
    "kulturtänkaren": "kulturtänkare",
    "kulturtänkarens": "kulturtänkare",
    "kulturtänkares": "kulturtänkare",
    "kulturtänkarna": "kulturtänkare",
    "kulturtänkarnas": "kulturtänkare",
    "kulturutbyten": "kulturutbyte",
    "kulturutbytena": "kulturutbyte",
    "kulturutbytenas": "kulturutbyte",
    "kulturutbytens": "kulturutbyte",
    "kulturutbytes": "kulturutbyte",
    "kulturutbytet": "kulturutbyte",
    "kulturutbytets": "kulturutbyte",
    "kulturväxten": "kulturväxt",
    "kulturväxtens": "kulturväxt",
    "kulturväxter": "kulturväxt",
    "kulturväxterna": "kulturväxt",
    "kulturväxternas": "kulturväxt",
    "kulturväxters": "kulturväxt",
    "kulturväxts": "kulturväxt",
    "kulturyttringar": "kulturyttring",
    "kulturyttringarna": "kulturyttring",
    "kulturyttringarnas": "kulturyttring",
    "kulturyttringars": "kulturyttring",
    "kulturyttringen": "kulturyttring",
    "kulturyttringens": "kulturyttring",
    "kulturyttrings": "kulturyttring",
    "kulventilen": "kulventil",
    "kulventilens": "kulventil",
    "kulventiler": "kulventil",
    "kulventilerna": "kulventil",
    "kulventilernas": "kulventil",
    "kulventilers": "kulventil",
    "kulventils": "kulventil",
    "kulvertar": "kulvert",
    "kulvertarna": "kulvert",
    "kulvertarnas": "kulvert",
    "kulvertars": "kulvert",
    "kulverten": "kulvert",
    "kulvertens": "kulvert",
    "kulverts": "kulvert",
    "kulören": "kulör",
    "kulörens": "kulör",
    "kulörer": "kulör",
    "kulörerna": "kulör",
    "kulörernas": "kulör",
    "kulörers": "kulör",
    "kulörs": "kulör",
    "kulörta": "kulört",
    "kulörtare": "kulört",
    "kulörtares": "kulört",
    "kulörtas": "kulört",
    "kulörtast": "kulört",
    "kulörtaste": "kulört",
    "kulörtastes": "kulört",
    "kulörtasts": "kulört",
    "kulörte": "kulört",
    "kulörtes": "kulört",
    "kulörtheten": "kulörthet",
    "kulörthetens": "kulörthet",
    "kulörthets": "kulörthet",
    "kulörts": "kulört",
    "kulörtvättar": "kulörtvätt",
    "kulörtvättarna": "kulörtvätt",
    "kulörtvättarnas": "kulörtvätt",
    "kulörtvättars": "kulörtvätt",
    "kulörtvätten": "kulörtvätt",
    "kulörtvättens": "kulörtvätt",
    "kulörtvätts": "kulörtvätt",
    "kumlar": "kummel",
    "kumlarna": "kummel",
    "kumlarnas": "kummel",
    "kumlars": "kummel",
    "kumlen": "kummel",
    "kumlens": "kummel",
    "kumlet": "kummel",
    "kumlets": "kummel",
    "kummeln": "kummel",
    "kummelns": "kummel",
    "kummels": "kummel",
    "kumminen": "kummin",
    "kumminens": "kummin",
    "kumminet": "kummin",
    "kumminets": "kummin",
    "kummins": "kummin",
    "kummlar": "kummel",
    "kummlarna": "kummel",
    "kummlarnas": "kummel",
    "kummlars": "kummel",
    "kumpanen": "kumpan",
    "kumpanens": "kumpan",
    "kumpaner": "kumpan",
    "kumpanerna": "kumpan",
    "kumpanernas": "kumpan",
    "kumpaners": "kumpan",
    "kumpans": "kumpan",
    "kumulationen": "kumulation",
    "kumulationens": "kumulation",
    "kumulationer": "kumulation",
    "kumulationerna": "kumulation",
    "kumulationernas": "kumulation",
    "kumulationers": "kumulation",
    "kumulations": "kumulation",
    "kumulativa": "kumulativ",
    "kumulativare": "kumulativ",
    "kumulativares": "kumulativ",
    "kumulativas": "kumulativ",
    "kumulativast": "kumulativ",
    "kumulativaste": "kumulativ",
    "kumulativastes": "kumulativ",
    "kumulativasts": "kumulativ",
    "kumulative": "kumulativ",
    "kumulatives": "kumulativ",
    "kumulativs": "kumulativ",
    "kumulativt": "kumulativ",
    "kumulativts": "kumulativ",
    "kumulerad": "kumulera",
    "kumulerade": "kumulera",
    "kumulerades": "kumulera",
    "kumulerads": "kumulera",
    "kumulerande": "kumulera",
    "kumuleranden": "kumulerande",
    "kumulerandena": "kumulerande",
    "kumulerandenas": "kumulerande",
    "kumulerandens": "kumulerande",
    "kumulerandes": "kumulerande",
    "kumulerandet": "kumulerande",
    "kumulerandets": "kumulerande",
    "kumulerar": "kumulera",
    "kumuleras": "kumulera",
    "kumulerat": "kumulera",
    "kumulerats": "kumulera",
    "kumulerbara": "kumulerbar",
    "kumulerbarare": "kumulerbar",
    "kumulerbarares": "kumulerbar",
    "kumulerbaras": "kumulerbar",
    "kumulerbarast": "kumulerbar",
    "kumulerbaraste": "kumulerbar",
    "kumulerbarastes": "kumulerbar",
    "kumulerbarasts": "kumulerbar",
    "kumulerbare": "kumulerbar",
    "kumulerbares": "kumulerbar",
    "kumulerbarheten": "kumulerbarhet",
    "kumulerbarhetens": "kumulerbarhet",
    "kumulerbarhets": "kumulerbarhet",
    "kumulerbars": "kumulerbar",
    "kumulerbart": "kumulerbar",
    "kumulerbarts": "kumulerbar",
    "kumuleringar": "kumulering",
    "kumuleringarna": "kumulering",
    "kumuleringarnas": "kumulering",
    "kumuleringars": "kumulering",
    "kumuleringen": "kumulering",
    "kumuleringens": "kumulering",
    "kumulerings": "kumulering",
    "kundcentrerade": "kundcentrerad",
    "kundcentrerades": "kundcentrerad",
    "kundcentrerads": "kundcentrerad",
    "kundcentrerat": "kundcentrerad",
    "kundcentrerats": "kundcentrerad",
    "kunde": "kunna",
    "kunden": "kund",
    "kundens": "kund",
    "kunder": "kund",
    "kunderna": "kund",
    "kundernas": "kund",
    "kunders": "kund",
    "kundkretsar": "kundkrets",
    "kundkretsarna": "kundkrets",
    "kundkretsarnas": "kundkrets",
    "kundkretsars": "kundkrets",
    "kundkretsen": "kundkrets",
    "kundkretsens": "kundkrets",
    "kundnöjdheten": "kundnöjdhet",
    "kundnöjdhetens": "kundnöjdhet",
    "kundnöjdhets": "kundnöjdhet",
    "kunds": "kund",
    "kundservicechefen": "kundservicechef",
    "kundservicechefens": "kundservicechef",
    "kundservicechefer": "kundservicechef",
    "kundservicecheferna": "kundservicechef",
    "kundservicechefernas": "kundservicechef",
    "kundservicechefers": "kundservicechef",
    "kundservicechefs": "kundservicechef",
    "kundservicen": "kundservice",
    "kundservicens": "kundservice",
    "kundservices": "kundservice",
    "kundtjänsten": "kundtjänst",
    "kundtjänstens": "kundtjänst",
    "kundtjänsts": "kundtjänst",
    "kundunderlagen": "kundunderlag",
    "kundunderlagens": "kundunderlag",
    "kundunderlaget": "kundunderlag",
    "kundunderlagets": "kundunderlag",
    "kundunderlags": "kundunderlag",
    "kundvagnar": "kundvagn",
    "kundvagnarna": "kundvagn",
    "kundvagnarnas": "kundvagn",
    "kundvagnars": "kundvagn",
    "kundvagnen": "kundvagn",
    "kundvagnens": "kundvagn",
    "kundvagns": "kundvagn",
    "kungadömen": "kungadöme",
    "kungadömena": "kungadöme",
    "kungadömenas": "kungadöme",
    "kungadömens": "kungadöme",
    "kungadömes": "kungadöme",
    "kungadömet": "kungadöme",
    "kungadömets": "kungadöme",
    "kungaeden": "kungaed",
    "kungaedens": "kungaed",
    "kungaeder": "kungaed",
    "kungaederna": "kungaed",
    "kungaedernas": "kungaed",
    "kungaeders": "kungaed",
    "kungaeds": "kungaed",
    "kungafamiljen": "kungafamilj",
    "kungafamiljens": "kungafamilj",
    "kungafamiljer": "kungafamilj",
    "kungafamiljerna": "kungafamilj",
    "kungafamiljernas": "kungafamilj",
    "kungafamiljers": "kungafamilj",
    "kungafamiljs": "kungafamilj",
    "kungaförsäkrans": "kungaförsäkran",
    "kungahusen": "kungahus",
    "kungahusens": "kungahus",
    "kungahuset": "kungahus",
    "kungahusets": "kungahus",
    "kungakron": "kungakrona",
    "kungakronan": "kungakrona",
    "kungakronans": "kungakrona",
    "kungakronas": "kungakrona",
    "kungakrone": "kungakrona",
    "kungakronor": "kungakrona",
    "kungakronorna": "kungakrona",
    "kungakronornas": "kungakrona",
    "kungakronors": "kungakrona",
    "kungakrons": "kungakrona",
    "kungalängden": "kungalängd",
    "kungalängdens": "kungalängd",
    "kungalängder": "kungalängd",
    "kungalängderna": "kungalängd",
    "kungalängdernas": "kungalängd",
    "kungalängders": "kungalängd",
    "kungalängds": "kungalängd",
    "kungamorden": "kungamord",
    "kungamordens": "kungamord",
    "kungamordet": "kungamord",
    "kungamordets": "kungamord",
    "kungamords": "kungamord",
    "kungaparen": "kungapar",
    "kungaparens": "kungapar",
    "kungaparet": "kungapar",
    "kungaparets": "kungapar",
    "kungapars": "kungapar",
    "kungar": "kung",
    "kungaresidensen": "kungaresidens",
    "kungaresidensens": "kungaresidens",
    "kungaresidenset": "kungaresidens",
    "kungaresidensets": "kungaresidens",
    "kungariken": "kungarike",
    "kungarikena": "kungarike",
    "kungarikenas": "kungarike",
    "kungarikens": "kungarike",
    "kungarikes": "kungarike",
    "kungariket": "kungarike",
    "kungarikets": "kungarike",
    "kungarna": "kung",
    "kungarnas": "kung",
    "kungars": "kung",
    "kungasäten": "kungasäte",
    "kungasätena": "kungasäte",
    "kungasätenas": "kungasäte",
    "kungasätens": "kungasäte",
    "kungasätes": "kungasäte",
    "kungasätet": "kungasäte",
    "kungasätets": "kungasäte",
    "kungavalen": "kungaval",
    "kungavalens": "kungaval",
    "kungavalet": "kungaval",
    "kungavalets": "kungaval",
    "kungavals": "kungaval",
    "kungaätten": "kungaätt",
    "kungaättens": "kungaätt",
    "kungaätter": "kungaätt",
    "kungaätterna": "kungaätt",
    "kungaätternas": "kungaätt",
    "kungaätters": "kungaätt",
    "kungaätts": "kungaätt",
    "kungen": "kung",
    "kungens": "kung",
    "kungjord": "kungöra",
    "kungjorda": "kungöra",
    "kungjordas": "kungöra",
    "kungjorde": "kungöra",
    "kungjordes": "kungöra",
    "kungjords": "kungöra",
    "kungjort": "kungöra",
    "kungjorts": "kungöra",
    "kungliga": "kunglig",
    "kungligare": "kunglig",
    "kungligares": "kunglig",
    "kungligas": "kunglig",
    "kungligast": "kunglig",
    "kungligaste": "kunglig",
    "kungligastes": "kunglig",
    "kungligasts": "kunglig",
    "kunglige": "kunglig",
    "kungliges": "kunglig",
    "kungligheten": "kunglighet",
    "kunglighetens": "kunglighet",
    "kungligheter": "kunglighet",
    "kungligheterna": "kunglighet",
    "kungligheternas": "kunglighet",
    "kungligheters": "kunglighet",
    "kunglighets": "kunglighet",
    "kungligs": "kunglig",
    "kungligt": "kunglig",
    "kungligts": "kunglig",
    "kungs": "kung",
    "kungsblåa": "kungsblå",
    "kungsblåare": "kungsblå",
    "kungsblåares": "kungsblå",
    "kungsblåas": "kungsblå",
    "kungsblåast": "kungsblå",
    "kungsblåaste": "kungsblå",
    "kungsblåastes": "kungsblå",
    "kungsblåasts": "kungsblå",
    "kungsblåe": "kungsblå",
    "kungsblåes": "kungsblå",
    "kungsblås": "kungsblå",
    "kungsblått": "kungsblå",
    "kungsblåtts": "kungsblå",
    "kungsbond": "kungsbonde",
    "kungsbonden": "kungsbonde",
    "kungsbondens": "kungsbonde",
    "kungsbondes": "kungsbonde",
    "kungsbonds": "kungsbonde",
    "kungsbönder": "kungsbonde",
    "kungsbönderna": "kungsbonde",
    "kungsböndernas": "kungsbonde",
    "kungsbönders": "kungsbonde",
    "kungsfiskar": "kungsfiskare",
    "kungsfiskaren": "kungsfiskare",
    "kungsfiskarens": "kungsfiskare",
    "kungsfiskares": "kungsfiskare",
    "kungsfiskarna": "kungsfiskare",
    "kungsfiskarnas": "kungsfiskare",
    "kungsfågeln": "kungsfågel",
    "kungsfågelns": "kungsfågel",
    "kungsfågels": "kungsfågel",
    "kungsfåglar": "kungsfågel",
    "kungsfåglarna": "kungsfågel",
    "kungsfåglarnas": "kungsfågel",
    "kungsfåglars": "kungsfågel",
    "kungsgambitar": "kungsgambit",
    "kungsgambitarna": "kungsgambit",
    "kungsgambitarnas": "kungsgambit",
    "kungsgambitars": "kungsgambit",
    "kungsgambiten": "kungsgambit",
    "kungsgambitens": "kungsgambit",
    "kungsgambiter": "kungsgambit",
    "kungsgambiterna": "kungsgambit",
    "kungsgambiternas": "kungsgambit",
    "kungsgambiters": "kungsgambit",
    "kungsgambits": "kungsgambit",
    "kungsgårdar": "kungsgård",
    "kungsgårdarna": "kungsgård",
    "kungsgårdarnas": "kungsgård",
    "kungsgårdars": "kungsgård",
    "kungsgården": "kungsgård",
    "kungsgårdens": "kungsgård",
    "kungsgårds": "kungsgård",
    "kungshögar": "kungshög",
    "kungshögarna": "kungshög",
    "kungshögarnas": "kungshög",
    "kungshögars": "kungshög",
    "kungshögen": "kungshög",
    "kungshögens": "kungshög",
    "kungshögs": "kungshög",
    "kungskrabb": "kungskrabba",
    "kungskrabban": "kungskrabba",
    "kungskrabbans": "kungskrabba",
    "kungskrabbas": "kungskrabba",
    "kungskrabbe": "kungskrabba",
    "kungskrabbor": "kungskrabba",
    "kungskrabborna": "kungskrabba",
    "kungskrabbornas": "kungskrabba",
    "kungskrabbors": "kungskrabba",
    "kungskrabbs": "kungskrabba",
    "kungsljusen": "kungsljus",
    "kungsljusens": "kungsljus",
    "kungsljuset": "kungsljus",
    "kungsljusets": "kungsljus",
    "kungsorden": "kungsord",
    "kungsordens": "kungsord",
    "kungsordet": "kungsord",
    "kungsordets": "kungsord",
    "kungsords": "kungsord",
    "kungstank": "kungstanke",
    "kungstankar": "kungstanke",
    "kungstankarna": "kungstanke",
    "kungstankarnas": "kungstanke",
    "kungstankars": "kungstanke",
    "kungstanken": "kungstanke",
    "kungstankens": "kungstanke",
    "kungstankes": "kungstanke",
    "kungstanks": "kungstanke",
    "kungstigern": "kungstiger",
    "kungstigerns": "kungstiger",
    "kungstigers": "kungstiger",
    "kungstigrar": "kungstiger",
    "kungstigrarna": "kungstiger",
    "kungstigrarnas": "kungstiger",
    "kungstigrars": "kungstiger",
    "kungsvattens": "kungsvatten",
    "kungsvattnet": "kungsvatten",
    "kungsvattnets": "kungsvatten",
    "kungsvägar": "kungsväg",
    "kungsvägarna": "kungsväg",
    "kungsvägarnas": "kungsväg",
    "kungsvägars": "kungsväg",
    "kungsvägen": "kungsväg",
    "kungsvägens": "kungsväg",
    "kungsvägs": "kungsväg",
    "kungsängsliljan": "kungsängslilja",
    "kungsängsliljans": "kungsängslilja",
    "kungsängsliljas": "kungsängslilja",
    "kungsängslilje": "kungsängslilja",
    "kungsängsliljor": "kungsängslilja",
    "kungsängsliljorna": "kungsängslilja",
    "kungsängsliljornas": "kungsängslilja",
    "kungsängsliljors": "kungsängslilja",
    "kungsåder": "kungsådra",
    "kungsådran": "kungsådra",
    "kungsådrans": "kungsådra",
    "kungsådras": "kungsådra",
    "kungsådre": "kungsådra",
    "kungsådror": "kungsådra",
    "kungsådrorna": "kungsådra",
    "kungsådrornas": "kungsådra",
    "kungsådrors": "kungsådra",
    "kungsörnar": "kungsörn",
    "kungsörnarna": "kungsörn",
    "kungsörnarnas": "kungsörn",
    "kungsörnars": "kungsörn",
    "kungsörnen": "kungsörn",
    "kungsörnens": "kungsörn",
    "kungsörns": "kungsörn",
    "kungör": "kungöra",
    "kungörande": "kungöra",
    "kungöranden": "kungörande",
    "kungörandena": "kungörande",
    "kungörandenas": "kungörande",
    "kungörandens": "kungörande",
    "kungörandes": "kungörande",
    "kungörandet": "kungörande",
    "kungörandets": "kungörande",
    "kungöras": "kungöra",
    "kungörelsen": "kungörelse",
    "kungörelsens": "kungörelse",
    "kungörelser": "kungörelse",
    "kungörelserna": "kungörelse",
    "kungörelsernas": "kungörelse",
    "kungörelsers": "kungörelse",
    "kungörelses": "kungörelse",
    "kungöres": "kungöra",
    "kungörs": "kungöra",
    "kunn": "kunna",
    "kunnande": "kunna",
    "kunnandes": "kunnande",
    "kunnandet": "kunnande",
    "kunnandets": "kunnande",
    "kunnat": "kunna",
    "kunniga": "kunnig",
    "kunnigare": "kunnig",
    "kunnigares": "kunnig",
    "kunnigas": "kunnig",
    "kunnigast": "kunnig",
    "kunnigaste": "kunnig",
    "kunnigastes": "kunnig",
    "kunnigasts": "kunnig",
    "kunnige": "kunnig",
    "kunniges": "kunnig",
    "kunnigheten": "kunnighet",
    "kunnighetens": "kunnighet",
    "kunnighets": "kunnighet",
    "kunnigs": "kunnig",
    "kunnigt": "kunnig",
    "kunnigts": "kunnig",
    "kunskapade": "kunskapa",
    "kunskapades": "kunskapa",
    "kunskapande": "kunskapa",
    "kunskapanden": "kunskapande",
    "kunskapandena": "kunskapande",
    "kunskapandenas": "kunskapande",
    "kunskapandens": "kunskapande",
    "kunskapandes": "kunskapande",
    "kunskapandet": "kunskapande",
    "kunskapandets": "kunskapande",
    "kunskapar": "kunskapare",
    "kunskaparen": "kunskapare",
    "kunskaparens": "kunskapare",
    "kunskapares": "kunskapare",
    "kunskaparna": "kunskapare",
    "kunskaparnas": "kunskapare",
    "kunskapas": "kunskapa",
    "kunskapat": "kunskapa",
    "kunskapats": "kunskapa",
    "kunskapen": "kunskap",
    "kunskapens": "kunskap",
    "kunskaper": "kunskap",
    "kunskaperna": "kunskap",
    "kunskapernas": "kunskap",
    "kunskapers": "kunskap",
    "kunskaps": "kunskap",
    "kunskapskontrollen": "kunskapskontroll",
    "kunskapskontrollens": "kunskapskontroll",
    "kunskapskontroller": "kunskapskontroll",
    "kunskapskontrollerna": "kunskapskontroll",
    "kunskapskontrollernas": "kunskapskontroll",
    "kunskapskontrollers": "kunskapskontroll",
    "kunskapskontrolls": "kunskapskontroll",
    "kunskapskäll": "kunskapskälla",
    "kunskapskällan": "kunskapskälla",
    "kunskapskällans": "kunskapskälla",
    "kunskapskällas": "kunskapskälla",
    "kunskapskälle": "kunskapskälla",
    "kunskapskällor": "kunskapskälla",
    "kunskapskällorna": "kunskapskälla",
    "kunskapskällornas": "kunskapskälla",
    "kunskapskällors": "kunskapskälla",
    "kunskapskälls": "kunskapskälla",
    "kunskapslidelsen": "kunskapslidelse",
    "kunskapslidelsens": "kunskapslidelse",
    "kunskapslidelses": "kunskapslidelse",
    "kunskapslägen": "kunskapsläge",
    "kunskapslägena": "kunskapsläge",
    "kunskapslägenas": "kunskapsläge",
    "kunskapslägens": "kunskapsläge",
    "kunskapsläges": "kunskapsläge",
    "kunskapsläget": "kunskapsläge",
    "kunskapslägets": "kunskapsläge",
    "kunskapsmaskinen": "kunskapsmaskin",
    "kunskapsmaskinens": "kunskapsmaskin",
    "kunskapsmaskiner": "kunskapsmaskin",
    "kunskapsmaskinerna": "kunskapsmaskin",
    "kunskapsmaskinernas": "kunskapsmaskin",
    "kunskapsmaskiners": "kunskapsmaskin",
    "kunskapsmaskins": "kunskapsmaskin",
    "kunskapsmässiga": "kunskapsmässig",
    "kunskapsmässigare": "kunskapsmässig",
    "kunskapsmässigares": "kunskapsmässig",
    "kunskapsmässigas": "kunskapsmässig",
    "kunskapsmässigast": "kunskapsmässig",
    "kunskapsmässigaste": "kunskapsmässig",
    "kunskapsmässigastes": "kunskapsmässig",
    "kunskapsmässigasts": "kunskapsmässig",
    "kunskapsmässige": "kunskapsmässig",
    "kunskapsmässiges": "kunskapsmässig",
    "kunskapsmässigs": "kunskapsmässig",
    "kunskapsmässigt": "kunskapsmässig",
    "kunskapsmässigts": "kunskapsmässig",
    "kunskapsnivåer": "kunskapsnivå",
    "kunskapsnivåerna": "kunskapsnivå",
    "kunskapsnivåernas": "kunskapsnivå",
    "kunskapsnivåers": "kunskapsnivå",
    "kunskapsnivån": "kunskapsnivå",
    "kunskapsnivåns": "kunskapsnivå",
    "kunskapsnivås": "kunskapsnivå",
    "kunskapsstoffen": "kunskapsstoff",
    "kunskapsstoffens": "kunskapsstoff",
    "kunskapsstoffet": "kunskapsstoff",
    "kunskapsstoffets": "kunskapsstoff",
    "kunskapsstoffs": "kunskapsstoff",
    "kunskapsteorien": "kunskapsteori",
    "kunskapsteoriens": "kunskapsteori",
    "kunskapsteorin": "kunskapsteori",
    "kunskapsteorins": "kunskapsteori",
    "kunskapsteoris": "kunskapsteori",
    "kup": "kupa",
    "kupad": "kupa",
    "kupade": "kupa",
    "kupades": "kupa",
    "kupads": "kupa",
    "kupan": "kupa",
    "kupande": "kupa",
    "kupanden": "kupande",
    "kupandena": "kupande",
    "kupandenas": "kupande",
    "kupandens": "kupande",
    "kupandes": "kupande",
    "kupandet": "kupande",
    "kupandets": "kupande",
    "kupans": "kupa",
    "kupar": "kupa",
    "kupas": "kupa",
    "kupat": "kupa",
    "kupats": "kupa",
    "kupe": "kupa",
    "kuperad": "kupera",
    "kuperade": "kuperad",
    "kuperades": "kuperad",
    "kuperads": "kuperad",
    "kuperande": "kupera",
    "kuperanden": "kuperande",
    "kuperandena": "kuperande",
    "kuperandenas": "kuperande",
    "kuperandens": "kuperande",
    "kuperandes": "kuperande",
    "kuperandet": "kuperande",
    "kuperandets": "kuperande",
    "kuperar": "kupera",
    "kuperas": "kupera",
    "kuperat": "kuperad",
    "kuperats": "kuperad",
    "kuperbara": "kuperbar",
    "kuperbarare": "kuperbar",
    "kuperbarares": "kuperbar",
    "kuperbaras": "kuperbar",
    "kuperbarast": "kuperbar",
    "kuperbaraste": "kuperbar",
    "kuperbarastes": "kuperbar",
    "kuperbarasts": "kuperbar",
    "kuperbare": "kuperbar",
    "kuperbares": "kuperbar",
    "kuperbarheten": "kuperbarhet",
    "kuperbarhetens": "kuperbarhet",
    "kuperbarhets": "kuperbarhet",
    "kuperbars": "kuperbar",
    "kuperbart": "kuperbar",
    "kuperbarts": "kuperbar",
    "kuperingar": "kupering",
    "kuperingarna": "kupering",
    "kuperingarnas": "kupering",
    "kuperingars": "kupering",
    "kuperingen": "kupering",
    "kuperingens": "kupering",
    "kuperings": "kupering",
    "kupidonen": "kupidon",
    "kupidonens": "kupidon",
    "kupidoner": "kupidon",
    "kupidonerna": "kupidon",
    "kupidonernas": "kupidon",
    "kupidoners": "kupidon",
    "kupidons": "kupidon",
    "kupiga": "kupig",
    "kupigare": "kupig",
    "kupigares": "kupig",
    "kupigas": "kupig",
    "kupigast": "kupig",
    "kupigaste": "kupig",
    "kupigastes": "kupig",
    "kupigasts": "kupig",
    "kupige": "kupig",
    "kupiges": "kupig",
    "kupigs": "kupig",
    "kupigt": "kupig",
    "kupigts": "kupig",
    "kupletten": "kuplett",
    "kuplettens": "kuplett",
    "kupletter": "kuplett",
    "kupletterna": "kuplett",
    "kupletternas": "kuplett",
    "kupletters": "kuplett",
    "kupletts": "kuplett",
    "kupolen": "kupol",
    "kupolens": "kupol",
    "kupoler": "kupol",
    "kupolerna": "kupol",
    "kupolernas": "kupol",
    "kupolers": "kupol",
    "kupolformiga": "kupolformig",
    "kupolformigare": "kupolformig",
    "kupolformigares": "kupolformig",
    "kupolformigas": "kupolformig",
    "kupolformigast": "kupolformig",
    "kupolformigaste": "kupolformig",
    "kupolformigastes": "kupolformig",
    "kupolformigasts": "kupolformig",
    "kupolformige": "kupolformig",
    "kupolformiges": "kupolformig",
    "kupolformigheten": "kupolformighet",
    "kupolformighetens": "kupolformighet",
    "kupolformighets": "kupolformighet",
    "kupolformigs": "kupolformig",
    "kupolformigt": "kupolformig",
    "kupolformigts": "kupolformig",
    "kupolförsedda": "kupolförsedd",
    "kupolförseddare": "kupolförsedd",
    "kupolförseddares": "kupolförsedd",
    "kupolförseddas": "kupolförsedd",
    "kupolförseddast": "kupolförsedd",
    "kupolförseddaste": "kupolförsedd",
    "kupolförseddastes": "kupolförsedd",
    "kupolförseddasts": "kupolförsedd",
    "kupolförsedde": "kupolförsedd",
    "kupolförseddes": "kupolförsedd",
    "kupolförsedds": "kupolförsedd",
    "kupolförsett": "kupolförsedd",
    "kupolförsetts": "kupolförsedd",
    "kupolgravar": "kupolgrav",
    "kupolgravarna": "kupolgrav",
    "kupolgravarnas": "kupolgrav",
    "kupolgravars": "kupolgrav",
    "kupolgraven": "kupolgrav",
    "kupolgravens": "kupolgrav",
    "kupolgravs": "kupolgrav",
    "kupols": "kupol",
    "kupongen": "kupong",
    "kupongens": "kupong",
    "kuponger": "kupong",
    "kupongerna": "kupong",
    "kupongernas": "kupong",
    "kupongers": "kupong",
    "kupongklippar": "kupongklippare",
    "kupongklipparen": "kupongklippare",
    "kupongklipparens": "kupongklippare",
    "kupongklippares": "kupongklippare",
    "kupongklipparna": "kupongklippare",
    "kupongklipparnas": "kupongklippare",
    "kupongs": "kupong",
    "kupor": "kupa",
    "kuporna": "kupa",
    "kupornas": "kupa",
    "kupors": "kupa",
    "kuppade": "kuppa",
    "kuppades": "kuppa",
    "kuppande": "kuppa",
    "kuppanden": "kuppande",
    "kuppandena": "kuppande",
    "kuppandenas": "kuppande",
    "kuppandens": "kuppande",
    "kuppandes": "kuppande",
    "kuppandet": "kuppande",
    "kuppandets": "kuppande",
    "kuppar": "kuppa",
    "kuppartade": "kuppartad",
    "kuppartades": "kuppartad",
    "kuppartads": "kuppartad",
    "kuppartat": "kuppartad",
    "kuppartats": "kuppartad",
    "kuppas": "kuppa",
    "kuppat": "kuppa",
    "kuppats": "kuppa",
    "kuppberedskapen": "kuppberedskap",
    "kuppberedskapens": "kuppberedskap",
    "kuppberedskaps": "kuppberedskap",
    "kuppen": "kupp",
    "kuppens": "kupp",
    "kupper": "kupp",
    "kupperna": "kupp",
    "kuppernas": "kupp",
    "kuppers": "kupp",
    "kuppförsöken": "kuppförsök",
    "kuppförsökens": "kuppförsök",
    "kuppförsöket": "kuppförsök",
    "kuppförsökets": "kuppförsök",
    "kuppförsöks": "kuppförsök",
    "kupps": "kupp",
    "kups": "kupa",
    "kupédörrar": "kupédörr",
    "kupédörrarna": "kupédörr",
    "kupédörrarnas": "kupédörr",
    "kupédörrars": "kupédörr",
    "kupédörren": "kupédörr",
    "kupédörrens": "kupédörr",
    "kupédörrs": "kupédörr",
    "kupéer": "kupé",
    "kupéerna": "kupé",
    "kupéernas": "kupé",
    "kupéers": "kupé",
    "kupéfönsterna": "kupéfönster",
    "kupéfönsternas": "kupéfönster",
    "kupéfönsters": "kupéfönster",
    "kupéfönstren": "kupéfönster",
    "kupéfönstrens": "kupéfönster",
    "kupéfönstret": "kupéfönster",
    "kupéfönstrets": "kupéfönster",
    "kupén": "kupé",
    "kupéns": "kupé",
    "kupés": "kupé",
    "kupévärmar": "kupévärmare",
    "kupévärmaren": "kupévärmare",
    "kupévärmarens": "kupévärmare",
    "kupévärmares": "kupévärmare",
    "kupévärmarna": "kupévärmare",
    "kupévärmarnas": "kupévärmare",
    "kur": "kura",
    "kurad": "kura",
    "kurade": "kura",
    "kurades": "kura",
    "kurads": "kura",
    "kurages": "kurage",
    "kuraget": "kurage",
    "kuragets": "kurage",
    "kurande": "kura",
    "kuranden": "kurande",
    "kurandena": "kurande",
    "kurandenas": "kurande",
    "kurandens": "kurande",
    "kurandes": "kurande",
    "kurandet": "kurande",
    "kurandets": "kurande",
    "kuranstalten": "kuranstalt",
    "kuranstaltens": "kuranstalt",
    "kuranstalter": "kuranstalt",
    "kuranstalterna": "kuranstalt",
    "kuranstalternas": "kuranstalt",
    "kuranstalters": "kuranstalt",
    "kuranstalts": "kuranstalt",
    "kuranta": "kurant",
    "kurantare": "kurant",
    "kurantares": "kurant",
    "kurantas": "kurant",
    "kurantast": "kurant",
    "kurantaste": "kurant",
    "kurantastes": "kurant",
    "kurantasts": "kurant",
    "kurante": "kurant",
    "kurantes": "kurant",
    "kurants": "kurant",
    "kurar": "kura",
    "kurares": "kurare",
    "kuraret": "kurare",
    "kurarets": "kurare",
    "kurarna": "kur",
    "kurarnas": "kur",
    "kurars": "kur",
    "kuras": "kura",
    "kurat": "kura",
    "kuratelen": "kuratel",
    "kuratelens": "kuratel",
    "kuratelet": "kuratel",
    "kuratelets": "kuratel",
    "kuratels": "kuratel",
    "kuraterad": "kuratera",
    "kuraterade": "kuratera",
    "kuraterades": "kuratera",
    "kuraterads": "kuratera",
    "kuraterande": "kuratera",
    "kurateranden": "kuraterande",
    "kuraterandena": "kuraterande",
    "kuraterandenas": "kuraterande",
    "kuraterandens": "kuraterande",
    "kuraterandes": "kuraterande",
    "kuraterandet": "kuraterande",
    "kuraterandets": "kuraterande",
    "kuraterar": "kuratera",
    "kurateras": "kuratera",
    "kuraterat": "kuratera",
    "kuraterats": "kuratera",
    "kuraterbara": "kuraterbar",
    "kuraterbarare": "kuraterbar",
    "kuraterbarares": "kuraterbar",
    "kuraterbaras": "kuraterbar",
    "kuraterbarast": "kuraterbar",
    "kuraterbaraste": "kuraterbar",
    "kuraterbarastes": "kuraterbar",
    "kuraterbarasts": "kuraterbar",
    "kuraterbare": "kuraterbar",
    "kuraterbares": "kuraterbar",
    "kuraterbarheten": "kuraterbarhet",
    "kuraterbarhetens": "kuraterbarhet",
    "kuraterbarhets": "kuraterbarhet",
    "kuraterbars": "kuraterbar",
    "kuraterbart": "kuraterbar",
    "kuraterbarts": "kuraterbar",
    "kurativa": "kurativ",
    "kurativare": "kurativ",
    "kurativares": "kurativ",
    "kurativas": "kurativ",
    "kurativast": "kurativ",
    "kurativaste": "kurativ",
    "kurativastes": "kurativ",
    "kurativasts": "kurativ",
    "kurative": "kurativ",
    "kuratives": "kurativ",
    "kurativs": "kurativ",
    "kurativt": "kurativ",
    "kurativts": "kurativ",
    "kuratorer": "kurator",
    "kuratorerna": "kurator",
    "kuratorernas": "kurator",
    "kuratorers": "kurator",
    "kuratorn": "kurator",
    "kuratorns": "kurator",
    "kurators": "kurator",
    "kurats": "kura",
    "kurbitsar": "kurbits",
    "kurbitsarna": "kurbits",
    "kurbitsarnas": "kurbits",
    "kurbitsars": "kurbits",
    "kurbitsen": "kurbits",
    "kurbitsens": "kurbits",
    "kurbitser": "kurbits",
    "kurbitserna": "kurbits",
    "kurbitsernas": "kurbits",
    "kurbitsers": "kurbits",
    "kurden": "kurd",
    "kurdens": "kurd",
    "kurder": "kurd",
    "kurdern": "kurder",
    "kurderna": "kurder",
    "kurdernas": "kurder",
    "kurderns": "kurder",
    "kurders": "kurder",
    "kurdisk": "kurdiska",
    "kurdiska": "kurdisk",
    "kurdiskan": "kurdiska",
    "kurdiskans": "kurdiska",
    "kurdiskare": "kurdisk",
    "kurdiskares": "kurdisk",
    "kurdiskas": "kurdiska",
    "kurdiskast": "kurdisk",
    "kurdiskaste": "kurdisk",
    "kurdiskastes": "kurdisk",
    "kurdiskasts": "kurdisk",
    "kurdiske": "kurdiska",
    "kurdiskes": "kurdisk",
    "kurdiskor": "kurdiska",
    "kurdiskorna": "kurdiska",
    "kurdiskornas": "kurdiska",
    "kurdiskors": "kurdiska",
    "kurdisks": "kurdisk",
    "kurdiskt": "kurdisk",
    "kurdiskts": "kurdisk",
    "kurds": "kurd",
    "kuren": "kur",
    "kurens": "kur",
    "kurer": "kur",
    "kurerad": "kurera",
    "kurerade": "kurera",
    "kurerades": "kurera",
    "kurerads": "kurera",
    "kurerande": "kurera",
    "kureranden": "kurerande",
    "kurerandena": "kurerande",
    "kurerandenas": "kurerande",
    "kurerandens": "kurerande",
    "kurerandes": "kurerande",
    "kurerandet": "kurerande",
    "kurerandets": "kurerande",
    "kurerar": "kurera",
    "kureras": "kurera",
    "kurerat": "kurera",
    "kurerats": "kurera",
    "kurerbara": "kurerbar",
    "kurerbarare": "kurerbar",
    "kurerbarares": "kurerbar",
    "kurerbaras": "kurerbar",
    "kurerbarast": "kurerbar",
    "kurerbaraste": "kurerbar",
    "kurerbarastes": "kurerbar",
    "kurerbarasts": "kurerbar",
    "kurerbare": "kurerbar",
    "kurerbares": "kurerbar",
    "kurerbarheten": "kurerbarhet",
    "kurerbarhetens": "kurerbarhet",
    "kurerbarhets": "kurerbarhet",
    "kurerbars": "kurerbar",
    "kurerbart": "kurerbar",
    "kurerbarts": "kurerbar",
    "kureringar": "kurering",
    "kureringarna": "kurering",
    "kureringarnas": "kurering",
    "kureringars": "kurering",
    "kureringen": "kurering",
    "kureringens": "kurering",
    "kurerings": "kurering",
    "kurerna": "kur",
    "kurernas": "kur",
    "kurers": "kur",
    "kurfurstar": "kurfurste",
    "kurfurstarna": "kurfurste",
    "kurfurstarnas": "kurfurste",
    "kurfurstars": "kurfurste",
    "kurfursten": "kurfurste",
    "kurfurstens": "kurfurste",
    "kurfurstes": "kurfurste",
    "kurganen": "kurgan",
    "kurganens": "kurgan",
    "kurganer": "kurgan",
    "kurganerna": "kurgan",
    "kurganernas": "kurgan",
    "kurganers": "kurgan",
    "kurgans": "kurgan",
    "kurhusen": "kurhus",
    "kurhusens": "kurhus",
    "kurhuset": "kurhus",
    "kurhusets": "kurhus",
    "kuri": "kuria",
    "kurialstilen": "kurialstil",
    "kurialstilens": "kurialstil",
    "kurialstils": "kurialstil",
    "kurian": "kuria",
    "kurians": "kuria",
    "kurias": "kuria",
    "kurie": "kuria",
    "kurior": "kuria",
    "kuriorna": "kuria",
    "kuriornas": "kuria",
    "kuriors": "kuria",
    "kuriosa": "kuriosum",
    "kuriosana": "kuriosum",
    "kuriosanas": "kuriosum",
    "kuriosas": "kuriosum",
    "kuriosaspalten": "kuriosaspalt",
    "kuriosaspaltens": "kuriosaspalt",
    "kuriosaspalter": "kuriosaspalt",
    "kuriosaspalterna": "kuriosaspalt",
    "kuriosaspalternas": "kuriosaspalt",
    "kuriosaspalters": "kuriosaspalt",
    "kuriosaspalts": "kuriosaspalt",
    "kuriositeten": "kuriositet",
    "kuriositetens": "kuriositet",
    "kuriositeter": "kuriositet",
    "kuriositeterna": "kuriositet",
    "kuriositeternas": "kuriositet",
    "kuriositeters": "kuriositet",
    "kuriositets": "kuriositet",
    "kuriosumet": "kuriosum",
    "kuriosumets": "kuriosum",
    "kuriosums": "kuriosum",
    "kuriren": "kurir",
    "kurirens": "kurir",
    "kurirer": "kurir",
    "kurirerna": "kurir",
    "kurirernas": "kurir",
    "kurirers": "kurir",
    "kurirpassen": "kurirpass",
    "kurirpassens": "kurirpass",
    "kurirpasset": "kurirpass",
    "kurirpassets": "kurirpass",
    "kurirresan": "kurirresa",
    "kurirresans": "kurirresa",
    "kurirresas": "kurirresa",
    "kurirrese": "kurirresa",
    "kurirresor": "kurirresa",
    "kurirresorna": "kurirresa",
    "kurirresornas": "kurirresa",
    "kurirresors": "kurirresa",
    "kurirs": "kurir",
    "kurirsäckar": "kurirsäck",
    "kurirsäckarna": "kurirsäck",
    "kurirsäckarnas": "kurirsäck",
    "kurirsäckars": "kurirsäck",
    "kurirsäcken": "kurirsäck",
    "kurirsäckens": "kurirsäck",
    "kurirsäcks": "kurirsäck",
    "kuris": "kuria",
    "kuriösa": "kuriös",
    "kuriösare": "kuriös",
    "kuriösares": "kuriös",
    "kuriösas": "kuriös",
    "kuriösast": "kuriös",
    "kuriösaste": "kuriös",
    "kuriösastes": "kuriös",
    "kuriösasts": "kuriös",
    "kuriöse": "kuriös",
    "kuriöses": "kuriös",
    "kuriöst": "kuriös",
    "kuriösts": "kuriös",
    "kurorten": "kurort",
    "kurortens": "kurort",
    "kurorter": "kurort",
    "kurorterna": "kurort",
    "kurorternas": "kurort",
    "kurorters": "kurort",
    "kurorts": "kurort",
    "kurr": "kurre",
    "kurrade": "kurra",
    "kurrades": "kurra",
    "kurragömmas": "kurragömma",
    "kurran": "kurra",
    "kurrande": "kurra",
    "kurranden": "kurrande",
    "kurrandena": "kurrande",
    "kurrandenas": "kurrande",
    "kurrandens": "kurrande",
    "kurrandes": "kurrande",
    "kurrandet": "kurrande",
    "kurrandets": "kurrande",
    "kurrans": "kurra",
    "kurrar": "kurre",
    "kurrarna": "kurre",
    "kurrarnas": "kurre",
    "kurrars": "kurre",
    "kurras": "kurra",
    "kurrat": "kurra",
    "kurrats": "kurra",
    "kurren": "kurre",
    "kurrens": "kurre",
    "kurres": "kurre",
    "kurret": "kurr",
    "kurrets": "kurr",
    "kurrs": "kurre",
    "kurryn": "kurry",
    "kurryns": "kurry",
    "kurrys": "kurry",
    "kurs": "kursa",
    "kursad": "kursa",
    "kursade": "kursa",
    "kursades": "kursa",
    "kursads": "kursa",
    "kursande": "kursa",
    "kursanden": "kursande",
    "kursandena": "kursande",
    "kursandenas": "kursande",
    "kursandens": "kursande",
    "kursandes": "kursande",
    "kursandet": "kursande",
    "kursandets": "kursande",
    "kursar": "kursare",
    "kursaren": "kursare",
    "kursarens": "kursare",
    "kursares": "kursare",
    "kursarna": "kursare",
    "kursarnas": "kursare",
    "kursas": "kursa",
    "kursat": "kursa",
    "kursats": "kursa",
    "kursbeskrivningar": "kursbeskrivning",
    "kursbeskrivningarna": "kursbeskrivning",
    "kursbeskrivningarnas": "kursbeskrivning",
    "kursbeskrivningars": "kursbeskrivning",
    "kursbeskrivningen": "kursbeskrivning",
    "kursbeskrivningens": "kursbeskrivning",
    "kursbeskrivnings": "kursbeskrivning",
    "kursen": "kurs",
    "kursens": "kurs",
    "kurser": "kurs",
    "kurserade": "kursera",
    "kurserades": "kursera",
    "kurserande": "kursera",
    "kurseranden": "kurserande",
    "kurserandena": "kurserande",
    "kurserandenas": "kurserande",
    "kurserandens": "kurserande",
    "kurserandes": "kurserande",
    "kurserandet": "kurserande",
    "kurserandets": "kurserande",
    "kurserar": "kursera",
    "kurseras": "kursera",
    "kurserat": "kursera",
    "kurserats": "kursera",
    "kurseringar": "kursering",
    "kurseringarna": "kursering",
    "kurseringarnas": "kursering",
    "kurseringars": "kursering",
    "kurseringen": "kursering",
    "kurseringens": "kursering",
    "kurserings": "kursering",
    "kurserna": "kurs",
    "kursernas": "kurs",
    "kursers": "kurs",
    "kursiva": "kursiv",
    "kursivare": "kursiv",
    "kursivares": "kursiv",
    "kursivas": "kursiv",
    "kursivast": "kursiv",
    "kursivaste": "kursiv",
    "kursivastes": "kursiv",
    "kursivasts": "kursiv",
    "kursive": "kursiv",
    "kursiven": "kursiv",
    "kursivens": "kursiv",
    "kursiver": "kursiv",
    "kursiverad": "kursivera",
    "kursiverade": "kursivera",
    "kursiverades": "kursivera",
    "kursiverads": "kursivera",
    "kursiverande": "kursivera",
    "kursiveranden": "kursiverande",
    "kursiverandena": "kursiverande",
    "kursiverandenas": "kursiverande",
    "kursiverandens": "kursiverande",
    "kursiverandes": "kursiverande",
    "kursiverandet": "kursiverande",
    "kursiverandets": "kursiverande",
    "kursiverar": "kursivera",
    "kursiveras": "kursivera",
    "kursiverat": "kursivera",
    "kursiverats": "kursivera",
    "kursiverbara": "kursiverbar",
    "kursiverbarare": "kursiverbar",
    "kursiverbarares": "kursiverbar",
    "kursiverbaras": "kursiverbar",
    "kursiverbarast": "kursiverbar",
    "kursiverbaraste": "kursiverbar",
    "kursiverbarastes": "kursiverbar",
    "kursiverbarasts": "kursiverbar",
    "kursiverbare": "kursiverbar",
    "kursiverbares": "kursiverbar",
    "kursiverbarheten": "kursiverbarhet",
    "kursiverbarhetens": "kursiverbarhet",
    "kursiverbarhets": "kursiverbarhet",
    "kursiverbars": "kursiverbar",
    "kursiverbart": "kursiverbar",
    "kursiverbarts": "kursiverbar",
    "kursiveringar": "kursivering",
    "kursiveringarna": "kursivering",
    "kursiveringarnas": "kursivering",
    "kursiveringars": "kursivering",
    "kursiveringen": "kursivering",
    "kursiveringens": "kursivering",
    "kursiverings": "kursivering",
    "kursiverna": "kursiv",
    "kursivernas": "kursiv",
    "kursivers": "kursiv",
    "kursives": "kursiv",
    "kursivs": "kursiv",
    "kursivt": "kursiv",
    "kursivts": "kursiv",
    "kurskamraten": "kurskamrat",
    "kurskamratens": "kurskamrat",
    "kurskamrater": "kurskamrat",
    "kurskamraterna": "kurskamrat",
    "kurskamraternas": "kurskamrat",
    "kurskamraters": "kurskamrat",
    "kurskamrats": "kurskamrat",
    "kursmässiga": "kursmässig",
    "kursmässigare": "kursmässig",
    "kursmässigares": "kursmässig",
    "kursmässigas": "kursmässig",
    "kursmässigast": "kursmässig",
    "kursmässigaste": "kursmässig",
    "kursmässigastes": "kursmässig",
    "kursmässigasts": "kursmässig",
    "kursmässige": "kursmässig",
    "kursmässiges": "kursmässig",
    "kursmässigs": "kursmässig",
    "kursmässigt": "kursmässig",
    "kursmässigts": "kursmässig",
    "kursnoteringar": "kursnotering",
    "kursnoteringarna": "kursnotering",
    "kursnoteringarnas": "kursnotering",
    "kursnoteringars": "kursnotering",
    "kursnoteringen": "kursnotering",
    "kursnoteringens": "kursnotering",
    "kursnoterings": "kursnotering",
    "kursorer": "kursor",
    "kursorerna": "kursor",
    "kursorernas": "kursor",
    "kursorers": "kursor",
    "kursoriska": "kursorisk",
    "kursoriskare": "kursorisk",
    "kursoriskares": "kursorisk",
    "kursoriskas": "kursorisk",
    "kursoriskast": "kursorisk",
    "kursoriskaste": "kursorisk",
    "kursoriskastes": "kursorisk",
    "kursoriskasts": "kursorisk",
    "kursoriske": "kursorisk",
    "kursoriskes": "kursorisk",
    "kursorisks": "kursorisk",
    "kursoriskt": "kursorisk",
    "kursoriskts": "kursorisk",
    "kursorn": "kursor",
    "kursorns": "kursor",
    "kursors": "kursor",
    "kursplane": "kursplan",
    "kursplanen": "kursplan",
    "kursplanens": "kursplan",
    "kursplaner": "kursplan",
    "kursplanerna": "kursplan",
    "kursplanernas": "kursplan",
    "kursplaners": "kursplan",
    "kursplans": "kursplan",
    "kursstegringar": "kursstegring",
    "kursstegringarna": "kursstegring",
    "kursstegringarnas": "kursstegring",
    "kursstegringars": "kursstegring",
    "kursstegringen": "kursstegring",
    "kursstegringens": "kursstegring",
    "kursstegrings": "kursstegring",
    "kursutvecklingar": "kursutveckling",
    "kursutvecklingarna": "kursutveckling",
    "kursutvecklingarnas": "kursutveckling",
    "kursutvecklingars": "kursutveckling",
    "kursutvecklingen": "kursutveckling",
    "kursutvecklingens": "kursutveckling",
    "kursutvecklings": "kursutveckling",
    "kursändringar": "kursändring",
    "kursändringarna": "kursändring",
    "kursändringarnas": "kursändring",
    "kursändringars": "kursändring",
    "kursändringen": "kursändring",
    "kursändringens": "kursändring",
    "kursändrings": "kursändring",
    "kurtagen": "kurtage",
    "kurtagens": "kurtage",
    "kurtages": "kurtage",
    "kurtaget": "kurtage",
    "kurtagets": "kurtage",
    "kurtisanen": "kurtisan",
    "kurtisanens": "kurtisan",
    "kurtisaner": "kurtisan",
    "kurtisanerna": "kurtisan",
    "kurtisanernas": "kurtisan",
    "kurtisaners": "kurtisan",
    "kurtisans": "kurtisan",
    "kurtisen": "kurtis",
    "kurtisens": "kurtis",
    "kurtiser": "kurtis",
    "kurtiserad": "kurtisera",
    "kurtiserade": "kurtisera",
    "kurtiserades": "kurtisera",
    "kurtiserads": "kurtisera",
    "kurtiserande": "kurtisera",
    "kurtiseranden": "kurtiserande",
    "kurtiserandena": "kurtiserande",
    "kurtiserandenas": "kurtiserande",
    "kurtiserandens": "kurtiserande",
    "kurtiserandes": "kurtiserande",
    "kurtiserandet": "kurtiserande",
    "kurtiserandets": "kurtiserande",
    "kurtiserar": "kurtisera",
    "kurtiseras": "kurtisera",
    "kurtiserat": "kurtisera",
    "kurtiserats": "kurtisera",
    "kurtiserbara": "kurtiserbar",
    "kurtiserbarare": "kurtiserbar",
    "kurtiserbarares": "kurtiserbar",
    "kurtiserbaras": "kurtiserbar",
    "kurtiserbarast": "kurtiserbar",
    "kurtiserbaraste": "kurtiserbar",
    "kurtiserbarastes": "kurtiserbar",
    "kurtiserbarasts": "kurtiserbar",
    "kurtiserbare": "kurtiserbar",
    "kurtiserbares": "kurtiserbar",
    "kurtiserbarheten": "kurtiserbarhet",
    "kurtiserbarhetens": "kurtiserbarhet",
    "kurtiserbarhets": "kurtiserbarhet",
    "kurtiserbars": "kurtiserbar",
    "kurtiserbart": "kurtiserbar",
    "kurtiserbarts": "kurtiserbar",
    "kurtiseringar": "kurtisering",
    "kurtiseringarna": "kurtisering",
    "kurtiseringarnas": "kurtisering",
    "kurtiseringars": "kurtisering",
    "kurtiseringen": "kurtisering",
    "kurtiseringens": "kurtisering",
    "kurtiserings": "kurtisering",
    "kurtiserna": "kurtis",
    "kurtisernas": "kurtis",
    "kurtisers": "kurtis",
    "kurtisören": "kurtisör",
    "kurtisörens": "kurtisör",
    "kurtisörer": "kurtisör",
    "kurtisörerna": "kurtisör",
    "kurtisörernas": "kurtisör",
    "kurtisörers": "kurtisör",
    "kurtisörs": "kurtisör",
    "kurv": "kurva",
    "kurvan": "kurva",
    "kurvans": "kurva",
    "kurvas": "kurva",
    "kurvaturen": "kurvatur",
    "kurvaturens": "kurvatur",
    "kurvaturer": "kurvatur",
    "kurvaturerna": "kurvatur",
    "kurvaturernas": "kurvatur",
    "kurvaturers": "kurvatur",
    "kurvaturs": "kurvatur",
    "kurve": "kurva",
    "kurviga": "kurvig",
    "kurvigare": "kurvig",
    "kurvigares": "kurvig",
    "kurvigas": "kurvig",
    "kurvigast": "kurvig",
    "kurvigaste": "kurvig",
    "kurvigastes": "kurvig",
    "kurvigasts": "kurvig",
    "kurvige": "kurvig",
    "kurviges": "kurvig",
    "kurvigheten": "kurvighet",
    "kurvighetens": "kurvighet",
    "kurvighets": "kurvighet",
    "kurvigs": "kurvig",
    "kurvigt": "kurvig",
    "kurvigts": "kurvig",
    "kurvor": "kurva",
    "kurvorna": "kurva",
    "kurvornas": "kurva",
    "kurvors": "kurva",
    "kurvs": "kurva",
    "kurvstabila": "kurvstabil",
    "kurvstabilare": "kurvstabil",
    "kurvstabilares": "kurvstabil",
    "kurvstabilas": "kurvstabil",
    "kurvstabilast": "kurvstabil",
    "kurvstabilaste": "kurvstabil",
    "kurvstabilastes": "kurvstabil",
    "kurvstabilasts": "kurvstabil",
    "kurvstabile": "kurvstabil",
    "kurvstabiles": "kurvstabil",
    "kurvstabils": "kurvstabil",
    "kurvstabilt": "kurvstabil",
    "kurvstabilts": "kurvstabil",
    "kurvtagningar": "kurvtagning",
    "kurvtagningarna": "kurvtagning",
    "kurvtagningarnas": "kurvtagning",
    "kurvtagningars": "kurvtagning",
    "kurvtagningen": "kurvtagning",
    "kurvtagningens": "kurvtagning",
    "kurvtagnings": "kurvtagning",
    "kurvtekniken": "kurvteknik",
    "kurvteknikens": "kurvteknik",
    "kurvtekniks": "kurvteknik",
    "kus": "kuse",
    "kusar": "kuse",
    "kusarna": "kuse",
    "kusarnas": "kuse",
    "kusars": "kuse",
    "kusch": "kuscha",
    "kuschad": "kuscha",
    "kuschade": "kuscha",
    "kuschades": "kuscha",
    "kuschads": "kuscha",
    "kuschande": "kuscha",
    "kuschanden": "kuschande",
    "kuschandena": "kuschande",
    "kuschandenas": "kuschande",
    "kuschandens": "kuschande",
    "kuschandes": "kuschande",
    "kuschandet": "kuschande",
    "kuschandets": "kuschande",
    "kuschar": "kuscha",
    "kuschas": "kuscha",
    "kuschat": "kuscha",
    "kuschats": "kuscha",
    "kusen": "kuse",
    "kusens": "kuse",
    "kuses": "kuse",
    "kusinen": "kusin",
    "kusinens": "kusin",
    "kusiner": "kusin",
    "kusinerna": "kusin",
    "kusinernas": "kusin",
    "kusiners": "kusin",
    "kusingiften": "kusingifte",
    "kusingiftena": "kusingifte",
    "kusingiftenas": "kusingifte",
    "kusingiftens": "kusingifte",
    "kusingiftes": "kusingifte",
    "kusingiftet": "kusingifte",
    "kusingiftets": "kusingifte",
    "kusins": "kusin",
    "kusinäktenskapen": "kusinäktenskap",
    "kusinäktenskapens": "kusinäktenskap",
    "kusinäktenskapet": "kusinäktenskap",
    "kusinäktenskapets": "kusinäktenskap",
    "kusinäktenskaps": "kusinäktenskap",
    "kusk": "kuska",
    "kuskade": "kuska",
    "kuskades": "kuska",
    "kuskande": "kuska",
    "kuskanden": "kuskande",
    "kuskandena": "kuskande",
    "kuskandenas": "kuskande",
    "kuskandens": "kuskande",
    "kuskandes": "kuskande",
    "kuskandet": "kuskande",
    "kuskandets": "kuskande",
    "kuskar": "kuska",
    "kuskarna": "kusk",
    "kuskarnas": "kusk",
    "kuskars": "kusk",
    "kuskas": "kuska",
    "kuskat": "kuska",
    "kuskats": "kuska",
    "kuskbockar": "kuskbock",
    "kuskbockarna": "kuskbock",
    "kuskbockarnas": "kuskbock",
    "kuskbockars": "kuskbock",
    "kuskbocken": "kuskbock",
    "kuskbockens": "kuskbock",
    "kuskbocks": "kuskbock",
    "kusken": "kusk",
    "kuskens": "kusk",
    "kusks": "kusk",
    "kusliga": "kuslig",
    "kusligare": "kuslig",
    "kusligares": "kuslig",
    "kusligas": "kuslig",
    "kusligast": "kuslig",
    "kusligaste": "kuslig",
    "kusligastes": "kuslig",
    "kusligasts": "kuslig",
    "kuslige": "kuslig",
    "kusliges": "kuslig",
    "kusligheten": "kuslighet",
    "kuslighetens": "kuslighet",
    "kusligheter": "kuslighet",
    "kusligheterna": "kuslighet",
    "kusligheternas": "kuslighet",
    "kusligheters": "kuslighet",
    "kuslighets": "kuslighet",
    "kusligs": "kuslig",
    "kusligt": "kuslig",
    "kusligts": "kuslig",
    "kustartilleriet": "kustartilleri",
    "kustartilleriets": "kustartilleri",
    "kustartilleris": "kustartilleri",
    "kustartillerit": "kustartilleri",
    "kustartillerits": "kustartilleri",
    "kustbandet": "kustband",
    "kustbandets": "kustband",
    "kustbands": "kustband",
    "kustbevakningar": "kustbevakning",
    "kustbevakningarna": "kustbevakning",
    "kustbevakningarnas": "kustbevakning",
    "kustbevakningars": "kustbevakning",
    "kustbevakningen": "kustbevakning",
    "kustbevakningens": "kustbevakning",
    "kustbevaknings": "kustbevakning",
    "kustbygden": "kustbygd",
    "kustbygdens": "kustbygd",
    "kustbygder": "kustbygd",
    "kustbygderna": "kustbygd",
    "kustbygdernas": "kustbygd",
    "kustbygders": "kustbygd",
    "kustbygds": "kustbygd",
    "kusten": "kust",
    "kustens": "kust",
    "kuster": "kust",
    "kusterna": "kust",
    "kusternas": "kust",
    "kusters": "kust",
    "kustfiskar": "kustfisk",
    "kustfiskarna": "kustfisk",
    "kustfiskarnas": "kustfisk",
    "kustfiskars": "kustfisk",
    "kustfisken": "kustfisk",
    "kustfiskens": "kustfisk",
    "kustfisks": "kustfisk",
    "kustflott": "kustflotta",
    "kustflottan": "kustflotta",
    "kustflottans": "kustflotta",
    "kustflottas": "kustflotta",
    "kustflotte": "kustflotta",
    "kustflottor": "kustflotta",
    "kustflottorna": "kustflotta",
    "kustflottornas": "kustflotta",
    "kustflottors": "kustflotta",
    "kustflotts": "kustflotta",
    "kustjägar": "kustjägare",
    "kustjägaren": "kustjägare",
    "kustjägarens": "kustjägare",
    "kustjägares": "kustjägare",
    "kustjägarna": "kustjägare",
    "kustjägarnas": "kustjägare",
    "kustklimatet": "kustklimat",
    "kustklimatets": "kustklimat",
    "kustklimats": "kustklimat",
    "kustlandet": "kustland",
    "kustlandets": "kustland",
    "kustlands": "kustland",
    "kustlinjen": "kustlinje",
    "kustlinjens": "kustlinje",
    "kustlinjer": "kustlinje",
    "kustlinjerna": "kustlinje",
    "kustlinjernas": "kustlinje",
    "kustlinjers": "kustlinje",
    "kustlinjes": "kustlinje",
    "kustoden": "kustod",
    "kustodens": "kustod",
    "kustoder": "kustod",
    "kustoderna": "kustod",
    "kustodernas": "kustod",
    "kustoders": "kustod",
    "kustods": "kustod",
    "kustområden": "kustområde",
    "kustområdena": "kustområde",
    "kustområdenas": "kustområde",
    "kustområdens": "kustområde",
    "kustområdes": "kustområde",
    "kustområdet": "kustområde",
    "kustområdets": "kustområde",
    "kustorten": "kustort",
    "kustortens": "kustort",
    "kustorter": "kustort",
    "kustorterna": "kustort",
    "kustorternas": "kustort",
    "kustorters": "kustort",
    "kustorts": "kustort",
    "kustradion": "kustradio",
    "kustradions": "kustradio",
    "kustradios": "kustradio",
    "kustrems": "kustremsa",
    "kustremsan": "kustremsa",
    "kustremsans": "kustremsa",
    "kustremsas": "kustremsa",
    "kustremse": "kustremsa",
    "kustremsor": "kustremsa",
    "kustremsorna": "kustremsa",
    "kustremsornas": "kustremsa",
    "kustremsors": "kustremsa",
    "kusts": "kust",
    "kustslätten": "kustslätt",
    "kustslättens": "kustslätt",
    "kustslätter": "kustslätt",
    "kustslätterna": "kustslätt",
    "kustslätternas": "kustslätt",
    "kustslätters": "kustslätt",
    "kustslätts": "kustslätt",
    "kuststaden": "kuststad",
    "kuststadens": "kuststad",
    "kuststads": "kuststad",
    "kuststan": "kuststad",
    "kuststans": "kuststad",
    "kuststräck": "kuststräcka",
    "kuststräckan": "kuststräcka",
    "kuststräckans": "kuststräcka",
    "kuststräckas": "kuststräcka",
    "kuststräcke": "kuststräcka",
    "kuststräckor": "kuststräcka",
    "kuststräckorna": "kuststräcka",
    "kuststräckornas": "kuststräcka",
    "kuststräckors": "kuststräcka",
    "kuststräcks": "kuststräcka",
    "kuststäder": "kuststad",
    "kuststäderna": "kuststad",
    "kuststädernas": "kuststad",
    "kuststäders": "kuststad",
    "kusttrafiken": "kusttrafik",
    "kusttrafikens": "kusttrafik",
    "kusttrafiks": "kusttrafik",
    "kut": "kuta",
    "kutade": "kuta",
    "kutades": "kuta",
    "kutande": "kuta",
    "kutanden": "kutande",
    "kutandena": "kutande",
    "kutandenas": "kutande",
    "kutandens": "kutande",
    "kutandes": "kutande",
    "kutandet": "kutande",
    "kutandets": "kutande",
    "kutar": "kuta",
    "kutarna": "kut",
    "kutarnas": "kut",
    "kutars": "kut",
    "kutas": "kuta",
    "kutat": "kuta",
    "kutats": "kuta",
    "kuten": "kut",
    "kutens": "kut",
    "kutiga": "kutig",
    "kutigare": "kutig",
    "kutigares": "kutig",
    "kutigas": "kutig",
    "kutigast": "kutig",
    "kutigaste": "kutig",
    "kutigastes": "kutig",
    "kutigasts": "kutig",
    "kutige": "kutig",
    "kutiges": "kutig",
    "kutigs": "kutig",
    "kutigt": "kutig",
    "kutigts": "kutig",
    "kutryggiga": "kutryggig",
    "kutryggigare": "kutryggig",
    "kutryggigares": "kutryggig",
    "kutryggigas": "kutryggig",
    "kutryggigast": "kutryggig",
    "kutryggigaste": "kutryggig",
    "kutryggigastes": "kutryggig",
    "kutryggigasts": "kutryggig",
    "kutryggige": "kutryggig",
    "kutryggiges": "kutryggig",
    "kutryggigheten": "kutryggighet",
    "kutryggighetens": "kutryggighet",
    "kutryggighets": "kutryggighet",
    "kutryggigs": "kutryggig",
    "kutryggigt": "kutryggig",
    "kutryggigts": "kutryggig",
    "kuts": "kut",
    "kutter": "kuttra",
    "kuttern": "kutter",
    "kutterns": "kutter",
    "kutters": "kutter",
    "kuttersmycken": "kuttersmycke",
    "kuttersmyckena": "kuttersmycke",
    "kuttersmyckenas": "kuttersmycke",
    "kuttersmyckens": "kuttersmycke",
    "kuttersmyckes": "kuttersmycke",
    "kuttersmycket": "kuttersmycke",
    "kuttersmyckets": "kuttersmycke",
    "kuttingar": "kutting",
    "kuttingarna": "kutting",
    "kuttingarnas": "kutting",
    "kuttingars": "kutting",
    "kuttingen": "kutting",
    "kuttingens": "kutting",
    "kuttings": "kutting",
    "kuttrade": "kuttra",
    "kuttrades": "kuttra",
    "kuttrande": "kuttra",
    "kuttranden": "kuttrande",
    "kuttrandena": "kuttrande",
    "kuttrandenas": "kuttrande",
    "kuttrandens": "kuttrande",
    "kuttrandes": "kuttrande",
    "kuttrandet": "kuttrande",
    "kuttrandets": "kuttrande",
    "kuttrar": "kuttra",
    "kuttrarna": "kutter",
    "kuttrarnas": "kutter",
    "kuttrars": "kutter",
    "kuttras": "kuttra",
    "kuttrasjun": "kuttrasju",
    "kuttrasjuna": "kuttrasju",
    "kuttrasjunas": "kuttrasju",
    "kuttrasjuns": "kuttrasju",
    "kuttrasjus": "kuttrasju",
    "kuttrasjut": "kuttrasju",
    "kuttrasjuts": "kuttrasju",
    "kuttrat": "kuttra",
    "kuttrats": "kuttra",
    "kuttret": "kutter",
    "kuttrets": "kutter",
    "kutymen": "kutym",
    "kutymens": "kutym",
    "kutymer": "kutym",
    "kutymerna": "kutym",
    "kutymernas": "kutym",
    "kutymers": "kutym",
    "kutyms": "kutym",
    "kuv": "kuva",
    "kuvad": "kuva",
    "kuvade": "kuva",
    "kuvades": "kuva",
    "kuvads": "kuva",
    "kuvande": "kuva",
    "kuvanden": "kuvande",
    "kuvandena": "kuvande",
    "kuvandenas": "kuvande",
    "kuvandens": "kuvande",
    "kuvandes": "kuvande",
    "kuvandet": "kuvande",
    "kuvandets": "kuvande",
    "kuvar": "kuva",
    "kuvas": "kuva",
    "kuvat": "kuva",
    "kuvats": "kuva",
    "kuvertavgiften": "kuvertavgift",
    "kuvertavgiftens": "kuvertavgift",
    "kuvertavgifter": "kuvertavgift",
    "kuvertavgifterna": "kuvertavgift",
    "kuvertavgifternas": "kuvertavgift",
    "kuvertavgifters": "kuvertavgift",
    "kuvertavgifts": "kuvertavgift",
    "kuvertbröden": "kuvertbröd",
    "kuvertbrödens": "kuvertbröd",
    "kuvertbrödet": "kuvertbröd",
    "kuvertbrödets": "kuvertbröd",
    "kuvertbröds": "kuvertbröd",
    "kuverten": "kuvert",
    "kuvertens": "kuvert",
    "kuverterad": "kuvertera",
    "kuverterade": "kuvertera",
    "kuverterades": "kuvertera",
    "kuverterads": "kuvertera",
    "kuverterande": "kuvertera",
    "kuverteranden": "kuverterande",
    "kuverterandena": "kuverterande",
    "kuverterandenas": "kuverterande",
    "kuverterandens": "kuverterande",
    "kuverterandes": "kuverterande",
    "kuverterandet": "kuverterande",
    "kuverterandets": "kuverterande",
    "kuverterar": "kuvertera",
    "kuverteras": "kuvertera",
    "kuverterat": "kuvertera",
    "kuverterats": "kuvertera",
    "kuverterbara": "kuverterbar",
    "kuverterbarare": "kuverterbar",
    "kuverterbarares": "kuverterbar",
    "kuverterbaras": "kuverterbar",
    "kuverterbarast": "kuverterbar",
    "kuverterbaraste": "kuverterbar",
    "kuverterbarastes": "kuverterbar",
    "kuverterbarasts": "kuverterbar",
    "kuverterbare": "kuverterbar",
    "kuverterbares": "kuverterbar",
    "kuverterbarheten": "kuverterbarhet",
    "kuverterbarhetens": "kuverterbarhet",
    "kuverterbarhets": "kuverterbarhet",
    "kuverterbars": "kuverterbar",
    "kuverterbart": "kuverterbar",
    "kuverterbarts": "kuverterbar",
    "kuverteringar": "kuvertering",
    "kuverteringarna": "kuvertering",
    "kuverteringarnas": "kuvertering",
    "kuverteringars": "kuvertering",
    "kuverteringen": "kuvertering",
    "kuverteringens": "kuvertering",
    "kuverterings": "kuvertering",
    "kuvertet": "kuvert",
    "kuvertets": "kuvert",
    "kuverts": "kuvert",
    "kuvertväsk": "kuvertväska",
    "kuvertväskan": "kuvertväska",
    "kuvertväskans": "kuvertväska",
    "kuvertväskas": "kuvertväska",
    "kuvertväske": "kuvertväska",
    "kuvertväskor": "kuvertväska",
    "kuvertväskorna": "kuvertväska",
    "kuvertväskornas": "kuvertväska",
    "kuvertväskors": "kuvertväska",
    "kuvösen": "kuvös",
    "kuvösens": "kuvös",
    "kuvöser": "kuvös",
    "kuvöserna": "kuvös",
    "kuvösernas": "kuvös",
    "kuvösers": "kuvös",
    "kuwaitiern": "kuwaitier",
    "kuwaitierna": "kuwaitier",
    "kuwaitiernas": "kuwaitier",
    "kuwaitierns": "kuwaitier",
    "kuwaitiers": "kuwaitier",
    "kuwaitiska": "kuwaitisk",
    "kuwaitiskan": "kuwaitiska",
    "kuwaitiskans": "kuwaitiska",
    "kuwaitiskare": "kuwaitisk",
    "kuwaitiskares": "kuwaitisk",
    "kuwaitiskas": "kuwaitiska",
    "kuwaitiskast": "kuwaitisk",
    "kuwaitiskaste": "kuwaitisk",
    "kuwaitiskastes": "kuwaitisk",
    "kuwaitiskasts": "kuwaitisk",
    "kuwaitiske": "kuwaitiska",
    "kuwaitiskes": "kuwaitisk",
    "kuwaitiskor": "kuwaitiska",
    "kuwaitiskorna": "kuwaitiska",
    "kuwaitiskornas": "kuwaitiska",
    "kuwaitiskors": "kuwaitiska",
    "kuwaitisks": "kuwaitisk",
    "kuwaitiskt": "kuwaitisk",
    "kuwaitiskts": "kuwaitisk",
    "kvack": "kvacka",
    "kvackade": "kvacka",
    "kvackades": "kvacka",
    "kvackande": "kvacka",
    "kvackanden": "kvackande",
    "kvackandena": "kvackande",
    "kvackandenas": "kvackande",
    "kvackandens": "kvackande",
    "kvackandes": "kvackande",
    "kvackandet": "kvackande",
    "kvackandets": "kvackande",
    "kvackar": "kvackare",
    "kvackaren": "kvackare",
    "kvackarens": "kvackare",
    "kvackares": "kvackare",
    "kvackarna": "kvackare",
    "kvackarnas": "kvackare",
    "kvackas": "kvacka",
    "kvackat": "kvacka",
    "kvackats": "kvacka",
    "kvacken": "kvack",
    "kvackens": "kvack",
    "kvacket": "kvack",
    "kvackets": "kvack",
    "kvacks": "kvack",
    "kvacksalvar": "kvacksalvare",
    "kvacksalvaren": "kvacksalvare",
    "kvacksalvarens": "kvacksalvare",
    "kvacksalvares": "kvacksalvare",
    "kvacksalvarna": "kvacksalvare",
    "kvacksalvarnas": "kvacksalvare",
    "kvacksalverier": "kvacksalveri",
    "kvacksalverierna": "kvacksalveri",
    "kvacksalveriernas": "kvacksalveri",
    "kvacksalveriers": "kvacksalveri",
    "kvacksalveriet": "kvacksalveri",
    "kvacksalveriets": "kvacksalveri",
    "kvacksalveris": "kvacksalveri",
    "kvacksalverit": "kvacksalveri",
    "kvacksalverits": "kvacksalveri",
    "kvad": "kväda",
    "kvadd": "kvadda",
    "kvaddad": "kvadda",
    "kvaddade": "kvadda",
    "kvaddades": "kvadda",
    "kvaddads": "kvadda",
    "kvaddande": "kvadda",
    "kvaddanden": "kvaddande",
    "kvaddandena": "kvaddande",
    "kvaddandenas": "kvaddande",
    "kvaddandens": "kvaddande",
    "kvaddandes": "kvaddande",
    "kvaddandet": "kvaddande",
    "kvaddandets": "kvaddande",
    "kvaddar": "kvadda",
    "kvaddas": "kvadda",
    "kvaddat": "kvadda",
    "kvaddats": "kvadda",
    "kvade": "kväda",
    "kvadern": "kvader",
    "kvaderns": "kvader",
    "kvaders": "kvader",
    "kvades": "kväda",
    "kvadranten": "kvadrant",
    "kvadrantens": "kvadrant",
    "kvadranter": "kvadrant",
    "kvadranterna": "kvadrant",
    "kvadranternas": "kvadrant",
    "kvadranters": "kvadrant",
    "kvadrants": "kvadrant",
    "kvadrar": "kvader",
    "kvadrarna": "kvader",
    "kvadrarnas": "kvader",
    "kvadrars": "kvader",
    "kvadraten": "kvadrat",
    "kvadratens": "kvadrat",
    "kvadrater": "kvadrat",
    "kvadraterna": "kvadrat",
    "kvadraternas": "kvadrat",
    "kvadraters": "kvadrat",
    "kvadratiska": "kvadratisk",
    "kvadratiskare": "kvadratisk",
    "kvadratiskares": "kvadratisk",
    "kvadratiskas": "kvadratisk",
    "kvadratiskast": "kvadratisk",
    "kvadratiskaste": "kvadratisk",
    "kvadratiskastes": "kvadratisk",
    "kvadratiskasts": "kvadratisk",
    "kvadratiske": "kvadratisk",
    "kvadratiskes": "kvadratisk",
    "kvadratisks": "kvadratisk",
    "kvadratiskt": "kvadratisk",
    "kvadratiskts": "kvadratisk",
    "kvadratkilometern": "kvadratkilometer",
    "kvadratkilometerna": "kvadratkilometer",
    "kvadratkilometernas": "kvadratkilometer",
    "kvadratkilometerns": "kvadratkilometer",
    "kvadratkilometers": "kvadratkilometer",
    "kvadratkilometrar": "kvadratkilometer",
    "kvadratkilometrarna": "kvadratkilometer",
    "kvadratkilometrarnas": "kvadratkilometer",
    "kvadratkilometrars": "kvadratkilometer",
    "kvadratmetern": "kvadratmeter",
    "kvadratmeterna": "kvadratmeter",
    "kvadratmeternas": "kvadratmeter",
    "kvadratmeterns": "kvadratmeter",
    "kvadratmeterprisen": "kvadratmeterpris",
    "kvadratmeterprisens": "kvadratmeterpris",
    "kvadratmeterpriser": "kvadratmeterpris",
    "kvadratmeterpriserna": "kvadratmeterpris",
    "kvadratmeterprisernas": "kvadratmeterpris",
    "kvadratmeterprisers": "kvadratmeterpris",
    "kvadratmeterpriset": "kvadratmeterpris",
    "kvadratmeterprisets": "kvadratmeterpris",
    "kvadratmeters": "kvadratmeter",
    "kvadratmetrar": "kvadratmeter",
    "kvadratmetrarna": "kvadratmeter",
    "kvadratmetrarnas": "kvadratmeter",
    "kvadratmetrars": "kvadratmeter",
    "kvadratroten": "kvadratrot",
    "kvadratrotens": "kvadratrot",
    "kvadratrots": "kvadratrot",
    "kvadratrötter": "kvadratrot",
    "kvadratrötterna": "kvadratrot",
    "kvadratrötternas": "kvadratrot",
    "kvadratrötters": "kvadratrot",
    "kvadrats": "kvadrat",
    "kvadraturen": "kvadratur",
    "kvadraturens": "kvadratur",
    "kvadraturs": "kvadratur",
    "kvadrerad": "kvadrera",
    "kvadrerade": "kvadrera",
    "kvadrerades": "kvadrera",
    "kvadrerads": "kvadrera",
    "kvadrerande": "kvadrera",
    "kvadreranden": "kvadrerande",
    "kvadrerandena": "kvadrerande",
    "kvadrerandenas": "kvadrerande",
    "kvadrerandens": "kvadrerande",
    "kvadrerandes": "kvadrerande",
    "kvadrerandet": "kvadrerande",
    "kvadrerandets": "kvadrerande",
    "kvadrerar": "kvadrera",
    "kvadreras": "kvadrera",
    "kvadrerat": "kvadrera",
    "kvadrerats": "kvadrera",
    "kvadrerbara": "kvadrerbar",
    "kvadrerbarare": "kvadrerbar",
    "kvadrerbarares": "kvadrerbar",
    "kvadrerbaras": "kvadrerbar",
    "kvadrerbarast": "kvadrerbar",
    "kvadrerbaraste": "kvadrerbar",
    "kvadrerbarastes": "kvadrerbar",
    "kvadrerbarasts": "kvadrerbar",
    "kvadrerbare": "kvadrerbar",
    "kvadrerbares": "kvadrerbar",
    "kvadrerbarheten": "kvadrerbarhet",
    "kvadrerbarhetens": "kvadrerbarhet",
    "kvadrerbarhets": "kvadrerbarhet",
    "kvadrerbars": "kvadrerbar",
    "kvadrerbart": "kvadrerbar",
    "kvadrerbarts": "kvadrerbar",
    "kvadreringar": "kvadrering",
    "kvadreringarna": "kvadrering",
    "kvadreringarnas": "kvadrering",
    "kvadreringars": "kvadrering",
    "kvadreringen": "kvadrering",
    "kvadreringens": "kvadrering",
    "kvadrerings": "kvadrering",
    "kvadriljonen": "kvadriljon",
    "kvadriljonens": "kvadriljon",
    "kvadriljoner": "kvadriljon",
    "kvadriljonerna": "kvadriljon",
    "kvadriljonernas": "kvadriljon",
    "kvadriljoners": "kvadriljon",
    "kvadriljons": "kvadriljon",
    "kvadrillionen": "kvadrillion",
    "kvadrillionens": "kvadrillion",
    "kvadrillioner": "kvadrillion",
    "kvadrillionerna": "kvadrillion",
    "kvadrillionernas": "kvadrillion",
    "kvadrillioners": "kvadrillion",
    "kvadrillions": "kvadrillion",
    "kvadrupelalliansen": "kvadrupelallians",
    "kvadrupelalliansens": "kvadrupelallians",
    "kvadrupelallianser": "kvadrupelallians",
    "kvadrupelallianserna": "kvadrupelallians",
    "kvadrupelalliansernas": "kvadrupelallians",
    "kvadrupelalliansers": "kvadrupelallians",
    "kvads": "kväda",
    "kvalade": "kvala",
    "kvalades": "kvala",
    "kvalande": "kvala",
    "kvalanden": "kvalande",
    "kvalandena": "kvalande",
    "kvalandenas": "kvalande",
    "kvalandens": "kvalande",
    "kvalandes": "kvalande",
    "kvalandet": "kvalande",
    "kvalandets": "kvalande",
    "kvalar": "kvala",
    "kvalas": "kvala",
    "kvalat": "kvala",
    "kvalats": "kvala",
    "kvald": "kvälja",
    "kvalda": "kvälja",
    "kvaldas": "kvälja",
    "kvalde": "kvälja",
    "kvaldes": "kvälja",
    "kvalds": "kvälja",
    "kvalen": "kval",
    "kvalens": "kval",
    "kvalet": "kval",
    "kvalets": "kval",
    "kvalfulla": "kvalfull",
    "kvalfullare": "kvalfull",
    "kvalfullares": "kvalfull",
    "kvalfullas": "kvalfull",
    "kvalfullast": "kvalfull",
    "kvalfullaste": "kvalfull",
    "kvalfullastes": "kvalfull",
    "kvalfullasts": "kvalfull",
    "kvalfulle": "kvalfull",
    "kvalfulles": "kvalfull",
    "kvalfullheten": "kvalfullhet",
    "kvalfullhetens": "kvalfullhet",
    "kvalfullhets": "kvalfullhet",
    "kvalfulls": "kvalfull",
    "kvalfullt": "kvalfull",
    "kvalfullts": "kvalfull",
    "kvalfyllda": "kvalfylld",
    "kvalfylldare": "kvalfylld",
    "kvalfylldares": "kvalfylld",
    "kvalfylldas": "kvalfylld",
    "kvalfylldast": "kvalfylld",
    "kvalfylldaste": "kvalfylld",
    "kvalfylldastes": "kvalfylld",
    "kvalfylldasts": "kvalfylld",
    "kvalfyllde": "kvalfylld",
    "kvalfylldes": "kvalfylld",
    "kvalfylldheten": "kvalfylldhet",
    "kvalfylldhetens": "kvalfylldhet",
    "kvalfylldhets": "kvalfylldhet",
    "kvalfyllds": "kvalfylld",
    "kvalfyllt": "kvalfylld",
    "kvalfyllts": "kvalfylld",
    "kvalificerad": "kvalificera",
    "kvalificerade": "kvalificerad",
    "kvalificerades": "kvalificerad",
    "kvalificerads": "kvalificerad",
    "kvalificerande": "kvalificera",
    "kvalificeranden": "kvalificerande",
    "kvalificerandena": "kvalificerande",
    "kvalificerandenas": "kvalificerande",
    "kvalificerandens": "kvalificerande",
    "kvalificerandes": "kvalificerande",
    "kvalificerandet": "kvalificerande",
    "kvalificerandets": "kvalificerande",
    "kvalificerar": "kvalificera",
    "kvalificeras": "kvalificera",
    "kvalificerat": "kvalificerad",
    "kvalificerats": "kvalificerad",
    "kvalificerbara": "kvalificerbar",
    "kvalificerbarare": "kvalificerbar",
    "kvalificerbarares": "kvalificerbar",
    "kvalificerbaras": "kvalificerbar",
    "kvalificerbarast": "kvalificerbar",
    "kvalificerbaraste": "kvalificerbar",
    "kvalificerbarastes": "kvalificerbar",
    "kvalificerbarasts": "kvalificerbar",
    "kvalificerbare": "kvalificerbar",
    "kvalificerbares": "kvalificerbar",
    "kvalificerbarheten": "kvalificerbarhet",
    "kvalificerbarhetens": "kvalificerbarhet",
    "kvalificerbarhets": "kvalificerbarhet",
    "kvalificerbars": "kvalificerbar",
    "kvalificerbart": "kvalificerbar",
    "kvalificerbarts": "kvalificerbar",
    "kvalificeringar": "kvalificering",
    "kvalificeringarna": "kvalificering",
    "kvalificeringarnas": "kvalificering",
    "kvalificeringars": "kvalificering",
    "kvalificeringen": "kvalificering",
    "kvalificeringens": "kvalificering",
    "kvalificerings": "kvalificering",
    "kvalifikationen": "kvalifikation",
    "kvalifikationens": "kvalifikation",
    "kvalifikationer": "kvalifikation",
    "kvalifikationerna": "kvalifikation",
    "kvalifikationernas": "kvalifikation",
    "kvalifikationers": "kvalifikation",
    "kvalifikations": "kvalifikation",
    "kvalifikationsåren": "kvalifikationsår",
    "kvalifikationsårens": "kvalifikationsår",
    "kvalifikationsåret": "kvalifikationsår",
    "kvalifikationsårets": "kvalifikationsår",
    "kvalifikationsårs": "kvalifikationsår",
    "kvalitativa": "kvalitativ",
    "kvalitativare": "kvalitativ",
    "kvalitativares": "kvalitativ",
    "kvalitativas": "kvalitativ",
    "kvalitativast": "kvalitativ",
    "kvalitativaste": "kvalitativ",
    "kvalitativastes": "kvalitativ",
    "kvalitativasts": "kvalitativ",
    "kvalitative": "kvalitativ",
    "kvalitatives": "kvalitativ",
    "kvalitativs": "kvalitativ",
    "kvalitativt": "kvalitativ",
    "kvalitativts": "kvalitativ",
    "kvaliteten": "kvalitet",
    "kvalitetens": "kvalitet",
    "kvaliteter": "kvalitet",
    "kvaliteterna": "kvalitet",
    "kvaliteternas": "kvalitet",
    "kvaliteters": "kvalitet",
    "kvalitets": "kvalitet",
    "kvalitetsarbeten": "kvalitetsarbete",
    "kvalitetsarbetena": "kvalitetsarbete",
    "kvalitetsarbetenas": "kvalitetsarbete",
    "kvalitetsarbetens": "kvalitetsarbete",
    "kvalitetsarbetes": "kvalitetsarbete",
    "kvalitetsarbetet": "kvalitetsarbete",
    "kvalitetsarbetets": "kvalitetsarbete",
    "kvalitetsarbets": "kvalitetsarbete",
    "kvalitetsauktionen": "kvalitetsauktion",
    "kvalitetsauktionens": "kvalitetsauktion",
    "kvalitetsauktioner": "kvalitetsauktion",
    "kvalitetsauktionerna": "kvalitetsauktion",
    "kvalitetsauktionernas": "kvalitetsauktion",
    "kvalitetsauktioners": "kvalitetsauktion",
    "kvalitetsauktions": "kvalitetsauktion",
    "kvalitetsgranskad": "kvalitetsgranska",
    "kvalitetsgranskade": "kvalitetsgranska",
    "kvalitetsgranskades": "kvalitetsgranska",
    "kvalitetsgranskads": "kvalitetsgranska",
    "kvalitetsgranskande": "kvalitetsgranska",
    "kvalitetsgranskanden": "kvalitetsgranskande",
    "kvalitetsgranskandena": "kvalitetsgranskande",
    "kvalitetsgranskandenas": "kvalitetsgranskande",
    "kvalitetsgranskandens": "kvalitetsgranskande",
    "kvalitetsgranskandes": "kvalitetsgranskande",
    "kvalitetsgranskandet": "kvalitetsgranskande",
    "kvalitetsgranskandets": "kvalitetsgranskande",
    "kvalitetsgranskar": "kvalitetsgranska",
    "kvalitetsgranskas": "kvalitetsgranska",
    "kvalitetsgranskat": "kvalitetsgranska",
    "kvalitetsgranskats": "kvalitetsgranska",
    "kvalitetsgranskningar": "kvalitetsgranskning",
    "kvalitetsgranskningarna": "kvalitetsgranskning",
    "kvalitetsgranskningarnas": "kvalitetsgranskning",
    "kvalitetsgranskningars": "kvalitetsgranskning",
    "kvalitetsgranskningen": "kvalitetsgranskning",
    "kvalitetsgranskningens": "kvalitetsgranskning",
    "kvalitetsgransknings": "kvalitetsgranskning",
    "kvalitetsjournalistiken": "kvalitetsjournalistik",
    "kvalitetsjournalistikens": "kvalitetsjournalistik",
    "kvalitetsjournalistiker": "kvalitetsjournalistik",
    "kvalitetsjournalistikerna": "kvalitetsjournalistik",
    "kvalitetsjournalistikernas": "kvalitetsjournalistik",
    "kvalitetsjournalistikers": "kvalitetsjournalistik",
    "kvalitetsjournalistiks": "kvalitetsjournalistik",
    "kvalitetskontrollen": "kvalitetskontroll",
    "kvalitetskontrollens": "kvalitetskontroll",
    "kvalitetskontroller": "kvalitetskontroll",
    "kvalitetskontrollerna": "kvalitetskontroll",
    "kvalitetskontrollernas": "kvalitetskontroll",
    "kvalitetskontrollers": "kvalitetskontroll",
    "kvalitetskontrolls": "kvalitetskontroll",
    "kvalitetskraven": "kvalitetskrav",
    "kvalitetskravens": "kvalitetskrav",
    "kvalitetskravet": "kvalitetskrav",
    "kvalitetskravets": "kvalitetskrav",
    "kvalitetskravs": "kvalitetskrav",
    "kvalitetsmässiga": "kvalitetsmässig",
    "kvalitetsmässigare": "kvalitetsmässig",
    "kvalitetsmässigares": "kvalitetsmässig",
    "kvalitetsmässigas": "kvalitetsmässig",
    "kvalitetsmässigast": "kvalitetsmässig",
    "kvalitetsmässigaste": "kvalitetsmässig",
    "kvalitetsmässigastes": "kvalitetsmässig",
    "kvalitetsmässigasts": "kvalitetsmässig",
    "kvalitetsmässige": "kvalitetsmässig",
    "kvalitetsmässiges": "kvalitetsmässig",
    "kvalitetsmässigs": "kvalitetsmässig",
    "kvalitetsmässigt": "kvalitetsmässig",
    "kvalitetsmässigts": "kvalitetsmässig",
    "kvalitetsnormen": "kvalitetsnorm",
    "kvalitetsnormens": "kvalitetsnorm",
    "kvalitetsnormer": "kvalitetsnorm",
    "kvalitetsnormerna": "kvalitetsnorm",
    "kvalitetsnormernas": "kvalitetsnorm",
    "kvalitetsnormers": "kvalitetsnorm",
    "kvalitetsnorms": "kvalitetsnorm",
    "kvalitetsprodukten": "kvalitetsprodukt",
    "kvalitetsproduktens": "kvalitetsprodukt",
    "kvalitetsprodukter": "kvalitetsprodukt",
    "kvalitetsprodukterna": "kvalitetsprodukt",
    "kvalitetsprodukternas": "kvalitetsprodukt",
    "kvalitetsprodukters": "kvalitetsprodukt",
    "kvalitetsprodukts": "kvalitetsprodukt",
    "kvalitetssäkrad": "kvalitetssäkra",
    "kvalitetssäkrade": "kvalitetssäkra",
    "kvalitetssäkrades": "kvalitetssäkra",
    "kvalitetssäkrads": "kvalitetssäkra",
    "kvalitetssäkrande": "kvalitetssäkra",
    "kvalitetssäkranden": "kvalitetssäkrande",
    "kvalitetssäkrandena": "kvalitetssäkrande",
    "kvalitetssäkrandenas": "kvalitetssäkrande",
    "kvalitetssäkrandens": "kvalitetssäkrande",
    "kvalitetssäkrandes": "kvalitetssäkrande",
    "kvalitetssäkrandet": "kvalitetssäkrande",
    "kvalitetssäkrandets": "kvalitetssäkrande",
    "kvalitetssäkrar": "kvalitetssäkra",
    "kvalitetssäkras": "kvalitetssäkra",
    "kvalitetssäkrat": "kvalitetssäkra",
    "kvalitetssäkrats": "kvalitetssäkra",
    "kvalitetssäkringar": "kvalitetssäkring",
    "kvalitetssäkringarna": "kvalitetssäkring",
    "kvalitetssäkringarnas": "kvalitetssäkring",
    "kvalitetssäkringars": "kvalitetssäkring",
    "kvalitetssäkringen": "kvalitetssäkring",
    "kvalitetssäkringens": "kvalitetssäkring",
    "kvalitetssäkrings": "kvalitetssäkring",
    "kvalitéer": "kvalité",
    "kvalitéerna": "kvalité",
    "kvalitéernas": "kvalité",
    "kvalitéers": "kvalité",
    "kvalitén": "kvalité",
    "kvaliténs": "kvalité",
    "kvalités": "kvalité",
    "kvalmet": "kvalm",
    "kvalmets": "kvalm",
    "kvalmiga": "kvalmig",
    "kvalmigare": "kvalmig",
    "kvalmigares": "kvalmig",
    "kvalmigas": "kvalmig",
    "kvalmigast": "kvalmig",
    "kvalmigaste": "kvalmig",
    "kvalmigastes": "kvalmig",
    "kvalmigasts": "kvalmig",
    "kvalmige": "kvalmig",
    "kvalmiges": "kvalmig",
    "kvalmigheten": "kvalmighet",
    "kvalmighetens": "kvalmighet",
    "kvalmigheter": "kvalmighet",
    "kvalmigheterna": "kvalmighet",
    "kvalmigheternas": "kvalmighet",
    "kvalmigheters": "kvalmighet",
    "kvalmighets": "kvalmighet",
    "kvalmigs": "kvalmig",
    "kvalmigt": "kvalmig",
    "kvalmigts": "kvalmig",
    "kvalms": "kvalm",
    "kvals": "kval",
    "kvalsterna": "kvalster",
    "kvalsternas": "kvalster",
    "kvalsters": "kvalster",
    "kvalstren": "kvalster",
    "kvalstrens": "kvalster",
    "kvalstret": "kvalster",
    "kvalstrets": "kvalster",
    "kvalt": "kvälja",
    "kvalts": "kvälja",
    "kvannen": "kvanne",
    "kvannens": "kvanne",
    "kvannes": "kvanne",
    "kvanta": "kvantum",
    "kvantana": "kvantum",
    "kvantanas": "kvantum",
    "kvantas": "kvantum",
    "kvantelektrodynamiken": "kvantelektrodynamik",
    "kvantelektrodynamikens": "kvantelektrodynamik",
    "kvantelektrodynamiks": "kvantelektrodynamik",
    "kvantfysiken": "kvantfysik",
    "kvantfysikens": "kvantfysik",
    "kvantfysiks": "kvantfysik",
    "kvantifierad": "kvantifiera",
    "kvantifierade": "kvantifiera",
    "kvantifierades": "kvantifiera",
    "kvantifierads": "kvantifiera",
    "kvantifierande": "kvantifiera",
    "kvantifieranden": "kvantifierande",
    "kvantifierandena": "kvantifierande",
    "kvantifierandenas": "kvantifierande",
    "kvantifierandens": "kvantifierande",
    "kvantifierandes": "kvantifierande",
    "kvantifierandet": "kvantifierande",
    "kvantifierandets": "kvantifierande",
    "kvantifierar": "kvantifiera",
    "kvantifieras": "kvantifiera",
    "kvantifierat": "kvantifiera",
    "kvantifierats": "kvantifiera",
    "kvantifierbara": "kvantifierbar",
    "kvantifierbarare": "kvantifierbar",
    "kvantifierbarares": "kvantifierbar",
    "kvantifierbaras": "kvantifierbar",
    "kvantifierbarast": "kvantifierbar",
    "kvantifierbaraste": "kvantifierbar",
    "kvantifierbarastes": "kvantifierbar",
    "kvantifierbarasts": "kvantifierbar",
    "kvantifierbare": "kvantifierbar",
    "kvantifierbares": "kvantifierbar",
    "kvantifierbarheten": "kvantifierbarhet",
    "kvantifierbarhetens": "kvantifierbarhet",
    "kvantifierbarhets": "kvantifierbarhet",
    "kvantifierbars": "kvantifierbar",
    "kvantifierbart": "kvantifierbar",
    "kvantifierbarts": "kvantifierbar",
    "kvantifieringar": "kvantifiering",
    "kvantifieringarna": "kvantifiering",
    "kvantifieringarnas": "kvantifiering",
    "kvantifieringars": "kvantifiering",
    "kvantifieringen": "kvantifiering",
    "kvantifieringens": "kvantifiering",
    "kvantifierings": "kvantifiering",
    "kvantitativa": "kvantitativ",
    "kvantitativare": "kvantitativ",
    "kvantitativares": "kvantitativ",
    "kvantitativas": "kvantitativ",
    "kvantitativast": "kvantitativ",
    "kvantitativaste": "kvantitativ",
    "kvantitativastes": "kvantitativ",
    "kvantitativasts": "kvantitativ",
    "kvantitative": "kvantitativ",
    "kvantitatives": "kvantitativ",
    "kvantitativs": "kvantitativ",
    "kvantitativt": "kvantitativ",
    "kvantitativts": "kvantitativ",
    "kvantiteten": "kvantitet",
    "kvantitetens": "kvantitet",
    "kvantiteter": "kvantitet",
    "kvantiteterna": "kvantitet",
    "kvantiteternas": "kvantitet",
    "kvantiteters": "kvantitet",
    "kvantitets": "kvantitet",
    "kvantitetsteorien": "kvantitetsteori",
    "kvantitetsteoriens": "kvantitetsteori",
    "kvantitetsteorin": "kvantitetsteori",
    "kvantitetsteorins": "kvantitetsteori",
    "kvantitetsteoris": "kvantitetsteori",
    "kvantmekaniken": "kvantmekanik",
    "kvantmekanikens": "kvantmekanik",
    "kvantmekaniks": "kvantmekanik",
    "kvanttalen": "kvanttal",
    "kvanttalens": "kvanttal",
    "kvanttalet": "kvanttal",
    "kvanttalets": "kvanttal",
    "kvanttals": "kvanttal",
    "kvantteorien": "kvantteori",
    "kvantteoriens": "kvantteori",
    "kvantteorin": "kvantteori",
    "kvantteorins": "kvantteori",
    "kvantteoris": "kvantteori",
    "kvantumen": "kvantum",
    "kvantumens": "kvantum",
    "kvantumet": "kvantum",
    "kvantumets": "kvantum",
    "kvantums": "kvantum",
    "kvarblev": "kvarbli",
    "kvarbleve": "kvarbli",
    "kvarblir": "kvarbli",
    "kvarbliv": "kvarbli",
    "kvarbliva": "kvarbli",
    "kvarblivande": "kvarbli",
    "kvarblivanden": "kvarblivande",
    "kvarblivandena": "kvarblivande",
    "kvarblivandenas": "kvarblivande",
    "kvarblivandens": "kvarblivande",
    "kvarblivandes": "kvarblivande",
    "kvarblivandet": "kvarblivande",
    "kvarblivandets": "kvarblivande",
    "kvarblive": "kvarbli",
    "kvarbliven": "kvarbli",
    "kvarblivens": "kvarbli",
    "kvarbliver": "kvarbli",
    "kvarblivet": "kvarbli",
    "kvarblivets": "kvarbli",
    "kvarblivit": "kvarbli",
    "kvarblivna": "kvarbli",
    "kvarblivnas": "kvarbli",
    "kvarblivne": "kvarbli",
    "kvarblivnes": "kvarbli",
    "kvardröj": "kvardröja",
    "kvardröjande": "kvardröja",
    "kvardröjanden": "kvardröjande",
    "kvardröjandena": "kvardröjande",
    "kvardröjandenas": "kvardröjande",
    "kvardröjandens": "kvardröjande",
    "kvardröjandes": "kvardröjande",
    "kvardröjandet": "kvardröjande",
    "kvardröjandets": "kvardröjande",
    "kvardröjas": "kvardröja",
    "kvardröjd": "kvardröja",
    "kvardröjda": "kvardröja",
    "kvardröjdas": "kvardröja",
    "kvardröjde": "kvardröja",
    "kvardröjdes": "kvardröja",
    "kvardröjds": "kvardröja",
    "kvardröjer": "kvardröja",
    "kvardröjes": "kvardröja",
    "kvardröjs": "kvardröja",
    "kvardröjt": "kvardröja",
    "kvardröjts": "kvardröja",
    "kvargen": "kvarg",
    "kvargens": "kvarg",
    "kvarglömda": "kvarglömd",
    "kvarglömdare": "kvarglömd",
    "kvarglömdares": "kvarglömd",
    "kvarglömdas": "kvarglömd",
    "kvarglömdast": "kvarglömd",
    "kvarglömdaste": "kvarglömd",
    "kvarglömdastes": "kvarglömd",
    "kvarglömdasts": "kvarglömd",
    "kvarglömde": "kvarglömd",
    "kvarglömdes": "kvarglömd",
    "kvarglömds": "kvarglömd",
    "kvarglömt": "kvarglömd",
    "kvarglömts": "kvarglömd",
    "kvargs": "kvarg",
    "kvarhåll": "kvarhålla",
    "kvarhållande": "kvarhålla",
    "kvarhållanden": "kvarhållande",
    "kvarhållandena": "kvarhållande",
    "kvarhållandenas": "kvarhållande",
    "kvarhållandens": "kvarhållande",
    "kvarhållandes": "kvarhållande",
    "kvarhållandet": "kvarhållande",
    "kvarhållandets": "kvarhållande",
    "kvarhållas": "kvarhålla",
    "kvarhålle": "kvarhålla",
    "kvarhållen": "kvarhålla",
    "kvarhållens": "kvarhålla",
    "kvarhåller": "kvarhålla",
    "kvarhålles": "kvarhålla",
    "kvarhållet": "kvarhålla",
    "kvarhållets": "kvarhålla",
    "kvarhållit": "kvarhålla",
    "kvarhållits": "kvarhålla",
    "kvarhållna": "kvarhålla",
    "kvarhållnas": "kvarhålla",
    "kvarhållne": "kvarhålla",
    "kvarhållnes": "kvarhålla",
    "kvarhålls": "kvarhålla",
    "kvarhöll": "kvarhålla",
    "kvarhölle": "kvarhålla",
    "kvarhölles": "kvarhålla",
    "kvarhölls": "kvarhålla",
    "kvarkan": "kvarka",
    "kvarkans": "kvarka",
    "kvarkar": "kvark",
    "kvarkarna": "kvark",
    "kvarkarnas": "kvark",
    "kvarkars": "kvark",
    "kvarkas": "kvarka",
    "kvarken": "kvark",
    "kvarkens": "kvark",
    "kvarkklimpar": "kvarkklimp",
    "kvarkklimparna": "kvarkklimp",
    "kvarkklimparnas": "kvarkklimp",
    "kvarkklimpars": "kvarkklimp",
    "kvarkklimpen": "kvarkklimp",
    "kvarkklimpens": "kvarkklimp",
    "kvarkklimps": "kvarkklimp",
    "kvarks": "kvark",
    "kvarlev": "kvarleva",
    "kvarlevan": "kvarleva",
    "kvarlevans": "kvarleva",
    "kvarlevas": "kvarleva",
    "kvarleve": "kvarleva",
    "kvarlevor": "kvarleva",
    "kvarlevorna": "kvarleva",
    "kvarlevornas": "kvarleva",
    "kvarlevors": "kvarleva",
    "kvarlevs": "kvarleva",
    "kvarlämnad": "kvarlämna",
    "kvarlämnade": "kvarlämna",
    "kvarlämnades": "kvarlämna",
    "kvarlämnads": "kvarlämna",
    "kvarlämnande": "kvarlämna",
    "kvarlämnanden": "kvarlämnande",
    "kvarlämnandena": "kvarlämnande",
    "kvarlämnandenas": "kvarlämnande",
    "kvarlämnandens": "kvarlämnande",
    "kvarlämnandes": "kvarlämnande",
    "kvarlämnandet": "kvarlämnande",
    "kvarlämnandets": "kvarlämnande",
    "kvarlämnar": "kvarlämna",
    "kvarlämnas": "kvarlämna",
    "kvarlämnat": "kvarlämna",
    "kvarlämnats": "kvarlämna",
    "kvarlåtenskapen": "kvarlåtenskap",
    "kvarlåtenskapens": "kvarlåtenskap",
    "kvarlåtenskaps": "kvarlåtenskap",
    "kvarnar": "kvarn",
    "kvarnarna": "kvarn",
    "kvarnarnas": "kvarn",
    "kvarnars": "kvarn",
    "kvarndammar": "kvarndamm",
    "kvarndammarna": "kvarndamm",
    "kvarndammarnas": "kvarndamm",
    "kvarndammars": "kvarndamm",
    "kvarndammen": "kvarndamm",
    "kvarndammens": "kvarndamm",
    "kvarndamms": "kvarndamm",
    "kvarnen": "kvarn",
    "kvarnens": "kvarn",
    "kvarnhjulen": "kvarnhjul",
    "kvarnhjulens": "kvarnhjul",
    "kvarnhjulet": "kvarnhjul",
    "kvarnhjulets": "kvarnhjul",
    "kvarnhjuls": "kvarnhjul",
    "kvarns": "kvarn",
    "kvarnstenar": "kvarnsten",
    "kvarnstenarna": "kvarnsten",
    "kvarnstenarnas": "kvarnsten",
    "kvarnstenars": "kvarnsten",
    "kvarnstenen": "kvarnsten",
    "kvarnstenens": "kvarnsten",
    "kvarnstens": "kvarnsten",
    "kvarnving": "kvarnvinge",
    "kvarnvingar": "kvarnvinge",
    "kvarnvingarna": "kvarnvinge",
    "kvarnvingarnas": "kvarnvinge",
    "kvarnvingars": "kvarnvinge",
    "kvarnvingen": "kvarnvinge",
    "kvarnvingens": "kvarnvinge",
    "kvarnvinges": "kvarnvinge",
    "kvarnvings": "kvarnvinge",
    "kvarsittar": "kvarsittare",
    "kvarsittaren": "kvarsittare",
    "kvarsittarens": "kvarsittare",
    "kvarsittares": "kvarsittare",
    "kvarsittarna": "kvarsittare",
    "kvarsittarnas": "kvarsittare",
    "kvarskatten": "kvarskatt",
    "kvarskattens": "kvarskatt",
    "kvarskatter": "kvarskatt",
    "kvarskatterna": "kvarskatt",
    "kvarskatternas": "kvarskatt",
    "kvarskatters": "kvarskatt",
    "kvarskatts": "kvarskatt",
    "kvarstaden": "kvarstad",
    "kvarstadens": "kvarstad",
    "kvarstader": "kvarstad",
    "kvarstaderna": "kvarstad",
    "kvarstadernas": "kvarstad",
    "kvarstaders": "kvarstad",
    "kvarstads": "kvarstad",
    "kvarstann": "kvarstanna",
    "kvarstannad": "kvarstanna",
    "kvarstannade": "kvarstanna",
    "kvarstannades": "kvarstanna",
    "kvarstannads": "kvarstanna",
    "kvarstannande": "kvarstanna",
    "kvarstannanden": "kvarstannande",
    "kvarstannandena": "kvarstannande",
    "kvarstannandenas": "kvarstannande",
    "kvarstannandens": "kvarstannande",
    "kvarstannandes": "kvarstannande",
    "kvarstannandet": "kvarstannande",
    "kvarstannandets": "kvarstannande",
    "kvarstannar": "kvarstanna",
    "kvarstannas": "kvarstanna",
    "kvarstannat": "kvarstanna",
    "kvarstannats": "kvarstanna",
    "kvarstod": "kvarstå",
    "kvarstode": "kvarstå",
    "kvarstodes": "kvarstå",
    "kvarstods": "kvarstå",
    "kvarstående": "kvarstå",
    "kvarståenden": "kvarstående",
    "kvarståendena": "kvarstående",
    "kvarståendenas": "kvarstående",
    "kvarståendens": "kvarstående",
    "kvarståendes": "kvarstående",
    "kvarståendet": "kvarstående",
    "kvarståendets": "kvarstående",
    "kvarstår": "kvarstå",
    "kvarstås": "kvarstå",
    "kvarstått": "kvarstå",
    "kvarståtts": "kvarstå",
    "kvartade": "kvarta",
    "kvartades": "kvarta",
    "kvartalen": "kvartal",
    "kvartalens": "kvartal",
    "kvartalet": "kvartal",
    "kvartalets": "kvartal",
    "kvartals": "kvartal",
    "kvartande": "kvarta",
    "kvartanden": "kvartande",
    "kvartandena": "kvartande",
    "kvartandenas": "kvartande",
    "kvartandens": "kvartande",
    "kvartandes": "kvartande",
    "kvartandet": "kvartande",
    "kvartandets": "kvartande",
    "kvartar": "kvarta",
    "kvartarna": "kvart",
    "kvartarnas": "kvart",
    "kvartars": "kvart",
    "kvartas": "kvarta",
    "kvartat": "kvarta",
    "kvartats": "kvarta",
    "kvarten": "kvart",
    "kvartens": "kvart",
    "kvarter": "kvart",
    "kvarteren": "kvarter",
    "kvarterens": "kvarter",
    "kvarteret": "kvarter",
    "kvarterets": "kvarter",
    "kvartermästar": "kvartermästare",
    "kvartermästaren": "kvartermästare",
    "kvartermästarens": "kvartermästare",
    "kvartermästares": "kvartermästare",
    "kvartermästarna": "kvartermästare",
    "kvartermästarnas": "kvartermästare",
    "kvarterna": "kvart",
    "kvarternas": "kvart",
    "kvarters": "kvarter",
    "kvarterspolisen": "kvarterspolis",
    "kvarterspolisens": "kvarterspolis",
    "kvarterspoliser": "kvarterspolis",
    "kvarterspoliserna": "kvarterspolis",
    "kvarterspolisernas": "kvarterspolis",
    "kvarterspolisers": "kvarterspolis",
    "kvartetten": "kvartett",
    "kvartettens": "kvartett",
    "kvartetter": "kvartett",
    "kvartetterna": "kvartett",
    "kvartetternas": "kvartett",
    "kvartetters": "kvartett",
    "kvartetts": "kvartett",
    "kvartilen": "kvartil",
    "kvartilens": "kvartil",
    "kvartiler": "kvartil",
    "kvartilerna": "kvartil",
    "kvartilernas": "kvartil",
    "kvartilers": "kvartil",
    "kvartils": "kvartil",
    "kvartingar": "kvarting",
    "kvartingarna": "kvarting",
    "kvartingarnas": "kvarting",
    "kvartingars": "kvarting",
    "kvartingen": "kvarting",
    "kvartingens": "kvarting",
    "kvartings": "kvarting",
    "kvartos": "kvarto",
    "kvarts": "kvart",
    "kvartsbuteljen": "kvartsbutelj",
    "kvartsbuteljens": "kvartsbutelj",
    "kvartsbuteljer": "kvartsbutelj",
    "kvartsbuteljerna": "kvartsbutelj",
    "kvartsbuteljernas": "kvartsbutelj",
    "kvartsbuteljers": "kvartsbutelj",
    "kvartsbuteljs": "kvartsbutelj",
    "kvartsen": "kvarts",
    "kvartsens": "kvarts",
    "kvartser": "kvarts",
    "kvartserna": "kvarts",
    "kvartsernas": "kvarts",
    "kvartsers": "kvarts",
    "kvartsfiguren": "kvartsfigur",
    "kvartsfigurens": "kvartsfigur",
    "kvartsfigurer": "kvartsfigur",
    "kvartsfigurerna": "kvartsfigur",
    "kvartsfigurernas": "kvartsfigur",
    "kvartsfigurers": "kvartsfigur",
    "kvartsfigurs": "kvartsfigur",
    "kvartsfinalen": "kvartsfinal",
    "kvartsfinalens": "kvartsfinal",
    "kvartsfinaler": "kvartsfinal",
    "kvartsfinalerna": "kvartsfinal",
    "kvartsfinalernas": "kvartsfinal",
    "kvartsfinalers": "kvartsfinal",
    "kvartsfinals": "kvartsfinal",
    "kvartsiten": "kvartsit",
    "kvartsitens": "kvartsit",
    "kvartsiter": "kvartsit",
    "kvartsiterna": "kvartsit",
    "kvartsiternas": "kvartsit",
    "kvartsiters": "kvartsit",
    "kvartsits": "kvartsit",
    "kvartskristallen": "kvartskristall",
    "kvartskristallens": "kvartskristall",
    "kvartskristaller": "kvartskristall",
    "kvartskristallerna": "kvartskristall",
    "kvartskristallernas": "kvartskristall",
    "kvartskristallers": "kvartskristall",
    "kvartskristalls": "kvartskristall",
    "kvartslamp": "kvartslampa",
    "kvartslampan": "kvartslampa",
    "kvartslampans": "kvartslampa",
    "kvartslampas": "kvartslampa",
    "kvartslampe": "kvartslampa",
    "kvartslampor": "kvartslampa",
    "kvartslamporna": "kvartslampa",
    "kvartslampornas": "kvartslampa",
    "kvartslampors": "kvartslampa",
    "kvartslamps": "kvartslampa",
    "kvartslivskrisen": "kvartslivskris",
    "kvartslivskrisens": "kvartslivskris",
    "kvartslivskriser": "kvartslivskris",
    "kvartslivskriserna": "kvartslivskris",
    "kvartslivskrisernas": "kvartslivskris",
    "kvartslivskrisers": "kvartslivskris",
    "kvartssamtalen": "kvartssamtal",
    "kvartssamtalens": "kvartssamtal",
    "kvartssamtalet": "kvartssamtal",
    "kvartssamtalets": "kvartssamtal",
    "kvartssamtals": "kvartssamtal",
    "kvartssekelgamla": "kvartssekelgammal",
    "kvartssekelgamlas": "kvartssekelgammal",
    "kvartssekelgamle": "kvartssekelgammal",
    "kvartssekelgamles": "kvartssekelgammal",
    "kvartssekelgammals": "kvartssekelgammal",
    "kvartssekelgammalt": "kvartssekelgammal",
    "kvartssekelgammalts": "kvartssekelgammal",
    "kvartssekels": "kvartssekel",
    "kvartsseklen": "kvartssekel",
    "kvartsseklens": "kvartssekel",
    "kvartssekler": "kvartssekel",
    "kvartsseklerna": "kvartssekel",
    "kvartsseklernas": "kvartssekel",
    "kvartsseklers": "kvartssekel",
    "kvartsseklet": "kvartssekel",
    "kvartsseklets": "kvartssekel",
    "kvartstonen": "kvartston",
    "kvartstonens": "kvartston",
    "kvartstoner": "kvartston",
    "kvartstonerna": "kvartston",
    "kvartstonernas": "kvartston",
    "kvartstoners": "kvartston",
    "kvartstons": "kvartston",
    "kvartsuren": "kvartsur",
    "kvartsurens": "kvartsur",
    "kvartsuret": "kvartsur",
    "kvartsurets": "kvartsur",
    "kvartsurs": "kvartsur",
    "kvartärs": "kvartär",
    "kvasaren": "kvasar",
    "kvasarens": "kvasar",
    "kvasarer": "kvasar",
    "kvasarerna": "kvasar",
    "kvasarernas": "kvasar",
    "kvasarers": "kvasar",
    "kvasars": "kvasar",
    "kvasiintellektuella": "kvasiintellektuell",
    "kvasiintellektuellas": "kvasiintellektuell",
    "kvasiintellektuelle": "kvasiintellektuell",
    "kvasiintellektuelles": "kvasiintellektuell",
    "kvasiintellektuells": "kvasiintellektuell",
    "kvasiintellektuellt": "kvasiintellektuell",
    "kvasiintellektuellts": "kvasiintellektuell",
    "kvasikontrakten": "kvasikontrakt",
    "kvasikontraktens": "kvasikontrakt",
    "kvasikontraktet": "kvasikontrakt",
    "kvasikontraktets": "kvasikontrakt",
    "kvasikontrakts": "kvasikontrakt",
    "kvasikristallen": "kvasikristall",
    "kvasikristallens": "kvasikristall",
    "kvasikristaller": "kvasikristall",
    "kvasikristallerna": "kvasikristall",
    "kvasikristallernas": "kvasikristall",
    "kvasikristallers": "kvasikristall",
    "kvasikristalls": "kvasikristall",
    "kvassar": "kvass",
    "kvassarna": "kvass",
    "kvassarnas": "kvass",
    "kvassars": "kvass",
    "kvassen": "kvass",
    "kvassens": "kvass",
    "kvassian": "kvassia",
    "kvassians": "kvassia",
    "kvassias": "kvassia",
    "kvastar": "kvast",
    "kvastarna": "kvast",
    "kvastarnas": "kvast",
    "kvastars": "kvast",
    "kvasten": "kvast",
    "kvastens": "kvast",
    "kvastfeningar": "kvastfening",
    "kvastfeningarna": "kvastfening",
    "kvastfeningarnas": "kvastfening",
    "kvastfeningars": "kvastfening",
    "kvastfeningen": "kvastfening",
    "kvastfeningens": "kvastfening",
    "kvastfenings": "kvastfening",
    "kvastprickar": "kvastprick",
    "kvastprickarna": "kvastprick",
    "kvastprickarnas": "kvastprick",
    "kvastprickars": "kvastprick",
    "kvastpricken": "kvastprick",
    "kvastprickens": "kvastprick",
    "kvastpricks": "kvastprick",
    "kvasts": "kvast",
    "kvastskaften": "kvastskaft",
    "kvastskaftens": "kvastskaft",
    "kvastskaftet": "kvastskaft",
    "kvastskaftets": "kvastskaft",
    "kvastskafts": "kvastskaft",
    "kvava": "kvav",
    "kvavare": "kvav",
    "kvavares": "kvav",
    "kvavas": "kvav",
    "kvavast": "kvav",
    "kvavaste": "kvav",
    "kvavastes": "kvav",
    "kvavasts": "kvav",
    "kvave": "kvav",
    "kvaves": "kvav",
    "kvavheten": "kvavhet",
    "kvavhetens": "kvavhet",
    "kvavhets": "kvavhet",
    "kvavs": "kvav",
    "kvavt": "kvav",
    "kvavts": "kvav",
    "kved": "kvida",
    "kvedar": "kved",
    "kvedarna": "kved",
    "kvedarnas": "kved",
    "kvedars": "kved",
    "kvede": "kvida",
    "kveden": "kved",
    "kvedens": "kved",
    "kveder": "kved",
    "kvederna": "kved",
    "kvedernas": "kved",
    "kveders": "kved",
    "kvedes": "kvida",
    "kveds": "kvida",
    "kverulansen": "kverulans",
    "kverulansens": "kverulans",
    "kverulanten": "kverulant",
    "kverulantens": "kverulant",
    "kverulanter": "kverulant",
    "kverulanterna": "kverulant",
    "kverulanternas": "kverulant",
    "kverulanters": "kverulant",
    "kverulantiska": "kverulantisk",
    "kverulantiskare": "kverulantisk",
    "kverulantiskares": "kverulantisk",
    "kverulantiskas": "kverulantisk",
    "kverulantiskast": "kverulantisk",
    "kverulantiskaste": "kverulantisk",
    "kverulantiskastes": "kverulantisk",
    "kverulantiskasts": "kverulantisk",
    "kverulantiske": "kverulantisk",
    "kverulantiskes": "kverulantisk",
    "kverulantisks": "kverulantisk",
    "kverulantiskt": "kverulantisk",
    "kverulantiskts": "kverulantisk",
    "kverulants": "kverulant",
    "kverulerade": "kverulera",
    "kverulerades": "kverulera",
    "kverulerande": "kverulera",
    "kveruleranden": "kverulerande",
    "kverulerandena": "kverulerande",
    "kverulerandenas": "kverulerande",
    "kverulerandens": "kverulerande",
    "kverulerandes": "kverulerande",
    "kverulerandet": "kverulerande",
    "kverulerandets": "kverulerande",
    "kverulerar": "kverulera",
    "kveruleras": "kverulera",
    "kverulerat": "kverulera",
    "kverulerats": "kverulera",
    "kveruleringar": "kverulering",
    "kveruleringarna": "kverulering",
    "kveruleringarnas": "kverulering",
    "kveruleringars": "kverulering",
    "kveruleringen": "kverulering",
    "kveruleringens": "kverulering",
    "kverulerings": "kverulering",
    "kvicka": "kvick",
    "kvickade": "kvicka",
    "kvickades": "kvicka",
    "kvickande": "kvicka",
    "kvickanden": "kvickande",
    "kvickandena": "kvickande",
    "kvickandenas": "kvickande",
    "kvickandens": "kvickande",
    "kvickandes": "kvickande",
    "kvickandet": "kvickande",
    "kvickandets": "kvickande",
    "kvickar": "kvicka",
    "kvickare": "kvick",
    "kvickares": "kvick",
    "kvickas": "kvicka",
    "kvickast": "kvick",
    "kvickaste": "kvick",
    "kvickastes": "kvick",
    "kvickasts": "kvick",
    "kvickat": "kvicka",
    "kvickats": "kvicka",
    "kvickdraget": "kvickdrag",
    "kvickdragets": "kvickdrag",
    "kvickdrags": "kvickdrag",
    "kvicke": "kvick",
    "kvickes": "kvick",
    "kvickfotade": "kvickfotad",
    "kvickfotades": "kvickfotad",
    "kvickfotads": "kvickfotad",
    "kvickfotat": "kvickfotad",
    "kvickfotats": "kvickfotad",
    "kvickheten": "kvickhet",
    "kvickhetens": "kvickhet",
    "kvickheter": "kvickhet",
    "kvickheterna": "kvickhet",
    "kvickheternas": "kvickhet",
    "kvickheters": "kvickhet",
    "kvickhets": "kvickhet",
    "kvickhuvuden": "kvickhuvud",
    "kvickhuvudena": "kvickhuvud",
    "kvickhuvudenas": "kvickhuvud",
    "kvickhuvudens": "kvickhuvud",
    "kvickhuvudet": "kvickhuvud",
    "kvickhuvudets": "kvickhuvud",
    "kvickhuvuds": "kvickhuvud",
    "kvickroten": "kvickrot",
    "kvickrotens": "kvickrot",
    "kvickrots": "kvickrot",
    "kvicks": "kvick",
    "kvicksanden": "kvicksand",
    "kvicksandens": "kvicksand",
    "kvicksands": "kvicksand",
    "kvicksilverbet": "kvicksilverbeta",
    "kvicksilverbetad": "kvicksilverbeta",
    "kvicksilverbetade": "kvicksilverbeta",
    "kvicksilverbetades": "kvicksilverbeta",
    "kvicksilverbetads": "kvicksilverbeta",
    "kvicksilverbetande": "kvicksilverbeta",
    "kvicksilverbetanden": "kvicksilverbetande",
    "kvicksilverbetandena": "kvicksilverbetande",
    "kvicksilverbetandenas": "kvicksilverbetande",
    "kvicksilverbetandens": "kvicksilverbetande",
    "kvicksilverbetandes": "kvicksilverbetande",
    "kvicksilverbetandet": "kvicksilverbetande",
    "kvicksilverbetandets": "kvicksilverbetande",
    "kvicksilverbetar": "kvicksilverbeta",
    "kvicksilverbetas": "kvicksilverbeta",
    "kvicksilverbetat": "kvicksilverbeta",
    "kvicksilverbetats": "kvicksilverbeta",
    "kvicksilverföreningar": "kvicksilverförening",
    "kvicksilverföreningarna": "kvicksilverförening",
    "kvicksilverföreningarnas": "kvicksilverförening",
    "kvicksilverföreningars": "kvicksilverförening",
    "kvicksilverföreningen": "kvicksilverförening",
    "kvicksilverföreningens": "kvicksilverförening",
    "kvicksilverförenings": "kvicksilverförening",
    "kvicksilvergruv": "kvicksilvergruva",
    "kvicksilvergruvan": "kvicksilvergruva",
    "kvicksilvergruvans": "kvicksilvergruva",
    "kvicksilvergruvas": "kvicksilvergruva",
    "kvicksilvergruve": "kvicksilvergruva",
    "kvicksilvergruvor": "kvicksilvergruva",
    "kvicksilvergruvorna": "kvicksilvergruva",
    "kvicksilvergruvornas": "kvicksilvergruva",
    "kvicksilvergruvors": "kvicksilvergruva",
    "kvicksilvergruvs": "kvicksilvergruva",
    "kvicksilverlamp": "kvicksilverlampa",
    "kvicksilverlampan": "kvicksilverlampa",
    "kvicksilverlampans": "kvicksilverlampa",
    "kvicksilverlampas": "kvicksilverlampa",
    "kvicksilverlampe": "kvicksilverlampa",
    "kvicksilverlampor": "kvicksilverlampa",
    "kvicksilverlamporna": "kvicksilverlampa",
    "kvicksilverlampornas": "kvicksilverlampa",
    "kvicksilverlampors": "kvicksilverlampa",
    "kvicksilverlamps": "kvicksilverlampa",
    "kvicksilverpelar": "kvicksilverpelare",
    "kvicksilverpelaren": "kvicksilverpelare",
    "kvicksilverpelarens": "kvicksilverpelare",
    "kvicksilverpelares": "kvicksilverpelare",
    "kvicksilverpelarna": "kvicksilverpelare",
    "kvicksilverpelarnas": "kvicksilverpelare",
    "kvicksilvers": "kvicksilver",
    "kvicksilvret": "kvicksilver",
    "kvicksilvrets": "kvicksilver",
    "kvickt": "kvick",
    "kvickts": "kvick",
    "kvicktänkta": "kvicktänkt",
    "kvicktänktare": "kvicktänkt",
    "kvicktänktares": "kvicktänkt",
    "kvicktänktas": "kvicktänkt",
    "kvicktänktast": "kvicktänkt",
    "kvicktänktaste": "kvicktänkt",
    "kvicktänktastes": "kvicktänkt",
    "kvicktänktasts": "kvicktänkt",
    "kvicktänkte": "kvicktänkt",
    "kvicktänktes": "kvicktänkt",
    "kvicktänktheten": "kvicktänkthet",
    "kvicktänkthetens": "kvicktänkthet",
    "kvicktänkthets": "kvicktänkthet",
    "kvicktänkts": "kvicktänkt",
    "kvickögda": "kvickögd",
    "kvickögdare": "kvickögd",
    "kvickögdares": "kvickögd",
    "kvickögdas": "kvickögd",
    "kvickögdast": "kvickögd",
    "kvickögdaste": "kvickögd",
    "kvickögdastes": "kvickögd",
    "kvickögdasts": "kvickögd",
    "kvickögde": "kvickögd",
    "kvickögdes": "kvickögd",
    "kvickögdheten": "kvickögdhet",
    "kvickögdhetens": "kvickögdhet",
    "kvickögdhets": "kvickögdhet",
    "kvickögds": "kvickögd",
    "kvickögt": "kvickögd",
    "kvickögts": "kvickögd",
    "kvid": "kvida",
    "kvidade": "kvida",
    "kvidades": "kvida",
    "kvidande": "kvida",
    "kvidanden": "kvidande",
    "kvidandena": "kvidande",
    "kvidandenas": "kvidande",
    "kvidandens": "kvidande",
    "kvidandes": "kvidande",
    "kvidandet": "kvidande",
    "kvidandets": "kvidande",
    "kvidans": "kvidan",
    "kvidas": "kvida",
    "kvidden": "kvidd",
    "kviddens": "kvidd",
    "kvidder": "kvidd",
    "kvidderna": "kvidd",
    "kviddernas": "kvidd",
    "kvidders": "kvidd",
    "kvidds": "kvidd",
    "kvide": "kvida",
    "kvider": "kvida",
    "kvides": "kvida",
    "kvidit": "kvida",
    "kvidits": "kvida",
    "kvids": "kvida",
    "kvietismen": "kvietism",
    "kvietismens": "kvietism",
    "kvietismer": "kvietism",
    "kvietismerna": "kvietism",
    "kvietismernas": "kvietism",
    "kvietismers": "kvietism",
    "kvietisms": "kvietism",
    "kvietistiska": "kvietistisk",
    "kvietistiskas": "kvietistisk",
    "kvietistiske": "kvietistisk",
    "kvietistiskes": "kvietistisk",
    "kvietistisks": "kvietistisk",
    "kvietistiskt": "kvietistisk",
    "kvietistiskts": "kvietistisk",
    "kvig": "kviga",
    "kvigan": "kviga",
    "kvigans": "kviga",
    "kvigas": "kviga",
    "kvige": "kviga",
    "kvigkalvar": "kvigkalv",
    "kvigkalvarna": "kvigkalv",
    "kvigkalvarnas": "kvigkalv",
    "kvigkalvars": "kvigkalv",
    "kvigkalven": "kvigkalv",
    "kvigkalvens": "kvigkalv",
    "kvigkalvs": "kvigkalv",
    "kvigor": "kviga",
    "kvigorna": "kviga",
    "kvigornas": "kviga",
    "kvigors": "kviga",
    "kvigs": "kviga",
    "kvillajabarken": "kvillajabark",
    "kvillajabarkens": "kvillajabark",
    "kvillajabarks": "kvillajabark",
    "kviller": "kvillra",
    "kvillrade": "kvillra",
    "kvillrades": "kvillra",
    "kvillrande": "kvillra",
    "kvillranden": "kvillrande",
    "kvillrandena": "kvillrande",
    "kvillrandenas": "kvillrande",
    "kvillrandens": "kvillrande",
    "kvillrandes": "kvillrande",
    "kvillrandet": "kvillrande",
    "kvillrandets": "kvillrande",
    "kvillrar": "kvillra",
    "kvillras": "kvillra",
    "kvillrat": "kvillra",
    "kvillrats": "kvillra",
    "kvilt": "kvilta",
    "kviltad": "kvilta",
    "kviltade": "kvilta",
    "kviltades": "kvilta",
    "kviltads": "kvilta",
    "kviltande": "kvilta",
    "kviltanden": "kviltande",
    "kviltandena": "kviltande",
    "kviltandenas": "kviltande",
    "kviltandens": "kviltande",
    "kviltandes": "kviltande",
    "kviltandet": "kviltande",
    "kviltandets": "kviltande",
    "kviltar": "kvilta",
    "kviltas": "kvilta",
    "kviltat": "kvilta",
    "kviltats": "kvilta",
    "kvinn": "kvinna",
    "kvinnan": "kvinna",
    "kvinnans": "kvinna",
    "kvinnas": "kvinna",
    "kvinne": "kvinna",
    "kvinnfolken": "kvinnfolk",
    "kvinnfolkens": "kvinnfolk",
    "kvinnfolket": "kvinnfolk",
    "kvinnfolkets": "kvinnfolk",
    "kvinnfolks": "kvinnfolk",
    "kvinnfolksgöras": "kvinnfolksgöra",
    "kvinnfolksgörat": "kvinnfolksgöra",
    "kvinnfolksgörats": "kvinnfolksgöra",
    "kvinnliga": "kvinnlig",
    "kvinnligare": "kvinnlig",
    "kvinnligares": "kvinnlig",
    "kvinnligas": "kvinnlig",
    "kvinnligast": "kvinnlig",
    "kvinnligaste": "kvinnlig",
    "kvinnligastes": "kvinnlig",
    "kvinnligasts": "kvinnlig",
    "kvinnlige": "kvinnlig",
    "kvinnliges": "kvinnlig",
    "kvinnligheten": "kvinnlighet",
    "kvinnlighetens": "kvinnlighet",
    "kvinnlighets": "kvinnlighet",
    "kvinnligs": "kvinnlig",
    "kvinnligt": "kvinnlig",
    "kvinnligts": "kvinnlig",
    "kvinno": "kvinna",
    "kvinnoaffären": "kvinnoaffär",
    "kvinnoaffärens": "kvinnoaffär",
    "kvinnoaffärer": "kvinnoaffär",
    "kvinnoaffärerna": "kvinnoaffär",
    "kvinnoaffärernas": "kvinnoaffär",
    "kvinnoaffärers": "kvinnoaffär",
    "kvinnoaffärs": "kvinnoaffär",
    "kvinnoarbeten": "kvinnoarbete",
    "kvinnoarbetena": "kvinnoarbete",
    "kvinnoarbetenas": "kvinnoarbete",
    "kvinnoarbetens": "kvinnoarbete",
    "kvinnoarbetes": "kvinnoarbete",
    "kvinnoarbetet": "kvinnoarbete",
    "kvinnoarbetets": "kvinnoarbete",
    "kvinnoarbets": "kvinnoarbete",
    "kvinnobenen": "kvinnoben",
    "kvinnobenens": "kvinnoben",
    "kvinnobenet": "kvinnoben",
    "kvinnobenets": "kvinnoben",
    "kvinnobens": "kvinnoben",
    "kvinnobilden": "kvinnobild",
    "kvinnobildens": "kvinnobild",
    "kvinnobilder": "kvinnobild",
    "kvinnobilderna": "kvinnobild",
    "kvinnobildernas": "kvinnobild",
    "kvinnobilders": "kvinnobild",
    "kvinnobilds": "kvinnobild",
    "kvinnobrösten": "kvinnobröst",
    "kvinnobröstens": "kvinnobröst",
    "kvinnobröstet": "kvinnobröst",
    "kvinnobröstets": "kvinnobröst",
    "kvinnobrösts": "kvinnobröst",
    "kvinnodräkten": "kvinnodräkt",
    "kvinnodräktens": "kvinnodräkt",
    "kvinnodräkter": "kvinnodräkt",
    "kvinnodräkterna": "kvinnodräkt",
    "kvinnodräkternas": "kvinnodräkt",
    "kvinnodräkters": "kvinnodräkt",
    "kvinnodräkts": "kvinnodräkt",
    "kvinnofientliga": "kvinnofientlig",
    "kvinnofientligare": "kvinnofientlig",
    "kvinnofientligares": "kvinnofientlig",
    "kvinnofientligas": "kvinnofientlig",
    "kvinnofientligast": "kvinnofientlig",
    "kvinnofientligaste": "kvinnofientlig",
    "kvinnofientligastes": "kvinnofientlig",
    "kvinnofientligasts": "kvinnofientlig",
    "kvinnofientlige": "kvinnofientlig",
    "kvinnofientliges": "kvinnofientlig",
    "kvinnofientligheten": "kvinnofientlighet",
    "kvinnofientlighetens": "kvinnofientlighet",
    "kvinnofientlighets": "kvinnofientlighet",
    "kvinnofientligs": "kvinnofientlig",
    "kvinnofientligt": "kvinnofientlig",
    "kvinnofientligts": "kvinnofientlig",
    "kvinnofriden": "kvinnofrid",
    "kvinnofridens": "kvinnofrid",
    "kvinnofrids": "kvinnofrid",
    "kvinnofridskränkningar": "kvinnofridskränkning",
    "kvinnofridskränkningarna": "kvinnofridskränkning",
    "kvinnofridskränkningarnas": "kvinnofridskränkning",
    "kvinnofridskränkningars": "kvinnofridskränkning",
    "kvinnofridskränkningen": "kvinnofridskränkning",
    "kvinnofridskränkningens": "kvinnofridskränkning",
    "kvinnofridskränknings": "kvinnofridskränkning",
    "kvinnofrisyren": "kvinnofrisyr",
    "kvinnofrisyrens": "kvinnofrisyr",
    "kvinnofrisyrer": "kvinnofrisyr",
    "kvinnofrisyrerna": "kvinnofrisyr",
    "kvinnofrisyrernas": "kvinnofrisyr",
    "kvinnofrisyrers": "kvinnofrisyr",
    "kvinnofrisyrs": "kvinnofrisyr",
    "kvinnofrågan": "kvinnofråga",
    "kvinnofrågans": "kvinnofråga",
    "kvinnofrågas": "kvinnofråga",
    "kvinnofråge": "kvinnofråga",
    "kvinnofrågor": "kvinnofråga",
    "kvinnofrågorna": "kvinnofråga",
    "kvinnofrågornas": "kvinnofråga",
    "kvinnofrågors": "kvinnofråga",
    "kvinnofäll": "kvinnofälla",
    "kvinnofällan": "kvinnofälla",
    "kvinnofällans": "kvinnofälla",
    "kvinnofällas": "kvinnofälla",
    "kvinnofälle": "kvinnofälla",
    "kvinnofällor": "kvinnofälla",
    "kvinnofällorna": "kvinnofälla",
    "kvinnofällornas": "kvinnofälla",
    "kvinnofällors": "kvinnofälla",
    "kvinnofälls": "kvinnofälla",
    "kvinnofängelser": "kvinnofängelse",
    "kvinnofängelserna": "kvinnofängelse",
    "kvinnofängelsernas": "kvinnofängelse",
    "kvinnofängelsers": "kvinnofängelse",
    "kvinnofängelses": "kvinnofängelse",
    "kvinnofängelset": "kvinnofängelse",
    "kvinnofängelsets": "kvinnofängelse",
    "kvinnoförförar": "kvinnoförförare",
    "kvinnoförföraren": "kvinnoförförare",
    "kvinnoförförarens": "kvinnoförförare",
    "kvinnoförförares": "kvinnoförförare",
    "kvinnoförförarna": "kvinnoförförare",
    "kvinnoförförarnas": "kvinnoförförare",
    "kvinnogestalten": "kvinnogestalt",
    "kvinnogestaltens": "kvinnogestalt",
    "kvinnogestalter": "kvinnogestalt",
    "kvinnogestalterna": "kvinnogestalt",
    "kvinnogestalternas": "kvinnogestalt",
    "kvinnogestalters": "kvinnogestalt",
    "kvinnogestalts": "kvinnogestalt",
    "kvinnogravar": "kvinnograv",
    "kvinnogravarna": "kvinnograv",
    "kvinnogravarnas": "kvinnograv",
    "kvinnogravars": "kvinnograv",
    "kvinnograven": "kvinnograv",
    "kvinnogravens": "kvinnograv",
    "kvinnogravs": "kvinnograv",
    "kvinnohusen": "kvinnohus",
    "kvinnohusens": "kvinnohus",
    "kvinnohuset": "kvinnohus",
    "kvinnohusets": "kvinnohus",
    "kvinnoidealen": "kvinnoideal",
    "kvinnoidealens": "kvinnoideal",
    "kvinnoidealet": "kvinnoideal",
    "kvinnoidealets": "kvinnoideal",
    "kvinnoideals": "kvinnoideal",
    "kvinnojouren": "kvinnojour",
    "kvinnojourens": "kvinnojour",
    "kvinnojourer": "kvinnojour",
    "kvinnojourerna": "kvinnojour",
    "kvinnojourernas": "kvinnojour",
    "kvinnojourers": "kvinnojour",
    "kvinnojours": "kvinnojour",
    "kvinnokampen": "kvinnokamp",
    "kvinnokampens": "kvinnokamp",
    "kvinnokamps": "kvinnokamp",
    "kvinnokliniken": "kvinnoklinik",
    "kvinnoklinikens": "kvinnoklinik",
    "kvinnokliniker": "kvinnoklinik",
    "kvinnoklinikerna": "kvinnoklinik",
    "kvinnoklinikernas": "kvinnoklinik",
    "kvinnoklinikers": "kvinnoklinik",
    "kvinnokliniks": "kvinnoklinik",
    "kvinnokläderna": "kvinnokläder",
    "kvinnoklädernas": "kvinnokläder",
    "kvinnokläders": "kvinnokläder",
    "kvinnoklädes": "kvinnokläder",
    "kvinnokläds": "kvinnokläder",
    "kvinnokönet": "kvinnokön",
    "kvinnokönets": "kvinnokön",
    "kvinnoköns": "kvinnokön",
    "kvinnokören": "kvinnokör",
    "kvinnokörens": "kvinnokör",
    "kvinnokörer": "kvinnokör",
    "kvinnokörerna": "kvinnokör",
    "kvinnokörernas": "kvinnokör",
    "kvinnokörers": "kvinnokör",
    "kvinnokörs": "kvinnokör",
    "kvinnolägerna": "kvinnoläger",
    "kvinnolägernas": "kvinnoläger",
    "kvinnolägers": "kvinnoläger",
    "kvinnolägren": "kvinnoläger",
    "kvinnolägrens": "kvinnoläger",
    "kvinnolägret": "kvinnoläger",
    "kvinnolägrets": "kvinnoläger",
    "kvinnoläkar": "kvinnoläkare",
    "kvinnoläkaren": "kvinnoläkare",
    "kvinnoläkarens": "kvinnoläkare",
    "kvinnoläkares": "kvinnoläkare",
    "kvinnoläkarna": "kvinnoläkare",
    "kvinnoläkarnas": "kvinnoläkare",
    "kvinnonamnen": "kvinnonamn",
    "kvinnonamnens": "kvinnonamn",
    "kvinnonamnet": "kvinnonamn",
    "kvinnonamnets": "kvinnonamn",
    "kvinnonamns": "kvinnonamn",
    "kvinnonaturen": "kvinnonatur",
    "kvinnonaturens": "kvinnonatur",
    "kvinnonaturer": "kvinnonatur",
    "kvinnonaturerna": "kvinnonatur",
    "kvinnonaturernas": "kvinnonatur",
    "kvinnonaturers": "kvinnonatur",
    "kvinnonaturs": "kvinnonatur",
    "kvinnoplaggen": "kvinnoplagg",
    "kvinnoplaggens": "kvinnoplagg",
    "kvinnoplagget": "kvinnoplagg",
    "kvinnoplaggets": "kvinnoplagg",
    "kvinnoplaggs": "kvinnoplagg",
    "kvinnopolitiken": "kvinnopolitik",
    "kvinnopolitikens": "kvinnopolitik",
    "kvinnopolitiks": "kvinnopolitik",
    "kvinnopolitiska": "kvinnopolitisk",
    "kvinnopolitiskas": "kvinnopolitisk",
    "kvinnopolitiske": "kvinnopolitisk",
    "kvinnopolitiskes": "kvinnopolitisk",
    "kvinnopolitisks": "kvinnopolitisk",
    "kvinnopolitiskt": "kvinnopolitisk",
    "kvinnopolitiskts": "kvinnopolitisk",
    "kvinnoprästen": "kvinnopräst",
    "kvinnoprästens": "kvinnopräst",
    "kvinnopräster": "kvinnopräst",
    "kvinnoprästerna": "kvinnopräst",
    "kvinnoprästernas": "kvinnopräst",
    "kvinnoprästers": "kvinnopräst",
    "kvinnoprästs": "kvinnopräst",
    "kvinnor": "kvinna",
    "kvinnorna": "kvinna",
    "kvinnornas": "kvinna",
    "kvinnorollen": "kvinnoroll",
    "kvinnorollens": "kvinnoroll",
    "kvinnoroller": "kvinnoroll",
    "kvinnorollerna": "kvinnoroll",
    "kvinnorollernas": "kvinnoroll",
    "kvinnorollers": "kvinnoroll",
    "kvinnorolls": "kvinnoroll",
    "kvinnoroven": "kvinnorov",
    "kvinnorovens": "kvinnorov",
    "kvinnorovet": "kvinnorov",
    "kvinnorovets": "kvinnorov",
    "kvinnorovs": "kvinnorov",
    "kvinnors": "kvinna",
    "kvinnorättsaktivisten": "kvinnorättsaktivist",
    "kvinnorättsaktivistens": "kvinnorättsaktivist",
    "kvinnorättsaktivister": "kvinnorättsaktivist",
    "kvinnorättsaktivisterna": "kvinnorättsaktivist",
    "kvinnorättsaktivisternas": "kvinnorättsaktivist",
    "kvinnorättsaktivisters": "kvinnorättsaktivist",
    "kvinnorättsaktivists": "kvinnorättsaktivist",
    "kvinnorörelsen": "kvinnorörelse",
    "kvinnorörelsens": "kvinnorörelse",
    "kvinnorörelser": "kvinnorörelse",
    "kvinnorörelserna": "kvinnorörelse",
    "kvinnorörelsernas": "kvinnorörelse",
    "kvinnorörelsers": "kvinnorörelse",
    "kvinnorörelses": "kvinnorörelse",
    "kvinnorösten": "kvinnoröst",
    "kvinnoröstens": "kvinnoröst",
    "kvinnoröster": "kvinnoröst",
    "kvinnorösterna": "kvinnoröst",
    "kvinnorösternas": "kvinnoröst",
    "kvinnorösters": "kvinnoröst",
    "kvinnorösts": "kvinnoröst",
    "kvinnosaken": "kvinnosak",
    "kvinnosakens": "kvinnosak",
    "kvinnosaks": "kvinnosak",
    "kvinnosakskvinnan": "kvinnosakskvinna",
    "kvinnosakskvinnans": "kvinnosakskvinna",
    "kvinnosakskvinnas": "kvinnosakskvinna",
    "kvinnosakskvinne": "kvinnosakskvinna",
    "kvinnosakskvinno": "kvinnosakskvinna",
    "kvinnosakskvinnor": "kvinnosakskvinna",
    "kvinnosakskvinnorna": "kvinnosakskvinna",
    "kvinnosakskvinnornas": "kvinnosakskvinna",
    "kvinnosakskvinnors": "kvinnosakskvinna",
    "kvinnosidan": "kvinnosida",
    "kvinnosidans": "kvinnosida",
    "kvinnosidas": "kvinnosida",
    "kvinnosjukdomar": "kvinnosjukdom",
    "kvinnosjukdomarna": "kvinnosjukdom",
    "kvinnosjukdomarnas": "kvinnosjukdom",
    "kvinnosjukdomars": "kvinnosjukdom",
    "kvinnosjukdomen": "kvinnosjukdom",
    "kvinnosjukdomens": "kvinnosjukdom",
    "kvinnosjukdoms": "kvinnosjukdom",
    "kvinnoskulpturen": "kvinnoskulptur",
    "kvinnoskulpturens": "kvinnoskulptur",
    "kvinnoskulpturer": "kvinnoskulptur",
    "kvinnoskulpturerna": "kvinnoskulptur",
    "kvinnoskulpturernas": "kvinnoskulptur",
    "kvinnoskulpturers": "kvinnoskulptur",
    "kvinnoskulpturs": "kvinnoskulptur",
    "kvinnosmycken": "kvinnosmycke",
    "kvinnosmyckena": "kvinnosmycke",
    "kvinnosmyckenas": "kvinnosmycke",
    "kvinnosmyckens": "kvinnosmycke",
    "kvinnosmyckes": "kvinnosmycke",
    "kvinnosmycket": "kvinnosmycke",
    "kvinnosmyckets": "kvinnosmycke",
    "kvinnospråket": "kvinnospråk",
    "kvinnospråkets": "kvinnospråk",
    "kvinnospråks": "kvinnospråk",
    "kvinnotjusar": "kvinnotjusare",
    "kvinnotjusaren": "kvinnotjusare",
    "kvinnotjusarens": "kvinnotjusare",
    "kvinnotjusares": "kvinnotjusare",
    "kvinnotjusarna": "kvinnotjusare",
    "kvinnotjusarnas": "kvinnotjusare",
    "kvinnotyckes": "kvinnotycke",
    "kvinnotycket": "kvinnotycke",
    "kvinnotyckets": "kvinnotycke",
    "kvinnoutbrotten": "kvinnoutbrott",
    "kvinnoutbrottens": "kvinnoutbrott",
    "kvinnoutbrottet": "kvinnoutbrott",
    "kvinnoutbrottets": "kvinnoutbrott",
    "kvinnoutbrotts": "kvinnoutbrott",
    "kvinnovåldet": "kvinnovåld",
    "kvinnovåldets": "kvinnovåld",
    "kvinnovålds": "kvinnovåld",
    "kvinnoöden": "kvinnoöde",
    "kvinnoödena": "kvinnoöde",
    "kvinnoödenas": "kvinnoöde",
    "kvinnoödens": "kvinnoöde",
    "kvinnoödes": "kvinnoöde",
    "kvinnoödet": "kvinnoöde",
    "kvinnoödets": "kvinnoöde",
    "kvinns": "kvinna",
    "kvinnsen": "kvinns",
    "kvinnsens": "kvinns",
    "kvinnset": "kvinns",
    "kvinnsets": "kvinns",
    "kvinten": "kvint",
    "kvintens": "kvint",
    "kvinter": "kvint",
    "kvinterna": "kvint",
    "kvinternas": "kvint",
    "kvinters": "kvint",
    "kvintessensen": "kvintessens",
    "kvintessensens": "kvintessens",
    "kvintetten": "kvintett",
    "kvintettens": "kvintett",
    "kvintetter": "kvintett",
    "kvintetterna": "kvintett",
    "kvintetternas": "kvintett",
    "kvintetters": "kvintett",
    "kvintetts": "kvintett",
    "kvintilerade": "kvintilera",
    "kvintilerades": "kvintilera",
    "kvintilerande": "kvintilera",
    "kvintileranden": "kvintilerande",
    "kvintilerandena": "kvintilerande",
    "kvintilerandenas": "kvintilerande",
    "kvintilerandens": "kvintilerande",
    "kvintilerandes": "kvintilerande",
    "kvintilerandet": "kvintilerande",
    "kvintilerandets": "kvintilerande",
    "kvintilerar": "kvintilera",
    "kvintileras": "kvintilera",
    "kvintilerat": "kvintilera",
    "kvintilerats": "kvintilera",
    "kvintileringar": "kvintilering",
    "kvintileringarna": "kvintilering",
    "kvintileringarnas": "kvintilering",
    "kvintileringars": "kvintilering",
    "kvintileringen": "kvintilering",
    "kvintileringens": "kvintilering",
    "kvintilerings": "kvintilering",
    "kvints": "kvint",
    "kvirr": "kvirra",
    "kvirrade": "kvirra",
    "kvirrades": "kvirra",
    "kvirrande": "kvirra",
    "kvirranden": "kvirrande",
    "kvirrandena": "kvirrande",
    "kvirrandenas": "kvirrande",
    "kvirrandens": "kvirrande",
    "kvirrandes": "kvirrande",
    "kvirrandet": "kvirrande",
    "kvirrandets": "kvirrande",
    "kvirrar": "kvirra",
    "kvirras": "kvirra",
    "kvirrat": "kvirra",
    "kvirrats": "kvirra",
    "kvissl": "kvissla",
    "kvisslan": "kvissla",
    "kvisslans": "kvissla",
    "kvisslas": "kvissla",
    "kvissle": "kvissla",
    "kvissliga": "kvisslig",
    "kvissligare": "kvisslig",
    "kvissligares": "kvisslig",
    "kvissligas": "kvisslig",
    "kvissligast": "kvisslig",
    "kvissligaste": "kvisslig",
    "kvissligastes": "kvisslig",
    "kvissligasts": "kvisslig",
    "kvisslige": "kvisslig",
    "kvissliges": "kvisslig",
    "kvissligheten": "kvisslighet",
    "kvisslighetens": "kvisslighet",
    "kvisslighets": "kvisslighet",
    "kvissligs": "kvisslig",
    "kvissligt": "kvisslig",
    "kvissligts": "kvisslig",
    "kvisslor": "kvissla",
    "kvisslorna": "kvissla",
    "kvisslornas": "kvissla",
    "kvisslors": "kvissla",
    "kvist": "kvista",
    "kvistad": "kvista",
    "kvistade": "kvista",
    "kvistades": "kvista",
    "kvistads": "kvista",
    "kvistande": "kvista",
    "kvistanden": "kvistande",
    "kvistandena": "kvistande",
    "kvistandenas": "kvistande",
    "kvistandens": "kvistande",
    "kvistandes": "kvistande",
    "kvistandet": "kvistande",
    "kvistandets": "kvistande",
    "kvistar": "kvista",
    "kvistarna": "kvist",
    "kvistarnas": "kvist",
    "kvistars": "kvist",
    "kvistas": "kvista",
    "kvistat": "kvista",
    "kvistats": "kvista",
    "kvisten": "kvist",
    "kvistens": "kvist",
    "kvistfria": "kvistfri",
    "kvistfriare": "kvistfri",
    "kvistfriares": "kvistfri",
    "kvistfrias": "kvistfri",
    "kvistfriast": "kvistfri",
    "kvistfriaste": "kvistfri",
    "kvistfriastes": "kvistfri",
    "kvistfriasts": "kvistfri",
    "kvistfrie": "kvistfri",
    "kvistfries": "kvistfri",
    "kvistfris": "kvistfri",
    "kvistfritt": "kvistfri",
    "kvistfritts": "kvistfri",
    "kvisthålen": "kvisthål",
    "kvisthålens": "kvisthål",
    "kvisthålet": "kvisthål",
    "kvisthålets": "kvisthål",
    "kvisthåls": "kvisthål",
    "kvistiga": "kvistig",
    "kvistigare": "kvistig",
    "kvistigares": "kvistig",
    "kvistigas": "kvistig",
    "kvistigast": "kvistig",
    "kvistigaste": "kvistig",
    "kvistigastes": "kvistig",
    "kvistigasts": "kvistig",
    "kvistige": "kvistig",
    "kvistiges": "kvistig",
    "kvistigheten": "kvistighet",
    "kvistighetens": "kvistighet",
    "kvistighets": "kvistighet",
    "kvistigs": "kvistig",
    "kvistigt": "kvistig",
    "kvistigts": "kvistig",
    "kvistlösa": "kvistlös",
    "kvistlösare": "kvistlös",
    "kvistlösares": "kvistlös",
    "kvistlösas": "kvistlös",
    "kvistlösast": "kvistlös",
    "kvistlösaste": "kvistlös",
    "kvistlösastes": "kvistlös",
    "kvistlösasts": "kvistlös",
    "kvistlöse": "kvistlös",
    "kvistlöses": "kvistlös",
    "kvistlösheten": "kvistlöshet",
    "kvistlöshetens": "kvistlöshet",
    "kvistlöshets": "kvistlöshet",
    "kvistlöst": "kvistlös",
    "kvistlösts": "kvistlös",
    "kvistningen": "kvistning",
    "kvistningens": "kvistning",
    "kvistnings": "kvistning",
    "kvistrun": "kvistruna",
    "kvistrunan": "kvistruna",
    "kvistrunans": "kvistruna",
    "kvistrunas": "kvistruna",
    "kvistrune": "kvistruna",
    "kvistrunor": "kvistruna",
    "kvistrunorna": "kvistruna",
    "kvistrunornas": "kvistruna",
    "kvistrunors": "kvistruna",
    "kvistruns": "kvistruna",
    "kvists": "kvist",
    "kvittad": "kvitta",
    "kvittade": "kvitta",
    "kvittades": "kvitta",
    "kvittads": "kvitta",
    "kvittande": "kvitta",
    "kvittanden": "kvittande",
    "kvittandena": "kvittande",
    "kvittandenas": "kvittande",
    "kvittandens": "kvittande",
    "kvittandes": "kvittande",
    "kvittandet": "kvittande",
    "kvittandets": "kvittande",
    "kvittar": "kvitta",
    "kvittas": "kvitta",
    "kvittat": "kvitta",
    "kvittats": "kvitta",
    "kvittena": "kvitten",
    "kvittenas": "kvitten",
    "kvittens": "kvitten",
    "kvittensen": "kvittens",
    "kvittensens": "kvittens",
    "kvittenser": "kvittens",
    "kvittenserna": "kvittens",
    "kvittensernas": "kvittens",
    "kvittensers": "kvittens",
    "kvitter": "kvittra",
    "kvitterad": "kvittera",
    "kvitterade": "kvittera",
    "kvitterades": "kvittera",
    "kvitterads": "kvittera",
    "kvitterande": "kvittera",
    "kvitteranden": "kvitterande",
    "kvitterandena": "kvitterande",
    "kvitterandenas": "kvitterande",
    "kvitterandens": "kvitterande",
    "kvitterandes": "kvitterande",
    "kvitterandet": "kvitterande",
    "kvitterandets": "kvitterande",
    "kvitterar": "kvittera",
    "kvitteras": "kvittera",
    "kvitterat": "kvittera",
    "kvitterats": "kvittera",
    "kvitterbara": "kvitterbar",
    "kvitterbarare": "kvitterbar",
    "kvitterbarares": "kvitterbar",
    "kvitterbaras": "kvitterbar",
    "kvitterbarast": "kvitterbar",
    "kvitterbaraste": "kvitterbar",
    "kvitterbarastes": "kvitterbar",
    "kvitterbarasts": "kvitterbar",
    "kvitterbare": "kvitterbar",
    "kvitterbares": "kvitterbar",
    "kvitterbarheten": "kvitterbarhet",
    "kvitterbarhetens": "kvitterbarhet",
    "kvitterbarhets": "kvitterbarhet",
    "kvitterbars": "kvitterbar",
    "kvitterbart": "kvitterbar",
    "kvitterbarts": "kvitterbar",
    "kvitteringar": "kvittering",
    "kvitteringarna": "kvittering",
    "kvitteringarnas": "kvittering",
    "kvitteringars": "kvittering",
    "kvitteringen": "kvittering",
    "kvitteringens": "kvittering",
    "kvitterings": "kvittering",
    "kvitteringsmålen": "kvitteringsmål",
    "kvitteringsmålens": "kvitteringsmål",
    "kvitteringsmålet": "kvitteringsmål",
    "kvitteringsmålets": "kvitteringsmål",
    "kvitteringsmåls": "kvitteringsmål",
    "kvitters": "kvitter",
    "kvittningar": "kvittning",
    "kvittningarna": "kvittning",
    "kvittningarnas": "kvittning",
    "kvittningars": "kvittning",
    "kvittningen": "kvittning",
    "kvittningens": "kvittning",
    "kvittnings": "kvittning",
    "kvitton": "kvitto",
    "kvittona": "kvitto",
    "kvittonas": "kvitto",
    "kvittons": "kvitto",
    "kvittos": "kvitto",
    "kvittot": "kvitto",
    "kvittots": "kvitto",
    "kvittrade": "kvittra",
    "kvittrades": "kvittra",
    "kvittrande": "kvittra",
    "kvittranden": "kvittrande",
    "kvittrandena": "kvittrande",
    "kvittrandenas": "kvittrande",
    "kvittrandens": "kvittrande",
    "kvittrandes": "kvittrande",
    "kvittrandet": "kvittrande",
    "kvittrandets": "kvittrande",
    "kvittrar": "kvittra",
    "kvittras": "kvittra",
    "kvittrat": "kvittra",
    "kvittrats": "kvittra",
    "kvittret": "kvitter",
    "kvittrets": "kvitter",
    "kvittriga": "kvittrig",
    "kvittrigare": "kvittrig",
    "kvittrigares": "kvittrig",
    "kvittrigas": "kvittrig",
    "kvittrigast": "kvittrig",
    "kvittrigaste": "kvittrig",
    "kvittrigastes": "kvittrig",
    "kvittrigasts": "kvittrig",
    "kvittrige": "kvittrig",
    "kvittriges": "kvittrig",
    "kvittrigheten": "kvittrighet",
    "kvittrighetens": "kvittrighet",
    "kvittrighets": "kvittrighet",
    "kvittrigs": "kvittrig",
    "kvittrigt": "kvittrig",
    "kvittrigts": "kvittrig",
    "kvoten": "kvot",
    "kvotens": "kvot",
    "kvoter": "kvot",
    "kvoterad": "kvotera",
    "kvoterade": "kvotera",
    "kvoterades": "kvotera",
    "kvoterads": "kvotera",
    "kvoterande": "kvotera",
    "kvoteranden": "kvoterande",
    "kvoterandena": "kvoterande",
    "kvoterandenas": "kvoterande",
    "kvoterandens": "kvoterande",
    "kvoterandes": "kvoterande",
    "kvoterandet": "kvoterande",
    "kvoterandets": "kvoterande",
    "kvoterar": "kvotera",
    "kvoteras": "kvotera",
    "kvoterat": "kvotera",
    "kvoterats": "kvotera",
    "kvoterbara": "kvoterbar",
    "kvoterbarare": "kvoterbar",
    "kvoterbarares": "kvoterbar",
    "kvoterbaras": "kvoterbar",
    "kvoterbarast": "kvoterbar",
    "kvoterbaraste": "kvoterbar",
    "kvoterbarastes": "kvoterbar",
    "kvoterbarasts": "kvoterbar",
    "kvoterbare": "kvoterbar",
    "kvoterbares": "kvoterbar",
    "kvoterbarheten": "kvoterbarhet",
    "kvoterbarhetens": "kvoterbarhet",
    "kvoterbarhets": "kvoterbarhet",
    "kvoterbars": "kvoterbar",
    "kvoterbart": "kvoterbar",
    "kvoterbarts": "kvoterbar",
    "kvoteringar": "kvotering",
    "kvoteringarna": "kvotering",
    "kvoteringarnas": "kvotering",
    "kvoteringars": "kvotering",
    "kvoteringen": "kvotering",
    "kvoteringens": "kvotering",
    "kvoterings": "kvotering",
    "kvoterna": "kvot",
    "kvoternas": "kvot",
    "kvoters": "kvot",
    "kvots": "kvot",
    "kväd": "kväda",
    "kvädande": "kväda",
    "kvädanden": "kvädande",
    "kvädandena": "kvädande",
    "kvädandenas": "kvädande",
    "kvädandens": "kvädande",
    "kvädandes": "kvädande",
    "kvädandet": "kvädande",
    "kvädandets": "kvädande",
    "kvädas": "kväda",
    "kvädde": "kväda",
    "kväddes": "kväda",
    "kväde": "kväda",
    "kväden": "kväde",
    "kvädena": "kväde",
    "kvädenas": "kväde",
    "kvädens": "kväde",
    "kväder": "kväda",
    "kvädes": "kväde",
    "kvädet": "kväde",
    "kvädets": "kväde",
    "kvädit": "kväda",
    "kvädits": "kväda",
    "kvädna": "kväda",
    "kvädnas": "kväda",
    "kvädne": "kväda",
    "kvädnes": "kväda",
    "kväds": "kväde",
    "kväk": "kväka",
    "kväkande": "kväka",
    "kväkanden": "kväkande",
    "kväkandena": "kväkande",
    "kväkandenas": "kväkande",
    "kväkandens": "kväkande",
    "kväkandes": "kväkande",
    "kväkandet": "kväkande",
    "kväkandets": "kväkande",
    "kväkar": "kväkare",
    "kväkaren": "kväkare",
    "kväkarens": "kväkare",
    "kväkares": "kväkare",
    "kväkarna": "kväkare",
    "kväkarnas": "kväkare",
    "kväkas": "kväka",
    "kväker": "kväka",
    "kväkes": "kväka",
    "kväks": "kväka",
    "kväkt": "kväka",
    "kväkte": "kväka",
    "kväktes": "kväka",
    "kväkts": "kväka",
    "kvälj": "kvälja",
    "kväljande": "kvälja",
    "kväljanden": "kväljande",
    "kväljandena": "kväljande",
    "kväljandenas": "kväljande",
    "kväljandens": "kväljande",
    "kväljandes": "kväljande",
    "kväljandet": "kväljande",
    "kväljandets": "kväljande",
    "kväljas": "kvälja",
    "kväljer": "kvälja",
    "kväljes": "kvälja",
    "kväljningar": "kväljning",
    "kväljningarna": "kväljning",
    "kväljningarnas": "kväljning",
    "kväljningars": "kväljning",
    "kväljningen": "kväljning",
    "kväljningens": "kväljning",
    "kväljnings": "kväljning",
    "kväljs": "kvälja",
    "kväll": "kvälla",
    "kvällades": "kvällas",
    "kvällande": "kvälla",
    "kvällanden": "kvällande",
    "kvällandena": "kvällande",
    "kvällandenas": "kvällande",
    "kvällandens": "kvällande",
    "kvällandes": "kvällande",
    "kvällandet": "kvällande",
    "kvällandets": "kvällande",
    "kvällar": "kväll",
    "kvällarna": "kväll",
    "kvällarnas": "kväll",
    "kvällars": "kväll",
    "kvällats": "kvällas",
    "kvällde": "kvälla",
    "kvällen": "kväll",
    "kvällens": "kväll",
    "kväller": "kvälla",
    "kvällningar": "kvällning",
    "kvällningarna": "kvällning",
    "kvällningarnas": "kvällning",
    "kvällningars": "kvällning",
    "kvällningen": "kvällning",
    "kvällningens": "kvällning",
    "kvällnings": "kvällning",
    "kvälls": "kväll",
    "kvällsbrisar": "kvällsbris",
    "kvällsbrisarna": "kvällsbris",
    "kvällsbrisarnas": "kvällsbris",
    "kvällsbrisars": "kvällsbris",
    "kvällsbrisen": "kvällsbris",
    "kvällsbrisens": "kvällsbris",
    "kvällsbriser": "kvällsbris",
    "kvällsbriserna": "kvällsbris",
    "kvällsbrisernas": "kvällsbris",
    "kvällsbrisers": "kvällsbris",
    "kvällsdim": "kvällsdimma",
    "kvällsdimman": "kvällsdimma",
    "kvällsdimmans": "kvällsdimma",
    "kvällsdimmas": "kvällsdimma",
    "kvällsdimme": "kvällsdimma",
    "kvällsdimmor": "kvällsdimma",
    "kvällsdimmorna": "kvällsdimma",
    "kvällsdimmornas": "kvällsdimma",
    "kvällsdimmors": "kvällsdimma",
    "kvällsdims": "kvällsdimma",
    "kvällsfärjan": "kvällsfärja",
    "kvällsfärjans": "kvällsfärja",
    "kvällsfärjas": "kvällsfärja",
    "kvällsfärje": "kvällsfärja",
    "kvällsfärjor": "kvällsfärja",
    "kvällsfärjorna": "kvällsfärja",
    "kvällsfärjornas": "kvällsfärja",
    "kvällsfärjors": "kvällsfärja",
    "kvällsföreläsningar": "kvällsföreläsning",
    "kvällsföreläsningarna": "kvällsföreläsning",
    "kvällsföreläsningarnas": "kvällsföreläsning",
    "kvällsföreläsningars": "kvällsföreläsning",
    "kvällsföreläsningen": "kvällsföreläsning",
    "kvällsföreläsningens": "kvällsföreläsning",
    "kvällsföreläsnings": "kvällsföreläsning",
    "kvällsignalen": "kvällsignal",
    "kvällsignalens": "kvällsignal",
    "kvällsignaler": "kvällsignal",
    "kvällsignalerna": "kvällsignal",
    "kvällsignalernas": "kvällsignal",
    "kvällsignalers": "kvällsignal",
    "kvällsignals": "kvällsignal",
    "kvällskursen": "kvällskurs",
    "kvällskursens": "kvällskurs",
    "kvällskurser": "kvällskurs",
    "kvällskurserna": "kvällskurs",
    "kvällskursernas": "kvällskurs",
    "kvällskursers": "kvällskurs",
    "kvällskylan": "kvällskyla",
    "kvällskylans": "kvällskyla",
    "kvällskylas": "kvällskyla",
    "kvällskyle": "kvällskyla",
    "kvällsliga": "kvällslig",
    "kvällsligare": "kvällslig",
    "kvällsligares": "kvällslig",
    "kvällsligas": "kvällslig",
    "kvällsligast": "kvällslig",
    "kvällsligaste": "kvällslig",
    "kvällsligastes": "kvällslig",
    "kvällsligasts": "kvällslig",
    "kvällslige": "kvällslig",
    "kvällsliges": "kvällslig",
    "kvällsligheten": "kvällslighet",
    "kvällslighetens": "kvällslighet",
    "kvällslighets": "kvällslighet",
    "kvällsligs": "kvällslig",
    "kvällsligt": "kvällslig",
    "kvällsligts": "kvällslig",
    "kvällsmaten": "kvällsmat",
    "kvällsmatens": "kvällsmat",
    "kvällsmats": "kvällsmat",
    "kvällsmänniskan": "kvällsmänniska",
    "kvällsmänniskans": "kvällsmänniska",
    "kvällsmänniskas": "kvällsmänniska",
    "kvällsmännisko": "kvällsmänniska",
    "kvällsmänniskor": "kvällsmänniska",
    "kvällsmänniskorna": "kvällsmänniska",
    "kvällsmänniskornas": "kvällsmänniska",
    "kvällsmänniskors": "kvällsmänniska",
    "kvällsmålen": "kvällsmål",
    "kvällsmålens": "kvällsmål",
    "kvällsmålet": "kvällsmål",
    "kvällsmålets": "kvällsmål",
    "kvällsmåls": "kvällsmål",
    "kvällsmåltiden": "kvällsmåltid",
    "kvällsmåltidens": "kvällsmåltid",
    "kvällsmåltider": "kvällsmåltid",
    "kvällsmåltiderna": "kvällsmåltid",
    "kvällsmåltidernas": "kvällsmåltid",
    "kvällsmåltiders": "kvällsmåltid",
    "kvällsmåltids": "kvällsmåltid",
    "kvällssammankomsten": "kvällssammankomst",
    "kvällssammankomstens": "kvällssammankomst",
    "kvällssammankomster": "kvällssammankomst",
    "kvällssammankomsterna": "kvällssammankomst",
    "kvällssammankomsternas": "kvällssammankomst",
    "kvällssammankomsters": "kvällssammankomst",
    "kvällssammankomsts": "kvällssammankomst",
    "kvällsskiften": "kvällsskift",
    "kvällsskiftens": "kvällsskift",
    "kvällsskiftet": "kvällsskift",
    "kvällsskiftets": "kvällsskift",
    "kvällsskifts": "kvällsskift",
    "kvällstidningar": "kvällstidning",
    "kvällstidningarna": "kvällstidning",
    "kvällstidningarnas": "kvällstidning",
    "kvällstidningars": "kvällstidning",
    "kvällstidningen": "kvällstidning",
    "kvällstidningens": "kvällstidning",
    "kvällstidnings": "kvällstidning",
    "kvällstidningsmässiga": "kvällstidningsmässig",
    "kvällstidningsmässigare": "kvällstidningsmässig",
    "kvällstidningsmässigares": "kvällstidningsmässig",
    "kvällstidningsmässigas": "kvällstidningsmässig",
    "kvällstidningsmässigast": "kvällstidningsmässig",
    "kvällstidningsmässigaste": "kvällstidningsmässig",
    "kvällstidningsmässigastes": "kvällstidningsmässig",
    "kvällstidningsmässigasts": "kvällstidningsmässig",
    "kvällstidningsmässige": "kvällstidningsmässig",
    "kvällstidningsmässiges": "kvällstidningsmässig",
    "kvällstidningsmässigs": "kvällstidningsmässig",
    "kvällstidningsmässigt": "kvällstidningsmässig",
    "kvällstidningsmässigts": "kvällstidningsmässig",
    "kvällstidningsrubriken": "kvällstidningsrubrik",
    "kvällstidningsrubrikens": "kvällstidningsrubrik",
    "kvällstidningsrubriker": "kvällstidningsrubrik",
    "kvällstidningsrubrikerna": "kvällstidningsrubrik",
    "kvällstidningsrubrikernas": "kvällstidningsrubrik",
    "kvällstidningsrubrikers": "kvällstidningsrubrik",
    "kvällstidningsrubriks": "kvällstidningsrubrik",
    "kvällsunderhållningar": "kvällsunderhållning",
    "kvällsunderhållningarna": "kvällsunderhållning",
    "kvällsunderhållningarnas": "kvällsunderhållning",
    "kvällsunderhållningars": "kvällsunderhållning",
    "kvällsunderhållningen": "kvällsunderhållning",
    "kvällsunderhållningens": "kvällsunderhållning",
    "kvällsunderhållnings": "kvällsunderhållning",
    "kvällsvarden": "kvällsvard",
    "kvällsvardens": "kvällsvard",
    "kvällsvarder": "kvällsvard",
    "kvällsvarderna": "kvällsvard",
    "kvällsvardernas": "kvällsvard",
    "kvällsvarders": "kvällsvard",
    "kvällsvards": "kvällsvard",
    "kvällsöppens": "kvällsöppen",
    "kvällsöppet": "kvällsöppen",
    "kvällsöppets": "kvällsöppen",
    "kvällsöppna": "kvällsöppen",
    "kvällsöppnare": "kvällsöppen",
    "kvällsöppnares": "kvällsöppen",
    "kvällsöppnas": "kvällsöppen",
    "kvällsöppnast": "kvällsöppen",
    "kvällsöppnaste": "kvällsöppen",
    "kvällsöppnastes": "kvällsöppen",
    "kvällsöppnasts": "kvällsöppen",
    "kvällsöppne": "kvällsöppen",
    "kvällsöppnes": "kvällsöppen",
    "kvällt": "kvälla",
    "kväs": "kväsa",
    "kväsande": "kväsa",
    "kväsanden": "kväsande",
    "kväsandena": "kväsande",
    "kväsandenas": "kväsande",
    "kväsandens": "kväsande",
    "kväsandes": "kväsande",
    "kväsandet": "kväsande",
    "kväsandets": "kväsande",
    "kväsas": "kväsa",
    "kväser": "kväsa",
    "kväses": "kväsa",
    "kväst": "kväsa",
    "kvästa": "kväsa",
    "kvästas": "kväsa",
    "kväste": "kväsa",
    "kvästes": "kväsa",
    "kvästs": "kväsa",
    "kväv": "kväva",
    "kvävande": "kväva",
    "kvävanden": "kvävande",
    "kvävandena": "kvävande",
    "kvävandenas": "kvävande",
    "kvävandens": "kvävande",
    "kvävandes": "kvävande",
    "kvävandet": "kvävande",
    "kvävandets": "kvävande",
    "kvävas": "kväva",
    "kvävd": "kväva",
    "kvävda": "kväva",
    "kvävdas": "kväva",
    "kvävde": "kväva",
    "kvävdes": "kväva",
    "kvävds": "kväva",
    "kvävebalansen": "kvävebalans",
    "kvävebalansens": "kvävebalans",
    "kvävegödselmedels": "kvävegödselmedel",
    "kvävegödselmedlen": "kvävegödselmedel",
    "kvävegödselmedlens": "kvävegödselmedel",
    "kvävegödselmedlet": "kvävegödselmedel",
    "kvävegödselmedlets": "kvävegödselmedel",
    "kväveoxiden": "kväveoxid",
    "kväveoxidens": "kväveoxid",
    "kväveoxider": "kväveoxid",
    "kväveoxiderna": "kväveoxid",
    "kväveoxidernas": "kväveoxid",
    "kväveoxiders": "kväveoxid",
    "kväveoxids": "kväveoxid",
    "kväver": "kväva",
    "kväves": "kväve",
    "kvävet": "kväve",
    "kvävets": "kväve",
    "kvävgasen": "kvävgas",
    "kvävgasens": "kvävgas",
    "kvävningar": "kvävning",
    "kvävningarna": "kvävning",
    "kvävningarnas": "kvävning",
    "kvävningars": "kvävning",
    "kvävningen": "kvävning",
    "kvävningens": "kvävning",
    "kvävnings": "kvävning",
    "kvävningsskadan": "kvävningsskada",
    "kvävningsskadans": "kvävningsskada",
    "kvävningsskadas": "kvävningsskada",
    "kvävningsskade": "kvävningsskada",
    "kvävningsskador": "kvävningsskada",
    "kvävningsskadorna": "kvävningsskada",
    "kvävningsskadornas": "kvävningsskada",
    "kvävningsskadors": "kvävningsskada",
    "kvävs": "kväva",
    "kvävt": "kväva",
    "kvävts": "kväva",
    "kybernetiken": "kybernetik",
    "kybernetikens": "kybernetik",
    "kybernetiker": "kybernetik",
    "kybernetikerna": "kybernetik",
    "kybernetikernas": "kybernetik",
    "kybernetikers": "kybernetik",
    "kybernetiks": "kybernetik",
    "kybernetiska": "kybernetisk",
    "kybernetiskare": "kybernetisk",
    "kybernetiskares": "kybernetisk",
    "kybernetiskas": "kybernetisk",
    "kybernetiskast": "kybernetisk",
    "kybernetiskaste": "kybernetisk",
    "kybernetiskastes": "kybernetisk",
    "kybernetiskasts": "kybernetisk",
    "kybernetiske": "kybernetisk",
    "kybernetiskes": "kybernetisk",
    "kybernetisks": "kybernetisk",
    "kybernetiskt": "kybernetisk",
    "kybernetiskts": "kybernetisk",
    "kycklingar": "kyckling",
    "kycklingarna": "kyckling",
    "kycklingarnas": "kyckling",
    "kycklingars": "kyckling",
    "kycklingen": "kyckling",
    "kycklingens": "kyckling",
    "kycklingmodern": "kycklingmoder",
    "kycklingmoderns": "kycklingmoder",
    "kycklingmoders": "kycklingmoder",
    "kycklingmödrar": "kycklingmoder",
    "kycklingmödrarna": "kycklingmoder",
    "kycklingmödrarnas": "kycklingmoder",
    "kycklingmödrars": "kycklingmoder",
    "kycklings": "kyckling",
    "kyffade": "kyffa",
    "kyffades": "kyffa",
    "kyffande": "kyffa",
    "kyffanden": "kyffande",
    "kyffandena": "kyffande",
    "kyffandenas": "kyffande",
    "kyffandens": "kyffande",
    "kyffandes": "kyffande",
    "kyffandet": "kyffande",
    "kyffandets": "kyffande",
    "kyffar": "kyffa",
    "kyffas": "kyffa",
    "kyffat": "kyffa",
    "kyffats": "kyffa",
    "kyffen": "kyffe",
    "kyffena": "kyffe",
    "kyffenas": "kyffe",
    "kyffens": "kyffe",
    "kyffes": "kyffe",
    "kyffet": "kyffe",
    "kyffets": "kyffe",
    "kyffiga": "kyffig",
    "kyffigare": "kyffig",
    "kyffigares": "kyffig",
    "kyffigas": "kyffig",
    "kyffigast": "kyffig",
    "kyffigaste": "kyffig",
    "kyffigastes": "kyffig",
    "kyffigasts": "kyffig",
    "kyffige": "kyffig",
    "kyffiges": "kyffig",
    "kyffigheten": "kyffighet",
    "kyffighetens": "kyffighet",
    "kyffighets": "kyffighet",
    "kyffigs": "kyffig",
    "kyffigt": "kyffig",
    "kyffigts": "kyffig",
    "kyffs": "kyffe",
    "kyl": "kyla",
    "kylan": "kyla",
    "kylande": "kyla",
    "kylanden": "kylande",
    "kylandena": "kylande",
    "kylandenas": "kylande",
    "kylandens": "kylande",
    "kylandes": "kylande",
    "kylandet": "kylande",
    "kylandets": "kylande",
    "kylans": "kyla",
    "kylar": "kylare",
    "kylaren": "kylare",
    "kylarens": "kylare",
    "kylares": "kylare",
    "kylargallerna": "kylargaller",
    "kylargallernas": "kylargaller",
    "kylargallers": "kylargaller",
    "kylargallren": "kylargaller",
    "kylargallrens": "kylargaller",
    "kylargallret": "kylargaller",
    "kylargallrets": "kylargaller",
    "kylargardinen": "kylargardin",
    "kylargardinens": "kylargardin",
    "kylargardiner": "kylargardin",
    "kylargardinerna": "kylargardin",
    "kylargardinernas": "kylargardin",
    "kylargardiners": "kylargardin",
    "kylargardins": "kylargardin",
    "kylarglykolen": "kylarglykol",
    "kylarglykolens": "kylarglykol",
    "kylarglykoler": "kylarglykol",
    "kylarglykolerna": "kylarglykol",
    "kylarglykolernas": "kylarglykol",
    "kylarglykolers": "kylarglykol",
    "kylarglykols": "kylarglykol",
    "kylarna": "kylare",
    "kylarnas": "kylare",
    "kylars": "kyl",
    "kylarvattens": "kylarvatten",
    "kylarvattnet": "kylarvatten",
    "kylarvattnets": "kylarvatten",
    "kylarvätskan": "kylarvätska",
    "kylarvätskans": "kylarvätska",
    "kylarvätskas": "kylarvätska",
    "kylarvätske": "kylarvätska",
    "kylas": "kyla",
    "kylboxar": "kylbox",
    "kylboxarna": "kylbox",
    "kylboxarnas": "kylbox",
    "kylboxars": "kylbox",
    "kylboxen": "kylbox",
    "kylboxens": "kylbox",
    "kyld": "kyla",
    "kylda": "kyla",
    "kyldas": "kyla",
    "kylde": "kyla",
    "kyldes": "kyla",
    "kyldiskar": "kyldisk",
    "kyldiskarna": "kyldisk",
    "kyldiskarnas": "kyldisk",
    "kyldiskars": "kyldisk",
    "kyldisken": "kyldisk",
    "kyldiskens": "kyldisk",
    "kyldisks": "kyldisk",
    "kylds": "kyla",
    "kylen": "kyl",
    "kylens": "kyl",
    "kyler": "kyla",
    "kyles": "kyla",
    "kylfläktar": "kylfläkt",
    "kylfläktarna": "kylfläkt",
    "kylfläktarnas": "kylfläkt",
    "kylfläktars": "kylfläkt",
    "kylfläkten": "kylfläkt",
    "kylfläktens": "kylfläkt",
    "kylfläkts": "kylfläkt",
    "kylhusen": "kylhus",
    "kylhusens": "kylhus",
    "kylhuset": "kylhus",
    "kylhusets": "kylhus",
    "kyliga": "kylig",
    "kyligare": "kylig",
    "kyligares": "kylig",
    "kyligas": "kylig",
    "kyligast": "kylig",
    "kyligaste": "kylig",
    "kyligastes": "kylig",
    "kyligasts": "kylig",
    "kylige": "kylig",
    "kyliges": "kylig",
    "kyligheten": "kylighet",
    "kylighetens": "kylighet",
    "kyligheter": "kylighet",
    "kyligheterna": "kylighet",
    "kyligheternas": "kylighet",
    "kyligheters": "kylighet",
    "kylighets": "kylighet",
    "kyligs": "kylig",
    "kyligt": "kylig",
    "kyligts": "kylig",
    "kylklampar": "kylklamp",
    "kylklamparna": "kylklamp",
    "kylklamparnas": "kylklamp",
    "kylklampars": "kylklamp",
    "kylklampen": "kylklamp",
    "kylklampens": "kylklamp",
    "kylklamps": "kylklamp",
    "kylkonserven": "kylkonserv",
    "kylkonservens": "kylkonserv",
    "kylkonserver": "kylkonserv",
    "kylkonserverna": "kylkonserv",
    "kylkonservernas": "kylkonserv",
    "kylkonservers": "kylkonserv",
    "kylkonservs": "kylkonserv",
    "kyllagrad": "kyllagra",
    "kyllagrade": "kyllagra",
    "kyllagrades": "kyllagra",
    "kyllagrads": "kyllagra",
    "kyllagrande": "kyllagra",
    "kyllagranden": "kyllagrande",
    "kyllagrandena": "kyllagrande",
    "kyllagrandenas": "kyllagrande",
    "kyllagrandens": "kyllagrande",
    "kyllagrandes": "kyllagrande",
    "kyllagrandet": "kyllagrande",
    "kyllagrandets": "kyllagrande",
    "kyllagrar": "kyllagra",
    "kyllagras": "kyllagra",
    "kyllagrat": "kyllagra",
    "kyllagrats": "kyllagra",
    "kylledningar": "kylledning",
    "kylledningarna": "kylledning",
    "kylledningarnas": "kylledning",
    "kylledningars": "kylledning",
    "kylledningen": "kylledning",
    "kylledningens": "kylledning",
    "kyllednings": "kylledning",
    "kyllerna": "kyller",
    "kyllernas": "kyller",
    "kyllers": "kyller",
    "kyllren": "kyller",
    "kyllrens": "kyller",
    "kyllret": "kyller",
    "kyllrets": "kyller",
    "kylnade": "kylna",
    "kylnades": "kylna",
    "kylnande": "kylna",
    "kylnanden": "kylnande",
    "kylnandena": "kylnande",
    "kylnandenas": "kylnande",
    "kylnandens": "kylnande",
    "kylnandes": "kylnande",
    "kylnandet": "kylnande",
    "kylnandets": "kylnande",
    "kylnar": "kylna",
    "kylnas": "kylna",
    "kylnat": "kylna",
    "kylnats": "kylna",
    "kylningar": "kylning",
    "kylningarna": "kylning",
    "kylningarnas": "kylning",
    "kylningars": "kylning",
    "kylningen": "kylning",
    "kylningens": "kylning",
    "kylnings": "kylning",
    "kyls": "kyla",
    "kylsiga": "kylsig",
    "kylsigare": "kylsig",
    "kylsigares": "kylsig",
    "kylsigas": "kylsig",
    "kylsigast": "kylsig",
    "kylsigaste": "kylsig",
    "kylsigastes": "kylsig",
    "kylsigasts": "kylsig",
    "kylsige": "kylsig",
    "kylsiges": "kylsig",
    "kylsigheten": "kylsighet",
    "kylsighetens": "kylsighet",
    "kylsighets": "kylsighet",
    "kylsigs": "kylsig",
    "kylsigt": "kylsig",
    "kylsigts": "kylsig",
    "kylskadan": "kylskada",
    "kylskadans": "kylskada",
    "kylskadas": "kylskada",
    "kylskade": "kylskada",
    "kylskador": "kylskada",
    "kylskadorna": "kylskada",
    "kylskadornas": "kylskada",
    "kylskadors": "kylskada",
    "kylskåpen": "kylskåp",
    "kylskåpens": "kylskåp",
    "kylskåpet": "kylskåp",
    "kylskåpets": "kylskåp",
    "kylskåps": "kylskåp",
    "kylskåpsdörrar": "kylskåpsdörr",
    "kylskåpsdörrarna": "kylskåpsdörr",
    "kylskåpsdörrarnas": "kylskåpsdörr",
    "kylskåpsdörrars": "kylskåpsdörr",
    "kylskåpsdörren": "kylskåpsdörr",
    "kylskåpsdörrens": "kylskåpsdörr",
    "kylskåpsdörrs": "kylskåpsdörr",
    "kylskåpsgallerna": "kylskåpsgaller",
    "kylskåpsgallernas": "kylskåpsgaller",
    "kylskåpsgallers": "kylskåpsgaller",
    "kylskåpsgallren": "kylskåpsgaller",
    "kylskåpsgallrens": "kylskåpsgaller",
    "kylskåpsgallret": "kylskåpsgaller",
    "kylskåpsgallrets": "kylskåpsgaller",
    "kylslagenheten": "kylslagenhet",
    "kylslagenhetens": "kylslagenhet",
    "kylslagenhets": "kylslagenhet",
    "kylslagens": "kylslagen",
    "kylslaget": "kylslagen",
    "kylslagets": "kylslagen",
    "kylslagna": "kylslagen",
    "kylslagnare": "kylslagen",
    "kylslagnares": "kylslagen",
    "kylslagnas": "kylslagen",
    "kylslagnast": "kylslagen",
    "kylslagnaste": "kylslagen",
    "kylslagnastes": "kylslagen",
    "kylslagnasts": "kylslagen",
    "kylslagne": "kylslagen",
    "kylslagnes": "kylslagen",
    "kylt": "kyla",
    "kylts": "kyla",
    "kylvagnar": "kylvagn",
    "kylvagnarna": "kylvagn",
    "kylvagnarnas": "kylvagn",
    "kylvagnars": "kylvagn",
    "kylvagnen": "kylvagn",
    "kylvagnens": "kylvagn",
    "kylvagns": "kylvagn",
    "kylvattens": "kylvatten",
    "kylvattnet": "kylvatten",
    "kylvattnets": "kylvatten",
    "kylväsk": "kylväska",
    "kylväskan": "kylväska",
    "kylväskans": "kylväska",
    "kylväskas": "kylväska",
    "kylväske": "kylväska",
    "kylväskor": "kylväska",
    "kylväskorna": "kylväska",
    "kylväskornas": "kylväska",
    "kylväskors": "kylväska",
    "kymatie": "kymation",
    "kymatier": "kymation",
    "kymatierna": "kymation",
    "kymatiernas": "kymation",
    "kymatiers": "kymation",
    "kymatiet": "kymation",
    "kymatiets": "kymation",
    "kymatium": "kymation",
    "kymatiums": "kymation",
    "kymiga": "kymig",
    "kymigare": "kymig",
    "kymigares": "kymig",
    "kymigas": "kymig",
    "kymigast": "kymig",
    "kymigaste": "kymig",
    "kymigastes": "kymig",
    "kymigasts": "kymig",
    "kymige": "kymig",
    "kymiges": "kymig",
    "kymigs": "kymig",
    "kymigt": "kymig",
    "kymigts": "kymig",
    "kymografen": "kymograf",
    "kymografens": "kymograf",
    "kymografer": "kymograf",
    "kymograferna": "kymograf",
    "kymografernas": "kymograf",
    "kymografers": "kymograf",
    "kymografs": "kymograf",
    "kymrern": "kymrer",
    "kymrerna": "kymrer",
    "kymrernas": "kymrer",
    "kymrerns": "kymrer",
    "kymrers": "kymrer",
    "kymrisk": "kymriska",
    "kymriskan": "kymriska",
    "kymriskans": "kymriska",
    "kymriskas": "kymriska",
    "kyndeln": "kyndel",
    "kyndelns": "kyndel",
    "kyndels": "kyndel",
    "kyndelsmäss": "kyndelsmässa",
    "kyndelsmässan": "kyndelsmässa",
    "kyndelsmässans": "kyndelsmässa",
    "kyndelsmässas": "kyndelsmässa",
    "kyndelsmässe": "kyndelsmässa",
    "kyndelsmässor": "kyndelsmässa",
    "kyndelsmässorna": "kyndelsmässa",
    "kyndelsmässornas": "kyndelsmässa",
    "kyndelsmässors": "kyndelsmässa",
    "kynikern": "kyniker",
    "kynikerna": "kyniker",
    "kynikernas": "kyniker",
    "kynikerns": "kyniker",
    "kynikers": "kyniker",
    "kyniska": "kynisk",
    "kyniskare": "kynisk",
    "kyniskares": "kynisk",
    "kyniskas": "kynisk",
    "kyniskast": "kynisk",
    "kyniskaste": "kynisk",
    "kyniskastes": "kynisk",
    "kyniskasts": "kynisk",
    "kyniske": "kynisk",
    "kyniskes": "kynisk",
    "kynisks": "kynisk",
    "kyniskt": "kynisk",
    "kyniskts": "kynisk",
    "kynnen": "kynne",
    "kynnena": "kynne",
    "kynnenas": "kynne",
    "kynnens": "kynne",
    "kynnes": "kynne",
    "kynnet": "kynne",
    "kynnets": "kynne",
    "kynns": "kynne",
    "kynologen": "kynolog",
    "kynologens": "kynolog",
    "kynologer": "kynolog",
    "kynologerna": "kynolog",
    "kynologernas": "kynolog",
    "kynologers": "kynolog",
    "kynologien": "kynologi",
    "kynologiens": "kynologi",
    "kynologin": "kynologi",
    "kynologins": "kynologi",
    "kynologis": "kynologi",
    "kynologs": "kynolog",
    "kypar": "kypare",
    "kyparen": "kypare",
    "kyparens": "kypare",
    "kypares": "kypare",
    "kyparna": "kypare",
    "kyparnas": "kypare",
    "kypars": "kyp",
    "kypen": "kyp",
    "kypens": "kyp",
    "kypertar": "kypert",
    "kypertarna": "kypert",
    "kypertarnas": "kypert",
    "kypertars": "kypert",
    "kyperten": "kypert",
    "kypertens": "kypert",
    "kyperts": "kypert",
    "kyprad": "kypra",
    "kyprade": "kypra",
    "kyprades": "kypra",
    "kyprads": "kypra",
    "kyprande": "kypra",
    "kypranden": "kyprande",
    "kyprandena": "kyprande",
    "kyprandenas": "kyprande",
    "kyprandens": "kyprande",
    "kyprandes": "kyprande",
    "kyprandet": "kyprande",
    "kyprandets": "kyprande",
    "kyprar": "kypra",
    "kypras": "kypra",
    "kyprat": "kypra",
    "kyprats": "kypra",
    "kyps": "kyp",
    "kyrassen": "kyrass",
    "kyrassens": "kyrass",
    "kyrasser": "kyrass",
    "kyrasserna": "kyrass",
    "kyrassernas": "kyrass",
    "kyrassers": "kyrass",
    "kyrassiären": "kyrassiär",
    "kyrassiärens": "kyrassiär",
    "kyrassiärer": "kyrassiär",
    "kyrassiärerna": "kyrassiär",
    "kyrassiärernas": "kyrassiär",
    "kyrassiärers": "kyrassiär",
    "kyrassiärs": "kyrassiär",
    "kyrassjären": "kyrassjär",
    "kyrassjärens": "kyrassjär",
    "kyrassjärer": "kyrassjär",
    "kyrassjärerna": "kyrassjär",
    "kyrassjärernas": "kyrassjär",
    "kyrassjärers": "kyrassjär",
    "kyrassjärs": "kyrassjär",
    "kyrilliska": "kyrillisk",
    "kyrilliskare": "kyrillisk",
    "kyrilliskares": "kyrillisk",
    "kyrilliskas": "kyrillisk",
    "kyrilliskast": "kyrillisk",
    "kyrilliskaste": "kyrillisk",
    "kyrilliskastes": "kyrillisk",
    "kyrilliskasts": "kyrillisk",
    "kyrilliske": "kyrillisk",
    "kyrilliskes": "kyrillisk",
    "kyrillisks": "kyrillisk",
    "kyrilliskt": "kyrillisk",
    "kyrilliskts": "kyrillisk",
    "kyrk": "kyrka",
    "kyrkan": "kyrka",
    "kyrkans": "kyrka",
    "kyrkas": "kyrka",
    "kyrkback": "kyrkbacke",
    "kyrkbackar": "kyrkbacke",
    "kyrkbackarna": "kyrkbacke",
    "kyrkbackarnas": "kyrkbacke",
    "kyrkbackars": "kyrkbacke",
    "kyrkbacken": "kyrkbacke",
    "kyrkbackens": "kyrkbacke",
    "kyrkbackes": "kyrkbacke",
    "kyrkbacks": "kyrkbacke",
    "kyrkbesöken": "kyrkbesök",
    "kyrkbesökens": "kyrkbesök",
    "kyrkbesöket": "kyrkbesök",
    "kyrkbesökets": "kyrkbesök",
    "kyrkbesöks": "kyrkbesök",
    "kyrkbibeln": "kyrkbibel",
    "kyrkbibelns": "kyrkbibel",
    "kyrkbibels": "kyrkbibel",
    "kyrkbiblar": "kyrkbibel",
    "kyrkbiblarna": "kyrkbibel",
    "kyrkbiblarnas": "kyrkbibel",
    "kyrkbiblars": "kyrkbibel",
    "kyrkboken": "kyrkbok",
    "kyrkbokens": "kyrkbok",
    "kyrkbokför": "kyrkbokföra",
    "kyrkbokförande": "kyrkbokföra",
    "kyrkbokföranden": "kyrkbokförande",
    "kyrkbokförandena": "kyrkbokförande",
    "kyrkbokförandenas": "kyrkbokförande",
    "kyrkbokförandens": "kyrkbokförande",
    "kyrkbokförandes": "kyrkbokförande",
    "kyrkbokförandet": "kyrkbokförande",
    "kyrkbokförandets": "kyrkbokförande",
    "kyrkbokföras": "kyrkbokföra",
    "kyrkbokförd": "kyrkbokföra",
    "kyrkbokförda": "kyrkbokföra",
    "kyrkbokfördas": "kyrkbokföra",
    "kyrkbokförde": "kyrkbokföra",
    "kyrkbokfördes": "kyrkbokföra",
    "kyrkbokförds": "kyrkbokföra",
    "kyrkbokföres": "kyrkbokföra",
    "kyrkbokföringar": "kyrkbokföring",
    "kyrkbokföringarna": "kyrkbokföring",
    "kyrkbokföringarnas": "kyrkbokföring",
    "kyrkbokföringars": "kyrkbokföring",
    "kyrkbokföringen": "kyrkbokföring",
    "kyrkbokföringens": "kyrkbokföring",
    "kyrkbokförings": "kyrkbokföring",
    "kyrkbokförs": "kyrkbokföra",
    "kyrkbokfört": "kyrkbokföra",
    "kyrkbokförts": "kyrkbokföra",
    "kyrkboks": "kyrkbok",
    "kyrkbröllopen": "kyrkbröllop",
    "kyrkbröllopens": "kyrkbröllop",
    "kyrkbröllopet": "kyrkbröllop",
    "kyrkbröllopets": "kyrkbröllop",
    "kyrkbröllops": "kyrkbröllop",
    "kyrkbyar": "kyrkby",
    "kyrkbyarna": "kyrkby",
    "kyrkbyarnas": "kyrkby",
    "kyrkbyars": "kyrkby",
    "kyrkbyggen": "kyrkbygge",
    "kyrkbyggena": "kyrkbygge",
    "kyrkbyggenas": "kyrkbygge",
    "kyrkbyggens": "kyrkbygge",
    "kyrkbygges": "kyrkbygge",
    "kyrkbygget": "kyrkbygge",
    "kyrkbyggets": "kyrkbygge",
    "kyrkbyn": "kyrkby",
    "kyrkbyns": "kyrkby",
    "kyrkbys": "kyrkby",
    "kyrkbänkar": "kyrkbänk",
    "kyrkbänkarna": "kyrkbänk",
    "kyrkbänkarnas": "kyrkbänk",
    "kyrkbänkars": "kyrkbänk",
    "kyrkbänken": "kyrkbänk",
    "kyrkbänkens": "kyrkbänk",
    "kyrkbänks": "kyrkbänk",
    "kyrkbåtar": "kyrkbåt",
    "kyrkbåtarna": "kyrkbåt",
    "kyrkbåtarnas": "kyrkbåt",
    "kyrkbåtars": "kyrkbåt",
    "kyrkbåten": "kyrkbåt",
    "kyrkbåtens": "kyrkbåt",
    "kyrkbåts": "kyrkbåt",
    "kyrkböcker": "kyrkbok",
    "kyrkböckerna": "kyrkbok",
    "kyrkböckernas": "kyrkbok",
    "kyrkböckers": "kyrkbok",
    "kyrke": "kyrka",
    "kyrkfönsterna": "kyrkfönster",
    "kyrkfönsternas": "kyrkfönster",
    "kyrkfönsters": "kyrkfönster",
    "kyrkfönstren": "kyrkfönster",
    "kyrkfönstrens": "kyrkfönster",
    "kyrkfönstret": "kyrkfönster",
    "kyrkfönstrets": "kyrkfönster",
    "kyrkkaffes": "kyrkkaffe",
    "kyrkkaffet": "kyrkkaffe",
    "kyrkkaffets": "kyrkkaffe",
    "kyrkklock": "kyrkklocka",
    "kyrkklockan": "kyrkklocka",
    "kyrkklockans": "kyrkklocka",
    "kyrkklockas": "kyrkklocka",
    "kyrkklocke": "kyrkklocka",
    "kyrkklockor": "kyrkklocka",
    "kyrkklockorna": "kyrkklocka",
    "kyrkklockornas": "kyrkklocka",
    "kyrkklockors": "kyrkklocka",
    "kyrkklocks": "kyrkklocka",
    "kyrkliga": "kyrklig",
    "kyrkligare": "kyrklig",
    "kyrkligares": "kyrklig",
    "kyrkligas": "kyrklig",
    "kyrkligast": "kyrklig",
    "kyrkligaste": "kyrklig",
    "kyrkligastes": "kyrklig",
    "kyrkligasts": "kyrklig",
    "kyrklige": "kyrklig",
    "kyrkliges": "kyrklig",
    "kyrkligheten": "kyrklighet",
    "kyrklighetens": "kyrklighet",
    "kyrklighets": "kyrklighet",
    "kyrkligs": "kyrklig",
    "kyrkligt": "kyrklig",
    "kyrkligts": "kyrklig",
    "kyrkmurar": "kyrkmur",
    "kyrkmurarna": "kyrkmur",
    "kyrkmurarnas": "kyrkmur",
    "kyrkmurars": "kyrkmur",
    "kyrkmuren": "kyrkmur",
    "kyrkmurens": "kyrkmur",
    "kyrkmurs": "kyrkmur",
    "kyrko": "kyrka",
    "kyrkoadjunkten": "kyrkoadjunkt",
    "kyrkoadjunktens": "kyrkoadjunkt",
    "kyrkoadjunkter": "kyrkoadjunkt",
    "kyrkoadjunkterna": "kyrkoadjunkt",
    "kyrkoadjunkternas": "kyrkoadjunkt",
    "kyrkoadjunkters": "kyrkoadjunkt",
    "kyrkoadjunkts": "kyrkoadjunkt",
    "kyrkoavgiften": "kyrkoavgift",
    "kyrkoavgiftens": "kyrkoavgift",
    "kyrkoavgifter": "kyrkoavgift",
    "kyrkoavgifterna": "kyrkoavgift",
    "kyrkoavgifternas": "kyrkoavgift",
    "kyrkoavgifters": "kyrkoavgift",
    "kyrkoavgifts": "kyrkoavgift",
    "kyrkobesökar": "kyrkobesökare",
    "kyrkobesökaren": "kyrkobesökare",
    "kyrkobesökarens": "kyrkobesökare",
    "kyrkobesökares": "kyrkobesökare",
    "kyrkobesökarna": "kyrkobesökare",
    "kyrkobesökarnas": "kyrkobesökare",
    "kyrkobesöken": "kyrkobesök",
    "kyrkobesökens": "kyrkobesök",
    "kyrkobesöket": "kyrkobesök",
    "kyrkobesökets": "kyrkobesök",
    "kyrkobesöks": "kyrkobesök",
    "kyrkobibeln": "kyrkobibel",
    "kyrkobibelns": "kyrkobibel",
    "kyrkobibels": "kyrkobibel",
    "kyrkobiblar": "kyrkobibel",
    "kyrkobiblarna": "kyrkobibel",
    "kyrkobiblarnas": "kyrkobibel",
    "kyrkobiblars": "kyrkobibel",
    "kyrkoboken": "kyrkobok",
    "kyrkobokens": "kyrkobok",
    "kyrkobokför": "kyrkobokföra",
    "kyrkobokförande": "kyrkobokföra",
    "kyrkobokföranden": "kyrkobokförande",
    "kyrkobokförandena": "kyrkobokförande",
    "kyrkobokförandenas": "kyrkobokförande",
    "kyrkobokförandens": "kyrkobokförande",
    "kyrkobokförandes": "kyrkobokförande",
    "kyrkobokförandet": "kyrkobokförande",
    "kyrkobokförandets": "kyrkobokförande",
    "kyrkobokföras": "kyrkobokföra",
    "kyrkobokförd": "kyrkobokföra",
    "kyrkobokförda": "kyrkobokföra",
    "kyrkobokfördas": "kyrkobokföra",
    "kyrkobokförde": "kyrkobokföra",
    "kyrkobokfördes": "kyrkobokföra",
    "kyrkobokförds": "kyrkobokföra",
    "kyrkobokföres": "kyrkobokföra",
    "kyrkobokföringar": "kyrkobokföring",
    "kyrkobokföringarna": "kyrkobokföring",
    "kyrkobokföringarnas": "kyrkobokföring",
    "kyrkobokföringars": "kyrkobokföring",
    "kyrkobokföringen": "kyrkobokföring",
    "kyrkobokföringens": "kyrkobokföring",
    "kyrkobokförings": "kyrkobokföring",
    "kyrkobokförs": "kyrkobokföra",
    "kyrkobokfört": "kyrkobokföra",
    "kyrkobokförts": "kyrkobokföra",
    "kyrkoboks": "kyrkobok",
    "kyrkobrodern": "kyrkobroder",
    "kyrkobroderns": "kyrkobroder",
    "kyrkobroders": "kyrkobroder",
    "kyrkobröder": "kyrkobroder",
    "kyrkobröderna": "kyrkobroder",
    "kyrkobrödernas": "kyrkobroder",
    "kyrkobröders": "kyrkobroder",
    "kyrkoböcker": "kyrkobok",
    "kyrkoböckerna": "kyrkobok",
    "kyrkoböckernas": "kyrkobok",
    "kyrkoböckers": "kyrkobok",
    "kyrkofadern": "kyrkofader",
    "kyrkofaderns": "kyrkofader",
    "kyrkofaders": "kyrkofader",
    "kyrkofriden": "kyrkofrid",
    "kyrkofridens": "kyrkofrid",
    "kyrkofrids": "kyrkofrid",
    "kyrkofullmäktige": "kyrkofullmäktig",
    "kyrkofullmäktigen": "kyrkofullmäktig",
    "kyrkofullmäktigena": "kyrkofullmäktig",
    "kyrkofullmäktigenas": "kyrkofullmäktig",
    "kyrkofullmäktigens": "kyrkofullmäktig",
    "kyrkofullmäktiges": "kyrkofullmäktig",
    "kyrkofullmäktigs": "kyrkofullmäktig",
    "kyrkofäder": "kyrkofader",
    "kyrkofäderna": "kyrkofader",
    "kyrkofädernas": "kyrkofader",
    "kyrkofäders": "kyrkofader",
    "kyrkogången": "kyrkogång",
    "kyrkogångens": "kyrkogång",
    "kyrkogångs": "kyrkogång",
    "kyrkogårdar": "kyrkogård",
    "kyrkogårdarna": "kyrkogård",
    "kyrkogårdarnas": "kyrkogård",
    "kyrkogårdars": "kyrkogård",
    "kyrkogården": "kyrkogård",
    "kyrkogårdens": "kyrkogård",
    "kyrkogårds": "kyrkogård",
    "kyrkogårdsförvaltningar": "kyrkogårdsförvaltning",
    "kyrkogårdsförvaltningarna": "kyrkogårdsförvaltning",
    "kyrkogårdsförvaltningarnas": "kyrkogårdsförvaltning",
    "kyrkogårdsförvaltningars": "kyrkogårdsförvaltning",
    "kyrkogårdsförvaltningen": "kyrkogårdsförvaltning",
    "kyrkogårdsförvaltningens": "kyrkogårdsförvaltning",
    "kyrkogårdsförvaltnings": "kyrkogårdsförvaltning",
    "kyrkohandboken": "kyrkohandbok",
    "kyrkohandbokens": "kyrkohandbok",
    "kyrkohandboks": "kyrkohandbok",
    "kyrkohandböcker": "kyrkohandbok",
    "kyrkohandböckerna": "kyrkohandbok",
    "kyrkohandböckernas": "kyrkohandbok",
    "kyrkohandböckers": "kyrkohandbok",
    "kyrkoherda": "kyrkoherde",
    "kyrkoherdar": "kyrkoherde",
    "kyrkoherdarna": "kyrkoherde",
    "kyrkoherdarnas": "kyrkoherde",
    "kyrkoherdars": "kyrkoherde",
    "kyrkoherden": "kyrkoherde",
    "kyrkoherdens": "kyrkoherde",
    "kyrkoherdes": "kyrkoherde",
    "kyrkohistorian": "kyrkohistoria",
    "kyrkohistorians": "kyrkohistoria",
    "kyrkohistorias": "kyrkohistoria",
    "kyrkohistorien": "kyrkohistoria",
    "kyrkohistoriens": "kyrkohistoria",
    "kyrkohällar": "kyrkohäll",
    "kyrkohällarna": "kyrkohäll",
    "kyrkohällarnas": "kyrkohäll",
    "kyrkohällars": "kyrkohäll",
    "kyrkohällen": "kyrkohäll",
    "kyrkohällens": "kyrkohäll",
    "kyrkohälls": "kyrkohäll",
    "kyrkokonserten": "kyrkokonsert",
    "kyrkokonsertens": "kyrkokonsert",
    "kyrkokonserter": "kyrkokonsert",
    "kyrkokonserterna": "kyrkokonsert",
    "kyrkokonserternas": "kyrkokonsert",
    "kyrkokonserters": "kyrkokonsert",
    "kyrkokonserts": "kyrkokonsert",
    "kyrkolatinet": "kyrkolatin",
    "kyrkolatinets": "kyrkolatin",
    "kyrkolatins": "kyrkolatin",
    "kyrkoledningar": "kyrkoledning",
    "kyrkoledningarna": "kyrkoledning",
    "kyrkoledningarnas": "kyrkoledning",
    "kyrkoledningars": "kyrkoledning",
    "kyrkoledningen": "kyrkoledning",
    "kyrkoledningens": "kyrkoledning",
    "kyrkolednings": "kyrkoledning",
    "kyrkomannen": "kyrkoman",
    "kyrkomannens": "kyrkoman",
    "kyrkomans": "kyrkoman",
    "kyrkomusiken": "kyrkomusik",
    "kyrkomusikens": "kyrkomusik",
    "kyrkomusikern": "kyrkomusiker",
    "kyrkomusikerna": "kyrkomusiker",
    "kyrkomusikernas": "kyrkomusiker",
    "kyrkomusikerns": "kyrkomusiker",
    "kyrkomusikers": "kyrkomusiker",
    "kyrkomusiks": "kyrkomusik",
    "kyrkomän": "kyrkoman",
    "kyrkomännen": "kyrkoman",
    "kyrkomännens": "kyrkoman",
    "kyrkomäns": "kyrkoman",
    "kyrkomöten": "kyrkomöte",
    "kyrkomötena": "kyrkomöte",
    "kyrkomötenas": "kyrkomöte",
    "kyrkomötens": "kyrkomöte",
    "kyrkomötes": "kyrkomöte",
    "kyrkomötet": "kyrkomöte",
    "kyrkomötets": "kyrkomöte",
    "kyrkor": "kyrka",
    "kyrkorna": "kyrka",
    "kyrkornas": "kyrka",
    "kyrkors": "kyrka",
    "kyrkoruinen": "kyrkoruin",
    "kyrkoruinens": "kyrkoruin",
    "kyrkoruiner": "kyrkoruin",
    "kyrkoruinerna": "kyrkoruin",
    "kyrkoruinernas": "kyrkoruin",
    "kyrkoruiners": "kyrkoruin",
    "kyrkoruins": "kyrkoruin",
    "kyrkorummen": "kyrkorum",
    "kyrkorummens": "kyrkorum",
    "kyrkorummet": "kyrkorum",
    "kyrkorummets": "kyrkorum",
    "kyrkorums": "kyrkorum",
    "kyrkoråden": "kyrkoråd",
    "kyrkorådens": "kyrkoråd",
    "kyrkorådet": "kyrkoråd",
    "kyrkorådets": "kyrkoråd",
    "kyrkoråds": "kyrkoråd",
    "kyrkosamfunden": "kyrkosamfund",
    "kyrkosamfundens": "kyrkosamfund",
    "kyrkosamfundet": "kyrkosamfund",
    "kyrkosamfundets": "kyrkosamfund",
    "kyrkosamfunds": "kyrkosamfund",
    "kyrkospråken": "kyrkospråk",
    "kyrkospråkens": "kyrkospråk",
    "kyrkospråket": "kyrkospråk",
    "kyrkospråkets": "kyrkospråk",
    "kyrkospråks": "kyrkospråk",
    "kyrkostaten": "kyrkostat",
    "kyrkostatens": "kyrkostat",
    "kyrkostats": "kyrkostat",
    "kyrkostriden": "kyrkostrid",
    "kyrkostridens": "kyrkostrid",
    "kyrkostrider": "kyrkostrid",
    "kyrkostriderna": "kyrkostrid",
    "kyrkostridernas": "kyrkostrid",
    "kyrkostriders": "kyrkostrid",
    "kyrkostrids": "kyrkostrid",
    "kyrkostämman": "kyrkostämma",
    "kyrkostämmans": "kyrkostämma",
    "kyrkostämmas": "kyrkostämma",
    "kyrkostämme": "kyrkostämma",
    "kyrkostämmo": "kyrkostämma",
    "kyrkostämmor": "kyrkostämma",
    "kyrkostämmorna": "kyrkostämma",
    "kyrkostämmornas": "kyrkostämma",
    "kyrkostämmors": "kyrkostämma",
    "kyrkosången": "kyrkosång",
    "kyrkosångens": "kyrkosång",
    "kyrkosånger": "kyrkosång",
    "kyrkosångerna": "kyrkosång",
    "kyrkosångernas": "kyrkosång",
    "kyrkosångers": "kyrkosång",
    "kyrkosångs": "kyrkosång",
    "kyrkotagningar": "kyrkotagning",
    "kyrkotagningarna": "kyrkotagning",
    "kyrkotagningarnas": "kyrkotagning",
    "kyrkotagningars": "kyrkotagning",
    "kyrkotagningen": "kyrkotagning",
    "kyrkotagningens": "kyrkotagning",
    "kyrkotagnings": "kyrkotagning",
    "kyrkotonarten": "kyrkotonart",
    "kyrkotonartens": "kyrkotonart",
    "kyrkotonarter": "kyrkotonart",
    "kyrkotonarterna": "kyrkotonart",
    "kyrkotonarternas": "kyrkotonart",
    "kyrkotonarters": "kyrkotonart",
    "kyrkotonarts": "kyrkotonart",
    "kyrkotonen": "kyrkoton",
    "kyrkotonens": "kyrkoton",
    "kyrkotoner": "kyrkoton",
    "kyrkotonerna": "kyrkoton",
    "kyrkotonernas": "kyrkoton",
    "kyrkotoners": "kyrkoton",
    "kyrkotons": "kyrkoton",
    "kyrkotukten": "kyrkotukt",
    "kyrkotuktens": "kyrkotukt",
    "kyrkotukts": "kyrkotukt",
    "kyrkoverksamheten": "kyrkoverksamhet",
    "kyrkoverksamhetens": "kyrkoverksamhet",
    "kyrkoverksamheter": "kyrkoverksamhet",
    "kyrkoverksamheterna": "kyrkoverksamhet",
    "kyrkoverksamheternas": "kyrkoverksamhet",
    "kyrkoverksamheters": "kyrkoverksamhet",
    "kyrkoverksamhets": "kyrkoverksamhet",
    "kyrkoåren": "kyrkoår",
    "kyrkoårens": "kyrkoår",
    "kyrkoåret": "kyrkoår",
    "kyrkoårets": "kyrkoår",
    "kyrkoårs": "kyrkoår",
    "kyrks": "kyrka",
    "kyrksalar": "kyrksal",
    "kyrksalarna": "kyrksal",
    "kyrksalarnas": "kyrksal",
    "kyrksalars": "kyrksal",
    "kyrksalen": "kyrksal",
    "kyrksalens": "kyrksal",
    "kyrksals": "kyrksal",
    "kyrksamheten": "kyrksamhet",
    "kyrksamhetens": "kyrksamhet",
    "kyrksamhets": "kyrksamhet",
    "kyrksamma": "kyrksam",
    "kyrksammare": "kyrksam",
    "kyrksammares": "kyrksam",
    "kyrksammas": "kyrksam",
    "kyrksammast": "kyrksam",
    "kyrksammaste": "kyrksam",
    "kyrksammastes": "kyrksam",
    "kyrksammasts": "kyrksam",
    "kyrksamme": "kyrksam",
    "kyrksammes": "kyrksam",
    "kyrksams": "kyrksam",
    "kyrksamt": "kyrksam",
    "kyrksamts": "kyrksam",
    "kyrksilvers": "kyrksilver",
    "kyrksilvret": "kyrksilver",
    "kyrksilvrets": "kyrksilver",
    "kyrkskrev": "kyrkskriva",
    "kyrkskrevs": "kyrkskriva",
    "kyrkskriv": "kyrkskriva",
    "kyrkskrivande": "kyrkskriva",
    "kyrkskrivanden": "kyrkskrivande",
    "kyrkskrivandena": "kyrkskrivande",
    "kyrkskrivandenas": "kyrkskrivande",
    "kyrkskrivandens": "kyrkskrivande",
    "kyrkskrivandes": "kyrkskrivande",
    "kyrkskrivandet": "kyrkskrivande",
    "kyrkskrivandets": "kyrkskrivande",
    "kyrkskrivas": "kyrkskriva",
    "kyrkskrive": "kyrkskriva",
    "kyrkskriven": "kyrkskriva",
    "kyrkskrivens": "kyrkskriva",
    "kyrkskriver": "kyrkskriva",
    "kyrkskrives": "kyrkskriva",
    "kyrkskrivet": "kyrkskriva",
    "kyrkskrivets": "kyrkskriva",
    "kyrkskrivit": "kyrkskriva",
    "kyrkskrivits": "kyrkskriva",
    "kyrkskrivna": "kyrkskriva",
    "kyrkskrivnas": "kyrkskriva",
    "kyrkskrivne": "kyrkskriva",
    "kyrkskrivnes": "kyrkskriva",
    "kyrkskrivs": "kyrkskriva",
    "kyrkslavisk": "kyrkslaviska",
    "kyrkslaviskan": "kyrkslaviska",
    "kyrkslaviskans": "kyrkslaviska",
    "kyrkslaviskas": "kyrkslaviska",
    "kyrksockenn": "kyrksocken",
    "kyrksockenns": "kyrksocken",
    "kyrksockens": "kyrksocken",
    "kyrksocknar": "kyrksocken",
    "kyrksocknarna": "kyrksocken",
    "kyrksocknarnas": "kyrksocken",
    "kyrksocknars": "kyrksocken",
    "kyrkstötar": "kyrkstöt",
    "kyrkstötarna": "kyrkstöt",
    "kyrkstötarnas": "kyrkstöt",
    "kyrkstötars": "kyrkstöt",
    "kyrkstöten": "kyrkstöt",
    "kyrkstötens": "kyrkstöt",
    "kyrkstöts": "kyrkstöt",
    "kyrktagningar": "kyrktagning",
    "kyrktagningarna": "kyrktagning",
    "kyrktagningarnas": "kyrktagning",
    "kyrktagningars": "kyrktagning",
    "kyrktagningen": "kyrktagning",
    "kyrktagningens": "kyrktagning",
    "kyrktagnings": "kyrktagning",
    "kyrktornen": "kyrktorn",
    "kyrktornens": "kyrktorn",
    "kyrktornet": "kyrktorn",
    "kyrktornets": "kyrktorn",
    "kyrktorns": "kyrktorn",
    "kyrktuppar": "kyrktupp",
    "kyrktupparna": "kyrktupp",
    "kyrktupparnas": "kyrktupp",
    "kyrktuppars": "kyrktupp",
    "kyrktuppen": "kyrktupp",
    "kyrktuppens": "kyrktupp",
    "kyrktupps": "kyrktupp",
    "kyrkvaktmästar": "kyrkvaktmästare",
    "kyrkvaktmästaren": "kyrkvaktmästare",
    "kyrkvaktmästarens": "kyrkvaktmästare",
    "kyrkvaktmästares": "kyrkvaktmästare",
    "kyrkvaktmästarna": "kyrkvaktmästare",
    "kyrkvaktmästarnas": "kyrkvaktmästare",
    "kyrkvärdar": "kyrkvärd",
    "kyrkvärdarna": "kyrkvärd",
    "kyrkvärdarnas": "kyrkvärd",
    "kyrkvärdars": "kyrkvärd",
    "kyrkvärden": "kyrkvärd",
    "kyrkvärdens": "kyrkvärd",
    "kyrkvärds": "kyrkvärd",
    "kyska": "kysk",
    "kyskare": "kysk",
    "kyskares": "kysk",
    "kyskas": "kysk",
    "kyskast": "kysk",
    "kyskaste": "kysk",
    "kyskastes": "kysk",
    "kyskasts": "kysk",
    "kyske": "kysk",
    "kyskes": "kysk",
    "kyskheten": "kyskhet",
    "kyskhetens": "kyskhet",
    "kyskheter": "kyskhet",
    "kyskheterna": "kyskhet",
    "kyskheternas": "kyskhet",
    "kyskheters": "kyskhet",
    "kyskhets": "kyskhet",
    "kyskhetsbälten": "kyskhetsbälte",
    "kyskhetsbältena": "kyskhetsbälte",
    "kyskhetsbältenas": "kyskhetsbälte",
    "kyskhetsbältens": "kyskhetsbälte",
    "kyskhetsbältes": "kyskhetsbälte",
    "kyskhetsbältet": "kyskhetsbälte",
    "kyskhetsbältets": "kyskhetsbälte",
    "kyskhetslåsen": "kyskhetslås",
    "kyskhetslåsens": "kyskhetslås",
    "kyskhetslåset": "kyskhetslås",
    "kyskhetslåsets": "kyskhetslås",
    "kyskhetslöften": "kyskhetslöfte",
    "kyskhetslöftena": "kyskhetslöfte",
    "kyskhetslöftenas": "kyskhetslöfte",
    "kyskhetslöftens": "kyskhetslöfte",
    "kyskhetslöftes": "kyskhetslöfte",
    "kyskhetslöftet": "kyskhetslöfte",
    "kyskhetslöftets": "kyskhetslöfte",
    "kyskhetsnormen": "kyskhetsnorm",
    "kyskhetsnormens": "kyskhetsnorm",
    "kyskhetsnormer": "kyskhetsnorm",
    "kyskhetsnormerna": "kyskhetsnorm",
    "kyskhetsnormernas": "kyskhetsnorm",
    "kyskhetsnormers": "kyskhetsnorm",
    "kyskhetsnorms": "kyskhetsnorm",
    "kysks": "kysk",
    "kyskt": "kysk",
    "kyskts": "kysk",
    "kyss": "kyssa",
    "kyssande": "kyssa",
    "kyssanden": "kyssande",
    "kyssandena": "kyssande",
    "kyssandenas": "kyssande",
    "kyssandens": "kyssande",
    "kyssandes": "kyssande",
    "kyssandet": "kyssande",
    "kyssandets": "kyssande",
    "kyssar": "kyss",
    "kyssarna": "kyss",
    "kyssarnas": "kyss",
    "kyssars": "kyss",
    "kyssas": "kyssa",
    "kyssen": "kyss",
    "kyssens": "kyss",
    "kysser": "kyssa",
    "kysses": "kyssa",
    "kysst": "kyssa",
    "kyssta": "kyssa",
    "kysstas": "kyssa",
    "kysste": "kyssa",
    "kysstes": "kyssas",
    "kyssts": "kyssas",
    "kysstäcka": "kysstäck",
    "kysstäckare": "kysstäck",
    "kysstäckares": "kysstäck",
    "kysstäckas": "kysstäck",
    "kysstäckast": "kysstäck",
    "kysstäckaste": "kysstäck",
    "kysstäckastes": "kysstäck",
    "kysstäckasts": "kysstäck",
    "kysstäcke": "kysstäck",
    "kysstäckes": "kysstäck",
    "kysstäckheten": "kysstäckhet",
    "kysstäckhetens": "kysstäckhet",
    "kysstäckhets": "kysstäckhet",
    "kysstäcks": "kysstäck",
    "kysstäckt": "kysstäck",
    "kysstäckts": "kysstäck",
    "kyssäkerheten": "kyssäkerhet",
    "kyssäkerhetens": "kyssäkerhet",
    "kyssäkerhets": "kyssäkerhet",
    "kyssäkers": "kyssäker",
    "kyssäkert": "kyssäker",
    "kyssäkerts": "kyssäker",
    "kyssäkra": "kyssäker",
    "kyssäkrare": "kyssäker",
    "kyssäkrares": "kyssäker",
    "kyssäkras": "kyssäker",
    "kyssäkrast": "kyssäker",
    "kyssäkraste": "kyssäker",
    "kyssäkrastes": "kyssäker",
    "kyssäkrasts": "kyssäker",
    "kyssäkre": "kyssäker",
    "kyssäkres": "kyssäker",
    "kytten": "kytt",
    "kyttens": "kytt",
    "kyttet": "kytt",
    "kyttets": "kytt",
    "kytts": "kytt",
    "käbbel": "käbbla",
    "käbbels": "käbbel",
    "käbblade": "käbbla",
    "käbblades": "käbbla",
    "käbblande": "käbbla",
    "käbblanden": "käbblande",
    "käbblandena": "käbblande",
    "käbblandenas": "käbblande",
    "käbblandens": "käbblande",
    "käbblandes": "käbblande",
    "käbblandet": "käbblande",
    "käbblandets": "käbblande",
    "käbblar": "käbbla",
    "käbblas": "käbbla",
    "käbblat": "käbbla",
    "käbblats": "käbbla",
    "käbblet": "käbbel",
    "käbblets": "käbbel",
    "käcka": "käck",
    "käckare": "käck",
    "käckares": "käck",
    "käckas": "käck",
    "käckast": "käck",
    "käckaste": "käck",
    "käckastes": "käck",
    "käckasts": "käck",
    "käcke": "käck",
    "käckes": "käck",
    "käckheten": "käckhet",
    "käckhetens": "käckhet",
    "käckheter": "käckhet",
    "käckheterna": "käckhet",
    "käckheternas": "käckhet",
    "käckheters": "käckhet",
    "käckhets": "käckhet",
    "käcks": "käck",
    "käckt": "käck",
    "käckts": "käck",
    "käftade": "käfta",
    "käftades": "käfta",
    "käftande": "käfta",
    "käftanden": "käftande",
    "käftandena": "käftande",
    "käftandenas": "käftande",
    "käftandens": "käftande",
    "käftandes": "käftande",
    "käftandet": "käftande",
    "käftandets": "käftande",
    "käftar": "käfta",
    "käftarna": "käft",
    "käftarnas": "käft",
    "käftars": "käft",
    "käftas": "käfta",
    "käftat": "käfta",
    "käftats": "käfta",
    "käften": "käft",
    "käftens": "käft",
    "käfts": "käft",
    "kägel": "kägla",
    "kägelbanan": "kägelbana",
    "kägelbanans": "kägelbana",
    "kägelbanas": "kägelbana",
    "kägelbane": "kägelbana",
    "kägelbanor": "kägelbana",
    "kägelbanorna": "kägelbana",
    "kägelbanornas": "kägelbana",
    "kägelbanors": "kägelbana",
    "kägelformiga": "kägelformig",
    "kägelformigare": "kägelformig",
    "kägelformigares": "kägelformig",
    "kägelformigas": "kägelformig",
    "kägelformigast": "kägelformig",
    "kägelformigaste": "kägelformig",
    "kägelformigastes": "kägelformig",
    "kägelformigasts": "kägelformig",
    "kägelformige": "kägelformig",
    "kägelformiges": "kägelformig",
    "kägelformigheten": "kägelformighet",
    "kägelformighetens": "kägelformighet",
    "kägelformighets": "kägelformighet",
    "kägelformigs": "kägelformig",
    "kägelformigt": "kägelformig",
    "kägelformigts": "kägelformig",
    "kägeln": "kägel",
    "kägelns": "kägel",
    "kägels": "kägel",
    "kägelsnitten": "kägelsnitt",
    "kägelsnittens": "kägelsnitt",
    "kägelsnittet": "kägelsnitt",
    "kägelsnittets": "kägelsnitt",
    "kägelsnitts": "kägelsnitt",
    "kägelspelet": "kägelspel",
    "kägelspelets": "kägelspel",
    "kägelspels": "kägelspel",
    "käglan": "kägla",
    "käglans": "kägla",
    "käglar": "kägel",
    "käglarna": "kägel",
    "käglarnas": "kägel",
    "käglars": "kägel",
    "käglas": "kägla",
    "kägle": "kägla",
    "käglor": "kägla",
    "käglorna": "kägla",
    "käglornas": "kägla",
    "käglors": "kägla",
    "käk": "käke",
    "käkad": "käka",
    "käkade": "käka",
    "käkades": "käka",
    "käkads": "käka",
    "käkande": "käka",
    "käkanden": "käkande",
    "käkandena": "käkande",
    "käkandenas": "käkande",
    "käkandens": "käkande",
    "käkandes": "käkande",
    "käkandet": "käkande",
    "käkandets": "käkande",
    "käkar": "käke",
    "käkarna": "käke",
    "käkarnas": "käke",
    "käkars": "käke",
    "käkas": "käka",
    "käkat": "käka",
    "käkats": "käka",
    "käkbenen": "käkben",
    "käkbenens": "käkben",
    "käkbenet": "käkben",
    "käkbenets": "käkben",
    "käkbens": "käkben",
    "käken": "käke",
    "käkens": "käke",
    "käkes": "käke",
    "käket": "käk",
    "käkets": "käk",
    "käkhål": "käkhåla",
    "käkhålan": "käkhåla",
    "käkhålans": "käkhåla",
    "käkhålas": "käkhåla",
    "käkhåle": "käkhåla",
    "käkhålor": "käkhåla",
    "käkhålorna": "käkhåla",
    "käkhålornas": "käkhåla",
    "käkhålors": "käkhåla",
    "käkhåls": "käkhåla",
    "käkleden": "käkled",
    "käkledens": "käkled",
    "käkleder": "käkled",
    "käklederna": "käkled",
    "käkledernas": "käkled",
    "käkleders": "käkled",
    "käkleds": "käkled",
    "käkpartier": "käkparti",
    "käkpartierna": "käkparti",
    "käkpartiernas": "käkparti",
    "käkpartiers": "käkparti",
    "käkpartiet": "käkparti",
    "käkpartiets": "käkparti",
    "käkpartis": "käkparti",
    "käkpartit": "käkparti",
    "käkpartits": "käkparti",
    "käkremmar": "käkrem",
    "käkremmarna": "käkrem",
    "käkremmarnas": "käkrem",
    "käkremmars": "käkrem",
    "käkremmen": "käkrem",
    "käkremmens": "käkrem",
    "käkrems": "käkrem",
    "käks": "käke",
    "käl": "käla",
    "kälad": "käla",
    "kälade": "käla",
    "kälades": "käla",
    "kälads": "käla",
    "kälande": "käla",
    "kälanden": "kälande",
    "kälandena": "kälande",
    "kälandenas": "kälande",
    "kälandens": "kälande",
    "kälandes": "kälande",
    "kälandet": "kälande",
    "kälandets": "kälande",
    "kälar": "käla",
    "kälarna": "käl",
    "kälarnas": "käl",
    "kälars": "käl",
    "kälas": "käla",
    "kälat": "käla",
    "kälats": "käla",
    "kälen": "käl",
    "kälens": "käl",
    "kälk": "kälke",
    "kälkar": "kälke",
    "kälkarna": "kälke",
    "kälkarnas": "kälke",
    "kälkars": "kälke",
    "kälkback": "kälkbacke",
    "kälkbackar": "kälkbacke",
    "kälkbackarna": "kälkbacke",
    "kälkbackarnas": "kälkbacke",
    "kälkbackars": "kälkbacke",
    "kälkbacken": "kälkbacke",
    "kälkbackens": "kälkbacke",
    "kälkbackes": "kälkbacke",
    "kälkbacks": "kälkbacke",
    "kälkborgar": "kälkborgare",
    "kälkborgaren": "kälkborgare",
    "kälkborgarens": "kälkborgare",
    "kälkborgares": "kälkborgare",
    "kälkborgarna": "kälkborgare",
    "kälkborgarnas": "kälkborgare",
    "kälken": "kälke",
    "kälkens": "kälke",
    "kälkes": "kälke",
    "kälks": "kälke",
    "käll": "källa",
    "källan": "källa",
    "källans": "källa",
    "källar": "källare",
    "källaren": "källare",
    "källarens": "källare",
    "källares": "källare",
    "källarhalsar": "källarhals",
    "källarhalsarna": "källarhals",
    "källarhalsarnas": "källarhals",
    "källarhalsars": "källarhals",
    "källarhalsen": "källarhals",
    "källarhalsens": "källarhals",
    "källarlokalen": "källarlokal",
    "källarlokalens": "källarlokal",
    "källarlokaler": "källarlokal",
    "källarlokalerna": "källarlokal",
    "källarlokalernas": "källarlokal",
    "källarlokalers": "källarlokal",
    "källarlokals": "källarlokal",
    "källarmästar": "källarmästare",
    "källarmästaren": "källarmästare",
    "källarmästarens": "källarmästare",
    "källarmästares": "källarmästare",
    "källarmästarna": "källarmästare",
    "källarmästarnas": "källarmästare",
    "källarna": "källare",
    "källarnas": "källare",
    "källartrapp": "källartrappa",
    "källartrappan": "källartrappa",
    "källartrappans": "källartrappa",
    "källartrappas": "källartrappa",
    "källartrappe": "källartrappa",
    "källartrappor": "källartrappa",
    "källartrapporna": "källartrappa",
    "källartrappornas": "källartrappa",
    "källartrappors": "källartrappa",
    "källartrapps": "källartrappa",
    "källarvåningar": "källarvåning",
    "källarvåningarna": "källarvåning",
    "källarvåningarnas": "källarvåning",
    "källarvåningars": "källarvåning",
    "källarvåningen": "källarvåning",
    "källarvåningens": "källarvåning",
    "källarvånings": "källarvåning",
    "källas": "källa",
    "källdragen": "källdrag",
    "källdragens": "källdrag",
    "källdraget": "källdrag",
    "källdragets": "källdrag",
    "källdrags": "källdrag",
    "källe": "källa",
    "källflöden": "källflöde",
    "källflödena": "källflöde",
    "källflödenas": "källflöde",
    "källflödens": "källflöde",
    "källflödes": "källflöde",
    "källflödet": "källflöde",
    "källflödets": "källflöde",
    "källförteckningar": "källförteckning",
    "källförteckningarna": "källförteckning",
    "källförteckningarnas": "källförteckning",
    "källförteckningars": "källförteckning",
    "källförteckningen": "källförteckning",
    "källförteckningens": "källförteckning",
    "källförtecknings": "källförteckning",
    "källhänvisningar": "källhänvisning",
    "källhänvisningarna": "källhänvisning",
    "källhänvisningarnas": "källhänvisning",
    "källhänvisningars": "källhänvisning",
    "källhänvisningen": "källhänvisning",
    "källhänvisningens": "källhänvisning",
    "källhänvisnings": "källhänvisning",
    "källingar": "källing",
    "källingarna": "källing",
    "källingarnas": "källing",
    "källingars": "källing",
    "källingen": "källing",
    "källingens": "källing",
    "källings": "källing",
    "källkritiken": "källkritik",
    "källkritikens": "källkritik",
    "källkritiks": "källkritik",
    "källmaterialen": "källmaterial",
    "källmaterialens": "källmaterial",
    "källmaterialet": "källmaterial",
    "källmaterialets": "källmaterial",
    "källmaterials": "källmaterial",
    "källor": "källa",
    "källorna": "källa",
    "källornas": "källa",
    "källors": "källa",
    "källs": "källa",
    "källsjöar": "källsjö",
    "källsjöarna": "källsjö",
    "källsjöarnas": "källsjö",
    "källsjöars": "källsjö",
    "källsjön": "källsjö",
    "källsjöns": "källsjö",
    "källsjös": "källsjö",
    "källskatten": "källskatt",
    "källskattens": "källskatt",
    "källskatter": "källskatt",
    "källskatterna": "källskatt",
    "källskatternas": "källskatt",
    "källskatters": "källskatt",
    "källskatts": "källskatt",
    "källskriften": "källskrift",
    "källskriftens": "källskrift",
    "källskrifter": "källskrift",
    "källskrifterna": "källskrift",
    "källskrifternas": "källskrift",
    "källskrifters": "källskrift",
    "källskrifts": "källskrift",
    "källsorterad": "källsortera",
    "källsorterade": "källsortera",
    "källsorterades": "källsortera",
    "källsorterads": "källsortera",
    "källsorterande": "källsortera",
    "källsorteranden": "källsorterande",
    "källsorterandena": "källsorterande",
    "källsorterandenas": "källsorterande",
    "källsorterandens": "källsorterande",
    "källsorterandes": "källsorterande",
    "källsorterandet": "källsorterande",
    "källsorterandets": "källsorterande",
    "källsorterar": "källsortera",
    "källsorteras": "källsortera",
    "källsorterat": "källsortera",
    "källsorterats": "källsortera",
    "källsorterbara": "källsorterbar",
    "källsorterbarare": "källsorterbar",
    "källsorterbarares": "källsorterbar",
    "källsorterbaras": "källsorterbar",
    "källsorterbarast": "källsorterbar",
    "källsorterbaraste": "källsorterbar",
    "källsorterbarastes": "källsorterbar",
    "källsorterbarasts": "källsorterbar",
    "källsorterbare": "källsorterbar",
    "källsorterbares": "källsorterbar",
    "källsorterbarheten": "källsorterbarhet",
    "källsorterbarhetens": "källsorterbarhet",
    "källsorterbarhets": "källsorterbarhet",
    "källsorterbars": "källsorterbar",
    "källsorterbart": "källsorterbar",
    "källsorterbarts": "källsorterbar",
    "källsprången": "källsprång",
    "källsprångens": "källsprång",
    "källsprånget": "källsprång",
    "källsprångets": "källsprång",
    "källsprångs": "källsprång",
    "källvattens": "källvatten",
    "källvattnen": "källvatten",
    "källvattnens": "källvatten",
    "källvattnet": "källvatten",
    "källvattnets": "källvatten",
    "källådern": "källåder",
    "källåderns": "källåder",
    "källåders": "källåder",
    "källådra": "källåder",
    "källådran": "källåder",
    "källådrans": "källåder",
    "källådras": "källåder",
    "källådre": "källåder",
    "källådror": "källåder",
    "källådrorna": "källåder",
    "källådrornas": "källåder",
    "källådrors": "källåder",
    "käls": "käl",
    "kältade": "kälta",
    "kältades": "kälta",
    "kältande": "kälta",
    "kältanden": "kältande",
    "kältandena": "kältande",
    "kältandenas": "kältande",
    "kältandens": "kältande",
    "kältandes": "kältande",
    "kältandet": "kältande",
    "kältandets": "kältande",
    "kältar": "kälta",
    "kältas": "kälta",
    "kältat": "kälta",
    "kältats": "kälta",
    "kältet": "kält",
    "kältets": "kält",
    "kälts": "kält",
    "kämnärsrätten": "kämnärsrätt",
    "kämnärsrättens": "kämnärsrätt",
    "kämnärsrätter": "kämnärsrätt",
    "kämnärsrätterna": "kämnärsrätt",
    "kämnärsrätternas": "kämnärsrätt",
    "kämnärsrätters": "kämnärsrätt",
    "kämnärsrätts": "kämnärsrätt",
    "kämpade": "kämpa",
    "kämpades": "kämpa",
    "kämpagravar": "kämpagrav",
    "kämpagravarna": "kämpagrav",
    "kämpagravarnas": "kämpagrav",
    "kämpagravars": "kämpagrav",
    "kämpagraven": "kämpagrav",
    "kämpagravens": "kämpagrav",
    "kämpagravs": "kämpagrav",
    "kämpahumöret": "kämpahumör",
    "kämpahumörets": "kämpahumör",
    "kämpahumörs": "kämpahumör",
    "kämpalekar": "kämpalek",
    "kämpalekarna": "kämpalek",
    "kämpalekarnas": "kämpalek",
    "kämpalekars": "kämpalek",
    "kämpaleken": "kämpalek",
    "kämpalekens": "kämpalek",
    "kämpaleks": "kämpalek",
    "kämpalika": "kämpalik",
    "kämpalikare": "kämpalik",
    "kämpalikares": "kämpalik",
    "kämpalikas": "kämpalik",
    "kämpalikast": "kämpalik",
    "kämpalikaste": "kämpalik",
    "kämpalikastes": "kämpalik",
    "kämpalikasts": "kämpalik",
    "kämpalike": "kämpalik",
    "kämpalikes": "kämpalik",
    "kämpaliks": "kämpalik",
    "kämpalikt": "kämpalik",
    "kämpalikts": "kämpalik",
    "kämpamässiga": "kämpamässig",
    "kämpamässigare": "kämpamässig",
    "kämpamässigares": "kämpamässig",
    "kämpamässigas": "kämpamässig",
    "kämpamässigast": "kämpamässig",
    "kämpamässigaste": "kämpamässig",
    "kämpamässigastes": "kämpamässig",
    "kämpamässigasts": "kämpamässig",
    "kämpamässige": "kämpamässig",
    "kämpamässiges": "kämpamässig",
    "kämpamässigs": "kämpamässig",
    "kämpamässigt": "kämpamässig",
    "kämpamässigts": "kämpamässig",
    "kämpande": "kämpa",
    "kämpanden": "kämpande",
    "kämpandena": "kämpande",
    "kämpandenas": "kämpande",
    "kämpandens": "kämpande",
    "kämpandes": "kämpande",
    "kämpandet": "kämpande",
    "kämpandets": "kämpande",
    "kämpar": "kämpe",
    "kämparna": "kämpe",
    "kämparnas": "kämpe",
    "kämpars": "kämpe",
    "kämpas": "kämpa",
    "kämpat": "kämpa",
    "kämpatagen": "kämpatag",
    "kämpatagens": "kämpatag",
    "kämpataget": "kämpatag",
    "kämpatagets": "kämpatag",
    "kämpatags": "kämpatag",
    "kämpats": "kämpa",
    "kämpen": "kämpe",
    "kämpens": "kämpe",
    "kämpes": "kämpe",
    "kämpiga": "kämpig",
    "kämpigare": "kämpig",
    "kämpigares": "kämpig",
    "kämpigas": "kämpig",
    "kämpigast": "kämpig",
    "kämpigaste": "kämpig",
    "kämpigastes": "kämpig",
    "kämpigasts": "kämpig",
    "kämpige": "kämpig",
    "kämpiges": "kämpig",
    "kämpigheten": "kämpighet",
    "kämpighetens": "kämpighet",
    "kämpighets": "kämpighet",
    "kämpigs": "kämpig",
    "kämpigt": "kämpig",
    "kämpigts": "kämpig",
    "känd": "känna",
    "kända": "känna",
    "kändare": "känd",
    "kändares": "känd",
    "kändas": "känna",
    "kändast": "känd",
    "kändaste": "känd",
    "kändastes": "känd",
    "kändasts": "känd",
    "kände": "känna",
    "kändes": "kännas",
    "kändheten": "kändhet",
    "kändhetens": "kändhet",
    "kändhets": "kändhet",
    "kändisar": "kändis",
    "kändisarna": "kändis",
    "kändisarnas": "kändis",
    "kändisars": "kändis",
    "kändisbloggar": "kändisblogg",
    "kändisbloggarna": "kändisblogg",
    "kändisbloggarnas": "kändisblogg",
    "kändisbloggars": "kändisblogg",
    "kändisbloggen": "kändisblogg",
    "kändisbloggens": "kändisblogg",
    "kändisbloggs": "kändisblogg",
    "kändisdyrkans": "kändisdyrkan",
    "kändisen": "kändis",
    "kändisens": "kändis",
    "kändiserier": "kändiseri",
    "kändiserierna": "kändiseri",
    "kändiseriernas": "kändiseri",
    "kändiseriers": "kändiseri",
    "kändiseriet": "kändiseri",
    "kändiseriets": "kändiseri",
    "kändiseris": "kändiseri",
    "kändiserit": "kändiseri",
    "kändiserits": "kändiseri",
    "kändismassören": "kändismassör",
    "kändismassörens": "kändismassör",
    "kändismassörer": "kändismassör",
    "kändismassörerna": "kändismassör",
    "kändismassörernas": "kändismassör",
    "kändismassörers": "kändismassör",
    "kändismassörs": "kändismassör",
    "kändisprylar": "kändispryl",
    "kändisprylarna": "kändispryl",
    "kändisprylarnas": "kändispryl",
    "kändisprylars": "kändispryl",
    "kändisprylen": "kändispryl",
    "kändisprylens": "kändispryl",
    "kändispryls": "kändispryl",
    "kändisskapet": "kändisskap",
    "kändisskapets": "kändisskap",
    "kändisskaps": "kändisskap",
    "känds": "känna",
    "käng": "känga",
    "kängan": "känga",
    "kängans": "känga",
    "kängas": "känga",
    "känge": "känga",
    "kängor": "känga",
    "kängorna": "känga",
    "kängornas": "känga",
    "kängors": "känga",
    "kängs": "känga",
    "känguruer": "känguru",
    "känguruerna": "känguru",
    "känguruernas": "känguru",
    "känguruers": "känguru",
    "kängurun": "känguru",
    "känguruns": "känguru",
    "kängurupungar": "kängurupung",
    "kängurupungarna": "kängurupung",
    "kängurupungarnas": "kängurupung",
    "kängurupungars": "kängurupung",
    "kängurupungen": "kängurupung",
    "kängurupungens": "kängurupung",
    "kängurupungs": "kängurupung",
    "kängurur": "känguru",
    "kängururna": "känguru",
    "kängururnas": "känguru",
    "kängururs": "känguru",
    "kängurus": "känguru",
    "känn": "känna",
    "kännande": "känna",
    "kännanden": "kännande",
    "kännandena": "kännande",
    "kännandenas": "kännande",
    "kännandens": "kännande",
    "kännandes": "kännande",
    "kännandet": "kännande",
    "kännandets": "kännande",
    "kännar": "kännare",
    "kännarblicken": "kännarblick",
    "kännarblickens": "kännarblick",
    "kännarblicks": "kännarblick",
    "kännaren": "kännare",
    "kännarens": "kännare",
    "kännares": "kännare",
    "kännarminen": "kännarmin",
    "kännarminens": "kännarmin",
    "kännarmins": "kännarmin",
    "kännarna": "kännare",
    "kännarnas": "kännare",
    "kännas": "känna",
    "kännbara": "kännbar",
    "kännbarare": "kännbar",
    "kännbarares": "kännbar",
    "kännbaras": "kännbar",
    "kännbarast": "kännbar",
    "kännbaraste": "kännbar",
    "kännbarastes": "kännbar",
    "kännbarasts": "kännbar",
    "kännbare": "kännbar",
    "kännbares": "kännbar",
    "kännbarheten": "kännbarhet",
    "kännbarhetens": "kännbarhet",
    "kännbarhets": "kännbarhet",
    "kännbars": "kännbar",
    "kännbart": "kännbar",
    "kännbarts": "kännbar",
    "känne": "känna",
    "kännedomar": "kännedom",
    "kännedomarna": "kännedom",
    "kännedomarnas": "kännedom",
    "kännedomars": "kännedom",
    "kännedomen": "kännedom",
    "kännedomens": "kännedom",
    "kännedoms": "kännedom",
    "kännemärken": "kännemärke",
    "kännemärkena": "kännemärke",
    "kännemärkenas": "kännemärke",
    "kännemärkens": "kännemärke",
    "kännemärkes": "kännemärke",
    "kännemärket": "kännemärke",
    "kännemärkets": "kännemärke",
    "känner": "känna",
    "kännes": "känna",
    "känneteckens": "kännetecken",
    "kännetecknad": "känneteckna",
    "kännetecknade": "känneteckna",
    "kännetecknades": "känneteckna",
    "kännetecknads": "känneteckna",
    "kännetecknande": "känneteckna",
    "kännetecknanden": "kännetecknande",
    "kännetecknandena": "kännetecknande",
    "kännetecknandenas": "kännetecknande",
    "kännetecknandens": "kännetecknande",
    "kännetecknandes": "kännetecknande",
    "kännetecknandet": "kännetecknande",
    "kännetecknandets": "kännetecknande",
    "kännetecknar": "känneteckna",
    "kännetecknas": "känneteckna",
    "kännetecknat": "känneteckna",
    "kännetecknats": "känneteckna",
    "kännetecknen": "kännetecken",
    "kännetecknens": "kännetecken",
    "kännetecknet": "kännetecken",
    "kännetecknets": "kännetecken",
    "känningar": "känning",
    "känningarna": "känning",
    "känningarnas": "känning",
    "känningars": "känning",
    "känningen": "känning",
    "känningens": "känning",
    "kännings": "känning",
    "känns": "kännas",
    "känselhåren": "känselhår",
    "känselhårens": "känselhår",
    "känselhåret": "känselhår",
    "känselhårets": "känselhår",
    "känselhårs": "känselhår",
    "känseln": "känsel",
    "känselns": "känsel",
    "känselorganen": "känselorgan",
    "känselorganens": "känselorgan",
    "känselorganet": "känselorgan",
    "känselorganets": "känselorgan",
    "känselorgans": "känselorgan",
    "känsels": "känsel",
    "känselspröten": "känselspröt",
    "känselsprötens": "känselspröt",
    "känselsprötet": "känselspröt",
    "känselsprötets": "känselspröt",
    "känselspröts": "känselspröt",
    "känsl": "känsla",
    "känslan": "känsla",
    "känslans": "känsla",
    "känslas": "känsla",
    "känsle": "känsla",
    "känsliga": "känslig",
    "känsligare": "känslig",
    "känsligares": "känslig",
    "känsligas": "känslig",
    "känsligast": "känslig",
    "känsligaste": "känslig",
    "känsligastes": "känslig",
    "känsligasts": "känslig",
    "känslige": "känslig",
    "känsliges": "känslig",
    "känsligheten": "känslighet",
    "känslighetens": "känslighet",
    "känsligheter": "känslighet",
    "känsligheterna": "känslighet",
    "känsligheternas": "känslighet",
    "känsligheters": "känslighet",
    "känslighets": "känslighet",
    "känsligs": "känslig",
    "känsligt": "känslig",
    "känsligts": "känslig",
    "känslo": "känsla",
    "känslofyllda": "känslofylld",
    "känslofylldare": "känslofylld",
    "känslofylldares": "känslofylld",
    "känslofylldas": "känslofylld",
    "känslofylldast": "känslofylld",
    "känslofylldaste": "känslofylld",
    "känslofylldastes": "känslofylld",
    "känslofylldasts": "känslofylld",
    "känslofyllde": "känslofylld",
    "känslofylldes": "känslofylld",
    "känslofylldheten": "känslofylldhet",
    "känslofylldhetens": "känslofylldhet",
    "känslofylldhets": "känslofylldhet",
    "känslofyllds": "känslofylld",
    "känslofyllt": "känslofylld",
    "känslofyllts": "känslofylld",
    "känsloikonen": "känsloikon",
    "känsloikonens": "känsloikon",
    "känsloikoner": "känsloikon",
    "känsloikonerna": "känsloikon",
    "känsloikonernas": "känsloikon",
    "känsloikoners": "känsloikon",
    "känsloikons": "känsloikon",
    "känslokalla": "känslokall",
    "känslokallare": "känslokall",
    "känslokallares": "känslokall",
    "känslokallas": "känslokall",
    "känslokallast": "känslokall",
    "känslokallaste": "känslokall",
    "känslokallastes": "känslokall",
    "känslokallasts": "känslokall",
    "känslokalle": "känslokall",
    "känslokalles": "känslokall",
    "känslokalls": "känslokall",
    "känslokallt": "känslokall",
    "känslokallts": "känslokall",
    "känslokyl": "känslokyla",
    "känslokylan": "känslokyla",
    "känslokylans": "känslokyla",
    "känslokylas": "känslokyla",
    "känslokyle": "känslokyla",
    "känslokylor": "känslokyla",
    "känslokylorna": "känslokyla",
    "känslokylornas": "känslokyla",
    "känslokylors": "känslokyla",
    "känslokyls": "känslokyla",
    "känsloladdade": "känsloladdad",
    "känsloladdades": "känsloladdad",
    "känsloladdads": "känsloladdad",
    "känsloladdat": "känsloladdad",
    "känsloladdats": "känsloladdad",
    "känslolivet": "känsloliv",
    "känslolivets": "känsloliv",
    "känslolivs": "känsloliv",
    "känslolägen": "känsloläge",
    "känslolägena": "känsloläge",
    "känslolägenas": "känsloläge",
    "känslolägens": "känsloläge",
    "känsloläges": "känsloläge",
    "känsloläget": "känsloläge",
    "känslolägets": "känsloläge",
    "känslolösa": "känslolös",
    "känslolösare": "känslolös",
    "känslolösares": "känslolös",
    "känslolösas": "känslolös",
    "känslolösast": "känslolös",
    "känslolösaste": "känslolös",
    "känslolösastes": "känslolös",
    "känslolösasts": "känslolös",
    "känslolöse": "känslolös",
    "känslolöses": "känslolös",
    "känslolösheten": "känslolöshet",
    "känslolöshetens": "känslolöshet",
    "känslolösheter": "känslolöshet",
    "känslolösheterna": "känslolöshet",
    "känslolösheternas": "känslolöshet",
    "känslolösheters": "känslolöshet",
    "känslolöshets": "känslolöshet",
    "känslolöst": "känslolös",
    "känslolösts": "känslolös",
    "känslomänniskan": "känslomänniska",
    "känslomänniskans": "känslomänniska",
    "känslomänniskas": "känslomänniska",
    "känslomännisko": "känslomänniska",
    "känslomänniskor": "känslomänniska",
    "känslomänniskorna": "känslomänniska",
    "känslomänniskornas": "känslomänniska",
    "känslomänniskors": "känslomänniska",
    "känslomässiga": "känslomässig",
    "känslomässigare": "känslomässig",
    "känslomässigares": "känslomässig",
    "känslomässigas": "känslomässig",
    "känslomässigast": "känslomässig",
    "känslomässigaste": "känslomässig",
    "känslomässigastes": "känslomässig",
    "känslomässigasts": "känslomässig",
    "känslomässige": "känslomässig",
    "känslomässiges": "känslomässig",
    "känslomässigheten": "känslomässighet",
    "känslomässighetens": "känslomässighet",
    "känslomässighets": "känslomässighet",
    "känslomässigs": "känslomässig",
    "känslomässigt": "känslomässig",
    "känslomässigts": "känslomässig",
    "känslopjunket": "känslopjunk",
    "känslopjunkets": "känslopjunk",
    "känslopjunks": "känslopjunk",
    "känslor": "känsla",
    "känslorna": "känsla",
    "känslornas": "känsla",
    "känslors": "känsla",
    "känslosamheten": "känslosamhet",
    "känslosamhetens": "känslosamhet",
    "känslosamheter": "känslosamhet",
    "känslosamheterna": "känslosamhet",
    "känslosamheternas": "känslosamhet",
    "känslosamheters": "känslosamhet",
    "känslosamhets": "känslosamhet",
    "känslosamma": "känslosam",
    "känslosammare": "känslosam",
    "känslosammares": "känslosam",
    "känslosammas": "känslosam",
    "känslosammast": "känslosam",
    "känslosammaste": "känslosam",
    "känslosammastes": "känslosam",
    "känslosammasts": "känslosam",
    "känslosamme": "känslosam",
    "känslosammes": "känslosam",
    "känslosams": "känslosam",
    "känslosamt": "känslosam",
    "känslosamts": "känslosam",
    "känslosträngar": "känslosträng",
    "känslosträngarna": "känslosträng",
    "känslosträngarnas": "känslosträng",
    "känslosträngars": "känslosträng",
    "känslosträngen": "känslosträng",
    "känslosträngens": "känslosträng",
    "känslosträngs": "känslosträng",
    "känslotänkandes": "känslotänkande",
    "känslotänkandet": "känslotänkande",
    "känslotänkandets": "känslotänkande",
    "känsloutbrotten": "känsloutbrott",
    "känsloutbrottens": "känsloutbrott",
    "känsloutbrottet": "känsloutbrott",
    "känsloutbrottets": "känsloutbrott",
    "känsloutbrotts": "känsloutbrott",
    "känslouttrycken": "känslouttryck",
    "känslouttryckens": "känslouttryck",
    "känslouttrycket": "känslouttryck",
    "känslouttryckets": "känslouttryck",
    "känslouttrycks": "känslouttryck",
    "känt": "känna",
    "känts": "kännas",
    "käppar": "käpp",
    "käpparna": "käpp",
    "käpparnas": "käpp",
    "käppars": "käpp",
    "käppen": "käpp",
    "käppens": "käpp",
    "käpphästar": "käpphäst",
    "käpphästarna": "käpphäst",
    "käpphästarnas": "käpphäst",
    "käpphästars": "käpphäst",
    "käpphästen": "käpphäst",
    "käpphästens": "käpphäst",
    "käpphästs": "käpphäst",
    "käppkryck": "käppkrycka",
    "käppkryckan": "käppkrycka",
    "käppkryckans": "käppkrycka",
    "käppkryckas": "käppkrycka",
    "käppkrycke": "käppkrycka",
    "käppkryckor": "käppkrycka",
    "käppkryckorna": "käppkrycka",
    "käppkryckornas": "käppkrycka",
    "käppkryckors": "käppkrycka",
    "käppkrycks": "käppkrycka",
    "käppraka": "käpprak",
    "käpprakare": "käpprak",
    "käpprakares": "käpprak",
    "käpprakas": "käpprak",
    "käpprakast": "käpprak",
    "käpprakaste": "käpprak",
    "käpprakastes": "käpprak",
    "käpprakasts": "käpprak",
    "käpprake": "käpprak",
    "käpprakes": "käpprak",
    "käppraks": "käpprak",
    "käpprakt": "käpprak",
    "käpprakts": "käpprak",
    "käpps": "käpp",
    "kär": "kära",
    "kära": "kär",
    "kärad": "kära",
    "kärade": "kära",
    "kärades": "kära",
    "kärads": "kära",
    "kärande": "kära",
    "käranden": "kärande",
    "kärandena": "kärande",
    "kärandenas": "kärande",
    "kärandens": "kärande",
    "kärandes": "kärande",
    "kärandet": "kärande",
    "kärandets": "kärande",
    "kärar": "kära",
    "kärare": "kär",
    "kärares": "kär",
    "käras": "kära",
    "kärast": "kär",
    "käraste": "kär",
    "kärasten": "käraste",
    "kärastens": "käraste",
    "kärastes": "käraste",
    "kärasts": "kär",
    "kärat": "kära",
    "kärats": "kära",
    "käre": "kär",
    "käres": "kär",
    "kärest": "käresta",
    "kärestan": "käresta",
    "kärestans": "käresta",
    "kärestas": "käresta",
    "käreste": "käresta",
    "kärestor": "käresta",
    "kärestorna": "käresta",
    "kärestornas": "käresta",
    "kärestors": "käresta",
    "kärheten": "kärhet",
    "kärhetens": "kärhet",
    "kärhets": "kärhet",
    "kärilen": "käril",
    "kärilens": "käril",
    "kärilet": "käril",
    "kärilets": "käril",
    "kärils": "käril",
    "käringar": "käring",
    "käringarna": "käring",
    "käringarnas": "käring",
    "käringars": "käring",
    "käringen": "käring",
    "käringens": "käring",
    "käringknopar": "käringknop",
    "käringknoparna": "käringknop",
    "käringknoparnas": "käringknop",
    "käringknopars": "käringknop",
    "käringknopen": "käringknop",
    "käringknopens": "käringknop",
    "käringknops": "käringknop",
    "käringknutar": "käringknut",
    "käringknutarna": "käringknut",
    "käringknutarnas": "käringknut",
    "käringknutars": "käringknut",
    "käringknuten": "käringknut",
    "käringknutens": "käringknut",
    "käringknuts": "käringknut",
    "käringpratet": "käringprat",
    "käringpratets": "käringprat",
    "käringprats": "käringprat",
    "kärings": "käring",
    "käringtanden": "käringtand",
    "käringtandens": "käringtand",
    "käringtands": "käringtand",
    "kärkommenheten": "kärkommenhet",
    "kärkommenhetens": "kärkommenhet",
    "kärkommenhets": "kärkommenhet",
    "kärkommens": "kärkommen",
    "kärkommet": "kärkommen",
    "kärkommets": "kärkommen",
    "kärkomna": "kärkommen",
    "kärkomnare": "kärkommen",
    "kärkomnares": "kärkommen",
    "kärkomnas": "kärkommen",
    "kärkomnast": "kärkommen",
    "kärkomnaste": "kärkommen",
    "kärkomnastes": "kärkommen",
    "kärkomnasts": "kärkommen",
    "kärkomne": "kärkommen",
    "kärkomnes": "kärkommen",
    "kärlekar": "kärlek",
    "kärlekarna": "kärlek",
    "kärlekarnas": "kärlek",
    "kärlekars": "kärlek",
    "kärleken": "kärlek",
    "kärlekens": "kärlek",
    "kärleks": "kärlek",
    "kärleksaffären": "kärleksaffär",
    "kärleksaffärens": "kärleksaffär",
    "kärleksaffärer": "kärleksaffär",
    "kärleksaffärerna": "kärleksaffär",
    "kärleksaffärernas": "kärleksaffär",
    "kärleksaffärers": "kärleksaffär",
    "kärleksaffärs": "kärleksaffär",
    "kärleksakten": "kärleksakt",
    "kärleksaktens": "kärleksakt",
    "kärleksakter": "kärleksakt",
    "kärleksakterna": "kärleksakt",
    "kärleksakternas": "kärleksakt",
    "kärleksakters": "kärleksakt",
    "kärleksakts": "kärleksakt",
    "kärleksbarden": "kärleksbard",
    "kärleksbardens": "kärleksbard",
    "kärleksbarder": "kärleksbard",
    "kärleksbarderna": "kärleksbard",
    "kärleksbardernas": "kärleksbard",
    "kärleksbarders": "kärleksbard",
    "kärleksbards": "kärleksbard",
    "kärleksbarnen": "kärleksbarn",
    "kärleksbarnens": "kärleksbarn",
    "kärleksbarnet": "kärleksbarn",
    "kärleksbarnets": "kärleksbarn",
    "kärleksbarns": "kärleksbarn",
    "kärleksberedda": "kärleksberedd",
    "kärleksbereddare": "kärleksberedd",
    "kärleksbereddares": "kärleksberedd",
    "kärleksbereddas": "kärleksberedd",
    "kärleksbereddast": "kärleksberedd",
    "kärleksbereddaste": "kärleksberedd",
    "kärleksbereddastes": "kärleksberedd",
    "kärleksbereddasts": "kärleksberedd",
    "kärleksberedde": "kärleksberedd",
    "kärleksbereddes": "kärleksberedd",
    "kärleksberedds": "kärleksberedd",
    "kärleksberett": "kärleksberedd",
    "kärleksberetts": "kärleksberedd",
    "kärleksbetygelsen": "kärleksbetygelse",
    "kärleksbetygelsens": "kärleksbetygelse",
    "kärleksbetygelser": "kärleksbetygelse",
    "kärleksbetygelserna": "kärleksbetygelse",
    "kärleksbetygelsernas": "kärleksbetygelse",
    "kärleksbetygelsers": "kärleksbetygelse",
    "kärleksbetygelses": "kärleksbetygelse",
    "kärleksbreven": "kärleksbrev",
    "kärleksbrevens": "kärleksbrev",
    "kärleksbrevet": "kärleksbrev",
    "kärleksbrevets": "kärleksbrev",
    "kärleksbrevs": "kärleksbrev",
    "kärleksbuden": "kärleksbud",
    "kärleksbudens": "kärleksbud",
    "kärleksbudet": "kärleksbud",
    "kärleksbudets": "kärleksbud",
    "kärleksbuds": "kärleksbud",
    "kärleksdikten": "kärleksdikt",
    "kärleksdiktens": "kärleksdikt",
    "kärleksdikter": "kärleksdikt",
    "kärleksdikterna": "kärleksdikt",
    "kärleksdikternas": "kärleksdikt",
    "kärleksdikters": "kärleksdikt",
    "kärleksdikts": "kärleksdikt",
    "kärleksdrycken": "kärleksdryck",
    "kärleksdryckens": "kärleksdryck",
    "kärleksdrycker": "kärleksdryck",
    "kärleksdryckerna": "kärleksdryck",
    "kärleksdryckernas": "kärleksdryck",
    "kärleksdryckers": "kärleksdryck",
    "kärleksdrycks": "kärleksdryck",
    "kärleksfulla": "kärleksfull",
    "kärleksfullare": "kärleksfull",
    "kärleksfullares": "kärleksfull",
    "kärleksfullas": "kärleksfull",
    "kärleksfullast": "kärleksfull",
    "kärleksfullaste": "kärleksfull",
    "kärleksfullastes": "kärleksfull",
    "kärleksfullasts": "kärleksfull",
    "kärleksfulle": "kärleksfull",
    "kärleksfulles": "kärleksfull",
    "kärleksfullheten": "kärleksfullhet",
    "kärleksfullhetens": "kärleksfullhet",
    "kärleksfullhets": "kärleksfullhet",
    "kärleksfulls": "kärleksfull",
    "kärleksfullt": "kärleksfull",
    "kärleksfullts": "kärleksfull",
    "kärleksförbindelsen": "kärleksförbindelse",
    "kärleksförbindelsens": "kärleksförbindelse",
    "kärleksförbindelser": "kärleksförbindelse",
    "kärleksförbindelserna": "kärleksförbindelse",
    "kärleksförbindelsernas": "kärleksförbindelse",
    "kärleksförbindelsers": "kärleksförbindelse",
    "kärleksförbindelses": "kärleksförbindelse",
    "kärleksförhållanden": "kärleksförhållande",
    "kärleksförhållandena": "kärleksförhållande",
    "kärleksförhållandenas": "kärleksförhållande",
    "kärleksförhållandens": "kärleksförhållande",
    "kärleksförhållandes": "kärleksförhållande",
    "kärleksförhållandet": "kärleksförhållande",
    "kärleksförhållandets": "kärleksförhållande",
    "kärleksgnabbet": "kärleksgnabb",
    "kärleksgnabbets": "kärleksgnabb",
    "kärleksgnabbs": "kärleksgnabb",
    "kärleksgudar": "kärleksgud",
    "kärleksgudarna": "kärleksgud",
    "kärleksgudarnas": "kärleksgud",
    "kärleksgudars": "kärleksgud",
    "kärleksguden": "kärleksgud",
    "kärleksgudens": "kärleksgud",
    "kärleksgudinnan": "kärleksgudinna",
    "kärleksgudinnans": "kärleksgudinna",
    "kärleksgudinnas": "kärleksgudinna",
    "kärleksgudinne": "kärleksgudinna",
    "kärleksgudinnor": "kärleksgudinna",
    "kärleksgudinnorna": "kärleksgudinna",
    "kärleksgudinnornas": "kärleksgudinna",
    "kärleksgudinnors": "kärleksgudinna",
    "kärleksguds": "kärleksgud",
    "kärleksgärningar": "kärleksgärning",
    "kärleksgärningarna": "kärleksgärning",
    "kärleksgärningarnas": "kärleksgärning",
    "kärleksgärningars": "kärleksgärning",
    "kärleksgärningen": "kärleksgärning",
    "kärleksgärningens": "kärleksgärning",
    "kärleksgärnings": "kärleksgärning",
    "kärlekshistorian": "kärlekshistoria",
    "kärlekshistorians": "kärlekshistoria",
    "kärlekshistorias": "kärlekshistoria",
    "kärlekshistorien": "kärlekshistoria",
    "kärlekshistoriens": "kärlekshistoria",
    "kärlekshistorier": "kärlekshistoria",
    "kärlekshistorierna": "kärlekshistoria",
    "kärlekshistoriernas": "kärlekshistoria",
    "kärlekshistoriers": "kärlekshistoria",
    "kärleksknepen": "kärleksknep",
    "kärleksknepens": "kärleksknep",
    "kärleksknepet": "kärleksknep",
    "kärleksknepets": "kärleksknep",
    "kärlekskneps": "kärleksknep",
    "kärlekskonflikten": "kärlekskonflikt",
    "kärlekskonfliktens": "kärlekskonflikt",
    "kärlekskonflikter": "kärlekskonflikt",
    "kärlekskonflikterna": "kärlekskonflikt",
    "kärlekskonflikternas": "kärlekskonflikt",
    "kärlekskonflikters": "kärlekskonflikt",
    "kärlekskonflikts": "kärlekskonflikt",
    "kärlekskranka": "kärlekskrank",
    "kärlekskrankare": "kärlekskrank",
    "kärlekskrankares": "kärlekskrank",
    "kärlekskrankas": "kärlekskrank",
    "kärlekskrankast": "kärlekskrank",
    "kärlekskrankaste": "kärlekskrank",
    "kärlekskrankastes": "kärlekskrank",
    "kärlekskrankasts": "kärlekskrank",
    "kärlekskranke": "kärlekskrank",
    "kärlekskrankes": "kärlekskrank",
    "kärlekskrankheten": "kärlekskrankhet",
    "kärlekskrankhetens": "kärlekskrankhet",
    "kärlekskrankhets": "kärlekskrankhet",
    "kärlekskranks": "kärlekskrank",
    "kärlekskrankt": "kärlekskrank",
    "kärlekskrankts": "kärlekskrank",
    "kärlekskrisen": "kärlekskris",
    "kärlekskrisens": "kärlekskris",
    "kärlekskriser": "kärlekskris",
    "kärlekskriserna": "kärlekskris",
    "kärlekskrisernas": "kärlekskris",
    "kärlekskrisers": "kärlekskris",
    "kärlekskvalen": "kärlekskval",
    "kärlekskvalens": "kärlekskval",
    "kärlekskvalet": "kärlekskval",
    "kärlekskvalets": "kärlekskval",
    "kärlekskvals": "kärlekskval",
    "kärlekslivet": "kärleksliv",
    "kärlekslivets": "kärleksliv",
    "kärlekslivs": "kärleksliv",
    "kärlekslyckan": "kärlekslycka",
    "kärlekslyckans": "kärlekslycka",
    "kärlekslyckas": "kärlekslycka",
    "kärlekslycke": "kärlekslycka",
    "kärlekslycko": "kärlekslycka",
    "kärlekslyriken": "kärlekslyrik",
    "kärlekslyrikens": "kärlekslyrik",
    "kärlekslyriks": "kärlekslyrik",
    "kärlekslängtans": "kärlekslängtan",
    "kärlekslåsen": "kärlekslås",
    "kärlekslåsens": "kärlekslås",
    "kärlekslåset": "kärlekslås",
    "kärlekslåsets": "kärlekslås",
    "kärlekslösa": "kärlekslös",
    "kärlekslösare": "kärlekslös",
    "kärlekslösares": "kärlekslös",
    "kärlekslösas": "kärlekslös",
    "kärlekslösast": "kärlekslös",
    "kärlekslösaste": "kärlekslös",
    "kärlekslösastes": "kärlekslös",
    "kärlekslösasts": "kärlekslös",
    "kärlekslöse": "kärlekslös",
    "kärlekslöses": "kärlekslös",
    "kärlekslösheten": "kärlekslöshet",
    "kärlekslöshetens": "kärlekslöshet",
    "kärlekslöshets": "kärlekslöshet",
    "kärlekslöst": "kärlekslös",
    "kärlekslösts": "kärlekslös",
    "kärleksmumsen": "kärleksmums",
    "kärleksmumsens": "kärleksmums",
    "kärleksmumset": "kärleksmums",
    "kärleksmumsets": "kärleksmums",
    "kärleksmöten": "kärleksmöte",
    "kärleksmötena": "kärleksmöte",
    "kärleksmötenas": "kärleksmöte",
    "kärleksmötens": "kärleksmöte",
    "kärleksmötes": "kärleksmöte",
    "kärleksmötet": "kärleksmöte",
    "kärleksmötets": "kärleksmöte",
    "kärleksnovellen": "kärleksnovell",
    "kärleksnovellens": "kärleksnovell",
    "kärleksnoveller": "kärleksnovell",
    "kärleksnovellerna": "kärleksnovell",
    "kärleksnovellernas": "kärleksnovell",
    "kärleksnovellers": "kärleksnovell",
    "kärleksnovells": "kärleksnovell",
    "kärleksorden": "kärleksord",
    "kärleksordens": "kärleksord",
    "kärleksordet": "kärleksord",
    "kärleksordets": "kärleksord",
    "kärleksords": "kärleksord",
    "kärleksparen": "kärlekspar",
    "kärleksparens": "kärlekspar",
    "kärleksparet": "kärlekspar",
    "kärleksparets": "kärlekspar",
    "kärlekspars": "kärlekspar",
    "kärleksrelationen": "kärleksrelation",
    "kärleksrelationens": "kärleksrelation",
    "kärleksrelationer": "kärleksrelation",
    "kärleksrelationerna": "kärleksrelation",
    "kärleksrelationernas": "kärleksrelation",
    "kärleksrelationers": "kärleksrelation",
    "kärleksrelations": "kärleksrelation",
    "kärleksromanen": "kärleksroman",
    "kärleksromanens": "kärleksroman",
    "kärleksromaner": "kärleksroman",
    "kärleksromanerna": "kärleksroman",
    "kärleksromanernas": "kärleksroman",
    "kärleksromaners": "kärleksroman",
    "kärleksromans": "kärleksroman",
    "kärlekssagan": "kärlekssaga",
    "kärlekssagans": "kärlekssaga",
    "kärlekssagas": "kärlekssaga",
    "kärlekssage": "kärlekssaga",
    "kärlekssago": "kärlekssaga",
    "kärlekssagor": "kärlekssaga",
    "kärlekssagorna": "kärlekssaga",
    "kärlekssagornas": "kärlekssaga",
    "kärlekssagors": "kärlekssaga",
    "kärleksstrejken": "kärleksstrejk",
    "kärleksstrejkens": "kärleksstrejk",
    "kärleksstrejker": "kärleksstrejk",
    "kärleksstrejkerna": "kärleksstrejk",
    "kärleksstrejkernas": "kärleksstrejk",
    "kärleksstrejkers": "kärleksstrejk",
    "kärleksstrejks": "kärleksstrejk",
    "kärlekstunlar": "kärlekstunnel",
    "kärlekstunlarna": "kärlekstunnel",
    "kärlekstunlarnas": "kärlekstunnel",
    "kärlekstunlars": "kärlekstunnel",
    "kärlekstunneln": "kärlekstunnel",
    "kärlekstunnelns": "kärlekstunnel",
    "kärlekstunnels": "kärlekstunnel",
    "kärlekstunnlar": "kärlekstunnel",
    "kärlekstunnlarna": "kärlekstunnel",
    "kärlekstunnlarnas": "kärlekstunnel",
    "kärlekstunnlars": "kärlekstunnel",
    "kärleksvalen": "kärleksval",
    "kärleksvalens": "kärleksval",
    "kärleksvalet": "kärleksval",
    "kärleksvalets": "kärleksval",
    "kärleksvals": "kärleksval",
    "kärleksörten": "kärleksört",
    "kärleksörtens": "kärleksört",
    "kärleksörts": "kärleksört",
    "kärlen": "kärl",
    "kärlens": "kärl",
    "kärlet": "kärl",
    "kärlets": "kärl",
    "kärliga": "kärlig",
    "kärligare": "kärlig",
    "kärligares": "kärlig",
    "kärligas": "kärlig",
    "kärligast": "kärlig",
    "kärligaste": "kärlig",
    "kärligastes": "kärlig",
    "kärligasts": "kärlig",
    "kärlige": "kärlig",
    "kärliges": "kärlig",
    "kärligheten": "kärlighet",
    "kärlighetens": "kärlighet",
    "kärlighets": "kärlighet",
    "kärligs": "kärlig",
    "kärligt": "kärlig",
    "kärligts": "kärlig",
    "kärlkrampen": "kärlkramp",
    "kärlkrampens": "kärlkramp",
    "kärlkramps": "kärlkramp",
    "kärls": "kärl",
    "kärlsjukdomar": "kärlsjukdom",
    "kärlsjukdomarna": "kärlsjukdom",
    "kärlsjukdomarnas": "kärlsjukdom",
    "kärlsjukdomars": "kärlsjukdom",
    "kärlsjukdomen": "kärlsjukdom",
    "kärlsjukdomens": "kärlsjukdom",
    "kärlsjukdoms": "kärlsjukdom",
    "kärlsvulsten": "kärlsvulst",
    "kärlsvulstens": "kärlsvulst",
    "kärlsvulster": "kärlsvulst",
    "kärlsvulsterna": "kärlsvulst",
    "kärlsvulsternas": "kärlsvulst",
    "kärlsvulsters": "kärlsvulst",
    "kärlsvulsts": "kärlsvulst",
    "kärn": "kärna",
    "kärnad": "kärna",
    "kärnade": "kärna",
    "kärnades": "kärna",
    "kärnads": "kärna",
    "kärnan": "kärna",
    "kärnande": "kärna",
    "kärnanden": "kärnande",
    "kärnandena": "kärnande",
    "kärnandenas": "kärnande",
    "kärnandens": "kärnande",
    "kärnandes": "kärnande",
    "kärnandet": "kärnande",
    "kärnandets": "kärnande",
    "kärnans": "kärna",
    "kärnar": "kärna",
    "kärnas": "kärna",
    "kärnat": "kärna",
    "kärnats": "kärna",
    "kärnbränslen": "kärnbränsle",
    "kärnbränslena": "kärnbränsle",
    "kärnbränslenas": "kärnbränsle",
    "kärnbränslens": "kärnbränsle",
    "kärnbränsles": "kärnbränsle",
    "kärnbränslet": "kärnbränsle",
    "kärnbränslets": "kärnbränsle",
    "kärne": "kärna",
    "kärnenergien": "kärnenergi",
    "kärnenergiens": "kärnenergi",
    "kärnenergin": "kärnenergi",
    "kärnenergins": "kärnenergi",
    "kärnenergis": "kärnenergi",
    "kärnfamiljen": "kärnfamilj",
    "kärnfamiljens": "kärnfamilj",
    "kärnfamiljer": "kärnfamilj",
    "kärnfamiljerna": "kärnfamilj",
    "kärnfamiljernas": "kärnfamilj",
    "kärnfamiljers": "kärnfamilj",
    "kärnfamiljs": "kärnfamilj",
    "kärnforskningar": "kärnforskning",
    "kärnforskningarna": "kärnforskning",
    "kärnforskningarnas": "kärnforskning",
    "kärnforskningars": "kärnforskning",
    "kärnforskningen": "kärnforskning",
    "kärnforskningens": "kärnforskning",
    "kärnforsknings": "kärnforskning",
    "kärnfria": "kärnfri",
    "kärnfriare": "kärnfri",
    "kärnfriares": "kärnfri",
    "kärnfrias": "kärnfri",
    "kärnfriast": "kärnfri",
    "kärnfriaste": "kärnfri",
    "kärnfriastes": "kärnfri",
    "kärnfriasts": "kärnfri",
    "kärnfrie": "kärnfri",
    "kärnfries": "kärnfri",
    "kärnfris": "kärnfri",
    "kärnfriska": "kärnfrisk",
    "kärnfriskare": "kärnfrisk",
    "kärnfriskares": "kärnfrisk",
    "kärnfriskas": "kärnfrisk",
    "kärnfriskast": "kärnfrisk",
    "kärnfriskaste": "kärnfrisk",
    "kärnfriskastes": "kärnfrisk",
    "kärnfriskasts": "kärnfrisk",
    "kärnfriske": "kärnfrisk",
    "kärnfriskes": "kärnfrisk",
    "kärnfrisks": "kärnfrisk",
    "kärnfriskt": "kärnfrisk",
    "kärnfriskts": "kärnfrisk",
    "kärnfritt": "kärnfri",
    "kärnfritts": "kärnfri",
    "kärnfrukten": "kärnfrukt",
    "kärnfruktens": "kärnfrukt",
    "kärnfrukter": "kärnfrukt",
    "kärnfrukterna": "kärnfrukt",
    "kärnfrukternas": "kärnfrukt",
    "kärnfrukters": "kärnfrukt",
    "kärnfrukts": "kärnfrukt",
    "kärnfrågan": "kärnfråga",
    "kärnfrågans": "kärnfråga",
    "kärnfrågas": "kärnfråga",
    "kärnfråge": "kärnfråga",
    "kärnfrågor": "kärnfråga",
    "kärnfrågorna": "kärnfråga",
    "kärnfrågornas": "kärnfråga",
    "kärnfrågors": "kärnfråga",
    "kärnfulla": "kärnfull",
    "kärnfullare": "kärnfull",
    "kärnfullares": "kärnfull",
    "kärnfullas": "kärnfull",
    "kärnfullast": "kärnfull",
    "kärnfullaste": "kärnfull",
    "kärnfullastes": "kärnfull",
    "kärnfullasts": "kärnfull",
    "kärnfulle": "kärnfull",
    "kärnfulles": "kärnfull",
    "kärnfullheten": "kärnfullhet",
    "kärnfullhetens": "kärnfullhet",
    "kärnfullheter": "kärnfullhet",
    "kärnfullheterna": "kärnfullhet",
    "kärnfullheternas": "kärnfullhet",
    "kärnfullheters": "kärnfullhet",
    "kärnfullhets": "kärnfullhet",
    "kärnfulls": "kärnfull",
    "kärnfullt": "kärnfull",
    "kärnfullts": "kärnfull",
    "kärnfuren": "kärnfur",
    "kärnfurens": "kärnfur",
    "kärnfurs": "kärnfur",
    "kärnfysiken": "kärnfysik",
    "kärnfysikens": "kärnfysik",
    "kärnfysiks": "kärnfysik",
    "kärngubb": "kärngubbe",
    "kärngubbar": "kärngubbe",
    "kärngubbarna": "kärngubbe",
    "kärngubbarnas": "kärngubbe",
    "kärngubbars": "kärngubbe",
    "kärngubben": "kärngubbe",
    "kärngubbens": "kärngubbe",
    "kärngubbes": "kärngubbe",
    "kärngubbs": "kärngubbe",
    "kärngum": "kärngumma",
    "kärngumman": "kärngumma",
    "kärngummans": "kärngumma",
    "kärngummas": "kärngumma",
    "kärngumme": "kärngumma",
    "kärngummor": "kärngumma",
    "kärngummorna": "kärngumma",
    "kärngummornas": "kärngumma",
    "kärngummors": "kärngumma",
    "kärngums": "kärngumma",
    "kärnhusen": "kärnhus",
    "kärnhusens": "kärnhus",
    "kärnhuset": "kärnhus",
    "kärnhusets": "kärnhus",
    "kärnisen": "kärnis",
    "kärnisens": "kärnis",
    "kärnkemien": "kärnkemi",
    "kärnkemiens": "kärnkemi",
    "kärnkemin": "kärnkemi",
    "kärnkemins": "kärnkemi",
    "kärnkemis": "kärnkemi",
    "kärnklyvningar": "kärnklyvning",
    "kärnklyvningarna": "kärnklyvning",
    "kärnklyvningarnas": "kärnklyvning",
    "kärnklyvningars": "kärnklyvning",
    "kärnklyvningen": "kärnklyvning",
    "kärnklyvningens": "kärnklyvning",
    "kärnklyvnings": "kärnklyvning",
    "kärnkraften": "kärnkraft",
    "kärnkraftens": "kärnkraft",
    "kärnkraftinspektionen": "kärnkraftinspektion",
    "kärnkraftinspektionens": "kärnkraftinspektion",
    "kärnkraftinspektioner": "kärnkraftinspektion",
    "kärnkraftinspektionerna": "kärnkraftinspektion",
    "kärnkraftinspektionernas": "kärnkraftinspektion",
    "kärnkraftinspektioners": "kärnkraftinspektion",
    "kärnkraftinspektions": "kärnkraftinspektion",
    "kärnkrafts": "kärnkraft",
    "kärnkraftsavfallet": "kärnkraftsavfall",
    "kärnkraftsavfallets": "kärnkraftsavfall",
    "kärnkraftsavfalls": "kärnkraftsavfall",
    "kärnkraftsmotståndar": "kärnkraftsmotståndare",
    "kärnkraftsmotståndaren": "kärnkraftsmotståndare",
    "kärnkraftsmotståndarens": "kärnkraftsmotståndare",
    "kärnkraftsmotståndares": "kärnkraftsmotståndare",
    "kärnkraftsmotståndarna": "kärnkraftsmotståndare",
    "kärnkraftsmotståndarnas": "kärnkraftsmotståndare",
    "kärnkraftsolyck": "kärnkraftsolycka",
    "kärnkraftsolyckan": "kärnkraftsolycka",
    "kärnkraftsolyckans": "kärnkraftsolycka",
    "kärnkraftsolyckas": "kärnkraftsolycka",
    "kärnkraftsolycke": "kärnkraftsolycka",
    "kärnkraftsolyckor": "kärnkraftsolycka",
    "kärnkraftsolyckorna": "kärnkraftsolycka",
    "kärnkraftsolyckornas": "kärnkraftsolycka",
    "kärnkraftsolyckors": "kärnkraftsolycka",
    "kärnkraftsolycks": "kärnkraftsolycka",
    "kärnkraftsoperatören": "kärnkraftsoperatör",
    "kärnkraftsoperatörens": "kärnkraftsoperatör",
    "kärnkraftsoperatörer": "kärnkraftsoperatör",
    "kärnkraftsoperatörerna": "kärnkraftsoperatör",
    "kärnkraftsoperatörernas": "kärnkraftsoperatör",
    "kärnkraftsoperatörers": "kärnkraftsoperatör",
    "kärnkraftsoperatörs": "kärnkraftsoperatör",
    "kärnkraftsutbyggnaden": "kärnkraftsutbyggnad",
    "kärnkraftsutbyggnadens": "kärnkraftsutbyggnad",
    "kärnkraftsutbyggnads": "kärnkraftsutbyggnad",
    "kärnkraftsäkerheten": "kärnkraftsäkerhet",
    "kärnkraftsäkerhetens": "kärnkraftsäkerhet",
    "kärnkraftsäkerheter": "kärnkraftsäkerhet",
    "kärnkraftsäkerheterna": "kärnkraftsäkerhet",
    "kärnkraftsäkerheternas": "kärnkraftsäkerhet",
    "kärnkraftsäkerheters": "kärnkraftsäkerhet",
    "kärnkraftsäkerhets": "kärnkraftsäkerhet",
    "kärnkraftverken": "kärnkraftverk",
    "kärnkraftverkens": "kärnkraftverk",
    "kärnkraftverket": "kärnkraftverk",
    "kärnkraftverkets": "kärnkraftverk",
    "kärnkraftverks": "kärnkraftverk",
    "kärnladdningar": "kärnladdning",
    "kärnladdningarna": "kärnladdning",
    "kärnladdningarnas": "kärnladdning",
    "kärnladdningars": "kärnladdning",
    "kärnladdningen": "kärnladdning",
    "kärnladdningens": "kärnladdning",
    "kärnladdnings": "kärnladdning",
    "kärnlanden": "kärnland",
    "kärnlandens": "kärnland",
    "kärnlandet": "kärnland",
    "kärnlandets": "kärnland",
    "kärnlands": "kärnland",
    "kärnlinjen": "kärnlinje",
    "kärnlinjens": "kärnlinje",
    "kärnlinjer": "kärnlinje",
    "kärnlinjerna": "kärnlinje",
    "kärnlinjernas": "kärnlinje",
    "kärnlinjers": "kärnlinje",
    "kärnlinjes": "kärnlinje",
    "kärnminnen": "kärnminne",
    "kärnminnena": "kärnminne",
    "kärnminnenas": "kärnminne",
    "kärnminnens": "kärnminne",
    "kärnminnes": "kärnminne",
    "kärnminnet": "kärnminne",
    "kärnminnets": "kärnminne",
    "kärnmjölken": "kärnmjölk",
    "kärnmjölkens": "kärnmjölk",
    "kärnmjölks": "kärnmjölk",
    "kärnor": "kärna",
    "kärnorna": "kärna",
    "kärnornas": "kärna",
    "kärnors": "kärna",
    "kärnpartikeln": "kärnpartikel",
    "kärnpartikelns": "kärnpartikel",
    "kärnpartikels": "kärnpartikel",
    "kärnpartiklar": "kärnpartikel",
    "kärnpartiklarna": "kärnpartikel",
    "kärnpartiklarnas": "kärnpartikel",
    "kärnpartiklars": "kärnpartikel",
    "kärnpunkten": "kärnpunkt",
    "kärnpunktens": "kärnpunkt",
    "kärnpunkter": "kärnpunkt",
    "kärnpunkterna": "kärnpunkt",
    "kärnpunkternas": "kärnpunkt",
    "kärnpunkters": "kärnpunkt",
    "kärnpunkts": "kärnpunkt",
    "kärnreaktionen": "kärnreaktion",
    "kärnreaktionens": "kärnreaktion",
    "kärnreaktioner": "kärnreaktion",
    "kärnreaktionerna": "kärnreaktion",
    "kärnreaktionernas": "kärnreaktion",
    "kärnreaktioners": "kärnreaktion",
    "kärnreaktions": "kärnreaktion",
    "kärnreaktorbyggen": "kärnreaktorbygge",
    "kärnreaktorbyggena": "kärnreaktorbygge",
    "kärnreaktorbyggenas": "kärnreaktorbygge",
    "kärnreaktorbyggens": "kärnreaktorbygge",
    "kärnreaktorbygges": "kärnreaktorbygge",
    "kärnreaktorbygget": "kärnreaktorbygge",
    "kärnreaktorbyggets": "kärnreaktorbygge",
    "kärnreaktorer": "kärnreaktor",
    "kärnreaktorerna": "kärnreaktor",
    "kärnreaktorernas": "kärnreaktor",
    "kärnreaktorers": "kärnreaktor",
    "kärnreaktorn": "kärnreaktor",
    "kärnreaktorns": "kärnreaktor",
    "kärnreaktors": "kärnreaktor",
    "kärnriken": "kärnrike",
    "kärnrikena": "kärnrike",
    "kärnrikenas": "kärnrike",
    "kärnrikens": "kärnrike",
    "kärnrikes": "kärnrike",
    "kärnriket": "kärnrike",
    "kärnrikets": "kärnrike",
    "kärns": "kärna",
    "kärnskugg": "kärnskugga",
    "kärnskuggan": "kärnskugga",
    "kärnskuggans": "kärnskugga",
    "kärnskuggas": "kärnskugga",
    "kärnskugge": "kärnskugga",
    "kärnskuggor": "kärnskugga",
    "kärnskuggorna": "kärnskugga",
    "kärnskuggornas": "kärnskugga",
    "kärnskuggors": "kärnskugga",
    "kärnskuggs": "kärnskugga",
    "kärnsönderfallen": "kärnsönderfall",
    "kärnsönderfallens": "kärnsönderfall",
    "kärnsönderfallet": "kärnsönderfall",
    "kärnsönderfallets": "kärnsönderfall",
    "kärnsönderfalls": "kärnsönderfall",
    "kärntekniken": "kärnteknik",
    "kärnteknikens": "kärnteknik",
    "kärntekniks": "kärnteknik",
    "kärntekniska": "kärnteknisk",
    "kärntekniskas": "kärnteknisk",
    "kärntekniske": "kärnteknisk",
    "kärntekniskes": "kärnteknisk",
    "kärnteknisks": "kärnteknisk",
    "kärntekniskt": "kärnteknisk",
    "kärntekniskts": "kärnteknisk",
    "kärnteknologien": "kärnteknologi",
    "kärnteknologiens": "kärnteknologi",
    "kärnteknologier": "kärnteknologi",
    "kärnteknologierna": "kärnteknologi",
    "kärnteknologiernas": "kärnteknologi",
    "kärnteknologiers": "kärnteknologi",
    "kärnteknologin": "kärnteknologi",
    "kärnteknologins": "kärnteknologi",
    "kärnteknologis": "kärnteknologi",
    "kärntruppen": "kärntrupp",
    "kärntruppens": "kärntrupp",
    "kärntrupper": "kärntrupp",
    "kärntrupperna": "kärntrupp",
    "kärntruppernas": "kärntrupp",
    "kärntruppers": "kärntrupp",
    "kärntrupps": "kärntrupp",
    "kärnvapenarsenalen": "kärnvapenarsenal",
    "kärnvapenarsenalens": "kärnvapenarsenal",
    "kärnvapenarsenaler": "kärnvapenarsenal",
    "kärnvapenarsenalerna": "kärnvapenarsenal",
    "kärnvapenarsenalernas": "kärnvapenarsenal",
    "kärnvapenarsenalers": "kärnvapenarsenal",
    "kärnvapenarsenals": "kärnvapenarsenal",
    "kärnvapenbegränsningar": "kärnvapenbegränsning",
    "kärnvapenbegränsningarna": "kärnvapenbegränsning",
    "kärnvapenbegränsningarnas": "kärnvapenbegränsning",
    "kärnvapenbegränsningars": "kärnvapenbegränsning",
    "kärnvapenbegränsningen": "kärnvapenbegränsning",
    "kärnvapenbegränsningens": "kärnvapenbegränsning",
    "kärnvapenbegränsnings": "kärnvapenbegränsning",
    "kärnvapenbestyckade": "kärnvapenbestyckad",
    "kärnvapenbestyckades": "kärnvapenbestyckad",
    "kärnvapenbestyckads": "kärnvapenbestyckad",
    "kärnvapenbestyckat": "kärnvapenbestyckad",
    "kärnvapenbestyckats": "kärnvapenbestyckad",
    "kärnvapenexplosionen": "kärnvapenexplosion",
    "kärnvapenexplosionens": "kärnvapenexplosion",
    "kärnvapenexplosioner": "kärnvapenexplosion",
    "kärnvapenexplosionerna": "kärnvapenexplosion",
    "kärnvapenexplosionernas": "kärnvapenexplosion",
    "kärnvapenexplosioners": "kärnvapenexplosion",
    "kärnvapenexplosions": "kärnvapenexplosion",
    "kärnvapenfria": "kärnvapenfri",
    "kärnvapenfriare": "kärnvapenfri",
    "kärnvapenfriares": "kärnvapenfri",
    "kärnvapenfrias": "kärnvapenfri",
    "kärnvapenfriast": "kärnvapenfri",
    "kärnvapenfriaste": "kärnvapenfri",
    "kärnvapenfriastes": "kärnvapenfri",
    "kärnvapenfriasts": "kärnvapenfri",
    "kärnvapenfrie": "kärnvapenfri",
    "kärnvapenfries": "kärnvapenfri",
    "kärnvapenfris": "kärnvapenfri",
    "kärnvapenfritt": "kärnvapenfri",
    "kärnvapenfritts": "kärnvapenfri",
    "kärnvapeninnehaven": "kärnvapeninnehav",
    "kärnvapeninnehavens": "kärnvapeninnehav",
    "kärnvapeninnehavet": "kärnvapeninnehav",
    "kärnvapeninnehavets": "kärnvapeninnehav",
    "kärnvapeninnehavs": "kärnvapeninnehav",
    "kärnvapenkrigen": "kärnvapenkrig",
    "kärnvapenkrigens": "kärnvapenkrig",
    "kärnvapenkriget": "kärnvapenkrig",
    "kärnvapenkrigets": "kärnvapenkrig",
    "kärnvapenkrigs": "kärnvapenkrig",
    "kärnvapenmakten": "kärnvapenmakt",
    "kärnvapenmaktens": "kärnvapenmakt",
    "kärnvapenmakter": "kärnvapenmakt",
    "kärnvapenmakterna": "kärnvapenmakt",
    "kärnvapenmakternas": "kärnvapenmakt",
    "kärnvapenmakters": "kärnvapenmakt",
    "kärnvapenmakts": "kärnvapenmakt",
    "kärnvapenmässiga": "kärnvapenmässig",
    "kärnvapenmässigare": "kärnvapenmässig",
    "kärnvapenmässigares": "kärnvapenmässig",
    "kärnvapenmässigas": "kärnvapenmässig",
    "kärnvapenmässigast": "kärnvapenmässig",
    "kärnvapenmässigaste": "kärnvapenmässig",
    "kärnvapenmässigastes": "kärnvapenmässig",
    "kärnvapenmässigasts": "kärnvapenmässig",
    "kärnvapenmässige": "kärnvapenmässig",
    "kärnvapenmässiges": "kärnvapenmässig",
    "kärnvapenmässigs": "kärnvapenmässig",
    "kärnvapenmässigt": "kärnvapenmässig",
    "kärnvapenmässigts": "kärnvapenmässig",
    "kärnvapenparaplyer": "kärnvapenparaply",
    "kärnvapenparaplyerna": "kärnvapenparaply",
    "kärnvapenparaplyernas": "kärnvapenparaply",
    "kärnvapenparaplyers": "kärnvapenparaply",
    "kärnvapenparaplyet": "kärnvapenparaply",
    "kärnvapenparaplyets": "kärnvapenparaply",
    "kärnvapenparaplyn": "kärnvapenparaply",
    "kärnvapenparaplyna": "kärnvapenparaply",
    "kärnvapenparaplynas": "kärnvapenparaply",
    "kärnvapenparaplyns": "kärnvapenparaply",
    "kärnvapenparaplys": "kärnvapenparaply",
    "kärnvapenparaplyt": "kärnvapenparaply",
    "kärnvapenparaplyts": "kärnvapenparaply",
    "kärnvapenproven": "kärnvapenprov",
    "kärnvapenprovens": "kärnvapenprov",
    "kärnvapenprover": "kärnvapenprov",
    "kärnvapenproverna": "kärnvapenprov",
    "kärnvapenprovernas": "kärnvapenprov",
    "kärnvapenprovers": "kärnvapenprov",
    "kärnvapenprovet": "kärnvapenprov",
    "kärnvapenprovets": "kärnvapenprov",
    "kärnvapenprovs": "kärnvapenprov",
    "kärnvapenprovsprängningar": "kärnvapenprovsprängning",
    "kärnvapenprovsprängningarna": "kärnvapenprovsprängning",
    "kärnvapenprovsprängningarnas": "kärnvapenprovsprängning",
    "kärnvapenprovsprängningars": "kärnvapenprovsprängning",
    "kärnvapenprovsprängningen": "kärnvapenprovsprängning",
    "kärnvapenprovsprängningens": "kärnvapenprovsprängning",
    "kärnvapenprovsprängnings": "kärnvapenprovsprängning",
    "kärnvapens": "kärnvapen",
    "kärnvapenstrategien": "kärnvapenstrategi",
    "kärnvapenstrategiens": "kärnvapenstrategi",
    "kärnvapenstrategier": "kärnvapenstrategi",
    "kärnvapenstrategierna": "kärnvapenstrategi",
    "kärnvapenstrategiernas": "kärnvapenstrategi",
    "kärnvapenstrategiers": "kärnvapenstrategi",
    "kärnvapenstrategin": "kärnvapenstrategi",
    "kärnvapenstrategins": "kärnvapenstrategi",
    "kärnvapenstrategis": "kärnvapenstrategi",
    "kärnvapnen": "kärnvapen",
    "kärnvapnens": "kärnvapen",
    "kärnvapnet": "kärnvapen",
    "kärnvapnets": "kärnvapen",
    "kärnveden": "kärnved",
    "kärnvedens": "kärnved",
    "kärnveds": "kärnved",
    "kärnverksamheten": "kärnverksamhet",
    "kärnverksamhetens": "kärnverksamhet",
    "kärnverksamheter": "kärnverksamhet",
    "kärnverksamheterna": "kärnverksamhet",
    "kärnverksamheternas": "kärnverksamhet",
    "kärnverksamheters": "kärnverksamhet",
    "kärnverksamhets": "kärnverksamhet",
    "kärnvetemjölet": "kärnvetemjöl",
    "kärnvetemjölets": "kärnvetemjöl",
    "kärnvetemjöls": "kärnvetemjöl",
    "kärnvirkes": "kärnvirke",
    "kärnvirket": "kärnvirke",
    "kärnvirkets": "kärnvirke",
    "kärnväljar": "kärnväljare",
    "kärnväljaren": "kärnväljare",
    "kärnväljarens": "kärnväljare",
    "kärnväljares": "kärnväljare",
    "kärnväljarna": "kärnväljare",
    "kärnväljarnas": "kärnväljare",
    "käromålen": "käromål",
    "käromålens": "käromål",
    "käromålet": "käromål",
    "käromålets": "käromål",
    "käromåls": "käromål",
    "kärr": "kärra",
    "kärran": "kärra",
    "kärrans": "kärra",
    "kärras": "kärra",
    "kärre": "kärra",
    "kärren": "kärr",
    "kärrens": "kärr",
    "kärret": "kärr",
    "kärrets": "kärr",
    "kärrhökar": "kärrhök",
    "kärrhökarna": "kärrhök",
    "kärrhökarnas": "kärrhök",
    "kärrhökars": "kärrhök",
    "kärrhöken": "kärrhök",
    "kärrhökens": "kärrhök",
    "kärrhöks": "kärrhök",
    "kärringar": "kärring",
    "kärringarna": "kärring",
    "kärringarnas": "kärring",
    "kärringars": "kärring",
    "kärringen": "kärring",
    "kärringens": "kärring",
    "kärrings": "kärring",
    "kärror": "kärra",
    "kärrorna": "kärra",
    "kärrornas": "kärra",
    "kärrors": "kärra",
    "kärrs": "kärra",
    "kärrsnäpp": "kärrsnäppa",
    "kärrsnäppan": "kärrsnäppa",
    "kärrsnäppans": "kärrsnäppa",
    "kärrsnäppas": "kärrsnäppa",
    "kärrsnäppe": "kärrsnäppa",
    "kärrsnäppor": "kärrsnäppa",
    "kärrsnäpporna": "kärrsnäppa",
    "kärrsnäppornas": "kärrsnäppa",
    "kärrsnäppors": "kärrsnäppa",
    "kärrsnäpps": "kärrsnäppa",
    "kärrvialen": "kärrvial",
    "kärrvialens": "kärrvial",
    "kärrvialer": "kärrvial",
    "kärrvialerna": "kärrvial",
    "kärrvialernas": "kärrvial",
    "kärrvialers": "kärrvial",
    "kärrvials": "kärrvial",
    "kärrängar": "kärräng",
    "kärrängarna": "kärräng",
    "kärrängarnas": "kärräng",
    "kärrängars": "kärräng",
    "kärrängen": "kärräng",
    "kärrängens": "kärräng",
    "kärrängs": "kärräng",
    "kärs": "kär",
    "kärt": "kär",
    "kärts": "kär",
    "kärv": "kärve",
    "kärva": "kärv",
    "kärvade": "kärva",
    "kärvades": "kärva",
    "kärvande": "kärva",
    "kärvanden": "kärvande",
    "kärvandena": "kärvande",
    "kärvandenas": "kärvande",
    "kärvandens": "kärvande",
    "kärvandes": "kärvande",
    "kärvandet": "kärvande",
    "kärvandets": "kärvande",
    "kärvar": "kärve",
    "kärvare": "kärv",
    "kärvares": "kärv",
    "kärvarna": "kärve",
    "kärvarnas": "kärve",
    "kärvars": "kärve",
    "kärvas": "kärva",
    "kärvast": "kärv",
    "kärvaste": "kärv",
    "kärvastes": "kärv",
    "kärvasts": "kärv",
    "kärvat": "kärva",
    "kärvats": "kärva",
    "kärve": "kärv",
    "kärven": "kärve",
    "kärvens": "kärve",
    "kärves": "kärve",
    "kärvheten": "kärvhet",
    "kärvhetens": "kärvhet",
    "kärvhets": "kärvhet",
    "kärvs": "kärve",
    "kärvt": "kärv",
    "kärvts": "kärv",
    "kärvänliga": "kärvänlig",
    "kärvänligare": "kärvänlig",
    "kärvänligares": "kärvänlig",
    "kärvänligas": "kärvänlig",
    "kärvänligast": "kärvänlig",
    "kärvänligaste": "kärvänlig",
    "kärvänligastes": "kärvänlig",
    "kärvänligasts": "kärvänlig",
    "kärvänlige": "kärvänlig",
    "kärvänliges": "kärvänlig",
    "kärvänligheten": "kärvänlighet",
    "kärvänlighetens": "kärvänlighet",
    "kärvänligheter": "kärvänlighet",
    "kärvänligheterna": "kärvänlighet",
    "kärvänligheternas": "kärvänlighet",
    "kärvänligheters": "kärvänlighet",
    "kärvänlighets": "kärvänlighet",
    "kärvänligs": "kärvänlig",
    "kärvänligt": "kärvänlig",
    "kärvänligts": "kärvänlig",
    "kärälskeliga": "kärälskelig",
    "kärälskeligare": "kärälskelig",
    "kärälskeligares": "kärälskelig",
    "kärälskeligas": "kärälskelig",
    "kärälskeligast": "kärälskelig",
    "kärälskeligaste": "kärälskelig",
    "kärälskeligastes": "kärälskelig",
    "kärälskeligasts": "kärälskelig",
    "kärälskelige": "kärälskelig",
    "kärälskeliges": "kärälskelig",
    "kärälskeligheten": "kärälskelighet",
    "kärälskelighetens": "kärälskelighet",
    "kärälskelighets": "kärälskelighet",
    "kärälskeligs": "kärälskelig",
    "kärälskeligt": "kärälskelig",
    "kärälskeligts": "kärälskelig",
    "kärälskliga": "kärälsklig",
    "kärälskligare": "kärälsklig",
    "kärälskligares": "kärälsklig",
    "kärälskligas": "kärälsklig",
    "kärälskligast": "kärälsklig",
    "kärälskligaste": "kärälsklig",
    "kärälskligastes": "kärälsklig",
    "kärälskligasts": "kärälsklig",
    "kärälsklige": "kärälsklig",
    "kärälskliges": "kärälsklig",
    "kärälskligheten": "kärälsklighet",
    "kärälsklighetens": "kärälsklighet",
    "kärälsklighets": "kärälsklighet",
    "kärälskligs": "kärälsklig",
    "kärälskligt": "kärälsklig",
    "kärälskligts": "kärälsklig",
    "kätt": "kätte",
    "kättar": "kätte",
    "kättarbålen": "kättarbål",
    "kättarbålens": "kättarbål",
    "kättarbålet": "kättarbål",
    "kättarbålets": "kättarbål",
    "kättarbåls": "kättarbål",
    "kättaren": "kättare",
    "kättarens": "kättare",
    "kättares": "kättare",
    "kättarna": "kätte",
    "kättarnas": "kätte",
    "kättars": "kätte",
    "kätten": "kätte",
    "kättens": "kätte",
    "kätterier": "kätteri",
    "kätterierna": "kätteri",
    "kätteriernas": "kätteri",
    "kätteriers": "kätteri",
    "kätteriet": "kätteri",
    "kätteriets": "kätteri",
    "kätteris": "kätteri",
    "kätterit": "kätteri",
    "kätterits": "kätteri",
    "kätterska": "kättersk",
    "kätterskare": "kättersk",
    "kätterskares": "kättersk",
    "kätterskas": "kättersk",
    "kätterskast": "kättersk",
    "kätterskaste": "kättersk",
    "kätterskastes": "kättersk",
    "kätterskasts": "kättersk",
    "kätterske": "kättersk",
    "kätterskes": "kättersk",
    "kättersks": "kättersk",
    "kätterskt": "kättersk",
    "kätterskts": "kättersk",
    "kättes": "kätte",
    "kättingar": "kätting",
    "kättingarna": "kätting",
    "kättingarnas": "kätting",
    "kättingars": "kätting",
    "kättingdiametern": "kättingdiameter",
    "kättingdiameterns": "kättingdiameter",
    "kättingdiameters": "kättingdiameter",
    "kättingdiametrar": "kättingdiameter",
    "kättingdiametrarna": "kättingdiameter",
    "kättingdiametrarnas": "kättingdiameter",
    "kättingdiametrars": "kättingdiameter",
    "kättingen": "kätting",
    "kättingens": "kätting",
    "kättings": "kätting",
    "kättingspännar": "kättingspännare",
    "kättingspännaren": "kättingspännare",
    "kättingspännarens": "kättingspännare",
    "kättingspännares": "kättingspännare",
    "kättingspännarna": "kättingspännare",
    "kättingspännarnas": "kättingspännare",
    "kättjan": "kättja",
    "kättjans": "kättja",
    "kättjas": "kättja",
    "kättjefulla": "kättjefull",
    "kättjefullare": "kättjefull",
    "kättjefullares": "kättjefull",
    "kättjefullas": "kättjefull",
    "kättjefullast": "kättjefull",
    "kättjefullaste": "kättjefull",
    "kättjefullastes": "kättjefull",
    "kättjefullasts": "kättjefull",
    "kättjefulle": "kättjefull",
    "kättjefulles": "kättjefull",
    "kättjefullheten": "kättjefullhet",
    "kättjefullhetens": "kättjefullhet",
    "kättjefullhets": "kättjefullhet",
    "kättjefulls": "kättjefull",
    "kättjefullt": "kättjefull",
    "kättjefullts": "kättjefull",
    "kätts": "kätte",
    "käxade": "käxa",
    "käxades": "käxa",
    "käxande": "käxa",
    "käxanden": "käxande",
    "käxandena": "käxande",
    "käxandenas": "käxande",
    "käxandens": "käxande",
    "käxandes": "käxande",
    "käxandet": "käxande",
    "käxandets": "käxande",
    "käxar": "käxa",
    "käxas": "käxa",
    "käxat": "käxa",
    "käxats": "käxa",
    "käxen": "käx",
    "käxens": "käx",
    "käxet": "käx",
    "käxets": "käx",
    "kåd": "kåda",
    "kådan": "kåda",
    "kådans": "kåda",
    "kådas": "kåda",
    "kåde": "kåda",
    "kådiga": "kådig",
    "kådigare": "kådig",
    "kådigares": "kådig",
    "kådigas": "kådig",
    "kådigast": "kådig",
    "kådigaste": "kådig",
    "kådigastes": "kådig",
    "kådigasts": "kådig",
    "kådige": "kådig",
    "kådiges": "kådig",
    "kådigs": "kådig",
    "kådigt": "kådig",
    "kådigts": "kådig",
    "kådor": "kåda",
    "kådorna": "kåda",
    "kådornas": "kåda",
    "kådors": "kåda",
    "kådrika": "kådrik",
    "kådrikare": "kådrik",
    "kådrikares": "kådrik",
    "kådrikas": "kådrik",
    "kådrikast": "kådrik",
    "kådrikaste": "kådrik",
    "kådrikastes": "kådrik",
    "kådrikasts": "kådrik",
    "kådrike": "kådrik",
    "kådrikes": "kådrik",
    "kådrikheten": "kådrikhet",
    "kådrikhetens": "kådrikhet",
    "kådrikhets": "kådrikhet",
    "kådriks": "kådrik",
    "kådrikt": "kådrik",
    "kådrikts": "kådrik",
    "kåds": "kåda",
    "kåkar": "kåk",
    "kåkarna": "kåk",
    "kåkarnas": "kåk",
    "kåkars": "kåk",
    "kåken": "kåk",
    "kåkens": "kåk",
    "kåkfarar": "kåkfarare",
    "kåkfararen": "kåkfarare",
    "kåkfararens": "kåkfarare",
    "kåkfarares": "kåkfarare",
    "kåkfararna": "kåkfarare",
    "kåkfararnas": "kåkfarare",
    "kåks": "kåk",
    "kåkstrykningar": "kåkstrykning",
    "kåkstrykningarna": "kåkstrykning",
    "kåkstrykningarnas": "kåkstrykning",
    "kåkstrykningars": "kåkstrykning",
    "kåkstrykningen": "kåkstrykning",
    "kåkstrykningens": "kåkstrykning",
    "kåkstryknings": "kåkstrykning",
    "kåldolm": "kåldolme",
    "kåldolman": "kåldolma",
    "kåldolmans": "kåldolma",
    "kåldolmar": "kåldolme",
    "kåldolmarna": "kåldolme",
    "kåldolmarnas": "kåldolme",
    "kåldolmars": "kåldolme",
    "kåldolmas": "kåldolma",
    "kåldolmen": "kåldolme",
    "kåldolmens": "kåldolme",
    "kåldolmes": "kåldolme",
    "kåldolms": "kåldolme",
    "kålen": "kål",
    "kålens": "kål",
    "kålfjärilar": "kålfjäril",
    "kålfjärilarna": "kålfjäril",
    "kålfjärilarnas": "kålfjäril",
    "kålfjärilars": "kålfjäril",
    "kålfjärilen": "kålfjäril",
    "kålfjärilens": "kålfjäril",
    "kålfjäriln": "kålfjäril",
    "kålfjärilns": "kålfjäril",
    "kålfjärils": "kålfjäril",
    "kålhuvuden": "kålhuvud",
    "kålhuvudena": "kålhuvud",
    "kålhuvudenas": "kålhuvud",
    "kålhuvudens": "kålhuvud",
    "kålhuvudet": "kålhuvud",
    "kålhuvudets": "kålhuvud",
    "kålhuvuds": "kålhuvud",
    "kållappar": "kållapp",
    "kållapparna": "kållapp",
    "kållapparnas": "kållapp",
    "kållappars": "kållapp",
    "kållappen": "kållapp",
    "kållappens": "kållapp",
    "kållapps": "kållapp",
    "kålmaskar": "kålmask",
    "kålmaskarna": "kålmask",
    "kålmaskarnas": "kålmask",
    "kålmaskars": "kålmask",
    "kålmasken": "kålmask",
    "kålmaskens": "kålmask",
    "kålmasks": "kålmask",
    "kålrabbin": "kålrabbi",
    "kålrabbins": "kålrabbi",
    "kålrabbis": "kålrabbi",
    "kålroten": "kålrot",
    "kålrotens": "kålrot",
    "kålrots": "kålrot",
    "kålrötter": "kålrot",
    "kålrötterna": "kålrot",
    "kålrötternas": "kålrot",
    "kålrötters": "kålrot",
    "kåls": "kål",
    "kålsoppan": "kålsoppa",
    "kålsoppans": "kålsoppa",
    "kålsoppas": "kålsoppa",
    "kålsoppe": "kålsoppa",
    "kålsoppor": "kålsoppa",
    "kålsopporna": "kålsoppa",
    "kålsoppornas": "kålsoppa",
    "kålsoppors": "kålsoppa",
    "kånk": "kånka",
    "kånkad": "kånka",
    "kånkade": "kånka",
    "kånkades": "kånka",
    "kånkads": "kånka",
    "kånkande": "kånka",
    "kånkanden": "kånkande",
    "kånkandena": "kånkande",
    "kånkandenas": "kånkande",
    "kånkandens": "kånkande",
    "kånkandes": "kånkande",
    "kånkandet": "kånkande",
    "kånkandets": "kånkande",
    "kånkar": "kånka",
    "kånkas": "kånka",
    "kånkat": "kånka",
    "kånkats": "kånka",
    "kåp": "kåpa",
    "kåpan": "kåpa",
    "kåpans": "kåpa",
    "kåpas": "kåpa",
    "kåpe": "kåpa",
    "kåpor": "kåpa",
    "kåporna": "kåpa",
    "kåpornas": "kåpa",
    "kåpors": "kåpa",
    "kåps": "kåpa",
    "kår": "kåre",
    "kårad": "kåra",
    "kårade": "kåra",
    "kårades": "kåras",
    "kårads": "kåra",
    "kårande": "kåra",
    "kåranden": "kårande",
    "kårandena": "kårande",
    "kårandenas": "kårande",
    "kårandens": "kårande",
    "kårandes": "kårande",
    "kårandet": "kårande",
    "kårandets": "kårande",
    "kårar": "kåre",
    "kårarna": "kåre",
    "kårarnas": "kåre",
    "kårars": "kåre",
    "kåras": "kåra",
    "kårat": "kåra",
    "kårats": "kåras",
    "kåren": "kåre",
    "kårens": "kåre",
    "kårer": "kår",
    "kårerna": "kår",
    "kårernas": "kår",
    "kårers": "kår",
    "kåres": "kåre",
    "kårhusen": "kårhus",
    "kårhusens": "kårhus",
    "kårhuset": "kårhus",
    "kårhusets": "kårhus",
    "kårknutt": "kårknutte",
    "kårknuttar": "kårknutte",
    "kårknuttarna": "kårknutte",
    "kårknuttarnas": "kårknutte",
    "kårknuttars": "kårknutte",
    "kårknutten": "kårknutte",
    "kårknuttens": "kårknutte",
    "kårknuttes": "kårknutte",
    "kårknutts": "kårknutte",
    "kårobligatorie": "kårobligatorium",
    "kårobligatorier": "kårobligatorium",
    "kårobligatorierna": "kårobligatorium",
    "kårobligatoriernas": "kårobligatorium",
    "kårobligatoriers": "kårobligatorium",
    "kårobligatoriet": "kårobligatorium",
    "kårobligatoriets": "kårobligatorium",
    "kårobligatoriums": "kårobligatorium",
    "kårordföranden": "kårordförande",
    "kårordförandena": "kårordförande",
    "kårordförandenas": "kårordförande",
    "kårordförandens": "kårordförande",
    "kårordförandes": "kårordförande",
    "kårpampar": "kårpamp",
    "kårpamparna": "kårpamp",
    "kårpamparnas": "kårpamp",
    "kårpampars": "kårpamp",
    "kårpampen": "kårpamp",
    "kårpampens": "kårpamp",
    "kårpamps": "kårpamp",
    "kårs": "kåre",
    "kås": "kåsa",
    "kåsan": "kåsa",
    "kåsans": "kåsa",
    "kåsas": "kåsa",
    "kåse": "kåsa",
    "kåserade": "kåsera",
    "kåserades": "kåsera",
    "kåserande": "kåsera",
    "kåseranden": "kåserande",
    "kåserandena": "kåserande",
    "kåserandenas": "kåserande",
    "kåserandens": "kåserande",
    "kåserandes": "kåserande",
    "kåserandet": "kåserande",
    "kåserandets": "kåserande",
    "kåserar": "kåsera",
    "kåseras": "kåsera",
    "kåserat": "kåsera",
    "kåserats": "kåsera",
    "kåserier": "kåseri",
    "kåserierna": "kåseri",
    "kåseriernas": "kåseri",
    "kåseriers": "kåseri",
    "kåseriet": "kåseri",
    "kåseriets": "kåseri",
    "kåseringar": "kåsering",
    "kåseringarna": "kåsering",
    "kåseringarnas": "kåsering",
    "kåseringars": "kåsering",
    "kåseringen": "kåsering",
    "kåseringens": "kåsering",
    "kåserings": "kåsering",
    "kåseris": "kåseri",
    "kåserit": "kåseri",
    "kåserits": "kåseri",
    "kåsor": "kåsa",
    "kåsorna": "kåsa",
    "kåsornas": "kåsa",
    "kåsors": "kåsa",
    "kåsören": "kåsör",
    "kåsörens": "kåsör",
    "kåsörer": "kåsör",
    "kåsörerna": "kåsör",
    "kåsörernas": "kåsör",
    "kåsörers": "kåsör",
    "kåsörprosan": "kåsörprosa",
    "kåsörprosans": "kåsörprosa",
    "kåsörprosas": "kåsörprosa",
    "kåsörprose": "kåsörprosa",
    "kåsörprosor": "kåsörprosa",
    "kåsörprosorna": "kåsörprosa",
    "kåsörprosornas": "kåsörprosa",
    "kåsörprosors": "kåsörprosa",
    "kåsörs": "kåsör",
    "kåt": "kåta",
    "kåta": "kåt",
    "kåtan": "kåta",
    "kåtans": "kåta",
    "kåtare": "kåt",
    "kåtares": "kåt",
    "kåtas": "kåta",
    "kåtast": "kåt",
    "kåtaste": "kåt",
    "kåtastes": "kåt",
    "kåtasts": "kåt",
    "kåtbockar": "kåtbock",
    "kåtbockarna": "kåtbock",
    "kåtbockarnas": "kåtbock",
    "kåtbockars": "kåtbock",
    "kåtbocken": "kåtbock",
    "kåtbockens": "kåtbock",
    "kåtbocks": "kåtbock",
    "kåte": "kåta",
    "kåtes": "kåt",
    "kåtheten": "kåthet",
    "kåthetens": "kåthet",
    "kåthets": "kåthet",
    "kåtman": "kåtma",
    "kåtmans": "kåtma",
    "kåtmas": "kåtma",
    "kåtor": "kåta",
    "kåtorna": "kåta",
    "kåtornas": "kåta",
    "kåtors": "kåta",
    "kåts": "kåta",
    "köade": "köa",
    "köades": "köa",
    "köande": "köa",
    "köanden": "köande",
    "köandena": "köande",
    "köandenas": "köande",
    "köandens": "köande",
    "köandes": "köande",
    "köandet": "köande",
    "köandets": "köande",
    "köar": "köa",
    "köas": "köa",
    "köat": "köa",
    "köats": "köa",
    "köbrick": "köbricka",
    "köbrickan": "köbricka",
    "köbrickans": "köbricka",
    "köbrickas": "köbricka",
    "köbricke": "köbricka",
    "köbrickor": "köbricka",
    "köbrickorna": "köbricka",
    "köbrickornas": "köbricka",
    "köbrickors": "köbricka",
    "köbricks": "köbricka",
    "köckenmöddingar": "köckenmödding",
    "köckenmöddingarna": "köckenmödding",
    "köckenmöddingarnas": "köckenmödding",
    "köckenmöddingars": "köckenmödding",
    "köckenmöddingen": "köckenmödding",
    "köckenmöddingens": "köckenmödding",
    "köckenmöddings": "köckenmödding",
    "köer": "kö",
    "köerna": "kö",
    "köernas": "kö",
    "köers": "kö",
    "köken": "kök",
    "kökens": "kök",
    "köket": "kök",
    "kökets": "kök",
    "kökkenmöddingar": "kökkenmödding",
    "kökkenmöddingarna": "kökkenmödding",
    "kökkenmöddingarnas": "kökkenmödding",
    "kökkenmöddingars": "kökkenmödding",
    "kökkenmöddingen": "kökkenmödding",
    "kökkenmöddingens": "kökkenmödding",
    "kökkenmöddings": "kökkenmödding",
    "köks": "köksa",
    "köksan": "köksa",
    "köksans": "köksa",
    "köksas": "köksa",
    "köksborden": "köksbord",
    "köksbordens": "köksbord",
    "köksbordet": "köksbord",
    "köksbordets": "köksbord",
    "köksbords": "köksbord",
    "köksbordssamtalen": "köksbordssamtal",
    "köksbordssamtalens": "köksbordssamtal",
    "köksbordssamtalet": "köksbordssamtal",
    "köksbordssamtalets": "köksbordssamtal",
    "köksbordssamtals": "köksbordssamtal",
    "köksbordsturnéer": "köksbordsturné",
    "köksbordsturnéerna": "köksbordsturné",
    "köksbordsturnéernas": "köksbordsturné",
    "köksbordsturnéers": "köksbordsturné",
    "köksbordsturnén": "köksbordsturné",
    "köksbordsturnéns": "köksbordsturné",
    "köksbordsturnés": "köksbordsturné",
    "köksdörrar": "köksdörr",
    "köksdörrarna": "köksdörr",
    "köksdörrarnas": "köksdörr",
    "köksdörrars": "köksdörr",
    "köksdörren": "köksdörr",
    "köksdörrens": "köksdörr",
    "köksdörrs": "köksdörr",
    "kökse": "köksa",
    "köksfläktar": "köksfläkt",
    "köksfläktarna": "köksfläkt",
    "köksfläktarnas": "köksfläkt",
    "köksfläktars": "köksfläkt",
    "köksfläkten": "köksfläkt",
    "köksfläktens": "köksfläkt",
    "köksfläkts": "köksfläkt",
    "köksfönsterna": "köksfönster",
    "köksfönsternas": "köksfönster",
    "köksfönsters": "köksfönster",
    "köksfönstren": "köksfönster",
    "köksfönstrens": "köksfönster",
    "köksfönstret": "köksfönster",
    "köksfönstrets": "köksfönster",
    "kökshanddukar": "kökshandduk",
    "kökshanddukarna": "kökshandduk",
    "kökshanddukarnas": "kökshandduk",
    "kökshanddukars": "kökshandduk",
    "kökshandduken": "kökshandduk",
    "kökshanddukens": "kökshandduk",
    "kökshandduks": "kökshandduk",
    "köksingångar": "köksingång",
    "köksingångarna": "köksingång",
    "köksingångarnas": "köksingång",
    "köksingångars": "köksingång",
    "köksingången": "köksingång",
    "köksingångens": "köksingång",
    "köksingångs": "köksingång",
    "kökslatinet": "kökslatin",
    "kökslatinets": "kökslatin",
    "kökslatins": "kökslatin",
    "köksmaskinen": "köksmaskin",
    "köksmaskinens": "köksmaskin",
    "köksmaskiner": "köksmaskin",
    "köksmaskinerna": "köksmaskin",
    "köksmaskinernas": "köksmaskin",
    "köksmaskiners": "köksmaskin",
    "köksmaskins": "köksmaskin",
    "köksmästar": "köksmästare",
    "köksmästaren": "köksmästare",
    "köksmästarens": "köksmästare",
    "köksmästares": "köksmästare",
    "köksmästarna": "köksmästare",
    "köksmästarnas": "köksmästare",
    "köksor": "köksa",
    "köksorna": "köksa",
    "köksornas": "köksa",
    "köksors": "köksa",
    "köksrull": "köksrulle",
    "köksrullar": "köksrulle",
    "köksrullarna": "köksrulle",
    "köksrullarnas": "köksrulle",
    "köksrullars": "köksrulle",
    "köksrullen": "köksrulle",
    "köksrullens": "köksrulle",
    "köksrulles": "köksrulle",
    "köksrulls": "köksrulle",
    "kökssaxar": "kökssax",
    "kökssaxarna": "kökssax",
    "kökssaxarnas": "kökssax",
    "kökssaxars": "kökssax",
    "kökssaxen": "kökssax",
    "kökssaxens": "kökssax",
    "kökssoff": "kökssoffa",
    "kökssoffan": "kökssoffa",
    "kökssoffans": "kökssoffa",
    "kökssoffas": "kökssoffa",
    "kökssoffe": "kökssoffa",
    "kökssoffor": "kökssoffa",
    "kökssofforna": "kökssoffa",
    "kökssoffornas": "kökssoffa",
    "kökssoffors": "kökssoffa",
    "kökssoffs": "kökssoffa",
    "köksspisar": "köksspis",
    "köksspisarna": "köksspis",
    "köksspisarnas": "köksspis",
    "köksspisars": "köksspis",
    "köksspisen": "köksspis",
    "köksspisens": "köksspis",
    "köksstolar": "köksstol",
    "köksstolarna": "köksstol",
    "köksstolarnas": "köksstol",
    "köksstolars": "köksstol",
    "köksstolen": "köksstol",
    "köksstolens": "köksstol",
    "köksstols": "köksstol",
    "kökssvampar": "kökssvamp",
    "kökssvamparna": "kökssvamp",
    "kökssvamparnas": "kökssvamp",
    "kökssvampars": "kökssvamp",
    "kökssvampen": "kökssvamp",
    "kökssvampens": "kökssvamp",
    "kökssvamps": "kökssvamp",
    "köksträdgårdar": "köksträdgård",
    "köksträdgårdarna": "köksträdgård",
    "köksträdgårdarnas": "köksträdgård",
    "köksträdgårdars": "köksträdgård",
    "köksträdgården": "köksträdgård",
    "köksträdgårdens": "köksträdgård",
    "köksträdgårds": "köksträdgård",
    "köksvägens": "köksvägen",
    "köksväxten": "köksväxt",
    "köksväxtens": "köksväxt",
    "köksväxter": "köksväxt",
    "köksväxterna": "köksväxt",
    "köksväxternas": "köksväxt",
    "köksväxters": "köksväxt",
    "köksväxts": "köksväxt",
    "kölade": "kölad",
    "kölades": "kölad",
    "kölads": "kölad",
    "kölar": "köl",
    "kölarna": "köl",
    "kölarnas": "köl",
    "kölars": "köl",
    "kölat": "kölad",
    "kölats": "kölad",
    "kölbåtar": "kölbåt",
    "kölbåtarna": "kölbåt",
    "kölbåtarnas": "kölbåt",
    "kölbåtars": "kölbåt",
    "kölbåten": "kölbåt",
    "kölbåtens": "kölbåt",
    "kölbåts": "kölbåt",
    "köldbeständiga": "köldbeständig",
    "köldbeständigare": "köldbeständig",
    "köldbeständigares": "köldbeständig",
    "köldbeständigas": "köldbeständig",
    "köldbeständigast": "köldbeständig",
    "köldbeständigaste": "köldbeständig",
    "köldbeständigastes": "köldbeständig",
    "köldbeständigasts": "köldbeständig",
    "köldbeständige": "köldbeständig",
    "köldbeständiges": "köldbeständig",
    "köldbeständigheten": "köldbeständighet",
    "köldbeständighetens": "köldbeständighet",
    "köldbeständighets": "köldbeständighet",
    "köldbeständigs": "köldbeständig",
    "köldbeständigt": "köldbeständig",
    "köldbeständigts": "köldbeständig",
    "köldblandningar": "köldblandning",
    "köldblandningarna": "köldblandning",
    "köldblandningarnas": "köldblandning",
    "köldblandningars": "köldblandning",
    "köldblandningen": "köldblandning",
    "köldblandningens": "köldblandning",
    "köldblandnings": "köldblandning",
    "kölden": "köld",
    "köldens": "köld",
    "köldgraden": "köldgrad",
    "köldgradens": "köldgrad",
    "köldgrader": "köldgrad",
    "köldgraderna": "köldgrad",
    "köldgradernas": "köldgrad",
    "köldgraders": "köldgrad",
    "köldgrads": "köldgrad",
    "köldhärdiga": "köldhärdig",
    "köldhärdigare": "köldhärdig",
    "köldhärdigares": "köldhärdig",
    "köldhärdigas": "köldhärdig",
    "köldhärdigast": "köldhärdig",
    "köldhärdigaste": "köldhärdig",
    "köldhärdigastes": "köldhärdig",
    "köldhärdigasts": "köldhärdig",
    "köldhärdige": "köldhärdig",
    "köldhärdiges": "köldhärdig",
    "köldhärdigheten": "köldhärdighet",
    "köldhärdighetens": "köldhärdighet",
    "köldhärdighets": "köldhärdighet",
    "köldhärdigs": "köldhärdig",
    "köldhärdigt": "köldhärdig",
    "köldhärdigts": "köldhärdig",
    "köldknäppar": "köldknäpp",
    "köldknäpparna": "köldknäpp",
    "köldknäpparnas": "köldknäpp",
    "köldknäppars": "köldknäpp",
    "köldknäppen": "köldknäpp",
    "köldknäppens": "köldknäpp",
    "köldknäpps": "köldknäpp",
    "köldpolen": "köldpol",
    "köldpolens": "köldpol",
    "köldpoler": "köldpol",
    "köldpolerna": "köldpol",
    "köldpolernas": "köldpol",
    "köldpolers": "köldpol",
    "köldpols": "köldpol",
    "köldpunkten": "köldpunkt",
    "köldpunktens": "köldpunkt",
    "köldpunkter": "köldpunkt",
    "köldpunkterna": "köldpunkt",
    "köldpunkternas": "köldpunkt",
    "köldpunkters": "köldpunkt",
    "köldpunkts": "köldpunkt",
    "kölds": "köld",
    "köldskadade": "köldskadad",
    "köldskadades": "köldskadad",
    "köldskadads": "köldskadad",
    "köldskadan": "köldskada",
    "köldskadans": "köldskada",
    "köldskadas": "köldskada",
    "köldskadat": "köldskadad",
    "köldskadats": "köldskadad",
    "köldskade": "köldskada",
    "köldskador": "köldskada",
    "köldskadorna": "köldskada",
    "köldskadornas": "köldskada",
    "köldskadors": "köldskada",
    "kölen": "köl",
    "kölens": "köl",
    "kölfen": "kölfena",
    "kölfenan": "kölfena",
    "kölfenans": "kölfena",
    "kölfenas": "kölfena",
    "kölfene": "kölfena",
    "kölfenor": "kölfena",
    "kölfenorna": "kölfena",
    "kölfenornas": "kölfena",
    "kölfenors": "kölfena",
    "kölfens": "kölfena",
    "kölhalad": "kölhala",
    "kölhalade": "kölhala",
    "kölhalades": "kölhala",
    "kölhalads": "kölhala",
    "kölhalande": "kölhala",
    "kölhalanden": "kölhalande",
    "kölhalandena": "kölhalande",
    "kölhalandenas": "kölhalande",
    "kölhalandens": "kölhalande",
    "kölhalandes": "kölhalande",
    "kölhalandet": "kölhalande",
    "kölhalandets": "kölhalande",
    "kölhalar": "kölhala",
    "kölhalas": "kölhala",
    "kölhalat": "kölhala",
    "kölhalats": "kölhala",
    "köln": "kölna",
    "kölnan": "kölna",
    "kölnans": "kölna",
    "kölnas": "kölna",
    "kölne": "kölna",
    "kölnor": "kölna",
    "kölnorna": "kölna",
    "kölnornas": "kölna",
    "kölnors": "kölna",
    "kölns": "kölna",
    "köls": "köl",
    "kölsken": "kölskena",
    "kölskenan": "kölskena",
    "kölskenans": "kölskena",
    "kölskenas": "kölskena",
    "kölskene": "kölskena",
    "kölskenor": "kölskena",
    "kölskenorna": "kölskena",
    "kölskenornas": "kölskena",
    "kölskenors": "kölskena",
    "kölskens": "kölskena",
    "kölsträckningar": "kölsträckning",
    "kölsträckningarna": "kölsträckning",
    "kölsträckningarnas": "kölsträckning",
    "kölsträckningars": "kölsträckning",
    "kölsträckningen": "kölsträckning",
    "kölsträckningens": "kölsträckning",
    "kölsträcknings": "kölsträckning",
    "kölsvinen": "kölsvin",
    "kölsvinens": "kölsvin",
    "kölsvinet": "kölsvin",
    "kölsvinets": "kölsvin",
    "kölsvins": "kölsvin",
    "kölvattens": "kölvatten",
    "kölvattnet": "kölvatten",
    "kölvattnets": "kölvatten",
    "kön": "köna",
    "könad": "köna",
    "könade": "köna",
    "könades": "köna",
    "könads": "köna",
    "könande": "köna",
    "könanden": "könande",
    "könandena": "könande",
    "könandenas": "könande",
    "könandens": "könande",
    "könandes": "könande",
    "könandet": "könande",
    "könandets": "könande",
    "könar": "köna",
    "könas": "köna",
    "könat": "köna",
    "könats": "köna",
    "könen": "kön",
    "könens": "kön",
    "könet": "kön",
    "könets": "kön",
    "könliga": "könlig",
    "könligare": "könlig",
    "könligares": "könlig",
    "könligas": "könlig",
    "könligast": "könlig",
    "könligaste": "könlig",
    "könligastes": "könlig",
    "könligasts": "könlig",
    "könlige": "könlig",
    "könliges": "könlig",
    "könligheten": "könlighet",
    "könlighetens": "könlighet",
    "könlighets": "könlighet",
    "könligs": "könlig",
    "könligt": "könlig",
    "könligts": "könlig",
    "könlösa": "könlös",
    "könlösare": "könlös",
    "könlösares": "könlös",
    "könlösas": "könlös",
    "könlösast": "könlös",
    "könlösaste": "könlös",
    "könlösastes": "könlös",
    "könlösasts": "könlös",
    "könlöse": "könlös",
    "könlöses": "könlös",
    "könlösheten": "könlöshet",
    "könlöshetens": "könlöshet",
    "könlöshets": "könlöshet",
    "könlöst": "könlös",
    "könlösts": "könlös",
    "köns": "kön",
    "könsakten": "könsakt",
    "könsaktens": "könsakt",
    "könsakter": "könsakt",
    "könsakterna": "könsakt",
    "könsakternas": "könsakt",
    "könsakters": "könsakt",
    "könsakts": "könsakt",
    "könsbundenheten": "könsbundenhet",
    "könsbundenhetens": "könsbundenhet",
    "könsbundenhets": "könsbundenhet",
    "könsbundens": "könsbunden",
    "könsbundet": "könsbunden",
    "könsbundets": "könsbunden",
    "könsbundna": "könsbunden",
    "könsbundnare": "könsbunden",
    "könsbundnares": "könsbunden",
    "könsbundnas": "könsbunden",
    "könsbundnast": "könsbunden",
    "könsbundnaste": "könsbunden",
    "könsbundnastes": "könsbunden",
    "könsbundnasts": "könsbunden",
    "könsbundne": "könsbunden",
    "könsbundnes": "könsbunden",
    "könsbyten": "könsbyte",
    "könsbytena": "könsbyte",
    "könsbytenas": "könsbyte",
    "könsbytens": "könsbyte",
    "könsbytes": "könsbyte",
    "könsbytet": "könsbyte",
    "könsbytets": "könsbyte",
    "könscellen": "könscell",
    "könscellens": "könscell",
    "könsceller": "könscell",
    "könscellerna": "könscell",
    "könscellernas": "könscell",
    "könscellers": "könscell",
    "könscells": "könscell",
    "könsdelarna": "könsdelar",
    "könsdelarnas": "könsdelar",
    "könsdelars": "könsdelar",
    "könsdels": "könsdelar",
    "könsdiskriminerad": "könsdiskriminera",
    "könsdiskriminerade": "könsdiskriminera",
    "könsdiskriminerades": "könsdiskriminera",
    "könsdiskriminerads": "könsdiskriminera",
    "könsdiskriminerande": "könsdiskriminera",
    "könsdiskrimineranden": "könsdiskriminerande",
    "könsdiskriminerandena": "könsdiskriminerande",
    "könsdiskriminerandenas": "könsdiskriminerande",
    "könsdiskriminerandens": "könsdiskriminerande",
    "könsdiskriminerandes": "könsdiskriminerande",
    "könsdiskriminerandet": "könsdiskriminerande",
    "könsdiskriminerandets": "könsdiskriminerande",
    "könsdiskriminerar": "könsdiskriminera",
    "könsdiskrimineras": "könsdiskriminera",
    "könsdiskriminerat": "könsdiskriminera",
    "könsdiskriminerats": "könsdiskriminera",
    "könsdiskriminerbara": "könsdiskriminerbar",
    "könsdiskriminerbarare": "könsdiskriminerbar",
    "könsdiskriminerbarares": "könsdiskriminerbar",
    "könsdiskriminerbaras": "könsdiskriminerbar",
    "könsdiskriminerbarast": "könsdiskriminerbar",
    "könsdiskriminerbaraste": "könsdiskriminerbar",
    "könsdiskriminerbarastes": "könsdiskriminerbar",
    "könsdiskriminerbarasts": "könsdiskriminerbar",
    "könsdiskriminerbare": "könsdiskriminerbar",
    "könsdiskriminerbares": "könsdiskriminerbar",
    "könsdiskriminerbarheten": "könsdiskriminerbarhet",
    "könsdiskriminerbarhetens": "könsdiskriminerbarhet",
    "könsdiskriminerbarhets": "könsdiskriminerbarhet",
    "könsdiskriminerbars": "könsdiskriminerbar",
    "könsdiskriminerbart": "könsdiskriminerbar",
    "könsdiskriminerbarts": "könsdiskriminerbar",
    "könsdiskrimineringar": "könsdiskriminering",
    "könsdiskrimineringarna": "könsdiskriminering",
    "könsdiskrimineringarnas": "könsdiskriminering",
    "könsdiskrimineringars": "könsdiskriminering",
    "könsdiskrimineringen": "könsdiskriminering",
    "könsdiskrimineringens": "könsdiskriminering",
    "könsdiskriminerings": "könsdiskriminering",
    "könsdriften": "könsdrift",
    "könsdriftens": "könsdrift",
    "könsdrifts": "könsdrift",
    "könsfördelningar": "könsfördelning",
    "könsfördelningarna": "könsfördelning",
    "könsfördelningarnas": "könsfördelning",
    "könsfördelningars": "könsfördelning",
    "könsfördelningen": "könsfördelning",
    "könsfördelningens": "könsfördelning",
    "könsfördelnings": "könsfördelning",
    "könshormonen": "könshormon",
    "könshormonens": "könshormon",
    "könshormoner": "könshormon",
    "könshormonerna": "könshormon",
    "könshormonernas": "könshormon",
    "könshormoners": "könshormon",
    "könshormonet": "könshormon",
    "könshormonets": "könshormon",
    "könshormons": "könshormon",
    "könshåren": "könshår",
    "könshårens": "könshår",
    "könshåret": "könshår",
    "könshårets": "könshår",
    "könshårs": "könshår",
    "könskaraktären": "könskaraktär",
    "könskaraktärens": "könskaraktär",
    "könskaraktärer": "könskaraktär",
    "könskaraktärerna": "könskaraktär",
    "könskaraktärernas": "könskaraktär",
    "könskaraktärers": "könskaraktär",
    "könskaraktärs": "könskaraktär",
    "könskvoterad": "könskvotera",
    "könskvoterade": "könskvotera",
    "könskvoterades": "könskvotera",
    "könskvoterads": "könskvotera",
    "könskvoterande": "könskvotera",
    "könskvoteranden": "könskvoterande",
    "könskvoterandena": "könskvoterande",
    "könskvoterandenas": "könskvoterande",
    "könskvoterandens": "könskvoterande",
    "könskvoterandes": "könskvoterande",
    "könskvoterandet": "könskvoterande",
    "könskvoterandets": "könskvoterande",
    "könskvoterar": "könskvotera",
    "könskvoteras": "könskvotera",
    "könskvoterat": "könskvotera",
    "könskvoterats": "könskvotera",
    "könskvoterbara": "könskvoterbar",
    "könskvoterbarare": "könskvoterbar",
    "könskvoterbarares": "könskvoterbar",
    "könskvoterbaras": "könskvoterbar",
    "könskvoterbarast": "könskvoterbar",
    "könskvoterbaraste": "könskvoterbar",
    "könskvoterbarastes": "könskvoterbar",
    "könskvoterbarasts": "könskvoterbar",
    "könskvoterbare": "könskvoterbar",
    "könskvoterbares": "könskvoterbar",
    "könskvoterbarheten": "könskvoterbarhet",
    "könskvoterbarhetens": "könskvoterbarhet",
    "könskvoterbarhets": "könskvoterbarhet",
    "könskvoterbars": "könskvoterbar",
    "könskvoterbart": "könskvoterbar",
    "könskvoterbarts": "könskvoterbar",
    "könskvoteringar": "könskvotering",
    "könskvoteringarna": "könskvotering",
    "könskvoteringarnas": "könskvotering",
    "könskvoteringars": "könskvotering",
    "könskvoteringen": "könskvotering",
    "könskvoteringens": "könskvotering",
    "könskvoterings": "könskvotering",
    "könskylan": "könskyla",
    "könskylans": "könskyla",
    "könskylas": "könskyla",
    "könskörteln": "könskörtel",
    "könskörtelns": "könskörtel",
    "könskörtels": "könskörtel",
    "könskörtlar": "könskörtel",
    "könskörtlarna": "könskörtel",
    "könskörtlarnas": "könskörtel",
    "könskörtlars": "könskörtel",
    "könsliga": "könslig",
    "könsligare": "könslig",
    "könsligares": "könslig",
    "könsligas": "könslig",
    "könsligast": "könslig",
    "könsligaste": "könslig",
    "könsligastes": "könslig",
    "könsligasts": "könslig",
    "könslige": "könslig",
    "könsliges": "könslig",
    "könsligheten": "könslighet",
    "könslighetens": "könslighet",
    "könslighets": "könslighet",
    "könsligs": "könslig",
    "könsligt": "könslig",
    "könsligts": "könslig",
    "könslivet": "könsliv",
    "könslivets": "könsliv",
    "könslivs": "könsliv",
    "könsmakten": "könsmakt",
    "könsmaktens": "könsmakt",
    "könsmakts": "könsmakt",
    "könsmaktsordningen": "könsmaktsordning",
    "könsmaktsordningens": "könsmaktsordning",
    "könsmaktsordnings": "könsmaktsordning",
    "könsmogenheten": "könsmogenhet",
    "könsmogenhetens": "könsmogenhet",
    "könsmogenhets": "könsmogenhet",
    "könsmogens": "könsmogen",
    "könsmoget": "könsmogen",
    "könsmogets": "könsmogen",
    "könsmogna": "könsmogen",
    "könsmognaden": "könsmognad",
    "könsmognadens": "könsmognad",
    "könsmognader": "könsmognad",
    "könsmognaderna": "könsmognad",
    "könsmognadernas": "könsmognad",
    "könsmognaders": "könsmognad",
    "könsmognads": "könsmognad",
    "könsmognare": "könsmogen",
    "könsmognares": "könsmogen",
    "könsmognas": "könsmogen",
    "könsmognast": "könsmogen",
    "könsmognaste": "könsmogen",
    "könsmognastes": "könsmogen",
    "könsmognasts": "könsmogen",
    "könsmogne": "könsmogen",
    "könsmognes": "könsmogen",
    "könsmässiga": "könsmässig",
    "könsmässigare": "könsmässig",
    "könsmässigares": "könsmässig",
    "könsmässigas": "könsmässig",
    "könsmässigast": "könsmässig",
    "könsmässigaste": "könsmässig",
    "könsmässigastes": "könsmässig",
    "könsmässigasts": "könsmässig",
    "könsmässige": "könsmässig",
    "könsmässiges": "könsmässig",
    "könsmässigs": "könsmässig",
    "könsmässigt": "könsmässig",
    "könsmässigts": "könsmässig",
    "könsorden": "könsord",
    "könsordens": "könsord",
    "könsordet": "könsord",
    "könsordets": "könsord",
    "könsords": "könsord",
    "könsorganen": "könsorgan",
    "könsorganens": "könsorgan",
    "könsorganet": "könsorgan",
    "könsorganets": "könsorgan",
    "könsorgans": "könsorgan",
    "könsrollen": "könsroll",
    "könsrollens": "könsroll",
    "könsroller": "könsroll",
    "könsrollerna": "könsroll",
    "könsrollernas": "könsroll",
    "könsrollers": "könsroll",
    "könsrolls": "könsroll",
    "könssjukdomar": "könssjukdom",
    "könssjukdomarna": "könssjukdom",
    "könssjukdomarnas": "könssjukdom",
    "könssjukdomars": "könssjukdom",
    "könssjukdomen": "könssjukdom",
    "könssjukdomens": "könssjukdom",
    "könssjukdoms": "könssjukdom",
    "könsskämten": "könsskämt",
    "könsskämtens": "könsskämt",
    "könsskämtet": "könsskämt",
    "könsskämtets": "könsskämt",
    "könsskämts": "könsskämt",
    "könsstympningen": "könsstympning",
    "könsstympningens": "könsstympning",
    "könsstympnings": "könsstympning",
    "könsumgängen": "könsumgänge",
    "könsumgängena": "könsumgänge",
    "könsumgängenas": "könsumgänge",
    "könsumgängens": "könsumgänge",
    "könsumgänges": "könsumgänge",
    "könsumgänget": "könsumgänge",
    "könsumgängets": "könsumgänge",
    "könsutjämningar": "könsutjämning",
    "könsutjämningarna": "könsutjämning",
    "könsutjämningarnas": "könsutjämning",
    "könsutjämningars": "könsutjämning",
    "könsutjämningen": "könsutjämning",
    "könsutjämningens": "könsutjämning",
    "könsutjämnings": "könsutjämning",
    "könsvarelsen": "könsvarelse",
    "könsvarelsens": "könsvarelse",
    "könsvarelser": "könsvarelse",
    "könsvarelserna": "könsvarelse",
    "könsvarelsernas": "könsvarelse",
    "könsvarelsers": "könsvarelse",
    "könsvarelses": "könsvarelse",
    "köp": "köpa",
    "köp-slit-och-slängs": "köp-slit-och-släng",
    "köpande": "köpa",
    "köpanden": "köpande",
    "köpandena": "köpande",
    "köpandenas": "köpande",
    "köpandens": "köpande",
    "köpandes": "köpande",
    "köpandet": "köpande",
    "köpandets": "köpande",
    "köpar": "köpare",
    "köparen": "köpare",
    "köparens": "köpare",
    "köpares": "köpare",
    "köparna": "köpare",
    "köparnas": "köpare",
    "köpas": "köpa",
    "köpcentra": "köpcentrum",
    "köpcentrana": "köpcentrum",
    "köpcentranas": "köpcentrum",
    "köpcentras": "köpcentrum",
    "köpcentrer": "köpcentrum",
    "köpcentrerna": "köpcentrum",
    "köpcentrernas": "köpcentrum",
    "köpcentrers": "köpcentrum",
    "köpcentret": "köpcentrum",
    "köpcentrets": "köpcentrum",
    "köpcentrumen": "köpcentrum",
    "köpcentrumens": "köpcentrum",
    "köpcentrumet": "köpcentrum",
    "köpcentrumets": "köpcentrum",
    "köpcentrums": "köpcentrum",
    "köpebreven": "köpebrev",
    "köpebrevens": "köpebrev",
    "köpebrevet": "köpebrev",
    "köpebrevets": "köpebrev",
    "köpebrevs": "köpebrev",
    "köpebröden": "köpebröd",
    "köpebrödens": "köpebröd",
    "köpebrödet": "köpebröd",
    "köpebrödets": "köpebröd",
    "köpebröds": "köpebröd",
    "köpekontrakten": "köpekontrakt",
    "köpekontraktens": "köpekontrakt",
    "köpekontraktet": "köpekontrakt",
    "köpekontraktets": "köpekontrakt",
    "köpekontrakts": "köpekontrakt",
    "köpen": "köp",
    "köpenickiaden": "köpenickiad",
    "köpenickiadens": "köpenickiad",
    "köpenickiader": "köpenickiad",
    "köpenickiaderna": "köpenickiad",
    "köpenickiadernas": "köpenickiad",
    "köpenickiaders": "köpenickiad",
    "köpenickiads": "köpenickiad",
    "köpens": "köp",
    "köpenskapen": "köpenskap",
    "köpenskapens": "köpenskap",
    "köpenskaper": "köpenskap",
    "köpenskaperna": "köpenskap",
    "köpenskapernas": "köpenskap",
    "köpenskapers": "köpenskap",
    "köpenskaps": "köpenskap",
    "köper": "köpa",
    "köpes": "köpa",
    "köpeskillingar": "köpeskilling",
    "köpeskillingarna": "köpeskilling",
    "köpeskillingarnas": "köpeskilling",
    "köpeskillingars": "köpeskilling",
    "köpeskillingen": "köpeskilling",
    "köpeskillingens": "köpeskilling",
    "köpeskillings": "köpeskilling",
    "köpet": "köp",
    "köpets": "köp",
    "köphetsen": "köphets",
    "köphetsens": "köphets",
    "köpingar": "köping",
    "köpingarna": "köping",
    "köpingarnas": "köping",
    "köpingars": "köping",
    "köpingen": "köping",
    "köpingens": "köping",
    "köpings": "köping",
    "köpkorten": "köpkort",
    "köpkortens": "köpkort",
    "köpkortet": "köpkort",
    "köpkortets": "köpkort",
    "köpkorts": "köpkort",
    "köpkraften": "köpkraft",
    "köpkraftens": "köpkraft",
    "köpkrafts": "köpkraft",
    "köpkursen": "köpkurs",
    "köpkursens": "köpkurs",
    "köpkurser": "köpkurs",
    "köpkurserna": "köpkurs",
    "köpkursernas": "köpkurs",
    "köpkursers": "köpkurs",
    "köplad": "köplada",
    "köpladan": "köplada",
    "köpladans": "köplada",
    "köpladas": "köplada",
    "köplade": "köplada",
    "köplador": "köplada",
    "köpladorna": "köplada",
    "köpladornas": "köplada",
    "köpladors": "köplada",
    "köplads": "köplada",
    "köpmannen": "köpman",
    "köpmannens": "köpman",
    "köpmans": "köpman",
    "köpmän": "köpman",
    "köpmännen": "köpman",
    "köpmännens": "köpman",
    "köpmäns": "köpman",
    "köps": "köpa",
    "köpslagans": "köpslagan",
    "köpslagen": "köpslå",
    "köpslagens": "köpslå",
    "köpslaget": "köpslå",
    "köpslagets": "köpslå",
    "köpslagit": "köpslå",
    "köpslagits": "köpslå",
    "köpslagna": "köpslå",
    "köpslagnas": "köpslå",
    "köpslagne": "köpslå",
    "köpslagnes": "köpslå",
    "köpslog": "köpslå",
    "köpsloge": "köpslå",
    "köpsloges": "köpslå",
    "köpslogs": "köpslå",
    "köpsluten": "köpslut",
    "köpslutens": "köpslut",
    "köpslutet": "köpslut",
    "köpslutets": "köpslut",
    "köpsluts": "köpslut",
    "köpslående": "köpslå",
    "köpslåendes": "köpslående",
    "köpslåendet": "köpslående",
    "köpslåendets": "köpslående",
    "köpslår": "köpslå",
    "köpslås": "köpslå",
    "köpstaden": "köpstad",
    "köpstadens": "köpstad",
    "köpstads": "köpstad",
    "köpstan": "köpstad",
    "köpstans": "köpstad",
    "köpstarka": "köpstark",
    "köpstarkare": "köpstark",
    "köpstarkares": "köpstark",
    "köpstarkas": "köpstark",
    "köpstarkast": "köpstark",
    "köpstarkaste": "köpstark",
    "köpstarkastes": "köpstark",
    "köpstarkasts": "köpstark",
    "köpstarke": "köpstark",
    "köpstarkes": "köpstark",
    "köpstarks": "köpstark",
    "köpstarkt": "köpstark",
    "köpstarkts": "köpstark",
    "köpstäder": "köpstad",
    "köpstäderna": "köpstad",
    "köpstädernas": "köpstad",
    "köpstäders": "köpstad",
    "köpt": "köpa",
    "köpta": "köpa",
    "köptas": "köpa",
    "köpte": "köpa",
    "köptes": "köpa",
    "köpts": "köpa",
    "köpvillkoren": "köpvillkor",
    "köpvillkorens": "köpvillkor",
    "köpvillkoret": "köpvillkor",
    "köpvillkorets": "köpvillkor",
    "köpvillkors": "köpvillkor",
    "kör": "köra",
    "körande": "köra",
    "köranden": "körande",
    "körandena": "körande",
    "körandenas": "körande",
    "körandens": "körande",
    "körandes": "körande",
    "körandet": "körande",
    "körandets": "körande",
    "körar": "körare",
    "köraren": "körare",
    "körarens": "körare",
    "körares": "körare",
    "körarna": "körare",
    "körarnas": "körare",
    "köras": "köra",
    "körbanan": "körbana",
    "körbanans": "körbana",
    "körbanas": "körbana",
    "körbane": "körbana",
    "körbanor": "körbana",
    "körbanorna": "körbana",
    "körbanornas": "körbana",
    "körbanors": "körbana",
    "körbara": "körbar",
    "körbarare": "körbar",
    "körbarares": "körbar",
    "körbaras": "körbar",
    "körbarast": "körbar",
    "körbaraste": "körbar",
    "körbarastes": "körbar",
    "körbarasts": "körbar",
    "körbare": "körbar",
    "körbares": "körbar",
    "körbarheten": "körbarhet",
    "körbarhetens": "körbarhet",
    "körbarhets": "körbarhet",
    "körbars": "körbar",
    "körbart": "körbar",
    "körbarts": "körbar",
    "körd": "köra",
    "körda": "körd",
    "kördare": "körd",
    "kördares": "körd",
    "kördas": "körd",
    "kördast": "körd",
    "kördaste": "körd",
    "kördastes": "körd",
    "kördasts": "körd",
    "körde": "körd",
    "kördes": "körd",
    "kördheten": "kördhet",
    "kördhetens": "kördhet",
    "kördhets": "kördhet",
    "körds": "körd",
    "köregenskapen": "köregenskap",
    "köregenskapens": "köregenskap",
    "köregenskaper": "köregenskap",
    "köregenskaperna": "köregenskap",
    "köregenskapernas": "köregenskap",
    "köregenskapers": "köregenskap",
    "köregenskaps": "köregenskap",
    "kören": "kör",
    "körens": "kör",
    "körer": "kör",
    "körerna": "kör",
    "körernas": "kör",
    "körers": "kör",
    "köres": "köra",
    "körfälten": "körfält",
    "körfältens": "körfält",
    "körfältet": "körfält",
    "körfältets": "körfält",
    "körfälts": "körfält",
    "körförbuden": "körförbud",
    "körförbudens": "körförbud",
    "körförbudet": "körförbud",
    "körförbudets": "körförbud",
    "körförbuds": "körförbud",
    "köriga": "körig",
    "körigare": "körig",
    "körigares": "körig",
    "körigas": "körig",
    "körigast": "körig",
    "körigaste": "körig",
    "körigastes": "körig",
    "körigasts": "körig",
    "körige": "körig",
    "köriges": "körig",
    "körigs": "körig",
    "körigt": "körig",
    "körigts": "körig",
    "körkarlar": "körkarl",
    "körkarlarna": "körkarl",
    "körkarlarnas": "körkarl",
    "körkarlars": "körkarl",
    "körkarlen": "körkarl",
    "körkarlens": "körkarl",
    "körkarls": "körkarl",
    "körkorten": "körkort",
    "körkortens": "körkort",
    "körkortet": "körkort",
    "körkortets": "körkort",
    "körkorts": "körkort",
    "körkortsinnehavar": "körkortsinnehavare",
    "körkortsinnehavaren": "körkortsinnehavare",
    "körkortsinnehavarens": "körkortsinnehavare",
    "körkortsinnehavares": "körkortsinnehavare",
    "körkortsinnehavarna": "körkortsinnehavare",
    "körkortsinnehavarnas": "körkortsinnehavare",
    "körkortsproven": "körkortsprov",
    "körkortsprovens": "körkortsprov",
    "körkortsprovet": "körkortsprov",
    "körkortsprovets": "körkortsprov",
    "körkortsprovs": "körkortsprov",
    "körkortstillstånden": "körkortstillstånd",
    "körkortstillståndens": "körkortstillstånd",
    "körkortstillståndet": "körkortstillstånd",
    "körkortstillståndets": "körkortstillstånd",
    "körkortstillstånds": "körkortstillstånd",
    "körledar": "körledare",
    "körledaren": "körledare",
    "körledarens": "körledare",
    "körledares": "körledare",
    "körledarna": "körledare",
    "körledarnas": "körledare",
    "körlektionen": "körlektion",
    "körlektionens": "körlektion",
    "körlektioner": "körlektion",
    "körlektionerna": "körlektion",
    "körlektionernas": "körlektion",
    "körlektioners": "körlektion",
    "körlektions": "körlektion",
    "körn": "körna",
    "körnad": "körna",
    "körnade": "körna",
    "körnades": "körna",
    "körnads": "körna",
    "körnande": "körna",
    "körnanden": "körnande",
    "körnandena": "körnande",
    "körnandenas": "körnande",
    "körnandens": "körnande",
    "körnandes": "körnande",
    "körnandet": "körnande",
    "körnandets": "körnande",
    "körnar": "körnare",
    "körnaren": "körnare",
    "körnarens": "körnare",
    "körnares": "körnare",
    "körnarna": "körnare",
    "körnarnas": "körnare",
    "körnas": "körna",
    "körnat": "körna",
    "körnats": "körna",
    "körningar": "körning",
    "körningarna": "körning",
    "körningarnas": "körning",
    "körningars": "körning",
    "körningen": "körning",
    "körningens": "körning",
    "körnings": "körning",
    "körriktningsvisar": "körriktningsvisare",
    "körriktningsvisaren": "körriktningsvisare",
    "körriktningsvisarens": "körriktningsvisare",
    "körriktningsvisares": "körriktningsvisare",
    "körriktningsvisarna": "körriktningsvisare",
    "körriktningsvisarnas": "körriktningsvisare",
    "körs": "köra",
    "körsbären": "körsbär",
    "körsbärens": "körsbär",
    "körsbäret": "körsbär",
    "körsbärets": "körsbär",
    "körsbärs": "körsbär",
    "körsbärsblommen": "körsbärsblom",
    "körsbärsblommens": "körsbärsblom",
    "körsbärsbloms": "körsbärsblom",
    "körsbärsfanerade": "körsbärsfanerad",
    "körsbärsfanerades": "körsbärsfanerad",
    "körsbärsfanerads": "körsbärsfanerad",
    "körsbärsfanerat": "körsbärsfanerad",
    "körsbärsfanerats": "körsbärsfanerad",
    "körsbärsfaneren": "körsbärsfaner",
    "körsbärsfanerens": "körsbärsfaner",
    "körsbärsfaneret": "körsbärsfaner",
    "körsbärsfanerets": "körsbärsfaner",
    "körsbärsfaners": "körsbärsfaner",
    "körsbärsfanéren": "körsbärsfanér",
    "körsbärsfanérens": "körsbärsfanér",
    "körsbärsfanéret": "körsbärsfanér",
    "körsbärsfanérets": "körsbärsfanér",
    "körsbärsfanérs": "körsbärsfanér",
    "körsbärsfärgade": "körsbärsfärgad",
    "körsbärsfärgades": "körsbärsfärgad",
    "körsbärsfärgads": "körsbärsfärgad",
    "körsbärsfärgat": "körsbärsfärgad",
    "körsbärsfärgats": "körsbärsfärgad",
    "körsbärsträden": "körsbärsträd",
    "körsbärsträdens": "körsbärsträd",
    "körsbärsträdet": "körsbärsträd",
    "körsbärsträdets": "körsbärsträd",
    "körsbärsträds": "körsbärsträd",
    "körsbärsträet": "körsbärsträ",
    "körsbärsträets": "körsbärsträ",
    "körsbärsträn": "körsbärsträd",
    "körsbärsträna": "körsbärsträd",
    "körsbärstränas": "körsbärsträd",
    "körsbärsträns": "körsbärsträd",
    "körsbärsträs": "körsbärsträ",
    "körsbärsträt": "körsbärsträ",
    "körsbärsträts": "körsbärsträ",
    "körseln": "körsel",
    "körselns": "körsel",
    "körsels": "körsel",
    "körsl": "körsla",
    "körslan": "körsla",
    "körslans": "körsla",
    "körslas": "körsla",
    "körsle": "körsla",
    "körslor": "körsla",
    "körslorna": "körsla",
    "körslornas": "körsla",
    "körslors": "körsla",
    "körsnären": "körsnär",
    "körsnärens": "körsnär",
    "körsnärer": "körsnär",
    "körsnärerna": "körsnär",
    "körsnärernas": "körsnär",
    "körsnärers": "körsnär",
    "körsnärs": "körsnär",
    "körsträck": "körsträcka",
    "körsträckan": "körsträcka",
    "körsträckans": "körsträcka",
    "körsträckas": "körsträcka",
    "körsträcke": "körsträcka",
    "körsträckor": "körsträcka",
    "körsträckorna": "körsträcka",
    "körsträckornas": "körsträcka",
    "körsträckors": "körsträcka",
    "körsträcks": "körsträcka",
    "körsvennen": "körsven",
    "körsvennens": "körsven",
    "körsvenner": "körsven",
    "körsvennerna": "körsven",
    "körsvennernas": "körsven",
    "körsvenners": "körsven",
    "körsvens": "körsven",
    "körsången": "körsång",
    "körsångens": "körsång",
    "körsångs": "körsång",
    "kört": "körd",
    "körtelcellen": "körtelcell",
    "körtelcellens": "körtelcell",
    "körtelceller": "körtelcell",
    "körtelcellerna": "körtelcell",
    "körtelcellernas": "körtelcell",
    "körtelcellers": "körtelcell",
    "körtelcells": "körtelcell",
    "körteln": "körtel",
    "körtelns": "körtel",
    "körtels": "körtel",
    "körtelöppningar": "körtelöppning",
    "körtelöppningarna": "körtelöppning",
    "körtelöppningarnas": "körtelöppning",
    "körtelöppningars": "körtelöppning",
    "körtelöppningen": "körtelöppning",
    "körtelöppningens": "körtelöppning",
    "körtelöppnings": "körtelöppning",
    "körtiden": "körtid",
    "körtidens": "körtid",
    "körtider": "körtid",
    "körtiderna": "körtid",
    "körtidernas": "körtid",
    "körtiders": "körtid",
    "körtids": "körtid",
    "körtlar": "körtel",
    "körtlarna": "körtel",
    "körtlarnas": "körtel",
    "körtlars": "körtel",
    "körts": "körd",
    "körveln": "körvel",
    "körvelns": "körvel",
    "körvels": "körvel",
    "körvis": "körvisa",
    "körvisan": "körvisa",
    "körvisans": "körvisa",
    "körvisas": "körvisa",
    "körvise": "körvisa",
    "körvisor": "körvisa",
    "körvisorna": "körvisa",
    "körvisornas": "körvisa",
    "körvisors": "körvisa",
    "körvägar": "körväg",
    "körvägarna": "körväg",
    "körvägarnas": "körväg",
    "körvägars": "körväg",
    "körvägen": "körväg",
    "körvägens": "körväg",
    "körvägs": "körväg",
    "kös": "kö",
    "köttbenen": "köttben",
    "köttbenens": "köttben",
    "köttbenet": "köttben",
    "köttbenets": "köttben",
    "köttbens": "köttben",
    "köttberget": "köttberg",
    "köttbergets": "köttberg",
    "köttbergs": "köttberg",
    "köttbond": "köttbonde",
    "köttbonden": "köttbonde",
    "köttbondens": "köttbonde",
    "köttbondes": "köttbonde",
    "köttbonds": "köttbonde",
    "köttboskapen": "köttboskap",
    "köttboskapens": "köttboskap",
    "köttboskaps": "köttboskap",
    "köttbull": "köttbulle",
    "köttbullar": "köttbulle",
    "köttbullarna": "köttbulle",
    "köttbullarnas": "köttbulle",
    "köttbullars": "köttbulle",
    "köttbullen": "köttbulle",
    "köttbullens": "köttbulle",
    "köttbulles": "köttbulle",
    "köttbulls": "köttbulle",
    "köttbullssmörgåsar": "köttbullssmörgås",
    "köttbullssmörgåsarna": "köttbullssmörgås",
    "köttbullssmörgåsarnas": "köttbullssmörgås",
    "köttbullssmörgåsars": "köttbullssmörgås",
    "köttbullssmörgåsen": "köttbullssmörgås",
    "köttbullssmörgåsens": "köttbullssmörgås",
    "köttbullsälskar": "köttbullsälskare",
    "köttbullsälskaren": "köttbullsälskare",
    "köttbullsälskarens": "köttbullsälskare",
    "köttbullsälskares": "köttbullsälskare",
    "köttbullsälskarna": "köttbullsälskare",
    "köttbullsälskarnas": "köttbullsälskare",
    "köttbönder": "köttbonde",
    "köttbönderna": "köttbonde",
    "köttböndernas": "köttbonde",
    "köttbönders": "köttbonde",
    "kötteden": "kötted",
    "köttedens": "kötted",
    "kötteder": "kötted",
    "köttederna": "kötted",
    "köttedernas": "kötted",
    "kötteders": "kötted",
    "kötteds": "kötted",
    "köttet": "kött",
    "köttets": "kött",
    "köttflug": "köttfluga",
    "köttflugan": "köttfluga",
    "köttflugans": "köttfluga",
    "köttflugas": "köttfluga",
    "köttfluge": "köttfluga",
    "köttflugor": "köttfluga",
    "köttflugorna": "köttfluga",
    "köttflugornas": "köttfluga",
    "köttflugors": "köttfluga",
    "köttflugs": "köttfluga",
    "köttfärgade": "köttfärgad",
    "köttfärgades": "köttfärgad",
    "köttfärgads": "köttfärgad",
    "köttfärgat": "köttfärgad",
    "köttfärgats": "köttfärgad",
    "köttfärsen": "köttfärs",
    "köttfärsens": "köttfärs",
    "köttfärsskandalen": "köttfärsskandal",
    "köttfärsskandalens": "köttfärsskandal",
    "köttfärsskandaler": "köttfärsskandal",
    "köttfärsskandalerna": "köttfärsskandal",
    "köttfärsskandalernas": "köttfärsskandal",
    "köttfärsskandalers": "köttfärsskandal",
    "köttfärsskandals": "köttfärsskandal",
    "köttgrytan": "köttgryta",
    "köttgrytans": "köttgryta",
    "köttgrytas": "köttgryta",
    "köttgryte": "köttgryta",
    "köttgrytor": "köttgryta",
    "köttgrytorna": "köttgryta",
    "köttgrytornas": "köttgryta",
    "köttgrytors": "köttgryta",
    "köttiga": "köttig",
    "köttigare": "köttig",
    "köttigares": "köttig",
    "köttigas": "köttig",
    "köttigast": "köttig",
    "köttigaste": "köttig",
    "köttigastes": "köttig",
    "köttigasts": "köttig",
    "köttige": "köttig",
    "köttiges": "köttig",
    "köttigheten": "köttighet",
    "köttighetens": "köttighet",
    "köttighets": "köttighet",
    "köttigs": "köttig",
    "köttigt": "köttig",
    "köttigts": "köttig",
    "köttklisters": "köttklister",
    "köttklistret": "köttklister",
    "köttklistrets": "köttklister",
    "köttkon": "köttko",
    "köttkons": "köttko",
    "köttkor": "köttko",
    "köttkorna": "köttko",
    "köttkornas": "köttko",
    "köttkors": "köttko",
    "köttkos": "köttko",
    "köttkvarnar": "köttkvarn",
    "köttkvarnarna": "köttkvarn",
    "köttkvarnarnas": "köttkvarn",
    "köttkvarnars": "köttkvarn",
    "köttkvarnen": "köttkvarn",
    "köttkvarnens": "köttkvarn",
    "köttkvarns": "köttkvarn",
    "köttmarknaden": "köttmarknad",
    "köttmarknadens": "köttmarknad",
    "köttmarknader": "köttmarknad",
    "köttmarknaderna": "köttmarknad",
    "köttmarknadernas": "köttmarknad",
    "köttmarknaders": "köttmarknad",
    "köttmarknads": "köttmarknad",
    "köttproduktionen": "köttproduktion",
    "köttproduktionens": "köttproduktion",
    "köttproduktions": "köttproduktion",
    "kötträtten": "kötträtt",
    "kötträttens": "kötträtt",
    "kötträtter": "kötträtt",
    "kötträtterna": "kötträtt",
    "kötträtternas": "kötträtt",
    "kötträtters": "kötträtt",
    "kötträtts": "kötträtt",
    "kötts": "kött",
    "köttsaften": "köttsaft",
    "köttsaftens": "köttsaft",
    "köttsafts": "köttsaft",
    "köttsidan": "köttsida",
    "köttsidans": "köttsida",
    "köttsidas": "köttsida",
    "köttside": "köttsida",
    "köttsides": "köttsida",
    "köttsidor": "köttsida",
    "köttsidorna": "köttsida",
    "köttsidornas": "köttsida",
    "köttsidors": "köttsida",
    "köttskivan": "köttskiva",
    "köttskivans": "köttskiva",
    "köttskivas": "köttskiva",
    "köttskive": "köttskiva",
    "köttskivor": "köttskiva",
    "köttskivorna": "köttskiva",
    "köttskivornas": "köttskiva",
    "köttskivors": "köttskiva",
    "köttslams": "köttslamsa",
    "köttslamsan": "köttslamsa",
    "köttslamsans": "köttslamsa",
    "köttslamsas": "köttslamsa",
    "köttslamse": "köttslamsa",
    "köttslamsor": "köttslamsa",
    "köttslamsorna": "köttslamsa",
    "köttslamsornas": "köttslamsa",
    "köttslamsors": "köttslamsa",
    "köttsliga": "köttslig",
    "köttsligare": "köttslig",
    "köttsligares": "köttslig",
    "köttsligas": "köttslig",
    "köttsligast": "köttslig",
    "köttsligaste": "köttslig",
    "köttsligastes": "köttslig",
    "köttsligasts": "köttslig",
    "köttslige": "köttslig",
    "köttsliges": "köttslig",
    "köttsligheten": "köttslighet",
    "köttslighetens": "köttslighet",
    "köttslighets": "köttslighet",
    "köttsligs": "köttslig",
    "köttsligt": "köttslig",
    "köttsligts": "köttslig",
    "köttsopp": "köttsoppa",
    "köttsoppan": "köttsoppa",
    "köttsoppans": "köttsoppa",
    "köttsoppas": "köttsoppa",
    "köttsoppe": "köttsoppa",
    "köttsoppor": "köttsoppa",
    "köttsopporna": "köttsoppa",
    "köttsoppornas": "köttsoppa",
    "köttsoppors": "köttsoppa",
    "köttsopps": "köttsoppa",
    "köttstycken": "köttstycke",
    "köttstyckena": "köttstycke",
    "köttstyckenas": "köttstycke",
    "köttstyckens": "köttstycke",
    "köttstyckes": "köttstycke",
    "köttstycket": "köttstycke",
    "köttstyckets": "köttstycke",
    "köttstycks": "köttstycke",
    "köttsåren": "köttsår",
    "köttsårens": "köttsår",
    "köttsåret": "köttsår",
    "köttsårets": "köttsår",
    "köttsårs": "köttsår",
    "köttviltet": "köttvilt",
    "köttviltets": "köttvilt",
    "köttvilts": "köttvilt",
    "köttyx": "köttyxa",
    "köttyxan": "köttyxa",
    "köttyxans": "köttyxa",
    "köttyxas": "köttyxa",
    "köttyxe": "köttyxa",
    "köttyxor": "köttyxa",
    "köttyxorna": "köttyxa",
    "köttyxornas": "köttyxa",
    "köttyxors": "köttyxa",
    "köttätar": "köttätare",
    "köttätaren": "köttätare",
    "köttätarens": "köttätare",
    "köttätares": "köttätare",
    "köttätarna": "köttätare",
    "köttätarnas": "köttätare",
    "köv": "köva",
    "kövande": "köva",
    "kövanden": "kövande",
    "kövandena": "kövande",
    "kövandenas": "kövande",
    "kövandens": "kövande",
    "kövandes": "kövande",
    "kövandet": "kövande",
    "kövandets": "kövande",
    "kövas": "köva",
    "kövd": "köva",
    "kövda": "köva",
    "kövdas": "köva",
    "kövde": "köva",
    "kövdes": "köva",
    "kövds": "köva",
    "köver": "köva",
    "köves": "köva",
    "kövs": "köva",
    "kövt": "köva",
    "kövts": "köva",
    "l-en": "l",
    "l-ens": "l",
    "l-et": "l",
    "l-ets": "l",
    "l-s": "l",
    "l:en": "l",
    "l:ens": "l",
    "l:et": "l",
    "l:ets": "l",
    "l:s": "l",
    "la": "lägga",
    "labar": "lab",
    "labarna": "lab",
    "labarnas": "lab",
    "labars": "lab",
    "labb": "labbe",
    "labbar": "labbe",
    "labbarna": "labbe",
    "labbarnas": "labbe",
    "labbars": "labbe",
    "labben": "labbe",
    "labbens": "labbe",
    "labbes": "labbe",
    "labbet": "labb",
    "labbets": "labb",
    "labbs": "labbe",
    "laben": "lab",
    "labens": "lab",
    "labers": "laber",
    "labert": "laber",
    "laberts": "laber",
    "labet": "lab",
    "labets": "lab",
    "labiala": "labial",
    "labialare": "labial",
    "labialares": "labial",
    "labialas": "labial",
    "labialast": "labial",
    "labialaste": "labial",
    "labialastes": "labial",
    "labialasts": "labial",
    "labiale": "labial",
    "labialen": "labial",
    "labialens": "labial",
    "labialer": "labial",
    "labialerna": "labial",
    "labialernas": "labial",
    "labialers": "labial",
    "labiales": "labial",
    "labialiserad": "labialisera",
    "labialiserade": "labialiserad",
    "labialiserades": "labialiserad",
    "labialiserads": "labialiserad",
    "labialiserande": "labialisera",
    "labialiseranden": "labialiserande",
    "labialiserandena": "labialiserande",
    "labialiserandenas": "labialiserande",
    "labialiserandens": "labialiserande",
    "labialiserandes": "labialiserande",
    "labialiserandet": "labialiserande",
    "labialiserandets": "labialiserande",
    "labialiserar": "labialisera",
    "labialiseras": "labialisera",
    "labialiserat": "labialiserad",
    "labialiserats": "labialiserad",
    "labialiserbara": "labialiserbar",
    "labialiserbarare": "labialiserbar",
    "labialiserbarares": "labialiserbar",
    "labialiserbaras": "labialiserbar",
    "labialiserbarast": "labialiserbar",
    "labialiserbaraste": "labialiserbar",
    "labialiserbarastes": "labialiserbar",
    "labialiserbarasts": "labialiserbar",
    "labialiserbare": "labialiserbar",
    "labialiserbares": "labialiserbar",
    "labialiserbarheten": "labialiserbarhet",
    "labialiserbarhetens": "labialiserbarhet",
    "labialiserbarhets": "labialiserbarhet",
    "labialiserbars": "labialiserbar",
    "labialiserbart": "labialiserbar",
    "labialiserbarts": "labialiserbar",
    "labialiseringar": "labialisering",
    "labialiseringarna": "labialisering",
    "labialiseringarnas": "labialisering",
    "labialiseringars": "labialisering",
    "labialiseringen": "labialisering",
    "labialiseringens": "labialisering",
    "labialiserings": "labialisering",
    "labialpip": "labialpipa",
    "labialpipan": "labialpipa",
    "labialpipans": "labialpipa",
    "labialpipas": "labialpipa",
    "labialpipe": "labialpipa",
    "labialpipor": "labialpipa",
    "labialpiporna": "labialpipa",
    "labialpipornas": "labialpipa",
    "labialpipors": "labialpipa",
    "labialpips": "labialpipa",
    "labials": "labial",
    "labialstämman": "labialstämma",
    "labialstämmans": "labialstämma",
    "labialstämmas": "labialstämma",
    "labialstämme": "labialstämma",
    "labialstämmo": "labialstämma",
    "labialstämmor": "labialstämma",
    "labialstämmorna": "labialstämma",
    "labialstämmornas": "labialstämma",
    "labialstämmors": "labialstämma",
    "labialt": "labial",
    "labialts": "labial",
    "labila": "labil",
    "labilare": "labil",
    "labilares": "labil",
    "labilas": "labil",
    "labilast": "labil",
    "labilaste": "labil",
    "labilastes": "labil",
    "labilasts": "labil",
    "labile": "labil",
    "labiles": "labil",
    "labiliteten": "labilitet",
    "labilitetens": "labilitet",
    "labiliteter": "labilitet",
    "labiliteterna": "labilitet",
    "labiliteternas": "labilitet",
    "labiliteters": "labilitet",
    "labilitets": "labilitet",
    "labils": "labil",
    "labilt": "labil",
    "labilts": "labil",
    "labiodentala": "labiodental",
    "labiodentalare": "labiodental",
    "labiodentalares": "labiodental",
    "labiodentalas": "labiodental",
    "labiodentalast": "labiodental",
    "labiodentalaste": "labiodental",
    "labiodentalastes": "labiodental",
    "labiodentalasts": "labiodental",
    "labiodentale": "labiodental",
    "labiodentalen": "labiodental",
    "labiodentalens": "labiodental",
    "labiodentaler": "labiodental",
    "labiodentalerna": "labiodental",
    "labiodentalernas": "labiodental",
    "labiodentalers": "labiodental",
    "labiodentales": "labiodental",
    "labiodentals": "labiodental",
    "labiodentalt": "labiodental",
    "labiodentalts": "labiodental",
    "labiologien": "labiologi",
    "labiologiens": "labiologi",
    "labiologin": "labiologi",
    "labiologins": "labiologi",
    "labiologis": "labiologi",
    "laboranten": "laborant",
    "laborantens": "laborant",
    "laboranter": "laborant",
    "laboranterna": "laborant",
    "laboranternas": "laborant",
    "laboranters": "laborant",
    "laborants": "laborant",
    "laborationen": "laboration",
    "laborationens": "laboration",
    "laborationer": "laboration",
    "laborationerna": "laboration",
    "laborationernas": "laboration",
    "laborationers": "laboration",
    "laborations": "laboration",
    "laborativa": "laborativ",
    "laborativare": "laborativ",
    "laborativares": "laborativ",
    "laborativas": "laborativ",
    "laborativast": "laborativ",
    "laborativaste": "laborativ",
    "laborativastes": "laborativ",
    "laborativasts": "laborativ",
    "laborative": "laborativ",
    "laboratives": "laborativ",
    "laborativs": "laborativ",
    "laborativt": "laborativ",
    "laborativts": "laborativ",
    "laboratorer": "laborator",
    "laboratorerna": "laborator",
    "laboratorernas": "laborator",
    "laboratorers": "laborator",
    "laboratorie": "laboratorium",
    "laboratorieassistenten": "laboratorieassistent",
    "laboratorieassistentens": "laboratorieassistent",
    "laboratorieassistenter": "laboratorieassistent",
    "laboratorieassistenterna": "laboratorieassistent",
    "laboratorieassistenternas": "laboratorieassistent",
    "laboratorieassistenters": "laboratorieassistent",
    "laboratorieassistents": "laboratorieassistent",
    "laboratorieexperimenten": "laboratorieexperiment",
    "laboratorieexperimentens": "laboratorieexperiment",
    "laboratorieexperimentet": "laboratorieexperiment",
    "laboratorieexperimentets": "laboratorieexperiment",
    "laboratorieexperiments": "laboratorieexperiment",
    "laboratoriekurios": "laboratoriekuriosa",
    "laboratoriekuriosan": "laboratoriekuriosa",
    "laboratoriekuriosans": "laboratoriekuriosa",
    "laboratoriekuriosas": "laboratoriekuriosa",
    "laboratoriekuriose": "laboratoriekuriosa",
    "laboratoriekuriosor": "laboratoriekuriosa",
    "laboratoriekuriosorna": "laboratoriekuriosa",
    "laboratoriekuriosornas": "laboratoriekuriosa",
    "laboratoriekuriosors": "laboratoriekuriosa",
    "laboratoriemässiga": "laboratoriemässig",
    "laboratoriemässigare": "laboratoriemässig",
    "laboratoriemässigares": "laboratoriemässig",
    "laboratoriemässigas": "laboratoriemässig",
    "laboratoriemässigast": "laboratoriemässig",
    "laboratoriemässigaste": "laboratoriemässig",
    "laboratoriemässigastes": "laboratoriemässig",
    "laboratoriemässigasts": "laboratoriemässig",
    "laboratoriemässige": "laboratoriemässig",
    "laboratoriemässiges": "laboratoriemässig",
    "laboratoriemässigs": "laboratoriemässig",
    "laboratoriemässigt": "laboratoriemässig",
    "laboratoriemässigts": "laboratoriemässig",
    "laboratorier": "laboratorium",
    "laboratorieresultaten": "laboratorieresultat",
    "laboratorieresultatens": "laboratorieresultat",
    "laboratorieresultatet": "laboratorieresultat",
    "laboratorieresultatets": "laboratorieresultat",
    "laboratorieresultats": "laboratorieresultat",
    "laboratorierna": "laboratorium",
    "laboratoriernas": "laboratorium",
    "laboratorierockar": "laboratorierock",
    "laboratorierockarna": "laboratorierock",
    "laboratorierockarnas": "laboratorierock",
    "laboratorierockars": "laboratorierock",
    "laboratorierocken": "laboratorierock",
    "laboratorierockens": "laboratorierock",
    "laboratorierocks": "laboratorierock",
    "laboratoriers": "laboratorium",
    "laboratorierått": "laboratorieråtta",
    "laboratorieråttan": "laboratorieråtta",
    "laboratorieråttans": "laboratorieråtta",
    "laboratorieråttas": "laboratorieråtta",
    "laboratorieråtte": "laboratorieråtta",
    "laboratorieråttor": "laboratorieråtta",
    "laboratorieråttorna": "laboratorieråtta",
    "laboratorieråttornas": "laboratorieråtta",
    "laboratorieråttors": "laboratorieråtta",
    "laboratorieråtts": "laboratorieråtta",
    "laboratoriet": "laboratorium",
    "laboratoriets": "laboratorium",
    "laboratoriums": "laboratorium",
    "laboratorn": "laborator",
    "laboratorns": "laborator",
    "laborators": "laborator",
    "laborerade": "laborera",
    "laborerades": "laborera",
    "laborerande": "laborera",
    "laboreranden": "laborerande",
    "laborerandena": "laborerande",
    "laborerandenas": "laborerande",
    "laborerandens": "laborerande",
    "laborerandes": "laborerande",
    "laborerandet": "laborerande",
    "laborerandets": "laborerande",
    "laborerar": "laborera",
    "laboreras": "laborera",
    "laborerat": "laborera",
    "laborerats": "laborera",
    "laboreringar": "laborering",
    "laboreringarna": "laborering",
    "laboreringarnas": "laborering",
    "laboreringars": "laborering",
    "laboreringen": "laborering",
    "laboreringens": "laborering",
    "laborerings": "laborering",
    "labourregeringar": "labourregering",
    "labourregeringarna": "labourregering",
    "labourregeringarnas": "labourregering",
    "labourregeringars": "labourregering",
    "labourregeringen": "labourregering",
    "labourregeringens": "labourregering",
    "labourregerings": "labourregering",
    "labours": "labour",
    "labra": "laber",
    "labradoren": "labrador",
    "labradorens": "labrador",
    "labradorer": "labrador",
    "labradorerna": "labrador",
    "labradorernas": "labrador",
    "labradorers": "labrador",
    "labradorhann": "labradorhanne",
    "labradorhannar": "labradorhanne",
    "labradorhannarna": "labradorhanne",
    "labradorhannarnas": "labradorhanne",
    "labradorhannars": "labradorhanne",
    "labradorhannen": "labradorhanne",
    "labradorhannens": "labradorhanne",
    "labradorhannes": "labradorhanne",
    "labradorhanns": "labradorhanne",
    "labradors": "labrador",
    "labrare": "laber",
    "labrares": "laber",
    "labras": "laber",
    "labrast": "laber",
    "labraste": "laber",
    "labrastes": "laber",
    "labrasts": "laber",
    "labre": "laber",
    "labres": "laber",
    "labs": "lab",
    "labyrinten": "labyrint",
    "labyrintens": "labyrint",
    "labyrinter": "labyrint",
    "labyrinterna": "labyrint",
    "labyrinternas": "labyrint",
    "labyrinters": "labyrint",
    "labyrintiska": "labyrintisk",
    "labyrintiskare": "labyrintisk",
    "labyrintiskares": "labyrintisk",
    "labyrintiskas": "labyrintisk",
    "labyrintiskast": "labyrintisk",
    "labyrintiskaste": "labyrintisk",
    "labyrintiskastes": "labyrintisk",
    "labyrintiskasts": "labyrintisk",
    "labyrintiske": "labyrintisk",
    "labyrintiskes": "labyrintisk",
    "labyrintisks": "labyrintisk",
    "labyrintiskt": "labyrintisk",
    "labyrintiskts": "labyrintisk",
    "labyrints": "labyrint",
    "lack": "lacka",
    "lackad": "lacka",
    "lackade": "lacka",
    "lackades": "lacka",
    "lackads": "lacka",
    "lackande": "lacka",
    "lackanden": "lackande",
    "lackandena": "lackande",
    "lackandenas": "lackande",
    "lackandens": "lackande",
    "lackandes": "lackande",
    "lackandet": "lackande",
    "lackandets": "lackande",
    "lackar": "lacka",
    "lackas": "lacka",
    "lackat": "lacka",
    "lackats": "lacka",
    "lacken": "lack",
    "lackens": "lack",
    "lacker": "lack",
    "lackerad": "lackera",
    "lackerade": "lackera",
    "lackerades": "lackera",
    "lackerads": "lackera",
    "lackerande": "lackera",
    "lackeranden": "lackerande",
    "lackerandena": "lackerande",
    "lackerandenas": "lackerande",
    "lackerandens": "lackerande",
    "lackerandes": "lackerande",
    "lackerandet": "lackerande",
    "lackerandets": "lackerande",
    "lackerar": "lackera",
    "lackeras": "lackera",
    "lackerat": "lackera",
    "lackerats": "lackera",
    "lackerbara": "lackerbar",
    "lackerbarare": "lackerbar",
    "lackerbarares": "lackerbar",
    "lackerbaras": "lackerbar",
    "lackerbarast": "lackerbar",
    "lackerbaraste": "lackerbar",
    "lackerbarastes": "lackerbar",
    "lackerbarasts": "lackerbar",
    "lackerbare": "lackerbar",
    "lackerbares": "lackerbar",
    "lackerbarheten": "lackerbarhet",
    "lackerbarhetens": "lackerbarhet",
    "lackerbarhets": "lackerbarhet",
    "lackerbars": "lackerbar",
    "lackerbart": "lackerbar",
    "lackerbarts": "lackerbar",
    "lackeringar": "lackering",
    "lackeringarna": "lackering",
    "lackeringarnas": "lackering",
    "lackeringars": "lackering",
    "lackeringen": "lackering",
    "lackeringens": "lackering",
    "lackerings": "lackering",
    "lackerna": "lack",
    "lackernas": "lack",
    "lackers": "lack",
    "lacket": "lack",
    "lackets": "lack",
    "lackfärgen": "lackfärg",
    "lackfärgens": "lackfärg",
    "lackfärger": "lackfärg",
    "lackfärgerna": "lackfärg",
    "lackfärgernas": "lackfärg",
    "lackfärgers": "lackfärg",
    "lackfärgs": "lackfärg",
    "lackmusen": "lackmus",
    "lackmusens": "lackmus",
    "lackmustesten": "lackmustest",
    "lackmustestens": "lackmustest",
    "lackmustester": "lackmustest",
    "lackmustesterna": "lackmustest",
    "lackmustesternas": "lackmustest",
    "lackmustesters": "lackmustest",
    "lackmustestet": "lackmustest",
    "lackmustestets": "lackmustest",
    "lackmustests": "lackmustest",
    "lacknaftan": "lacknafta",
    "lacknaftans": "lacknafta",
    "lacknaftas": "lacknafta",
    "lackningar": "lackning",
    "lackningarna": "lackning",
    "lackningarnas": "lackning",
    "lackningars": "lackning",
    "lackningen": "lackning",
    "lackningens": "lackning",
    "lacknings": "lackning",
    "lackpenseln": "lackpensel",
    "lackpenselns": "lackpensel",
    "lackpensels": "lackpensel",
    "lackpenslar": "lackpensel",
    "lackpenslarna": "lackpensel",
    "lackpenslarnas": "lackpensel",
    "lackpenslars": "lackpensel",
    "lackrollern": "lackroller",
    "lackrollerna": "lackroller",
    "lackrollernas": "lackroller",
    "lackrollerns": "lackroller",
    "lackrollers": "lackroller",
    "lackrollrar": "lackroller",
    "lackrollrarna": "lackroller",
    "lackrollrarnas": "lackroller",
    "lackrollrars": "lackroller",
    "lackrull": "lackrulle",
    "lackrullar": "lackrulle",
    "lackrullarna": "lackrulle",
    "lackrullarnas": "lackrulle",
    "lackrullars": "lackrulle",
    "lackrullen": "lackrulle",
    "lackrullens": "lackrulle",
    "lackrulles": "lackrulle",
    "lackrulls": "lackrulle",
    "lacks": "lack",
    "lackskon": "lacksko",
    "lackskons": "lacksko",
    "lackskor": "lacksko",
    "lackskorna": "lacksko",
    "lackskornas": "lacksko",
    "lackskors": "lacksko",
    "lackskos": "lacksko",
    "lackskärpen": "lackskärp",
    "lackskärpens": "lackskärp",
    "lackskärpet": "lackskärp",
    "lackskärpets": "lackskärp",
    "lackskärps": "lackskärp",
    "lacksköldlusen": "lacksköldlus",
    "lacksköldlusens": "lacksköldlus",
    "lacksköldlöss": "lacksköldlus",
    "lacksköldlössen": "lacksköldlus",
    "lacksköldlössens": "lacksköldlus",
    "lackviolen": "lackviol",
    "lackviolens": "lackviol",
    "lackvioler": "lackviol",
    "lackviolerna": "lackviol",
    "lackviolernas": "lackviol",
    "lackviolers": "lackviol",
    "lackviols": "lackviol",
    "lad": "lada",
    "ladan": "lada",
    "ladans": "lada",
    "ladas": "lada",
    "ladd": "ladda",
    "laddad": "ladda",
    "laddade": "laddad",
    "laddades": "laddad",
    "laddads": "laddad",
    "laddande": "ladda",
    "laddanden": "laddande",
    "laddandena": "laddande",
    "laddandenas": "laddande",
    "laddandens": "laddande",
    "laddandes": "laddande",
    "laddandet": "laddande",
    "laddandets": "laddande",
    "laddar": "laddare",
    "laddaren": "laddare",
    "laddarens": "laddare",
    "laddares": "laddare",
    "laddarna": "laddare",
    "laddarnas": "laddare",
    "laddas": "ladda",
    "laddat": "laddad",
    "laddats": "laddad",
    "laddindiceringar": "laddindicering",
    "laddindiceringarna": "laddindicering",
    "laddindiceringarnas": "laddindicering",
    "laddindiceringars": "laddindicering",
    "laddindiceringen": "laddindicering",
    "laddindiceringens": "laddindicering",
    "laddindicerings": "laddindicering",
    "laddindikeringar": "laddindikering",
    "laddindikeringarna": "laddindikering",
    "laddindikeringarnas": "laddindikering",
    "laddindikeringars": "laddindikering",
    "laddindikeringen": "laddindikering",
    "laddindikeringens": "laddindikering",
    "laddindikerings": "laddindikering",
    "laddningar": "laddning",
    "laddningarna": "laddning",
    "laddningarnas": "laddning",
    "laddningars": "laddning",
    "laddningen": "laddning",
    "laddningens": "laddning",
    "laddnings": "laddning",
    "laddningsregulatorer": "laddningsregulator",
    "laddningsregulatorerna": "laddningsregulator",
    "laddningsregulatorernas": "laddningsregulator",
    "laddningsregulatorers": "laddningsregulator",
    "laddningsregulatorn": "laddningsregulator",
    "laddningsregulatorns": "laddningsregulator",
    "laddningsregulators": "laddningsregulator",
    "laddningsstolp": "laddningsstolpe",
    "laddningsstolpar": "laddningsstolpe",
    "laddningsstolparna": "laddningsstolpe",
    "laddningsstolparnas": "laddningsstolpe",
    "laddningsstolpars": "laddningsstolpe",
    "laddningsstolpen": "laddningsstolpe",
    "laddningsstolpens": "laddningsstolpe",
    "laddningsstolpes": "laddningsstolpe",
    "laddningsstolps": "laddningsstolpe",
    "laddningsströmmar": "laddningsström",
    "laddningsströmmarna": "laddningsström",
    "laddningsströmmarnas": "laddningsström",
    "laddningsströmmars": "laddningsström",
    "laddningsströmmen": "laddningsström",
    "laddningsströmmens": "laddningsström",
    "laddningsströms": "laddningsström",
    "laddningstiden": "laddningstid",
    "laddningstidens": "laddningstid",
    "laddningstider": "laddningstid",
    "laddningstiderna": "laddningstid",
    "laddningstidernas": "laddningstid",
    "laddningstiders": "laddningstid",
    "laddningstids": "laddningstid",
    "laddramar": "laddram",
    "laddramarna": "laddram",
    "laddramarnas": "laddram",
    "laddramars": "laddram",
    "laddramen": "laddram",
    "laddramens": "laddram",
    "laddrams": "laddram",
    "laddstockar": "laddstock",
    "laddstockarna": "laddstock",
    "laddstockarnas": "laddstock",
    "laddstockars": "laddstock",
    "laddstocken": "laddstock",
    "laddstockens": "laddstock",
    "laddstocks": "laddstock",
    "laddstolp": "laddstolpe",
    "laddstolpar": "laddstolpe",
    "laddstolparna": "laddstolpe",
    "laddstolparnas": "laddstolpe",
    "laddstolpars": "laddstolpe",
    "laddstolpen": "laddstolpe",
    "laddstolpens": "laddstolpe",
    "laddstolpes": "laddstolpe",
    "laddstolps": "laddstolpe",
    "laddströmmar": "laddström",
    "laddströmmarna": "laddström",
    "laddströmmarnas": "laddström",
    "laddströmmars": "laddström",
    "laddströmmen": "laddström",
    "laddströmmens": "laddström",
    "laddströms": "laddström",
    "lade": "lägga",
    "laden": "lad",
    "ladens": "lad",
    "lades": "lägga",
    "ladet": "lad",
    "ladets": "lad",
    "ladies": "lady",
    "ladiesarna": "lady",
    "ladiesarnas": "lady",
    "lador": "lada",
    "ladorna": "lada",
    "ladornas": "lada",
    "ladors": "lada",
    "lads": "lada",
    "ladugårdar": "ladugård",
    "ladugårdarna": "ladugård",
    "ladugårdarnas": "ladugård",
    "ladugårdars": "ladugård",
    "ladugården": "ladugård",
    "ladugårdens": "ladugård",
    "ladugårds": "ladugård",
    "ladugårdstaken": "ladugårdstak",
    "ladugårdstakens": "ladugårdstak",
    "ladugårdstaket": "ladugårdstak",
    "ladugårdstakets": "ladugårdstak",
    "ladugårdstaks": "ladugårdstak",
    "ladusvalan": "ladusvala",
    "ladusvalans": "ladusvala",
    "ladusvalas": "ladusvala",
    "ladusvale": "ladusvala",
    "ladusvalor": "ladusvala",
    "ladusvalorna": "ladusvala",
    "ladusvalornas": "ladusvala",
    "ladusvalors": "ladusvala",
    "ladyn": "lady",
    "ladyns": "lady",
    "ladys": "lady",
    "laestadianen": "laestadian",
    "laestadianer": "laestadian",
    "laestadianernas": "laestadian",
    "laestadianismen": "laestadianism",
    "laestadianismer": "laestadianism",
    "laestadianismernas": "laestadianism",
    "laestadianisms": "laestadianism",
    "lafsade": "lafsa",
    "lafsades": "lafsa",
    "lafsande": "lafsa",
    "lafsanden": "lafsande",
    "lafsandena": "lafsande",
    "lafsandenas": "lafsande",
    "lafsandens": "lafsande",
    "lafsandes": "lafsande",
    "lafsandet": "lafsande",
    "lafsandets": "lafsande",
    "lafsar": "lafsa",
    "lafsas": "lafsa",
    "lafsat": "lafsa",
    "lafsats": "lafsa",
    "lafset": "lafs",
    "lafsets": "lafs",
    "lafsiga": "lafsig",
    "lafsigare": "lafsig",
    "lafsigares": "lafsig",
    "lafsigas": "lafsig",
    "lafsigast": "lafsig",
    "lafsigaste": "lafsig",
    "lafsigastes": "lafsig",
    "lafsigasts": "lafsig",
    "lafsige": "lafsig",
    "lafsiges": "lafsig",
    "lafsigheten": "lafsighet",
    "lafsighetens": "lafsighet",
    "lafsighets": "lafsighet",
    "lafsigs": "lafsig",
    "lafsigt": "lafsig",
    "lafsigts": "lafsig",
    "lag": "laga",
    "lagad": "laga",
    "lagade": "laga",
    "lagades": "laga",
    "lagads": "laga",
    "lagandan": "laganda",
    "lagandans": "laganda",
    "lagandas": "laganda",
    "lagande": "laga",
    "laganden": "lagande",
    "lagandena": "lagande",
    "lagandenas": "lagande",
    "lagandens": "lagande",
    "lagandes": "lagande",
    "lagandet": "lagande",
    "lagandets": "lagande",
    "lagar": "laga",
    "lagarbeten": "lagarbete",
    "lagarbetena": "lagarbete",
    "lagarbetenas": "lagarbete",
    "lagarbetens": "lagarbete",
    "lagarbetes": "lagarbete",
    "lagarbetet": "lagarbete",
    "lagarbetets": "lagarbete",
    "lagarbets": "lagarbete",
    "lagarna": "lag",
    "lagarnas": "lag",
    "lagars": "lag",
    "lagas": "laga",
    "lagat": "laga",
    "lagats": "laga",
    "lagbalkar": "lagbalk",
    "lagbalkarna": "lagbalk",
    "lagbalkarnas": "lagbalk",
    "lagbalkars": "lagbalk",
    "lagbalken": "lagbalk",
    "lagbalkens": "lagbalk",
    "lagbalks": "lagbalk",
    "lagberedningar": "lagberedning",
    "lagberedningarna": "lagberedning",
    "lagberedningarnas": "lagberedning",
    "lagberedningars": "lagberedning",
    "lagberedningen": "lagberedning",
    "lagberedningens": "lagberedning",
    "lagberednings": "lagberedning",
    "lagboken": "lagbok",
    "lagbokens": "lagbok",
    "lagboks": "lagbok",
    "lagbundenheten": "lagbundenhet",
    "lagbundenhetens": "lagbundenhet",
    "lagbundenheter": "lagbundenhet",
    "lagbundenheterna": "lagbundenhet",
    "lagbundenheternas": "lagbundenhet",
    "lagbundenheters": "lagbundenhet",
    "lagbundenhets": "lagbundenhet",
    "lagbundens": "lagbunden",
    "lagbundet": "lagbunden",
    "lagbundets": "lagbunden",
    "lagbundna": "lagbunden",
    "lagbundnare": "lagbunden",
    "lagbundnares": "lagbunden",
    "lagbundnas": "lagbunden",
    "lagbundnast": "lagbunden",
    "lagbundnaste": "lagbunden",
    "lagbundnastes": "lagbunden",
    "lagbundnasts": "lagbunden",
    "lagbundne": "lagbunden",
    "lagbundnes": "lagbunden",
    "lagböcker": "lagbok",
    "lagböckerna": "lagbok",
    "lagböckernas": "lagbok",
    "lagböckers": "lagbok",
    "lagd": "lägga",
    "lagda": "lägga",
    "lagdare": "lagd",
    "lagdares": "lagd",
    "lagdas": "lägga",
    "lagdast": "lagd",
    "lagdaste": "lagd",
    "lagdastes": "lagd",
    "lagdasts": "lagd",
    "lagde": "lägga",
    "lagdes": "lägga",
    "lagds": "lägga",
    "lagen": "lag",
    "lagenliga": "lagenlig",
    "lagenligare": "lagenlig",
    "lagenligares": "lagenlig",
    "lagenligas": "lagenlig",
    "lagenligast": "lagenlig",
    "lagenligaste": "lagenlig",
    "lagenligastes": "lagenlig",
    "lagenligasts": "lagenlig",
    "lagenlige": "lagenlig",
    "lagenliges": "lagenlig",
    "lagenligheten": "lagenlighet",
    "lagenlighetens": "lagenlighet",
    "lagenlighets": "lagenlighet",
    "lagenligs": "lagenlig",
    "lagenligt": "lagenlig",
    "lagenligts": "lagenlig",
    "lagens": "lag",
    "lagerbladen": "lagerblad",
    "lagerbladens": "lagerblad",
    "lagerbladet": "lagerblad",
    "lagerbladets": "lagerblad",
    "lagerblads": "lagerblad",
    "lagerboken": "lagerbok",
    "lagerbokens": "lagerbok",
    "lagerboks": "lagerbok",
    "lagerboxar": "lagerbox",
    "lagerboxarna": "lagerbox",
    "lagerboxarnas": "lagerbox",
    "lagerboxars": "lagerbox",
    "lagerboxen": "lagerbox",
    "lagerboxens": "lagerbox",
    "lagerbärsbladen": "lagerbärsblad",
    "lagerbärsbladens": "lagerbärsblad",
    "lagerbärsbladet": "lagerbärsblad",
    "lagerbärsbladets": "lagerbärsblad",
    "lagerbärsblads": "lagerbärsblad",
    "lagerböcker": "lagerbok",
    "lagerböckerna": "lagerbok",
    "lagerböckernas": "lagerbok",
    "lagerböckers": "lagerbok",
    "lagerföljden": "lagerföljd",
    "lagerföljdens": "lagerföljd",
    "lagerföljder": "lagerföljd",
    "lagerföljderna": "lagerföljd",
    "lagerföljdernas": "lagerföljd",
    "lagerföljders": "lagerföljd",
    "lagerföljds": "lagerföljd",
    "lagerför": "lagerföra",
    "lagerförande": "lagerföra",
    "lagerföranden": "lagerförande",
    "lagerförandena": "lagerförande",
    "lagerförandenas": "lagerförande",
    "lagerförandens": "lagerförande",
    "lagerförandes": "lagerförande",
    "lagerförandet": "lagerförande",
    "lagerförandets": "lagerförande",
    "lagerföras": "lagerföra",
    "lagerförd": "lagerföra",
    "lagerförda": "lagerföra",
    "lagerfördas": "lagerföra",
    "lagerförde": "lagerföra",
    "lagerfördes": "lagerföra",
    "lagerförds": "lagerföra",
    "lagerföres": "lagerföra",
    "lagerförs": "lagerföra",
    "lagerfört": "lagerföra",
    "lagerförts": "lagerföra",
    "lagergångar": "lagergång",
    "lagergångarna": "lagergång",
    "lagergångarnas": "lagergång",
    "lagergångars": "lagergång",
    "lagergången": "lagergång",
    "lagergångens": "lagergång",
    "lagergångs": "lagergång",
    "lagerkon": "lagerkona",
    "lagerkonan": "lagerkona",
    "lagerkonans": "lagerkona",
    "lagerkonas": "lagerkona",
    "lagerkone": "lagerkona",
    "lagerkonor": "lagerkona",
    "lagerkonorna": "lagerkona",
    "lagerkonornas": "lagerkona",
    "lagerkonors": "lagerkona",
    "lagerkons": "lagerkona",
    "lagerkostnaden": "lagerkostnad",
    "lagerkostnadens": "lagerkostnad",
    "lagerkostnader": "lagerkostnad",
    "lagerkostnaderna": "lagerkostnad",
    "lagerkostnadernas": "lagerkostnad",
    "lagerkostnaders": "lagerkostnad",
    "lagerkostnads": "lagerkostnad",
    "lagerkrans": "lagerkransa",
    "lagerkransad": "lagerkransa",
    "lagerkransade": "lagerkransa",
    "lagerkransades": "lagerkransa",
    "lagerkransads": "lagerkransa",
    "lagerkransande": "lagerkransa",
    "lagerkransanden": "lagerkransande",
    "lagerkransandena": "lagerkransande",
    "lagerkransandenas": "lagerkransande",
    "lagerkransandens": "lagerkransande",
    "lagerkransandes": "lagerkransande",
    "lagerkransandet": "lagerkransande",
    "lagerkransandets": "lagerkransande",
    "lagerkransar": "lagerkransa",
    "lagerkransarna": "lagerkrans",
    "lagerkransarnas": "lagerkrans",
    "lagerkransars": "lagerkrans",
    "lagerkransas": "lagerkransa",
    "lagerkransat": "lagerkransa",
    "lagerkransats": "lagerkransa",
    "lagerkransen": "lagerkrans",
    "lagerkransens": "lagerkrans",
    "lagerkrön": "lagerkröna",
    "lagerkrönande": "lagerkröna",
    "lagerkrönanden": "lagerkrönande",
    "lagerkrönandena": "lagerkrönande",
    "lagerkrönandenas": "lagerkrönande",
    "lagerkrönandens": "lagerkrönande",
    "lagerkrönandes": "lagerkrönande",
    "lagerkrönandet": "lagerkrönande",
    "lagerkrönandets": "lagerkrönande",
    "lagerkrönas": "lagerkröna",
    "lagerkröner": "lagerkröna",
    "lagerkrönes": "lagerkröna",
    "lagerkröns": "lagerkröna",
    "lagerkrönt": "lagerkröna",
    "lagerkrönta": "lagerkröna",
    "lagerkröntas": "lagerkröna",
    "lagerkrönte": "lagerkröna",
    "lagerkröntes": "lagerkröna",
    "lagerkrönts": "lagerkröna",
    "lagerkörsen": "lagerkörs",
    "lagerkörsens": "lagerkörs",
    "lagerlokalen": "lagerlokal",
    "lagerlokalens": "lagerlokal",
    "lagerlokaler": "lagerlokal",
    "lagerlokalerna": "lagerlokal",
    "lagerlokalernas": "lagerlokal",
    "lagerlokalers": "lagerlokal",
    "lagerlokals": "lagerlokal",
    "lagern": "lager",
    "lagerna": "lager",
    "lagernas": "lager",
    "lagerns": "lager",
    "lagers": "lager",
    "lagerserien": "lagerserie",
    "lagerseriens": "lagerserie",
    "lagerserier": "lagerserie",
    "lagerserierna": "lagerserie",
    "lagerseriernas": "lagerserie",
    "lagerseriers": "lagerserie",
    "lagerseries": "lagerserie",
    "lagerölen": "lageröl",
    "lagerölens": "lageröl",
    "lagerölet": "lageröl",
    "lagerölets": "lageröl",
    "lageröls": "lageröl",
    "laget": "lag",
    "lagets": "lag",
    "lagfar": "lagfara",
    "lagfarande": "lagfara",
    "lagfaranden": "lagfarande",
    "lagfarandena": "lagfarande",
    "lagfarandenas": "lagfarande",
    "lagfarandens": "lagfarande",
    "lagfarandes": "lagfarande",
    "lagfarandet": "lagfarande",
    "lagfarandets": "lagfarande",
    "lagfaras": "lagfara",
    "lagfare": "lagfara",
    "lagfaren": "lagfara",
    "lagfarenheten": "lagfarenhet",
    "lagfarenhetens": "lagfarenhet",
    "lagfarenhets": "lagfarenhet",
    "lagfarens": "lagfaren",
    "lagfares": "lagfara",
    "lagfaret": "lagfaren",
    "lagfarets": "lagfaren",
    "lagfarit": "lagfara",
    "lagfarits": "lagfara",
    "lagfarna": "lagfaren",
    "lagfarnare": "lagfaren",
    "lagfarnares": "lagfaren",
    "lagfarnas": "lagfaren",
    "lagfarnast": "lagfaren",
    "lagfarnaste": "lagfaren",
    "lagfarnastes": "lagfaren",
    "lagfarnasts": "lagfaren",
    "lagfarne": "lagfaren",
    "lagfarnes": "lagfaren",
    "lagfars": "lagfara",
    "lagfarten": "lagfart",
    "lagfartens": "lagfart",
    "lagfarter": "lagfart",
    "lagfarterna": "lagfart",
    "lagfarternas": "lagfart",
    "lagfarters": "lagfart",
    "lagfarts": "lagfart",
    "lagfor": "lagfara",
    "lagfore": "lagfara",
    "lagfores": "lagfara",
    "lagfors": "lagfara",
    "lagfäst": "lagfästa",
    "lagfästande": "lagfästa",
    "lagfästanden": "lagfästande",
    "lagfästandena": "lagfästande",
    "lagfästandenas": "lagfästande",
    "lagfästandens": "lagfästande",
    "lagfästandes": "lagfästande",
    "lagfästandet": "lagfästande",
    "lagfästandets": "lagfästande",
    "lagfästas": "lagfästa",
    "lagfäste": "lagfästa",
    "lagfäster": "lagfästa",
    "lagfästes": "lagfästa",
    "lagfästs": "lagfästa",
    "lagfångens": "lagfången",
    "lagfånget": "lagfången",
    "lagfångets": "lagfången",
    "lagfångna": "lagfången",
    "lagfångnare": "lagfången",
    "lagfångnares": "lagfången",
    "lagfångnas": "lagfången",
    "lagfångnast": "lagfången",
    "lagfångnaste": "lagfången",
    "lagfångnastes": "lagfången",
    "lagfångnasts": "lagfången",
    "lagfångne": "lagfången",
    "lagfångnes": "lagfången",
    "lagför": "lagföra",
    "lagförande": "lagföra",
    "lagföranden": "lagförande",
    "lagförandena": "lagförande",
    "lagförandenas": "lagförande",
    "lagförandens": "lagförande",
    "lagförandes": "lagförande",
    "lagförandet": "lagförande",
    "lagförandets": "lagförande",
    "lagföras": "lagföra",
    "lagförd": "lagföra",
    "lagförda": "lagföra",
    "lagfördas": "lagföra",
    "lagförde": "lagföra",
    "lagfördes": "lagföra",
    "lagförds": "lagföra",
    "lagföres": "lagföra",
    "lagförs": "lagföra",
    "lagförslagen": "lagförslag",
    "lagförslagens": "lagförslag",
    "lagförslaget": "lagförslag",
    "lagförslagets": "lagförslag",
    "lagförslags": "lagförslag",
    "lagfört": "lagföra",
    "lagförts": "lagföra",
    "lagg": "lagga",
    "laggad": "lagga",
    "laggade": "lagga",
    "laggades": "lagga",
    "laggads": "lagga",
    "laggande": "lagga",
    "lagganden": "laggande",
    "laggandena": "laggande",
    "laggandenas": "laggande",
    "laggandens": "laggande",
    "laggandes": "laggande",
    "laggandet": "laggande",
    "laggandets": "laggande",
    "laggar": "lagga",
    "laggarna": "lagg",
    "laggarnas": "lagg",
    "laggars": "lagg",
    "laggas": "lagga",
    "laggat": "lagga",
    "laggats": "lagga",
    "laggbanden": "laggband",
    "laggbandens": "laggband",
    "laggbandet": "laggband",
    "laggbandets": "laggband",
    "laggbands": "laggband",
    "laggdiken": "laggdike",
    "laggdikena": "laggdike",
    "laggdikenas": "laggdike",
    "laggdikens": "laggdike",
    "laggdikes": "laggdike",
    "laggdiket": "laggdike",
    "laggdikets": "laggdike",
    "laggen": "lagg",
    "laggens": "lagg",
    "laggkärlen": "laggkärl",
    "laggkärlens": "laggkärl",
    "laggkärlet": "laggkärl",
    "laggkärlets": "laggkärl",
    "laggkärls": "laggkärl",
    "laggs": "lagg",
    "lagiska": "lagisk",
    "lagiskare": "lagisk",
    "lagiskares": "lagisk",
    "lagiskas": "lagisk",
    "lagiskast": "lagisk",
    "lagiskaste": "lagisk",
    "lagiskastes": "lagisk",
    "lagiskasts": "lagisk",
    "lagiske": "lagisk",
    "lagiskes": "lagisk",
    "lagisks": "lagisk",
    "lagiskt": "lagisk",
    "lagiskts": "lagisk",
    "lagkamraten": "lagkamrat",
    "lagkamratens": "lagkamrat",
    "lagkamrater": "lagkamrat",
    "lagkamraterna": "lagkamrat",
    "lagkamraternas": "lagkamrat",
    "lagkamraters": "lagkamrat",
    "lagkamrats": "lagkamrat",
    "lagkappen": "lagkapp",
    "lagkappens": "lagkapp",
    "lagkapper": "lagkapp",
    "lagkapperna": "lagkapp",
    "lagkappernas": "lagkapp",
    "lagkappers": "lagkapp",
    "lagkapps": "lagkapp",
    "lagkappsimningar": "lagkappsimning",
    "lagkappsimningarna": "lagkappsimning",
    "lagkappsimningarnas": "lagkappsimning",
    "lagkappsimningars": "lagkappsimning",
    "lagkappsimningen": "lagkappsimning",
    "lagkappsimningens": "lagkappsimning",
    "lagkappsimnings": "lagkappsimning",
    "lagkaptenen": "lagkapten",
    "lagkaptenens": "lagkapten",
    "lagkaptener": "lagkapten",
    "lagkaptenerna": "lagkapten",
    "lagkaptenernas": "lagkapten",
    "lagkapteners": "lagkapten",
    "lagkaptens": "lagkapten",
    "lagkarlar": "lagkarl",
    "lagkarlarna": "lagkarl",
    "lagkarlarnas": "lagkarl",
    "lagkarlars": "lagkarl",
    "lagkarlen": "lagkarl",
    "lagkarlens": "lagkarl",
    "lagkarls": "lagkarl",
    "lagkloka": "lagklok",
    "lagklokare": "lagklok",
    "lagklokares": "lagklok",
    "lagklokas": "lagklok",
    "lagklokast": "lagklok",
    "lagklokaste": "lagklok",
    "lagklokastes": "lagklok",
    "lagklokasts": "lagklok",
    "lagkloke": "lagklok",
    "lagklokes": "lagklok",
    "lagklokheten": "lagklokhet",
    "lagklokhetens": "lagklokhet",
    "lagklokhets": "lagklokhet",
    "lagkloks": "lagklok",
    "lagklokt": "lagklok",
    "lagklokts": "lagklok",
    "lagledar": "lagledare",
    "lagledaren": "lagledare",
    "lagledarens": "lagledare",
    "lagledares": "lagledare",
    "lagledarna": "lagledare",
    "lagledarnas": "lagledare",
    "lagliga": "laglig",
    "lagligare": "laglig",
    "lagligares": "laglig",
    "lagligas": "laglig",
    "lagligast": "laglig",
    "lagligaste": "laglig",
    "lagligastes": "laglig",
    "lagligasts": "laglig",
    "laglige": "laglig",
    "lagliges": "laglig",
    "lagligheten": "laglighet",
    "laglighetens": "laglighet",
    "lagligheter": "laglighet",
    "lagligheterna": "laglighet",
    "lagligheternas": "laglighet",
    "lagligheters": "laglighet",
    "laglighets": "laglighet",
    "lagligs": "laglig",
    "lagligt": "laglig",
    "lagligts": "laglig",
    "laglotten": "laglott",
    "laglottens": "laglott",
    "laglotter": "laglott",
    "laglotterna": "laglott",
    "laglotternas": "laglott",
    "laglotters": "laglott",
    "laglotts": "laglott",
    "laglydiga": "laglydig",
    "laglydigare": "laglydig",
    "laglydigares": "laglydig",
    "laglydigas": "laglydig",
    "laglydigast": "laglydig",
    "laglydigaste": "laglydig",
    "laglydigastes": "laglydig",
    "laglydigasts": "laglydig",
    "laglydige": "laglydig",
    "laglydiges": "laglydig",
    "laglydigheten": "laglydighet",
    "laglydighetens": "laglydighet",
    "laglydighets": "laglydighet",
    "laglydigs": "laglydig",
    "laglydigt": "laglydig",
    "laglydigts": "laglydig",
    "laglösa": "laglös",
    "laglösare": "laglös",
    "laglösares": "laglös",
    "laglösas": "laglös",
    "laglösast": "laglös",
    "laglösaste": "laglös",
    "laglösastes": "laglös",
    "laglösasts": "laglös",
    "laglöse": "laglös",
    "laglöses": "laglös",
    "laglösheten": "laglöshet",
    "laglöshetens": "laglöshet",
    "laglösheter": "laglöshet",
    "laglösheterna": "laglöshet",
    "laglösheternas": "laglöshet",
    "laglösheters": "laglöshet",
    "laglöshets": "laglöshet",
    "laglöst": "laglös",
    "laglösts": "laglös",
    "lagmannen": "lagman",
    "lagmannens": "lagman",
    "lagmans": "lagman",
    "lagmän": "lagman",
    "lagmännen": "lagman",
    "lagmännens": "lagman",
    "lagmäns": "lagman",
    "lagmässiga": "lagmässig",
    "lagmässigare": "lagmässig",
    "lagmässigares": "lagmässig",
    "lagmässigas": "lagmässig",
    "lagmässigast": "lagmässig",
    "lagmässigaste": "lagmässig",
    "lagmässigastes": "lagmässig",
    "lagmässigasts": "lagmässig",
    "lagmässige": "lagmässig",
    "lagmässiges": "lagmässig",
    "lagmässigs": "lagmässig",
    "lagmässigt": "lagmässig",
    "lagmässigts": "lagmässig",
    "lagnen": "lagn",
    "lagnens": "lagn",
    "lagnet": "lagn",
    "lagnets": "lagn",
    "lagningar": "lagning",
    "lagningarna": "lagning",
    "lagningarnas": "lagning",
    "lagningars": "lagning",
    "lagningen": "lagning",
    "lagningens": "lagning",
    "lagnings": "lagning",
    "lagns": "lagn",
    "lagoma": "lagom",
    "lagomare": "lagom",
    "lagomares": "lagom",
    "lagomas": "lagom",
    "lagomast": "lagom",
    "lagomaste": "lagom",
    "lagomastes": "lagom",
    "lagomasts": "lagom",
    "lagome": "lagom",
    "lagomes": "lagom",
    "lagomheten": "lagomhet",
    "lagomhetens": "lagomhet",
    "lagomhets": "lagomhet",
    "lagomhetssträvans": "lagomhetssträvan",
    "lagoms": "lagom",
    "lagomt": "lagom",
    "lagomts": "lagom",
    "lagrad": "lagra",
    "lagrade": "lagra",
    "lagrades": "lagra",
    "lagrads": "lagra",
    "lagrande": "lagra",
    "lagranden": "lagrande",
    "lagrandena": "lagrande",
    "lagrandenas": "lagrande",
    "lagrandens": "lagrande",
    "lagrandes": "lagrande",
    "lagrandet": "lagrande",
    "lagrandets": "lagrande",
    "lagrar": "lagra",
    "lagrarna": "lager",
    "lagrarnas": "lager",
    "lagrars": "lager",
    "lagras": "lagra",
    "lagrat": "lagra",
    "lagrats": "lagra",
    "lagren": "lager",
    "lagrens": "lager",
    "lagret": "lager",
    "lagrets": "lager",
    "lagringar": "lagring",
    "lagringarna": "lagring",
    "lagringarnas": "lagring",
    "lagringars": "lagring",
    "lagringen": "lagring",
    "lagringens": "lagring",
    "lagrings": "lagring",
    "lagringsförlusten": "lagringsförlust",
    "lagringsförlustens": "lagringsförlust",
    "lagringsförluster": "lagringsförlust",
    "lagringsförlusterna": "lagringsförlust",
    "lagringsförlusternas": "lagringsförlust",
    "lagringsförlusters": "lagringsförlust",
    "lagringsförlusts": "lagringsförlust",
    "lagringskostnaden": "lagringskostnad",
    "lagringskostnadens": "lagringskostnad",
    "lagringskostnader": "lagringskostnad",
    "lagringskostnaderna": "lagringskostnad",
    "lagringskostnadernas": "lagringskostnad",
    "lagringskostnaders": "lagringskostnad",
    "lagringskostnads": "lagringskostnad",
    "lagrummen": "lagrum",
    "lagrummens": "lagrum",
    "lagrummet": "lagrum",
    "lagrummets": "lagrum",
    "lagrums": "lagrum",
    "lagråden": "lagråd",
    "lagrådens": "lagråd",
    "lagrådet": "lagråd",
    "lagrådets": "lagråd",
    "lagråds": "lagråd",
    "lags": "lag",
    "lagsagan": "lagsaga",
    "lagsagans": "lagsaga",
    "lagsagas": "lagsaga",
    "lagsage": "lagsaga",
    "lagsago": "lagsaga",
    "lagsagor": "lagsaga",
    "lagsagorna": "lagsaga",
    "lagsagornas": "lagsaga",
    "lagsagors": "lagsaga",
    "lagskipningar": "lagskipning",
    "lagskipningarna": "lagskipning",
    "lagskipningarnas": "lagskipning",
    "lagskipningars": "lagskipning",
    "lagskipningen": "lagskipning",
    "lagskipningens": "lagskipning",
    "lagskipnings": "lagskipning",
    "lagspelen": "lagspel",
    "lagspelens": "lagspel",
    "lagspelet": "lagspel",
    "lagspelets": "lagspel",
    "lagspels": "lagspel",
    "lagspråken": "lagspråk",
    "lagspråkens": "lagspråk",
    "lagspråket": "lagspråk",
    "lagspråkets": "lagspråk",
    "lagspråks": "lagspråk",
    "lagstadgade": "lagstadgad",
    "lagstadgades": "lagstadgad",
    "lagstadgads": "lagstadgad",
    "lagstadgande": "lagstadga",
    "lagstadgandes": "lagstadga",
    "lagstadgar": "lagstadga",
    "lagstadgas": "lagstadga",
    "lagstadgat": "lagstadgad",
    "lagstadgats": "lagstadgad",
    "lagstift": "lagstifta",
    "lagstiftad": "lagstifta",
    "lagstiftade": "lagstifta",
    "lagstiftades": "lagstifta",
    "lagstiftads": "lagstifta",
    "lagstiftande": "lagstifta",
    "lagstiftanden": "lagstiftande",
    "lagstiftandena": "lagstiftande",
    "lagstiftandenas": "lagstiftande",
    "lagstiftandens": "lagstiftande",
    "lagstiftandes": "lagstiftande",
    "lagstiftandet": "lagstiftande",
    "lagstiftandets": "lagstiftande",
    "lagstiftar": "lagstiftare",
    "lagstiftaren": "lagstiftare",
    "lagstiftarens": "lagstiftare",
    "lagstiftares": "lagstiftare",
    "lagstiftarna": "lagstiftare",
    "lagstiftarnas": "lagstiftare",
    "lagstiftas": "lagstifta",
    "lagstiftat": "lagstifta",
    "lagstiftats": "lagstifta",
    "lagstiftningar": "lagstiftning",
    "lagstiftningarna": "lagstiftning",
    "lagstiftningarnas": "lagstiftning",
    "lagstiftningars": "lagstiftning",
    "lagstiftningen": "lagstiftning",
    "lagstiftningens": "lagstiftning",
    "lagstiftnings": "lagstiftning",
    "lagstiftningsmässiga": "lagstiftningsmässig",
    "lagstiftningsmässigare": "lagstiftningsmässig",
    "lagstiftningsmässigares": "lagstiftningsmässig",
    "lagstiftningsmässigas": "lagstiftningsmässig",
    "lagstiftningsmässigast": "lagstiftningsmässig",
    "lagstiftningsmässigaste": "lagstiftningsmässig",
    "lagstiftningsmässigastes": "lagstiftningsmässig",
    "lagstiftningsmässigasts": "lagstiftningsmässig",
    "lagstiftningsmässige": "lagstiftningsmässig",
    "lagstiftningsmässiges": "lagstiftningsmässig",
    "lagstiftningsmässigs": "lagstiftningsmässig",
    "lagstiftningsmässigt": "lagstiftningsmässig",
    "lagstiftningsmässigts": "lagstiftningsmässig",
    "lagstridiga": "lagstridig",
    "lagstridigare": "lagstridig",
    "lagstridigares": "lagstridig",
    "lagstridigas": "lagstridig",
    "lagstridigast": "lagstridig",
    "lagstridigaste": "lagstridig",
    "lagstridigastes": "lagstridig",
    "lagstridigasts": "lagstridig",
    "lagstridige": "lagstridig",
    "lagstridiges": "lagstridig",
    "lagstridigheten": "lagstridighet",
    "lagstridighetens": "lagstridighet",
    "lagstridighets": "lagstridighet",
    "lagstridigs": "lagstridig",
    "lagstridigt": "lagstridig",
    "lagstridigts": "lagstridig",
    "lagsök": "lagsöka",
    "lagsökande": "lagsöka",
    "lagsökanden": "lagsökande",
    "lagsökandena": "lagsökande",
    "lagsökandenas": "lagsökande",
    "lagsökandens": "lagsökande",
    "lagsökandes": "lagsökande",
    "lagsökandet": "lagsökande",
    "lagsökandets": "lagsökande",
    "lagsökas": "lagsöka",
    "lagsöker": "lagsöka",
    "lagsökes": "lagsöka",
    "lagsöks": "lagsöka",
    "lagsökt": "lagsöka",
    "lagsökta": "lagsöka",
    "lagsöktas": "lagsöka",
    "lagsökte": "lagsöka",
    "lagsöktes": "lagsöka",
    "lagsökts": "lagsöka",
    "lagt": "lägga",
    "lagtempoloppen": "lagtempolopp",
    "lagtempoloppens": "lagtempolopp",
    "lagtempoloppet": "lagtempolopp",
    "lagtempoloppets": "lagtempolopp",
    "lagtempolopps": "lagtempolopp",
    "lagtempon": "lagtempo",
    "lagtempona": "lagtempo",
    "lagtemponas": "lagtempo",
    "lagtempons": "lagtempo",
    "lagtempos": "lagtempo",
    "lagtempot": "lagtempo",
    "lagtempots": "lagtempo",
    "lagtexten": "lagtext",
    "lagtextens": "lagtext",
    "lagtexter": "lagtext",
    "lagtexterna": "lagtext",
    "lagtexternas": "lagtext",
    "lagtexters": "lagtext",
    "lagtexts": "lagtext",
    "lagts": "lägga",
    "lagunen": "lagun",
    "lagunens": "lagun",
    "laguner": "lagun",
    "lagunerna": "lagun",
    "lagunernas": "lagun",
    "laguners": "lagun",
    "laguns": "lagun",
    "lagunsjöar": "lagunsjö",
    "lagunsjöarna": "lagunsjö",
    "lagunsjöarnas": "lagunsjö",
    "lagunsjöars": "lagunsjö",
    "lagunsjön": "lagunsjö",
    "lagunsjöns": "lagunsjö",
    "lagunsjös": "lagunsjö",
    "laguppställningar": "laguppställning",
    "laguppställningarna": "laguppställning",
    "laguppställningarnas": "laguppställning",
    "laguppställningars": "laguppställning",
    "laguppställningen": "laguppställning",
    "laguppställningens": "laguppställning",
    "laguppställnings": "laguppställning",
    "lagutskotten": "lagutskott",
    "lagutskottens": "lagutskott",
    "lagutskottet": "lagutskott",
    "lagutskottets": "lagutskott",
    "lagutskotts": "lagutskott",
    "lagvigda": "lagvigd",
    "lagvigdare": "lagvigd",
    "lagvigdares": "lagvigd",
    "lagvigdas": "lagvigd",
    "lagvigdast": "lagvigd",
    "lagvigdaste": "lagvigd",
    "lagvigdastes": "lagvigd",
    "lagvigdasts": "lagvigd",
    "lagvigde": "lagvigd",
    "lagvigdes": "lagvigd",
    "lagvigds": "lagvigd",
    "lagvigt": "lagvigd",
    "lagvigts": "lagvigd",
    "lagvrängar": "lagvrängare",
    "lagvrängaren": "lagvrängare",
    "lagvrängarens": "lagvrängare",
    "lagvrängares": "lagvrängare",
    "lagvrängarna": "lagvrängare",
    "lagvrängarnas": "lagvrängare",
    "lagvunna": "lagvunnen",
    "lagvunnare": "lagvunnen",
    "lagvunnares": "lagvunnen",
    "lagvunnas": "lagvunnen",
    "lagvunnast": "lagvunnen",
    "lagvunnaste": "lagvunnen",
    "lagvunnastes": "lagvunnen",
    "lagvunnasts": "lagvunnen",
    "lagvunne": "lagvunnen",
    "lagvunnens": "lagvunnen",
    "lagvunnes": "lagvunnen",
    "lagvunnet": "lagvunnen",
    "lagvunnets": "lagvunnen",
    "lagändringar": "lagändring",
    "lagändringarna": "lagändring",
    "lagändringarnas": "lagändring",
    "lagändringars": "lagändring",
    "lagändringen": "lagändring",
    "lagändringens": "lagändring",
    "lagändrings": "lagändring",
    "lagårdar": "lagård",
    "lagårdarna": "lagård",
    "lagårdarnas": "lagård",
    "lagårdars": "lagård",
    "lagården": "lagård",
    "lagårdens": "lagård",
    "lagårds": "lagård",
    "laissez-faires": "laissez-faire",
    "lak": "lake",
    "lakanen": "lakan",
    "lakanens": "lakan",
    "lakanet": "lakan",
    "lakanets": "lakan",
    "lakans": "lakan",
    "lakanspås": "lakanspåse",
    "lakanspåsar": "lakanspåse",
    "lakanspåsarna": "lakanspåse",
    "lakanspåsarnas": "lakanspåse",
    "lakanspåsars": "lakanspåse",
    "lakanspåsen": "lakanspåse",
    "lakanspåsens": "lakanspåse",
    "lakanspåses": "lakanspåse",
    "lakansrems": "lakansremsa",
    "lakansremsan": "lakansremsa",
    "lakansremsans": "lakansremsa",
    "lakansremsas": "lakansremsa",
    "lakansremse": "lakansremsa",
    "lakansremsor": "lakansremsa",
    "lakansremsorna": "lakansremsa",
    "lakansremsornas": "lakansremsa",
    "lakansremsors": "lakansremsa",
    "lakansspetsar": "lakansspets",
    "lakansspetsarna": "lakansspets",
    "lakansspetsarnas": "lakansspets",
    "lakansspetsars": "lakansspets",
    "lakansspetsen": "lakansspets",
    "lakansspetsens": "lakansspets",
    "lakar": "lake",
    "lakarna": "lake",
    "lakarnas": "lake",
    "lakars": "lake",
    "lakejen": "lakej",
    "lakejens": "lakej",
    "lakejer": "lakej",
    "lakejerna": "lakej",
    "lakejernas": "lakej",
    "lakejers": "lakej",
    "lakejs": "lakej",
    "laken": "lake",
    "lakens": "lake",
    "lakes": "lake",
    "lakkan": "lakka",
    "lakkans": "lakka",
    "lakkas": "lakka",
    "lakoniska": "lakonisk",
    "lakoniskare": "lakonisk",
    "lakoniskares": "lakonisk",
    "lakoniskas": "lakonisk",
    "lakoniskast": "lakonisk",
    "lakoniskaste": "lakonisk",
    "lakoniskastes": "lakonisk",
    "lakoniskasts": "lakonisk",
    "lakoniske": "lakonisk",
    "lakoniskes": "lakonisk",
    "lakonisks": "lakonisk",
    "lakoniskt": "lakonisk",
    "lakoniskts": "lakonisk",
    "lakonismen": "lakonism",
    "lakonismens": "lakonism",
    "lakonismer": "lakonism",
    "lakonismerna": "lakonism",
    "lakonismernas": "lakonism",
    "lakonismers": "lakonism",
    "lakonisms": "lakonism",
    "lakritsen": "lakrits",
    "lakritsens": "lakrits",
    "lakritsroten": "lakritsrot",
    "lakritsrotens": "lakritsrot",
    "lakritsrots": "lakritsrot",
    "lakritsrötter": "lakritsrot",
    "lakritsrötterna": "lakritsrot",
    "lakritsrötternas": "lakritsrot",
    "lakritsrötters": "lakritsrot",
    "laks": "lake",
    "laktalbuminen": "laktalbumin",
    "laktalbuminens": "laktalbumin",
    "laktalbuminer": "laktalbumin",
    "laktalbuminerna": "laktalbumin",
    "laktalbuminernas": "laktalbumin",
    "laktalbuminers": "laktalbumin",
    "laktalbuminet": "laktalbumin",
    "laktalbuminets": "laktalbumin",
    "laktalbumins": "laktalbumin",
    "laktationen": "laktation",
    "laktationens": "laktation",
    "laktationer": "laktation",
    "laktationerna": "laktation",
    "laktationernas": "laktation",
    "laktationers": "laktation",
    "laktations": "laktation",
    "laktosen": "laktos",
    "laktosens": "laktos",
    "laktosfria": "laktosfri",
    "laktosfriare": "laktosfri",
    "laktosfriares": "laktosfri",
    "laktosfrias": "laktosfri",
    "laktosfriast": "laktosfri",
    "laktosfriaste": "laktosfri",
    "laktosfriastes": "laktosfri",
    "laktosfriasts": "laktosfri",
    "laktosfrie": "laktosfri",
    "laktosfries": "laktosfri",
    "laktosfris": "laktosfri",
    "laktosfritt": "laktosfri",
    "laktosfritts": "laktosfri",
    "laktosintoleransen": "laktosintolerans",
    "laktosintoleransens": "laktosintolerans",
    "laktosintoleranta": "laktosintolerant",
    "laktosintolerantare": "laktosintolerant",
    "laktosintolerantares": "laktosintolerant",
    "laktosintolerantas": "laktosintolerant",
    "laktosintolerantast": "laktosintolerant",
    "laktosintolerantaste": "laktosintolerant",
    "laktosintolerantastes": "laktosintolerant",
    "laktosintolerantasts": "laktosintolerant",
    "laktosintolerante": "laktosintolerant",
    "laktosintolerantes": "laktosintolerant",
    "laktosintolerants": "laktosintolerant",
    "laktovegetarianen": "laktovegetarian",
    "laktovegetarianens": "laktovegetarian",
    "laktovegetarianer": "laktovegetarian",
    "laktovegetarianerna": "laktovegetarian",
    "laktovegetarianernas": "laktovegetarian",
    "laktovegetarianers": "laktovegetarian",
    "laktovegetarians": "laktovegetarian",
    "lakunen": "lakun",
    "lakunens": "lakun",
    "lakuner": "lakun",
    "lakunerna": "lakun",
    "lakunernas": "lakun",
    "lakuners": "lakun",
    "lakuns": "lakun",
    "lall": "lalla",
    "lallade": "lalla",
    "lallades": "lalla",
    "lallande": "lalla",
    "lallanden": "lallande",
    "lallandena": "lallande",
    "lallandenas": "lallande",
    "lallandens": "lallande",
    "lallandes": "lallande",
    "lallandet": "lallande",
    "lallandets": "lallande",
    "lallar": "lalla",
    "lallas": "lalla",
    "lallat": "lalla",
    "lallats": "lalla",
    "lam": "lama",
    "lama": "lam",
    "lamadjuren": "lamadjur",
    "lamadjurens": "lamadjur",
    "lamadjuret": "lamadjur",
    "lamadjurets": "lamadjur",
    "lamadjurs": "lamadjur",
    "lamaer": "lama",
    "lamaerna": "lama",
    "lamaernas": "lama",
    "lamaers": "lama",
    "lamaismen": "lamaism",
    "lamaismens": "lamaism",
    "lamaismer": "lamaism",
    "lamaismerna": "lamaism",
    "lamaismernas": "lamaism",
    "lamaismers": "lamaism",
    "lamaisms": "lamaism",
    "lamaistiska": "lamaistisk",
    "lamaistiskas": "lamaistisk",
    "lamaistiske": "lamaistisk",
    "lamaistiskes": "lamaistisk",
    "lamaistisks": "lamaistisk",
    "lamaistiskt": "lamaistisk",
    "lamaistiskts": "lamaistisk",
    "laman": "lama",
    "lamans": "lama",
    "lamare": "lam",
    "lamares": "lam",
    "lamas": "lama",
    "lamast": "lam",
    "lamaste": "lam",
    "lamastes": "lam",
    "lamasts": "lam",
    "lamat": "lama",
    "lamats": "lama",
    "lambadan": "lambada",
    "lambadans": "lambada",
    "lambadas": "lambada",
    "lambdan": "lambda",
    "lambdana": "lambda",
    "lambdanas": "lambda",
    "lambdans": "lambda",
    "lambdas": "lambda",
    "lambdat": "lambda",
    "lambdats": "lambda",
    "lame": "lama",
    "lamellen": "lamell",
    "lamellens": "lamell",
    "lameller": "lamell",
    "lamellerna": "lamell",
    "lamellernas": "lamell",
    "lamellers": "lamell",
    "lamellhusen": "lamellhus",
    "lamellhusens": "lamellhus",
    "lamellhuset": "lamellhus",
    "lamellhusets": "lamellhus",
    "lamellkontakten": "lamellkontakt",
    "lamellkontaktens": "lamellkontakt",
    "lamellkontakter": "lamellkontakt",
    "lamellkontakterna": "lamellkontakt",
    "lamellkontakternas": "lamellkontakt",
    "lamellkontakters": "lamellkontakt",
    "lamellkontakts": "lamellkontakt",
    "lamellkopplingar": "lamellkoppling",
    "lamellkopplingarna": "lamellkoppling",
    "lamellkopplingarnas": "lamellkoppling",
    "lamellkopplingars": "lamellkoppling",
    "lamellkopplingen": "lamellkoppling",
    "lamellkopplingens": "lamellkoppling",
    "lamellkopplings": "lamellkoppling",
    "lamells": "lamell",
    "lamellträet": "lamellträ",
    "lamellträets": "lamellträ",
    "lamellträs": "lamellträ",
    "lamellträt": "lamellträ",
    "lamellträts": "lamellträ",
    "lamentationen": "lamentation",
    "lamentationens": "lamentation",
    "lamentationer": "lamentation",
    "lamentationerna": "lamentation",
    "lamentationernas": "lamentation",
    "lamentationers": "lamentation",
    "lamentations": "lamentation",
    "lamenterad": "lamentera",
    "lamenterade": "lamentera",
    "lamenterades": "lamentera",
    "lamenterads": "lamentera",
    "lamenterande": "lamentera",
    "lamenteranden": "lamenterande",
    "lamenterandena": "lamenterande",
    "lamenterandenas": "lamenterande",
    "lamenterandens": "lamenterande",
    "lamenterandes": "lamenterande",
    "lamenterandet": "lamenterande",
    "lamenterandets": "lamenterande",
    "lamenterar": "lamentera",
    "lamenteras": "lamentera",
    "lamenterat": "lamentera",
    "lamenterats": "lamentera",
    "lamenterbara": "lamenterbar",
    "lamenterbarare": "lamenterbar",
    "lamenterbarares": "lamenterbar",
    "lamenterbaras": "lamenterbar",
    "lamenterbarast": "lamenterbar",
    "lamenterbaraste": "lamenterbar",
    "lamenterbarastes": "lamenterbar",
    "lamenterbarasts": "lamenterbar",
    "lamenterbare": "lamenterbar",
    "lamenterbares": "lamenterbar",
    "lamenterbarheten": "lamenterbarhet",
    "lamenterbarhetens": "lamenterbarhet",
    "lamenterbarhets": "lamenterbarhet",
    "lamenterbars": "lamenterbar",
    "lamenterbart": "lamenterbar",
    "lamenterbarts": "lamenterbar",
    "lamenteringar": "lamentering",
    "lamenteringarna": "lamentering",
    "lamenteringarnas": "lamentering",
    "lamenteringars": "lamentering",
    "lamenteringen": "lamentering",
    "lamenteringens": "lamentering",
    "lamenterings": "lamentering",
    "lames": "lam",
    "lamheten": "lamhet",
    "lamhetens": "lamhet",
    "lamhets": "lamhet",
    "laminaten": "laminat",
    "laminatens": "laminat",
    "laminatet": "laminat",
    "laminatets": "laminat",
    "laminats": "laminat",
    "laminerad": "laminera",
    "laminerade": "laminera",
    "laminerades": "laminera",
    "laminerads": "laminera",
    "laminerande": "laminera",
    "lamineranden": "laminerande",
    "laminerandena": "laminerande",
    "laminerandenas": "laminerande",
    "laminerandens": "laminerande",
    "laminerandes": "laminerande",
    "laminerandet": "laminerande",
    "laminerandets": "laminerande",
    "laminerar": "laminera",
    "lamineras": "laminera",
    "laminerat": "laminera",
    "laminerats": "laminera",
    "laminerbara": "laminerbar",
    "laminerbarare": "laminerbar",
    "laminerbarares": "laminerbar",
    "laminerbaras": "laminerbar",
    "laminerbarast": "laminerbar",
    "laminerbaraste": "laminerbar",
    "laminerbarastes": "laminerbar",
    "laminerbarasts": "laminerbar",
    "laminerbare": "laminerbar",
    "laminerbares": "laminerbar",
    "laminerbarheten": "laminerbarhet",
    "laminerbarhetens": "laminerbarhet",
    "laminerbarhets": "laminerbarhet",
    "laminerbars": "laminerbar",
    "laminerbart": "laminerbar",
    "laminerbarts": "laminerbar",
    "lamineringar": "laminering",
    "lamineringarna": "laminering",
    "lamineringarnas": "laminering",
    "lamineringars": "laminering",
    "lamineringen": "laminering",
    "lamineringens": "laminering",
    "laminerings": "laminering",
    "laminära": "laminär",
    "laminärare": "laminär",
    "laminärares": "laminär",
    "laminäras": "laminär",
    "laminärast": "laminär",
    "laminäraste": "laminär",
    "laminärastes": "laminär",
    "laminärasts": "laminär",
    "laminäre": "laminär",
    "laminäres": "laminär",
    "laminärs": "laminär",
    "laminärt": "laminär",
    "laminärts": "laminär",
    "lammade": "lamma",
    "lammades": "lamma",
    "lammande": "lamma",
    "lammanden": "lammande",
    "lammandena": "lammande",
    "lammandenas": "lammande",
    "lammandens": "lammande",
    "lammandes": "lammande",
    "lammandet": "lammande",
    "lammandets": "lammande",
    "lammar": "lamma",
    "lammas": "lamma",
    "lammat": "lamma",
    "lammats": "lamma",
    "lammen": "lamm",
    "lammens": "lamm",
    "lammet": "lamm",
    "lammets": "lamm",
    "lammköttet": "lammkött",
    "lammköttets": "lammkött",
    "lammkötts": "lammkött",
    "lamms": "lamm",
    "lammsadeln": "lammsadel",
    "lammsadelns": "lammsadel",
    "lammsadels": "lammsadel",
    "lammsadlar": "lammsadel",
    "lammsadlarna": "lammsadel",
    "lammsadlarnas": "lammsadel",
    "lammsadlars": "lammsadel",
    "lammskinnen": "lammskinn",
    "lammskinnens": "lammskinn",
    "lammskinnet": "lammskinn",
    "lammskinnets": "lammskinn",
    "lammskinns": "lammskinn",
    "lammungar": "lammunge",
    "lammungarna": "lammunge",
    "lammungarnas": "lammunge",
    "lammungars": "lammunge",
    "lammungen": "lammunge",
    "lammungens": "lammunge",
    "lammunges": "lammunge",
    "lamningar": "lamning",
    "lamningarna": "lamning",
    "lamningarnas": "lamning",
    "lamningars": "lamning",
    "lamningen": "lamning",
    "lamningens": "lamning",
    "lamnings": "lamning",
    "lamor": "lama",
    "lamorna": "lama",
    "lamornas": "lama",
    "lamors": "lama",
    "lamp": "lampa",
    "lampan": "lampa",
    "lampans": "lampa",
    "lampas": "lampa",
    "lampe": "lampa",
    "lampetten": "lampett",
    "lampettens": "lampett",
    "lampetter": "lampett",
    "lampetterna": "lampett",
    "lampetternas": "lampett",
    "lampetters": "lampett",
    "lampetts": "lampett",
    "lampfabriken": "lampfabrik",
    "lampfabrikens": "lampfabrik",
    "lampfabriker": "lampfabrik",
    "lampfabrikerna": "lampfabrik",
    "lampfabrikernas": "lampfabrik",
    "lampfabrikers": "lampfabrik",
    "lampfabriks": "lampfabrik",
    "lampfoten": "lampfot",
    "lampfotens": "lampfot",
    "lampfots": "lampfot",
    "lampfötter": "lampfot",
    "lampfötterna": "lampfot",
    "lampfötternas": "lampfot",
    "lampfötters": "lampfot",
    "lamphållar": "lamphållare",
    "lamphållaren": "lamphållare",
    "lamphållarens": "lamphållare",
    "lamphållares": "lamphållare",
    "lamphållarna": "lamphållare",
    "lamphållarnas": "lamphållare",
    "lampkup": "lampkupa",
    "lampkupan": "lampkupa",
    "lampkupans": "lampkupa",
    "lampkupas": "lampkupa",
    "lampkupe": "lampkupa",
    "lampkupor": "lampkupa",
    "lampkuporna": "lampkupa",
    "lampkupornas": "lampkupa",
    "lampkupors": "lampkupa",
    "lampkups": "lampkupa",
    "lampoljan": "lampolja",
    "lampoljans": "lampolja",
    "lampoljas": "lampolja",
    "lampolje": "lampolja",
    "lampor": "lampa",
    "lamporna": "lampa",
    "lampornas": "lampa",
    "lampors": "lampa",
    "lamps": "lampa",
    "lampskenen": "lampsken",
    "lampskenens": "lampsken",
    "lampskenet": "lampsken",
    "lampskenets": "lampsken",
    "lampskens": "lampsken",
    "lampskärmar": "lampskärm",
    "lampskärmarna": "lampskärm",
    "lampskärmarnas": "lampskärm",
    "lampskärmars": "lampskärm",
    "lampskärmen": "lampskärm",
    "lampskärmens": "lampskärm",
    "lampskärms": "lampskärm",
    "lampsvarts": "lampsvart",
    "lams": "lama",
    "lamslagen": "lamslå",
    "lamslagens": "lamslå",
    "lamslaget": "lamslå",
    "lamslagets": "lamslå",
    "lamslagit": "lamslå",
    "lamslagits": "lamslå",
    "lamslagna": "lamslå",
    "lamslagnas": "lamslå",
    "lamslagne": "lamslå",
    "lamslagnes": "lamslå",
    "lamslog": "lamslå",
    "lamsloge": "lamslå",
    "lamsloges": "lamslå",
    "lamslogs": "lamslå",
    "lamslående": "lamslå",
    "lamslåenden": "lamslående",
    "lamslåendena": "lamslående",
    "lamslåendenas": "lamslående",
    "lamslåendens": "lamslående",
    "lamslåendes": "lamslående",
    "lamslåendet": "lamslående",
    "lamslåendets": "lamslående",
    "lamslår": "lamslå",
    "lamslås": "lamslå",
    "lamt": "lam",
    "lamts": "lam",
    "laméer": "lamé",
    "laméerna": "lamé",
    "laméernas": "lamé",
    "laméers": "lamé",
    "lamén": "lamé",
    "laméns": "lamé",
    "lamés": "lamé",
    "lan": "lana",
    "lanan": "lana",
    "lanans": "lana",
    "lanas": "lana",
    "land": "landa",
    "landad": "landa",
    "landade": "landa",
    "landades": "landa",
    "landads": "landa",
    "landamären": "landamäre",
    "landamärena": "landamäre",
    "landamärenas": "landamäre",
    "landamärens": "landamäre",
    "landamäres": "landamäre",
    "landamäret": "landamäre",
    "landamärets": "landamäre",
    "landande": "landa",
    "landanden": "landande",
    "landandena": "landande",
    "landandenas": "landande",
    "landandens": "landande",
    "landandes": "landande",
    "landandet": "landande",
    "landandets": "landande",
    "landar": "landa",
    "landas": "landa",
    "landat": "landa",
    "landats": "landa",
    "landbon": "landbo",
    "landbons": "landbo",
    "landbor": "landbo",
    "landborgar": "landborg",
    "landborgarna": "landborg",
    "landborgarnas": "landborg",
    "landborgars": "landborg",
    "landborgen": "landborg",
    "landborgens": "landborg",
    "landborgs": "landborg",
    "landborna": "landbo",
    "landbornas": "landbo",
    "landbors": "landbo",
    "landbos": "landbo",
    "landbrisar": "landbris",
    "landbrisarna": "landbris",
    "landbrisarnas": "landbris",
    "landbrisars": "landbris",
    "landbrisen": "landbris",
    "landbrisens": "landbris",
    "landbriser": "landbris",
    "landbriserna": "landbris",
    "landbrisernas": "landbris",
    "landbrisers": "landbris",
    "landbrygg": "landbrygga",
    "landbryggan": "landbrygga",
    "landbryggans": "landbrygga",
    "landbryggas": "landbrygga",
    "landbrygge": "landbrygga",
    "landbryggor": "landbrygga",
    "landbryggorna": "landbrygga",
    "landbryggornas": "landbrygga",
    "landbryggors": "landbrygga",
    "landbryggs": "landbrygga",
    "landdrivens": "landdriven",
    "landdrivet": "landdriven",
    "landdrivets": "landdriven",
    "landdrivna": "landdriven",
    "landdrivnare": "landdriven",
    "landdrivnares": "landdriven",
    "landdrivnas": "landdriven",
    "landdrivnast": "landdriven",
    "landdrivnaste": "landdriven",
    "landdrivnastes": "landdriven",
    "landdrivnasts": "landdriven",
    "landdrivne": "landdriven",
    "landdrivnes": "landdriven",
    "landen": "land",
    "landens": "land",
    "landet": "land",
    "landets": "land",
    "landfäst": "landfäste",
    "landfästen": "landfäste",
    "landfästena": "landfäste",
    "landfästenas": "landfäste",
    "landfästens": "landfäste",
    "landfästes": "landfäste",
    "landfästet": "landfäste",
    "landfästets": "landfäste",
    "landgångar": "landgång",
    "landgångarna": "landgång",
    "landgångarnas": "landgång",
    "landgångars": "landgång",
    "landgången": "landgång",
    "landgångens": "landgång",
    "landgångs": "landgång",
    "landhockeyn": "landhockey",
    "landhockeyns": "landhockey",
    "landhockeys": "landhockey",
    "landhöjningar": "landhöjning",
    "landhöjningarna": "landhöjning",
    "landhöjningarnas": "landhöjning",
    "landhöjningars": "landhöjning",
    "landhöjningen": "landhöjning",
    "landhöjningens": "landhöjning",
    "landhöjnings": "landhöjning",
    "landisar": "landis",
    "landisarna": "landis",
    "landisarnas": "landis",
    "landisars": "landis",
    "landisen": "landis",
    "landisens": "landis",
    "landkrabb": "landkrabba",
    "landkrabban": "landkrabba",
    "landkrabbans": "landkrabba",
    "landkrabbas": "landkrabba",
    "landkrabbe": "landkrabba",
    "landkrabbor": "landkrabba",
    "landkrabborna": "landkrabba",
    "landkrabbornas": "landkrabba",
    "landkrabbors": "landkrabba",
    "landkrabbs": "landkrabba",
    "landkänningar": "landkänning",
    "landkänningarna": "landkänning",
    "landkänningarnas": "landkänning",
    "landkänningars": "landkänning",
    "landkänningen": "landkänning",
    "landkänningens": "landkänning",
    "landkännings": "landkänning",
    "landmassan": "landmassa",
    "landmassans": "landmassa",
    "landmassas": "landmassa",
    "landmasse": "landmassa",
    "landmassor": "landmassa",
    "landmassorna": "landmassa",
    "landmassornas": "landmassa",
    "landmassors": "landmassa",
    "landmin": "landmina",
    "landminan": "landmina",
    "landminans": "landmina",
    "landminas": "landmina",
    "landmine": "landmina",
    "landminor": "landmina",
    "landminorna": "landmina",
    "landminornas": "landmina",
    "landminors": "landmina",
    "landmins": "landmina",
    "landmärken": "landmärke",
    "landmärkena": "landmärke",
    "landmärkenas": "landmärke",
    "landmärkens": "landmärke",
    "landmärkes": "landmärke",
    "landmärket": "landmärke",
    "landmärkets": "landmärke",
    "landningar": "landning",
    "landningarna": "landning",
    "landningarnas": "landning",
    "landningars": "landning",
    "landningen": "landning",
    "landningens": "landning",
    "landnings": "landning",
    "landningsbanan": "landningsbana",
    "landningsbanans": "landningsbana",
    "landningsbanas": "landningsbana",
    "landningsbane": "landningsbana",
    "landningsbanor": "landningsbana",
    "landningsbanorna": "landningsbana",
    "landningsbanornas": "landningsbana",
    "landningsbanors": "landningsbana",
    "landningsfarkosten": "landningsfarkost",
    "landningsfarkostens": "landningsfarkost",
    "landningsfarkoster": "landningsfarkost",
    "landningsfarkosterna": "landningsfarkost",
    "landningsfarkosternas": "landningsfarkost",
    "landningsfarkosters": "landningsfarkost",
    "landningsfarkosts": "landningsfarkost",
    "landningsförbuden": "landningsförbud",
    "landningsförbudens": "landningsförbud",
    "landningsförbudet": "landningsförbud",
    "landningsförbudets": "landningsförbud",
    "landningsförbuds": "landningsförbud",
    "landningshjulen": "landningshjul",
    "landningshjulens": "landningshjul",
    "landningshjulet": "landningshjul",
    "landningshjulets": "landningshjul",
    "landningshjuls": "landningshjul",
    "landningsmärken": "landningsmärke",
    "landningsmärkena": "landningsmärke",
    "landningsmärkenas": "landningsmärke",
    "landningsmärkens": "landningsmärke",
    "landningsmärkes": "landningsmärke",
    "landningsmärket": "landningsmärke",
    "landningsmärkets": "landningsmärke",
    "landningsställen": "landningsställ",
    "landningsställens": "landningsställ",
    "landningsstället": "landningsställ",
    "landningsställets": "landningsställ",
    "landningsställs": "landningsställ",
    "landningszonen": "landningszon",
    "landningszonens": "landningszon",
    "landningszoner": "landningszon",
    "landningszonerna": "landningszon",
    "landningszonernas": "landningszon",
    "landningszoners": "landningszon",
    "landningszons": "landningszon",
    "landningsögonblicken": "landningsögonblick",
    "landningsögonblickens": "landningsögonblick",
    "landningsögonblicket": "landningsögonblick",
    "landningsögonblickets": "landningsögonblick",
    "landningsögonblicks": "landningsögonblick",
    "landnotar": "landnot",
    "landnotarna": "landnot",
    "landnotarnas": "landnot",
    "landnotars": "landnot",
    "landnoten": "landnot",
    "landnotens": "landnot",
    "landnots": "landnot",
    "landområden": "landområde",
    "landområdena": "landområde",
    "landområdenas": "landområde",
    "landområdens": "landområde",
    "landområdes": "landområde",
    "landområdet": "landområde",
    "landområdets": "landområde",
    "landpermissionen": "landpermission",
    "landpermissionens": "landpermission",
    "landpermissioner": "landpermission",
    "landpermissionerna": "landpermission",
    "landpermissionernas": "landpermission",
    "landpermissioners": "landpermission",
    "landpermissions": "landpermission",
    "landrems": "landremsa",
    "landremsan": "landremsa",
    "landremsans": "landremsa",
    "landremsas": "landremsa",
    "landremse": "landremsa",
    "landremsor": "landremsa",
    "landremsorna": "landremsa",
    "landremsornas": "landremsa",
    "landremsors": "landremsa",
    "landryggar": "landrygg",
    "landryggarna": "landrygg",
    "landryggarnas": "landrygg",
    "landryggars": "landrygg",
    "landryggen": "landrygg",
    "landryggens": "landrygg",
    "landryggs": "landrygg",
    "lands": "land",
    "landsantikvarien": "landsantikvarie",
    "landsantikvariens": "landsantikvarie",
    "landsantikvarier": "landsantikvarie",
    "landsantikvarierna": "landsantikvarie",
    "landsantikvariernas": "landsantikvarie",
    "landsantikvariers": "landsantikvarie",
    "landsantikvaries": "landsantikvarie",
    "landsarkivarien": "landsarkivarie",
    "landsarkivariens": "landsarkivarie",
    "landsarkivarier": "landsarkivarie",
    "landsarkivarierna": "landsarkivarie",
    "landsarkivariernas": "landsarkivarie",
    "landsarkivariers": "landsarkivarie",
    "landsarkivaries": "landsarkivarie",
    "landsarkiven": "landsarkiv",
    "landsarkivens": "landsarkiv",
    "landsarkivet": "landsarkiv",
    "landsarkivets": "landsarkiv",
    "landsarkivs": "landsarkiv",
    "landsatt": "landsätta",
    "landsatta": "landsätta",
    "landsattas": "landsätta",
    "landsatte": "landsätta",
    "landsattes": "landsätta",
    "landsatts": "landsätta",
    "landsbodd": "landsbo",
    "landsbodda": "landsbo",
    "landsboddas": "landsbo",
    "landsbodde": "landsbo",
    "landsboddes": "landsbo",
    "landsbodds": "landsbo",
    "landsboende": "landsbo",
    "landsboendes": "landsbo",
    "landsbor": "landsbo",
    "landsbos": "landsbo",
    "landsbott": "landsbo",
    "landsbotts": "landsbo",
    "landsbygden": "landsbygd",
    "landsbygdens": "landsbygd",
    "landsbygds": "landsbygd",
    "landsbygdsbefolkningar": "landsbygdsbefolkning",
    "landsbygdsbefolkningarna": "landsbygdsbefolkning",
    "landsbygdsbefolkningarnas": "landsbygdsbefolkning",
    "landsbygdsbefolkningars": "landsbygdsbefolkning",
    "landsbygdsbefolkningen": "landsbygdsbefolkning",
    "landsbygdsbefolkningens": "landsbygdsbefolkning",
    "landsbygdsbefolknings": "landsbygdsbefolkning",
    "landsdelar": "landsdel",
    "landsdelarna": "landsdel",
    "landsdelarnas": "landsdel",
    "landsdelars": "landsdel",
    "landsdelen": "landsdel",
    "landsdelens": "landsdel",
    "landsdels": "landsdel",
    "landsfadern": "landsfader",
    "landsfaderns": "landsfader",
    "landsfaders": "landsfader",
    "landsfiskalen": "landsfiskal",
    "landsfiskalens": "landsfiskal",
    "landsfiskaler": "landsfiskal",
    "landsfiskalerna": "landsfiskal",
    "landsfiskalernas": "landsfiskal",
    "landsfiskalers": "landsfiskal",
    "landsfiskals": "landsfiskal",
    "landsflykten": "landsflykt",
    "landsflyktens": "landsflykt",
    "landsflyktiga": "landsflyktig",
    "landsflyktigare": "landsflyktig",
    "landsflyktigares": "landsflyktig",
    "landsflyktigas": "landsflyktig",
    "landsflyktigast": "landsflyktig",
    "landsflyktigaste": "landsflyktig",
    "landsflyktigastes": "landsflyktig",
    "landsflyktigasts": "landsflyktig",
    "landsflyktige": "landsflyktig",
    "landsflyktiges": "landsflyktig",
    "landsflyktigs": "landsflyktig",
    "landsflyktigt": "landsflyktig",
    "landsflyktigts": "landsflyktig",
    "landsflykts": "landsflykt",
    "landsfogd": "landsfogde",
    "landsfogdar": "landsfogde",
    "landsfogdarna": "landsfogde",
    "landsfogdarnas": "landsfogde",
    "landsfogdars": "landsfogde",
    "landsfogden": "landsfogde",
    "landsfogdens": "landsfogde",
    "landsfogdes": "landsfogde",
    "landsfogds": "landsfogde",
    "landsfäder": "landsfader",
    "landsfäderna": "landsfader",
    "landsfädernas": "landsfader",
    "landsfäders": "landsfader",
    "landsförrädar": "landsförrädare",
    "landsförrädaren": "landsförrädare",
    "landsförrädarens": "landsförrädare",
    "landsförrädares": "landsförrädare",
    "landsförrädarna": "landsförrädare",
    "landsförrädarnas": "landsförrädare",
    "landsförräderier": "landsförräderi",
    "landsförräderierna": "landsförräderi",
    "landsförräderiernas": "landsförräderi",
    "landsförräderiers": "landsförräderi",
    "landsförräderiet": "landsförräderi",
    "landsförräderiets": "landsförräderi",
    "landsförräderis": "landsförräderi",
    "landsförräderit": "landsförräderi",
    "landsförräderits": "landsförräderi",
    "landsförvis": "landsförvisa",
    "landsförvisad": "landsförvisa",
    "landsförvisade": "landsförvisa",
    "landsförvisades": "landsförvisa",
    "landsförvisads": "landsförvisa",
    "landsförvisande": "landsförvisa",
    "landsförvisanden": "landsförvisande",
    "landsförvisandena": "landsförvisande",
    "landsförvisandenas": "landsförvisande",
    "landsförvisandens": "landsförvisande",
    "landsförvisandes": "landsförvisande",
    "landsförvisandet": "landsförvisande",
    "landsförvisandets": "landsförvisande",
    "landsförvisar": "landsförvisa",
    "landsförvisas": "landsförvisa",
    "landsförvisat": "landsförvisa",
    "landsförvisats": "landsförvisa",
    "landsförvisningar": "landsförvisning",
    "landsförvisningarna": "landsförvisning",
    "landsförvisningarnas": "landsförvisning",
    "landsförvisningars": "landsförvisning",
    "landsförvisningen": "landsförvisning",
    "landsförvisningens": "landsförvisning",
    "landsförvisnings": "landsförvisning",
    "landshövdingar": "landshövding",
    "landshövdingarna": "landshövding",
    "landshövdingarnas": "landshövding",
    "landshövdingars": "landshövding",
    "landshövdingehusen": "landshövdingehus",
    "landshövdingehusens": "landshövdingehus",
    "landshövdingehuset": "landshövdingehus",
    "landshövdingehusets": "landshövdingehus",
    "landshövdingen": "landshövding",
    "landshövdingens": "landshövding",
    "landshövdingeämbeten": "landshövdingeämbete",
    "landshövdingeämbetena": "landshövdingeämbete",
    "landshövdingeämbetenas": "landshövdingeämbete",
    "landshövdingeämbetens": "landshövdingeämbete",
    "landshövdingeämbetes": "landshövdingeämbete",
    "landshövdingeämbetet": "landshövdingeämbete",
    "landshövdingeämbetets": "landshövdingeämbete",
    "landshövdings": "landshövding",
    "landsidan": "landsida",
    "landsidans": "landsida",
    "landsidas": "landsida",
    "landside": "landsida",
    "landsides": "landsida",
    "landsidor": "landsida",
    "landsidorna": "landsida",
    "landsidornas": "landsida",
    "landsidors": "landsida",
    "landskampen": "landskamp",
    "landskampens": "landskamp",
    "landskamper": "landskamp",
    "landskamperna": "landskamp",
    "landskampernas": "landskamp",
    "landskampers": "landskamp",
    "landskamps": "landskamp",
    "landskanslier": "landskansli",
    "landskanslierna": "landskansli",
    "landskansliernas": "landskansli",
    "landskansliers": "landskansli",
    "landskansliet": "landskansli",
    "landskansliets": "landskansli",
    "landskanslis": "landskansli",
    "landskanslit": "landskansli",
    "landskanslits": "landskansli",
    "landskapen": "landskap",
    "landskapens": "landskap",
    "landskapet": "landskap",
    "landskapets": "landskap",
    "landskaps": "landskap",
    "landskapsblom": "landskapsblomma",
    "landskapsblomman": "landskapsblomma",
    "landskapsblommans": "landskapsblomma",
    "landskapsblommas": "landskapsblomma",
    "landskapsblomme": "landskapsblomma",
    "landskapsblommor": "landskapsblomma",
    "landskapsblommorna": "landskapsblomma",
    "landskapsblommornas": "landskapsblomma",
    "landskapsblommors": "landskapsblomma",
    "landskapsbloms": "landskapsblomma",
    "landskapslagar": "landskapslag",
    "landskapslagarna": "landskapslag",
    "landskapslagarnas": "landskapslag",
    "landskapslagars": "landskapslag",
    "landskapslagen": "landskapslag",
    "landskapslagens": "landskapslag",
    "landskapslags": "landskapslag",
    "landskapsmässiga": "landskapsmässig",
    "landskapsmässigare": "landskapsmässig",
    "landskapsmässigares": "landskapsmässig",
    "landskapsmässigas": "landskapsmässig",
    "landskapsmässigast": "landskapsmässig",
    "landskapsmässigaste": "landskapsmässig",
    "landskapsmässigastes": "landskapsmässig",
    "landskapsmässigasts": "landskapsmässig",
    "landskapsmässige": "landskapsmässig",
    "landskapsmässiges": "landskapsmässig",
    "landskapsmässigs": "landskapsmässig",
    "landskapsmässigt": "landskapsmässig",
    "landskapsmässigts": "landskapsmässig",
    "landskapsskildringar": "landskapsskildring",
    "landskapsskildringarna": "landskapsskildring",
    "landskapsskildringarnas": "landskapsskildring",
    "landskapsskildringars": "landskapsskildring",
    "landskapsskildringen": "landskapsskildring",
    "landskapsskildringens": "landskapsskildring",
    "landskapsskildrings": "landskapsskildring",
    "landskapsvapens": "landskapsvapen",
    "landskapsvapnen": "landskapsvapen",
    "landskapsvapnens": "landskapsvapen",
    "landskapsvapnet": "landskapsvapen",
    "landskapsvapnets": "landskapsvapen",
    "landsknektar": "landsknekt",
    "landsknektarna": "landsknekt",
    "landsknektarnas": "landsknekt",
    "landsknektars": "landsknekt",
    "landsknekten": "landsknekt",
    "landsknektens": "landsknekt",
    "landsknekts": "landsknekt",
    "landskommunen": "landskommun",
    "landskommunens": "landskommun",
    "landskommuner": "landskommun",
    "landskommunerna": "landskommun",
    "landskommunernas": "landskommun",
    "landskommuners": "landskommun",
    "landskommuns": "landskommun",
    "landslagar": "landslag",
    "landslagarna": "landslag",
    "landslagarnas": "landslag",
    "landslagars": "landslag",
    "landslagen": "landslag",
    "landslagens": "landslag",
    "landslaget": "landslag",
    "landslagets": "landslag",
    "landslags": "landslag",
    "landslagsmässiga": "landslagsmässig",
    "landslagsmässigare": "landslagsmässig",
    "landslagsmässigares": "landslagsmässig",
    "landslagsmässigas": "landslagsmässig",
    "landslagsmässigast": "landslagsmässig",
    "landslagsmässigaste": "landslagsmässig",
    "landslagsmässigastes": "landslagsmässig",
    "landslagsmässigasts": "landslagsmässig",
    "landslagsmässige": "landslagsmässig",
    "landslagsmässiges": "landslagsmässig",
    "landslagsmässigs": "landslagsmässig",
    "landslagsmässigt": "landslagsmässig",
    "landslagsmässigts": "landslagsmässig",
    "landslagsträningen": "landslagsträning",
    "landslagsträningens": "landslagsträning",
    "landslagstränings": "landslagsträning",
    "landsmaninnan": "landsmaninna",
    "landsmaninnans": "landsmaninna",
    "landsmaninnas": "landsmaninna",
    "landsmaninne": "landsmaninna",
    "landsmaninnor": "landsmaninna",
    "landsmaninnorna": "landsmaninna",
    "landsmaninnornas": "landsmaninna",
    "landsmaninnors": "landsmaninna",
    "landsmannen": "landsman",
    "landsmannens": "landsman",
    "landsmans": "landsman",
    "landsmän": "landsman",
    "landsmännen": "landsman",
    "landsmännens": "landsman",
    "landsmäns": "landsman",
    "landsmålen": "landsmål",
    "landsmålens": "landsmål",
    "landsmålet": "landsmål",
    "landsmålets": "landsmål",
    "landsmåls": "landsmål",
    "landsmålsalfabeten": "landsmålsalfabet",
    "landsmålsalfabetens": "landsmålsalfabet",
    "landsmålsalfabetet": "landsmålsalfabet",
    "landsmålsalfabetets": "landsmålsalfabet",
    "landsmålsalfabets": "landsmålsalfabet",
    "landsnummerna": "landsnummer",
    "landsnummernas": "landsnummer",
    "landsnummers": "landsnummer",
    "landsnumren": "landsnummer",
    "landsnumrens": "landsnummer",
    "landsnumret": "landsnummer",
    "landsnumrets": "landsnummer",
    "landsnäck": "landsnäcka",
    "landsnäckan": "landsnäcka",
    "landsnäckans": "landsnäcka",
    "landsnäckas": "landsnäcka",
    "landsnäcke": "landsnäcka",
    "landsnäckor": "landsnäcka",
    "landsnäckorna": "landsnäcka",
    "landsnäckornas": "landsnäcka",
    "landsnäckors": "landsnäcka",
    "landsnäcks": "landsnäcka",
    "landsorten": "landsort",
    "landsortens": "landsort",
    "landsorts": "landsort",
    "landsortsstaden": "landsortsstad",
    "landsortsstadens": "landsortsstad",
    "landsortsstads": "landsortsstad",
    "landsortsstan": "landsortsstad",
    "landsortsstans": "landsortsstad",
    "landsortsstäder": "landsortsstad",
    "landsortsstäderna": "landsortsstad",
    "landsortsstädernas": "landsortsstad",
    "landsortsstäders": "landsortsstad",
    "landsplågan": "landsplåga",
    "landsplågans": "landsplåga",
    "landsplågas": "landsplåga",
    "landsplåge": "landsplåga",
    "landsplågo": "landsplåga",
    "landsplågor": "landsplåga",
    "landsplågorna": "landsplåga",
    "landsplågornas": "landsplåga",
    "landsplågors": "landsplåga",
    "landsrätten": "landsrätt",
    "landsrättens": "landsrätt",
    "landsrätts": "landsrätt",
    "landssekretariaten": "landssekretariat",
    "landssekretariatens": "landssekretariat",
    "landssekretariatet": "landssekretariat",
    "landssekretariatets": "landssekretariat",
    "landssekretariats": "landssekretariat",
    "landssorgen": "landssorg",
    "landssorgens": "landssorg",
    "landssorgs": "landssorg",
    "landsteg": "landstiga",
    "landstegs": "landstiga",
    "landstig": "landstiga",
    "landstigande": "landstiga",
    "landstiganden": "landstigande",
    "landstigandena": "landstigande",
    "landstigandenas": "landstigande",
    "landstigandens": "landstigande",
    "landstigandes": "landstigande",
    "landstigandet": "landstigande",
    "landstigandets": "landstigande",
    "landstigas": "landstiga",
    "landstige": "landstiga",
    "landstigen": "landstiga",
    "landstigens": "landstiga",
    "landstiger": "landstiga",
    "landstiges": "landstiga",
    "landstiget": "landstiga",
    "landstigets": "landstiga",
    "landstigit": "landstiga",
    "landstigits": "landstiga",
    "landstigna": "landstiga",
    "landstignas": "landstiga",
    "landstigne": "landstiga",
    "landstignes": "landstiga",
    "landstigningar": "landstigning",
    "landstigningarna": "landstigning",
    "landstigningarnas": "landstigning",
    "landstigningars": "landstigning",
    "landstigningen": "landstigning",
    "landstigningens": "landstigning",
    "landstignings": "landstigning",
    "landstigningsbåtar": "landstigningsbåt",
    "landstigningsbåtarna": "landstigningsbåt",
    "landstigningsbåtarnas": "landstigningsbåt",
    "landstigningsbåtars": "landstigningsbåt",
    "landstigningsbåten": "landstigningsbåt",
    "landstigningsbåtens": "landstigningsbåt",
    "landstigningsbåts": "landstigningsbåt",
    "landstigs": "landstiga",
    "landstingen": "landsting",
    "landstingens": "landsting",
    "landstinget": "landsting",
    "landstingets": "landsting",
    "landstings": "landsting",
    "landstingsdirektören": "landstingsdirektör",
    "landstingsdirektörens": "landstingsdirektör",
    "landstingsdirektörer": "landstingsdirektör",
    "landstingsdirektörerna": "landstingsdirektör",
    "landstingsdirektörernas": "landstingsdirektör",
    "landstingsdirektörers": "landstingsdirektör",
    "landstingsdirektörn": "landstingsdirektör",
    "landstingsdirektörns": "landstingsdirektör",
    "landstingsdirektörs": "landstingsdirektör",
    "landstingsförbunden": "landstingsförbund",
    "landstingsförbundens": "landstingsförbund",
    "landstingsförbundet": "landstingsförbund",
    "landstingsförbundets": "landstingsförbund",
    "landstingsförbunds": "landstingsförbund",
    "landstingskatalogen": "landstingskatalog",
    "landstingskatalogens": "landstingskatalog",
    "landstingskataloger": "landstingskatalog",
    "landstingskatalogerna": "landstingskatalog",
    "landstingskatalogernas": "landstingskatalog",
    "landstingskatalogers": "landstingskatalog",
    "landstingskatalogs": "landstingskatalog",
    "landstingskommunen": "landstingskommun",
    "landstingskommunens": "landstingskommun",
    "landstingskommuner": "landstingskommun",
    "landstingskommunerna": "landstingskommun",
    "landstingskommunernas": "landstingskommun",
    "landstingskommuners": "landstingskommun",
    "landstingskommuns": "landstingskommun",
    "landstingsmannen": "landstingsman",
    "landstingsmannens": "landstingsman",
    "landstingsmans": "landstingsman",
    "landstingsmän": "landstingsman",
    "landstingsmännen": "landstingsman",
    "landstingsmännens": "landstingsman",
    "landstingsmäns": "landstingsman",
    "landstingsråden": "landstingsråd",
    "landstingsrådens": "landstingsråd",
    "landstingsrådet": "landstingsråd",
    "landstingsrådets": "landstingsråd",
    "landstingsråds": "landstingsråd",
    "landstormen": "landstorm",
    "landstormens": "landstorm",
    "landstorms": "landstorm",
    "landstrykar": "landstrykare",
    "landstrykaren": "landstrykare",
    "landstrykarens": "landstrykare",
    "landstrykares": "landstrykare",
    "landstrykarna": "landstrykare",
    "landstrykarnas": "landstrykare",
    "landställen": "landställe",
    "landställena": "landställe",
    "landställenas": "landställe",
    "landställens": "landställe",
    "landställes": "landställe",
    "landstället": "landställe",
    "landställets": "landställe",
    "landsvägar": "landsväg",
    "landsvägarna": "landsväg",
    "landsvägarnas": "landsväg",
    "landsvägars": "landsväg",
    "landsvägen": "landsväg",
    "landsvägens": "landsväg",
    "landsvägs": "landsväg",
    "landsvägsbussar": "landsvägsbuss",
    "landsvägsbussarna": "landsvägsbuss",
    "landsvägsbussarnas": "landsvägsbuss",
    "landsvägsbussars": "landsvägsbuss",
    "landsvägsbussen": "landsvägsbuss",
    "landsvägsbussens": "landsvägsbuss",
    "landsvägsriddar": "landsvägsriddare",
    "landsvägsriddaren": "landsvägsriddare",
    "landsvägsriddarens": "landsvägsriddare",
    "landsvägsriddares": "landsvägsriddare",
    "landsvägsriddarna": "landsvägsriddare",
    "landsvägsriddarnas": "landsvägsriddare",
    "landsänd": "landsända",
    "landsändan": "landsända",
    "landsändans": "landsända",
    "landsändar": "landsände",
    "landsändarna": "landsände",
    "landsändarnas": "landsände",
    "landsändars": "landsände",
    "landsändas": "landsända",
    "landsände": "landsända",
    "landsänden": "landsände",
    "landsändens": "landsände",
    "landsändes": "landsände",
    "landsändor": "landsända",
    "landsändorna": "landsända",
    "landsändornas": "landsända",
    "landsändors": "landsända",
    "landsänds": "landsända",
    "landsätt": "landsätta",
    "landsättande": "landsätta",
    "landsättanden": "landsättande",
    "landsättandena": "landsättande",
    "landsättandenas": "landsättande",
    "landsättandens": "landsättande",
    "landsättandes": "landsättande",
    "landsättandet": "landsättande",
    "landsättandets": "landsättande",
    "landsättas": "landsätta",
    "landsätter": "landsätta",
    "landsättes": "landsätta",
    "landsättningar": "landsättning",
    "landsättningarna": "landsättning",
    "landsättningarnas": "landsättning",
    "landsättningars": "landsättning",
    "landsättningen": "landsättning",
    "landsättningens": "landsättning",
    "landsättnings": "landsättning",
    "landsätts": "landsätta",
    "landtungan": "landtunga",
    "landtungans": "landtunga",
    "landtungas": "landtunga",
    "landtunge": "landtunga",
    "landtungo": "landtunga",
    "landtungor": "landtunga",
    "landtungorna": "landtunga",
    "landtungornas": "landtunga",
    "landtungors": "landtunga",
    "landvadar": "landvad",
    "landvadarna": "landvad",
    "landvadarnas": "landvad",
    "landvadars": "landvad",
    "landvaden": "landvad",
    "landvadens": "landvad",
    "landvads": "landvad",
    "landvindar": "landvind",
    "landvindarna": "landvind",
    "landvindarnas": "landvind",
    "landvindars": "landvind",
    "landvinden": "landvind",
    "landvindens": "landvind",
    "landvinds": "landvind",
    "landvinningar": "landvinning",
    "landvinningarna": "landvinning",
    "landvinningarnas": "landvinning",
    "landvinningars": "landvinning",
    "landvinningen": "landvinning",
    "landvinningens": "landvinning",
    "landvinnings": "landvinning",
    "landvägens": "landvägen",
    "landåer": "landå",
    "landåerna": "landå",
    "landåernas": "landå",
    "landåers": "landå",
    "landån": "landå",
    "landåns": "landå",
    "landås": "landå",
    "lane": "lana",
    "lanen": "lan",
    "lanens": "lan",
    "laner": "lan",
    "lanerna": "laner",
    "lanernas": "laner",
    "laners": "laner",
    "lang": "langa",
    "langad": "langa",
    "langade": "langa",
    "langades": "langa",
    "langads": "langa",
    "langande": "langa",
    "langanden": "langande",
    "langandena": "langande",
    "langandenas": "langande",
    "langandens": "langande",
    "langandes": "langande",
    "langandet": "langande",
    "langandets": "langande",
    "langar": "langare",
    "langaren": "langare",
    "langarens": "langare",
    "langares": "langare",
    "langarna": "langare",
    "langarnas": "langare",
    "langarner": "langarn",
    "langarnerna": "langarn",
    "langarnernas": "langarn",
    "langarners": "langarn",
    "langarnet": "langarn",
    "langarnets": "langarn",
    "langarns": "langarn",
    "langas": "langa",
    "langat": "langa",
    "langats": "langa",
    "langetten": "langett",
    "langettens": "langett",
    "langetter": "langett",
    "langetterad": "langettera",
    "langetterade": "langettera",
    "langetterades": "langettera",
    "langetterads": "langettera",
    "langetterande": "langettera",
    "langetteranden": "langetterande",
    "langetterandena": "langetterande",
    "langetterandenas": "langetterande",
    "langetterandens": "langetterande",
    "langetterandes": "langetterande",
    "langetterandet": "langetterande",
    "langetterandets": "langetterande",
    "langetterar": "langettera",
    "langetteras": "langettera",
    "langetterat": "langettera",
    "langetterats": "langettera",
    "langetterbara": "langetterbar",
    "langetterbarare": "langetterbar",
    "langetterbarares": "langetterbar",
    "langetterbaras": "langetterbar",
    "langetterbarast": "langetterbar",
    "langetterbaraste": "langetterbar",
    "langetterbarastes": "langetterbar",
    "langetterbarasts": "langetterbar",
    "langetterbare": "langetterbar",
    "langetterbares": "langetterbar",
    "langetterbarheten": "langetterbarhet",
    "langetterbarhetens": "langetterbarhet",
    "langetterbarhets": "langetterbarhet",
    "langetterbars": "langetterbar",
    "langetterbart": "langetterbar",
    "langetterbarts": "langetterbar",
    "langetteringar": "langettering",
    "langetteringarna": "langettering",
    "langetteringarnas": "langettering",
    "langetteringars": "langettering",
    "langetteringen": "langettering",
    "langetteringens": "langettering",
    "langetterings": "langettering",
    "langetterna": "langett",
    "langetternas": "langett",
    "langetters": "langett",
    "langetts": "langett",
    "langettstygnen": "langettstygn",
    "langettstygnens": "langettstygn",
    "langettstygnet": "langettstygn",
    "langettstygnets": "langettstygn",
    "langettstygns": "langettstygn",
    "langobarden": "langobard",
    "langobardens": "langobard",
    "langobarder": "langobard",
    "langobarderna": "langobard",
    "langobardernas": "langobard",
    "langobarders": "langobard",
    "langobards": "langobard",
    "langosar": "langos",
    "langosarna": "langos",
    "langosarnas": "langos",
    "langosars": "langos",
    "langosen": "langos",
    "langosens": "langos",
    "langusten": "langust",
    "langustens": "langust",
    "languster": "langust",
    "langusterna": "langust",
    "langusternas": "langust",
    "langusters": "langust",
    "langusts": "langust",
    "lank": "lanka",
    "lankan": "lanka",
    "lankans": "lanka",
    "lankas": "lanka",
    "lanke": "lanka",
    "lanken": "lank",
    "lankens": "lank",
    "lankesen": "lankes",
    "lankesens": "lankes",
    "lankeser": "lankes",
    "lankeserna": "lankes",
    "lankesernas": "lankes",
    "lankesers": "lankes",
    "lankesiska": "lankesisk",
    "lankesiskan": "lankesiska",
    "lankesiskans": "lankesiska",
    "lankesiskare": "lankesisk",
    "lankesiskares": "lankesisk",
    "lankesiskas": "lankesiska",
    "lankesiskast": "lankesisk",
    "lankesiskaste": "lankesisk",
    "lankesiskastes": "lankesisk",
    "lankesiskasts": "lankesisk",
    "lankesiske": "lankesiska",
    "lankesiskes": "lankesisk",
    "lankesiskor": "lankesiska",
    "lankesiskorna": "lankesiska",
    "lankesiskornas": "lankesiska",
    "lankesiskors": "lankesiska",
    "lankesisks": "lankesisk",
    "lankesiskt": "lankesisk",
    "lankesiskts": "lankesisk",
    "lankor": "lanka",
    "lankorna": "lanka",
    "lankornas": "lanka",
    "lankors": "lanka",
    "lanks": "lanka",
    "lanolinen": "lanolin",
    "lanolinens": "lanolin",
    "lanolinet": "lanolin",
    "lanolinets": "lanolin",
    "lanolins": "lanolin",
    "lanor": "lana",
    "lanorna": "lana",
    "lanornas": "lana",
    "lanors": "lana",
    "lans": "lana",
    "lansar": "lans",
    "lansarna": "lans",
    "lansarnas": "lans",
    "lansars": "lans",
    "lansen": "lans",
    "lansens": "lans",
    "lanserad": "lansera",
    "lanserade": "lansera",
    "lanserades": "lansera",
    "lanserads": "lansera",
    "lanserande": "lansera",
    "lanseranden": "lanserande",
    "lanserandena": "lanserande",
    "lanserandenas": "lanserande",
    "lanserandens": "lanserande",
    "lanserandes": "lanserande",
    "lanserandet": "lanserande",
    "lanserandets": "lanserande",
    "lanserar": "lansera",
    "lanseras": "lansera",
    "lanserat": "lansera",
    "lanserats": "lansera",
    "lanserbara": "lanserbar",
    "lanserbarare": "lanserbar",
    "lanserbarares": "lanserbar",
    "lanserbaras": "lanserbar",
    "lanserbarast": "lanserbar",
    "lanserbaraste": "lanserbar",
    "lanserbarastes": "lanserbar",
    "lanserbarasts": "lanserbar",
    "lanserbare": "lanserbar",
    "lanserbares": "lanserbar",
    "lanserbarheten": "lanserbarhet",
    "lanserbarhetens": "lanserbarhet",
    "lanserbarhets": "lanserbarhet",
    "lanserbars": "lanserbar",
    "lanserbart": "lanserbar",
    "lanserbarts": "lanserbar",
    "lanseringar": "lansering",
    "lanseringarna": "lansering",
    "lanseringarnas": "lansering",
    "lanseringars": "lansering",
    "lanseringen": "lansering",
    "lanseringens": "lansering",
    "lanserings": "lansering",
    "lansetten": "lansett",
    "lansettens": "lansett",
    "lansetter": "lansett",
    "lansetterna": "lansett",
    "lansetternas": "lansett",
    "lansetters": "lansett",
    "lansettfiskar": "lansettfisk",
    "lansettfiskarna": "lansettfisk",
    "lansettfiskarnas": "lansettfisk",
    "lansettfiskars": "lansettfisk",
    "lansettfisken": "lansettfisk",
    "lansettfiskens": "lansettfisk",
    "lansettfisks": "lansettfisk",
    "lansetts": "lansett",
    "lansiären": "lansiär",
    "lansiärens": "lansiär",
    "lansiärer": "lansiär",
    "lansiärerna": "lansiär",
    "lansiärernas": "lansiär",
    "lansiärers": "lansiär",
    "lansiärs": "lansiär",
    "lantanen": "lantan",
    "lantanens": "lantan",
    "lantanet": "lantan",
    "lantanets": "lantan",
    "lantans": "lantan",
    "lantarbetar": "lantarbetare",
    "lantarbetaren": "lantarbetare",
    "lantarbetarens": "lantarbetare",
    "lantarbetares": "lantarbetare",
    "lantarbetarhustrun": "lantarbetarhustru",
    "lantarbetarhustruns": "lantarbetarhustru",
    "lantarbetarhustrur": "lantarbetarhustru",
    "lantarbetarhustrurna": "lantarbetarhustru",
    "lantarbetarhustrurnas": "lantarbetarhustru",
    "lantarbetarhustrurs": "lantarbetarhustru",
    "lantarbetarhustrus": "lantarbetarhustru",
    "lantarbetarna": "lantarbetare",
    "lantarbetarnas": "lantarbetare",
    "lantbodd": "lantbo",
    "lantbodda": "lantbo",
    "lantboddas": "lantbo",
    "lantbodde": "lantbo",
    "lantboddes": "lantbo",
    "lantbodds": "lantbo",
    "lantboende": "lantbo",
    "lantboendes": "lantbo",
    "lantbor": "lantbo",
    "lantbos": "lantbo",
    "lantbott": "lantbo",
    "lantbotts": "lantbo",
    "lantbrevbärar": "lantbrevbärare",
    "lantbrevbäraren": "lantbrevbärare",
    "lantbrevbärarens": "lantbrevbärare",
    "lantbrevbärares": "lantbrevbärare",
    "lantbrevbärarna": "lantbrevbärare",
    "lantbrevbärarnas": "lantbrevbärare",
    "lantbrukar": "lantbrukare",
    "lantbrukaren": "lantbrukare",
    "lantbrukarens": "lantbrukare",
    "lantbrukares": "lantbrukare",
    "lantbrukarna": "lantbrukare",
    "lantbrukarnas": "lantbrukare",
    "lantbruken": "lantbruk",
    "lantbrukens": "lantbruk",
    "lantbruket": "lantbruk",
    "lantbrukets": "lantbruk",
    "lantbruks": "lantbruk",
    "lantbruksdirektören": "lantbruksdirektör",
    "lantbruksdirektörens": "lantbruksdirektör",
    "lantbruksdirektörer": "lantbruksdirektör",
    "lantbruksdirektörerna": "lantbruksdirektör",
    "lantbruksdirektörernas": "lantbruksdirektör",
    "lantbruksdirektörers": "lantbruksdirektör",
    "lantbruksdirektörn": "lantbruksdirektör",
    "lantbruksdirektörns": "lantbruksdirektör",
    "lantbruksdirektörs": "lantbruksdirektör",
    "lantbruksförbunden": "lantbruksförbund",
    "lantbruksförbundens": "lantbruksförbund",
    "lantbruksförbundet": "lantbruksförbund",
    "lantbruksförbundets": "lantbruksförbund",
    "lantbruksförbunds": "lantbruksförbund",
    "lantbrukskonsulenten": "lantbrukskonsulent",
    "lantbrukskonsulentens": "lantbrukskonsulent",
    "lantbrukskonsulenter": "lantbrukskonsulent",
    "lantbrukskonsulenterna": "lantbrukskonsulent",
    "lantbrukskonsulenternas": "lantbrukskonsulent",
    "lantbrukskonsulenters": "lantbrukskonsulent",
    "lantbrukskonsulents": "lantbrukskonsulent",
    "lantbrukskunnanden": "lantbrukskunnande",
    "lantbrukskunnandena": "lantbrukskunnande",
    "lantbrukskunnandenas": "lantbrukskunnande",
    "lantbrukskunnandens": "lantbrukskunnande",
    "lantbrukskunnandes": "lantbrukskunnande",
    "lantbrukskunnandet": "lantbrukskunnande",
    "lantbrukskunnandets": "lantbrukskunnande",
    "lantbruksnämnden": "lantbruksnämnd",
    "lantbruksnämndens": "lantbruksnämnd",
    "lantbruksnämnder": "lantbruksnämnd",
    "lantbruksnämnderna": "lantbruksnämnd",
    "lantbruksnämndernas": "lantbruksnämnd",
    "lantbruksnämnders": "lantbruksnämnd",
    "lantbruksnämnds": "lantbruksnämnd",
    "lantbruksstyrelsen": "lantbruksstyrelse",
    "lantbruksstyrelsens": "lantbruksstyrelse",
    "lantbruksstyrelser": "lantbruksstyrelse",
    "lantbruksstyrelserna": "lantbruksstyrelse",
    "lantbruksstyrelsernas": "lantbruksstyrelse",
    "lantbruksstyrelsers": "lantbruksstyrelse",
    "lantbruksstyrelses": "lantbruksstyrelse",
    "lantbruksuniversiteten": "lantbruksuniversitet",
    "lantbruksuniversitetens": "lantbruksuniversitet",
    "lantbruksuniversitetet": "lantbruksuniversitet",
    "lantbruksuniversitetets": "lantbruksuniversitet",
    "lantbruksuniversitets": "lantbruksuniversitet",
    "lantdagar": "lantdag",
    "lantdagarna": "lantdag",
    "lantdagarnas": "lantdag",
    "lantdagars": "lantdag",
    "lantdagen": "lantdag",
    "lantdagens": "lantdag",
    "lantdags": "lantdag",
    "lantegendomar": "lantegendom",
    "lantegendomarna": "lantegendom",
    "lantegendomarnas": "lantegendom",
    "lantegendomars": "lantegendom",
    "lantegendomen": "lantegendom",
    "lantegendomens": "lantegendom",
    "lantegendoms": "lantegendom",
    "lantern": "lanterna",
    "lanternan": "lanterna",
    "lanternans": "lanterna",
    "lanternas": "lanterna",
    "lanterne": "lanterna",
    "lanterninen": "lanternin",
    "lanterninens": "lanternin",
    "lanterniner": "lanternin",
    "lanterninerna": "lanternin",
    "lanterninernas": "lanternin",
    "lanterniners": "lanternin",
    "lanternins": "lanternin",
    "lanternor": "lanterna",
    "lanternorna": "lanterna",
    "lanternornas": "lanterna",
    "lanternors": "lanterna",
    "lanterns": "lanterna",
    "lantgrev": "lantgreve",
    "lantgrevar": "lantgreve",
    "lantgrevarna": "lantgreve",
    "lantgrevarnas": "lantgreve",
    "lantgrevars": "lantgreve",
    "lantgreven": "lantgreve",
    "lantgrevens": "lantgreve",
    "lantgreves": "lantgreve",
    "lantgrevs": "lantgreve",
    "lantgårdar": "lantgård",
    "lantgårdarna": "lantgård",
    "lantgårdarnas": "lantgård",
    "lantgårdars": "lantgård",
    "lantgården": "lantgård",
    "lantgårdens": "lantgård",
    "lantgårds": "lantgård",
    "lanthandeln": "lanthandel",
    "lanthandelns": "lanthandel",
    "lanthandels": "lanthandel",
    "lanthandlar": "lanthandel",
    "lanthandlarna": "lanthandel",
    "lanthandlarnas": "lanthandel",
    "lanthandlars": "lanthandel",
    "lanthushållningar": "lanthushållning",
    "lanthushållningarna": "lanthushållning",
    "lanthushållningarnas": "lanthushållning",
    "lanthushållningars": "lanthushållning",
    "lanthushållningen": "lanthushållning",
    "lanthushållningens": "lanthushållning",
    "lanthushållnings": "lanthushållning",
    "lantisar": "lantis",
    "lantisarna": "lantis",
    "lantisarnas": "lantis",
    "lantisars": "lantis",
    "lantisen": "lantis",
    "lantisens": "lantis",
    "lantjunkar": "lantjunkare",
    "lantjunkaren": "lantjunkare",
    "lantjunkarens": "lantjunkare",
    "lantjunkares": "lantjunkare",
    "lantjunkarna": "lantjunkare",
    "lantjunkarnas": "lantjunkare",
    "lantliga": "lantlig",
    "lantligare": "lantlig",
    "lantligares": "lantlig",
    "lantligas": "lantlig",
    "lantligast": "lantlig",
    "lantligaste": "lantlig",
    "lantligastes": "lantlig",
    "lantligasts": "lantlig",
    "lantlige": "lantlig",
    "lantliges": "lantlig",
    "lantligheten": "lantlighet",
    "lantlighetens": "lantlighet",
    "lantlighets": "lantlighet",
    "lantligs": "lantlig",
    "lantligt": "lantlig",
    "lantligts": "lantlig",
    "lantloll": "lantlolla",
    "lantlollan": "lantlolla",
    "lantlollans": "lantlolla",
    "lantlollas": "lantlolla",
    "lantlolle": "lantlolla",
    "lantlollor": "lantlolla",
    "lantlollorna": "lantlolla",
    "lantlollornas": "lantlolla",
    "lantlollors": "lantlolla",
    "lantlolls": "lantlolla",
    "lantluften": "lantluft",
    "lantluftens": "lantluft",
    "lantlufts": "lantluft",
    "lantmannapartiet": "lantmannaparti",
    "lantmannapartiets": "lantmannaparti",
    "lantmannapartis": "lantmannaparti",
    "lantmannen": "lantman",
    "lantmannens": "lantman",
    "lantmans": "lantman",
    "lantmarskalkar": "lantmarskalk",
    "lantmarskalkarna": "lantmarskalk",
    "lantmarskalkarnas": "lantmarskalk",
    "lantmarskalkars": "lantmarskalk",
    "lantmarskalken": "lantmarskalk",
    "lantmarskalkens": "lantmarskalk",
    "lantmarskalks": "lantmarskalk",
    "lantmän": "lantman",
    "lantmännen": "lantman",
    "lantmännens": "lantman",
    "lantmäns": "lantman",
    "lantmässiga": "lantmässig",
    "lantmässigare": "lantmässig",
    "lantmässigares": "lantmässig",
    "lantmässigas": "lantmässig",
    "lantmässigast": "lantmässig",
    "lantmässigaste": "lantmässig",
    "lantmässigastes": "lantmässig",
    "lantmässigasts": "lantmässig",
    "lantmässige": "lantmässig",
    "lantmässiges": "lantmässig",
    "lantmässigs": "lantmässig",
    "lantmässigt": "lantmässig",
    "lantmässigts": "lantmässig",
    "lantmästar": "lantmästare",
    "lantmästaren": "lantmästare",
    "lantmästarens": "lantmästare",
    "lantmästares": "lantmästare",
    "lantmästarna": "lantmästare",
    "lantmästarnas": "lantmästare",
    "lantmätar": "lantmätare",
    "lantmätaren": "lantmätare",
    "lantmätarens": "lantmätare",
    "lantmätares": "lantmätare",
    "lantmätarna": "lantmätare",
    "lantmätarnas": "lantmätare",
    "lantmäterier": "lantmäteri",
    "lantmäterierna": "lantmäteri",
    "lantmäteriernas": "lantmäteri",
    "lantmäteriers": "lantmäteri",
    "lantmäteriet": "lantmäteri",
    "lantmäteriets": "lantmäteri",
    "lantmäteris": "lantmäteri",
    "lantmäterit": "lantmäteri",
    "lantmäterits": "lantmäteri",
    "lantrasen": "lantras",
    "lantrasens": "lantras",
    "lantraser": "lantras",
    "lantraserna": "lantras",
    "lantrasernas": "lantras",
    "lantrasers": "lantras",
    "lantrasgrisar": "lantrasgris",
    "lantrasgrisarna": "lantrasgris",
    "lantrasgrisarnas": "lantrasgris",
    "lantrasgrisars": "lantrasgris",
    "lantrasgrisen": "lantrasgris",
    "lantrasgrisens": "lantrasgris",
    "lantsmöret": "lantsmör",
    "lantsmörets": "lantsmör",
    "lantsmörs": "lantsmör",
    "lantställen": "lantställe",
    "lantställena": "lantställe",
    "lantställenas": "lantställe",
    "lantställens": "lantställe",
    "lantställes": "lantställe",
    "lantstället": "lantställe",
    "lantställets": "lantställe",
    "lantviner": "lantvin",
    "lantvinerna": "lantvin",
    "lantvinernas": "lantvin",
    "lantviners": "lantvin",
    "lantvinet": "lantvin",
    "lantvinets": "lantvin",
    "lantvins": "lantvin",
    "lantvärnen": "lantvärn",
    "lantvärnens": "lantvärn",
    "lantvärnet": "lantvärn",
    "lantvärnets": "lantvärn",
    "lantvärns": "lantvärn",
    "laotiern": "laotier",
    "laotierna": "laotier",
    "laotiernas": "laotier",
    "laotierns": "laotier",
    "laotiers": "laotier",
    "laotisk": "laotiska",
    "laotiska": "laotisk",
    "laotiskan": "laotiska",
    "laotiskans": "laotiska",
    "laotiskare": "laotisk",
    "laotiskares": "laotisk",
    "laotiskas": "laotiska",
    "laotiskast": "laotisk",
    "laotiskaste": "laotisk",
    "laotiskastes": "laotisk",
    "laotiskasts": "laotisk",
    "laotiske": "laotiska",
    "laotiskes": "laotisk",
    "laotiskor": "laotiska",
    "laotiskorna": "laotiska",
    "laotiskornas": "laotiska",
    "laotiskors": "laotiska",
    "laotisks": "laotisk",
    "laotiskt": "laotisk",
    "laotiskts": "laotisk",
    "lap": "lapa",
    "lapad": "lapa",
    "lapade": "lapa",
    "lapades": "lapa",
    "lapads": "lapa",
    "lapande": "lapa",
    "lapanden": "lapande",
    "lapandena": "lapande",
    "lapandenas": "lapande",
    "lapandens": "lapande",
    "lapandes": "lapande",
    "lapandet": "lapande",
    "lapandets": "lapande",
    "lapar": "lapa",
    "laparoskopien": "laparoskopi",
    "laparoskopiens": "laparoskopi",
    "laparoskopin": "laparoskopi",
    "laparoskopins": "laparoskopi",
    "laparoskopis": "laparoskopi",
    "lapas": "lapa",
    "lapat": "lapa",
    "lapats": "lapa",
    "lapidariska": "lapidarisk",
    "lapidariskare": "lapidarisk",
    "lapidariskares": "lapidarisk",
    "lapidariskas": "lapidarisk",
    "lapidariskast": "lapidarisk",
    "lapidariskaste": "lapidarisk",
    "lapidariskastes": "lapidarisk",
    "lapidariskasts": "lapidarisk",
    "lapidariske": "lapidarisk",
    "lapidariskes": "lapidarisk",
    "lapidarisks": "lapidarisk",
    "lapidariskt": "lapidarisk",
    "lapidariskts": "lapidarisk",
    "lapidarstilen": "lapidarstil",
    "lapidarstilens": "lapidarstil",
    "lapidarstils": "lapidarstil",
    "lapisen": "lapis",
    "lapisens": "lapis",
    "lapiserad": "lapisera",
    "lapiserade": "lapisera",
    "lapiserades": "lapisera",
    "lapiserads": "lapisera",
    "lapiserande": "lapisera",
    "lapiseranden": "lapiserande",
    "lapiserandena": "lapiserande",
    "lapiserandenas": "lapiserande",
    "lapiserandens": "lapiserande",
    "lapiserandes": "lapiserande",
    "lapiserandet": "lapiserande",
    "lapiserandets": "lapiserande",
    "lapiserar": "lapisera",
    "lapiseras": "lapisera",
    "lapiserat": "lapisera",
    "lapiserats": "lapisera",
    "lapiserbara": "lapiserbar",
    "lapiserbarare": "lapiserbar",
    "lapiserbarares": "lapiserbar",
    "lapiserbaras": "lapiserbar",
    "lapiserbarast": "lapiserbar",
    "lapiserbaraste": "lapiserbar",
    "lapiserbarastes": "lapiserbar",
    "lapiserbarasts": "lapiserbar",
    "lapiserbare": "lapiserbar",
    "lapiserbares": "lapiserbar",
    "lapiserbarheten": "lapiserbarhet",
    "lapiserbarhetens": "lapiserbarhet",
    "lapiserbarhets": "lapiserbarhet",
    "lapiserbars": "lapiserbar",
    "lapiserbart": "lapiserbar",
    "lapiserbarts": "lapiserbar",
    "lapiseringar": "lapisering",
    "lapiseringarna": "lapisering",
    "lapiseringarnas": "lapisering",
    "lapiseringars": "lapisering",
    "lapiseringen": "lapisering",
    "lapiseringens": "lapisering",
    "lapiserings": "lapisering",
    "lapkojsen": "lapkojs",
    "lapkojsens": "lapkojs",
    "lapkojset": "lapkojs",
    "lapkojsets": "lapkojs",
    "lapp": "lappa",
    "lappad": "lappa",
    "lappade": "lappa",
    "lappades": "lappa",
    "lappads": "lappa",
    "lappande": "lappa",
    "lappanden": "lappande",
    "lappandena": "lappande",
    "lappandenas": "lappande",
    "lappandens": "lappande",
    "lappandes": "lappande",
    "lappandet": "lappande",
    "lappandets": "lappande",
    "lappar": "lappa",
    "lapparna": "lapp",
    "lapparnas": "lapp",
    "lappars": "lapp",
    "lappas": "lappa",
    "lappat": "lappa",
    "lappats": "lappa",
    "lappen": "lapp",
    "lappens": "lapp",
    "lapphundar": "lapphund",
    "lapphundarna": "lapphund",
    "lapphundarnas": "lapphund",
    "lapphundars": "lapphund",
    "lapphunden": "lapphund",
    "lapphundens": "lapphund",
    "lapphunds": "lapphund",
    "lappkasten": "lappkast",
    "lappkastens": "lappkast",
    "lappkastet": "lappkast",
    "lappkastets": "lappkast",
    "lappkasts": "lappkast",
    "lappkojsen": "lappkojs",
    "lappkojsens": "lappkojs",
    "lappkojset": "lappkojs",
    "lappkojsets": "lappkojs",
    "lapplandsgranar": "lapplandsgran",
    "lapplandsgranarna": "lapplandsgran",
    "lapplandsgranarnas": "lapplandsgran",
    "lapplandsgranars": "lapplandsgran",
    "lapplandsgranen": "lapplandsgran",
    "lapplandsgranens": "lapplandsgran",
    "lapplandsgrans": "lapplandsgran",
    "lapplis": "lapplisa",
    "lapplisan": "lapplisa",
    "lapplisans": "lapplisa",
    "lapplisas": "lapplisa",
    "lapplise": "lapplisa",
    "lapplisor": "lapplisa",
    "lapplisorna": "lapplisa",
    "lapplisornas": "lapplisa",
    "lapplisors": "lapplisa",
    "lappländska": "lappländsk",
    "lappländskan": "lappländska",
    "lappländskans": "lappländska",
    "lappländskare": "lappländsk",
    "lappländskares": "lappländsk",
    "lappländskas": "lappländska",
    "lappländskast": "lappländsk",
    "lappländskaste": "lappländsk",
    "lappländskastes": "lappländsk",
    "lappländskasts": "lappländsk",
    "lappländske": "lappländska",
    "lappländskes": "lappländsk",
    "lappländskor": "lappländska",
    "lappländskorna": "lappländska",
    "lappländskornas": "lappländska",
    "lappländskors": "lappländska",
    "lappländsks": "lappländsk",
    "lappländskt": "lappländsk",
    "lappländskts": "lappländsk",
    "lapplänningar": "lapplänning",
    "lapplänningarna": "lapplänning",
    "lapplänningarnas": "lapplänning",
    "lapplänningars": "lapplänning",
    "lapplänningen": "lapplänning",
    "lapplänningens": "lapplänning",
    "lapplännings": "lapplänning",
    "lappris": "lappri",
    "lapprit": "lappri",
    "lapprits": "lappri",
    "lapps": "lapp",
    "lappsjukan": "lappsjuka",
    "lappsjukans": "lappsjuka",
    "lappsjukas": "lappsjuka",
    "lappsjuke": "lappsjuka",
    "lappsjuks": "lappsjuka",
    "lappskojsen": "lappskojs",
    "lappskojsens": "lappskojs",
    "lappskojset": "lappskojs",
    "lappskojsets": "lappskojs",
    "lappskrivningar": "lappskrivning",
    "lappskrivningarna": "lappskrivning",
    "lappskrivningarnas": "lappskrivning",
    "lappskrivningars": "lappskrivning",
    "lappskrivningen": "lappskrivning",
    "lappskrivningens": "lappskrivning",
    "lappskrivnings": "lappskrivning",
    "lappsparvar": "lappsparv",
    "lappsparvarna": "lappsparv",
    "lappsparvarnas": "lappsparv",
    "lappsparvars": "lappsparv",
    "lappsparven": "lappsparv",
    "lappsparvens": "lappsparv",
    "lappsparvs": "lappsparv",
    "lapptäcken": "lapptäcke",
    "lapptäckena": "lapptäcke",
    "lapptäckenas": "lapptäcke",
    "lapptäckens": "lapptäcke",
    "lapptäckes": "lapptäcke",
    "lapptäcket": "lapptäcke",
    "lapptäckets": "lapptäcke",
    "lappvant": "lappvante",
    "lappvantar": "lappvante",
    "lappvantarna": "lappvante",
    "lappvantarnas": "lappvante",
    "lappvantars": "lappvante",
    "lappvanten": "lappvante",
    "lappvantens": "lappvante",
    "lappvantes": "lappvante",
    "lappvants": "lappvante",
    "lappverken": "lappverk",
    "lappverkens": "lappverk",
    "lappverket": "lappverk",
    "lappverkets": "lappverk",
    "lappverks": "lappverk",
    "lapsk": "lapska",
    "lapska": "lapsk",
    "lapskan": "lapska",
    "lapskans": "lapska",
    "lapskare": "lapsk",
    "lapskares": "lapsk",
    "lapskas": "lapska",
    "lapskast": "lapsk",
    "lapskaste": "lapsk",
    "lapskastes": "lapsk",
    "lapskasts": "lapsk",
    "lapske": "lapska",
    "lapskes": "lapsk",
    "lapskheten": "lapskhet",
    "lapskhetens": "lapskhet",
    "lapskhets": "lapskhet",
    "lapskojsen": "lapskojs",
    "lapskojsens": "lapskojs",
    "lapskojset": "lapskojs",
    "lapskojsets": "lapskojs",
    "lapskor": "lapska",
    "lapskorna": "lapska",
    "lapskornas": "lapska",
    "lapskors": "lapska",
    "lapsks": "lapsk",
    "lapskt": "lapsk",
    "lapskts": "lapsk",
    "lapsusar": "lapsus",
    "lapsusarna": "lapsus",
    "lapsusarnas": "lapsus",
    "lapsusars": "lapsus",
    "lapsusen": "lapsus",
    "lapsusens": "lapsus",
    "laptopar": "laptop",
    "laptoparna": "laptop",
    "laptoparnas": "laptop",
    "laptopars": "laptop",
    "laptopen": "laptop",
    "laptopens": "laptop",
    "laptoppar": "laptopp",
    "laptopparna": "laptopp",
    "laptopparnas": "laptopp",
    "laptoppars": "laptopp",
    "laptoppen": "laptopp",
    "laptoppens": "laptopp",
    "laptopps": "laptopp",
    "laptoppsarna": "laptopp",
    "laptoppsarnas": "laptopp",
    "laptoppsen": "laptopp",
    "laptoppsens": "laptopp",
    "laptops": "laptop",
    "laptopsarna": "laptop",
    "laptopsarnas": "laptop",
    "laptopsen": "laptop",
    "laptopsens": "laptop",
    "largetton": "largetto",
    "largettona": "largetto",
    "largettonas": "largetto",
    "largettons": "largetto",
    "largettos": "largetto",
    "largettot": "largetto",
    "largettots": "largetto",
    "largon": "largo",
    "largona": "largo",
    "largonas": "largo",
    "largons": "largo",
    "largos": "largo",
    "largot": "largo",
    "largots": "largo",
    "larmad": "larma",
    "larmade": "larma",
    "larmades": "larma",
    "larmads": "larma",
    "larmande": "larma",
    "larmanden": "larmande",
    "larmandena": "larmande",
    "larmandenas": "larmande",
    "larmandens": "larmande",
    "larmandes": "larmande",
    "larmandet": "larmande",
    "larmandets": "larmande",
    "larmar": "larma",
    "larmas": "larma",
    "larmat": "larma",
    "larmats": "larma",
    "larmberedskapen": "larmberedskap",
    "larmberedskapens": "larmberedskap",
    "larmberedskaps": "larmberedskap",
    "larmen": "larm",
    "larmens": "larm",
    "larmet": "larm",
    "larmets": "larm",
    "larmförläggningar": "larmförläggning",
    "larmförläggningarna": "larmförläggning",
    "larmförläggningarnas": "larmförläggning",
    "larmförläggningars": "larmförläggning",
    "larmförläggningen": "larmförläggning",
    "larmförläggningens": "larmförläggning",
    "larmförläggnings": "larmförläggning",
    "larmklock": "larmklocka",
    "larmklockan": "larmklocka",
    "larmklockans": "larmklocka",
    "larmklockas": "larmklocka",
    "larmklocke": "larmklocka",
    "larmklockor": "larmklocka",
    "larmklockorna": "larmklocka",
    "larmklockornas": "larmklocka",
    "larmklockors": "larmklocka",
    "larmklocks": "larmklocka",
    "larmrapporten": "larmrapport",
    "larmrapportens": "larmrapport",
    "larmrapporter": "larmrapport",
    "larmrapporterna": "larmrapport",
    "larmrapporternas": "larmrapport",
    "larmrapporters": "larmrapport",
    "larmrapports": "larmrapport",
    "larms": "larm",
    "larv": "larva",
    "larvade": "larva",
    "larvades": "larva",
    "larvan": "larva",
    "larvande": "larva",
    "larvanden": "larvande",
    "larvandena": "larvande",
    "larvandenas": "larvande",
    "larvandens": "larvande",
    "larvandes": "larvande",
    "larvandet": "larvande",
    "larvandets": "larvande",
    "larvans": "larva",
    "larvar": "larver",
    "larvarna": "larver",
    "larvarnas": "larver",
    "larvars": "larver",
    "larvas": "larva",
    "larvat": "larva",
    "larvats": "larva",
    "larvbanden": "larvband",
    "larvbandens": "larvband",
    "larvbandet": "larvband",
    "larvbandets": "larvband",
    "larvbands": "larvband",
    "larve": "larva",
    "larven": "larv",
    "larvens": "larv",
    "larver": "larv",
    "larvern": "larver",
    "larverna": "larv",
    "larvernas": "larv",
    "larverns": "larver",
    "larvers": "larver",
    "larvet": "larv",
    "larvets": "larv",
    "larvfots": "larvfötter",
    "larvfötterna": "larvfötter",
    "larvfötternas": "larvfötter",
    "larvfötters": "larvfötter",
    "larviga": "larvig",
    "larvigare": "larvig",
    "larvigares": "larvig",
    "larvigas": "larvig",
    "larvigast": "larvig",
    "larvigaste": "larvig",
    "larvigastes": "larvig",
    "larvigasts": "larvig",
    "larvige": "larvig",
    "larviges": "larvig",
    "larvigheten": "larvighet",
    "larvighetens": "larvighet",
    "larvighets": "larvighet",
    "larvigs": "larvig",
    "larvigt": "larvig",
    "larvigts": "larvig",
    "larvor": "larva",
    "larvorna": "larva",
    "larvornas": "larva",
    "larvors": "larva",
    "larvrar": "larver",
    "larvrarna": "larver",
    "larvrarnas": "larver",
    "larvrars": "larver",
    "larvs": "larva",
    "larvtraktorer": "larvtraktor",
    "larvtraktorerna": "larvtraktor",
    "larvtraktorernas": "larvtraktor",
    "larvtraktorers": "larvtraktor",
    "larvtraktorn": "larvtraktor",
    "larvtraktorns": "larvtraktor",
    "larvtraktors": "larvtraktor",
    "laryngala": "laryngal",
    "laryngalare": "laryngal",
    "laryngalares": "laryngal",
    "laryngalas": "laryngal",
    "laryngalast": "laryngal",
    "laryngalaste": "laryngal",
    "laryngalastes": "laryngal",
    "laryngalasts": "laryngal",
    "laryngale": "laryngal",
    "laryngalen": "laryngal",
    "laryngalens": "laryngal",
    "laryngaler": "laryngal",
    "laryngalerna": "laryngal",
    "laryngalernas": "laryngal",
    "laryngalers": "laryngal",
    "laryngales": "laryngal",
    "laryngals": "laryngal",
    "laryngalt": "laryngal",
    "laryngalts": "laryngal",
    "laryngiten": "laryngit",
    "laryngitens": "laryngit",
    "laryngiter": "laryngit",
    "laryngiterna": "laryngit",
    "laryngiternas": "laryngit",
    "laryngiters": "laryngit",
    "laryngits": "laryngit",
    "laryngologen": "laryngolog",
    "laryngologens": "laryngolog",
    "laryngologer": "laryngolog",
    "laryngologerna": "laryngolog",
    "laryngologernas": "laryngolog",
    "laryngologers": "laryngolog",
    "laryngologien": "laryngologi",
    "laryngologiens": "laryngologi",
    "laryngologin": "laryngologi",
    "laryngologins": "laryngologi",
    "laryngologis": "laryngologi",
    "laryngologs": "laryngolog",
    "laryngoskopen": "laryngoskop",
    "laryngoskopens": "laryngoskop",
    "laryngoskopet": "laryngoskop",
    "laryngoskopets": "laryngoskop",
    "laryngoskopien": "laryngoskopi",
    "laryngoskopiens": "laryngoskopi",
    "laryngoskopier": "laryngoskopi",
    "laryngoskopierna": "laryngoskopi",
    "laryngoskopiernas": "laryngoskopi",
    "laryngoskopiers": "laryngoskopi",
    "laryngoskopin": "laryngoskopi",
    "laryngoskopins": "laryngoskopi",
    "laryngoskopis": "laryngoskopi",
    "laryngoskops": "laryngoskop",
    "las": "lägga",
    "lasade": "lasad",
    "lasades": "lasad",
    "lasads": "lasad",
    "lasagnen": "lasagne",
    "lasagnens": "lasagne",
    "lasagnes": "lasagne",
    "lasaretten": "lasarett",
    "lasarettens": "lasarett",
    "lasarettet": "lasarett",
    "lasarettets": "lasarett",
    "lasaretts": "lasarett",
    "lasaronen": "lasaron",
    "lasaronens": "lasaron",
    "lasaroner": "lasaron",
    "lasaronerna": "lasaron",
    "lasaronernas": "lasaron",
    "lasaroners": "lasaron",
    "lasarons": "lasaron",
    "lasat": "lasad",
    "lasats": "lasad",
    "lasciva": "lasciv",
    "lascivare": "lasciv",
    "lascivares": "lasciv",
    "lascivas": "lasciv",
    "lascivast": "lasciv",
    "lascivaste": "lasciv",
    "lascivastes": "lasciv",
    "lascivasts": "lasciv",
    "lascive": "lasciv",
    "lascives": "lasciv",
    "lascivs": "lasciv",
    "lascivt": "lasciv",
    "lascivts": "lasciv",
    "laserad": "lasera",
    "laserade": "lasera",
    "laserades": "lasera",
    "laserads": "lasera",
    "laserande": "lasera",
    "laseranden": "laserande",
    "laserandena": "laserande",
    "laserandenas": "laserande",
    "laserandens": "laserande",
    "laserandes": "laserande",
    "laserandet": "laserande",
    "laserandets": "laserande",
    "laserar": "lasera",
    "laseras": "lasera",
    "laserat": "lasera",
    "laserats": "lasera",
    "laserbara": "laserbar",
    "laserbarare": "laserbar",
    "laserbarares": "laserbar",
    "laserbaras": "laserbar",
    "laserbarast": "laserbar",
    "laserbaraste": "laserbar",
    "laserbarastes": "laserbar",
    "laserbarasts": "laserbar",
    "laserbare": "laserbar",
    "laserbares": "laserbar",
    "laserbarheten": "laserbarhet",
    "laserbarhetens": "laserbarhet",
    "laserbarhets": "laserbarhet",
    "laserbars": "laserbar",
    "laserbart": "laserbar",
    "laserbarts": "laserbar",
    "laserfärgen": "laserfärg",
    "laserfärgens": "laserfärg",
    "laserfärger": "laserfärg",
    "laserfärgerna": "laserfärg",
    "laserfärgernas": "laserfärg",
    "laserfärgers": "laserfärg",
    "laserfärgs": "laserfärg",
    "laseringar": "lasering",
    "laseringarna": "lasering",
    "laseringarnas": "lasering",
    "laseringars": "lasering",
    "laseringen": "lasering",
    "laseringens": "lasering",
    "laserings": "lasering",
    "laserkanonen": "laserkanon",
    "laserkanonens": "laserkanon",
    "laserkanoner": "laserkanon",
    "laserkanonerna": "laserkanon",
    "laserkanonernas": "laserkanon",
    "laserkanoners": "laserkanon",
    "laserkanons": "laserkanon",
    "lasern": "laser",
    "laserns": "laser",
    "lasers": "laser",
    "lasersikten": "lasersikte",
    "lasersiktena": "lasersikte",
    "lasersiktenas": "lasersikte",
    "lasersiktens": "lasersikte",
    "lasersiktes": "lasersikte",
    "lasersiktet": "lasersikte",
    "lasersiktets": "lasersikte",
    "laserskivan": "laserskiva",
    "laserskivans": "laserskiva",
    "laserskivas": "laserskiva",
    "laserskive": "laserskiva",
    "laserskivor": "laserskiva",
    "laserskivorna": "laserskiva",
    "laserskivornas": "laserskiva",
    "laserskivors": "laserskiva",
    "laserstrålningar": "laserstrålning",
    "laserstrålningarna": "laserstrålning",
    "laserstrålningarnas": "laserstrålning",
    "laserstrålningars": "laserstrålning",
    "laserstrålningen": "laserstrålning",
    "laserstrålningens": "laserstrålning",
    "laserstrålnings": "laserstrålning",
    "laserstyrda": "laserstyrd",
    "laserstyrdare": "laserstyrd",
    "laserstyrdares": "laserstyrd",
    "laserstyrdas": "laserstyrd",
    "laserstyrdast": "laserstyrd",
    "laserstyrdaste": "laserstyrd",
    "laserstyrdastes": "laserstyrd",
    "laserstyrdasts": "laserstyrd",
    "laserstyrde": "laserstyrd",
    "laserstyrdes": "laserstyrd",
    "laserstyrds": "laserstyrd",
    "laserstyrt": "laserstyrd",
    "laserstyrts": "laserstyrd",
    "lasertekniken": "laserteknik",
    "laserteknikens": "laserteknik",
    "lasertekniker": "laserteknik",
    "laserteknikerna": "laserteknik",
    "laserteknikernas": "laserteknik",
    "laserteknikers": "laserteknik",
    "lasertekniks": "laserteknik",
    "lask": "laska",
    "laskad": "laska",
    "laskade": "laska",
    "laskades": "laska",
    "laskads": "laska",
    "laskande": "laska",
    "laskanden": "laskande",
    "laskandena": "laskande",
    "laskandenas": "laskande",
    "laskandens": "laskande",
    "laskandes": "laskande",
    "laskandet": "laskande",
    "laskandets": "laskande",
    "laskar": "laska",
    "laskarna": "lask",
    "laskarnas": "lask",
    "laskars": "lask",
    "laskas": "laska",
    "laskat": "laska",
    "laskats": "laska",
    "lasken": "lask",
    "laskens": "lask",
    "laskningar": "laskning",
    "laskningarna": "laskning",
    "laskningarnas": "laskning",
    "laskningars": "laskning",
    "laskningen": "laskning",
    "laskningens": "laskning",
    "lasknings": "laskning",
    "lasks": "lask",
    "lasrar": "laser",
    "lasrarna": "laser",
    "lasrarnas": "laser",
    "lasrars": "laser",
    "lass": "lassa",
    "lassade": "lassa",
    "lassades": "lassa",
    "lassande": "lassa",
    "lassanden": "lassande",
    "lassandena": "lassande",
    "lassandenas": "lassande",
    "lassandens": "lassande",
    "lassandes": "lassande",
    "lassandet": "lassande",
    "lassandets": "lassande",
    "lassar": "lassa",
    "lassas": "lassa",
    "lassat": "lassa",
    "lassats": "lassa",
    "lassen": "lass",
    "lassens": "lass",
    "lasset": "lass",
    "lassets": "lass",
    "lasson": "lasso",
    "lassona": "lasso",
    "lassonas": "lasso",
    "lassons": "lasso",
    "lassor": "lasso",
    "lassorna": "lasso",
    "lassornas": "lasso",
    "lassors": "lasso",
    "lassos": "lasso",
    "lassot": "lasso",
    "lassots": "lasso",
    "last": "lasta",
    "lastad": "lasta",
    "lastade": "lasta",
    "lastades": "lasta",
    "lastads": "lasta",
    "lastageplatsen": "lastageplats",
    "lastageplatsens": "lastageplats",
    "lastageplatser": "lastageplats",
    "lastageplatserna": "lastageplats",
    "lastageplatsernas": "lastageplats",
    "lastageplatsers": "lastageplats",
    "lastande": "lasta",
    "lastanden": "lastande",
    "lastandena": "lastande",
    "lastandenas": "lastande",
    "lastandens": "lastande",
    "lastandes": "lastande",
    "lastandet": "lastande",
    "lastandets": "lastande",
    "lastar": "lastare",
    "lastaren": "lastare",
    "lastarens": "lastare",
    "lastares": "lastare",
    "lastarna": "lastare",
    "lastarnas": "lastare",
    "lastas": "lasta",
    "lastat": "lasta",
    "lastats": "lasta",
    "lastbara": "lastbar",
    "lastbarare": "lastbar",
    "lastbarares": "lastbar",
    "lastbaras": "lastbar",
    "lastbarast": "lastbar",
    "lastbaraste": "lastbar",
    "lastbarastes": "lastbar",
    "lastbarasts": "lastbar",
    "lastbare": "lastbar",
    "lastbares": "lastbar",
    "lastbarheten": "lastbarhet",
    "lastbarhetens": "lastbarhet",
    "lastbarheter": "lastbarhet",
    "lastbarheterna": "lastbarhet",
    "lastbarheternas": "lastbarhet",
    "lastbarheters": "lastbarhet",
    "lastbarhets": "lastbarhet",
    "lastbars": "lastbar",
    "lastbart": "lastbar",
    "lastbarts": "lastbar",
    "lastbilar": "lastbil",
    "lastbilarna": "lastbil",
    "lastbilarnas": "lastbil",
    "lastbilars": "lastbil",
    "lastbilen": "lastbil",
    "lastbilens": "lastbil",
    "lastbils": "lastbil",
    "lastbilsbaren": "lastbilsbar",
    "lastbilsbarens": "lastbilsbar",
    "lastbilsbarer": "lastbilsbar",
    "lastbilsbarerna": "lastbilsbar",
    "lastbilsbarernas": "lastbilsbar",
    "lastbilsbarers": "lastbilsbar",
    "lastbilsbars": "lastbilsbar",
    "lastbilschauffören": "lastbilschaufför",
    "lastbilschaufförens": "lastbilschaufför",
    "lastbilschaufförer": "lastbilschaufför",
    "lastbilschaufförerna": "lastbilschaufför",
    "lastbilschaufförernas": "lastbilschaufför",
    "lastbilschaufförers": "lastbilschaufför",
    "lastbilschaufförn": "lastbilschaufför",
    "lastbilschaufförns": "lastbilschaufför",
    "lastbilschaufförs": "lastbilschaufför",
    "lastbilsförar": "lastbilsförare",
    "lastbilsföraren": "lastbilsförare",
    "lastbilsförarens": "lastbilsförare",
    "lastbilsförares": "lastbilsförare",
    "lastbilsförarna": "lastbilsförare",
    "lastbilsförarnas": "lastbilsförare",
    "lastbilskrockar": "lastbilskrock",
    "lastbilskrockarna": "lastbilskrock",
    "lastbilskrockarnas": "lastbilskrock",
    "lastbilskrockars": "lastbilskrock",
    "lastbilskrocken": "lastbilskrock",
    "lastbilskrockens": "lastbilskrock",
    "lastbilskrocks": "lastbilskrock",
    "lastbilslassen": "lastbilslass",
    "lastbilslassens": "lastbilslass",
    "lastbilslasset": "lastbilslass",
    "lastbilslassets": "lastbilslass",
    "lastbilstransporten": "lastbilstransport",
    "lastbilstransportens": "lastbilstransport",
    "lastbilstransporter": "lastbilstransport",
    "lastbilstransporterna": "lastbilstransport",
    "lastbilstransporternas": "lastbilstransport",
    "lastbilstransporters": "lastbilstransport",
    "lastbilstransports": "lastbilstransport",
    "lastbrygg": "lastbrygga",
    "lastbryggan": "lastbrygga",
    "lastbryggans": "lastbrygga",
    "lastbryggas": "lastbrygga",
    "lastbrygge": "lastbrygga",
    "lastbryggor": "lastbrygga",
    "lastbryggorna": "lastbrygga",
    "lastbryggornas": "lastbrygga",
    "lastbryggors": "lastbrygga",
    "lastbryggs": "lastbrygga",
    "lastdjuren": "lastdjur",
    "lastdjurens": "lastdjur",
    "lastdjuret": "lastdjur",
    "lastdjurets": "lastdjur",
    "lastdjurs": "lastdjur",
    "lastdryga": "lastdryg",
    "lastdrygare": "lastdryg",
    "lastdrygares": "lastdryg",
    "lastdrygas": "lastdryg",
    "lastdrygast": "lastdryg",
    "lastdrygaste": "lastdryg",
    "lastdrygastes": "lastdryg",
    "lastdrygasts": "lastdryg",
    "lastdryge": "lastdryg",
    "lastdryges": "lastdryg",
    "lastdrygs": "lastdryg",
    "lastdrygt": "lastdryg",
    "lastdrygts": "lastdryg",
    "lasteliga": "lastelig",
    "lasteligare": "lastelig",
    "lasteligares": "lastelig",
    "lasteligas": "lastelig",
    "lasteligast": "lastelig",
    "lasteligaste": "lastelig",
    "lasteligastes": "lastelig",
    "lasteligasts": "lastelig",
    "lastelige": "lastelig",
    "lasteliges": "lastelig",
    "lasteligheten": "lastelighet",
    "lastelighetens": "lastelighet",
    "lastelighets": "lastelighet",
    "lasteligs": "lastelig",
    "lasteligt": "lastelig",
    "lasteligts": "lastelig",
    "lasten": "last",
    "lastens": "last",
    "laster": "last",
    "lasterna": "last",
    "lasternas": "last",
    "lasters": "last",
    "lastfartygen": "lastfartyg",
    "lastfartygens": "lastfartyg",
    "lastfartyget": "lastfartyg",
    "lastfartygets": "lastfartyg",
    "lastfartygs": "lastfartyg",
    "lastflaken": "lastflak",
    "lastflakens": "lastflak",
    "lastflaket": "lastflak",
    "lastflakets": "lastflak",
    "lastflaks": "lastflak",
    "lastfulla": "lastfull",
    "lastfullare": "lastfull",
    "lastfullares": "lastfull",
    "lastfullas": "lastfull",
    "lastfullast": "lastfull",
    "lastfullaste": "lastfull",
    "lastfullastes": "lastfull",
    "lastfullasts": "lastfull",
    "lastfulle": "lastfull",
    "lastfulles": "lastfull",
    "lastfullheten": "lastfullhet",
    "lastfullhetens": "lastfullhet",
    "lastfullhets": "lastfullhet",
    "lastfulls": "lastfull",
    "lastfullt": "lastfull",
    "lastfullts": "lastfull",
    "lastgallerna": "lastgaller",
    "lastgallernas": "lastgaller",
    "lastgallers": "lastgaller",
    "lastgallren": "lastgaller",
    "lastgallrens": "lastgaller",
    "lastgallret": "lastgaller",
    "lastgallrets": "lastgaller",
    "lastgamla": "lastgammal",
    "lastgamlas": "lastgammal",
    "lastgamle": "lastgammal",
    "lastgamles": "lastgammal",
    "lastgammals": "lastgammal",
    "lastgammalt": "lastgammal",
    "lastgammalts": "lastgammal",
    "lasthållar": "lasthållare",
    "lasthållaren": "lasthållare",
    "lasthållarens": "lasthållare",
    "lasthållares": "lasthållare",
    "lasthållarna": "lasthållare",
    "lasthållarnas": "lasthållare",
    "lastingen": "lasting",
    "lastingens": "lasting",
    "lastings": "lasting",
    "lastklara": "lastklar",
    "lastklarare": "lastklar",
    "lastklarares": "lastklar",
    "lastklaras": "lastklar",
    "lastklarast": "lastklar",
    "lastklaraste": "lastklar",
    "lastklarastes": "lastklar",
    "lastklarasts": "lastklar",
    "lastklare": "lastklar",
    "lastklares": "lastklar",
    "lastklars": "lastklar",
    "lastklart": "lastklar",
    "lastklarts": "lastklar",
    "lastkranar": "lastkran",
    "lastkranarna": "lastkran",
    "lastkranarnas": "lastkran",
    "lastkranars": "lastkran",
    "lastkranen": "lastkran",
    "lastkranens": "lastkran",
    "lastkrans": "lastkran",
    "lastlinjen": "lastlinje",
    "lastlinjens": "lastlinje",
    "lastlinjer": "lastlinje",
    "lastlinjerna": "lastlinje",
    "lastlinjernas": "lastlinje",
    "lastlinjers": "lastlinje",
    "lastlinjes": "lastlinje",
    "lastluck": "lastlucka",
    "lastluckan": "lastlucka",
    "lastluckans": "lastlucka",
    "lastluckas": "lastlucka",
    "lastlucke": "lastlucka",
    "lastluckor": "lastlucka",
    "lastluckorna": "lastlucka",
    "lastluckornas": "lastlucka",
    "lastluckors": "lastlucka",
    "lastlucks": "lastlucka",
    "lastmaskinen": "lastmaskin",
    "lastmaskinens": "lastmaskin",
    "lastmaskiner": "lastmaskin",
    "lastmaskinerna": "lastmaskin",
    "lastmaskinernas": "lastmaskin",
    "lastmaskiners": "lastmaskin",
    "lastmaskins": "lastmaskin",
    "lastningar": "lastning",
    "lastningarna": "lastning",
    "lastningarnas": "lastning",
    "lastningars": "lastning",
    "lastningen": "lastning",
    "lastningens": "lastning",
    "lastnings": "lastning",
    "lastnäten": "lastnät",
    "lastnätens": "lastnät",
    "lastnätet": "lastnät",
    "lastnätets": "lastnät",
    "lastnäts": "lastnät",
    "lastpallar": "lastpall",
    "lastpallarna": "lastpall",
    "lastpallarnas": "lastpall",
    "lastpallars": "lastpall",
    "lastpallen": "lastpall",
    "lastpallens": "lastpall",
    "lastpalls": "lastpall",
    "lastplatt": "lastplatta",
    "lastplattan": "lastplatta",
    "lastplattans": "lastplatta",
    "lastplattas": "lastplatta",
    "lastplatte": "lastplatta",
    "lastplattor": "lastplatta",
    "lastplattorna": "lastplatta",
    "lastplattornas": "lastplatta",
    "lastplattors": "lastplatta",
    "lastplatts": "lastplatta",
    "lastportar": "lastport",
    "lastportarna": "lastport",
    "lastportarnas": "lastport",
    "lastportars": "lastport",
    "lastporten": "lastport",
    "lastportens": "lastport",
    "lastports": "lastport",
    "lastprofilen": "lastprofil",
    "lastprofilens": "lastprofil",
    "lastprofiler": "lastprofil",
    "lastprofilerna": "lastprofil",
    "lastprofilernas": "lastprofil",
    "lastprofilers": "lastprofil",
    "lastprofils": "lastprofil",
    "lastrummen": "lastrum",
    "lastrummens": "lastrum",
    "lastrummet": "lastrum",
    "lastrummets": "lastrum",
    "lastrums": "lastrum",
    "lasts": "last",
    "lastvattenlinjen": "lastvattenlinje",
    "lastvattenlinjens": "lastvattenlinje",
    "lastvattenlinjer": "lastvattenlinje",
    "lastvattenlinjerna": "lastvattenlinje",
    "lastvattenlinjernas": "lastvattenlinje",
    "lastvattenlinjers": "lastvattenlinje",
    "lastvattenlinjes": "lastvattenlinje",
    "lastytan": "lastyta",
    "lastytans": "lastyta",
    "lastytas": "lastyta",
    "lastyte": "lastyta",
    "lastytor": "lastyta",
    "lastytorna": "lastyta",
    "lastytornas": "lastyta",
    "lastytors": "lastyta",
    "lastzonen": "lastzon",
    "lastzonens": "lastzon",
    "lastzoner": "lastzon",
    "lastzonerna": "lastzon",
    "lastzonernas": "lastzon",
    "lastzoners": "lastzon",
    "lastzons": "lastzon",
    "laståsnan": "laståsna",
    "laståsnans": "laståsna",
    "laståsnas": "laståsna",
    "laståsne": "laståsna",
    "laståsnor": "laståsna",
    "laståsnorna": "laståsna",
    "laståsnornas": "laståsna",
    "laståsnors": "laståsna",
    "lasuren": "lasur",
    "lasurens": "lasur",
    "lasurer": "lasur",
    "lasurerna": "lasur",
    "lasurernas": "lasur",
    "lasurers": "lasur",
    "lasurs": "lasur",
    "lasyren": "lasyr",
    "lasyrens": "lasyr",
    "lasyrer": "lasyr",
    "lasyrerna": "lasyr",
    "lasyrernas": "lasyr",
    "lasyrers": "lasyr",
    "lasyrs": "lasyr",
    "lat": "later",
    "lata": "lat",
    "latare": "lat",
    "latares": "lat",
    "latas": "lat",
    "latast": "lat",
    "lataste": "lat",
    "latastes": "lat",
    "latasts": "lat",
    "late": "lat",
    "latensen": "latens",
    "latensens": "latens",
    "latenstiden": "latenstid",
    "latenstidens": "latenstid",
    "latenstider": "latenstid",
    "latenstiderna": "latenstid",
    "latenstidernas": "latenstid",
    "latenstiders": "latenstid",
    "latenstids": "latenstid",
    "latenta": "latent",
    "latentare": "latent",
    "latentares": "latent",
    "latentas": "latent",
    "latentast": "latent",
    "latentaste": "latent",
    "latentastes": "latent",
    "latentasts": "latent",
    "latente": "latent",
    "latentes": "latent",
    "latentheten": "latenthet",
    "latenthetens": "latenthet",
    "latenthets": "latenthet",
    "latents": "latent",
    "laterala": "lateral",
    "lateralare": "lateral",
    "lateralares": "lateral",
    "lateralas": "lateral",
    "lateralast": "lateral",
    "lateralaste": "lateral",
    "lateralastes": "lateral",
    "lateralasts": "lateral",
    "laterale": "lateral",
    "lateralen": "lateral",
    "lateralens": "lateral",
    "lateraler": "lateral",
    "lateralerna": "lateral",
    "lateralernas": "lateral",
    "lateralers": "lateral",
    "laterales": "lateral",
    "laterals": "lateral",
    "lateralt": "lateral",
    "lateralts": "lateral",
    "laterna": "later",
    "laternas": "later",
    "laters": "later",
    "lates": "lat",
    "latexen": "latex",
    "latexens": "latex",
    "latexet": "latex",
    "latexets": "latex",
    "latexmålningar": "latexmålning",
    "latexmålningarna": "latexmålning",
    "latexmålningarnas": "latexmålning",
    "latexmålningars": "latexmålning",
    "latexmålningen": "latexmålning",
    "latexmålningens": "latexmålning",
    "latexmålnings": "latexmålning",
    "latheten": "lathet",
    "lathetens": "lathet",
    "lathets": "lathet",
    "lathundar": "lathund",
    "lathundarna": "lathund",
    "lathundarnas": "lathund",
    "lathundars": "lathund",
    "lathunden": "lathund",
    "lathundens": "lathund",
    "lathunds": "lathund",
    "latin-amerikanska": "latin-amerikansk",
    "latin-amerikanskare": "latin-amerikansk",
    "latin-amerikanskares": "latin-amerikansk",
    "latin-amerikanskas": "latin-amerikansk",
    "latin-amerikanskast": "latin-amerikansk",
    "latin-amerikanskaste": "latin-amerikansk",
    "latin-amerikanskastes": "latin-amerikansk",
    "latin-amerikanskasts": "latin-amerikansk",
    "latin-amerikanske": "latin-amerikansk",
    "latin-amerikanskes": "latin-amerikansk",
    "latin-amerikansks": "latin-amerikansk",
    "latin-amerikanskt": "latin-amerikansk",
    "latin-amerikanskts": "latin-amerikansk",
    "latinamerikanen": "latinamerikan",
    "latinamerikanens": "latinamerikan",
    "latinamerikaner": "latinamerikan",
    "latinamerikanerna": "latinamerikan",
    "latinamerikanernas": "latinamerikan",
    "latinamerikaners": "latinamerikan",
    "latinamerikans": "latinamerikan",
    "latinamerikanska": "latinamerikansk",
    "latinamerikanskan": "latinamerikanska",
    "latinamerikanskans": "latinamerikanska",
    "latinamerikanskare": "latinamerikansk",
    "latinamerikanskares": "latinamerikansk",
    "latinamerikanskas": "latinamerikanska",
    "latinamerikanskast": "latinamerikansk",
    "latinamerikanskaste": "latinamerikansk",
    "latinamerikanskastes": "latinamerikansk",
    "latinamerikanskasts": "latinamerikansk",
    "latinamerikanske": "latinamerikanska",
    "latinamerikanskes": "latinamerikansk",
    "latinamerikanskor": "latinamerikanska",
    "latinamerikanskorna": "latinamerikanska",
    "latinamerikanskornas": "latinamerikanska",
    "latinamerikanskors": "latinamerikanska",
    "latinamerikansks": "latinamerikansk",
    "latinamerikanskt": "latinamerikansk",
    "latinamerikanskts": "latinamerikansk",
    "latinar": "latinare",
    "latinaren": "latinare",
    "latinarens": "latinare",
    "latinares": "latinare",
    "latinarna": "latinare",
    "latinarnas": "latinare",
    "latinet": "latin",
    "latinets": "latin",
    "latiniserad": "latinisera",
    "latiniserade": "latinisera",
    "latiniserades": "latinisera",
    "latiniserads": "latinisera",
    "latiniserande": "latinisera",
    "latiniseranden": "latiniserande",
    "latiniserandena": "latiniserande",
    "latiniserandenas": "latiniserande",
    "latiniserandens": "latiniserande",
    "latiniserandes": "latiniserande",
    "latiniserandet": "latiniserande",
    "latiniserandets": "latiniserande",
    "latiniserar": "latinisera",
    "latiniseras": "latinisera",
    "latiniserat": "latinisera",
    "latiniserats": "latinisera",
    "latiniserbara": "latiniserbar",
    "latiniserbarare": "latiniserbar",
    "latiniserbarares": "latiniserbar",
    "latiniserbaras": "latiniserbar",
    "latiniserbarast": "latiniserbar",
    "latiniserbaraste": "latiniserbar",
    "latiniserbarastes": "latiniserbar",
    "latiniserbarasts": "latiniserbar",
    "latiniserbare": "latiniserbar",
    "latiniserbares": "latiniserbar",
    "latiniserbarheten": "latiniserbarhet",
    "latiniserbarhetens": "latiniserbarhet",
    "latiniserbarhets": "latiniserbarhet",
    "latiniserbars": "latiniserbar",
    "latiniserbart": "latiniserbar",
    "latiniserbarts": "latiniserbar",
    "latiniseringar": "latinisering",
    "latiniseringarna": "latinisering",
    "latiniseringarnas": "latinisering",
    "latiniseringars": "latinisering",
    "latiniseringen": "latinisering",
    "latiniseringens": "latinisering",
    "latiniserings": "latinisering",
    "latinismen": "latinism",
    "latinismens": "latinism",
    "latinismer": "latinism",
    "latinismerna": "latinism",
    "latinismernas": "latinism",
    "latinismers": "latinism",
    "latinisms": "latinism",
    "latinkunniga": "latinkunnig",
    "latinkunnigare": "latinkunnig",
    "latinkunnigares": "latinkunnig",
    "latinkunnigas": "latinkunnig",
    "latinkunnigast": "latinkunnig",
    "latinkunnigaste": "latinkunnig",
    "latinkunnigastes": "latinkunnig",
    "latinkunnigasts": "latinkunnig",
    "latinkunnige": "latinkunnig",
    "latinkunniges": "latinkunnig",
    "latinkunnigheten": "latinkunnighet",
    "latinkunnighetens": "latinkunnighet",
    "latinkunnighets": "latinkunnighet",
    "latinkunnigs": "latinkunnig",
    "latinkunnigt": "latinkunnig",
    "latinkunnigts": "latinkunnig",
    "latinlektorer": "latinlektor",
    "latinlektorerna": "latinlektor",
    "latinlektorernas": "latinlektor",
    "latinlektorers": "latinlektor",
    "latinlektorn": "latinlektor",
    "latinlektorns": "latinlektor",
    "latinlektors": "latinlektor",
    "latinlinjen": "latinlinje",
    "latinlinjens": "latinlinje",
    "latinlinjer": "latinlinje",
    "latinlinjerna": "latinlinje",
    "latinlinjernas": "latinlinje",
    "latinlinjers": "latinlinje",
    "latinlinjes": "latinlinje",
    "latinläroverken": "latinläroverk",
    "latinläroverkens": "latinläroverk",
    "latinläroverket": "latinläroverk",
    "latinläroverkets": "latinläroverk",
    "latinläroverks": "latinläroverk",
    "latins": "latin",
    "latinsegels": "latinsegel",
    "latinseglen": "latinsegel",
    "latinseglens": "latinsegel",
    "latinseglet": "latinsegel",
    "latinseglets": "latinsegel",
    "latinska": "latinsk",
    "latinskare": "latinsk",
    "latinskares": "latinsk",
    "latinskas": "latinsk",
    "latinskast": "latinsk",
    "latinskaste": "latinsk",
    "latinskastes": "latinsk",
    "latinskasts": "latinsk",
    "latinske": "latinsk",
    "latinskes": "latinsk",
    "latinsks": "latinsk",
    "latinskt": "latinsk",
    "latinskts": "latinsk",
    "latituden": "latitud",
    "latitudens": "latitud",
    "latituder": "latitud",
    "latituderna": "latitud",
    "latitudernas": "latitud",
    "latituders": "latitud",
    "latituds": "latitud",
    "lativen": "lativ",
    "lativens": "lativ",
    "lativer": "lativ",
    "lativerna": "lativ",
    "lativernas": "lativ",
    "lativers": "lativ",
    "lativs": "lativ",
    "latmaskar": "latmask",
    "latmaskarna": "latmask",
    "latmaskarnas": "latmask",
    "latmaskars": "latmask",
    "latmasken": "latmask",
    "latmaskens": "latmask",
    "latmasks": "latmask",
    "latrinen": "latrin",
    "latrinens": "latrin",
    "latriner": "latrin",
    "latrinerna": "latrin",
    "latrinernas": "latrin",
    "latriners": "latrin",
    "latrins": "latrin",
    "lats": "later",
    "latt": "latta",
    "lattan": "latta",
    "lattans": "latta",
    "lattar": "latte",
    "lattarna": "latte",
    "lattarnas": "latte",
    "lattars": "latte",
    "lattas": "latta",
    "latte": "latta",
    "lattebaren": "lattebar",
    "lattebarens": "lattebar",
    "lattebarer": "lattebar",
    "lattebarerna": "lattebar",
    "lattebarernas": "lattebar",
    "lattebarers": "lattebar",
    "lattebars": "lattebar",
    "latten": "latte",
    "lattena": "latte",
    "lattenas": "latte",
    "lattens": "latte",
    "lattes": "latte",
    "lattesarna": "latte",
    "lattesarnas": "latte",
    "lattjade": "lattja",
    "lattjades": "lattja",
    "lattjande": "lattja",
    "lattjanden": "lattjande",
    "lattjandena": "lattjande",
    "lattjandenas": "lattjande",
    "lattjandens": "lattjande",
    "lattjandes": "lattjande",
    "lattjandet": "lattjande",
    "lattjandets": "lattjande",
    "lattjar": "lattja",
    "lattjas": "lattja",
    "lattjat": "lattja",
    "lattjats": "lattja",
    "lattor": "latta",
    "lattorna": "latta",
    "lattornas": "latta",
    "lattors": "latta",
    "latts": "latta",
    "laudatren": "laudatur",
    "laudatrens": "laudatur",
    "laudatret": "laudatur",
    "laudatrets": "laudatur",
    "laudaturen": "laudatur",
    "laudaturens": "laudatur",
    "laudaturet": "laudatur",
    "laudaturets": "laudatur",
    "laudaturs": "laudatur",
    "laur": "laura",
    "lauran": "laura",
    "laurans": "laura",
    "lauras": "laura",
    "laure": "laura",
    "laurentiet": "laurentium",
    "laurentiets": "laurentium",
    "laurentiumet": "laurentium",
    "laurentiumets": "laurentium",
    "laurentiums": "laurentium",
    "lauror": "laura",
    "laurorna": "laura",
    "laurornas": "laura",
    "laurors": "laura",
    "laurs": "laura",
    "lav": "lave",
    "lavaflöden": "lavaflöde",
    "lavaflödena": "lavaflöde",
    "lavaflödenas": "lavaflöde",
    "lavaflödens": "lavaflöde",
    "lavaflödes": "lavaflöde",
    "lavaflödet": "lavaflöde",
    "lavaflödets": "lavaflöde",
    "lavafälten": "lavafält",
    "lavafältens": "lavafält",
    "lavafältet": "lavafält",
    "lavafältets": "lavafält",
    "lavafälts": "lavafält",
    "lavan": "lava",
    "lavans": "lava",
    "lavar": "lave",
    "lavarna": "lave",
    "lavarnas": "lave",
    "lavars": "lave",
    "lavas": "lava",
    "lavasjöar": "lavasjö",
    "lavasjöarna": "lavasjö",
    "lavasjöarnas": "lavasjö",
    "lavasjöars": "lavasjö",
    "lavasjön": "lavasjö",
    "lavasjöns": "lavasjö",
    "lavasjös": "lavasjö",
    "lave": "lava",
    "lavemangen": "lavemang",
    "lavemangens": "lavemang",
    "lavemanget": "lavemang",
    "lavemangets": "lavemang",
    "lavemangs": "lavemang",
    "laven": "lave",
    "lavendelblåa": "lavendelblå",
    "lavendelblåare": "lavendelblå",
    "lavendelblåares": "lavendelblå",
    "lavendelblåas": "lavendelblå",
    "lavendelblåast": "lavendelblå",
    "lavendelblåaste": "lavendelblå",
    "lavendelblåastes": "lavendelblå",
    "lavendelblåasts": "lavendelblå",
    "lavendelblåe": "lavendelblå",
    "lavendelblåes": "lavendelblå",
    "lavendelblås": "lavendelblå",
    "lavendelblått": "lavendelblå",
    "lavendelblåtts": "lavendelblå",
    "lavendelfärgade": "lavendelfärgad",
    "lavendelfärgades": "lavendelfärgad",
    "lavendelfärgads": "lavendelfärgad",
    "lavendelfärgat": "lavendelfärgad",
    "lavendelfärgats": "lavendelfärgad",
    "lavendeln": "lavendel",
    "lavendelns": "lavendel",
    "lavendels": "lavendel",
    "lavendeltvålar": "lavendeltvål",
    "lavendeltvålarna": "lavendeltvål",
    "lavendeltvålarnas": "lavendeltvål",
    "lavendeltvålars": "lavendeltvål",
    "lavendeltvålen": "lavendeltvål",
    "lavendeltvålens": "lavendeltvål",
    "lavendeltvåls": "lavendeltvål",
    "lavens": "lave",
    "laverad": "lavera",
    "laverade": "lavera",
    "laverades": "lavera",
    "laverads": "lavera",
    "laverande": "lavera",
    "laveranden": "laverande",
    "laverandena": "laverande",
    "laverandenas": "laverande",
    "laverandens": "laverande",
    "laverandes": "laverande",
    "laverandet": "laverande",
    "laverandets": "laverande",
    "laverar": "lavera",
    "laveras": "lavera",
    "laverat": "lavera",
    "laverats": "lavera",
    "laverbara": "laverbar",
    "laverbarare": "laverbar",
    "laverbarares": "laverbar",
    "laverbaras": "laverbar",
    "laverbarast": "laverbar",
    "laverbaraste": "laverbar",
    "laverbarastes": "laverbar",
    "laverbarasts": "laverbar",
    "laverbare": "laverbar",
    "laverbares": "laverbar",
    "laverbarheten": "laverbarhet",
    "laverbarhetens": "laverbarhet",
    "laverbarhets": "laverbarhet",
    "laverbars": "laverbar",
    "laverbart": "laverbar",
    "laverbarts": "laverbar",
    "laveringar": "lavering",
    "laveringarna": "lavering",
    "laveringarnas": "lavering",
    "laveringars": "lavering",
    "laveringen": "lavering",
    "laveringens": "lavering",
    "laverings": "lavering",
    "laves": "lave",
    "lavetten": "lavett",
    "lavettens": "lavett",
    "lavetter": "lavett",
    "lavetterna": "lavett",
    "lavetternas": "lavett",
    "lavetters": "lavett",
    "lavetts": "lavett",
    "lavinartade": "lavinartad",
    "lavinartades": "lavinartad",
    "lavinartads": "lavinartad",
    "lavinartat": "lavinartad",
    "lavinartats": "lavinartad",
    "lavinen": "lavin",
    "lavinens": "lavin",
    "laviner": "lavin",
    "lavinerna": "lavin",
    "lavinernas": "lavin",
    "laviners": "lavin",
    "lavinhundar": "lavinhund",
    "lavinhundarna": "lavinhund",
    "lavinhundarnas": "lavinhund",
    "lavinhundars": "lavinhund",
    "lavinhunden": "lavinhund",
    "lavinhundens": "lavinhund",
    "lavinhunds": "lavinhund",
    "lavins": "lavin",
    "lavoaren": "lavoar",
    "lavoarens": "lavoar",
    "lavoarer": "lavoar",
    "lavoarerna": "lavoar",
    "lavoarernas": "lavoar",
    "lavoarers": "lavoar",
    "lavoars": "lavoar",
    "lavor": "lava",
    "lavorna": "lava",
    "lavornas": "lava",
    "lavors": "lava",
    "lavregionen": "lavregion",
    "lavregionens": "lavregion",
    "lavregioner": "lavregion",
    "lavregionerna": "lavregion",
    "lavregionernas": "lavregion",
    "lavregioners": "lavregion",
    "lavregions": "lavregion",
    "lavs": "lave",
    "lavskrik": "lavskrika",
    "lavskrikan": "lavskrika",
    "lavskrikans": "lavskrika",
    "lavskrikas": "lavskrika",
    "lavskrike": "lavskrika",
    "lavskrikor": "lavskrika",
    "lavskrikorna": "lavskrika",
    "lavskrikornas": "lavskrika",
    "lavskrikors": "lavskrika",
    "lavskriks": "lavskrika",
    "lavyren": "lavyr",
    "lavyrens": "lavyr",
    "lavyrer": "lavyr",
    "lavyrerna": "lavyr",
    "lavyrernas": "lavyr",
    "lavyrers": "lavyr",
    "lavyrs": "lavyr",
    "lax": "laxa",
    "laxad": "laxa",
    "laxade": "laxa",
    "laxades": "laxa",
    "laxads": "laxa",
    "laxande": "laxa",
    "laxanden": "laxande",
    "laxandena": "laxande",
    "laxandenas": "laxande",
    "laxandens": "laxande",
    "laxandes": "laxande",
    "laxandet": "laxande",
    "laxandets": "laxande",
    "laxar": "laxa",
    "laxarna": "lax",
    "laxarnas": "lax",
    "laxars": "lax",
    "laxas": "laxa",
    "laxat": "laxa",
    "laxativen": "laxativ",
    "laxativens": "laxativ",
    "laxativet": "laxativ",
    "laxativets": "laxativ",
    "laxativs": "laxativ",
    "laxats": "laxa",
    "laxen": "lax",
    "laxens": "lax",
    "laxer": "laxera",
    "laxerade": "laxera",
    "laxerades": "laxera",
    "laxerande": "laxera",
    "laxeranden": "laxerande",
    "laxerandena": "laxerande",
    "laxerandenas": "laxerande",
    "laxerandens": "laxerande",
    "laxerandes": "laxerande",
    "laxerandet": "laxerande",
    "laxerandets": "laxerande",
    "laxerar": "laxera",
    "laxeras": "laxera",
    "laxerat": "laxera",
    "laxerats": "laxera",
    "laxeringar": "laxering",
    "laxeringarna": "laxering",
    "laxeringarnas": "laxering",
    "laxeringars": "laxering",
    "laxeringen": "laxering",
    "laxeringens": "laxering",
    "laxerings": "laxering",
    "laxermedels": "laxermedel",
    "laxermedlen": "laxermedel",
    "laxermedlens": "laxermedel",
    "laxermedlet": "laxermedel",
    "laxermedlets": "laxermedel",
    "laxerpillerna": "laxerpiller",
    "laxerpillernas": "laxerpiller",
    "laxerpillers": "laxerpiller",
    "laxerpillren": "laxerpiller",
    "laxerpillrens": "laxerpiller",
    "laxerpillret": "laxerpiller",
    "laxerpillrets": "laxerpiller",
    "laxfileer": "laxfile",
    "laxfileerna": "laxfile",
    "laxfileernas": "laxfile",
    "laxfileers": "laxfile",
    "laxfilen": "laxfile",
    "laxfilens": "laxfile",
    "laxfiles": "laxfile",
    "laxfiléer": "laxfilé",
    "laxfiléerna": "laxfilé",
    "laxfiléernas": "laxfilé",
    "laxfiléers": "laxfilé",
    "laxfilén": "laxfilé",
    "laxfiléns": "laxfilé",
    "laxfilés": "laxfilé",
    "laxfiskar": "laxfisk",
    "laxfiskarna": "laxfisk",
    "laxfiskarnas": "laxfisk",
    "laxfiskars": "laxfisk",
    "laxfisken": "laxfisk",
    "laxfiskens": "laxfisk",
    "laxfisks": "laxfisk",
    "laxfärgade": "laxfärgad",
    "laxfärgades": "laxfärgad",
    "laxfärgads": "laxfärgad",
    "laxfärgat": "laxfärgad",
    "laxfärgats": "laxfärgad",
    "laxfärgen": "laxfärg",
    "laxfärgens": "laxfärg",
    "laxfärger": "laxfärg",
    "laxfärgerna": "laxfärg",
    "laxfärgernas": "laxfärg",
    "laxfärgers": "laxfärg",
    "laxfärgs": "laxfärg",
    "laxgårdar": "laxgård",
    "laxgårdarna": "laxgård",
    "laxgårdarnas": "laxgård",
    "laxgårdars": "laxgård",
    "laxgården": "laxgård",
    "laxgårdens": "laxgård",
    "laxgårds": "laxgård",
    "laxkaren": "laxkar",
    "laxkarens": "laxkar",
    "laxkaret": "laxkar",
    "laxkarets": "laxkar",
    "laxkars": "laxkar",
    "laxkist": "laxkista",
    "laxkistan": "laxkista",
    "laxkistans": "laxkista",
    "laxkistas": "laxkista",
    "laxkiste": "laxkista",
    "laxkistor": "laxkista",
    "laxkistorna": "laxkista",
    "laxkistornas": "laxkista",
    "laxkistors": "laxkista",
    "laxränn": "laxränna",
    "laxrännan": "laxränna",
    "laxrännans": "laxränna",
    "laxrännas": "laxränna",
    "laxränne": "laxränna",
    "laxrännor": "laxränna",
    "laxrännorna": "laxränna",
    "laxrännornas": "laxränna",
    "laxrännors": "laxränna",
    "laxränns": "laxränna",
    "laxsidan": "laxsida",
    "laxsidans": "laxsida",
    "laxsidas": "laxsida",
    "laxside": "laxsida",
    "laxsides": "laxsida",
    "laxsidor": "laxsida",
    "laxsidorna": "laxsida",
    "laxsidornas": "laxsida",
    "laxsidors": "laxsida",
    "laxstjärtar": "laxstjärt",
    "laxstjärtarna": "laxstjärt",
    "laxstjärtarnas": "laxstjärt",
    "laxstjärtars": "laxstjärt",
    "laxstjärten": "laxstjärt",
    "laxstjärtens": "laxstjärt",
    "laxstjärts": "laxstjärt",
    "laxtrapp": "laxtrappa",
    "laxtrappan": "laxtrappa",
    "laxtrappans": "laxtrappa",
    "laxtrappas": "laxtrappa",
    "laxtrappe": "laxtrappa",
    "laxtrappor": "laxtrappa",
    "laxtrapporna": "laxtrappa",
    "laxtrappornas": "laxtrappa",
    "laxtrappors": "laxtrappa",
    "laxtrapps": "laxtrappa",
    "laxyngels": "laxyngel",
    "laxynglen": "laxyngel",
    "laxynglens": "laxyngel",
    "laxynglet": "laxyngel",
    "laxynglets": "laxyngel",
    "laxöringar": "laxöring",
    "laxöringarna": "laxöring",
    "laxöringarnas": "laxöring",
    "laxöringars": "laxöring",
    "laxöringen": "laxöring",
    "laxöringens": "laxöring",
    "laxörings": "laxöring",
    "layoutchefen": "layoutchef",
    "layoutchefens": "layoutchef",
    "layoutchefer": "layoutchef",
    "layoutcheferna": "layoutchef",
    "layoutchefernas": "layoutchef",
    "layoutchefers": "layoutchef",
    "layoutchefs": "layoutchef",
    "layouten": "layout",
    "layoutens": "layout",
    "layouter": "layout",
    "layouterna": "layout",
    "layouternas": "layout",
    "layouters": "layout",
    "layoutmässiga": "layoutmässig",
    "layoutmässigare": "layoutmässig",
    "layoutmässigares": "layoutmässig",
    "layoutmässigas": "layoutmässig",
    "layoutmässigast": "layoutmässig",
    "layoutmässigaste": "layoutmässig",
    "layoutmässigastes": "layoutmässig",
    "layoutmässigasts": "layoutmässig",
    "layoutmässige": "layoutmässig",
    "layoutmässiges": "layoutmässig",
    "layoutmässigs": "layoutmässig",
    "layoutmässigt": "layoutmässig",
    "layoutmässigts": "layoutmässig",
    "layouts": "layout",
    "lazzaronen": "lazzaron",
    "lazzaronens": "lazzaron",
    "lazzaroner": "lazzaron",
    "lazzaronerna": "lazzaron",
    "lazzaronernas": "lazzaron",
    "lazzaroners": "lazzaron",
    "lazzarons": "lazzaron",
    "lea": "le",
    "lealösa": "lealös",
    "lealösare": "lealös",
    "lealösares": "lealös",
    "lealösas": "lealös",
    "lealösast": "lealös",
    "lealösaste": "lealös",
    "lealösastes": "lealös",
    "lealösasts": "lealös",
    "lealöse": "lealös",
    "lealöses": "lealös",
    "lealösheten": "lealöshet",
    "lealöshetens": "lealöshet",
    "lealöshets": "lealöshet",
    "lealöst": "lealös",
    "lealösts": "lealös",
    "leare": "le",
    "leares": "le",
    "leas": "leasa",
    "leasad": "leasa",
    "leasade": "leasa",
    "leasades": "leasa",
    "leasads": "leasa",
    "leasande": "leasa",
    "leasanden": "leasande",
    "leasandena": "leasande",
    "leasandenas": "leasande",
    "leasandens": "leasande",
    "leasandes": "leasande",
    "leasandet": "leasande",
    "leasandets": "leasande",
    "leasar": "leasa",
    "leasas": "leasa",
    "leasat": "leasa",
    "leasats": "leasa",
    "leasingar": "leasing",
    "leasingarna": "leasing",
    "leasingarnas": "leasing",
    "leasingars": "leasing",
    "leasingen": "leasing",
    "leasingens": "leasing",
    "leasings": "leasing",
    "least": "le",
    "leaste": "le",
    "leastes": "le",
    "leasts": "le",
    "lebemannen": "lebeman",
    "lebemannens": "lebeman",
    "lebemans": "lebeman",
    "lebemän": "lebeman",
    "lebemännen": "lebeman",
    "lebemännens": "lebeman",
    "lebemäns": "lebeman",
    "lecitinen": "lecitin",
    "lecitinens": "lecitin",
    "lecitiner": "lecitin",
    "lecitinerna": "lecitin",
    "lecitinernas": "lecitin",
    "lecitiners": "lecitin",
    "lecitinet": "lecitin",
    "lecitinets": "lecitin",
    "lecitins": "lecitin",
    "led": "lida",
    "leda": "led",
    "ledad": "leda",
    "ledade": "ledad",
    "ledades": "ledad",
    "ledads": "ledad",
    "ledamoten": "ledamot",
    "ledamotens": "ledamot",
    "ledamots": "ledamot",
    "ledamöter": "ledamot",
    "ledamöterna": "ledamot",
    "ledamöternas": "ledamot",
    "ledamöters": "ledamot",
    "ledan": "leda",
    "ledande": "leda",
    "ledanden": "ledande",
    "ledandena": "ledande",
    "ledandenas": "ledande",
    "ledandens": "ledande",
    "ledandes": "ledande",
    "ledandet": "ledande",
    "ledandets": "ledande",
    "ledans": "leda",
    "ledar": "ledare",
    "ledarbegåvningar": "ledarbegåvning",
    "ledarbegåvningarna": "ledarbegåvning",
    "ledarbegåvningarnas": "ledarbegåvning",
    "ledarbegåvningars": "ledarbegåvning",
    "ledarbegåvningen": "ledarbegåvning",
    "ledarbegåvningens": "ledarbegåvning",
    "ledarbegåvnings": "ledarbegåvning",
    "ledare": "led",
    "ledaren": "ledare",
    "ledarens": "ledare",
    "ledares": "ledare",
    "ledarhundar": "ledarhund",
    "ledarhundarna": "ledarhund",
    "ledarhundarnas": "ledarhund",
    "ledarhundars": "ledarhund",
    "ledarhunden": "ledarhund",
    "ledarhundens": "ledarhund",
    "ledarhunds": "ledarhund",
    "ledarkulten": "ledarkult",
    "ledarkultens": "ledarkult",
    "ledarkulter": "ledarkult",
    "ledarkulterna": "ledarkult",
    "ledarkulternas": "ledarkult",
    "ledarkulters": "ledarkult",
    "ledarkults": "ledarkult",
    "ledarna": "ledare",
    "ledarnas": "ledare",
    "ledarsidan": "ledarsida",
    "ledarsidans": "ledarsida",
    "ledarsidas": "ledarsida",
    "ledarside": "ledarsida",
    "ledarsides": "ledarsida",
    "ledarsidor": "ledarsida",
    "ledarsidorna": "ledarsida",
    "ledarsidornas": "ledarsida",
    "ledarsidors": "ledarsida",
    "ledarskapet": "ledarskap",
    "ledarskapets": "ledarskap",
    "ledarskaps": "ledarskap",
    "ledarskapsmässiga": "ledarskapsmässig",
    "ledarskapsmässigare": "ledarskapsmässig",
    "ledarskapsmässigares": "ledarskapsmässig",
    "ledarskapsmässigas": "ledarskapsmässig",
    "ledarskapsmässigast": "ledarskapsmässig",
    "ledarskapsmässigaste": "ledarskapsmässig",
    "ledarskapsmässigastes": "ledarskapsmässig",
    "ledarskapsmässigasts": "ledarskapsmässig",
    "ledarskapsmässige": "ledarskapsmässig",
    "ledarskapsmässiges": "ledarskapsmässig",
    "ledarskapsmässigs": "ledarskapsmässig",
    "ledarskapsmässigt": "ledarskapsmässig",
    "ledarskapsmässigts": "ledarskapsmässig",
    "ledarskiften": "ledarskifte",
    "ledarskiftena": "ledarskifte",
    "ledarskiftenas": "ledarskifte",
    "ledarskiftens": "ledarskifte",
    "ledarskiftes": "ledarskifte",
    "ledarskiftet": "ledarskifte",
    "ledarskiftets": "ledarskifte",
    "ledarskikten": "ledarskikt",
    "ledarskiktens": "ledarskikt",
    "ledarskiktet": "ledarskikt",
    "ledarskiktets": "ledarskikt",
    "ledarskikts": "ledarskikt",
    "ledarskribenten": "ledarskribent",
    "ledarskribentens": "ledarskribent",
    "ledarskribenter": "ledarskribent",
    "ledarskribenterna": "ledarskribent",
    "ledarskribenternas": "ledarskribent",
    "ledarskribenters": "ledarskribent",
    "ledarskribents": "ledarskribent",
    "ledarsticken": "ledarstick",
    "ledarstickens": "ledarstick",
    "ledarsticket": "ledarstick",
    "ledarstickets": "ledarstick",
    "ledarsticks": "ledarstick",
    "ledas": "leda",
    "ledast": "led",
    "ledaste": "led",
    "ledastes": "led",
    "ledasts": "led",
    "ledat": "ledad",
    "ledats": "ledas",
    "ledbanden": "ledband",
    "ledbandens": "ledband",
    "ledbandet": "ledband",
    "ledbandets": "ledband",
    "ledbands": "ledband",
    "ledbrosken": "ledbrosk",
    "ledbroskens": "ledbrosk",
    "ledbrosket": "ledbrosk",
    "ledbroskets": "ledbrosk",
    "ledbrosks": "ledbrosk",
    "ledbrutenheten": "ledbrutenhet",
    "ledbrutenhetens": "ledbrutenhet",
    "ledbrutenhets": "ledbrutenhet",
    "ledbrutens": "ledbruten",
    "ledbrutet": "ledbruten",
    "ledbrutets": "ledbruten",
    "ledbrutna": "ledbruten",
    "ledbrutnare": "ledbruten",
    "ledbrutnares": "ledbruten",
    "ledbrutnas": "ledbruten",
    "ledbrutnast": "ledbruten",
    "ledbrutnaste": "ledbruten",
    "ledbrutnastes": "ledbruten",
    "ledbrutnasts": "ledbruten",
    "ledbrutne": "ledbruten",
    "ledbrutnes": "ledbruten",
    "ledd": "leda",
    "ledda": "leda",
    "leddas": "leda",
    "ledde": "leda",
    "ledden": "ledd",
    "leddens": "ledd",
    "ledder": "ledd",
    "ledderna": "ledd",
    "leddernas": "ledd",
    "ledders": "ledd",
    "leddes": "ledas",
    "leddjuren": "leddjur",
    "leddjurens": "leddjur",
    "leddjuret": "leddjur",
    "leddjurets": "leddjur",
    "leddjurs": "leddjur",
    "leddock": "leddocka",
    "leddockan": "leddocka",
    "leddockans": "leddocka",
    "leddockas": "leddocka",
    "leddocke": "leddocka",
    "leddockor": "leddocka",
    "leddockorna": "leddocka",
    "leddockornas": "leddocka",
    "leddockors": "leddocka",
    "leddocks": "leddocka",
    "ledds": "ledd",
    "lede": "led",
    "leden": "led",
    "leder": "leda",
    "ledes": "ledas",
    "ledet": "led",
    "ledets": "led",
    "ledfyrar": "ledfyr",
    "ledfyrarna": "ledfyr",
    "ledfyrarnas": "ledfyr",
    "ledfyrars": "ledfyr",
    "ledfyren": "ledfyr",
    "ledfyrens": "ledfyr",
    "ledfyrs": "ledfyr",
    "ledförslitningar": "ledförslitning",
    "ledförslitningarna": "ledförslitning",
    "ledförslitningarnas": "ledförslitning",
    "ledförslitningars": "ledförslitning",
    "ledförslitningen": "ledförslitning",
    "ledförslitningens": "ledförslitning",
    "ledförslitnings": "ledförslitning",
    "ledgångsreumatismen": "ledgångsreumatism",
    "ledgångsreumatismens": "ledgångsreumatism",
    "ledgångsreumatismer": "ledgångsreumatism",
    "ledgångsreumatismerna": "ledgångsreumatism",
    "ledgångsreumatismernas": "ledgångsreumatism",
    "ledgångsreumatismers": "ledgångsreumatism",
    "ledgångsreumatisms": "ledgångsreumatism",
    "ledheten": "ledhet",
    "ledhetens": "ledhet",
    "ledhets": "ledhet",
    "ledhuvuden": "ledhuvud",
    "ledhuvudena": "ledhuvud",
    "ledhuvudenas": "ledhuvud",
    "ledhuvudens": "ledhuvud",
    "ledhuvudet": "ledhuvud",
    "ledhuvudets": "ledhuvud",
    "ledhuvuds": "ledhuvud",
    "lediga": "ledig",
    "ledigare": "ledig",
    "ledigares": "ledig",
    "ledigas": "ledig",
    "ledigast": "ledig",
    "ledigaste": "ledig",
    "ledigastes": "ledig",
    "ledigasts": "ledig",
    "ledige": "ledig",
    "lediges": "ledig",
    "ledigförklarad": "ledigförklara",
    "ledigförklarade": "ledigförklara",
    "ledigförklarades": "ledigförklara",
    "ledigförklarads": "ledigförklara",
    "ledigförklarande": "ledigförklara",
    "ledigförklaranden": "ledigförklarande",
    "ledigförklarandena": "ledigförklarande",
    "ledigförklarandenas": "ledigförklarande",
    "ledigförklarandens": "ledigförklarande",
    "ledigförklarandes": "ledigförklarande",
    "ledigförklarandet": "ledigförklarande",
    "ledigförklarandets": "ledigförklarande",
    "ledigförklarar": "ledigförklara",
    "ledigförklaras": "ledigförklara",
    "ledigförklarat": "ledigförklara",
    "ledigförklarats": "ledigförklara",
    "ledigheten": "ledighet",
    "ledighetens": "ledighet",
    "ledigheter": "ledighet",
    "ledigheterna": "ledighet",
    "ledigheternas": "ledighet",
    "ledigheters": "ledighet",
    "ledighets": "ledighet",
    "ledighetskommittéer": "ledighetskommitté",
    "ledighetskommittéerna": "ledighetskommitté",
    "ledighetskommittéernas": "ledighetskommitté",
    "ledighetskommittéers": "ledighetskommitté",
    "ledighetskommittén": "ledighetskommitté",
    "ledighetskommitténs": "ledighetskommitté",
    "ledighetskommittés": "ledighetskommitté",
    "ledigs": "ledig",
    "ledigt": "ledig",
    "ledigts": "ledig",
    "ledinflammationen": "ledinflammation",
    "ledinflammationens": "ledinflammation",
    "ledinflammationer": "ledinflammation",
    "ledinflammationerna": "ledinflammation",
    "ledinflammationernas": "ledinflammation",
    "ledinflammationers": "ledinflammation",
    "ledinflammations": "ledinflammation",
    "ledkapseln": "ledkapsel",
    "ledkapselns": "ledkapsel",
    "ledkapsels": "ledkapsel",
    "ledkapslar": "ledkapsel",
    "ledkapslarna": "ledkapsel",
    "ledkapslarnas": "ledkapsel",
    "ledkapslars": "ledkapsel",
    "ledkorten": "ledkort",
    "ledkortens": "ledkort",
    "ledkortet": "ledkort",
    "ledkortets": "ledkort",
    "ledkorts": "ledkort",
    "ledmotiven": "ledmotiv",
    "ledmotivens": "ledmotiv",
    "ledmotivet": "ledmotiv",
    "ledmotivets": "ledmotiv",
    "ledmotivs": "ledmotiv",
    "ledningar": "ledning",
    "ledningarna": "ledning",
    "ledningarnas": "ledning",
    "ledningars": "ledning",
    "ledningen": "ledning",
    "ledningens": "ledning",
    "lednings": "ledning",
    "ledningsförmågan": "ledningsförmåga",
    "ledningsförmågans": "ledningsförmåga",
    "ledningsförmågas": "ledningsförmåga",
    "ledningsförmåge": "ledningsförmåga",
    "ledningsgruppen": "ledningsgrupp",
    "ledningsgruppens": "ledningsgrupp",
    "ledningsgrupper": "ledningsgrupp",
    "ledningsgrupperna": "ledningsgrupp",
    "ledningsgruppernas": "ledningsgrupp",
    "ledningsgruppers": "ledningsgrupp",
    "ledningsgrupps": "ledningsgrupp",
    "ledningsmotstånden": "ledningsmotstånd",
    "ledningsmotståndens": "ledningsmotstånd",
    "ledningsmotståndet": "ledningsmotstånd",
    "ledningsmotståndets": "ledningsmotstånd",
    "ledningsmotstånds": "ledningsmotstånd",
    "ledningsmässiga": "ledningsmässig",
    "ledningsmässigare": "ledningsmässig",
    "ledningsmässigares": "ledningsmässig",
    "ledningsmässigas": "ledningsmässig",
    "ledningsmässigast": "ledningsmässig",
    "ledningsmässigaste": "ledningsmässig",
    "ledningsmässigastes": "ledningsmässig",
    "ledningsmässigasts": "ledningsmässig",
    "ledningsmässige": "ledningsmässig",
    "ledningsmässiges": "ledningsmässig",
    "ledningsmässigs": "ledningsmässig",
    "ledningsmässigt": "ledningsmässig",
    "ledningsmässigts": "ledningsmässig",
    "ledningsmålen": "ledningsmål",
    "ledningsmålens": "ledningsmål",
    "ledningsmålet": "ledningsmål",
    "ledningsmålets": "ledningsmål",
    "ledningsmåls": "ledningsmål",
    "ledningsorganen": "ledningsorgan",
    "ledningsorganens": "ledningsorgan",
    "ledningsorganet": "ledningsorgan",
    "ledningsorganets": "ledningsorgan",
    "ledningsorgans": "ledningsorgan",
    "ledningsstolp": "ledningsstolpe",
    "ledningsstolpar": "ledningsstolpe",
    "ledningsstolparna": "ledningsstolpe",
    "ledningsstolparnas": "ledningsstolpe",
    "ledningsstolpars": "ledningsstolpe",
    "ledningsstolpen": "ledningsstolpe",
    "ledningsstolpens": "ledningsstolpe",
    "ledningsstolpes": "ledningsstolpe",
    "ledningsstolps": "ledningsstolpe",
    "ledningsvävnaden": "ledningsvävnad",
    "ledningsvävnadens": "ledningsvävnad",
    "ledningsvävnader": "ledningsvävnad",
    "ledningsvävnaderna": "ledningsvävnad",
    "ledningsvävnadernas": "ledningsvävnad",
    "ledningsvävnaders": "ledningsvävnad",
    "ledningsvävnads": "ledningsvävnad",
    "leds": "lida",
    "ledsag": "ledsaga",
    "ledsagad": "ledsaga",
    "ledsagade": "ledsaga",
    "ledsagades": "ledsaga",
    "ledsagads": "ledsaga",
    "ledsagande": "ledsaga",
    "ledsaganden": "ledsagande",
    "ledsagandena": "ledsagande",
    "ledsagandenas": "ledsagande",
    "ledsagandens": "ledsagande",
    "ledsagandes": "ledsagande",
    "ledsagandet": "ledsagande",
    "ledsagandets": "ledsagande",
    "ledsagar": "ledsagare",
    "ledsagaren": "ledsagare",
    "ledsagarens": "ledsagare",
    "ledsagares": "ledsagare",
    "ledsagarna": "ledsagare",
    "ledsagarnas": "ledsagare",
    "ledsagas": "ledsaga",
    "ledsagat": "ledsaga",
    "ledsagats": "ledsaga",
    "ledsamheten": "ledsamhet",
    "ledsamhetens": "ledsamhet",
    "ledsamheter": "ledsamhet",
    "ledsamheterna": "ledsamhet",
    "ledsamheternas": "ledsamhet",
    "ledsamheters": "ledsamhet",
    "ledsamhets": "ledsamhet",
    "ledsamma": "ledsam",
    "ledsammare": "ledsam",
    "ledsammares": "ledsam",
    "ledsammas": "ledsam",
    "ledsammast": "ledsam",
    "ledsammaste": "ledsam",
    "ledsammastes": "ledsam",
    "ledsammasts": "ledsam",
    "ledsamme": "ledsam",
    "ledsammes": "ledsam",
    "ledsams": "ledsam",
    "ledsamt": "ledsam",
    "ledsamts": "ledsam",
    "ledsegels": "ledsegel",
    "ledseglen": "ledsegel",
    "ledseglens": "ledsegel",
    "ledseglet": "ledsegel",
    "ledseglets": "ledsegel",
    "ledsenheten": "ledsenhet",
    "ledsenhetens": "ledsenhet",
    "ledsenheter": "ledsenhet",
    "ledsenheterna": "ledsenhet",
    "ledsenheternas": "ledsenhet",
    "ledsenheters": "ledsenhet",
    "ledsenhets": "ledsenhet",
    "ledsens": "ledsen",
    "ledset": "ledsen",
    "ledsets": "ledsen",
    "ledskålar": "ledskål",
    "ledskålarna": "ledskål",
    "ledskålarnas": "ledskål",
    "ledskålars": "ledskål",
    "ledskålen": "ledskål",
    "ledskålens": "ledskål",
    "ledskåls": "ledskål",
    "ledsna": "ledsen",
    "ledsnade": "ledsna",
    "ledsnaden": "ledsnad",
    "ledsnadens": "ledsnad",
    "ledsnader": "ledsnad",
    "ledsnaderna": "ledsnad",
    "ledsnadernas": "ledsnad",
    "ledsnaders": "ledsnad",
    "ledsnades": "ledsna",
    "ledsnads": "ledsnad",
    "ledsnande": "ledsna",
    "ledsnanden": "ledsnande",
    "ledsnandena": "ledsnande",
    "ledsnandenas": "ledsnande",
    "ledsnandens": "ledsnande",
    "ledsnandes": "ledsnande",
    "ledsnandet": "ledsnande",
    "ledsnandets": "ledsnande",
    "ledsnar": "ledsna",
    "ledsnare": "ledsen",
    "ledsnares": "ledsen",
    "ledsnas": "ledsna",
    "ledsnast": "ledsen",
    "ledsnaste": "ledsen",
    "ledsnastes": "ledsen",
    "ledsnasts": "ledsen",
    "ledsnat": "ledsna",
    "ledsnats": "ledsna",
    "ledsne": "ledsen",
    "ledsnes": "ledsen",
    "ledstjärnan": "ledstjärna",
    "ledstjärnans": "ledstjärna",
    "ledstjärnas": "ledstjärna",
    "ledstjärne": "ledstjärna",
    "ledstjärnor": "ledstjärna",
    "ledstjärnorna": "ledstjärna",
    "ledstjärnornas": "ledstjärna",
    "ledstjärnors": "ledstjärna",
    "ledstänger": "ledstång",
    "ledstängerna": "ledstång",
    "ledstängernas": "ledstång",
    "ledstängers": "ledstång",
    "ledstången": "ledstång",
    "ledstångens": "ledstång",
    "ledstångs": "ledstång",
    "ledsynen": "ledsyn",
    "ledsynens": "ledsyn",
    "ledsyns": "ledsyn",
    "ledtrådar": "ledtråd",
    "ledtrådarna": "ledtråd",
    "ledtrådarnas": "ledtråd",
    "ledtrådars": "ledtråd",
    "ledtråden": "ledtråd",
    "ledtrådens": "ledtråd",
    "ledtråds": "ledtråd",
    "ledungen": "ledung",
    "ledungens": "ledung",
    "ledungs": "ledung",
    "ledungsskeppen": "ledungsskepp",
    "ledungsskeppens": "ledungsskepp",
    "ledungsskeppet": "ledungsskepp",
    "ledungsskeppets": "ledungsskepp",
    "ledungsskepps": "ledungsskepp",
    "ledutrymmen": "ledutrymme",
    "ledutrymmena": "ledutrymme",
    "ledutrymmenas": "ledutrymme",
    "ledutrymmens": "ledutrymme",
    "ledutrymmes": "ledutrymme",
    "ledutrymmet": "ledutrymme",
    "ledutrymmets": "ledutrymme",
    "ledvätskan": "ledvätska",
    "ledvätskans": "ledvätska",
    "ledvätskas": "ledvätska",
    "ledvätske": "ledvätska",
    "ledytan": "ledyta",
    "ledytans": "ledyta",
    "ledytas": "ledyta",
    "ledyte": "ledyta",
    "ledytor": "ledyta",
    "ledytorna": "ledyta",
    "ledytornas": "ledyta",
    "ledytors": "ledyta",
    "leende": "le",
    "leenden": "leende",
    "leendena": "leende",
    "leendenas": "leende",
    "leendens": "leende",
    "leendes": "leende",
    "leendet": "leende",
    "leendets": "leende",
    "leg": "lega",
    "legala": "legal",
    "legalare": "legal",
    "legalares": "legal",
    "legalas": "legal",
    "legalast": "legal",
    "legalaste": "legal",
    "legalastes": "legal",
    "legalasts": "legal",
    "legale": "legal",
    "legales": "legal",
    "legalisationen": "legalisation",
    "legalisationens": "legalisation",
    "legalisationer": "legalisation",
    "legalisationerna": "legalisation",
    "legalisationernas": "legalisation",
    "legalisationers": "legalisation",
    "legalisations": "legalisation",
    "legaliserad": "legalisera",
    "legaliserade": "legalisera",
    "legaliserades": "legalisera",
    "legaliserads": "legalisera",
    "legaliserande": "legalisera",
    "legaliseranden": "legaliserande",
    "legaliserandena": "legaliserande",
    "legaliserandenas": "legaliserande",
    "legaliserandens": "legaliserande",
    "legaliserandes": "legaliserande",
    "legaliserandet": "legaliserande",
    "legaliserandets": "legaliserande",
    "legaliserar": "legalisera",
    "legaliseras": "legalisera",
    "legaliserat": "legalisera",
    "legaliserats": "legalisera",
    "legaliserbara": "legaliserbar",
    "legaliserbarare": "legaliserbar",
    "legaliserbarares": "legaliserbar",
    "legaliserbaras": "legaliserbar",
    "legaliserbarast": "legaliserbar",
    "legaliserbaraste": "legaliserbar",
    "legaliserbarastes": "legaliserbar",
    "legaliserbarasts": "legaliserbar",
    "legaliserbare": "legaliserbar",
    "legaliserbares": "legaliserbar",
    "legaliserbarheten": "legaliserbarhet",
    "legaliserbarhetens": "legaliserbarhet",
    "legaliserbarhets": "legaliserbarhet",
    "legaliserbars": "legaliserbar",
    "legaliserbart": "legaliserbar",
    "legaliserbarts": "legaliserbar",
    "legaliseringar": "legalisering",
    "legaliseringarna": "legalisering",
    "legaliseringarnas": "legalisering",
    "legaliseringars": "legalisering",
    "legaliseringen": "legalisering",
    "legaliseringens": "legalisering",
    "legaliserings": "legalisering",
    "legaliteten": "legalitet",
    "legalitetens": "legalitet",
    "legaliteter": "legalitet",
    "legaliteterna": "legalitet",
    "legaliteternas": "legalitet",
    "legaliteters": "legalitet",
    "legalitets": "legalitet",
    "legals": "legal",
    "legalt": "legal",
    "legalts": "legal",
    "legan": "lega",
    "legans": "lega",
    "legas": "lega",
    "legat": "ligga",
    "legatarien": "legatarie",
    "legatariens": "legatarie",
    "legatarier": "legatarie",
    "legatarierna": "legatarie",
    "legatariernas": "legatarie",
    "legatariers": "legatarie",
    "legataries": "legatarie",
    "legaten": "legat",
    "legatens": "legat",
    "legater": "legat",
    "legaterna": "legat",
    "legaternas": "legat",
    "legaters": "legat",
    "legatet": "legat",
    "legatets": "legat",
    "legationen": "legation",
    "legationens": "legation",
    "legationer": "legation",
    "legationerna": "legation",
    "legationernas": "legation",
    "legationers": "legation",
    "legations": "legation",
    "legaton": "legato",
    "legatona": "legato",
    "legatonas": "legato",
    "legatons": "legato",
    "legatos": "legato",
    "legatot": "legato",
    "legatots": "legato",
    "legats": "ligga",
    "lege": "lega",
    "legen": "leg",
    "legendaren": "legendar",
    "legendarens": "legendar",
    "legendarer": "legendar",
    "legendarerna": "legendar",
    "legendarernas": "legendar",
    "legendarers": "legendar",
    "legendarie": "legendarium",
    "legendarier": "legendarium",
    "legendarierna": "legendarium",
    "legendariernas": "legendarium",
    "legendariers": "legendarium",
    "legendariet": "legendarium",
    "legendariets": "legendarium",
    "legendariska": "legendarisk",
    "legendariskare": "legendarisk",
    "legendariskares": "legendarisk",
    "legendariskas": "legendarisk",
    "legendariskast": "legendarisk",
    "legendariskaste": "legendarisk",
    "legendariskastes": "legendarisk",
    "legendariskasts": "legendarisk",
    "legendariske": "legendarisk",
    "legendariskes": "legendarisk",
    "legendarisks": "legendarisk",
    "legendariskt": "legendarisk",
    "legendariskts": "legendarisk",
    "legendariums": "legendarium",
    "legendars": "legendar",
    "legenden": "legend",
    "legendens": "legend",
    "legender": "legend",
    "legenderna": "legend",
    "legendernas": "legend",
    "legenders": "legend",
    "legendomspunna": "legendomspunnen",
    "legendomspunnare": "legendomspunnen",
    "legendomspunnares": "legendomspunnen",
    "legendomspunnas": "legendomspunnen",
    "legendomspunnast": "legendomspunnen",
    "legendomspunnaste": "legendomspunnen",
    "legendomspunnastes": "legendomspunnen",
    "legendomspunnasts": "legendomspunnen",
    "legendomspunne": "legendomspunnen",
    "legendomspunnens": "legendomspunnen",
    "legendomspunnes": "legendomspunnen",
    "legendomspunnet": "legendomspunnen",
    "legendomspunnets": "legendomspunnen",
    "legendomsusade": "legendomsusad",
    "legendomsusades": "legendomsusad",
    "legendomsusads": "legendomsusad",
    "legendomsusat": "legendomsusad",
    "legendomsusats": "legendomsusad",
    "legends": "legend",
    "legens": "leg",
    "legerad": "legera",
    "legerade": "legera",
    "legerades": "legera",
    "legerads": "legera",
    "legerande": "legera",
    "legeranden": "legerande",
    "legerandena": "legerande",
    "legerandenas": "legerande",
    "legerandens": "legerande",
    "legerandes": "legerande",
    "legerandet": "legerande",
    "legerandets": "legerande",
    "legerar": "legera",
    "legeras": "legera",
    "legerat": "legera",
    "legerats": "legera",
    "legerbara": "legerbar",
    "legerbarare": "legerbar",
    "legerbarares": "legerbar",
    "legerbaras": "legerbar",
    "legerbarast": "legerbar",
    "legerbaraste": "legerbar",
    "legerbarastes": "legerbar",
    "legerbarasts": "legerbar",
    "legerbare": "legerbar",
    "legerbares": "legerbar",
    "legerbarheten": "legerbarhet",
    "legerbarhetens": "legerbarhet",
    "legerbarhets": "legerbarhet",
    "legerbars": "legerbar",
    "legerbart": "legerbar",
    "legerbarts": "legerbar",
    "legeringar": "legering",
    "legeringarna": "legering",
    "legeringarnas": "legering",
    "legeringars": "legering",
    "legeringen": "legering",
    "legeringens": "legering",
    "legerings": "legering",
    "leget": "leg",
    "legets": "leg",
    "leggen": "legg",
    "leggens": "legg",
    "legget": "legg",
    "leggets": "legg",
    "leggs": "legg",
    "legionen": "legion",
    "legionens": "legion",
    "legioner": "legion",
    "legionerna": "legion",
    "legionernas": "legion",
    "legioners": "legion",
    "legions": "legion",
    "legionären": "legionär",
    "legionärens": "legionär",
    "legionärer": "legionär",
    "legionärerna": "legionär",
    "legionärernas": "legionär",
    "legionärers": "legionär",
    "legionärs": "legionär",
    "legislativa": "legislativ",
    "legislativare": "legislativ",
    "legislativares": "legislativ",
    "legislativas": "legislativ",
    "legislativast": "legislativ",
    "legislativaste": "legislativ",
    "legislativastes": "legislativ",
    "legislativasts": "legislativ",
    "legislative": "legislativ",
    "legislatives": "legislativ",
    "legislativs": "legislativ",
    "legislativt": "legislativ",
    "legislativts": "legislativ",
    "legislaturen": "legislatur",
    "legislaturens": "legislatur",
    "legislaturer": "legislatur",
    "legislaturerna": "legislatur",
    "legislaturernas": "legislatur",
    "legislaturers": "legislatur",
    "legislaturs": "legislatur",
    "legitima": "legitim",
    "legitimare": "legitim",
    "legitimares": "legitim",
    "legitimas": "legitim",
    "legitimast": "legitim",
    "legitimaste": "legitim",
    "legitimastes": "legitim",
    "legitimasts": "legitim",
    "legitimationen": "legitimation",
    "legitimationens": "legitimation",
    "legitimationer": "legitimation",
    "legitimationerna": "legitimation",
    "legitimationernas": "legitimation",
    "legitimationers": "legitimation",
    "legitimations": "legitimation",
    "legitime": "legitim",
    "legitimerad": "legitimera",
    "legitimerade": "legitimera",
    "legitimerades": "legitimera",
    "legitimerads": "legitimera",
    "legitimerande": "legitimera",
    "legitimeranden": "legitimerande",
    "legitimerandena": "legitimerande",
    "legitimerandenas": "legitimerande",
    "legitimerandens": "legitimerande",
    "legitimerandes": "legitimerande",
    "legitimerandet": "legitimerande",
    "legitimerandets": "legitimerande",
    "legitimerar": "legitimera",
    "legitimeras": "legitimera",
    "legitimerat": "legitimera",
    "legitimerats": "legitimera",
    "legitimerbara": "legitimerbar",
    "legitimerbarare": "legitimerbar",
    "legitimerbarares": "legitimerbar",
    "legitimerbaras": "legitimerbar",
    "legitimerbarast": "legitimerbar",
    "legitimerbaraste": "legitimerbar",
    "legitimerbarastes": "legitimerbar",
    "legitimerbarasts": "legitimerbar",
    "legitimerbare": "legitimerbar",
    "legitimerbares": "legitimerbar",
    "legitimerbarheten": "legitimerbarhet",
    "legitimerbarhetens": "legitimerbarhet",
    "legitimerbarhets": "legitimerbarhet",
    "legitimerbars": "legitimerbar",
    "legitimerbart": "legitimerbar",
    "legitimerbarts": "legitimerbar",
    "legitimeringar": "legitimering",
    "legitimeringarna": "legitimering",
    "legitimeringarnas": "legitimering",
    "legitimeringars": "legitimering",
    "legitimeringen": "legitimering",
    "legitimeringens": "legitimering",
    "legitimerings": "legitimering",
    "legitimes": "legitim",
    "legitimisten": "legitimist",
    "legitimistens": "legitimist",
    "legitimister": "legitimist",
    "legitimisterna": "legitimist",
    "legitimisternas": "legitimist",
    "legitimisters": "legitimist",
    "legitimists": "legitimist",
    "legitimiteten": "legitimitet",
    "legitimitetens": "legitimitet",
    "legitimiteter": "legitimitet",
    "legitimiteterna": "legitimitet",
    "legitimiteternas": "legitimitet",
    "legitimiteters": "legitimitet",
    "legitimitets": "legitimitet",
    "legitimitetsprincipen": "legitimitetsprincip",
    "legitimitetsprincipens": "legitimitetsprincip",
    "legitimitetsprincips": "legitimitetsprincip",
    "legitimitetsproblemen": "legitimitetsproblem",
    "legitimitetsproblemens": "legitimitetsproblem",
    "legitimitetsproblemet": "legitimitetsproblem",
    "legitimitetsproblemets": "legitimitetsproblem",
    "legitimitetsproblems": "legitimitetsproblem",
    "legitims": "legitim",
    "legitimt": "legitim",
    "legitimts": "legitim",
    "legoavtalen": "legoavtal",
    "legoavtalens": "legoavtal",
    "legoavtalet": "legoavtal",
    "legoavtalets": "legoavtal",
    "legoavtals": "legoavtal",
    "legoknektar": "legoknekt",
    "legoknektarna": "legoknekt",
    "legoknektarnas": "legoknekt",
    "legoknektars": "legoknekt",
    "legoknekten": "legoknekt",
    "legoknektens": "legoknekt",
    "legoknekts": "legoknekt",
    "legon": "lego",
    "legona": "lego",
    "legonas": "lego",
    "legons": "lego",
    "legor": "lega",
    "legorna": "lega",
    "legornas": "lega",
    "legors": "lega",
    "legos": "lego",
    "legosoldaten": "legosoldat",
    "legosoldatens": "legosoldat",
    "legosoldater": "legosoldat",
    "legosoldaterna": "legosoldat",
    "legosoldaternas": "legosoldat",
    "legosoldaters": "legosoldat",
    "legosoldats": "legosoldat",
    "legot": "lego",
    "legotillverkningar": "legotillverkning",
    "legotillverkningarna": "legotillverkning",
    "legotillverkningarnas": "legotillverkning",
    "legotillverkningars": "legotillverkning",
    "legotillverkningen": "legotillverkning",
    "legotillverkningens": "legotillverkning",
    "legotillverknings": "legotillverkning",
    "legotruppen": "legotrupp",
    "legotruppens": "legotrupp",
    "legotrupper": "legotrupp",
    "legotrupperna": "legotrupp",
    "legotruppernas": "legotrupp",
    "legotruppers": "legotrupp",
    "legotrupps": "legotrupp",
    "legots": "lego",
    "legs": "lega",
    "leguanen": "leguan",
    "leguanens": "leguan",
    "leguaner": "leguan",
    "leguanerna": "leguan",
    "leguanernas": "leguan",
    "leguaners": "leguan",
    "leguans": "leguan",
    "legym": "legymer",
    "legymerna": "legymer",
    "legymernas": "legymer",
    "legymers": "legymer",
    "legyms": "legymer",
    "legymsalladen": "legymsallad",
    "legymsalladens": "legymsallad",
    "legymsallader": "legymsallad",
    "legymsalladerna": "legymsallad",
    "legymsalladernas": "legymsallad",
    "legymsalladers": "legymsallad",
    "legymsallads": "legymsallad",
    "legära": "legär",
    "legärare": "legär",
    "legärares": "legär",
    "legäras": "legär",
    "legärast": "legär",
    "legäraste": "legär",
    "legärastes": "legär",
    "legärasts": "legär",
    "legäre": "legär",
    "legäres": "legär",
    "legärs": "legär",
    "legärt": "legär",
    "legärts": "legär",
    "leheten": "lehet",
    "lehetens": "lehet",
    "lehets": "lehet",
    "leidenflask": "leidenflaska",
    "leidenflaskan": "leidenflaska",
    "leidenflaskans": "leidenflaska",
    "leidenflaskas": "leidenflaska",
    "leidenflaske": "leidenflaska",
    "leidenflaskor": "leidenflaska",
    "leidenflaskorna": "leidenflaska",
    "leidenflaskornas": "leidenflaska",
    "leidenflaskors": "leidenflaska",
    "leidnerflask": "leidnerflaska",
    "leidnerflaskan": "leidnerflaska",
    "leidnerflaskans": "leidnerflaska",
    "leidnerflaskas": "leidnerflaska",
    "leidnerflaske": "leidnerflaska",
    "leidnerflaskor": "leidnerflaska",
    "leidnerflaskorna": "leidnerflaska",
    "leidnerflaskornas": "leidnerflaska",
    "leidnerflaskors": "leidnerflaska",
    "lej": "leja",
    "lejande": "leja",
    "lejanden": "lejande",
    "lejandena": "lejande",
    "lejandenas": "lejande",
    "lejandens": "lejande",
    "lejandes": "lejande",
    "lejandet": "lejande",
    "lejandets": "lejande",
    "lejas": "leja",
    "lejd": "leja",
    "lejda": "leja",
    "lejdar": "lejdare",
    "lejdaren": "lejdare",
    "lejdarens": "lejdare",
    "lejdares": "lejdare",
    "lejdarna": "lejdare",
    "lejdarnas": "lejdare",
    "lejdars": "lejd",
    "lejdas": "leja",
    "lejdbåtar": "lejdbåt",
    "lejdbåtarna": "lejdbåt",
    "lejdbåtarnas": "lejdbåt",
    "lejdbåtars": "lejdbåt",
    "lejdbåten": "lejdbåt",
    "lejdbåtens": "lejdbåt",
    "lejdbåts": "lejdbåt",
    "lejde": "leja",
    "lejdebreven": "lejdebrev",
    "lejdebrevens": "lejdebrev",
    "lejdebrevet": "lejdebrev",
    "lejdebrevets": "lejdebrev",
    "lejdebrevs": "lejdebrev",
    "lejden": "lejd",
    "lejdens": "lejd",
    "lejdes": "leja",
    "lejdrad": "lejdra",
    "lejdrade": "lejdra",
    "lejdrades": "lejdra",
    "lejdrads": "lejdra",
    "lejdrande": "lejdra",
    "lejdranden": "lejdrande",
    "lejdrandena": "lejdrande",
    "lejdrandenas": "lejdrande",
    "lejdrandens": "lejdrande",
    "lejdrandes": "lejdrande",
    "lejdrandet": "lejdrande",
    "lejdrandets": "lejdrande",
    "lejdrar": "lejdra",
    "lejdras": "lejdra",
    "lejdrat": "lejdra",
    "lejdrats": "lejdra",
    "lejds": "lejd",
    "lejdtrafiken": "lejdtrafik",
    "lejdtrafikens": "lejdtrafik",
    "lejdtrafiks": "lejdtrafik",
    "lejer": "leja",
    "lejes": "leja",
    "lejonen": "lejon",
    "lejonens": "lejon",
    "lejonet": "lejon",
    "lejonets": "lejon",
    "lejonfoten": "lejonfot",
    "lejonfotens": "lejonfot",
    "lejonfots": "lejonfot",
    "lejonfötter": "lejonfot",
    "lejonfötterna": "lejonfot",
    "lejonfötternas": "lejonfot",
    "lejonfötters": "lejonfot",
    "lejongapen": "lejongap",
    "lejongapens": "lejongap",
    "lejongapet": "lejongap",
    "lejongapets": "lejongap",
    "lejongaps": "lejongap",
    "lejongropar": "lejongrop",
    "lejongroparna": "lejongrop",
    "lejongroparnas": "lejongrop",
    "lejongropars": "lejongrop",
    "lejongropen": "lejongrop",
    "lejongropens": "lejongrop",
    "lejongrops": "lejongrop",
    "lejoninnan": "lejoninna",
    "lejoninnans": "lejoninna",
    "lejoninnas": "lejoninna",
    "lejoninne": "lejoninna",
    "lejoninnor": "lejoninna",
    "lejoninnorna": "lejoninna",
    "lejoninnornas": "lejoninna",
    "lejoninnors": "lejoninna",
    "lejonkul": "lejonkula",
    "lejonkulan": "lejonkula",
    "lejonkulans": "lejonkula",
    "lejonkulas": "lejonkula",
    "lejonkule": "lejonkula",
    "lejonkulor": "lejonkula",
    "lejonkulorna": "lejonkula",
    "lejonkulornas": "lejonkula",
    "lejonkulors": "lejonkula",
    "lejonkuls": "lejonkula",
    "lejonparten": "lejonpart",
    "lejonpartens": "lejonpart",
    "lejonparts": "lejonpart",
    "lejons": "lejon",
    "lejontämjar": "lejontämjare",
    "lejontämjaren": "lejontämjare",
    "lejontämjarens": "lejontämjare",
    "lejontämjares": "lejontämjare",
    "lejontämjarna": "lejontämjare",
    "lejontämjarnas": "lejontämjare",
    "lejs": "leja",
    "lejt": "leja",
    "lejts": "leja",
    "lek": "leka",
    "lekamens": "lekamen",
    "lekamliga": "lekamlig",
    "lekamligare": "lekamlig",
    "lekamligares": "lekamlig",
    "lekamligas": "lekamlig",
    "lekamligast": "lekamlig",
    "lekamligaste": "lekamlig",
    "lekamligastes": "lekamlig",
    "lekamligasts": "lekamlig",
    "lekamlige": "lekamlig",
    "lekamliges": "lekamlig",
    "lekamligheten": "lekamlighet",
    "lekamlighetens": "lekamlighet",
    "lekamlighets": "lekamlighet",
    "lekamligs": "lekamlig",
    "lekamligt": "lekamlig",
    "lekamligts": "lekamlig",
    "lekande": "leka",
    "lekanden": "lekande",
    "lekandena": "lekande",
    "lekandenas": "lekande",
    "lekandens": "lekande",
    "lekandes": "lekande",
    "lekandet": "lekande",
    "lekandets": "lekande",
    "lekar": "lekare",
    "lekaren": "lekare",
    "lekarens": "lekare",
    "lekares": "lekare",
    "lekarna": "lekare",
    "lekarnas": "lekare",
    "lekars": "lek",
    "lekas": "leka",
    "lekatten": "lekatt",
    "lekattens": "lekatt",
    "lekatter": "lekatt",
    "lekatterna": "lekatt",
    "lekatternas": "lekatt",
    "lekatters": "lekatt",
    "lekattfäll": "lekattfälla",
    "lekattfällan": "lekattfälla",
    "lekattfällans": "lekattfälla",
    "lekattfällas": "lekattfälla",
    "lekattfälle": "lekattfälla",
    "lekattfällor": "lekattfälla",
    "lekattfällorna": "lekattfälla",
    "lekattfällornas": "lekattfälla",
    "lekattfällors": "lekattfälla",
    "lekattfälls": "lekattfälla",
    "lekatts": "lekatt",
    "lekbollar": "lekboll",
    "lekbollarna": "lekboll",
    "lekbollarnas": "lekboll",
    "lekbollars": "lekboll",
    "lekbollen": "lekboll",
    "lekbollens": "lekboll",
    "lekbolls": "lekboll",
    "lekdammar": "lekdamm",
    "lekdammarna": "lekdamm",
    "lekdammarnas": "lekdamm",
    "lekdammars": "lekdamm",
    "lekdammen": "lekdamm",
    "lekdammens": "lekdamm",
    "lekdamms": "lekdamm",
    "lekdräkten": "lekdräkt",
    "lekdräktens": "lekdräkt",
    "lekdräkter": "lekdräkt",
    "lekdräkterna": "lekdräkt",
    "lekdräkternas": "lekdräkt",
    "lekdräkters": "lekdräkt",
    "lekdräkts": "lekdräkt",
    "leken": "lek",
    "lekens": "lek",
    "leker": "leka",
    "lekes": "leka",
    "lekfiskar": "lekfisk",
    "lekfiskarna": "lekfisk",
    "lekfiskarnas": "lekfisk",
    "lekfiskars": "lekfisk",
    "lekfisken": "lekfisk",
    "lekfiskens": "lekfisk",
    "lekfiskes": "lekfiske",
    "lekfisket": "lekfiske",
    "lekfiskets": "lekfiske",
    "lekfisks": "lekfisk",
    "lekfulla": "lekfull",
    "lekfullare": "lekfull",
    "lekfullares": "lekfull",
    "lekfullas": "lekfull",
    "lekfullast": "lekfull",
    "lekfullaste": "lekfull",
    "lekfullastes": "lekfull",
    "lekfullasts": "lekfull",
    "lekfulle": "lekfull",
    "lekfulles": "lekfull",
    "lekfullheten": "lekfullhet",
    "lekfullhetens": "lekfullhet",
    "lekfullheter": "lekfullhet",
    "lekfullheterna": "lekfullhet",
    "lekfullheternas": "lekfullhet",
    "lekfullheters": "lekfullhet",
    "lekfullhets": "lekfullhet",
    "lekfulls": "lekfull",
    "lekfullt": "lekfull",
    "lekfullts": "lekfull",
    "lekfärdiga": "lekfärdig",
    "lekfärdigare": "lekfärdig",
    "lekfärdigares": "lekfärdig",
    "lekfärdigas": "lekfärdig",
    "lekfärdigast": "lekfärdig",
    "lekfärdigaste": "lekfärdig",
    "lekfärdigastes": "lekfärdig",
    "lekfärdigasts": "lekfärdig",
    "lekfärdige": "lekfärdig",
    "lekfärdiges": "lekfärdig",
    "lekfärdigheten": "lekfärdighet",
    "lekfärdighetens": "lekfärdighet",
    "lekfärdighets": "lekfärdighet",
    "lekfärdigs": "lekfärdig",
    "lekfärdigt": "lekfärdig",
    "lekfärdigts": "lekfärdig",
    "lekkamraten": "lekkamrat",
    "lekkamratens": "lekkamrat",
    "lekkamrater": "lekkamrat",
    "lekkamraterna": "lekkamrat",
    "lekkamraternas": "lekkamrat",
    "lekkamraters": "lekkamrat",
    "lekkamrats": "lekkamrat",
    "lekledar": "lekledare",
    "lekledaren": "lekledare",
    "lekledarens": "lekledare",
    "lekledares": "lekledare",
    "lekledarna": "lekledare",
    "lekledarnas": "lekledare",
    "leklynnes": "leklynne",
    "leklynnet": "leklynne",
    "leklynnets": "leklynne",
    "leklystenheten": "leklystenhet",
    "leklystenhetens": "leklystenhet",
    "leklystenhets": "leklystenhet",
    "leklystens": "leklysten",
    "leklystet": "leklysten",
    "leklystets": "leklysten",
    "leklystna": "leklysten",
    "leklystnare": "leklysten",
    "leklystnares": "leklysten",
    "leklystnas": "leklysten",
    "leklystnast": "leklysten",
    "leklystnaste": "leklysten",
    "leklystnastes": "leklysten",
    "leklystnasts": "leklysten",
    "leklystne": "leklysten",
    "leklystnes": "leklysten",
    "lekmannabrodern": "lekmannabroder",
    "lekmannabroderns": "lekmannabroder",
    "lekmannabroders": "lekmannabroder",
    "lekmannabröder": "lekmannabroder",
    "lekmannabröderna": "lekmannabroder",
    "lekmannabrödernas": "lekmannabroder",
    "lekmannabröders": "lekmannabroder",
    "lekmannaförståndet": "lekmannaförstånd",
    "lekmannaförståndets": "lekmannaförstånd",
    "lekmannaförstånds": "lekmannaförstånd",
    "lekmannamässiga": "lekmannamässig",
    "lekmannamässigare": "lekmannamässig",
    "lekmannamässigares": "lekmannamässig",
    "lekmannamässigas": "lekmannamässig",
    "lekmannamässigast": "lekmannamässig",
    "lekmannamässigaste": "lekmannamässig",
    "lekmannamässigastes": "lekmannamässig",
    "lekmannamässigasts": "lekmannamässig",
    "lekmannamässige": "lekmannamässig",
    "lekmannamässiges": "lekmannamässig",
    "lekmannamässigs": "lekmannamässig",
    "lekmannamässigt": "lekmannamässig",
    "lekmannamässigts": "lekmannamässig",
    "lekmannaorganisationen": "lekmannaorganisation",
    "lekmannaorganisationens": "lekmannaorganisation",
    "lekmannaorganisationer": "lekmannaorganisation",
    "lekmannaorganisationerna": "lekmannaorganisation",
    "lekmannaorganisationernas": "lekmannaorganisation",
    "lekmannaorganisationers": "lekmannaorganisation",
    "lekmannaorganisations": "lekmannaorganisation",
    "lekmannen": "lekman",
    "lekmannens": "lekman",
    "lekmans": "lekman",
    "lekmän": "lekman",
    "lekmännen": "lekman",
    "lekmännens": "lekman",
    "lekmäns": "lekman",
    "lekoteken": "lekotek",
    "lekotekens": "lekotek",
    "lekoteket": "lekotek",
    "lekotekets": "lekotek",
    "lekoteks": "lekotek",
    "lekparken": "lekpark",
    "lekparkens": "lekpark",
    "lekparker": "lekpark",
    "lekparkerna": "lekpark",
    "lekparkernas": "lekpark",
    "lekparkers": "lekpark",
    "lekparks": "lekpark",
    "lekplatsen": "lekplats",
    "lekplatsens": "lekplats",
    "lekplatser": "lekplats",
    "lekplatserna": "lekplats",
    "lekplatsernas": "lekplats",
    "lekplatsers": "lekplats",
    "leks": "leka",
    "leksaken": "leksak",
    "leksakens": "leksak",
    "leksaker": "leksak",
    "leksakerna": "leksak",
    "leksakernas": "leksak",
    "leksakers": "leksak",
    "leksaks": "leksak",
    "leksaksbilar": "leksaksbil",
    "leksaksbilarna": "leksaksbil",
    "leksaksbilarnas": "leksaksbil",
    "leksaksbilars": "leksaksbil",
    "leksaksbilen": "leksaksbil",
    "leksaksbilens": "leksaksbil",
    "leksaksbils": "leksaksbil",
    "leksaksbjörnar": "leksaksbjörn",
    "leksaksbjörnarna": "leksaksbjörn",
    "leksaksbjörnarnas": "leksaksbjörn",
    "leksaksbjörnars": "leksaksbjörn",
    "leksaksbjörnen": "leksaksbjörn",
    "leksaksbjörnens": "leksaksbjörn",
    "leksaksbjörns": "leksaksbjörn",
    "leksaksbåtar": "leksaksbåt",
    "leksaksbåtarna": "leksaksbåt",
    "leksaksbåtarnas": "leksaksbåt",
    "leksaksbåtars": "leksaksbåt",
    "leksaksbåten": "leksaksbåt",
    "leksaksbåtens": "leksaksbåt",
    "leksaksbåts": "leksaksbåt",
    "leksaksböss": "leksaksbössa",
    "leksaksbössan": "leksaksbössa",
    "leksaksbössans": "leksaksbössa",
    "leksaksbössas": "leksaksbössa",
    "leksaksbösse": "leksaksbössa",
    "leksaksbössor": "leksaksbössa",
    "leksaksbössorna": "leksaksbössa",
    "leksaksbössornas": "leksaksbössa",
    "leksaksbössors": "leksaksbössa",
    "leksaksfiguren": "leksaksfigur",
    "leksaksfigurens": "leksaksfigur",
    "leksaksfigurer": "leksaksfigur",
    "leksaksfigurerna": "leksaksfigur",
    "leksaksfigurernas": "leksaksfigur",
    "leksaksfigurers": "leksaksfigur",
    "leksaksfigurs": "leksaksfigur",
    "leksakshästar": "leksakshäst",
    "leksakshästarna": "leksakshäst",
    "leksakshästarnas": "leksakshäst",
    "leksakshästars": "leksakshäst",
    "leksakshästen": "leksakshäst",
    "leksakshästens": "leksakshäst",
    "leksakshästs": "leksakshäst",
    "leksakspistolen": "leksakspistol",
    "leksakspistolens": "leksakspistol",
    "leksakspistoler": "leksakspistol",
    "leksakspistolerna": "leksakspistol",
    "leksakspistolernas": "leksakspistol",
    "leksakspistolers": "leksakspistol",
    "leksakspistols": "leksakspistol",
    "lekskolan": "lekskola",
    "lekskolans": "lekskola",
    "lekskolas": "lekskola",
    "lekskole": "lekskola",
    "lekskolor": "lekskola",
    "lekskolorna": "lekskola",
    "lekskolornas": "lekskola",
    "lekskolors": "lekskola",
    "lekstugan": "lekstuga",
    "lekstugans": "lekstuga",
    "lekstugas": "lekstuga",
    "lekstuge": "lekstuga",
    "lekstugor": "lekstuga",
    "lekstugorna": "lekstuga",
    "lekstugornas": "lekstuga",
    "lekstugors": "lekstuga",
    "lekstugu": "lekstuga",
    "lekt": "leka",
    "lekte": "leka",
    "lektes": "leka",
    "lektiden": "lektid",
    "lektidens": "lektid",
    "lektider": "lektid",
    "lektiderna": "lektid",
    "lektidernas": "lektid",
    "lektiders": "lektid",
    "lektids": "lektid",
    "lektionen": "lektion",
    "lektionens": "lektion",
    "lektioner": "lektion",
    "lektionerna": "lektion",
    "lektionernas": "lektion",
    "lektioners": "lektion",
    "lektions": "lektion",
    "lektionstim": "lektionstimme",
    "lektionstimman": "lektionstimma",
    "lektionstimmans": "lektionstimma",
    "lektionstimmar": "lektionstimme",
    "lektionstimmarna": "lektionstimme",
    "lektionstimmarnas": "lektionstimme",
    "lektionstimmars": "lektionstimme",
    "lektionstimmas": "lektionstimma",
    "lektionstimmen": "lektionstimme",
    "lektionstimmens": "lektionstimme",
    "lektionstimmes": "lektionstimme",
    "lektionstims": "lektionstimme",
    "lektoraten": "lektorat",
    "lektoratens": "lektorat",
    "lektoratet": "lektorat",
    "lektoratets": "lektorat",
    "lektorats": "lektorat",
    "lektorer": "lektor",
    "lektorerna": "lektor",
    "lektorernas": "lektor",
    "lektorers": "lektor",
    "lektorn": "lektor",
    "lektorns": "lektor",
    "lektors": "lektor",
    "lektrisen": "lektris",
    "lektrisens": "lektris",
    "lektriser": "lektris",
    "lektriserna": "lektris",
    "lektrisernas": "lektris",
    "lektrisers": "lektris",
    "lekts": "leka",
    "lektyren": "lektyr",
    "lektyrens": "lektyr",
    "lektyrs": "lektyr",
    "lektören": "lektör",
    "lektörens": "lektör",
    "lektörer": "lektör",
    "lektörerna": "lektör",
    "lektörernas": "lektör",
    "lektörers": "lektör",
    "lektörs": "lektör",
    "lekvandringar": "lekvandring",
    "lekvandringarna": "lekvandring",
    "lekvandringarnas": "lekvandring",
    "lekvandringars": "lekvandring",
    "lekvandringen": "lekvandring",
    "lekvandringens": "lekvandring",
    "lekvandrings": "lekvandring",
    "lekverken": "lekverk",
    "lekverkens": "lekverk",
    "lekverket": "lekverk",
    "lekverkets": "lekverk",
    "lekverks": "lekverk",
    "lemgrammen": "lemgram",
    "lemgrammens": "lemgram",
    "lemgrammet": "lemgram",
    "lemgrammets": "lemgram",
    "lemgrams": "lemgram",
    "lemläst": "lemlästa",
    "lemlästad": "lemlästa",
    "lemlästade": "lemlästa",
    "lemlästades": "lemlästa",
    "lemlästads": "lemlästa",
    "lemlästande": "lemlästa",
    "lemlästanden": "lemlästande",
    "lemlästandena": "lemlästande",
    "lemlästandenas": "lemlästande",
    "lemlästandens": "lemlästande",
    "lemlästandes": "lemlästande",
    "lemlästandet": "lemlästande",
    "lemlästandets": "lemlästande",
    "lemlästar": "lemlästa",
    "lemlästas": "lemlästa",
    "lemlästat": "lemlästa",
    "lemlästats": "lemlästa",
    "lemmalytta": "lemmalytt",
    "lemmalyttare": "lemmalytt",
    "lemmalyttares": "lemmalytt",
    "lemmalyttas": "lemmalytt",
    "lemmalyttast": "lemmalytt",
    "lemmalyttaste": "lemmalytt",
    "lemmalyttastes": "lemmalytt",
    "lemmalyttasts": "lemmalytt",
    "lemmalytte": "lemmalytt",
    "lemmalyttes": "lemmalytt",
    "lemmalyttheten": "lemmalytthet",
    "lemmalytthetens": "lemmalytthet",
    "lemmalytthets": "lemmalytthet",
    "lemmalytts": "lemmalytt",
    "lemman": "lemma",
    "lemmana": "lemma",
    "lemmanas": "lemma",
    "lemmans": "lemma",
    "lemmar": "lem",
    "lemmarna": "lem",
    "lemmarnas": "lem",
    "lemmars": "lem",
    "lemmas": "lemma",
    "lemmat": "lemma",
    "lemmats": "lemma",
    "lemmen": "lem",
    "lemmens": "lem",
    "lemonaden": "lemonad",
    "lemonadens": "lemonad",
    "lemonader": "lemonad",
    "lemonaderna": "lemonad",
    "lemonadernas": "lemonad",
    "lemonaders": "lemonad",
    "lemonads": "lemonad",
    "lems": "lem",
    "lemuren": "lemur",
    "lemurens": "lemur",
    "lemurer": "lemur",
    "lemurerna": "lemur",
    "lemurernas": "lemur",
    "lemurers": "lemur",
    "lemurs": "lemur",
    "len": "lena",
    "lena": "len",
    "lenad": "lena",
    "lenade": "lena",
    "lenades": "lena",
    "lenads": "lena",
    "lenande": "lena",
    "lenanden": "lenande",
    "lenandena": "lenande",
    "lenandenas": "lenande",
    "lenandens": "lenande",
    "lenandes": "lenande",
    "lenandet": "lenande",
    "lenandets": "lenande",
    "lenar": "lena",
    "lenare": "len",
    "lenares": "len",
    "lenas": "lena",
    "lenast": "len",
    "lenaste": "len",
    "lenastes": "len",
    "lenasts": "len",
    "lenat": "lena",
    "lenats": "lena",
    "lene": "len",
    "lenes": "len",
    "lenheten": "lenhet",
    "lenhetens": "lenhet",
    "lenhets": "lenhet",
    "leninismen": "leninism",
    "leninismens": "leninism",
    "leninismer": "leninism",
    "leninismerna": "leninism",
    "leninismernas": "leninism",
    "leninismers": "leninism",
    "leninisms": "leninism",
    "leninistiska": "leninistisk",
    "leninistiskare": "leninistisk",
    "leninistiskares": "leninistisk",
    "leninistiskas": "leninistisk",
    "leninistiskast": "leninistisk",
    "leninistiskaste": "leninistisk",
    "leninistiskastes": "leninistisk",
    "leninistiskasts": "leninistisk",
    "leninistiske": "leninistisk",
    "leninistiskes": "leninistisk",
    "leninistisks": "leninistisk",
    "leninistiskt": "leninistisk",
    "leninistiskts": "leninistisk",
    "lens": "len",
    "lent": "len",
    "lents": "len",
    "leoparden": "leopard",
    "leopardens": "leopard",
    "leoparder": "leopard",
    "leoparderna": "leopard",
    "leopardernas": "leopard",
    "leoparders": "leopard",
    "leopardmönstrade": "leopardmönstrad",
    "leopardmönstrades": "leopardmönstrad",
    "leopardmönstrads": "leopardmönstrad",
    "leopardmönstrat": "leopardmönstrad",
    "leopardmönstrats": "leopardmönstrad",
    "leopards": "leopard",
    "leopardskinnen": "leopardskinn",
    "leopardskinnens": "leopardskinn",
    "leopardskinnet": "leopardskinn",
    "leopardskinnets": "leopardskinn",
    "leopardskinns": "leopardskinn",
    "lepran": "lepra",
    "leprans": "lepra",
    "lepras": "lepra",
    "leprösa": "leprös",
    "leprösare": "leprös",
    "leprösares": "leprös",
    "leprösas": "leprös",
    "leprösast": "leprös",
    "leprösaste": "leprös",
    "leprösastes": "leprös",
    "leprösasts": "leprös",
    "lepröse": "leprös",
    "lepröses": "leprös",
    "lepröst": "leprös",
    "leprösts": "leprös",
    "leptiten": "leptit",
    "leptitens": "leptit",
    "leptits": "leptit",
    "leptosoma": "leptosom",
    "leptosomare": "leptosom",
    "leptosomares": "leptosom",
    "leptosomas": "leptosom",
    "leptosomast": "leptosom",
    "leptosomaste": "leptosom",
    "leptosomastes": "leptosom",
    "leptosomasts": "leptosom",
    "leptosome": "leptosom",
    "leptosomes": "leptosom",
    "leptosoms": "leptosom",
    "leptosomt": "leptosom",
    "leptosomts": "leptosom",
    "ler": "lera",
    "leran": "lera",
    "lerans": "lera",
    "leras": "lera",
    "lerbottens": "lerbotten",
    "lerbottnar": "lerbotten",
    "lerbottnarna": "lerbotten",
    "lerbottnarnas": "lerbotten",
    "lerbottnars": "lerbotten",
    "lerbottnen": "lerbotten",
    "lerbottnens": "lerbotten",
    "lercylindern": "lercylinder",
    "lercylinderns": "lercylinder",
    "lercylinders": "lercylinder",
    "lercylindrar": "lercylinder",
    "lercylindrarna": "lercylinder",
    "lercylindrarnas": "lercylinder",
    "lercylindrars": "lercylinder",
    "lerduv": "lerduva",
    "lerduvan": "lerduva",
    "lerduvans": "lerduva",
    "lerduvas": "lerduva",
    "lerduve": "lerduva",
    "lerduveskyttes": "lerduveskytte",
    "lerduveskyttet": "lerduveskytte",
    "lerduveskyttets": "lerduveskytte",
    "lerduvor": "lerduva",
    "lerduvorna": "lerduva",
    "lerduvornas": "lerduva",
    "lerduvors": "lerduva",
    "lerduvs": "lerduva",
    "lere": "lera",
    "lerfots": "lerfötter",
    "lerfötterna": "lerfötter",
    "lerfötternas": "lerfötter",
    "lerfötters": "lerfötter",
    "lergodset": "lergods",
    "lergodsets": "lergods",
    "lergökar": "lergök",
    "lergökarna": "lergök",
    "lergökarnas": "lergök",
    "lergökars": "lergök",
    "lergöken": "lergök",
    "lergökens": "lergök",
    "lergöks": "lergök",
    "lerhalten": "lerhalt",
    "lerhaltens": "lerhalt",
    "lerhalter": "lerhalt",
    "lerhalterna": "lerhalt",
    "lerhalternas": "lerhalt",
    "lerhalters": "lerhalt",
    "lerhaltiga": "lerhaltig",
    "lerhaltigare": "lerhaltig",
    "lerhaltigares": "lerhaltig",
    "lerhaltigas": "lerhaltig",
    "lerhaltigast": "lerhaltig",
    "lerhaltigaste": "lerhaltig",
    "lerhaltigastes": "lerhaltig",
    "lerhaltigasts": "lerhaltig",
    "lerhaltige": "lerhaltig",
    "lerhaltiges": "lerhaltig",
    "lerhaltigs": "lerhaltig",
    "lerhaltigt": "lerhaltig",
    "lerhaltigts": "lerhaltig",
    "lerhalts": "lerhalt",
    "lerhärdar": "lerhärd",
    "lerhärdarna": "lerhärd",
    "lerhärdarnas": "lerhärd",
    "lerhärdars": "lerhärd",
    "lerhärden": "lerhärd",
    "lerhärdens": "lerhärd",
    "lerhärds": "lerhärd",
    "leriga": "lerig",
    "lerigare": "lerig",
    "lerigares": "lerig",
    "lerigas": "lerig",
    "lerigast": "lerig",
    "lerigaste": "lerig",
    "lerigastes": "lerig",
    "lerigasts": "lerig",
    "lerige": "lerig",
    "leriges": "lerig",
    "lerigs": "lerig",
    "lerigt": "lerig",
    "lerigts": "lerig",
    "lerjordar": "lerjord",
    "lerjordarna": "lerjord",
    "lerjordarnas": "lerjord",
    "lerjordars": "lerjord",
    "lerjorden": "lerjord",
    "lerjordens": "lerjord",
    "lerjords": "lerjord",
    "lerkliningar": "lerklining",
    "lerkliningarna": "lerklining",
    "lerkliningarnas": "lerklining",
    "lerkliningars": "lerklining",
    "lerkliningen": "lerklining",
    "lerkliningens": "lerklining",
    "lerklinings": "lerklining",
    "lerkruk": "lerkruka",
    "lerkrukan": "lerkruka",
    "lerkrukans": "lerkruka",
    "lerkrukas": "lerkruka",
    "lerkruke": "lerkruka",
    "lerkrukor": "lerkruka",
    "lerkrukorna": "lerkruka",
    "lerkrukornas": "lerkruka",
    "lerkrukors": "lerkruka",
    "lerkruks": "lerkruka",
    "lerkärlen": "lerkärl",
    "lerkärlens": "lerkärl",
    "lerkärlet": "lerkärl",
    "lerkärlets": "lerkärl",
    "lerkärls": "lerkärl",
    "leror": "lera",
    "lerorna": "lera",
    "lerornas": "lera",
    "lerors": "lera",
    "lerrasen": "lerras",
    "lerrasens": "lerras",
    "lerraset": "lerras",
    "lerrasets": "lerras",
    "lers": "lera",
    "lerskiffern": "lerskiffer",
    "lerskifferns": "lerskiffer",
    "lerskiffers": "lerskiffer",
    "lerskiffrar": "lerskiffer",
    "lerskiffrarna": "lerskiffer",
    "lerskiffrarnas": "lerskiffer",
    "lerskiffrars": "lerskiffer",
    "lerskärv": "lerskärva",
    "lerskärvan": "lerskärva",
    "lerskärvans": "lerskärva",
    "lerskärvas": "lerskärva",
    "lerskärve": "lerskärva",
    "lerskärvor": "lerskärva",
    "lerskärvorna": "lerskärva",
    "lerskärvornas": "lerskärva",
    "lerskärvors": "lerskärva",
    "lerskärvs": "lerskärva",
    "lerslätten": "lerslätt",
    "lerslättens": "lerslätt",
    "lerslätter": "lerslätt",
    "lerslätterna": "lerslätt",
    "lerslätternas": "lerslätt",
    "lerslätters": "lerslätt",
    "lerslätts": "lerslätt",
    "lerväggar": "lervägg",
    "lerväggarna": "lervägg",
    "lerväggarnas": "lervägg",
    "lerväggars": "lervägg",
    "lerväggen": "lervägg",
    "lerväggens": "lervägg",
    "lerväggs": "lervägg",
    "lervällingar": "lervälling",
    "lervällingarna": "lervälling",
    "lervällingarnas": "lervälling",
    "lervällingars": "lervälling",
    "lervällingen": "lervälling",
    "lervällingens": "lervälling",
    "lervällings": "lervälling",
    "les": "le",
    "lesbiska": "lesbisk",
    "lesbiskare": "lesbisk",
    "lesbiskares": "lesbisk",
    "lesbiskas": "lesbisk",
    "lesbiskast": "lesbisk",
    "lesbiskaste": "lesbisk",
    "lesbiskastes": "lesbisk",
    "lesbiskasts": "lesbisk",
    "lesbiske": "lesbisk",
    "lesbiskes": "lesbisk",
    "lesbisks": "lesbisk",
    "lesbiskt": "lesbisk",
    "lesbiskts": "lesbisk",
    "lesionen": "lesion",
    "lesionens": "lesion",
    "lesioner": "lesion",
    "lesionerna": "lesion",
    "lesionernas": "lesion",
    "lesioners": "lesion",
    "lesions": "lesion",
    "lesothiern": "lesothier",
    "lesothierna": "lesothier",
    "lesothiernas": "lesothier",
    "lesothierns": "lesothier",
    "lesothiers": "lesothier",
    "lesothiska": "lesothisk",
    "lesothiskan": "lesothiska",
    "lesothiskans": "lesothiska",
    "lesothiskare": "lesothisk",
    "lesothiskares": "lesothisk",
    "lesothiskas": "lesothiska",
    "lesothiskast": "lesothisk",
    "lesothiskaste": "lesothisk",
    "lesothiskastes": "lesothisk",
    "lesothiskasts": "lesothisk",
    "lesothiske": "lesothiska",
    "lesothiskes": "lesothisk",
    "lesothiskor": "lesothiska",
    "lesothiskorna": "lesothiska",
    "lesothiskornas": "lesothiska",
    "lesothiskors": "lesothiska",
    "lesothisks": "lesothisk",
    "lesothiskt": "lesothisk",
    "lesothiskts": "lesothisk",
    "lessenheten": "lessenhet",
    "lessenhetens": "lessenhet",
    "lessenheter": "lessenhet",
    "lessenheterna": "lessenhet",
    "lessenheternas": "lessenhet",
    "lessenheters": "lessenhet",
    "lessenhets": "lessenhet",
    "lessens": "lessen",
    "lesset": "lessen",
    "lessets": "lessen",
    "lessna": "lessen",
    "lessnade": "lessna",
    "lessnaden": "lessnad",
    "lessnadens": "lessnad",
    "lessnader": "lessnad",
    "lessnaderna": "lessnad",
    "lessnadernas": "lessnad",
    "lessnaders": "lessnad",
    "lessnades": "lessna",
    "lessnads": "lessnad",
    "lessnande": "lessna",
    "lessnanden": "lessnande",
    "lessnandena": "lessnande",
    "lessnandenas": "lessnande",
    "lessnandens": "lessnande",
    "lessnandes": "lessnande",
    "lessnandet": "lessnande",
    "lessnandets": "lessnande",
    "lessnar": "lessna",
    "lessnare": "lessen",
    "lessnares": "lessen",
    "lessnas": "lessna",
    "lessnast": "lessen",
    "lessnaste": "lessen",
    "lessnastes": "lessen",
    "lessnasts": "lessen",
    "lessnat": "lessna",
    "lessnats": "lessna",
    "lessne": "lessen",
    "lessnes": "lessen",
    "lestadianen": "lestadian",
    "lestadianens": "lestadian",
    "lestadianer": "lestadian",
    "lestadianerna": "lestadian",
    "lestadianernas": "lestadian",
    "lestadianers": "lestadian",
    "lestadianismen": "lestadianism",
    "lestadianismens": "lestadianism",
    "lestadianismer": "lestadianism",
    "lestadianismerna": "lestadianism",
    "lestadianismernas": "lestadianism",
    "lestadianismers": "lestadianism",
    "lestadianisms": "lestadianism",
    "lestadians": "lestadian",
    "let": "leta",
    "letad": "leta",
    "letade": "leta",
    "letades": "leta",
    "letads": "leta",
    "letala": "letal",
    "letalare": "letal",
    "letalares": "letal",
    "letalas": "letal",
    "letalast": "letal",
    "letalaste": "letal",
    "letalastes": "letal",
    "letalasts": "letal",
    "letale": "letal",
    "letales": "letal",
    "letals": "letal",
    "letalt": "letal",
    "letalts": "letal",
    "letande": "leta",
    "letanden": "letande",
    "letandena": "letande",
    "letandenas": "letande",
    "letandens": "letande",
    "letandes": "letande",
    "letandet": "letande",
    "letandets": "letande",
    "letar": "leta",
    "letargien": "letargi",
    "letargiens": "letargi",
    "letargin": "letargi",
    "letargins": "letargi",
    "letargis": "letargi",
    "letargiska": "letargisk",
    "letargiskare": "letargisk",
    "letargiskares": "letargisk",
    "letargiskas": "letargisk",
    "letargiskast": "letargisk",
    "letargiskaste": "letargisk",
    "letargiskastes": "letargisk",
    "letargiskasts": "letargisk",
    "letargiske": "letargisk",
    "letargiskes": "letargisk",
    "letargisks": "letargisk",
    "letargiskt": "letargisk",
    "letargiskts": "letargisk",
    "letas": "leta",
    "letat": "leta",
    "letats": "leta",
    "lets": "l",
    "lett": "leda",
    "letten": "lett",
    "lettens": "lett",
    "letter": "lettra",
    "letterna": "lett",
    "letternas": "lett",
    "letters": "lett",
    "lettisk": "lettiska",
    "lettiska": "lettisk",
    "lettiskan": "lettiska",
    "lettiskans": "lettiska",
    "lettiskare": "lettisk",
    "lettiskares": "lettisk",
    "lettiskas": "lettiska",
    "lettiskast": "lettisk",
    "lettiskaste": "lettisk",
    "lettiskastes": "lettisk",
    "lettiskasts": "lettisk",
    "lettiske": "lettiska",
    "lettiskes": "lettisk",
    "lettiskor": "lettiska",
    "lettiskorna": "lettiska",
    "lettiskornas": "lettiska",
    "lettiskors": "lettiska",
    "lettisks": "lettisk",
    "lettiskt": "lettisk",
    "lettiskts": "lettisk",
    "lettländar": "lettländare",
    "lettländaren": "lettländare",
    "lettländarens": "lettländare",
    "lettländares": "lettländare",
    "lettländarna": "lettländare",
    "lettländarnas": "lettländare",
    "lettländsk": "lettländska",
    "lettländskan": "lettländska",
    "lettländskans": "lettländska",
    "lettländskas": "lettländska",
    "lettländske": "lettländska",
    "lettländskor": "lettländska",
    "lettländskorna": "lettländska",
    "lettländskornas": "lettländska",
    "lettländskors": "lettländska",
    "lettrad": "lettra",
    "lettrade": "lettra",
    "lettrades": "lettra",
    "lettrads": "lettra",
    "lettrande": "lettra",
    "lettranden": "lettrande",
    "lettrandena": "lettrande",
    "lettrandenas": "lettrande",
    "lettrandens": "lettrande",
    "lettrandes": "lettrande",
    "lettrandet": "lettrande",
    "lettrandets": "lettrande",
    "lettrar": "lettra",
    "lettras": "lettra",
    "lettrat": "lettra",
    "lettrats": "lettra",
    "letts": "lett",
    "leukemien": "leukemi",
    "leukemiens": "leukemi",
    "leukemier": "leukemi",
    "leukemierna": "leukemi",
    "leukemiernas": "leukemi",
    "leukemiers": "leukemi",
    "leukemin": "leukemi",
    "leukemins": "leukemi",
    "leukemis": "leukemi",
    "leukocyten": "leukocyt",
    "leukocytens": "leukocyt",
    "leukocyter": "leukocyt",
    "leukocyterna": "leukocyt",
    "leukocyternas": "leukocyt",
    "leukocyters": "leukocyt",
    "leukocyts": "leukocyt",
    "lev": "leva",
    "levan": "leva",
    "levana": "leva",
    "levanas": "leva",
    "levande": "leva",
    "levandegjord": "levandegöra",
    "levandegjorda": "levandegöra",
    "levandegjordas": "levandegöra",
    "levandegjorde": "levandegöra",
    "levandegjordes": "levandegöra",
    "levandegjords": "levandegöra",
    "levandegjort": "levandegöra",
    "levandegjorts": "levandegöra",
    "levandegör": "levandegöra",
    "levandegörande": "levandegöra",
    "levandegöranden": "levandegörande",
    "levandegörandena": "levandegörande",
    "levandegörandenas": "levandegörande",
    "levandegörandens": "levandegörande",
    "levandegörandes": "levandegörande",
    "levandegörandet": "levandegörande",
    "levandegörandets": "levandegörande",
    "levandegöras": "levandegöra",
    "levandegöres": "levandegöra",
    "levandegörs": "levandegöra",
    "levanden": "levande",
    "levandena": "levande",
    "levandenas": "levande",
    "levandens": "levande",
    "levandes": "levande",
    "levandet": "levande",
    "levandets": "levande",
    "levangen": "levang",
    "levangens": "levang",
    "levanger": "levang",
    "levangerna": "levang",
    "levangernas": "levang",
    "levangers": "levang",
    "levangs": "levang",
    "levans": "leva",
    "levantinen": "levantin",
    "levantinens": "levantin",
    "levantiner": "levantin",
    "levantinerna": "levantin",
    "levantinernas": "levantin",
    "levantiners": "levantin",
    "levantins": "levantin",
    "levar": "lev",
    "levarna": "lev",
    "levarnas": "lev",
    "levars": "lev",
    "levas": "leva",
    "levat": "leva",
    "levats": "leva",
    "levd": "leva",
    "levda": "leva",
    "levdas": "leva",
    "levde": "leva",
    "levdes": "leva",
    "levds": "leva",
    "levebrödet": "levebröd",
    "levebrödets": "levebröd",
    "levebröds": "levebröd",
    "leven": "leve",
    "levena": "leve",
    "levenas": "leve",
    "levens": "leve",
    "lever": "leva",
    "leverabeln": "leverabel",
    "leverabelns": "leverabel",
    "leverabels": "leverabel",
    "leverabler": "leverabel",
    "leverablerna": "leverabel",
    "leverablernas": "leverabel",
    "leverablers": "leverabel",
    "leveransavtalen": "leveransavtal",
    "leveransavtalens": "leveransavtal",
    "leveransavtalet": "leveransavtal",
    "leveransavtalets": "leveransavtal",
    "leveransavtals": "leveransavtal",
    "leveransen": "leverans",
    "leveransens": "leverans",
    "leveranser": "leverans",
    "leveranserna": "leverans",
    "leveransernas": "leverans",
    "leveransers": "leverans",
    "leveransklara": "leveransklar",
    "leveransklarare": "leveransklar",
    "leveransklarares": "leveransklar",
    "leveransklaras": "leveransklar",
    "leveransklarast": "leveransklar",
    "leveransklaraste": "leveransklar",
    "leveransklarastes": "leveransklar",
    "leveransklarasts": "leveransklar",
    "leveransklare": "leveransklar",
    "leveransklares": "leveransklar",
    "leveransklars": "leveransklar",
    "leveransklart": "leveransklar",
    "leveransklarts": "leveransklar",
    "leveranstiden": "leveranstid",
    "leveranstidens": "leveranstid",
    "leveranstider": "leveranstid",
    "leveranstiderna": "leveranstid",
    "leveranstidernas": "leveranstid",
    "leveranstiders": "leveranstid",
    "leveranstids": "leveranstid",
    "leverantören": "leverantör",
    "leverantörens": "leverantör",
    "leverantörer": "leverantör",
    "leverantörerna": "leverantör",
    "leverantörernas": "leverantör",
    "leverantörers": "leverantör",
    "leverantörs": "leverantör",
    "leverbruna": "leverbrun",
    "leverbrunare": "leverbrun",
    "leverbrunares": "leverbrun",
    "leverbrunas": "leverbrun",
    "leverbrunast": "leverbrun",
    "leverbrunaste": "leverbrun",
    "leverbrunastes": "leverbrun",
    "leverbrunasts": "leverbrun",
    "leverbrune": "leverbrun",
    "leverbrunes": "leverbrun",
    "leverbruns": "leverbrun",
    "leverbrunt": "leverbrun",
    "leverbrunts": "leverbrun",
    "levercellen": "levercell",
    "levercellens": "levercell",
    "leverceller": "levercell",
    "levercellerna": "levercell",
    "levercellernas": "levercell",
    "levercellers": "levercell",
    "levercells": "levercell",
    "levererad": "leverera",
    "levererade": "leverera",
    "levererades": "leverera",
    "levererads": "leverera",
    "levererande": "leverera",
    "levereranden": "levererande",
    "levererandena": "levererande",
    "levererandenas": "levererande",
    "levererandens": "levererande",
    "levererandes": "levererande",
    "levererandet": "levererande",
    "levererandets": "levererande",
    "levererar": "leverera",
    "levereras": "leverera",
    "levererat": "leverera",
    "levererats": "leverera",
    "levererbara": "levererbar",
    "levererbarare": "levererbar",
    "levererbarares": "levererbar",
    "levererbaras": "levererbar",
    "levererbarast": "levererbar",
    "levererbaraste": "levererbar",
    "levererbarastes": "levererbar",
    "levererbarasts": "levererbar",
    "levererbare": "levererbar",
    "levererbares": "levererbar",
    "levererbarheten": "levererbarhet",
    "levererbarhetens": "levererbarhet",
    "levererbarhets": "levererbarhet",
    "levererbars": "levererbar",
    "levererbart": "levererbar",
    "levererbarts": "levererbar",
    "levereringar": "leverering",
    "levereringarna": "leverering",
    "levereringarnas": "leverering",
    "levereringars": "leverering",
    "levereringen": "leverering",
    "levereringens": "leverering",
    "levererings": "leverering",
    "leverfläckar": "leverfläck",
    "leverfläckarna": "leverfläck",
    "leverfläckarnas": "leverfläck",
    "leverfläckars": "leverfläck",
    "leverfläcken": "leverfläck",
    "leverfläckens": "leverfläck",
    "leverfläcks": "leverfläck",
    "levermoss": "levermossa",
    "levermossan": "levermossa",
    "levermossans": "levermossa",
    "levermossas": "levermossa",
    "levermosse": "levermossa",
    "levermossor": "levermossa",
    "levermossorna": "levermossa",
    "levermossornas": "levermossa",
    "levermossors": "levermossa",
    "levern": "lever",
    "levernes": "leverne",
    "levernet": "leverne",
    "levernets": "leverne",
    "leverns": "lever",
    "leveropen": "leverop",
    "leveropens": "leverop",
    "leveropet": "leverop",
    "leveropets": "leverop",
    "leverops": "leverop",
    "leverpastejen": "leverpastej",
    "leverpastejens": "leverpastej",
    "leverpastejer": "leverpastej",
    "leverpastejerna": "leverpastej",
    "leverpastejernas": "leverpastej",
    "leverpastejers": "leverpastej",
    "leverpastejs": "leverpastej",
    "leverpastejsmörgåsar": "leverpastejsmörgås",
    "leverpastejsmörgåsarna": "leverpastejsmörgås",
    "leverpastejsmörgåsarnas": "leverpastejsmörgås",
    "leverpastejsmörgåsars": "leverpastejsmörgås",
    "leverpastejsmörgåsen": "leverpastejsmörgås",
    "leverpastejsmörgåsens": "leverpastejsmörgås",
    "levers": "lever",
    "leverskrumpningar": "leverskrumpning",
    "leverskrumpningarna": "leverskrumpning",
    "leverskrumpningarnas": "leverskrumpning",
    "leverskrumpningars": "leverskrumpning",
    "leverskrumpningen": "leverskrumpning",
    "leverskrumpningens": "leverskrumpning",
    "leverskrumpnings": "leverskrumpning",
    "levertranen": "levertran",
    "levertranens": "levertran",
    "levertrans": "levertran",
    "leves": "leve",
    "levet": "leve",
    "levets": "leve",
    "leviten": "levit",
    "levitens": "levit",
    "leviter": "levit",
    "leviterna": "levit",
    "leviternas": "levit",
    "leviters": "levit",
    "levits": "levit",
    "levnaden": "levnad",
    "levnadens": "levnad",
    "levnader": "levnad",
    "levnaderna": "levnad",
    "levnadernas": "levnad",
    "levnaders": "levnad",
    "levnads": "levnad",
    "levnadsaftonen": "levnadsafton",
    "levnadsaftonens": "levnadsafton",
    "levnadsaftons": "levnadsafton",
    "levnadsbanan": "levnadsbana",
    "levnadsbanans": "levnadsbana",
    "levnadsbanas": "levnadsbana",
    "levnadsbane": "levnadsbana",
    "levnadsbanor": "levnadsbana",
    "levnadsbanorna": "levnadsbana",
    "levnadsbanornas": "levnadsbana",
    "levnadsbanors": "levnadsbana",
    "levnadsbeskrivningar": "levnadsbeskrivning",
    "levnadsbeskrivningarna": "levnadsbeskrivning",
    "levnadsbeskrivningarnas": "levnadsbeskrivning",
    "levnadsbeskrivningars": "levnadsbeskrivning",
    "levnadsbeskrivningen": "levnadsbeskrivning",
    "levnadsbeskrivningens": "levnadsbeskrivning",
    "levnadsbeskrivnings": "levnadsbeskrivning",
    "levnadsglada": "levnadsglad",
    "levnadsgladare": "levnadsglad",
    "levnadsgladares": "levnadsglad",
    "levnadsgladas": "levnadsglad",
    "levnadsgladast": "levnadsglad",
    "levnadsgladaste": "levnadsglad",
    "levnadsgladastes": "levnadsglad",
    "levnadsgladasts": "levnadsglad",
    "levnadsglade": "levnadsglad",
    "levnadsglades": "levnadsglad",
    "levnadsglads": "levnadsglad",
    "levnadsglatt": "levnadsglad",
    "levnadsglatts": "levnadsglad",
    "levnadskonsten": "levnadskonst",
    "levnadskonstens": "levnadskonst",
    "levnadskonstnären": "levnadskonstnär",
    "levnadskonstnärens": "levnadskonstnär",
    "levnadskonstnärer": "levnadskonstnär",
    "levnadskonstnärerna": "levnadskonstnär",
    "levnadskonstnärernas": "levnadskonstnär",
    "levnadskonstnärers": "levnadskonstnär",
    "levnadskonstnärs": "levnadskonstnär",
    "levnadskonsts": "levnadskonst",
    "levnadskostnaden": "levnadskostnad",
    "levnadskostnadens": "levnadskostnad",
    "levnadskostnader": "levnadskostnad",
    "levnadskostnaderna": "levnadskostnad",
    "levnadskostnadernas": "levnadskostnad",
    "levnadskostnaders": "levnadskostnad",
    "levnadskostnads": "levnadskostnad",
    "levnadsloppen": "levnadslopp",
    "levnadsloppens": "levnadslopp",
    "levnadsloppet": "levnadslopp",
    "levnadsloppets": "levnadslopp",
    "levnadslopps": "levnadslopp",
    "levnadsmönsterna": "levnadsmönster",
    "levnadsmönsternas": "levnadsmönster",
    "levnadsmönsters": "levnadsmönster",
    "levnadsmönstren": "levnadsmönster",
    "levnadsmönstrens": "levnadsmönster",
    "levnadsmönstret": "levnadsmönster",
    "levnadsmönstrets": "levnadsmönster",
    "levnadsnivåer": "levnadsnivå",
    "levnadsnivåerna": "levnadsnivå",
    "levnadsnivåernas": "levnadsnivå",
    "levnadsnivåers": "levnadsnivå",
    "levnadsnivån": "levnadsnivå",
    "levnadsnivåns": "levnadsnivå",
    "levnadsnivås": "levnadsnivå",
    "levnadsregeln": "levnadsregel",
    "levnadsregelns": "levnadsregel",
    "levnadsregels": "levnadsregel",
    "levnadsregler": "levnadsregel",
    "levnadsreglerna": "levnadsregel",
    "levnadsreglernas": "levnadsregel",
    "levnadsreglers": "levnadsregel",
    "levnadsstandarden": "levnadsstandard",
    "levnadsstandardens": "levnadsstandard",
    "levnadsstandards": "levnadsstandard",
    "levnadssätten": "levnadssätt",
    "levnadssättens": "levnadssätt",
    "levnadssättet": "levnadssätt",
    "levnadssättets": "levnadssätt",
    "levnadssätts": "levnadssätt",
    "levnadstecknar": "levnadstecknare",
    "levnadstecknaren": "levnadstecknare",
    "levnadstecknarens": "levnadstecknare",
    "levnadstecknares": "levnadstecknare",
    "levnadstecknarna": "levnadstecknare",
    "levnadstecknarnas": "levnadstecknare",
    "levnadsteckningar": "levnadsteckning",
    "levnadsteckningarna": "levnadsteckning",
    "levnadsteckningarnas": "levnadsteckning",
    "levnadsteckningars": "levnadsteckning",
    "levnadsteckningen": "levnadsteckning",
    "levnadsteckningens": "levnadsteckning",
    "levnadstecknings": "levnadsteckning",
    "levnadströtta": "levnadstrött",
    "levnadströttare": "levnadstrött",
    "levnadströttares": "levnadstrött",
    "levnadströttas": "levnadstrött",
    "levnadströttast": "levnadstrött",
    "levnadströttaste": "levnadstrött",
    "levnadströttastes": "levnadstrött",
    "levnadströttasts": "levnadstrött",
    "levnadströtte": "levnadstrött",
    "levnadströttes": "levnadstrött",
    "levnadströttheten": "levnadströtthet",
    "levnadströtthetens": "levnadströtthet",
    "levnadströtthets": "levnadströtthet",
    "levnadströtts": "levnadstrött",
    "levnadsvisdomar": "levnadsvisdom",
    "levnadsvisdomarna": "levnadsvisdom",
    "levnadsvisdomarnas": "levnadsvisdom",
    "levnadsvisdomars": "levnadsvisdom",
    "levnadsvisdomen": "levnadsvisdom",
    "levnadsvisdomens": "levnadsvisdom",
    "levnadsvisdoms": "levnadsvisdom",
    "levnadsåldern": "levnadsålder",
    "levnadsålderns": "levnadsålder",
    "levnadsålders": "levnadsålder",
    "levnadsåldrar": "levnadsålder",
    "levnadsåldrarna": "levnadsålder",
    "levnadsåldrarnas": "levnadsålder",
    "levnadsåldrars": "levnadsålder",
    "levnadsåren": "levnadsår",
    "levnadsårens": "levnadsår",
    "levnadsåret": "levnadsår",
    "levnadsårets": "levnadsår",
    "levnadsårs": "levnadsår",
    "levnadsöden": "levnadsöde",
    "levnadsödena": "levnadsöde",
    "levnadsödenas": "levnadsöde",
    "levnadsödens": "levnadsöde",
    "levnadsödes": "levnadsöde",
    "levnadsödet": "levnadsöde",
    "levnadsödets": "levnadsöde",
    "levrades": "levras",
    "levrar": "lever",
    "levrarna": "lever",
    "levrarnas": "lever",
    "levrars": "lever",
    "levrats": "levras",
    "levs": "leva",
    "levt": "leva",
    "levts": "leva",
    "lexemen": "lexem",
    "lexemens": "lexem",
    "lexemet": "lexem",
    "lexemets": "lexem",
    "lexems": "lexem",
    "lexfrasen": "lexfras",
    "lexfrasens": "lexfras",
    "lexfraser": "lexfras",
    "lexfraserna": "lexfras",
    "lexfrasernas": "lexfras",
    "lexfrasers": "lexfras",
    "lexika": "lexikon",
    "lexikala": "lexikal",
    "lexikalare": "lexikal",
    "lexikalares": "lexikal",
    "lexikalas": "lexikal",
    "lexikalast": "lexikal",
    "lexikalaste": "lexikal",
    "lexikalastes": "lexikal",
    "lexikalasts": "lexikal",
    "lexikale": "lexikal",
    "lexikales": "lexikal",
    "lexikaliska": "lexikalisk",
    "lexikaliskare": "lexikalisk",
    "lexikaliskares": "lexikalisk",
    "lexikaliskas": "lexikalisk",
    "lexikaliskast": "lexikalisk",
    "lexikaliskaste": "lexikalisk",
    "lexikaliskastes": "lexikalisk",
    "lexikaliskasts": "lexikalisk",
    "lexikaliske": "lexikalisk",
    "lexikaliskes": "lexikalisk",
    "lexikalisks": "lexikalisk",
    "lexikaliskt": "lexikalisk",
    "lexikaliskts": "lexikalisk",
    "lexikals": "lexikal",
    "lexikalt": "lexikal",
    "lexikalts": "lexikal",
    "lexikas": "lexikon",
    "lexikografen": "lexikograf",
    "lexikografens": "lexikograf",
    "lexikografer": "lexikograf",
    "lexikograferna": "lexikograf",
    "lexikografernas": "lexikograf",
    "lexikografers": "lexikograf",
    "lexikografien": "lexikografi",
    "lexikografiens": "lexikografi",
    "lexikografin": "lexikografi",
    "lexikografins": "lexikografi",
    "lexikografis": "lexikografi",
    "lexikografiska": "lexikografisk",
    "lexikografiskare": "lexikografisk",
    "lexikografiskares": "lexikografisk",
    "lexikografiskas": "lexikografisk",
    "lexikografiskast": "lexikografisk",
    "lexikografiskaste": "lexikografisk",
    "lexikografiskastes": "lexikografisk",
    "lexikografiskasts": "lexikografisk",
    "lexikografiske": "lexikografisk",
    "lexikografiskes": "lexikografisk",
    "lexikografisks": "lexikografisk",
    "lexikografiskt": "lexikografisk",
    "lexikografiskts": "lexikografisk",
    "lexikografs": "lexikograf",
    "lexikologen": "lexikolog",
    "lexikologens": "lexikolog",
    "lexikologer": "lexikolog",
    "lexikologerna": "lexikolog",
    "lexikologernas": "lexikolog",
    "lexikologers": "lexikolog",
    "lexikologien": "lexikologi",
    "lexikologiens": "lexikologi",
    "lexikologin": "lexikologi",
    "lexikologins": "lexikologi",
    "lexikologis": "lexikologi",
    "lexikologiska": "lexikologisk",
    "lexikologiskare": "lexikologisk",
    "lexikologiskares": "lexikologisk",
    "lexikologiskas": "lexikologisk",
    "lexikologiskast": "lexikologisk",
    "lexikologiskaste": "lexikologisk",
    "lexikologiskastes": "lexikologisk",
    "lexikologiskasts": "lexikologisk",
    "lexikologiske": "lexikologisk",
    "lexikologiskes": "lexikologisk",
    "lexikologisks": "lexikologisk",
    "lexikologiskt": "lexikologisk",
    "lexikologiskts": "lexikologisk",
    "lexikologs": "lexikolog",
    "lexikonen": "lexikon",
    "lexikonens": "lexikon",
    "lexikonet": "lexikon",
    "lexikonets": "lexikon",
    "lexikonprojekten": "lexikonprojekt",
    "lexikonprojektens": "lexikonprojekt",
    "lexikonprojektet": "lexikonprojekt",
    "lexikonprojektets": "lexikonprojekt",
    "lexikonprojekts": "lexikonprojekt",
    "lexikons": "lexikon",
    "lexikostatistiken": "lexikostatistik",
    "lexikostatistikens": "lexikostatistik",
    "lexikostatistiks": "lexikostatistik",
    "lexikostatistiska": "lexikostatistisk",
    "lexikostatistiskare": "lexikostatistisk",
    "lexikostatistiskares": "lexikostatistisk",
    "lexikostatistiskas": "lexikostatistisk",
    "lexikostatistiskast": "lexikostatistisk",
    "lexikostatistiskaste": "lexikostatistisk",
    "lexikostatistiskastes": "lexikostatistisk",
    "lexikostatistiskasts": "lexikostatistisk",
    "lexikostatistiske": "lexikostatistisk",
    "lexikostatistiskes": "lexikostatistisk",
    "lexikostatistisks": "lexikostatistisk",
    "lexikostatistiskt": "lexikostatistisk",
    "lexikostatistiskts": "lexikostatistisk",
    "li": "lie",
    "lianen": "lian",
    "lianens": "lian",
    "lianer": "lian",
    "lianerna": "lian",
    "lianernas": "lian",
    "lianers": "lian",
    "lians": "lian",
    "liar": "lie",
    "liarna": "lie",
    "liarnas": "lie",
    "liars": "lie",
    "liasen": "lias",
    "liasens": "lias",
    "libanesen": "libanes",
    "libanesens": "libanes",
    "libaneser": "libanes",
    "libaneserna": "libanes",
    "libanesernas": "libanes",
    "libanesers": "libanes",
    "libanesiska": "libanesisk",
    "libanesiskan": "libanesiska",
    "libanesiskans": "libanesiska",
    "libanesiskare": "libanesisk",
    "libanesiskares": "libanesisk",
    "libanesiskas": "libanesiska",
    "libanesiskast": "libanesisk",
    "libanesiskaste": "libanesisk",
    "libanesiskastes": "libanesisk",
    "libanesiskasts": "libanesisk",
    "libanesiske": "libanesiska",
    "libanesiskes": "libanesisk",
    "libanesiskor": "libanesiska",
    "libanesiskorna": "libanesiska",
    "libanesiskornas": "libanesiska",
    "libanesiskors": "libanesiska",
    "libanesisks": "libanesisk",
    "libanesiskt": "libanesisk",
    "libanesiskts": "libanesisk",
    "libationen": "libation",
    "libationens": "libation",
    "libationer": "libation",
    "libationerna": "libation",
    "libationernas": "libation",
    "libationers": "libation",
    "libations": "libation",
    "libbstick": "libbsticka",
    "libbstickan": "libbsticka",
    "libbstickans": "libbsticka",
    "libbstickas": "libbsticka",
    "libbsticke": "libbsticka",
    "libbstickor": "libbsticka",
    "libbstickorna": "libbsticka",
    "libbstickornas": "libbsticka",
    "libbstickors": "libbsticka",
    "libbsticks": "libbsticka",
    "libellen": "libell",
    "libellens": "libell",
    "libeller": "libell",
    "libellerna": "libell",
    "libellernas": "libell",
    "libellers": "libell",
    "libells": "libell",
    "liberala": "liberal",
    "liberalare": "liberal",
    "liberalares": "liberal",
    "liberalas": "liberal",
    "liberalast": "liberal",
    "liberalaste": "liberal",
    "liberalastes": "liberal",
    "liberalasts": "liberal",
    "liberale": "liberal",
    "liberalen": "liberal",
    "liberalens": "liberal",
    "liberaler": "liberal",
    "liberalerna": "liberal",
    "liberalernas": "liberal",
    "liberalers": "liberal",
    "liberales": "liberal",
    "liberaliserad": "liberalisera",
    "liberaliserade": "liberalisera",
    "liberaliserades": "liberalisera",
    "liberaliserads": "liberalisera",
    "liberaliserande": "liberalisera",
    "liberaliseranden": "liberaliserande",
    "liberaliserandena": "liberaliserande",
    "liberaliserandenas": "liberaliserande",
    "liberaliserandens": "liberaliserande",
    "liberaliserandes": "liberaliserande",
    "liberaliserandet": "liberaliserande",
    "liberaliserandets": "liberaliserande",
    "liberaliserar": "liberalisera",
    "liberaliseras": "liberalisera",
    "liberaliserat": "liberalisera",
    "liberaliserats": "liberalisera",
    "liberaliserbara": "liberaliserbar",
    "liberaliserbarare": "liberaliserbar",
    "liberaliserbarares": "liberaliserbar",
    "liberaliserbaras": "liberaliserbar",
    "liberaliserbarast": "liberaliserbar",
    "liberaliserbaraste": "liberaliserbar",
    "liberaliserbarastes": "liberaliserbar",
    "liberaliserbarasts": "liberaliserbar",
    "liberaliserbare": "liberaliserbar",
    "liberaliserbares": "liberaliserbar",
    "liberaliserbarheten": "liberaliserbarhet",
    "liberaliserbarhetens": "liberaliserbarhet",
    "liberaliserbarhets": "liberaliserbarhet",
    "liberaliserbars": "liberaliserbar",
    "liberaliserbart": "liberaliserbar",
    "liberaliserbarts": "liberaliserbar",
    "liberaliseringar": "liberalisering",
    "liberaliseringarna": "liberalisering",
    "liberaliseringarnas": "liberalisering",
    "liberaliseringars": "liberalisering",
    "liberaliseringen": "liberalisering",
    "liberaliseringens": "liberalisering",
    "liberaliserings": "liberalisering",
    "liberalismen": "liberalism",
    "liberalismens": "liberalism",
    "liberalismer": "liberalism",
    "liberalismerna": "liberalism",
    "liberalismernas": "liberalism",
    "liberalismers": "liberalism",
    "liberalisms": "liberalism",
    "liberalistiska": "liberalistisk",
    "liberalistiskas": "liberalistisk",
    "liberalistiske": "liberalistisk",
    "liberalistiskes": "liberalistisk",
    "liberalistisks": "liberalistisk",
    "liberalistiskt": "liberalistisk",
    "liberalistiskts": "liberalistisk",
    "liberals": "liberal",
    "liberalt": "liberal",
    "liberalts": "liberal",
    "liberianen": "liberian",
    "liberianens": "liberian",
    "liberianer": "liberian",
    "liberianerna": "liberian",
    "liberianernas": "liberian",
    "liberianers": "liberian",
    "liberians": "liberian",
    "liberianska": "liberiansk",
    "liberianskan": "liberianska",
    "liberianskans": "liberianska",
    "liberianskare": "liberiansk",
    "liberianskares": "liberiansk",
    "liberianskas": "liberianska",
    "liberianskast": "liberiansk",
    "liberianskaste": "liberiansk",
    "liberianskastes": "liberiansk",
    "liberianskasts": "liberiansk",
    "liberianske": "liberianska",
    "liberianskes": "liberiansk",
    "liberianskor": "liberianska",
    "liberianskorna": "liberianska",
    "liberianskornas": "liberianska",
    "liberianskors": "liberianska",
    "liberiansks": "liberiansk",
    "liberianskt": "liberiansk",
    "liberianskts": "liberiansk",
    "liberiern": "liberier",
    "liberierna": "liberier",
    "liberiernas": "liberier",
    "liberierns": "liberier",
    "liberiers": "liberier",
    "liberiska": "liberisk",
    "liberiskare": "liberisk",
    "liberiskares": "liberisk",
    "liberiskas": "liberisk",
    "liberiskast": "liberisk",
    "liberiskaste": "liberisk",
    "liberiskastes": "liberisk",
    "liberiskasts": "liberisk",
    "liberiske": "liberisk",
    "liberiskes": "liberisk",
    "liberisks": "liberisk",
    "liberiskt": "liberisk",
    "liberiskts": "liberisk",
    "liberoer": "libero",
    "liberoerna": "libero",
    "liberoernas": "libero",
    "liberoers": "libero",
    "liberon": "libero",
    "liberons": "libero",
    "liberor": "libero",
    "liberorna": "libero",
    "liberornas": "libero",
    "liberors": "libero",
    "liberos": "libero",
    "libertinen": "libertin",
    "libertinens": "libertin",
    "libertiner": "libertin",
    "libertinerna": "libertin",
    "libertinernas": "libertin",
    "libertiners": "libertin",
    "libertinismen": "libertinism",
    "libertinismens": "libertinism",
    "libertinismer": "libertinism",
    "libertinismerna": "libertinism",
    "libertinismernas": "libertinism",
    "libertinismers": "libertinism",
    "libertinisms": "libertinism",
    "libertins": "libertin",
    "libidon": "libido",
    "libidona": "libido",
    "libidonas": "libido",
    "libidons": "libido",
    "libidos": "libido",
    "libidot": "libido",
    "libidots": "libido",
    "librationen": "libration",
    "librationens": "libration",
    "librationer": "libration",
    "librationerna": "libration",
    "librationernas": "libration",
    "librationers": "libration",
    "librations": "libration",
    "librettisten": "librettist",
    "librettistens": "librettist",
    "librettister": "librettist",
    "librettisterna": "librettist",
    "librettisternas": "librettist",
    "librettisters": "librettist",
    "librettists": "librettist",
    "libretton": "libretto",
    "librettona": "libretto",
    "librettonas": "libretto",
    "librettons": "libretto",
    "librettor": "libretto",
    "librettorna": "libretto",
    "librettornas": "libretto",
    "librettors": "libretto",
    "librettos": "libretto",
    "librettot": "libretto",
    "librettots": "libretto",
    "libstick": "libsticka",
    "libstickan": "libsticka",
    "libstickans": "libsticka",
    "libstickas": "libsticka",
    "libsticke": "libsticka",
    "libstickor": "libsticka",
    "libstickorna": "libsticka",
    "libstickornas": "libsticka",
    "libstickors": "libsticka",
    "libsticks": "libsticka",
    "libyern": "libyer",
    "libyerna": "libyer",
    "libyernas": "libyer",
    "libyerns": "libyer",
    "libyers": "libyer",
    "libyska": "libysk",
    "libyskan": "libyska",
    "libyskans": "libyska",
    "libyskare": "libysk",
    "libyskares": "libysk",
    "libyskas": "libyska",
    "libyskast": "libysk",
    "libyskaste": "libysk",
    "libyskastes": "libysk",
    "libyskasts": "libysk",
    "libyske": "libyska",
    "libyskes": "libysk",
    "libyskor": "libyska",
    "libyskorna": "libyska",
    "libyskornas": "libyska",
    "libyskors": "libyska",
    "libysks": "libysk",
    "libyskt": "libysk",
    "libyskts": "libysk",
    "licensbela": "licensbelägga",
    "licensbelade": "licensbelägga",
    "licensbelades": "licensbelägga",
    "licensbelagd": "licensbelägga",
    "licensbelagda": "licensbelägga",
    "licensbelagdas": "licensbelägga",
    "licensbelagde": "licensbelägga",
    "licensbelagdes": "licensbelägga",
    "licensbelagds": "licensbelägga",
    "licensbelagt": "licensbelägga",
    "licensbelagts": "licensbelägga",
    "licensbelas": "licensbelägga",
    "licensbelägg": "licensbelägga",
    "licensbeläggande": "licensbelägga",
    "licensbelägganden": "licensbeläggande",
    "licensbeläggandena": "licensbeläggande",
    "licensbeläggandenas": "licensbeläggande",
    "licensbeläggandens": "licensbeläggande",
    "licensbeläggandes": "licensbeläggande",
    "licensbeläggandet": "licensbeläggande",
    "licensbeläggandets": "licensbeläggande",
    "licensbeläggas": "licensbelägga",
    "licensbelägger": "licensbelägga",
    "licensbelägges": "licensbelägga",
    "licensbeläggs": "licensbelägga",
    "licensen": "licens",
    "licensens": "licens",
    "licenser": "licens",
    "licenserad": "licensera",
    "licenserade": "licensera",
    "licenserades": "licensera",
    "licenserads": "licensera",
    "licenserande": "licensera",
    "licenseranden": "licenserande",
    "licenserandena": "licenserande",
    "licenserandenas": "licenserande",
    "licenserandens": "licenserande",
    "licenserandes": "licenserande",
    "licenserandet": "licenserande",
    "licenserandets": "licenserande",
    "licenserar": "licensera",
    "licenseras": "licensera",
    "licenserat": "licensera",
    "licenserats": "licensera",
    "licenserbara": "licenserbar",
    "licenserbarare": "licenserbar",
    "licenserbarares": "licenserbar",
    "licenserbaras": "licenserbar",
    "licenserbarast": "licenserbar",
    "licenserbaraste": "licenserbar",
    "licenserbarastes": "licenserbar",
    "licenserbarasts": "licenserbar",
    "licenserbare": "licenserbar",
    "licenserbares": "licenserbar",
    "licenserbarheten": "licenserbarhet",
    "licenserbarhetens": "licenserbarhet",
    "licenserbarhets": "licenserbarhet",
    "licenserbars": "licenserbar",
    "licenserbart": "licenserbar",
    "licenserbarts": "licenserbar",
    "licenseringar": "licensering",
    "licenseringarna": "licensering",
    "licenseringarnas": "licensering",
    "licenseringars": "licensering",
    "licenseringen": "licensering",
    "licenseringens": "licensering",
    "licenserings": "licensering",
    "licenserna": "licens",
    "licensernas": "licens",
    "licensers": "licens",
    "licensfria": "licensfri",
    "licensfriare": "licensfri",
    "licensfriares": "licensfri",
    "licensfrias": "licensfri",
    "licensfriast": "licensfri",
    "licensfriaste": "licensfri",
    "licensfriastes": "licensfri",
    "licensfriasts": "licensfri",
    "licensfrie": "licensfri",
    "licensfries": "licensfri",
    "licensfris": "licensfri",
    "licensfritt": "licensfri",
    "licensfritts": "licensfri",
    "licensierad": "licensiera",
    "licensierade": "licensiera",
    "licensierades": "licensiera",
    "licensierads": "licensiera",
    "licensierande": "licensiera",
    "licensieranden": "licensierande",
    "licensierandena": "licensierande",
    "licensierandenas": "licensierande",
    "licensierandens": "licensierande",
    "licensierandes": "licensierande",
    "licensierandet": "licensierande",
    "licensierandets": "licensierande",
    "licensierar": "licensiera",
    "licensieras": "licensiera",
    "licensierat": "licensiera",
    "licensierats": "licensiera",
    "licensierbara": "licensierbar",
    "licensierbarare": "licensierbar",
    "licensierbarares": "licensierbar",
    "licensierbaras": "licensierbar",
    "licensierbarast": "licensierbar",
    "licensierbaraste": "licensierbar",
    "licensierbarastes": "licensierbar",
    "licensierbarasts": "licensierbar",
    "licensierbare": "licensierbar",
    "licensierbares": "licensierbar",
    "licensierbarheten": "licensierbarhet",
    "licensierbarhetens": "licensierbarhet",
    "licensierbarhets": "licensierbarhet",
    "licensierbars": "licensierbar",
    "licensierbart": "licensierbar",
    "licensierbarts": "licensierbar",
    "licensieringar": "licensiering",
    "licensieringarna": "licensiering",
    "licensieringarnas": "licensiering",
    "licensieringars": "licensiering",
    "licensieringen": "licensiering",
    "licensieringens": "licensiering",
    "licensierings": "licensiering",
    "licensinnehavar": "licensinnehavare",
    "licensinnehavaren": "licensinnehavare",
    "licensinnehavarens": "licensinnehavare",
    "licensinnehavares": "licensinnehavare",
    "licensinnehavarna": "licensinnehavare",
    "licensinnehavarnas": "licensinnehavare",
    "licentiaten": "licentiat",
    "licentiatens": "licentiat",
    "licentiater": "licentiat",
    "licentiaterna": "licentiat",
    "licentiaternas": "licentiat",
    "licentiaters": "licentiat",
    "licentiats": "licentiat",
    "licentierad": "licentiera",
    "licentierade": "licentiera",
    "licentierades": "licentiera",
    "licentierads": "licentiera",
    "licentierande": "licentiera",
    "licentieranden": "licentierande",
    "licentierandena": "licentierande",
    "licentierandenas": "licentierande",
    "licentierandens": "licentierande",
    "licentierandes": "licentierande",
    "licentierandet": "licentierande",
    "licentierandets": "licentierande",
    "licentierar": "licentiera",
    "licentieras": "licentiera",
    "licentierat": "licentiera",
    "licentierats": "licentiera",
    "licentierbara": "licentierbar",
    "licentierbarare": "licentierbar",
    "licentierbarares": "licentierbar",
    "licentierbaras": "licentierbar",
    "licentierbarast": "licentierbar",
    "licentierbaraste": "licentierbar",
    "licentierbarastes": "licentierbar",
    "licentierbarasts": "licentierbar",
    "licentierbare": "licentierbar",
    "licentierbares": "licentierbar",
    "licentierbarheten": "licentierbarhet",
    "licentierbarhetens": "licentierbarhet",
    "licentierbarhets": "licentierbarhet",
    "licentierbars": "licentierbar",
    "licentierbart": "licentierbar",
    "licentierbarts": "licentierbar",
    "licentieringar": "licentiering",
    "licentieringarna": "licentiering",
    "licentieringarnas": "licentiering",
    "licentieringars": "licentiering",
    "licentieringen": "licentiering",
    "licentieringens": "licentiering",
    "licentierings": "licentiering",
    "lid": "lida",
    "lidande": "lida",
    "lidanden": "lidande",
    "lidandena": "lidande",
    "lidandenas": "lidande",
    "lidandens": "lidande",
    "lidandes": "lidande",
    "lidandeshistorian": "lidandeshistoria",
    "lidandeshistorians": "lidandeshistoria",
    "lidandeshistorias": "lidandeshistoria",
    "lidandeshistorien": "lidandeshistoria",
    "lidandeshistoriens": "lidandeshistoria",
    "lidandeshistorier": "lidandeshistoria",
    "lidandeshistorierna": "lidandeshistoria",
    "lidandeshistoriernas": "lidandeshistoria",
    "lidandeshistoriers": "lidandeshistoria",
    "lidandet": "lidande",
    "lidandets": "lidande",
    "lidas": "lida",
    "lide": "lida",
    "lidelsefria": "lidelsefri",
    "lidelsefriare": "lidelsefri",
    "lidelsefriares": "lidelsefri",
    "lidelsefrias": "lidelsefri",
    "lidelsefriast": "lidelsefri",
    "lidelsefriaste": "lidelsefri",
    "lidelsefriastes": "lidelsefri",
    "lidelsefriasts": "lidelsefri",
    "lidelsefrie": "lidelsefri",
    "lidelsefries": "lidelsefri",
    "lidelsefris": "lidelsefri",
    "lidelsefritt": "lidelsefri",
    "lidelsefritts": "lidelsefri",
    "lidelsefulla": "lidelsefull",
    "lidelsefullare": "lidelsefull",
    "lidelsefullares": "lidelsefull",
    "lidelsefullas": "lidelsefull",
    "lidelsefullast": "lidelsefull",
    "lidelsefullaste": "lidelsefull",
    "lidelsefullastes": "lidelsefull",
    "lidelsefullasts": "lidelsefull",
    "lidelsefulle": "lidelsefull",
    "lidelsefulles": "lidelsefull",
    "lidelsefullheten": "lidelsefullhet",
    "lidelsefullhetens": "lidelsefullhet",
    "lidelsefullheter": "lidelsefullhet",
    "lidelsefullheterna": "lidelsefullhet",
    "lidelsefullheternas": "lidelsefullhet",
    "lidelsefullheters": "lidelsefullhet",
    "lidelsefullhets": "lidelsefullhet",
    "lidelsefulls": "lidelsefull",
    "lidelsefullt": "lidelsefull",
    "lidelsefullts": "lidelsefull",
    "lidelsen": "lidelse",
    "lidelsens": "lidelse",
    "lidelser": "lidelse",
    "lidelserna": "lidelse",
    "lidelsernas": "lidelse",
    "lidelsers": "lidelse",
    "lidelses": "lidelse",
    "liden": "lida",
    "lidens": "lida",
    "lider": "lida",
    "liderliga": "liderlig",
    "liderligare": "liderlig",
    "liderligares": "liderlig",
    "liderligas": "liderlig",
    "liderligast": "liderlig",
    "liderligaste": "liderlig",
    "liderligastes": "liderlig",
    "liderligasts": "liderlig",
    "liderlige": "liderlig",
    "liderliges": "liderlig",
    "liderligheten": "liderlighet",
    "liderlighetens": "liderlighet",
    "liderligheter": "liderlighet",
    "liderligheterna": "liderlighet",
    "liderligheternas": "liderlighet",
    "liderligheters": "liderlighet",
    "liderlighets": "liderlighet",
    "liderligs": "liderlig",
    "liderligt": "liderlig",
    "liderligts": "liderlig",
    "liderna": "lider",
    "lidernas": "lider",
    "liders": "lider",
    "lides": "lida",
    "lidet": "lida",
    "lidets": "lida",
    "lidit": "lida",
    "lidits": "lida",
    "lidna": "lida",
    "lidnas": "lida",
    "lidne": "lida",
    "lidnes": "lida",
    "lidren": "lider",
    "lidrens": "lider",
    "lidret": "lider",
    "lidrets": "lider",
    "lids": "lida",
    "liechtensteinar": "liechtensteinare",
    "liechtensteinaren": "liechtensteinare",
    "liechtensteinarens": "liechtensteinare",
    "liechtensteinares": "liechtensteinare",
    "liechtensteinarna": "liechtensteinare",
    "liechtensteinarnas": "liechtensteinare",
    "liechtensteinska": "liechtensteinsk",
    "liechtensteinskan": "liechtensteinska",
    "liechtensteinskans": "liechtensteinska",
    "liechtensteinskare": "liechtensteinsk",
    "liechtensteinskares": "liechtensteinsk",
    "liechtensteinskas": "liechtensteinska",
    "liechtensteinskast": "liechtensteinsk",
    "liechtensteinskaste": "liechtensteinsk",
    "liechtensteinskastes": "liechtensteinsk",
    "liechtensteinskasts": "liechtensteinsk",
    "liechtensteinske": "liechtensteinska",
    "liechtensteinskes": "liechtensteinsk",
    "liechtensteinskor": "liechtensteinska",
    "liechtensteinskorna": "liechtensteinska",
    "liechtensteinskornas": "liechtensteinska",
    "liechtensteinskors": "liechtensteinska",
    "liechtensteinsks": "liechtensteinsk",
    "liechtensteinskt": "liechtensteinsk",
    "liechtensteinskts": "liechtensteinsk",
    "lieknaggar": "lieknagg",
    "lieknaggarna": "lieknagg",
    "lieknaggarnas": "lieknagg",
    "lieknaggars": "lieknagg",
    "lieknaggen": "lieknagg",
    "lieknaggens": "lieknagg",
    "lieknaggs": "lieknagg",
    "liemannen": "lieman",
    "liemannens": "lieman",
    "liemans": "lieman",
    "lien": "lie",
    "liens": "lie",
    "lierad": "liera",
    "lierade": "liera",
    "lierades": "liera",
    "lierads": "liera",
    "lierande": "liera",
    "lieranden": "lierande",
    "lierandena": "lierande",
    "lierandenas": "lierande",
    "lierandens": "lierande",
    "lierandes": "lierande",
    "lierandet": "lierande",
    "lierandets": "lierande",
    "lierar": "liera",
    "lieras": "liera",
    "lierat": "liera",
    "lierats": "liera",
    "lierbara": "lierbar",
    "lierbarare": "lierbar",
    "lierbarares": "lierbar",
    "lierbaras": "lierbar",
    "lierbarast": "lierbar",
    "lierbaraste": "lierbar",
    "lierbarastes": "lierbar",
    "lierbarasts": "lierbar",
    "lierbare": "lierbar",
    "lierbares": "lierbar",
    "lierbarheten": "lierbarhet",
    "lierbarhetens": "lierbarhet",
    "lierbarhets": "lierbarhet",
    "lierbars": "lierbar",
    "lierbart": "lierbar",
    "lierbarts": "lierbar",
    "lieringar": "liering",
    "lieringarna": "liering",
    "lieringarnas": "liering",
    "lieringars": "liering",
    "lieringen": "liering",
    "lieringens": "liering",
    "lierings": "liering",
    "lies": "lie",
    "lieskaften": "lieskaft",
    "lieskaftens": "lieskaft",
    "lieskaftet": "lieskaft",
    "lieskaftets": "lieskaft",
    "lieskafts": "lieskaft",
    "liftade": "lifta",
    "liftades": "lifta",
    "liftande": "lifta",
    "liftanden": "liftande",
    "liftandena": "liftande",
    "liftandenas": "liftande",
    "liftandens": "liftande",
    "liftandes": "liftande",
    "liftandet": "liftande",
    "liftandets": "liftande",
    "liftar": "liftare",
    "liftaren": "liftare",
    "liftarens": "liftare",
    "liftares": "liftare",
    "liftarna": "liftare",
    "liftarnas": "liftare",
    "liftars": "lift",
    "liftas": "lifta",
    "liftat": "lifta",
    "liftats": "lifta",
    "liften": "lift",
    "liftens": "lift",
    "lifter": "lift",
    "lifterna": "lift",
    "lifternas": "lift",
    "lifters": "lift",
    "lifts": "lift",
    "ligamenten": "ligament",
    "ligamentens": "ligament",
    "ligamentet": "ligament",
    "ligamentets": "ligament",
    "ligaments": "ligament",
    "ligan": "liga",
    "ligans": "liga",
    "ligas": "liga",
    "ligaturen": "ligatur",
    "ligaturens": "ligatur",
    "ligaturer": "ligatur",
    "ligaturerna": "ligatur",
    "ligaturernas": "ligatur",
    "ligaturers": "ligatur",
    "ligaturs": "ligatur",
    "ligg": "ligga",
    "liggande": "ligga",
    "ligganden": "liggande",
    "liggandena": "liggande",
    "liggandenas": "liggande",
    "liggandens": "liggande",
    "liggandes": "liggande",
    "liggandet": "liggande",
    "liggandets": "liggande",
    "liggar": "liggare",
    "liggaren": "liggare",
    "liggarens": "liggare",
    "liggares": "liggare",
    "liggarna": "liggare",
    "liggarnas": "liggare",
    "liggas": "ligga",
    "ligge": "ligga",
    "liggegodset": "liggegods",
    "liggegodsets": "liggegods",
    "liggen": "ligg",
    "liggens": "ligg",
    "ligger": "ligga",
    "ligges": "ligga",
    "ligget": "ligg",
    "liggetiden": "liggetid",
    "liggetidens": "liggetid",
    "liggetider": "liggetid",
    "liggetiderna": "liggetid",
    "liggetidernas": "liggetid",
    "liggetiders": "liggetid",
    "liggetids": "liggetid",
    "liggets": "ligg",
    "ligghön": "ligghöna",
    "ligghönan": "ligghöna",
    "ligghönans": "ligghöna",
    "ligghönas": "ligghöna",
    "ligghöne": "ligghöna",
    "ligghönor": "ligghöna",
    "ligghönorna": "ligghöna",
    "ligghönornas": "ligghöna",
    "ligghönors": "ligghöna",
    "ligghöns": "ligghöna",
    "liggplatsen": "liggplats",
    "liggplatsens": "liggplats",
    "liggplatser": "liggplats",
    "liggplatserna": "liggplats",
    "liggplatsernas": "liggplats",
    "liggplatsers": "liggplats",
    "liggriktiga": "liggriktig",
    "liggriktigare": "liggriktig",
    "liggriktigares": "liggriktig",
    "liggriktigas": "liggriktig",
    "liggriktigast": "liggriktig",
    "liggriktigaste": "liggriktig",
    "liggriktigastes": "liggriktig",
    "liggriktigasts": "liggriktig",
    "liggriktige": "liggriktig",
    "liggriktiges": "liggriktig",
    "liggriktigheten": "liggriktighet",
    "liggriktighetens": "liggriktighet",
    "liggriktighets": "liggriktighet",
    "liggriktigs": "liggriktig",
    "liggriktigt": "liggriktig",
    "liggriktigts": "liggriktig",
    "liggs": "ligga",
    "liggsjuka": "liggsjuk",
    "liggsjukare": "liggsjuk",
    "liggsjukares": "liggsjuk",
    "liggsjukas": "liggsjuk",
    "liggsjukast": "liggsjuk",
    "liggsjukaste": "liggsjuk",
    "liggsjukastes": "liggsjuk",
    "liggsjukasts": "liggsjuk",
    "liggsjuke": "liggsjuk",
    "liggsjukes": "liggsjuk",
    "liggsjuks": "liggsjuk",
    "liggsjukt": "liggsjuk",
    "liggsjukts": "liggsjuk",
    "liggsäden": "liggsäd",
    "liggsädens": "liggsäd",
    "liggsädes": "liggsäd",
    "liggsäds": "liggsäd",
    "liggsåren": "liggsår",
    "liggsårens": "liggsår",
    "liggsåret": "liggsår",
    "liggsårets": "liggsår",
    "liggsårs": "liggsår",
    "liggunderlagen": "liggunderlag",
    "liggunderlagens": "liggunderlag",
    "liggunderlaget": "liggunderlag",
    "liggunderlagets": "liggunderlag",
    "liggunderlags": "liggunderlag",
    "liggvagnar": "liggvagn",
    "liggvagnarna": "liggvagn",
    "liggvagnarnas": "liggvagn",
    "liggvagnars": "liggvagn",
    "liggvagnen": "liggvagn",
    "liggvagnens": "liggvagn",
    "liggvagns": "liggvagn",
    "liggvirkes": "liggvirke",
    "liggvirket": "liggvirke",
    "liggvirkets": "liggvirke",
    "ligisten": "ligist",
    "ligistens": "ligist",
    "ligister": "ligist",
    "ligisterna": "ligist",
    "ligisternas": "ligist",
    "ligisters": "ligist",
    "ligists": "ligist",
    "ligninen": "lignin",
    "ligninens": "lignin",
    "ligniner": "lignin",
    "ligninerna": "lignin",
    "ligninernas": "lignin",
    "ligniners": "lignin",
    "ligninet": "lignin",
    "ligninets": "lignin",
    "lignins": "lignin",
    "ligor": "liga",
    "ligorna": "liga",
    "ligornas": "liga",
    "ligors": "liga",
    "liguren": "ligur",
    "ligurens": "ligur",
    "ligurer": "ligur",
    "ligurerna": "ligur",
    "ligurernas": "ligur",
    "ligurers": "ligur",
    "liguriska": "ligurisk",
    "liguriskare": "ligurisk",
    "liguriskares": "ligurisk",
    "liguriskas": "ligurisk",
    "liguriskast": "ligurisk",
    "liguriskaste": "ligurisk",
    "liguriskastes": "ligurisk",
    "liguriskasts": "ligurisk",
    "liguriske": "ligurisk",
    "liguriskes": "ligurisk",
    "ligurisks": "ligurisk",
    "liguriskt": "ligurisk",
    "liguriskts": "ligurisk",
    "ligurs": "ligur",
    "ligusterfjärilar": "ligusterfjäril",
    "ligusterfjärilarna": "ligusterfjäril",
    "ligusterfjärilarnas": "ligusterfjäril",
    "ligusterfjärilars": "ligusterfjäril",
    "ligusterfjärilen": "ligusterfjäril",
    "ligusterfjärilens": "ligusterfjäril",
    "ligusterfjäriln": "ligusterfjäril",
    "ligusterfjärilns": "ligusterfjäril",
    "ligusterfjärils": "ligusterfjäril",
    "ligustern": "liguster",
    "ligusterns": "liguster",
    "ligusters": "liguster",
    "ligustersvärmar": "ligustersvärmare",
    "ligustersvärmaren": "ligustersvärmare",
    "ligustersvärmarens": "ligustersvärmare",
    "ligustersvärmares": "ligustersvärmare",
    "ligustersvärmarna": "ligustersvärmare",
    "ligustersvärmarnas": "ligustersvärmare",
    "ligustrar": "liguster",
    "ligustrarna": "liguster",
    "ligustrarnas": "liguster",
    "ligustrars": "liguster",
    "lik": "like",
    "lika": "lik",
    "likaberättigade": "likaberättigad",
    "likaberättigades": "likaberättigad",
    "likaberättigads": "likaberättigad",
    "likaberättigandes": "likaberättigande",
    "likaberättigandet": "likaberättigande",
    "likaberättigandets": "likaberättigande",
    "likaberättigat": "likaberättigad",
    "likaberättigats": "likaberättigad",
    "likad": "lika",
    "likadana": "likadan",
    "likadanare": "likadan",
    "likadanares": "likadan",
    "likadanas": "likadan",
    "likadanast": "likadan",
    "likadanaste": "likadan",
    "likadanastes": "likadan",
    "likadanasts": "likadan",
    "likadane": "likadan",
    "likadanes": "likadan",
    "likadans": "likadan",
    "likadant": "likadan",
    "likadants": "likadan",
    "likade": "lika",
    "likades": "lika",
    "likads": "lika",
    "likalönen": "likalön",
    "likalönens": "likalön",
    "likalöner": "likalön",
    "likalönerna": "likalön",
    "likalönernas": "likalön",
    "likalöners": "likalön",
    "likalöns": "likalön",
    "likande": "lika",
    "likanden": "likande",
    "likandena": "likande",
    "likandenas": "likande",
    "likandens": "likande",
    "likandes": "likande",
    "likandet": "likande",
    "likandets": "likande",
    "likar": "like",
    "likare": "lik",
    "likaren": "likare",
    "likarens": "likare",
    "likares": "likare",
    "likarna": "like",
    "likarnas": "like",
    "likars": "like",
    "likartade": "likartad",
    "likartades": "likartad",
    "likartads": "likartad",
    "likartat": "likartad",
    "likartats": "likartad",
    "likas": "lika",
    "likasinnade": "likasinnad",
    "likasinnades": "likasinnad",
    "likasinnads": "likasinnad",
    "likasinnat": "likasinnad",
    "likasinnats": "likasinnad",
    "likast": "lik",
    "likaste": "lik",
    "likastes": "lik",
    "likasts": "lik",
    "likat": "lika",
    "likats": "lika",
    "likbenta": "likbent",
    "likbentare": "likbent",
    "likbentares": "likbent",
    "likbentas": "likbent",
    "likbentast": "likbent",
    "likbentaste": "likbent",
    "likbentastes": "likbent",
    "likbentasts": "likbent",
    "likbente": "likbent",
    "likbentes": "likbent",
    "likbentheten": "likbenthet",
    "likbenthetens": "likbenthet",
    "likbenthets": "likbenthet",
    "likbents": "likbent",
    "likbesiktningar": "likbesiktning",
    "likbesiktningarna": "likbesiktning",
    "likbesiktningarnas": "likbesiktning",
    "likbesiktningars": "likbesiktning",
    "likbesiktningen": "likbesiktning",
    "likbesiktningens": "likbesiktning",
    "likbesiktnings": "likbesiktning",
    "likbjudarminen": "likbjudarmin",
    "likbjudarminens": "likbjudarmin",
    "likbjudarminer": "likbjudarmin",
    "likbjudarminerna": "likbjudarmin",
    "likbjudarminernas": "likbjudarmin",
    "likbjudarminers": "likbjudarmin",
    "likbjudarmins": "likbjudarmin",
    "likbleka": "likblek",
    "likblekare": "likblek",
    "likblekares": "likblek",
    "likblekas": "likblek",
    "likblekast": "likblek",
    "likblekaste": "likblek",
    "likblekastes": "likblek",
    "likblekasts": "likblek",
    "likbleke": "likblek",
    "likblekes": "likblek",
    "likblekheten": "likblekhet",
    "likblekhetens": "likblekhet",
    "likblekhets": "likblekhet",
    "likbleks": "likblek",
    "likblekt": "likblek",
    "likblekts": "likblek",
    "likblånaden": "likblånad",
    "likblånadens": "likblånad",
    "likblånader": "likblånad",
    "likblånaderna": "likblånad",
    "likblånadernas": "likblånad",
    "likblånaders": "likblånad",
    "likblånads": "likblånad",
    "like": "lik",
    "liken": "like",
    "likens": "like",
    "likes": "like",
    "liket": "lik",
    "likets": "lik",
    "likfläckar": "likfläck",
    "likfläckarna": "likfläck",
    "likfläckarnas": "likfläck",
    "likfläckars": "likfläck",
    "likfläcken": "likfläck",
    "likfläckens": "likfläck",
    "likfläcks": "likfläck",
    "likformiga": "likformig",
    "likformigare": "likformig",
    "likformigares": "likformig",
    "likformigas": "likformig",
    "likformigast": "likformig",
    "likformigaste": "likformig",
    "likformigastes": "likformig",
    "likformigasts": "likformig",
    "likformige": "likformig",
    "likformiges": "likformig",
    "likformigheten": "likformighet",
    "likformighetens": "likformighet",
    "likformigheter": "likformighet",
    "likformigheterna": "likformighet",
    "likformigheternas": "likformighet",
    "likformigheters": "likformighet",
    "likformighets": "likformighet",
    "likformigs": "likformig",
    "likformigt": "likformig",
    "likformigts": "likformig",
    "likfynden": "likfynd",
    "likfyndens": "likfynd",
    "likfyndet": "likfynd",
    "likfyndets": "likfynd",
    "likfynds": "likfynd",
    "likfärden": "likfärd",
    "likfärdens": "likfärd",
    "likfärder": "likfärd",
    "likfärderna": "likfärd",
    "likfärdernas": "likfärd",
    "likfärders": "likfärd",
    "likfärds": "likfärd",
    "likförgiftningar": "likförgiftning",
    "likförgiftningarna": "likförgiftning",
    "likförgiftningarnas": "likförgiftning",
    "likförgiftningars": "likförgiftning",
    "likförgiftningen": "likförgiftning",
    "likförgiftningens": "likförgiftning",
    "likförgiftnings": "likförgiftning",
    "likgiltiga": "likgiltig",
    "likgiltigare": "likgiltig",
    "likgiltigares": "likgiltig",
    "likgiltigas": "likgiltig",
    "likgiltigast": "likgiltig",
    "likgiltigaste": "likgiltig",
    "likgiltigastes": "likgiltig",
    "likgiltigasts": "likgiltig",
    "likgiltige": "likgiltig",
    "likgiltiges": "likgiltig",
    "likgiltigheten": "likgiltighet",
    "likgiltighetens": "likgiltighet",
    "likgiltigheter": "likgiltighet",
    "likgiltigheterna": "likgiltighet",
    "likgiltigheternas": "likgiltighet",
    "likgiltigheters": "likgiltighet",
    "likgiltighets": "likgiltighet",
    "likgiltigs": "likgiltig",
    "likgiltigt": "likgiltig",
    "likgiltigts": "likgiltig",
    "likheten": "likhet",
    "likhetens": "likhet",
    "likheter": "likhet",
    "likheterna": "likhet",
    "likheternas": "likhet",
    "likheters": "likhet",
    "likhets": "likhet",
    "likhetsteckens": "likhetstecken",
    "likhetstecknen": "likhetstecken",
    "likhetstecknens": "likhetstecken",
    "likhetstecknet": "likhetstecken",
    "likhetstecknets": "likhetstecken",
    "likhögar": "likhög",
    "likhögarna": "likhög",
    "likhögarnas": "likhög",
    "likhögars": "likhög",
    "likhögen": "likhög",
    "likhögens": "likhög",
    "likhögs": "likhög",
    "likkist": "likkista",
    "likkistan": "likkista",
    "likkistans": "likkista",
    "likkistas": "likkista",
    "likkiste": "likkista",
    "likkistor": "likkista",
    "likkistorna": "likkista",
    "likkistornas": "likkista",
    "likkistors": "likkista",
    "likn": "likna",
    "liknade": "likna",
    "liknades": "likna",
    "liknande": "likna",
    "liknanden": "liknande",
    "liknandena": "liknande",
    "liknandenas": "liknande",
    "liknandens": "liknande",
    "liknandes": "liknande",
    "liknandet": "liknande",
    "liknandets": "liknande",
    "liknar": "likna",
    "liknas": "likna",
    "liknat": "likna",
    "liknats": "likna",
    "liknelsen": "liknelse",
    "liknelsens": "liknelse",
    "liknelser": "liknelse",
    "liknelserna": "liknelse",
    "liknelsernas": "liknelse",
    "liknelsers": "liknelse",
    "liknelses": "liknelse",
    "liknämniga": "liknämnig",
    "liknämnigare": "liknämnig",
    "liknämnigares": "liknämnig",
    "liknämnigas": "liknämnig",
    "liknämnigast": "liknämnig",
    "liknämnigaste": "liknämnig",
    "liknämnigastes": "liknämnig",
    "liknämnigasts": "liknämnig",
    "liknämnige": "liknämnig",
    "liknämniges": "liknämnig",
    "liknämnigs": "liknämnig",
    "liknämnigt": "liknämnig",
    "liknämnigts": "liknämnig",
    "liknöjda": "liknöjd",
    "liknöjdare": "liknöjd",
    "liknöjdares": "liknöjd",
    "liknöjdas": "liknöjd",
    "liknöjdast": "liknöjd",
    "liknöjdaste": "liknöjd",
    "liknöjdastes": "liknöjd",
    "liknöjdasts": "liknöjd",
    "liknöjde": "liknöjd",
    "liknöjdes": "liknöjd",
    "liknöjdheten": "liknöjdhet",
    "liknöjdhetens": "liknöjdhet",
    "liknöjdhets": "liknöjdhet",
    "liknöjds": "liknöjd",
    "liknöjt": "liknöjd",
    "liknöjts": "liknöjd",
    "likrikt": "likrikta",
    "likriktad": "likrikta",
    "likriktade": "likriktad",
    "likriktades": "likriktad",
    "likriktads": "likriktad",
    "likriktande": "likrikta",
    "likriktanden": "likriktande",
    "likriktandena": "likriktande",
    "likriktandenas": "likriktande",
    "likriktandens": "likriktande",
    "likriktandes": "likriktande",
    "likriktandet": "likriktande",
    "likriktandets": "likriktande",
    "likriktar": "likriktare",
    "likriktaren": "likriktare",
    "likriktarens": "likriktare",
    "likriktares": "likriktare",
    "likriktarna": "likriktare",
    "likriktarnas": "likriktare",
    "likriktas": "likrikta",
    "likriktat": "likriktad",
    "likriktats": "likriktad",
    "liks": "like",
    "liksidiga": "liksidig",
    "liksidigare": "liksidig",
    "liksidigares": "liksidig",
    "liksidigas": "liksidig",
    "liksidigast": "liksidig",
    "liksidigaste": "liksidig",
    "liksidigastes": "liksidig",
    "liksidigasts": "liksidig",
    "liksidige": "liksidig",
    "liksidiges": "liksidig",
    "liksidigheten": "liksidighet",
    "liksidighetens": "liksidighet",
    "liksidighets": "liksidighet",
    "liksidigs": "liksidig",
    "liksidigt": "liksidig",
    "liksidigts": "liksidig",
    "liksidingar": "liksiding",
    "liksidingarna": "liksiding",
    "liksidingarnas": "liksiding",
    "liksidingars": "liksiding",
    "liksidingen": "liksiding",
    "liksidingens": "liksiding",
    "liksidings": "liksiding",
    "likskändar": "likskändare",
    "likskändaren": "likskändare",
    "likskändarens": "likskändare",
    "likskändares": "likskändare",
    "likskändarna": "likskändare",
    "likskändarnas": "likskändare",
    "likspänningar": "likspänning",
    "likspänningarna": "likspänning",
    "likspänningarnas": "likspänning",
    "likspänningars": "likspänning",
    "likspänningen": "likspänning",
    "likspänningens": "likspänning",
    "likspännings": "likspänning",
    "likstelheten": "likstelhet",
    "likstelhetens": "likstelhet",
    "likstelheter": "likstelhet",
    "likstelheterna": "likstelhet",
    "likstelheternas": "likstelhet",
    "likstelheters": "likstelhet",
    "likstelhets": "likstelhet",
    "likströmmar": "likström",
    "likströmmarna": "likström",
    "likströmmarnas": "likström",
    "likströmmars": "likström",
    "likströmmen": "likström",
    "likströmmens": "likström",
    "likströms": "likström",
    "likstyckningen": "likstyckning",
    "likstyckningens": "likstyckning",
    "likstycknings": "likstyckning",
    "likställ": "likställa",
    "likställande": "likställa",
    "likställanden": "likställande",
    "likställandena": "likställande",
    "likställandenas": "likställande",
    "likställandens": "likställande",
    "likställandes": "likställande",
    "likställandet": "likställande",
    "likställandets": "likställande",
    "likställas": "likställa",
    "likställd": "likställa",
    "likställda": "likställa",
    "likställdas": "likställa",
    "likställde": "likställa",
    "likställdes": "likställa",
    "likställds": "likställa",
    "likställer": "likställa",
    "likställes": "likställa",
    "likställiga": "likställig",
    "likställigare": "likställig",
    "likställigares": "likställig",
    "likställigas": "likställig",
    "likställigast": "likställig",
    "likställigaste": "likställig",
    "likställigastes": "likställig",
    "likställigasts": "likställig",
    "likställige": "likställig",
    "likställiges": "likställig",
    "likställigheten": "likställighet",
    "likställighetens": "likställighet",
    "likställigheter": "likställighet",
    "likställigheterna": "likställighet",
    "likställigheternas": "likställighet",
    "likställigheters": "likställighet",
    "likställighets": "likställighet",
    "likställigs": "likställig",
    "likställigt": "likställig",
    "likställigts": "likställig",
    "likställs": "likställa",
    "likställt": "likställa",
    "likställts": "likställa",
    "likstämmiga": "likstämmig",
    "likstämmigare": "likstämmig",
    "likstämmigares": "likstämmig",
    "likstämmigas": "likstämmig",
    "likstämmigast": "likstämmig",
    "likstämmigaste": "likstämmig",
    "likstämmigastes": "likstämmig",
    "likstämmigasts": "likstämmig",
    "likstämmige": "likstämmig",
    "likstämmiges": "likstämmig",
    "likstämmigheten": "likstämmighet",
    "likstämmighetens": "likstämmighet",
    "likstämmigheter": "likstämmighet",
    "likstämmigheterna": "likstämmighet",
    "likstämmigheternas": "likstämmighet",
    "likstämmigheters": "likstämmighet",
    "likstämmighets": "likstämmighet",
    "likstämmigs": "likstämmig",
    "likstämmigt": "likstämmig",
    "likstämmigts": "likstämmig",
    "liksvampar": "liksvamp",
    "liksvamparna": "liksvamp",
    "liksvamparnas": "liksvamp",
    "liksvampars": "liksvamp",
    "liksvampen": "liksvamp",
    "liksvampens": "liksvamp",
    "liksvamps": "liksvamp",
    "liksvepningar": "liksvepning",
    "liksvepningarna": "liksvepning",
    "liksvepningarnas": "liksvepning",
    "liksvepningars": "liksvepning",
    "liksvepningen": "liksvepning",
    "liksvepningens": "liksvepning",
    "liksvepnings": "liksvepning",
    "likt": "lik",
    "liktorer": "liktor",
    "liktorerna": "liktor",
    "liktorernas": "liktor",
    "liktorers": "liktor",
    "liktorn": "liktor",
    "liktornar": "liktorn",
    "liktornarna": "liktorn",
    "liktornarnas": "liktorn",
    "liktornars": "liktorn",
    "liktornen": "liktorn",
    "liktornens": "liktorn",
    "liktorns": "liktorn",
    "liktors": "liktor",
    "likts": "lik",
    "liktydiga": "liktydig",
    "liktydigare": "liktydig",
    "liktydigares": "liktydig",
    "liktydigas": "liktydig",
    "liktydigast": "liktydig",
    "liktydigaste": "liktydig",
    "liktydigastes": "liktydig",
    "liktydigasts": "liktydig",
    "liktydige": "liktydig",
    "liktydiges": "liktydig",
    "liktydigheten": "liktydighet",
    "liktydighetens": "liktydighet",
    "liktydighets": "liktydighet",
    "liktydigs": "liktydig",
    "liktydigt": "liktydig",
    "liktydigts": "liktydig",
    "liktydingar": "liktyding",
    "liktydingarna": "liktyding",
    "liktydingarnas": "liktyding",
    "liktydingars": "liktyding",
    "liktydingen": "liktyding",
    "liktydingens": "liktyding",
    "liktydings": "liktyding",
    "likvak": "likvaka",
    "likvakan": "likvaka",
    "likvakans": "likvaka",
    "likvakas": "likvaka",
    "likvake": "likvaka",
    "likvakor": "likvaka",
    "likvakorna": "likvaka",
    "likvakornas": "likvaka",
    "likvakors": "likvaka",
    "likvaks": "likvaka",
    "likvid": "likvida",
    "likvida": "likvid",
    "likvidan": "likvida",
    "likvidans": "likvida",
    "likvidare": "likvid",
    "likvidares": "likvid",
    "likvidas": "likvida",
    "likvidast": "likvid",
    "likvidaste": "likvid",
    "likvidastes": "likvid",
    "likvidasts": "likvid",
    "likvidationen": "likvidation",
    "likvidationens": "likvidation",
    "likvidationer": "likvidation",
    "likvidationerna": "likvidation",
    "likvidationernas": "likvidation",
    "likvidationers": "likvidation",
    "likvidations": "likvidation",
    "likvidatorer": "likvidator",
    "likvidatorerna": "likvidator",
    "likvidatorernas": "likvidator",
    "likvidatorers": "likvidator",
    "likvidatorn": "likvidator",
    "likvidatorns": "likvidator",
    "likvidators": "likvidator",
    "likvide": "likvida",
    "likviden": "likvid",
    "likvidens": "likvid",
    "likvider": "likvid",
    "likviderad": "likvidera",
    "likviderade": "likvidera",
    "likviderades": "likvidera",
    "likviderads": "likvidera",
    "likviderande": "likvidera",
    "likvideranden": "likviderande",
    "likviderandena": "likviderande",
    "likviderandenas": "likviderande",
    "likviderandens": "likviderande",
    "likviderandes": "likviderande",
    "likviderandet": "likviderande",
    "likviderandets": "likviderande",
    "likviderar": "likvidera",
    "likvideras": "likvidera",
    "likviderat": "likvidera",
    "likviderats": "likvidera",
    "likviderbara": "likviderbar",
    "likviderbarare": "likviderbar",
    "likviderbarares": "likviderbar",
    "likviderbaras": "likviderbar",
    "likviderbarast": "likviderbar",
    "likviderbaraste": "likviderbar",
    "likviderbarastes": "likviderbar",
    "likviderbarasts": "likviderbar",
    "likviderbare": "likviderbar",
    "likviderbares": "likviderbar",
    "likviderbarheten": "likviderbarhet",
    "likviderbarhetens": "likviderbarhet",
    "likviderbarhets": "likviderbarhet",
    "likviderbars": "likviderbar",
    "likviderbart": "likviderbar",
    "likviderbarts": "likviderbar",
    "likvideringar": "likvidering",
    "likvideringarna": "likvidering",
    "likvideringarnas": "likvidering",
    "likvideringars": "likvidering",
    "likvideringen": "likvidering",
    "likvideringens": "likvidering",
    "likviderings": "likvidering",
    "likviderna": "likvid",
    "likvidernas": "likvid",
    "likviders": "likvid",
    "likvides": "likvid",
    "likviditeten": "likviditet",
    "likviditetens": "likviditet",
    "likviditeter": "likviditet",
    "likviditeterna": "likviditet",
    "likviditeternas": "likviditet",
    "likviditeters": "likviditet",
    "likviditets": "likviditet",
    "likvidor": "likvida",
    "likvidorna": "likvida",
    "likvidornas": "likvida",
    "likvidors": "likvida",
    "likvids": "likvida",
    "likvärda": "likvärd",
    "likvärdare": "likvärd",
    "likvärdares": "likvärd",
    "likvärdas": "likvärd",
    "likvärdast": "likvärd",
    "likvärdaste": "likvärd",
    "likvärdastes": "likvärd",
    "likvärdasts": "likvärd",
    "likvärde": "likvärd",
    "likvärdes": "likvärd",
    "likvärdheten": "likvärdhet",
    "likvärdhetens": "likvärdhet",
    "likvärdhets": "likvärdhet",
    "likvärdiga": "likvärdig",
    "likvärdigare": "likvärdig",
    "likvärdigares": "likvärdig",
    "likvärdigas": "likvärdig",
    "likvärdigast": "likvärdig",
    "likvärdigaste": "likvärdig",
    "likvärdigastes": "likvärdig",
    "likvärdigasts": "likvärdig",
    "likvärdige": "likvärdig",
    "likvärdiges": "likvärdig",
    "likvärdigheten": "likvärdighet",
    "likvärdighetens": "likvärdighet",
    "likvärdighets": "likvärdighet",
    "likvärdigs": "likvärdig",
    "likvärdigt": "likvärdig",
    "likvärdigts": "likvärdig",
    "likvärds": "likvärd",
    "likvärt": "likvärd",
    "likvärts": "likvärd",
    "likören": "likör",
    "likörens": "likör",
    "likörer": "likör",
    "likörerna": "likör",
    "likörernas": "likör",
    "likörers": "likör",
    "likörglasen": "likörglas",
    "likörglasens": "likörglas",
    "likörglaset": "likörglas",
    "likörglasets": "likörglas",
    "likörs": "likör",
    "lilas": "lila",
    "liljan": "lilja",
    "liljans": "lilja",
    "liljas": "lilja",
    "lilje": "lilja",
    "liljehyn": "liljehy",
    "liljehyns": "liljehy",
    "liljehys": "liljehy",
    "liljekonvaljen": "liljekonvalje",
    "liljekonvaljens": "liljekonvalje",
    "liljekonvaljer": "liljekonvalje",
    "liljekonvaljerna": "liljekonvalje",
    "liljekonvaljernas": "liljekonvalje",
    "liljekonvaljers": "liljekonvalje",
    "liljekonvaljes": "liljekonvalje",
    "liljekonvaljs": "liljekonvalj",
    "liljemönsterna": "liljemönster",
    "liljemönsternas": "liljemönster",
    "liljemönsters": "liljemönster",
    "liljemönstren": "liljemönster",
    "liljemönstrens": "liljemönster",
    "liljemönstret": "liljemönster",
    "liljemönstrets": "liljemönster",
    "liljevita": "liljevit",
    "liljevitare": "liljevit",
    "liljevitares": "liljevit",
    "liljevitas": "liljevit",
    "liljevitast": "liljevit",
    "liljevitaste": "liljevit",
    "liljevitastes": "liljevit",
    "liljevitasts": "liljevit",
    "liljevite": "liljevit",
    "liljevites": "liljevit",
    "liljevits": "liljevit",
    "liljevitt": "liljevit",
    "liljevitts": "liljevit",
    "liljeväxten": "liljeväxt",
    "liljeväxtens": "liljeväxt",
    "liljeväxter": "liljeväxt",
    "liljeväxterna": "liljeväxt",
    "liljeväxternas": "liljeväxt",
    "liljeväxters": "liljeväxt",
    "liljeväxts": "liljeväxt",
    "liljor": "lilja",
    "liljorna": "lilja",
    "liljornas": "lilja",
    "liljors": "lilja",
    "lilla": "liten",
    "lillans": "lillan",
    "lillas": "liten",
    "lillasyskonen": "lillasyskon",
    "lillasyskonens": "lillasyskon",
    "lillasyskonet": "lillasyskon",
    "lillasyskonets": "lillasyskon",
    "lillasyskons": "lillasyskon",
    "lillasystern": "lillasyster",
    "lillasysterns": "lillasyster",
    "lillasysters": "lillasyster",
    "lillasystrar": "lillasyster",
    "lillasystrarna": "lillasyster",
    "lillasystrarnas": "lillasyster",
    "lillasystrars": "lillasyster",
    "lillaxeln": "lillaxel",
    "lillaxelns": "lillaxel",
    "lillaxels": "lillaxel",
    "lillaxlar": "lillaxel",
    "lillaxlarna": "lillaxel",
    "lillaxlarnas": "lillaxel",
    "lillaxlars": "lillaxel",
    "lille": "liten",
    "lillebrors": "lillebror",
    "lillefars": "lillefar",
    "lillens": "lillen",
    "lilleputtar": "lilleputt",
    "lilleputtarna": "lilleputt",
    "lilleputtarnas": "lilleputt",
    "lilleputtars": "lilleputt",
    "lilleputten": "lilleputt",
    "lilleputtens": "lilleputt",
    "lilleputter": "lilleputt",
    "lilleputterna": "lilleputt",
    "lilleputternas": "lilleputt",
    "lilleputters": "lilleputt",
    "lilleputts": "lilleputt",
    "lilles": "liten",
    "lillfingern": "lillfinger",
    "lillfingerns": "lillfinger",
    "lillfingers": "lillfinger",
    "lillfingertoppar": "lillfingertopp",
    "lillfingertopparna": "lillfingertopp",
    "lillfingertopparnas": "lillfingertopp",
    "lillfingertoppars": "lillfingertopp",
    "lillfingertoppen": "lillfingertopp",
    "lillfingertoppens": "lillfingertopp",
    "lillfingertopps": "lillfingertopp",
    "lillfingrar": "lillfinger",
    "lillfingrarna": "lillfinger",
    "lillfingrarnas": "lillfinger",
    "lillfingrars": "lillfinger",
    "lillfingret": "lillfinger",
    "lillfingrets": "lillfinger",
    "lillgamla": "lillgammal",
    "lillgamlas": "lillgammal",
    "lillgamle": "lillgammal",
    "lillgamles": "lillgammal",
    "lillgammals": "lillgammal",
    "lillgammalt": "lillgammal",
    "lillgammalts": "lillgammal",
    "lillhjärnan": "lillhjärna",
    "lillhjärnans": "lillhjärna",
    "lillhjärnas": "lillhjärna",
    "lillsemestern": "lillsemester",
    "lillsemesterns": "lillsemester",
    "lillsemesters": "lillsemester",
    "lillsemestrar": "lillsemester",
    "lillsemestrarna": "lillsemester",
    "lillsemestrarnas": "lillsemester",
    "lillsemestrars": "lillsemester",
    "lillslammar": "lillslam",
    "lillslammarna": "lillslam",
    "lillslammarnas": "lillslam",
    "lillslammars": "lillslam",
    "lillslammen": "lillslam",
    "lillslammens": "lillslam",
    "lillslams": "lillslam",
    "lillstugan": "lillstuga",
    "lillstugans": "lillstuga",
    "lillstugas": "lillstuga",
    "lillstuge": "lillstuga",
    "lillstugor": "lillstuga",
    "lillstugorna": "lillstuga",
    "lillstugornas": "lillstuga",
    "lillstugors": "lillstuga",
    "lillstugu": "lillstuga",
    "lillsyskonen": "lillsyskon",
    "lillsyskonens": "lillsyskon",
    "lillsyskonet": "lillsyskon",
    "lillsyskonets": "lillsyskon",
    "lillsyskons": "lillsyskon",
    "lilltån": "lilltå",
    "lilltåns": "lilltå",
    "lilltår": "lilltå",
    "lilltårna": "lilltå",
    "lilltårnas": "lilltå",
    "lilltårs": "lilltå",
    "lilltås": "lilltå",
    "lillvärdinnan": "lillvärdinna",
    "lillvärdinnans": "lillvärdinna",
    "lillvärdinnas": "lillvärdinna",
    "lillvärdinne": "lillvärdinna",
    "lillvärdinnor": "lillvärdinna",
    "lillvärdinnorna": "lillvärdinna",
    "lillvärdinnornas": "lillvärdinna",
    "lillvärdinnors": "lillvärdinna",
    "limabön": "limaböna",
    "limabönan": "limaböna",
    "limabönans": "limaböna",
    "limabönas": "limaböna",
    "limaböne": "limaböna",
    "limabönor": "limaböna",
    "limabönorna": "limaböna",
    "limabönornas": "limaböna",
    "limabönors": "limaböna",
    "limaböns": "limaböna",
    "limborst": "limborste",
    "limborstar": "limborste",
    "limborstarna": "limborste",
    "limborstarnas": "limborste",
    "limborstars": "limborste",
    "limborsten": "limborste",
    "limborstens": "limborste",
    "limborstes": "limborste",
    "limen": "lime",
    "limens": "lime",
    "limer": "lime",
    "limerickar": "limerick",
    "limerickarna": "limerick",
    "limerickarnas": "limerick",
    "limerickars": "limerick",
    "limericken": "limerick",
    "limerickens": "limerick",
    "limericks": "limerick",
    "limerna": "lime",
    "limernas": "lime",
    "limers": "lime",
    "limes": "lime",
    "limfärgen": "limfärg",
    "limfärgens": "limfärg",
    "limfärger": "limfärg",
    "limfärgerna": "limfärg",
    "limfärgernas": "limfärg",
    "limfärgers": "limfärg",
    "limfärgs": "limfärg",
    "limgördeln": "limgördel",
    "limgördelns": "limgördel",
    "limgördels": "limgördel",
    "limgördlar": "limgördel",
    "limgördlarna": "limgördel",
    "limgördlarnas": "limgördel",
    "limgördlars": "limgördel",
    "limitationen": "limitation",
    "limitationens": "limitation",
    "limitationer": "limitation",
    "limitationerna": "limitation",
    "limitationernas": "limitation",
    "limitationers": "limitation",
    "limitations": "limitation",
    "limitativa": "limitativ",
    "limitativare": "limitativ",
    "limitativares": "limitativ",
    "limitativas": "limitativ",
    "limitativast": "limitativ",
    "limitativaste": "limitativ",
    "limitativastes": "limitativ",
    "limitativasts": "limitativ",
    "limitative": "limitativ",
    "limitatives": "limitativ",
    "limitativs": "limitativ",
    "limitativt": "limitativ",
    "limitativts": "limitativ",
    "limiten": "limit",
    "limitens": "limit",
    "limiter": "limit",
    "limiterade": "limiterad",
    "limiterades": "limiterad",
    "limiterads": "limiterad",
    "limiterat": "limiterad",
    "limiterats": "limiterad",
    "limiterna": "limit",
    "limiternas": "limit",
    "limiters": "limit",
    "limits": "limit",
    "limklämman": "limklämma",
    "limklämmans": "limklämma",
    "limklämmas": "limklämma",
    "limklämme": "limklämma",
    "limklämmor": "limklämma",
    "limklämmorna": "limklämma",
    "limklämmornas": "limklämma",
    "limklämmors": "limklämma",
    "limkokerier": "limkokeri",
    "limkokerierna": "limkokeri",
    "limkokeriernas": "limkokeri",
    "limkokeriers": "limkokeri",
    "limkokeriet": "limkokeri",
    "limkokeriets": "limkokeri",
    "limkokeris": "limkokeri",
    "limkokerit": "limkokeri",
    "limkokerits": "limkokeri",
    "limmad": "limma",
    "limmade": "limma",
    "limmades": "limma",
    "limmads": "limma",
    "limmande": "limma",
    "limmanden": "limmande",
    "limmandena": "limmande",
    "limmandenas": "limmande",
    "limmandens": "limmande",
    "limmandes": "limmande",
    "limmandet": "limmande",
    "limmandets": "limmande",
    "limmar": "limma",
    "limmas": "limma",
    "limmat": "limma",
    "limmats": "limma",
    "limmen": "lim",
    "limmens": "lim",
    "limmer": "lim",
    "limmerna": "lim",
    "limmernas": "lim",
    "limmers": "lim",
    "limmet": "lim",
    "limmets": "lim",
    "limningar": "limning",
    "limningarna": "limning",
    "limningarnas": "limning",
    "limningars": "limning",
    "limningen": "limning",
    "limningens": "limning",
    "limnings": "limning",
    "limningsmaskinen": "limningsmaskin",
    "limningsmaskinens": "limningsmaskin",
    "limningsmaskiner": "limningsmaskin",
    "limningsmaskinerna": "limningsmaskin",
    "limningsmaskinernas": "limningsmaskin",
    "limningsmaskiners": "limningsmaskin",
    "limningsmaskins": "limningsmaskin",
    "limniska": "limnisk",
    "limniskare": "limnisk",
    "limniskares": "limnisk",
    "limniskas": "limnisk",
    "limniskast": "limnisk",
    "limniskaste": "limnisk",
    "limniskastes": "limnisk",
    "limniskasts": "limnisk",
    "limniske": "limnisk",
    "limniskes": "limnisk",
    "limnisks": "limnisk",
    "limniskt": "limnisk",
    "limniskts": "limnisk",
    "limnografen": "limnograf",
    "limnografens": "limnograf",
    "limnografer": "limnograf",
    "limnograferna": "limnograf",
    "limnografernas": "limnograf",
    "limnografers": "limnograf",
    "limnografs": "limnograf",
    "limnologien": "limnologi",
    "limnologiens": "limnologi",
    "limnologin": "limnologi",
    "limnologins": "limnologi",
    "limnologis": "limnologi",
    "limnologiska": "limnologisk",
    "limnologiskare": "limnologisk",
    "limnologiskares": "limnologisk",
    "limnologiskas": "limnologisk",
    "limnologiskast": "limnologisk",
    "limnologiskaste": "limnologisk",
    "limnologiskastes": "limnologisk",
    "limnologiskasts": "limnologisk",
    "limnologiske": "limnologisk",
    "limnologiskes": "limnologisk",
    "limnologisks": "limnologisk",
    "limnologiskt": "limnologisk",
    "limnologiskts": "limnologisk",
    "limoniten": "limonit",
    "limonitens": "limonit",
    "limonits": "limonit",
    "limousinen": "limousine",
    "limousinens": "limousine",
    "limousiner": "limousine",
    "limousinerna": "limousine",
    "limousinernas": "limousine",
    "limousiners": "limousine",
    "limousines": "limousine",
    "limousins": "limousin",
    "limp": "limpa",
    "limpan": "limpa",
    "limpans": "limpa",
    "limpas": "limpa",
    "limpe": "limpa",
    "limpinn": "limpinne",
    "limpinnar": "limpinne",
    "limpinnarna": "limpinne",
    "limpinnarnas": "limpinne",
    "limpinnars": "limpinne",
    "limpinnen": "limpinne",
    "limpinnens": "limpinne",
    "limpinnes": "limpinne",
    "limpinns": "limpinne",
    "limpor": "limpa",
    "limporna": "limpa",
    "limpornas": "limpa",
    "limpors": "limpa",
    "limps": "limpa",
    "limpåstrykningar": "limpåstrykning",
    "limpåstrykningarna": "limpåstrykning",
    "limpåstrykningarnas": "limpåstrykning",
    "limpåstrykningars": "limpåstrykning",
    "limpåstrykningen": "limpåstrykning",
    "limpåstrykningens": "limpåstrykning",
    "limpåstryknings": "limpåstrykning",
    "limringar": "limring",
    "limringarna": "limring",
    "limringarnas": "limring",
    "limringars": "limring",
    "limringen": "limring",
    "limringens": "limring",
    "limrings": "limring",
    "lims": "lim",
    "limstick": "limsticka",
    "limstickan": "limsticka",
    "limstickans": "limsticka",
    "limstickas": "limsticka",
    "limsticke": "limsticka",
    "limstickor": "limsticka",
    "limstickorna": "limsticka",
    "limstickornas": "limsticka",
    "limstickors": "limsticka",
    "limsticks": "limsticka",
    "limtillverkningar": "limtillverkning",
    "limtillverkningarna": "limtillverkning",
    "limtillverkningarnas": "limtillverkning",
    "limtillverkningars": "limtillverkning",
    "limtillverkningen": "limtillverkning",
    "limtillverkningens": "limtillverkning",
    "limtillverknings": "limtillverkning",
    "limämnen": "limämne",
    "limämnena": "limämne",
    "limämnenas": "limämne",
    "limämnens": "limämne",
    "limämnes": "limämne",
    "limämnet": "limämne",
    "limämnets": "limämne",
    "lin": "lina",
    "linan": "lina",
    "linans": "lina",
    "linas": "lina",
    "linbanan": "linbana",
    "linbanans": "linbana",
    "linbanas": "linbana",
    "linbane": "linbana",
    "linbanor": "linbana",
    "linbanorna": "linbana",
    "linbanornas": "linbana",
    "linbanors": "linbana",
    "linblånorna": "linblånor",
    "linblånornas": "linblånor",
    "linblånors": "linblånor",
    "linblåns": "linblånor",
    "linbråkningar": "linbråkning",
    "linbråkningarna": "linbråkning",
    "linbråkningarnas": "linbråkning",
    "linbråkningars": "linbråkning",
    "linbråkningen": "linbråkning",
    "linbråkningens": "linbråkning",
    "linbråknings": "linbråkning",
    "lind": "linda",
    "lindad": "linda",
    "lindade": "linda",
    "lindades": "linda",
    "lindads": "linda",
    "lindan": "linda",
    "lindande": "linda",
    "lindanden": "lindande",
    "lindandena": "lindande",
    "lindandenas": "lindande",
    "lindandens": "lindande",
    "lindandes": "lindande",
    "lindandet": "lindande",
    "lindandets": "lindande",
    "lindans": "linda",
    "lindansar": "lindansare",
    "lindansaren": "lindansare",
    "lindansarens": "lindansare",
    "lindansares": "lindansare",
    "lindansarna": "lindansare",
    "lindansarnas": "lindansare",
    "lindar": "lindare",
    "lindaren": "lindare",
    "lindarens": "lindare",
    "lindares": "lindare",
    "lindarna": "lindare",
    "lindarnas": "lindare",
    "lindars": "lind",
    "lindas": "linda",
    "lindat": "linda",
    "lindats": "linda",
    "lindblom": "lindblomma",
    "lindblomman": "lindblomma",
    "lindblommans": "lindblomma",
    "lindblommas": "lindblomma",
    "lindblomme": "lindblomma",
    "lindblommen": "lindblom",
    "lindblommens": "lindblom",
    "lindblommor": "lindblomma",
    "lindblommorna": "lindblomma",
    "lindblommornas": "lindblomma",
    "lindblommors": "lindblomma",
    "lindbloms": "lindblomma",
    "lindblomsteet": "lindblomste",
    "lindblomsteets": "lindblomste",
    "lindblomstes": "lindblomste",
    "lindblomstet": "lindblomste",
    "lindblomstets": "lindblomste",
    "linddragen": "linddrag",
    "linddragens": "linddrag",
    "linddraget": "linddrag",
    "linddragets": "linddrag",
    "linddrags": "linddrag",
    "linde": "linda",
    "lindebarnen": "lindebarn",
    "lindebarnens": "lindebarn",
    "lindebarnet": "lindebarn",
    "lindebarnets": "lindebarn",
    "lindebarns": "lindebarn",
    "linden": "lind",
    "lindens": "lind",
    "lindlöven": "lindlöv",
    "lindlövens": "lindlöv",
    "lindlövet": "lindlöv",
    "lindlövets": "lindlöv",
    "lindlövs": "lindlöv",
    "lindningar": "lindning",
    "lindningarna": "lindning",
    "lindningarnas": "lindning",
    "lindningars": "lindning",
    "lindningen": "lindning",
    "lindningens": "lindning",
    "lindnings": "lindning",
    "lindor": "linda",
    "lindormar": "lindorm",
    "lindormarna": "lindorm",
    "lindormarnas": "lindorm",
    "lindormars": "lindorm",
    "lindormen": "lindorm",
    "lindormens": "lindorm",
    "lindorms": "lindorm",
    "lindorna": "linda",
    "lindornas": "linda",
    "lindors": "linda",
    "lindrad": "lindra",
    "lindrade": "lindra",
    "lindrades": "lindra",
    "lindrads": "lindra",
    "lindrande": "lindra",
    "lindranden": "lindrande",
    "lindrandena": "lindrande",
    "lindrandenas": "lindrande",
    "lindrandens": "lindrande",
    "lindrandes": "lindrande",
    "lindrandet": "lindrande",
    "lindrandets": "lindrande",
    "lindrar": "lindra",
    "lindras": "lindra",
    "lindrat": "lindra",
    "lindrats": "lindra",
    "lindriga": "lindrig",
    "lindrigare": "lindrig",
    "lindrigares": "lindrig",
    "lindrigas": "lindrig",
    "lindrigast": "lindrig",
    "lindrigaste": "lindrig",
    "lindrigastes": "lindrig",
    "lindrigasts": "lindrig",
    "lindrige": "lindrig",
    "lindriges": "lindrig",
    "lindrigheten": "lindrighet",
    "lindrighetens": "lindrighet",
    "lindrighets": "lindrighet",
    "lindrigs": "lindrig",
    "lindrigt": "lindrig",
    "lindrigts": "lindrig",
    "lindringar": "lindring",
    "lindringarna": "lindring",
    "lindringarnas": "lindring",
    "lindringars": "lindring",
    "lindringen": "lindring",
    "lindringens": "lindring",
    "lindrings": "lindring",
    "linds": "linda",
    "line": "lina",
    "linearritningar": "linearritning",
    "linearritningarna": "linearritning",
    "linearritningarnas": "linearritning",
    "linearritningars": "linearritning",
    "linearritningen": "linearritning",
    "linearritningens": "linearritning",
    "linearritnings": "linearritning",
    "linet": "lin",
    "linets": "lin",
    "lineära": "lineär",
    "lineärare": "lineär",
    "lineärares": "lineär",
    "lineäras": "lineär",
    "lineärast": "lineär",
    "lineäraste": "lineär",
    "lineärastes": "lineär",
    "lineärasts": "lineär",
    "lineäre": "lineär",
    "lineäres": "lineär",
    "lineärs": "lineär",
    "lineärt": "lineär",
    "lineärts": "lineär",
    "linfröen": "linfrö",
    "linfröens": "linfrö",
    "linfröet": "linfrö",
    "linfröets": "linfrö",
    "linfrön": "linfrö",
    "linfröna": "linfrö",
    "linfrönas": "linfrö",
    "linfröns": "linfrö",
    "linfrös": "linfrö",
    "linfröt": "linfrö",
    "linfröts": "linfrö",
    "linfärgade": "linfärgad",
    "linfärgades": "linfärgad",
    "linfärgads": "linfärgad",
    "linfärgat": "linfärgad",
    "linfärgats": "linfärgad",
    "lingarnen": "lingarn",
    "lingarnens": "lingarn",
    "lingarner": "lingarn",
    "lingarnerna": "lingarn",
    "lingarnernas": "lingarn",
    "lingarners": "lingarn",
    "lingarnet": "lingarn",
    "lingarnets": "lingarn",
    "lingarns": "lingarn",
    "lingerier": "lingeri",
    "lingerierna": "lingeri",
    "lingeriernas": "lingeri",
    "lingeriers": "lingeri",
    "lingeriet": "lingeri",
    "lingeriets": "lingeri",
    "lingeris": "lingeri",
    "lingerit": "lingeri",
    "lingerits": "lingeri",
    "lingonbusk": "lingonbuske",
    "lingonbuskar": "lingonbuske",
    "lingonbuskarna": "lingonbuske",
    "lingonbuskarnas": "lingonbuske",
    "lingonbuskars": "lingonbuske",
    "lingonbusken": "lingonbuske",
    "lingonbuskens": "lingonbuske",
    "lingonbuskes": "lingonbuske",
    "lingondrickan": "lingondricka",
    "lingondrickans": "lingondricka",
    "lingondrickas": "lingondricka",
    "lingondricke": "lingondricka",
    "lingondricks": "lingondricka",
    "lingonen": "lingon",
    "lingonens": "lingon",
    "lingonet": "lingon",
    "lingonets": "lingon",
    "lingonmosen": "lingonmos",
    "lingonmosens": "lingonmos",
    "lingonmoset": "lingonmos",
    "lingonmosets": "lingonmos",
    "lingonplockar": "lingonplockare",
    "lingonplockaren": "lingonplockare",
    "lingonplockarens": "lingonplockare",
    "lingonplockares": "lingonplockare",
    "lingonplockarna": "lingonplockare",
    "lingonplockarnas": "lingonplockare",
    "lingonpäronen": "lingonpäron",
    "lingonpäronens": "lingonpäron",
    "lingonpäronet": "lingonpäron",
    "lingonpäronets": "lingonpäron",
    "lingonpärons": "lingonpäron",
    "lingonriset": "lingonris",
    "lingonrisets": "lingonris",
    "lingonrutan": "lingonruta",
    "lingonrutans": "lingonruta",
    "lingonrutas": "lingonruta",
    "lingonrute": "lingonruta",
    "lingonrutor": "lingonruta",
    "lingonrutorna": "lingonruta",
    "lingonrutornas": "lingonruta",
    "lingonrutors": "lingonruta",
    "lingonröda": "lingonröd",
    "lingonrödare": "lingonröd",
    "lingonrödares": "lingonröd",
    "lingonrödas": "lingonröd",
    "lingonrödast": "lingonröd",
    "lingonrödaste": "lingonröd",
    "lingonrödastes": "lingonröd",
    "lingonrödasts": "lingonröd",
    "lingonröde": "lingonröd",
    "lingonrödes": "lingonröd",
    "lingonröds": "lingonröd",
    "lingonrött": "lingonröd",
    "lingonrötts": "lingonröd",
    "lingons": "lingon",
    "lingonsaften": "lingonsaft",
    "lingonsaftens": "lingonsaft",
    "lingonsafts": "lingonsaft",
    "lingonsylten": "lingonsylt",
    "lingonsyltens": "lingonsylt",
    "lingonsylts": "lingonsylt",
    "lingula": "lingul",
    "lingulare": "lingul",
    "lingulares": "lingul",
    "lingulas": "lingul",
    "lingulast": "lingul",
    "lingulaste": "lingul",
    "lingulastes": "lingul",
    "lingulasts": "lingul",
    "lingule": "lingul",
    "lingules": "lingul",
    "linguls": "lingul",
    "lingult": "lingul",
    "lingults": "lingul",
    "lingvisten": "lingvist",
    "lingvistens": "lingvist",
    "lingvister": "lingvist",
    "lingvisterna": "lingvist",
    "lingvisternas": "lingvist",
    "lingvisters": "lingvist",
    "lingvistiken": "lingvistik",
    "lingvistikens": "lingvistik",
    "lingvistiks": "lingvistik",
    "lingvistiska": "lingvistisk",
    "lingvistiskare": "lingvistisk",
    "lingvistiskares": "lingvistisk",
    "lingvistiskas": "lingvistisk",
    "lingvistiskast": "lingvistisk",
    "lingvistiskaste": "lingvistisk",
    "lingvistiskastes": "lingvistisk",
    "lingvistiskasts": "lingvistisk",
    "lingvistiske": "lingvistisk",
    "lingvistiskes": "lingvistisk",
    "lingvistisks": "lingvistisk",
    "lingvistiskt": "lingvistisk",
    "lingvistiskts": "lingvistisk",
    "lingvists": "lingvist",
    "linhåriga": "linhårig",
    "linhårigare": "linhårig",
    "linhårigares": "linhårig",
    "linhårigas": "linhårig",
    "linhårigast": "linhårig",
    "linhårigaste": "linhårig",
    "linhårigastes": "linhårig",
    "linhårigasts": "linhårig",
    "linhårige": "linhårig",
    "linhåriges": "linhårig",
    "linhårigheten": "linhårighet",
    "linhårighetens": "linhårighet",
    "linhårighets": "linhårighet",
    "linhårigs": "linhårig",
    "linhårigt": "linhårig",
    "linhårigts": "linhårig",
    "linimenten": "liniment",
    "linimentens": "liniment",
    "linimentet": "liniment",
    "linimentets": "liniment",
    "liniments": "liniment",
    "linjalen": "linjal",
    "linjalens": "linjal",
    "linjaler": "linjal",
    "linjalerna": "linjal",
    "linjalernas": "linjal",
    "linjalers": "linjal",
    "linjals": "linjal",
    "linjearbeten": "linjearbete",
    "linjearbetena": "linjearbete",
    "linjearbetenas": "linjearbete",
    "linjearbetens": "linjearbete",
    "linjearbetes": "linjearbete",
    "linjearbetet": "linjearbete",
    "linjearbetets": "linjearbete",
    "linjearbets": "linjearbete",
    "linjeblockeringar": "linjeblockering",
    "linjeblockeringarna": "linjeblockering",
    "linjeblockeringarnas": "linjeblockering",
    "linjeblockeringars": "linjeblockering",
    "linjeblockeringen": "linjeblockering",
    "linjeblockeringens": "linjeblockering",
    "linjeblockerings": "linjeblockering",
    "linjedomar": "linjedomare",
    "linjedomaren": "linjedomare",
    "linjedomarens": "linjedomare",
    "linjedomares": "linjedomare",
    "linjedomarna": "linjedomare",
    "linjedomarnas": "linjedomare",
    "linjefarten": "linjefart",
    "linjefartens": "linjefart",
    "linjefarts": "linjefart",
    "linjeflyget": "linjeflyg",
    "linjeflygets": "linjeflyg",
    "linjeflygs": "linjeflyg",
    "linjeföringar": "linjeföring",
    "linjeföringarna": "linjeföring",
    "linjeföringarnas": "linjeföring",
    "linjeföringars": "linjeföring",
    "linjeföringen": "linjeföring",
    "linjeföringens": "linjeföring",
    "linjeförings": "linjeföring",
    "linjeloppen": "linjelopp",
    "linjeloppens": "linjelopp",
    "linjeloppet": "linjelopp",
    "linjeloppets": "linjelopp",
    "linjelopps": "linjelopp",
    "linjemannen": "linjeman",
    "linjemannens": "linjeman",
    "linjemans": "linjeman",
    "linjemän": "linjeman",
    "linjemännen": "linjeman",
    "linjemännens": "linjeman",
    "linjemäns": "linjeman",
    "linjen": "linje",
    "linjens": "linje",
    "linjenämnden": "linjenämnd",
    "linjenämndens": "linjenämnd",
    "linjenämnder": "linjenämnd",
    "linjenämnderna": "linjenämnd",
    "linjenämndernas": "linjenämnd",
    "linjenämnders": "linjenämnd",
    "linjenämnds": "linjenämnd",
    "linjer": "linje",
    "linjerad": "linjera",
    "linjerade": "linjera",
    "linjerades": "linjera",
    "linjerads": "linjera",
    "linjerande": "linjera",
    "linjeranden": "linjerande",
    "linjerandena": "linjerande",
    "linjerandenas": "linjerande",
    "linjerandens": "linjerande",
    "linjerandes": "linjerande",
    "linjerandet": "linjerande",
    "linjerandets": "linjerande",
    "linjerar": "linjera",
    "linjeras": "linjera",
    "linjerat": "linjera",
    "linjerats": "linjera",
    "linjerbara": "linjerbar",
    "linjerbarare": "linjerbar",
    "linjerbarares": "linjerbar",
    "linjerbaras": "linjerbar",
    "linjerbarast": "linjerbar",
    "linjerbaraste": "linjerbar",
    "linjerbarastes": "linjerbar",
    "linjerbarasts": "linjerbar",
    "linjerbare": "linjerbar",
    "linjerbares": "linjerbar",
    "linjerbarheten": "linjerbarhet",
    "linjerbarhetens": "linjerbarhet",
    "linjerbarhets": "linjerbarhet",
    "linjerbars": "linjerbar",
    "linjerbart": "linjerbar",
    "linjerbarts": "linjerbar",
    "linjerena": "linjeren",
    "linjerenare": "linjeren",
    "linjerenares": "linjeren",
    "linjerenas": "linjeren",
    "linjerenast": "linjeren",
    "linjerenaste": "linjeren",
    "linjerenastes": "linjeren",
    "linjerenasts": "linjeren",
    "linjerene": "linjeren",
    "linjerenes": "linjeren",
    "linjerenheten": "linjerenhet",
    "linjerenhetens": "linjerenhet",
    "linjerenhets": "linjerenhet",
    "linjerens": "linjeren",
    "linjerent": "linjeren",
    "linjerents": "linjeren",
    "linjeringar": "linjering",
    "linjeringarna": "linjering",
    "linjeringarnas": "linjering",
    "linjeringars": "linjering",
    "linjeringen": "linjering",
    "linjeringens": "linjering",
    "linjerings": "linjering",
    "linjerna": "linje",
    "linjernas": "linje",
    "linjers": "linje",
    "linjes": "linje",
    "linjeskeppen": "linjeskepp",
    "linjeskeppens": "linjeskepp",
    "linjeskeppet": "linjeskepp",
    "linjeskeppets": "linjeskepp",
    "linjeskepps": "linjeskepp",
    "linjespektra": "linjespektrum",
    "linjespektrana": "linjespektrum",
    "linjespektranas": "linjespektrum",
    "linjespektras": "linjespektrum",
    "linjespektrena": "linjespektrum",
    "linjespektrenas": "linjespektrum",
    "linjespektrer": "linjespektrum",
    "linjespektrers": "linjespektrum",
    "linjespektret": "linjespektrum",
    "linjespektrets": "linjespektrum",
    "linjespektrumen": "linjespektrum",
    "linjespektrumens": "linjespektrum",
    "linjespektrumet": "linjespektrum",
    "linjespektrumets": "linjespektrum",
    "linjespektrums": "linjespektrum",
    "linjespelen": "linjespel",
    "linjespelens": "linjespel",
    "linjespelet": "linjespel",
    "linjespelets": "linjespel",
    "linjespels": "linjespel",
    "linjetrafiken": "linjetrafik",
    "linjetrafikens": "linjetrafik",
    "linjetrafiks": "linjetrafik",
    "linjeväljar": "linjeväljare",
    "linjeväljaren": "linjeväljare",
    "linjeväljarens": "linjeväljare",
    "linjeväljares": "linjeväljare",
    "linjeväljarna": "linjeväljare",
    "linjeväljarnas": "linjeväljare",
    "linjära": "linjär",
    "linjärare": "linjär",
    "linjärares": "linjär",
    "linjäras": "linjär",
    "linjärast": "linjär",
    "linjäraste": "linjär",
    "linjärastes": "linjär",
    "linjärasts": "linjär",
    "linjäre": "linjär",
    "linjäres": "linjär",
    "linjärs": "linjär",
    "linjärt": "linjär",
    "linjärts": "linjär",
    "link": "linka",
    "linkade": "linka",
    "linkades": "linka",
    "linkande": "linka",
    "linkanden": "linkande",
    "linkandena": "linkande",
    "linkandenas": "linkande",
    "linkandens": "linkande",
    "linkandes": "linkande",
    "linkandet": "linkande",
    "linkandets": "linkande",
    "linkar": "linka",
    "linkas": "linka",
    "linkat": "linka",
    "linkats": "linka",
    "linluggar": "linlugg",
    "linluggarna": "linlugg",
    "linluggarnas": "linlugg",
    "linluggars": "linlugg",
    "linluggen": "linlugg",
    "linluggens": "linlugg",
    "linluggs": "linlugg",
    "linne": "linnea",
    "linnean": "linnea",
    "linneans": "linnea",
    "linneas": "linnea",
    "linnedamasten": "linnedamast",
    "linnedamastens": "linnedamast",
    "linnedamaster": "linnedamast",
    "linnedamasterna": "linnedamast",
    "linnedamasternas": "linnedamast",
    "linnedamasters": "linnedamast",
    "linnedamasts": "linnedamast",
    "linnedukar": "linneduk",
    "linnedukarna": "linneduk",
    "linnedukarnas": "linneduk",
    "linnedukars": "linneduk",
    "linneduken": "linneduk",
    "linnedukens": "linneduk",
    "linneduks": "linneduk",
    "linnee": "linnea",
    "linnefibern": "linnefiber",
    "linnefiberns": "linnefiber",
    "linnefibers": "linnefiber",
    "linnefibrer": "linnefiber",
    "linnefibrerna": "linnefiber",
    "linnefibrernas": "linnefiber",
    "linnefibrers": "linnefiber",
    "linneklänningar": "linneklänning",
    "linneklänningarna": "linneklänning",
    "linneklänningarnas": "linneklänning",
    "linneklänningars": "linneklänning",
    "linneklänningen": "linneklänning",
    "linneklänningens": "linneklänning",
    "linneklännings": "linneklänning",
    "linnen": "linne",
    "linnena": "linne",
    "linnenas": "linne",
    "linnens": "linne",
    "linneor": "linnea",
    "linneorna": "linnea",
    "linneornas": "linnea",
    "linneors": "linnea",
    "linnes": "linnea",
    "linneskåpen": "linneskåp",
    "linneskåpens": "linneskåp",
    "linneskåpet": "linneskåp",
    "linneskåpets": "linneskåp",
    "linneskåps": "linneskåp",
    "linnet": "linne",
    "linnets": "linne",
    "linningar": "linning",
    "linningarna": "linning",
    "linningarnas": "linning",
    "linningars": "linning",
    "linningen": "linning",
    "linningens": "linning",
    "linnings": "linning",
    "linolensyran": "linolensyra",
    "linolensyrans": "linolensyra",
    "linolensyras": "linolensyra",
    "linolensyre": "linolensyra",
    "linolensyror": "linolensyra",
    "linolensyrorna": "linolensyra",
    "linolensyrornas": "linolensyra",
    "linolensyrors": "linolensyra",
    "linoleumen": "linoleum",
    "linoleumens": "linoleum",
    "linoleumet": "linoleum",
    "linoleumets": "linoleum",
    "linoleummatt": "linoleummatta",
    "linoleummattan": "linoleummatta",
    "linoleummattans": "linoleummatta",
    "linoleummattas": "linoleummatta",
    "linoleummatte": "linoleummatta",
    "linoleummattor": "linoleummatta",
    "linoleummattorna": "linoleummatta",
    "linoleummattornas": "linoleummatta",
    "linoleummattors": "linoleummatta",
    "linoleummatts": "linoleummatta",
    "linoleums": "linoleum",
    "linoleumsnitten": "linoleumsnitt",
    "linoleumsnittens": "linoleumsnitt",
    "linoleumsnittet": "linoleumsnitt",
    "linoleumsnittets": "linoleumsnitt",
    "linoleumsnitts": "linoleumsnitt",
    "linoljan": "linolja",
    "linoljans": "linolja",
    "linoljas": "linolja",
    "linolje": "linolja",
    "linoljebaserade": "linoljebaserad",
    "linoljebaserades": "linoljebaserad",
    "linoljebaserads": "linoljebaserad",
    "linoljebaserat": "linoljebaserad",
    "linoljebaserats": "linoljebaserad",
    "linoljefärgen": "linoljefärg",
    "linoljefärgens": "linoljefärg",
    "linoljefärger": "linoljefärg",
    "linoljefärgerna": "linoljefärg",
    "linoljefärgernas": "linoljefärg",
    "linoljefärgers": "linoljefärg",
    "linoljefärgs": "linoljefärg",
    "linoljor": "linolja",
    "linoljorna": "linolja",
    "linoljornas": "linolja",
    "linoljors": "linolja",
    "linolsyran": "linolsyra",
    "linolsyrans": "linolsyra",
    "linolsyras": "linolsyra",
    "linolsyre": "linolsyra",
    "linolsyror": "linolsyra",
    "linolsyrorna": "linolsyra",
    "linolsyrornas": "linolsyra",
    "linolsyrors": "linolsyra",
    "linongen": "linong",
    "linongens": "linong",
    "linonget": "linong",
    "linongets": "linong",
    "linongs": "linong",
    "linor": "lina",
    "linorna": "lina",
    "linornas": "lina",
    "linors": "lina",
    "lins": "lina",
    "linsdiametern": "linsdiameter",
    "linsdiameterns": "linsdiameter",
    "linsdiameters": "linsdiameter",
    "linsdiametrar": "linsdiameter",
    "linsdiametrarna": "linsdiameter",
    "linsdiametrarnas": "linsdiameter",
    "linsdiametrars": "linsdiameter",
    "linsen": "lins",
    "linsens": "lins",
    "linser": "lins",
    "linserna": "lins",
    "linsernas": "lins",
    "linsers": "lins",
    "linsfelen": "linsfel",
    "linsfelens": "linsfel",
    "linsfelet": "linsfel",
    "linsfelets": "linsfel",
    "linsfels": "linsfel",
    "linskivan": "linskiva",
    "linskivans": "linskiva",
    "linskivas": "linskiva",
    "linskive": "linskiva",
    "linskivor": "linskiva",
    "linskivorna": "linskiva",
    "linskivornas": "linskiva",
    "linskivors": "linskiva",
    "linslusen": "linslus",
    "linslusens": "linslus",
    "linslöss": "linslus",
    "linslössen": "linslus",
    "linslössens": "linslus",
    "linssopp": "linssoppa",
    "linssoppan": "linssoppa",
    "linssoppans": "linssoppa",
    "linssoppas": "linssoppa",
    "linssoppe": "linssoppa",
    "linssoppor": "linssoppa",
    "linssopporna": "linssoppa",
    "linssoppornas": "linssoppa",
    "linssoppors": "linssoppa",
    "linssopps": "linssoppa",
    "linssystemen": "linssystem",
    "linssystemens": "linssystem",
    "linssystemet": "linssystem",
    "linssystemets": "linssystem",
    "linssystems": "linssystem",
    "lintottar": "lintott",
    "lintottarna": "lintott",
    "lintottarnas": "lintott",
    "lintottars": "lintott",
    "lintotten": "lintott",
    "lintottens": "lintott",
    "lintotts": "lintott",
    "linvita": "linvit",
    "linvitare": "linvit",
    "linvitares": "linvit",
    "linvitas": "linvit",
    "linvitast": "linvit",
    "linvitaste": "linvit",
    "linvitastes": "linvit",
    "linvitasts": "linvit",
    "linvite": "linvit",
    "linvites": "linvit",
    "linvits": "linvit",
    "linvitt": "linvit",
    "linvitts": "linvit",
    "linåkern": "linåker",
    "linåkerns": "linåker",
    "linåkers": "linåker",
    "linåkrar": "linåker",
    "linåkrarna": "linåker",
    "linåkrarnas": "linåker",
    "linåkrars": "linåker",
    "lip": "lipa",
    "lipade": "lipa",
    "lipades": "lipa",
    "lipande": "lipa",
    "lipanden": "lipande",
    "lipandena": "lipande",
    "lipandenas": "lipande",
    "lipandens": "lipande",
    "lipandes": "lipande",
    "lipandet": "lipande",
    "lipandets": "lipande",
    "lipar": "lipa",
    "lipas": "lipa",
    "lipasen": "lipas",
    "lipasens": "lipas",
    "lipaser": "lipas",
    "lipaserna": "lipas",
    "lipasernas": "lipas",
    "lipasers": "lipas",
    "lipat": "lipa",
    "lipats": "lipa",
    "lipiden": "lipid",
    "lipidens": "lipid",
    "lipider": "lipid",
    "lipiderna": "lipid",
    "lipidernas": "lipid",
    "lipiders": "lipid",
    "lipids": "lipid",
    "lipiga": "lipig",
    "lipigare": "lipig",
    "lipigares": "lipig",
    "lipigas": "lipig",
    "lipigast": "lipig",
    "lipigaste": "lipig",
    "lipigastes": "lipig",
    "lipigasts": "lipig",
    "lipige": "lipig",
    "lipiges": "lipig",
    "lipigs": "lipig",
    "lipigt": "lipig",
    "lipigts": "lipig",
    "lipomen": "lipom",
    "lipomens": "lipom",
    "lipomet": "lipom",
    "lipomets": "lipom",
    "lipoms": "lipom",
    "lipsillar": "lipsill",
    "lipsillarna": "lipsill",
    "lipsillarnas": "lipsill",
    "lipsillars": "lipsill",
    "lipsillen": "lipsill",
    "lipsillens": "lipsill",
    "lipsills": "lipsill",
    "lir": "lira",
    "lirad": "lira",
    "lirade": "lira",
    "lirades": "lira",
    "lirads": "lira",
    "liran": "lira",
    "lirande": "lira",
    "liranden": "lirande",
    "lirandena": "lirande",
    "lirandenas": "lirande",
    "lirandens": "lirande",
    "lirandes": "lirande",
    "lirandet": "lirande",
    "lirandets": "lirande",
    "lirans": "lira",
    "lirar": "lirare",
    "liraren": "lirare",
    "lirarens": "lirare",
    "lirares": "lirare",
    "lirarna": "lirare",
    "lirarnas": "lirare",
    "liras": "lira",
    "lirat": "lira",
    "lirats": "lira",
    "lire": "lira",
    "liren": "lire",
    "lirena": "lire",
    "lirenas": "lire",
    "lirens": "lire",
    "lires": "lire",
    "liret": "lir",
    "lirets": "lir",
    "lirk": "lirka",
    "lirkade": "lirka",
    "lirkades": "lirka",
    "lirkande": "lirka",
    "lirkanden": "lirkande",
    "lirkandena": "lirkande",
    "lirkandenas": "lirkande",
    "lirkandens": "lirkande",
    "lirkandes": "lirkande",
    "lirkandet": "lirkande",
    "lirkandets": "lirkande",
    "lirkar": "lirka",
    "lirkas": "lirka",
    "lirkat": "lirka",
    "lirkats": "lirka",
    "liror": "lira",
    "lirorna": "lira",
    "lirornas": "lira",
    "lirors": "lira",
    "lirs": "lira",
    "lis": "lie",
    "lisans": "lisa",
    "lisenen": "lisen",
    "lisenens": "lisen",
    "lisener": "lisen",
    "lisenerna": "lisen",
    "lisenernas": "lisen",
    "liseners": "lisen",
    "lisens": "lisen",
    "lismade": "lisma",
    "lismades": "lisma",
    "lismande": "lisma",
    "lismanden": "lismande",
    "lismandena": "lismande",
    "lismandenas": "lismande",
    "lismandens": "lismande",
    "lismandes": "lismande",
    "lismandet": "lismande",
    "lismandets": "lismande",
    "lismar": "lismare",
    "lismaren": "lismare",
    "lismarens": "lismare",
    "lismares": "lismare",
    "lismarna": "lismare",
    "lismarnas": "lismare",
    "lismas": "lisma",
    "lismat": "lisma",
    "lismats": "lisma",
    "lispunden": "lispund",
    "lispundens": "lispund",
    "lispundet": "lispund",
    "lispundets": "lispund",
    "lispunds": "lispund",
    "lisserad": "lissera",
    "lisserade": "lissera",
    "lisserades": "lissera",
    "lisserads": "lissera",
    "lisserande": "lissera",
    "lisseranden": "lisserande",
    "lisserandena": "lisserande",
    "lisserandenas": "lisserande",
    "lisserandens": "lisserande",
    "lisserandes": "lisserande",
    "lisserandet": "lisserande",
    "lisserandets": "lisserande",
    "lisserar": "lissera",
    "lisseras": "lissera",
    "lisserat": "lissera",
    "lisserats": "lissera",
    "lisserbara": "lisserbar",
    "lisserbarare": "lisserbar",
    "lisserbarares": "lisserbar",
    "lisserbaras": "lisserbar",
    "lisserbarast": "lisserbar",
    "lisserbaraste": "lisserbar",
    "lisserbarastes": "lisserbar",
    "lisserbarasts": "lisserbar",
    "lisserbare": "lisserbar",
    "lisserbares": "lisserbar",
    "lisserbarheten": "lisserbarhet",
    "lisserbarhetens": "lisserbarhet",
    "lisserbarhets": "lisserbarhet",
    "lisserbars": "lisserbar",
    "lisserbart": "lisserbar",
    "lisserbarts": "lisserbar",
    "lisseringar": "lissering",
    "lisseringarna": "lissering",
    "lisseringarnas": "lissering",
    "lisseringars": "lissering",
    "lisseringen": "lissering",
    "lisseringens": "lissering",
    "lisserings": "lissering",
    "list": "lista",
    "listad": "lista",
    "listade": "lista",
    "listades": "lista",
    "listads": "lista",
    "listan": "lista",
    "listande": "lista",
    "listanden": "listande",
    "listandena": "listande",
    "listandenas": "listande",
    "listandens": "listande",
    "listandes": "listande",
    "listandet": "listande",
    "listandets": "listande",
    "listans": "lista",
    "listar": "lista",
    "listas": "lista",
    "listat": "lista",
    "listats": "lista",
    "liste": "lista",
    "listen": "list",
    "listens": "list",
    "lister": "list",
    "listerna": "list",
    "listernas": "list",
    "listers": "list",
    "listettan": "listetta",
    "listettans": "listetta",
    "listettas": "listetta",
    "listettor": "listetta",
    "listettorna": "listetta",
    "listettornas": "listetta",
    "listettors": "listetta",
    "listiga": "listig",
    "listigare": "listig",
    "listigares": "listig",
    "listigas": "listig",
    "listigast": "listig",
    "listigaste": "listig",
    "listigastes": "listig",
    "listigasts": "listig",
    "listige": "listig",
    "listiges": "listig",
    "listigheten": "listighet",
    "listighetens": "listighet",
    "listighets": "listighet",
    "listigs": "listig",
    "listigt": "listig",
    "listigts": "listig",
    "listor": "lista",
    "listorna": "lista",
    "listornamenten": "listornament",
    "listornamentens": "listornament",
    "listornamentet": "listornament",
    "listornamentets": "listornament",
    "listornaments": "listornament",
    "listornas": "lista",
    "listors": "lista",
    "listprofilen": "listprofil",
    "listprofilens": "listprofil",
    "listprofiler": "listprofil",
    "listprofilerna": "listprofil",
    "listprofilernas": "listprofil",
    "listprofilers": "listprofil",
    "listprofils": "listprofil",
    "lists": "list",
    "listverken": "listverk",
    "listverkens": "listverk",
    "listverket": "listverk",
    "listverkets": "listverk",
    "listverks": "listverk",
    "lisösen": "lisös",
    "lisösens": "lisös",
    "lisöser": "lisös",
    "lisöserna": "lisös",
    "lisösernas": "lisös",
    "lisösers": "lisös",
    "litade": "lita",
    "litades": "lita",
    "litande": "lita",
    "litanden": "litande",
    "litandena": "litande",
    "litandenas": "litande",
    "litandens": "litande",
    "litandes": "litande",
    "litandet": "litande",
    "litandets": "litande",
    "litani": "litania",
    "litanian": "litania",
    "litanians": "litania",
    "litanias": "litania",
    "litanie": "litania",
    "litanior": "litania",
    "litaniorna": "litania",
    "litaniornas": "litania",
    "litaniors": "litania",
    "litanis": "litania",
    "litar": "lita",
    "litas": "lita",
    "litat": "lita",
    "litats": "lita",
    "litauern": "litauer",
    "litauerna": "litauer",
    "litauernas": "litauer",
    "litauerns": "litauer",
    "litauers": "litauer",
    "litauisk": "litauiska",
    "litauiska": "litauisk",
    "litauiskan": "litauiska",
    "litauiskans": "litauiska",
    "litauiskare": "litauisk",
    "litauiskares": "litauisk",
    "litauiskas": "litauiska",
    "litauiskast": "litauisk",
    "litauiskaste": "litauisk",
    "litauiskastes": "litauisk",
    "litauiskasts": "litauisk",
    "litauiske": "litauiska",
    "litauiskes": "litauisk",
    "litauiskor": "litauiska",
    "litauiskorna": "litauiska",
    "litauiskornas": "litauiska",
    "litauiskors": "litauiska",
    "litauisks": "litauisk",
    "litauiskt": "litauisk",
    "litauiskts": "litauisk",
    "litenheten": "litenhet",
    "litenhetens": "litenhet",
    "litenheter": "litenhet",
    "litenheterna": "litenhet",
    "litenheternas": "litenhet",
    "litenheters": "litenhet",
    "litenhets": "litenhet",
    "litens": "liten",
    "litermåtten": "litermått",
    "litermåttens": "litermått",
    "litermåttet": "litermått",
    "litermåttets": "litermått",
    "litermåtts": "litermått",
    "litern": "liter",
    "literna": "liter",
    "liternas": "liter",
    "literns": "liter",
    "liters": "liter",
    "litervikten": "litervikt",
    "literviktens": "litervikt",
    "litervikts": "litervikt",
    "litet": "liten",
    "litets": "liten",
    "litiet": "litium",
    "litiets": "litium",
    "litiumbatterier": "litiumbatteri",
    "litiumbatterierna": "litiumbatteri",
    "litiumbatteriernas": "litiumbatteri",
    "litiumbatteriers": "litiumbatteri",
    "litiumbatteriet": "litiumbatteri",
    "litiumbatteriets": "litiumbatteri",
    "litiumbatteris": "litiumbatteri",
    "litiumbatterit": "litiumbatteri",
    "litiumbatterits": "litiumbatteri",
    "litiumet": "litium",
    "litiumets": "litium",
    "litiums": "litium",
    "litografen": "litograf",
    "litografens": "litograf",
    "litografer": "litograf",
    "litograferad": "litografera",
    "litograferade": "litografera",
    "litograferades": "litografera",
    "litograferads": "litografera",
    "litograferande": "litografera",
    "litograferanden": "litograferande",
    "litograferandena": "litograferande",
    "litograferandenas": "litograferande",
    "litograferandens": "litograferande",
    "litograferandes": "litograferande",
    "litograferandet": "litograferande",
    "litograferandets": "litograferande",
    "litograferar": "litografera",
    "litograferas": "litografera",
    "litograferat": "litografera",
    "litograferats": "litografera",
    "litograferbara": "litograferbar",
    "litograferbarare": "litograferbar",
    "litograferbarares": "litograferbar",
    "litograferbaras": "litograferbar",
    "litograferbarast": "litograferbar",
    "litograferbaraste": "litograferbar",
    "litograferbarastes": "litograferbar",
    "litograferbarasts": "litograferbar",
    "litograferbare": "litograferbar",
    "litograferbares": "litograferbar",
    "litograferbarheten": "litograferbarhet",
    "litograferbarhetens": "litograferbarhet",
    "litograferbarhets": "litograferbarhet",
    "litograferbars": "litograferbar",
    "litograferbart": "litograferbar",
    "litograferbarts": "litograferbar",
    "litograferingar": "litografering",
    "litograferingarna": "litografering",
    "litograferingarnas": "litografering",
    "litograferingars": "litografering",
    "litograferingen": "litografering",
    "litograferingens": "litografering",
    "litograferings": "litografering",
    "litograferna": "litograf",
    "litografernas": "litograf",
    "litografers": "litograf",
    "litografien": "litografi",
    "litografiens": "litografi",
    "litografier": "litografi",
    "litografierna": "litografi",
    "litografiernas": "litografi",
    "litografiers": "litografi",
    "litografin": "litografi",
    "litografins": "litografi",
    "litografis": "litografi",
    "litografs": "litograf",
    "litorala": "litoral",
    "litoralare": "litoral",
    "litoralares": "litoral",
    "litoralas": "litoral",
    "litoralast": "litoral",
    "litoralaste": "litoral",
    "litoralastes": "litoral",
    "litoralasts": "litoral",
    "litorale": "litoral",
    "litorales": "litoral",
    "litorals": "litoral",
    "litoralt": "litoral",
    "litoralts": "litoral",
    "litosfären": "litosfär",
    "litosfärens": "litosfär",
    "litosfärs": "litosfär",
    "litotesen": "litotes",
    "litotesens": "litotes",
    "litoteser": "litotes",
    "litoteserna": "litotes",
    "litotesernas": "litotes",
    "litotesers": "litotes",
    "litrar": "liter",
    "litrarna": "liter",
    "litrarnas": "liter",
    "litrars": "liter",
    "lits": "litsa",
    "litsad": "litsa",
    "litsade": "litsa",
    "litsades": "litsa",
    "litsads": "litsa",
    "litsande": "litsa",
    "litsanden": "litsande",
    "litsandena": "litsande",
    "litsandenas": "litsande",
    "litsandens": "litsande",
    "litsandes": "litsande",
    "litsandet": "litsande",
    "litsandets": "litsande",
    "litsar": "litsa",
    "litsas": "litsa",
    "litsat": "litsa",
    "litsats": "litsa",
    "litter": "littera",
    "litteran": "littera",
    "litterans": "littera",
    "litteras": "littera",
    "litterata": "litterat",
    "litteratare": "litterat",
    "litteratares": "litterat",
    "litteratas": "litterat",
    "litteratast": "litterat",
    "litterataste": "litterat",
    "litteratastes": "litterat",
    "litteratasts": "litterat",
    "litterate": "litterat",
    "litterates": "litterat",
    "litterats": "litterat",
    "litteraturanmälans": "litteraturanmälan",
    "litteraturanmälningar": "litteraturanmälan",
    "litteraturanmälningarna": "litteraturanmälan",
    "litteraturanmälningarnas": "litteraturanmälan",
    "litteraturanmälningars": "litteraturanmälan",
    "litteraturanvisningar": "litteraturanvisning",
    "litteraturanvisningarna": "litteraturanvisning",
    "litteraturanvisningarnas": "litteraturanvisning",
    "litteraturanvisningars": "litteraturanvisning",
    "litteraturanvisningen": "litteraturanvisning",
    "litteraturanvisningens": "litteraturanvisning",
    "litteraturanvisnings": "litteraturanvisning",
    "litteraturen": "litteratur",
    "litteraturens": "litteratur",
    "litteraturer": "litteratur",
    "litteraturerna": "litteratur",
    "litteraturernas": "litteratur",
    "litteraturers": "litteratur",
    "litteraturforskar": "litteraturforskare",
    "litteraturforskaren": "litteraturforskare",
    "litteraturforskarens": "litteraturforskare",
    "litteraturforskares": "litteraturforskare",
    "litteraturforskarna": "litteraturforskare",
    "litteraturforskarnas": "litteraturforskare",
    "litteraturförteckningar": "litteraturförteckning",
    "litteraturförteckningarna": "litteraturförteckning",
    "litteraturförteckningarnas": "litteraturförteckning",
    "litteraturförteckningars": "litteraturförteckning",
    "litteraturförteckningen": "litteraturförteckning",
    "litteraturförteckningens": "litteraturförteckning",
    "litteraturförtecknings": "litteraturförteckning",
    "litteraturgenren": "litteraturgenre",
    "litteraturgenrens": "litteraturgenre",
    "litteraturgenrer": "litteraturgenre",
    "litteraturgenrerna": "litteraturgenre",
    "litteraturgenrernas": "litteraturgenre",
    "litteraturgenrers": "litteraturgenre",
    "litteraturgenres": "litteraturgenre",
    "litteraturhistorian": "litteraturhistoria",
    "litteraturhistorians": "litteraturhistoria",
    "litteraturhistorias": "litteraturhistoria",
    "litteraturhistorien": "litteraturhistoria",
    "litteraturhistoriens": "litteraturhistoria",
    "litteraturhistoriska": "litteraturhistorisk",
    "litteraturhistoriskare": "litteraturhistorisk",
    "litteraturhistoriskares": "litteraturhistorisk",
    "litteraturhistoriskas": "litteraturhistorisk",
    "litteraturhistoriskast": "litteraturhistorisk",
    "litteraturhistoriskaste": "litteraturhistorisk",
    "litteraturhistoriskastes": "litteraturhistorisk",
    "litteraturhistoriskasts": "litteraturhistorisk",
    "litteraturhistoriske": "litteraturhistorisk",
    "litteraturhistoriskes": "litteraturhistorisk",
    "litteraturhistorisks": "litteraturhistorisk",
    "litteraturhistoriskt": "litteraturhistorisk",
    "litteraturhistoriskts": "litteraturhistorisk",
    "litteraturhänvisningar": "litteraturhänvisning",
    "litteraturhänvisningarna": "litteraturhänvisning",
    "litteraturhänvisningarnas": "litteraturhänvisning",
    "litteraturhänvisningars": "litteraturhänvisning",
    "litteraturhänvisningen": "litteraturhänvisning",
    "litteraturhänvisningens": "litteraturhänvisning",
    "litteraturhänvisnings": "litteraturhänvisning",
    "litteraturingenjören": "litteraturingenjör",
    "litteraturingenjörens": "litteraturingenjör",
    "litteraturingenjörer": "litteraturingenjör",
    "litteraturingenjörerna": "litteraturingenjör",
    "litteraturingenjörernas": "litteraturingenjör",
    "litteraturingenjörers": "litteraturingenjör",
    "litteraturingenjörn": "litteraturingenjör",
    "litteraturingenjörns": "litteraturingenjör",
    "litteraturingenjörs": "litteraturingenjör",
    "litteraturkanonen": "litteraturkanon",
    "litteraturkanonens": "litteraturkanon",
    "litteraturkanoner": "litteraturkanon",
    "litteraturkanonerna": "litteraturkanon",
    "litteraturkanonernas": "litteraturkanon",
    "litteraturkanoners": "litteraturkanon",
    "litteraturkanons": "litteraturkanon",
    "litteraturkritiken": "litteraturkritik",
    "litteraturkritikens": "litteraturkritik",
    "litteraturkritikern": "litteraturkritiker",
    "litteraturkritikerna": "litteraturkritiker",
    "litteraturkritikernas": "litteraturkritiker",
    "litteraturkritikerns": "litteraturkritiker",
    "litteraturkritikers": "litteraturkritiker",
    "litteraturkritiks": "litteraturkritik",
    "litteraturprofessorer": "litteraturprofessor",
    "litteraturprofessorerna": "litteraturprofessor",
    "litteraturprofessorernas": "litteraturprofessor",
    "litteraturprofessorers": "litteraturprofessor",
    "litteraturprofessorn": "litteraturprofessor",
    "litteraturprofessorns": "litteraturprofessor",
    "litteraturprofessors": "litteraturprofessor",
    "litteraturs": "litteratur",
    "litteratursociologien": "litteratursociologi",
    "litteratursociologiens": "litteratursociologi",
    "litteratursociologin": "litteratursociologi",
    "litteratursociologins": "litteratursociologi",
    "litteratursociologis": "litteratursociologi",
    "litteraturspråken": "litteraturspråk",
    "litteraturspråkens": "litteraturspråk",
    "litteraturspråket": "litteraturspråk",
    "litteraturspråkets": "litteraturspråk",
    "litteraturspråks": "litteraturspråk",
    "litteratursynen": "litteratursyn",
    "litteratursynens": "litteratursyn",
    "litteratursyner": "litteratursyn",
    "litteratursynerna": "litteratursyn",
    "litteratursynernas": "litteratursyn",
    "litteratursyners": "litteratursyn",
    "litteratursyns": "litteratursyn",
    "litteratursökningar": "litteratursökning",
    "litteratursökningarna": "litteratursökning",
    "litteratursökningarnas": "litteratursökning",
    "litteratursökningars": "litteratursökning",
    "litteratursökningen": "litteratursökning",
    "litteratursökningens": "litteratursökning",
    "litteratursöknings": "litteratursökning",
    "litteraturvetenskapen": "litteraturvetenskap",
    "litteraturvetenskapens": "litteraturvetenskap",
    "litteraturvetenskapliga": "litteraturvetenskaplig",
    "litteraturvetenskapligas": "litteraturvetenskaplig",
    "litteraturvetenskaplige": "litteraturvetenskaplig",
    "litteraturvetenskapliges": "litteraturvetenskaplig",
    "litteraturvetenskapligs": "litteraturvetenskaplig",
    "litteraturvetenskapligt": "litteraturvetenskaplig",
    "litteraturvetenskapligts": "litteraturvetenskaplig",
    "litteraturvetenskaps": "litteraturvetenskap",
    "litteratören": "litteratör",
    "litteratörens": "litteratör",
    "litteratörer": "litteratör",
    "litteratörerna": "litteratör",
    "litteratörernas": "litteratör",
    "litteratörers": "litteratör",
    "litteratörs": "litteratör",
    "littere": "littera",
    "litteror": "littera",
    "litterorna": "littera",
    "litterornas": "littera",
    "litterors": "littera",
    "litters": "littera",
    "litterära": "litterär",
    "litterärare": "litterär",
    "litterärares": "litterär",
    "litteräras": "litterär",
    "litterärast": "litterär",
    "litteräraste": "litterär",
    "litterärastes": "litterär",
    "litterärasts": "litterär",
    "litteräre": "litterär",
    "litteräres": "litterär",
    "litterärs": "litterär",
    "litterärt": "litterär",
    "litterärts": "litterär",
    "liturgen": "liturg",
    "liturgens": "liturg",
    "liturger": "liturg",
    "liturgerna": "liturg",
    "liturgernas": "liturg",
    "liturgers": "liturg",
    "liturgien": "liturgi",
    "liturgiens": "liturgi",
    "liturgier": "liturgi",
    "liturgierna": "liturgi",
    "liturgiernas": "liturgi",
    "liturgiers": "liturgi",
    "liturgin": "liturgi",
    "liturgins": "liturgi",
    "liturgis": "liturgi",
    "liturgiska": "liturgisk",
    "liturgiskare": "liturgisk",
    "liturgiskares": "liturgisk",
    "liturgiskas": "liturgisk",
    "liturgiskast": "liturgisk",
    "liturgiskaste": "liturgisk",
    "liturgiskastes": "liturgisk",
    "liturgiskasts": "liturgisk",
    "liturgiske": "liturgisk",
    "liturgiskes": "liturgisk",
    "liturgisks": "liturgisk",
    "liturgiskt": "liturgisk",
    "liturgiskts": "liturgisk",
    "liturgs": "liturg",
    "liv": "liva",
    "livad": "liva",
    "livade": "livad",
    "livades": "livad",
    "livads": "livad",
    "livaktiga": "livaktig",
    "livaktigare": "livaktig",
    "livaktigares": "livaktig",
    "livaktigas": "livaktig",
    "livaktigast": "livaktig",
    "livaktigaste": "livaktig",
    "livaktigastes": "livaktig",
    "livaktigasts": "livaktig",
    "livaktige": "livaktig",
    "livaktiges": "livaktig",
    "livaktigheten": "livaktighet",
    "livaktighetens": "livaktighet",
    "livaktighets": "livaktighet",
    "livaktigs": "livaktig",
    "livaktigt": "livaktig",
    "livaktigts": "livaktig",
    "livande": "liva",
    "livanden": "livande",
    "livandena": "livande",
    "livandenas": "livande",
    "livandens": "livande",
    "livandes": "livande",
    "livandet": "livande",
    "livandets": "livande",
    "livar": "liva",
    "livas": "liva",
    "livat": "livad",
    "livats": "livad",
    "livbojar": "livboj",
    "livbojarna": "livboj",
    "livbojarnas": "livboj",
    "livbojars": "livboj",
    "livbojen": "livboj",
    "livbojens": "livboj",
    "livbojs": "livboj",
    "livbojsorten": "livbojsort",
    "livbojsortens": "livbojsort",
    "livbojsorter": "livbojsort",
    "livbojsorterna": "livbojsort",
    "livbojsorternas": "livbojsort",
    "livbojsorters": "livbojsort",
    "livbojsorts": "livbojsort",
    "livbälten": "livbälte",
    "livbältena": "livbälte",
    "livbältenas": "livbälte",
    "livbältens": "livbälte",
    "livbältes": "livbälte",
    "livbältet": "livbälte",
    "livbältets": "livbälte",
    "livbåtar": "livbåt",
    "livbåtarna": "livbåt",
    "livbåtarnas": "livbåt",
    "livbåtars": "livbåt",
    "livbåten": "livbåt",
    "livbåtens": "livbåt",
    "livbåts": "livbåt",
    "livdjuren": "livdjur",
    "livdjurens": "livdjur",
    "livdjuret": "livdjur",
    "livdjurets": "livdjur",
    "livdjurs": "livdjur",
    "livdrabanten": "livdrabant",
    "livdrabantens": "livdrabant",
    "livdrabanter": "livdrabant",
    "livdrabanterna": "livdrabant",
    "livdrabanternas": "livdrabant",
    "livdrabanters": "livdrabant",
    "livdrabants": "livdrabant",
    "livdömda": "livdömd",
    "livdömdare": "livdömd",
    "livdömdares": "livdömd",
    "livdömdas": "livdömd",
    "livdömdast": "livdömd",
    "livdömdaste": "livdömd",
    "livdömdastes": "livdömd",
    "livdömdasts": "livdömd",
    "livdömde": "livdömd",
    "livdömdes": "livdömd",
    "livdömds": "livdömd",
    "livdömt": "livdömd",
    "livdömts": "livdömd",
    "live-showen": "live-show",
    "live-showens": "live-show",
    "live-shower": "live-show",
    "live-showerna": "live-show",
    "live-showernas": "live-show",
    "live-showers": "live-show",
    "live-shows": "live-show",
    "livegenheten": "livegenhet",
    "livegenhetens": "livegenhet",
    "livegenhets": "livegenhet",
    "livegens": "livegen",
    "livegenskapen": "livegenskap",
    "livegenskapens": "livegenskap",
    "livegenskaps": "livegenskap",
    "liveget": "livegen",
    "livegets": "livegen",
    "livegna": "livegen",
    "livegnare": "livegen",
    "livegnares": "livegen",
    "livegnas": "livegen",
    "livegnast": "livegen",
    "livegnaste": "livegen",
    "livegnastes": "livegen",
    "livegnasts": "livegen",
    "livegne": "livegen",
    "livegnes": "livegen",
    "liven": "liv",
    "livens": "liv",
    "livet": "liv",
    "livets": "liv",
    "livfulla": "livfull",
    "livfullare": "livfull",
    "livfullares": "livfull",
    "livfullas": "livfull",
    "livfullast": "livfull",
    "livfullaste": "livfull",
    "livfullastes": "livfull",
    "livfullasts": "livfull",
    "livfulle": "livfull",
    "livfulles": "livfull",
    "livfullheten": "livfullhet",
    "livfullhetens": "livfullhet",
    "livfullhets": "livfullhet",
    "livfulls": "livfull",
    "livfullt": "livfull",
    "livfullts": "livfull",
    "livförsäkrad": "livförsäkra",
    "livförsäkrade": "livförsäkra",
    "livförsäkrades": "livförsäkra",
    "livförsäkrads": "livförsäkra",
    "livförsäkrande": "livförsäkra",
    "livförsäkranden": "livförsäkrande",
    "livförsäkrandena": "livförsäkrande",
    "livförsäkrandenas": "livförsäkrande",
    "livförsäkrandens": "livförsäkrande",
    "livförsäkrandes": "livförsäkrande",
    "livförsäkrandet": "livförsäkrande",
    "livförsäkrandets": "livförsäkrande",
    "livförsäkrar": "livförsäkra",
    "livförsäkras": "livförsäkra",
    "livförsäkrat": "livförsäkra",
    "livförsäkrats": "livförsäkra",
    "livförsäkringar": "livförsäkring",
    "livförsäkringarna": "livförsäkring",
    "livförsäkringarnas": "livförsäkring",
    "livförsäkringars": "livförsäkring",
    "livförsäkringen": "livförsäkring",
    "livförsäkringens": "livförsäkring",
    "livförsäkrings": "livförsäkring",
    "livgarden": "livgarde",
    "livgardena": "livgarde",
    "livgardenas": "livgarde",
    "livgardens": "livgarde",
    "livgardes": "livgarde",
    "livgardet": "livgarde",
    "livgardets": "livgarde",
    "livhanken": "livhank",
    "livhankens": "livhank",
    "livhanks": "livhank",
    "livklädnaden": "livklädnad",
    "livklädnadens": "livklädnad",
    "livklädnader": "livklädnad",
    "livklädnaderna": "livklädnad",
    "livklädnadernas": "livklädnad",
    "livklädnaders": "livklädnad",
    "livklädnads": "livklädnad",
    "livliga": "livlig",
    "livligare": "livlig",
    "livligares": "livlig",
    "livligas": "livlig",
    "livligast": "livlig",
    "livligaste": "livlig",
    "livligastes": "livlig",
    "livligasts": "livlig",
    "livlige": "livlig",
    "livliges": "livlig",
    "livligheten": "livlighet",
    "livlighetens": "livlighet",
    "livligheter": "livlighet",
    "livligheterna": "livlighet",
    "livligheternas": "livlighet",
    "livligheters": "livlighet",
    "livlighets": "livlighet",
    "livligs": "livlig",
    "livligt": "livlig",
    "livligts": "livlig",
    "livlin": "livlina",
    "livlinan": "livlina",
    "livlinans": "livlina",
    "livlinas": "livlina",
    "livline": "livlina",
    "livlinor": "livlina",
    "livlinorna": "livlina",
    "livlinornas": "livlina",
    "livlinors": "livlina",
    "livlins": "livlina",
    "livlösa": "livlös",
    "livlösare": "livlös",
    "livlösares": "livlös",
    "livlösas": "livlös",
    "livlösast": "livlös",
    "livlösaste": "livlös",
    "livlösastes": "livlös",
    "livlösasts": "livlös",
    "livlöse": "livlös",
    "livlöses": "livlös",
    "livlösheten": "livlöshet",
    "livlöshetens": "livlöshet",
    "livlöshets": "livlöshet",
    "livlöst": "livlös",
    "livlösts": "livlös",
    "livmedici": "livmedikus",
    "livmedicina": "livmedikus",
    "livmedicinas": "livmedikus",
    "livmedicis": "livmedikus",
    "livmedikusen": "livmedikus",
    "livmedikusens": "livmedikus",
    "livmoderframfallen": "livmoderframfall",
    "livmoderframfallens": "livmoderframfall",
    "livmoderframfallet": "livmoderframfall",
    "livmoderframfallets": "livmoderframfall",
    "livmoderframfalls": "livmoderframfall",
    "livmoderhalsar": "livmoderhals",
    "livmoderhalsarna": "livmoderhals",
    "livmoderhalsarnas": "livmoderhals",
    "livmoderhalsars": "livmoderhals",
    "livmoderhalsen": "livmoderhals",
    "livmoderhalsens": "livmoderhals",
    "livmoderhål": "livmoderhåla",
    "livmoderhålan": "livmoderhåla",
    "livmoderhålans": "livmoderhåla",
    "livmoderhålas": "livmoderhåla",
    "livmoderhåle": "livmoderhåla",
    "livmoderhålor": "livmoderhåla",
    "livmoderhålorna": "livmoderhåla",
    "livmoderhålornas": "livmoderhåla",
    "livmoderhålors": "livmoderhåla",
    "livmoderhåls": "livmoderhåla",
    "livmodermunnar": "livmodermun",
    "livmodermunnarna": "livmodermun",
    "livmodermunnarnas": "livmodermun",
    "livmodermunnars": "livmodermun",
    "livmodermunnen": "livmodermun",
    "livmodermunnens": "livmodermun",
    "livmodermuns": "livmodermun",
    "livmodern": "livmoder",
    "livmoderns": "livmoder",
    "livmoders": "livmoder",
    "livmodersslemhinnan": "livmodersslemhinna",
    "livmodersslemhinnans": "livmodersslemhinna",
    "livmodersslemhinnas": "livmodersslemhinna",
    "livmodersslemhinne": "livmodersslemhinna",
    "livmodersslemhinnor": "livmodersslemhinna",
    "livmodersslemhinnorna": "livmodersslemhinna",
    "livmodersslemhinnornas": "livmodersslemhinna",
    "livmodersslemhinnors": "livmodersslemhinna",
    "livnär": "livnära",
    "livnärande": "livnära",
    "livnäranden": "livnärande",
    "livnärandena": "livnärande",
    "livnärandenas": "livnärande",
    "livnärandens": "livnärande",
    "livnärandes": "livnärande",
    "livnärandet": "livnärande",
    "livnärandets": "livnärande",
    "livnäras": "livnära",
    "livnärd": "livnära",
    "livnärda": "livnära",
    "livnärdas": "livnära",
    "livnärde": "livnära",
    "livnärdes": "livnära",
    "livnärds": "livnära",
    "livnäres": "livnära",
    "livnärs": "livnära",
    "livnärt": "livnära",
    "livnärts": "livnära",
    "livregementen": "livregemente",
    "livregementena": "livregemente",
    "livregementenas": "livregemente",
    "livregementens": "livregemente",
    "livregementes": "livregemente",
    "livregementet": "livregemente",
    "livregementets": "livregemente",
    "livremmar": "livrem",
    "livremmarna": "livrem",
    "livremmarnas": "livrem",
    "livremmars": "livrem",
    "livremmen": "livrem",
    "livremmens": "livrem",
    "livrems": "livrem",
    "livrustkammar": "livrustkammare",
    "livrustkammaren": "livrustkammare",
    "livrustkammarens": "livrustkammare",
    "livrustkammares": "livrustkammare",
    "livrustkamrar": "livrustkammare",
    "livrustkamrarna": "livrustkammare",
    "livrustkamrarnas": "livrustkammare",
    "livrustkamrars": "livrustkammare",
    "livrädda": "livrädd",
    "livräddar": "livräddare",
    "livräddare": "livrädd",
    "livräddaren": "livräddare",
    "livräddarens": "livräddare",
    "livräddares": "livräddare",
    "livräddarna": "livräddare",
    "livräddarnas": "livräddare",
    "livräddas": "livrädd",
    "livräddast": "livrädd",
    "livräddaste": "livrädd",
    "livräddastes": "livrädd",
    "livräddasts": "livrädd",
    "livrädde": "livrädd",
    "livräddes": "livrädd",
    "livräddningar": "livräddning",
    "livräddningarna": "livräddning",
    "livräddningarnas": "livräddning",
    "livräddningars": "livräddning",
    "livräddningen": "livräddning",
    "livräddningens": "livräddning",
    "livräddnings": "livräddning",
    "livräddningsdräkten": "livräddningsdräkt",
    "livräddningsdräktens": "livräddningsdräkt",
    "livräddningsdräkter": "livräddningsdräkt",
    "livräddningsdräkterna": "livräddningsdräkt",
    "livräddningsdräkternas": "livräddningsdräkt",
    "livräddningsdräkters": "livräddningsdräkt",
    "livräddningsdräkts": "livräddningsdräkt",
    "livrädds": "livrädd",
    "livräntan": "livränta",
    "livräntans": "livränta",
    "livräntas": "livränta",
    "livränte": "livränta",
    "livräntor": "livränta",
    "livräntorna": "livränta",
    "livräntornas": "livränta",
    "livräntors": "livränta",
    "livrätten": "livrätt",
    "livrättens": "livrätt",
    "livrätter": "livrätt",
    "livrätterna": "livrätt",
    "livrätternas": "livrätt",
    "livrätters": "livrätt",
    "livrätts": "livrätt",
    "livréer": "livré",
    "livréerna": "livré",
    "livréernas": "livré",
    "livréers": "livré",
    "livréet": "livré",
    "livréets": "livré",
    "livrés": "livré",
    "livrét": "livré",
    "livréts": "livré",
    "livs": "liv",
    "livsandarna": "livsandar",
    "livsandarnas": "livsandar",
    "livsandars": "livsandar",
    "livsanden": "livsande",
    "livsandens": "livsande",
    "livsandes": "livsande",
    "livsarvingar": "livsarvinge",
    "livsarvingarna": "livsarvinge",
    "livsarvingarnas": "livsarvinge",
    "livsarvingars": "livsarvinge",
    "livsarvingen": "livsarvinge",
    "livsarvingens": "livsarvinge",
    "livsarvinges": "livsarvinge",
    "livsbejakar": "livsbejakare",
    "livsbejakaren": "livsbejakare",
    "livsbejakarens": "livsbejakare",
    "livsbejakares": "livsbejakare",
    "livsbejakarna": "livsbejakare",
    "livsbejakarnas": "livsbejakare",
    "livsbejakelsen": "livsbejakelse",
    "livsbejakelsens": "livsbejakelse",
    "livsbejakelses": "livsbejakelse",
    "livsbetingelsen": "livsbetingelse",
    "livsbetingelsens": "livsbetingelse",
    "livsbetingelser": "livsbetingelse",
    "livsbetingelserna": "livsbetingelse",
    "livsbetingelsernas": "livsbetingelse",
    "livsbetingelsers": "livsbetingelse",
    "livsbetingelses": "livsbetingelse",
    "livscykeln": "livscykel",
    "livscykelns": "livscykel",
    "livscykels": "livscykel",
    "livscyklar": "livscykel",
    "livscyklarna": "livscykel",
    "livscyklarnas": "livscykel",
    "livscyklars": "livscykel",
    "livscykler": "livscykel",
    "livscyklerna": "livscykel",
    "livscyklernas": "livscykel",
    "livscyklers": "livscykel",
    "livsdugliga": "livsduglig",
    "livsdugligare": "livsduglig",
    "livsdugligares": "livsduglig",
    "livsdugligas": "livsduglig",
    "livsdugligast": "livsduglig",
    "livsdugligaste": "livsduglig",
    "livsdugligastes": "livsduglig",
    "livsdugligasts": "livsduglig",
    "livsduglige": "livsduglig",
    "livsdugliges": "livsduglig",
    "livsdugligheten": "livsduglighet",
    "livsduglighetens": "livsduglighet",
    "livsduglighets": "livsduglighet",
    "livsdugligs": "livsduglig",
    "livsdugligt": "livsduglig",
    "livsdugligts": "livsduglig",
    "livselixiren": "livselixir",
    "livselixirens": "livselixir",
    "livselixiret": "livselixir",
    "livselixirets": "livselixir",
    "livselixirs": "livselixir",
    "livsen": "livs",
    "livsens": "livs",
    "livserfarenheten": "livserfarenhet",
    "livserfarenhetens": "livserfarenhet",
    "livserfarenheter": "livserfarenhet",
    "livserfarenheterna": "livserfarenhet",
    "livserfarenheternas": "livserfarenhet",
    "livserfarenheters": "livserfarenhet",
    "livserfarenhets": "livserfarenhet",
    "livset": "livs",
    "livsets": "livs",
    "livsfaran": "livsfara",
    "livsfarans": "livsfara",
    "livsfaras": "livsfara",
    "livsfare": "livsfara",
    "livsfarliga": "livsfarlig",
    "livsfarligare": "livsfarlig",
    "livsfarligares": "livsfarlig",
    "livsfarligas": "livsfarlig",
    "livsfarligast": "livsfarlig",
    "livsfarligaste": "livsfarlig",
    "livsfarligastes": "livsfarlig",
    "livsfarligasts": "livsfarlig",
    "livsfarlige": "livsfarlig",
    "livsfarliges": "livsfarlig",
    "livsfarligheten": "livsfarlighet",
    "livsfarlighetens": "livsfarlighet",
    "livsfarligheter": "livsfarlighet",
    "livsfarligheterna": "livsfarlighet",
    "livsfarligheternas": "livsfarlighet",
    "livsfarligheters": "livsfarlighet",
    "livsfarlighets": "livsfarlighet",
    "livsfarligs": "livsfarlig",
    "livsfarligt": "livsfarlig",
    "livsfarligts": "livsfarlig",
    "livsfaro": "livsfara",
    "livsformen": "livsform",
    "livsformens": "livsform",
    "livsformer": "livsform",
    "livsformerna": "livsform",
    "livsformernas": "livsform",
    "livsformers": "livsform",
    "livsforms": "livsform",
    "livsfrågan": "livsfråga",
    "livsfrågans": "livsfråga",
    "livsfrågas": "livsfråga",
    "livsfråge": "livsfråga",
    "livsfrågor": "livsfråga",
    "livsfrågorna": "livsfråga",
    "livsfrågornas": "livsfråga",
    "livsfrågors": "livsfråga",
    "livsföringar": "livsföring",
    "livsföringarna": "livsföring",
    "livsföringarnas": "livsföring",
    "livsföringars": "livsföring",
    "livsföringen": "livsföring",
    "livsföringens": "livsföring",
    "livsförings": "livsföring",
    "livsförnekelsen": "livsförnekelse",
    "livsförnekelsens": "livsförnekelse",
    "livsförnekelser": "livsförnekelse",
    "livsförnekelserna": "livsförnekelse",
    "livsförnekelsernas": "livsförnekelse",
    "livsförnekelsers": "livsförnekelse",
    "livsförnekelses": "livsförnekelse",
    "livsförnödenheterna": "livsförnödenheter",
    "livsförnödenheternas": "livsförnödenheter",
    "livsförnödenheters": "livsförnödenheter",
    "livsförnödenhets": "livsförnödenheter",
    "livsglädjen": "livsglädje",
    "livsglädjens": "livsglädje",
    "livsglädjes": "livsglädje",
    "livsgärningar": "livsgärning",
    "livsgärningarna": "livsgärning",
    "livsgärningarnas": "livsgärning",
    "livsgärningars": "livsgärning",
    "livsgärningen": "livsgärning",
    "livsgärningens": "livsgärning",
    "livsgärnings": "livsgärning",
    "livshållningar": "livshållning",
    "livshållningarna": "livshållning",
    "livshållningarnas": "livshållning",
    "livshållningars": "livshållning",
    "livshållningen": "livshållning",
    "livshållningens": "livshållning",
    "livshållnings": "livshållning",
    "livskamraten": "livskamrat",
    "livskamratens": "livskamrat",
    "livskamrater": "livskamrat",
    "livskamraterna": "livskamrat",
    "livskamraternas": "livskamrat",
    "livskamraters": "livskamrat",
    "livskamrats": "livskamrat",
    "livskraften": "livskraft",
    "livskraftens": "livskraft",
    "livskraftiga": "livskraftig",
    "livskraftigare": "livskraftig",
    "livskraftigares": "livskraftig",
    "livskraftigas": "livskraftig",
    "livskraftigast": "livskraftig",
    "livskraftigaste": "livskraftig",
    "livskraftigastes": "livskraftig",
    "livskraftigasts": "livskraftig",
    "livskraftige": "livskraftig",
    "livskraftiges": "livskraftig",
    "livskraftigheten": "livskraftighet",
    "livskraftighetens": "livskraftighet",
    "livskraftighets": "livskraftighet",
    "livskraftigs": "livskraftig",
    "livskraftigt": "livskraftig",
    "livskraftigts": "livskraftig",
    "livskrafts": "livskraft",
    "livskrisen": "livskris",
    "livskrisens": "livskris",
    "livskriser": "livskris",
    "livskriserna": "livskris",
    "livskrisernas": "livskris",
    "livskrisers": "livskris",
    "livskvaliteten": "livskvalitet",
    "livskvalitetens": "livskvalitet",
    "livskvaliteter": "livskvalitet",
    "livskvaliteterna": "livskvalitet",
    "livskvaliteternas": "livskvalitet",
    "livskvaliteters": "livskvalitet",
    "livskvalitets": "livskvalitet",
    "livskänslan": "livskänsla",
    "livskänslans": "livskänsla",
    "livskänslas": "livskänsla",
    "livskänsle": "livskänsla",
    "livskänslo": "livskänsla",
    "livslagar": "livslag",
    "livslagarna": "livslag",
    "livslagarnas": "livslag",
    "livslagars": "livslag",
    "livslagen": "livslag",
    "livslagens": "livslag",
    "livslags": "livslag",
    "livsledan": "livsleda",
    "livsledans": "livsleda",
    "livsledas": "livsleda",
    "livslinjen": "livslinje",
    "livslinjens": "livslinje",
    "livslinjer": "livslinje",
    "livslinjerna": "livslinje",
    "livslinjernas": "livslinje",
    "livslinjers": "livslinje",
    "livslinjes": "livslinje",
    "livsluften": "livsluft",
    "livsluftens": "livsluft",
    "livslufts": "livsluft",
    "livslustar": "livslust",
    "livslustarna": "livslust",
    "livslustarnas": "livslust",
    "livslustars": "livslust",
    "livslusten": "livslust",
    "livslustens": "livslust",
    "livslusts": "livslust",
    "livslängden": "livslängd",
    "livslängdens": "livslängd",
    "livslängder": "livslängd",
    "livslängderna": "livslängd",
    "livslängdernas": "livslängd",
    "livslängders": "livslängd",
    "livslängds": "livslängd",
    "livslåg": "livslåga",
    "livslågan": "livslåga",
    "livslågans": "livslåga",
    "livslågas": "livslåga",
    "livslåge": "livslåga",
    "livslågor": "livslåga",
    "livslågorna": "livslåga",
    "livslågornas": "livslåga",
    "livslågors": "livslåga",
    "livslågs": "livslåga",
    "livslånga": "livslång",
    "livslångare": "livslång",
    "livslångares": "livslång",
    "livslångas": "livslång",
    "livslångast": "livslång",
    "livslångaste": "livslång",
    "livslångastes": "livslång",
    "livslångasts": "livslång",
    "livslånge": "livslång",
    "livslånges": "livslång",
    "livslångs": "livslång",
    "livslångt": "livslång",
    "livslångts": "livslång",
    "livslögnen": "livslögn",
    "livslögnens": "livslögn",
    "livslögner": "livslögn",
    "livslögnerna": "livslögn",
    "livslögnernas": "livslögn",
    "livslögners": "livslögn",
    "livslögns": "livslögn",
    "livsmedels": "livsmedel",
    "livsmedelsaffären": "livsmedelsaffär",
    "livsmedelsaffärens": "livsmedelsaffär",
    "livsmedelsaffärer": "livsmedelsaffär",
    "livsmedelsaffärerna": "livsmedelsaffär",
    "livsmedelsaffärernas": "livsmedelsaffär",
    "livsmedelsaffärers": "livsmedelsaffär",
    "livsmedelsaffärs": "livsmedelsaffär",
    "livsmedelsavfallen": "livsmedelsavfall",
    "livsmedelsavfallens": "livsmedelsavfall",
    "livsmedelsavfallet": "livsmedelsavfall",
    "livsmedelsavfallets": "livsmedelsavfall",
    "livsmedelsavfalls": "livsmedelsavfall",
    "livsmedelsbutiken": "livsmedelsbutik",
    "livsmedelsbutikens": "livsmedelsbutik",
    "livsmedelsbutiker": "livsmedelsbutik",
    "livsmedelsbutikerna": "livsmedelsbutik",
    "livsmedelsbutikernas": "livsmedelsbutik",
    "livsmedelsbutikers": "livsmedelsbutik",
    "livsmedelsbutiks": "livsmedelsbutik",
    "livsmedelsfärgen": "livsmedelsfärg",
    "livsmedelsfärgens": "livsmedelsfärg",
    "livsmedelsfärger": "livsmedelsfärg",
    "livsmedelsfärgerna": "livsmedelsfärg",
    "livsmedelsfärgernas": "livsmedelsfärg",
    "livsmedelsfärgers": "livsmedelsfärg",
    "livsmedelsfärgs": "livsmedelsfärg",
    "livsmedelsförsörjningar": "livsmedelsförsörjning",
    "livsmedelsförsörjningarna": "livsmedelsförsörjning",
    "livsmedelsförsörjningarnas": "livsmedelsförsörjning",
    "livsmedelsförsörjningars": "livsmedelsförsörjning",
    "livsmedelsförsörjningen": "livsmedelsförsörjning",
    "livsmedelsförsörjningens": "livsmedelsförsörjning",
    "livsmedelsförsörjnings": "livsmedelsförsörjning",
    "livsmedelskedjan": "livsmedelskedja",
    "livsmedelskedjans": "livsmedelskedja",
    "livsmedelskedjas": "livsmedelskedja",
    "livsmedelskedje": "livsmedelskedja",
    "livsmedelskedjor": "livsmedelskedja",
    "livsmedelskedjorna": "livsmedelskedja",
    "livsmedelskedjornas": "livsmedelskedja",
    "livsmedelskedjors": "livsmedelskedja",
    "livsmedelskemien": "livsmedelskemi",
    "livsmedelskemiens": "livsmedelskemi",
    "livsmedelskemin": "livsmedelskemi",
    "livsmedelskemins": "livsmedelskemi",
    "livsmedelskemis": "livsmedelskemi",
    "livsmedelskontrollen": "livsmedelskontroll",
    "livsmedelskontrollens": "livsmedelskontroll",
    "livsmedelskontroller": "livsmedelskontroll",
    "livsmedelskontrollerna": "livsmedelskontroll",
    "livsmedelskontrollernas": "livsmedelskontroll",
    "livsmedelskontrollers": "livsmedelskontroll",
    "livsmedelskontrolls": "livsmedelskontroll",
    "livsmedelslagar": "livsmedelslag",
    "livsmedelslagarna": "livsmedelslag",
    "livsmedelslagarnas": "livsmedelslag",
    "livsmedelslagars": "livsmedelslag",
    "livsmedelslagen": "livsmedelslag",
    "livsmedelslagens": "livsmedelslag",
    "livsmedelslags": "livsmedelslag",
    "livsmedelstillsatsen": "livsmedelstillsats",
    "livsmedelstillsatsens": "livsmedelstillsats",
    "livsmedelstillsatser": "livsmedelstillsats",
    "livsmedelstillsatserna": "livsmedelstillsats",
    "livsmedelstillsatsernas": "livsmedelstillsats",
    "livsmedelstillsatsers": "livsmedelstillsats",
    "livsmedlen": "livsmedel",
    "livsmedlens": "livsmedel",
    "livsmedlet": "livsmedel",
    "livsmedlets": "livsmedel",
    "livsmiljöer": "livsmiljö",
    "livsmiljöerna": "livsmiljö",
    "livsmiljöernas": "livsmiljö",
    "livsmiljöers": "livsmiljö",
    "livsmiljön": "livsmiljö",
    "livsmiljöns": "livsmiljö",
    "livsmiljös": "livsmiljö",
    "livsmodet": "livsmod",
    "livsmodets": "livsmod",
    "livsmods": "livsmod",
    "livsnaturen": "livsnatur",
    "livsnaturens": "livsnatur",
    "livsnaturer": "livsnatur",
    "livsnaturerna": "livsnatur",
    "livsnaturernas": "livsnatur",
    "livsnaturers": "livsnatur",
    "livsnaturs": "livsnatur",
    "livsnerven": "livsnerv",
    "livsnervens": "livsnerv",
    "livsnerver": "livsnerv",
    "livsnerverna": "livsnerv",
    "livsnervernas": "livsnerv",
    "livsnervers": "livsnerv",
    "livsnervs": "livsnerv",
    "livsnödvändiga": "livsnödvändig",
    "livsnödvändigare": "livsnödvändig",
    "livsnödvändigares": "livsnödvändig",
    "livsnödvändigas": "livsnödvändig",
    "livsnödvändigast": "livsnödvändig",
    "livsnödvändigaste": "livsnödvändig",
    "livsnödvändigastes": "livsnödvändig",
    "livsnödvändigasts": "livsnödvändig",
    "livsnödvändige": "livsnödvändig",
    "livsnödvändiges": "livsnödvändig",
    "livsnödvändigheten": "livsnödvändighet",
    "livsnödvändighetens": "livsnödvändighet",
    "livsnödvändighets": "livsnödvändighet",
    "livsnödvändigs": "livsnödvändig",
    "livsnödvändigt": "livsnödvändig",
    "livsnödvändigts": "livsnödvändig",
    "livsproblemen": "livsproblem",
    "livsproblemens": "livsproblem",
    "livsproblemet": "livsproblem",
    "livsproblemets": "livsproblem",
    "livsproblems": "livsproblem",
    "livsprocessen": "livsprocess",
    "livsprocessens": "livsprocess",
    "livsprocesser": "livsprocess",
    "livsprocesserna": "livsprocess",
    "livsprocessernas": "livsprocess",
    "livsprocessers": "livsprocess",
    "livspussels": "livspussel",
    "livspusslen": "livspussel",
    "livspusslens": "livspussel",
    "livspusslet": "livspussel",
    "livspusslets": "livspussel",
    "livsreaktionen": "livsreaktion",
    "livsreaktionens": "livsreaktion",
    "livsreaktioner": "livsreaktion",
    "livsreaktionerna": "livsreaktion",
    "livsreaktionernas": "livsreaktion",
    "livsreaktioners": "livsreaktion",
    "livsreaktions": "livsreaktion",
    "livsrummet": "livsrum",
    "livsrummets": "livsrum",
    "livsrums": "livsrum",
    "livssituationen": "livssituation",
    "livssituationens": "livssituation",
    "livssituationer": "livssituation",
    "livssituationerna": "livssituation",
    "livssituationernas": "livssituation",
    "livssituationers": "livssituation",
    "livssituations": "livssituation",
    "livssluten": "livsslut",
    "livsslutens": "livsslut",
    "livsslutet": "livsslut",
    "livsslutets": "livsslut",
    "livssluts": "livsslut",
    "livsstilar": "livsstil",
    "livsstilarna": "livsstil",
    "livsstilarnas": "livsstil",
    "livsstilars": "livsstil",
    "livsstilen": "livsstil",
    "livsstilens": "livsstil",
    "livsstils": "livsstil",
    "livsstilsfaktorer": "livsstilsfaktor",
    "livsstilsfaktorerna": "livsstilsfaktor",
    "livsstilsfaktorernas": "livsstilsfaktor",
    "livsstilsfaktorers": "livsstilsfaktor",
    "livsstilsfaktorn": "livsstilsfaktor",
    "livsstilsfaktorns": "livsstilsfaktor",
    "livsstilsfaktors": "livsstilsfaktor",
    "livsstilsförändringar": "livsstilsförändring",
    "livsstilsförändringarna": "livsstilsförändring",
    "livsstilsförändringarnas": "livsstilsförändring",
    "livsstilsförändringars": "livsstilsförändring",
    "livsstilsförändringen": "livsstilsförändring",
    "livsstilsförändringens": "livsstilsförändring",
    "livsstilsförändrings": "livsstilsförändring",
    "livsstilsoasen": "livsstilsoas",
    "livsstilsoasens": "livsstilsoas",
    "livsstilsoaser": "livsstilsoas",
    "livsstilsoaserna": "livsstilsoas",
    "livsstilsoasernas": "livsstilsoas",
    "livsstilsoasers": "livsstilsoas",
    "livssynen": "livssyn",
    "livssynens": "livssyn",
    "livssyner": "livssyn",
    "livssynerna": "livssyn",
    "livssynernas": "livssyn",
    "livssyners": "livssyn",
    "livssyns": "livssyn",
    "livsteckens": "livstecken",
    "livstecknen": "livstecken",
    "livstecknens": "livstecken",
    "livstecknet": "livstecken",
    "livstecknets": "livstecken",
    "livstiden": "livstid",
    "livstidens": "livstid",
    "livstids": "livstid",
    "livstidsdomar": "livstidsdom",
    "livstidsdomarna": "livstidsdom",
    "livstidsdomarnas": "livstidsdom",
    "livstidsdomars": "livstidsdom",
    "livstidsdomen": "livstidsdom",
    "livstidsdomens": "livstidsdom",
    "livstidsdoms": "livstidsdom",
    "livstidsdömde": "livstidsdömd",
    "livstidsdömdes": "livstidsdömd",
    "livstidsdömds": "livstidsdömd",
    "livstidsdömt": "livstidsdömd",
    "livstidsdömts": "livstidsdömd",
    "livstidsfångar": "livstidsfånge",
    "livstidsfångarna": "livstidsfånge",
    "livstidsfångarnas": "livstidsfånge",
    "livstidsfångars": "livstidsfånge",
    "livstidsfången": "livstidsfånge",
    "livstidsfångens": "livstidsfånge",
    "livstidsfånges": "livstidsfånge",
    "livstidsstraffen": "livstidsstraff",
    "livstidsstraffens": "livstidsstraff",
    "livstidsstraffet": "livstidsstraff",
    "livstidsstraffets": "livstidsstraff",
    "livstidsstraffs": "livstidsstraff",
    "livstron": "livstro",
    "livstrons": "livstro",
    "livstros": "livstro",
    "livsträden": "livsträd",
    "livsträdens": "livsträd",
    "livsträdet": "livsträd",
    "livsträdets": "livsträd",
    "livsträds": "livsträd",
    "livstycken": "livstycke",
    "livstyckena": "livstycke",
    "livstyckenas": "livstycke",
    "livstyckens": "livstycke",
    "livstyckes": "livstycke",
    "livstycket": "livstycke",
    "livstyckets": "livstycke",
    "livstycks": "livstycke",
    "livsuppehälles": "livsuppehälle",
    "livsuppehället": "livsuppehälle",
    "livsuppehällets": "livsuppehälle",
    "livsuppgiften": "livsuppgift",
    "livsuppgiftens": "livsuppgift",
    "livsuppgifter": "livsuppgift",
    "livsuppgifterna": "livsuppgift",
    "livsuppgifternas": "livsuppgift",
    "livsuppgifters": "livsuppgift",
    "livsuppgifts": "livsuppgift",
    "livsutvecklingar": "livsutveckling",
    "livsutvecklingarna": "livsutveckling",
    "livsutvecklingarnas": "livsutveckling",
    "livsutvecklingars": "livsutveckling",
    "livsutvecklingen": "livsutveckling",
    "livsutvecklingens": "livsutveckling",
    "livsutvecklings": "livsutveckling",
    "livsverken": "livsverk",
    "livsverkens": "livsverk",
    "livsverket": "livsverk",
    "livsverkets": "livsverk",
    "livsverks": "livsverk",
    "livsviktiga": "livsviktig",
    "livsviktigare": "livsviktig",
    "livsviktigares": "livsviktig",
    "livsviktigas": "livsviktig",
    "livsviktigast": "livsviktig",
    "livsviktigaste": "livsviktig",
    "livsviktigastes": "livsviktig",
    "livsviktigasts": "livsviktig",
    "livsviktige": "livsviktig",
    "livsviktiges": "livsviktig",
    "livsviktigheten": "livsviktighet",
    "livsviktighetens": "livsviktighet",
    "livsviktighets": "livsviktighet",
    "livsviktigs": "livsviktig",
    "livsviktigt": "livsviktig",
    "livsviktigts": "livsviktig",
    "livsviljan": "livsvilja",
    "livsviljans": "livsvilja",
    "livsviljas": "livsvilja",
    "livsvillkoren": "livsvillkor",
    "livsvillkorens": "livsvillkor",
    "livsvillkoret": "livsvillkor",
    "livsvillkorets": "livsvillkor",
    "livsvillkors": "livsvillkor",
    "livsvänliga": "livsvänlig",
    "livsvänligare": "livsvänlig",
    "livsvänligares": "livsvänlig",
    "livsvänligas": "livsvänlig",
    "livsvänligast": "livsvänlig",
    "livsvänligaste": "livsvänlig",
    "livsvänligastes": "livsvänlig",
    "livsvänligasts": "livsvänlig",
    "livsvänlige": "livsvänlig",
    "livsvänliges": "livsvänlig",
    "livsvänligheten": "livsvänlighet",
    "livsvänlighetens": "livsvänlighet",
    "livsvänlighets": "livsvänlighet",
    "livsvänligs": "livsvänlig",
    "livsvänligt": "livsvänlig",
    "livsvänligts": "livsvänlig",
    "livsyttringar": "livsyttring",
    "livsyttringarna": "livsyttring",
    "livsyttringarnas": "livsyttring",
    "livsyttringars": "livsyttring",
    "livsyttringen": "livsyttring",
    "livsyttringens": "livsyttring",
    "livsyttrings": "livsyttring",
    "livsåskådningar": "livsåskådning",
    "livsåskådningarna": "livsåskådning",
    "livsåskådningarnas": "livsåskådning",
    "livsåskådningars": "livsåskådning",
    "livsåskådningen": "livsåskådning",
    "livsåskådningens": "livsåskådning",
    "livsåskådnings": "livsåskådning",
    "livsåskådningsmässiga": "livsåskådningsmässig",
    "livsåskådningsmässigare": "livsåskådningsmässig",
    "livsåskådningsmässigares": "livsåskådningsmässig",
    "livsåskådningsmässigas": "livsåskådningsmässig",
    "livsåskådningsmässigast": "livsåskådningsmässig",
    "livsåskådningsmässigaste": "livsåskådningsmässig",
    "livsåskådningsmässigastes": "livsåskådningsmässig",
    "livsåskådningsmässigasts": "livsåskådningsmässig",
    "livsåskådningsmässige": "livsåskådningsmässig",
    "livsåskådningsmässiges": "livsåskådningsmässig",
    "livsåskådningsmässigs": "livsåskådningsmässig",
    "livsåskådningsmässigt": "livsåskådningsmässig",
    "livsåskådningsmässigts": "livsåskådningsmässig",
    "livtagen": "livtag",
    "livtagens": "livtag",
    "livtaget": "livtag",
    "livtagets": "livtag",
    "livtags": "livtag",
    "livvakten": "livvakt",
    "livvaktens": "livvakt",
    "livvakter": "livvakt",
    "livvakterna": "livvakt",
    "livvakternas": "livvakt",
    "livvakters": "livvakt",
    "livvakts": "livvakt",
    "lixen": "lix",
    "lixens": "lix",
    "lixet": "lix",
    "lixets": "lix",
    "ljud": "ljuda",
    "ljudad": "ljuda",
    "ljudade": "ljuda",
    "ljudades": "ljuda",
    "ljudads": "ljuda",
    "ljudande": "ljuda",
    "ljudanden": "ljudande",
    "ljudandena": "ljudande",
    "ljudandenas": "ljudande",
    "ljudandens": "ljudande",
    "ljudandes": "ljudande",
    "ljudandet": "ljudande",
    "ljudandets": "ljudande",
    "ljudar": "ljuda",
    "ljudas": "ljuda",
    "ljudat": "ljuda",
    "ljudats": "ljuda",
    "ljudbanden": "ljudband",
    "ljudbandens": "ljudband",
    "ljudbandet": "ljudband",
    "ljudbandets": "ljudband",
    "ljudbands": "ljudband",
    "ljudbangar": "ljudbang",
    "ljudbangarna": "ljudbang",
    "ljudbangarnas": "ljudbang",
    "ljudbangars": "ljudbang",
    "ljudbangen": "ljudbang",
    "ljudbangens": "ljudbang",
    "ljudbangs": "ljudbang",
    "ljudbildbanden": "ljudbildband",
    "ljudbildbandens": "ljudbildband",
    "ljudbildbandet": "ljudbildband",
    "ljudbildbandets": "ljudbildband",
    "ljudbildbands": "ljudbildband",
    "ljudbilden": "ljudbild",
    "ljudbildens": "ljudbild",
    "ljudbilder": "ljudbild",
    "ljudbilderna": "ljudbild",
    "ljudbildernas": "ljudbild",
    "ljudbilders": "ljudbild",
    "ljudbilds": "ljudbild",
    "ljudbojar": "ljudboj",
    "ljudbojarna": "ljudboj",
    "ljudbojarnas": "ljudboj",
    "ljudbojars": "ljudboj",
    "ljudbojen": "ljudboj",
    "ljudbojens": "ljudboj",
    "ljudbojs": "ljudboj",
    "ljudboken": "ljudbok",
    "ljudbokens": "ljudbok",
    "ljudboks": "ljudbok",
    "ljudbreven": "ljudbrev",
    "ljudbrevens": "ljudbrev",
    "ljudbrevet": "ljudbrev",
    "ljudbrevets": "ljudbrev",
    "ljudbrevs": "ljudbrev",
    "ljudböcker": "ljudbok",
    "ljudböckerna": "ljudbok",
    "ljudböckernas": "ljudbok",
    "ljudböckers": "ljudbok",
    "ljuddämpar": "ljuddämpare",
    "ljuddämparen": "ljuddämpare",
    "ljuddämparens": "ljuddämpare",
    "ljuddämpares": "ljuddämpare",
    "ljuddämparna": "ljuddämpare",
    "ljuddämparnas": "ljuddämpare",
    "ljuddämpningar": "ljuddämpning",
    "ljuddämpningarna": "ljuddämpning",
    "ljuddämpningarnas": "ljuddämpning",
    "ljuddämpningars": "ljuddämpning",
    "ljuddämpningen": "ljuddämpning",
    "ljuddämpningens": "ljuddämpning",
    "ljuddämpnings": "ljuddämpning",
    "ljude": "ljuda",
    "ljuden": "ljud",
    "ljudenliga": "ljudenlig",
    "ljudenligare": "ljudenlig",
    "ljudenligares": "ljudenlig",
    "ljudenligas": "ljudenlig",
    "ljudenligast": "ljudenlig",
    "ljudenligaste": "ljudenlig",
    "ljudenligastes": "ljudenlig",
    "ljudenligasts": "ljudenlig",
    "ljudenlige": "ljudenlig",
    "ljudenliges": "ljudenlig",
    "ljudenligheten": "ljudenlighet",
    "ljudenlighetens": "ljudenlighet",
    "ljudenlighets": "ljudenlighet",
    "ljudenligs": "ljudenlig",
    "ljudenligt": "ljudenlig",
    "ljudenligts": "ljudenlig",
    "ljudens": "ljud",
    "ljuder": "ljuda",
    "ljudes": "ljuda",
    "ljudet": "ljud",
    "ljudets": "ljud",
    "ljudfilmen": "ljudfilm",
    "ljudfilmens": "ljudfilm",
    "ljudfilmer": "ljudfilm",
    "ljudfilmerna": "ljudfilm",
    "ljudfilmernas": "ljudfilm",
    "ljudfilmers": "ljudfilm",
    "ljudfilms": "ljudfilm",
    "ljudfrekvensen": "ljudfrekvens",
    "ljudfrekvensens": "ljudfrekvens",
    "ljudfrekvenser": "ljudfrekvens",
    "ljudfrekvenserna": "ljudfrekvens",
    "ljudfrekvensernas": "ljudfrekvens",
    "ljudfrekvensers": "ljudfrekvens",
    "ljudförbindelsen": "ljudförbindelse",
    "ljudförbindelsens": "ljudförbindelse",
    "ljudförbindelser": "ljudförbindelse",
    "ljudförbindelserna": "ljudförbindelse",
    "ljudförbindelsernas": "ljudförbindelse",
    "ljudförbindelsers": "ljudförbindelse",
    "ljudförbindelses": "ljudförbindelse",
    "ljudförändringar": "ljudförändring",
    "ljudförändringarna": "ljudförändring",
    "ljudförändringarnas": "ljudförändring",
    "ljudförändringars": "ljudförändring",
    "ljudförändringen": "ljudförändring",
    "ljudförändringens": "ljudförändring",
    "ljudförändrings": "ljudförändring",
    "ljudhastigheten": "ljudhastighet",
    "ljudhastighetens": "ljudhastighet",
    "ljudhastigheter": "ljudhastighet",
    "ljudhastigheterna": "ljudhastighet",
    "ljudhastigheternas": "ljudhastighet",
    "ljudhastigheters": "ljudhastighet",
    "ljudhastighets": "ljudhastighet",
    "ljudhålen": "ljudhål",
    "ljudhålens": "ljudhål",
    "ljudhålet": "ljudhål",
    "ljudhålets": "ljudhål",
    "ljudhåls": "ljudhål",
    "ljudinspelar": "ljudinspelare",
    "ljudinspelaren": "ljudinspelare",
    "ljudinspelarens": "ljudinspelare",
    "ljudinspelares": "ljudinspelare",
    "ljudinspelarna": "ljudinspelare",
    "ljudinspelarnas": "ljudinspelare",
    "ljudinspelningar": "ljudinspelning",
    "ljudinspelningarna": "ljudinspelning",
    "ljudinspelningarnas": "ljudinspelning",
    "ljudinspelningars": "ljudinspelning",
    "ljudinspelningen": "ljudinspelning",
    "ljudinspelningens": "ljudinspelning",
    "ljudinspelnings": "ljudinspelning",
    "ljudisolerad": "ljudisolera",
    "ljudisolerade": "ljudisolera",
    "ljudisolerades": "ljudisolera",
    "ljudisolerads": "ljudisolera",
    "ljudisolerande": "ljudisolera",
    "ljudisoleranden": "ljudisolerande",
    "ljudisolerandena": "ljudisolerande",
    "ljudisolerandenas": "ljudisolerande",
    "ljudisolerandens": "ljudisolerande",
    "ljudisolerandes": "ljudisolerande",
    "ljudisolerandet": "ljudisolerande",
    "ljudisolerandets": "ljudisolerande",
    "ljudisolerar": "ljudisolera",
    "ljudisoleras": "ljudisolera",
    "ljudisolerat": "ljudisolera",
    "ljudisolerats": "ljudisolera",
    "ljudisolerbara": "ljudisolerbar",
    "ljudisolerbarare": "ljudisolerbar",
    "ljudisolerbarares": "ljudisolerbar",
    "ljudisolerbaras": "ljudisolerbar",
    "ljudisolerbarast": "ljudisolerbar",
    "ljudisolerbaraste": "ljudisolerbar",
    "ljudisolerbarastes": "ljudisolerbar",
    "ljudisolerbarasts": "ljudisolerbar",
    "ljudisolerbare": "ljudisolerbar",
    "ljudisolerbares": "ljudisolerbar",
    "ljudisolerbarheten": "ljudisolerbarhet",
    "ljudisolerbarhetens": "ljudisolerbarhet",
    "ljudisolerbarhets": "ljudisolerbarhet",
    "ljudisolerbars": "ljudisolerbar",
    "ljudisolerbart": "ljudisolerbar",
    "ljudisolerbarts": "ljudisolerbar",
    "ljudisoleringar": "ljudisolering",
    "ljudisoleringarna": "ljudisolering",
    "ljudisoleringarnas": "ljudisolering",
    "ljudisoleringars": "ljudisolering",
    "ljudisoleringen": "ljudisolering",
    "ljudisoleringens": "ljudisolering",
    "ljudisolerings": "ljudisolering",
    "ljudit": "ljuda",
    "ljudits": "ljuda",
    "ljudkulissen": "ljudkuliss",
    "ljudkulissens": "ljudkuliss",
    "ljudkulisser": "ljudkuliss",
    "ljudkulisserna": "ljudkuliss",
    "ljudkulissernas": "ljudkuliss",
    "ljudkulissers": "ljudkuliss",
    "ljudkvaliteten": "ljudkvalitet",
    "ljudkvalitetens": "ljudkvalitet",
    "ljudkvaliteter": "ljudkvalitet",
    "ljudkvaliteterna": "ljudkvalitet",
    "ljudkvaliteternas": "ljudkvalitet",
    "ljudkvaliteters": "ljudkvalitet",
    "ljudkvalitets": "ljudkvalitet",
    "ljudkäll": "ljudkälla",
    "ljudkällan": "ljudkälla",
    "ljudkällans": "ljudkälla",
    "ljudkällas": "ljudkälla",
    "ljudkälle": "ljudkälla",
    "ljudkällor": "ljudkälla",
    "ljudkällorna": "ljudkälla",
    "ljudkällornas": "ljudkälla",
    "ljudkällors": "ljudkälla",
    "ljudkälls": "ljudkälla",
    "ljudlagar": "ljudlag",
    "ljudlagarna": "ljudlag",
    "ljudlagarnas": "ljudlag",
    "ljudlagars": "ljudlag",
    "ljudlagen": "ljudlag",
    "ljudlagens": "ljudlag",
    "ljudlags": "ljudlag",
    "ljudliga": "ljudlig",
    "ljudligare": "ljudlig",
    "ljudligares": "ljudlig",
    "ljudligas": "ljudlig",
    "ljudligast": "ljudlig",
    "ljudligaste": "ljudlig",
    "ljudligastes": "ljudlig",
    "ljudligasts": "ljudlig",
    "ljudlige": "ljudlig",
    "ljudliges": "ljudlig",
    "ljudligheten": "ljudlighet",
    "ljudlighetens": "ljudlighet",
    "ljudlighets": "ljudlighet",
    "ljudligs": "ljudlig",
    "ljudligt": "ljudlig",
    "ljudligts": "ljudlig",
    "ljudläran": "ljudlära",
    "ljudlärans": "ljudlära",
    "ljudläras": "ljudlära",
    "ljudläre": "ljudlära",
    "ljudläro": "ljudlära",
    "ljudläror": "ljudlära",
    "ljudlärorna": "ljudlära",
    "ljudlärornas": "ljudlära",
    "ljudlärors": "ljudlära",
    "ljudlösa": "ljudlös",
    "ljudlösare": "ljudlös",
    "ljudlösares": "ljudlös",
    "ljudlösas": "ljudlös",
    "ljudlösast": "ljudlös",
    "ljudlösaste": "ljudlös",
    "ljudlösastes": "ljudlös",
    "ljudlösasts": "ljudlös",
    "ljudlöse": "ljudlös",
    "ljudlöses": "ljudlös",
    "ljudlösheten": "ljudlöshet",
    "ljudlöshetens": "ljudlöshet",
    "ljudlöshets": "ljudlöshet",
    "ljudlöst": "ljudlös",
    "ljudlösts": "ljudlös",
    "ljudmässiga": "ljudmässig",
    "ljudmässigare": "ljudmässig",
    "ljudmässigares": "ljudmässig",
    "ljudmässigas": "ljudmässig",
    "ljudmässigast": "ljudmässig",
    "ljudmässigaste": "ljudmässig",
    "ljudmässigastes": "ljudmässig",
    "ljudmässigasts": "ljudmässig",
    "ljudmässige": "ljudmässig",
    "ljudmässiges": "ljudmässig",
    "ljudmässigs": "ljudmässig",
    "ljudmässigt": "ljudmässig",
    "ljudmässigts": "ljudmässig",
    "ljudnivåer": "ljudnivå",
    "ljudnivåerna": "ljudnivå",
    "ljudnivåernas": "ljudnivå",
    "ljudnivåers": "ljudnivå",
    "ljudnivån": "ljudnivå",
    "ljudnivåns": "ljudnivå",
    "ljudnivås": "ljudnivå",
    "ljudradion": "ljudradio",
    "ljudradions": "ljudradio",
    "ljudradios": "ljudradio",
    "ljudresultaten": "ljudresultat",
    "ljudresultatens": "ljudresultat",
    "ljudresultatet": "ljudresultat",
    "ljudresultatets": "ljudresultat",
    "ljudresultats": "ljudresultat",
    "ljuds": "ljuda",
    "ljudsatt": "ljudsätta",
    "ljudsatta": "ljudsätta",
    "ljudsattas": "ljudsätta",
    "ljudsatte": "ljudsätta",
    "ljudsattes": "ljudsätta",
    "ljudsatts": "ljudsätta",
    "ljudsignalen": "ljudsignal",
    "ljudsignalens": "ljudsignal",
    "ljudsignaler": "ljudsignal",
    "ljudsignalerna": "ljudsignal",
    "ljudsignalernas": "ljudsignal",
    "ljudsignalers": "ljudsignal",
    "ljudsignals": "ljudsignal",
    "ljudskridningar": "ljudskridning",
    "ljudskridningarna": "ljudskridning",
    "ljudskridningarnas": "ljudskridning",
    "ljudskridningars": "ljudskridning",
    "ljudskridningen": "ljudskridning",
    "ljudskridningens": "ljudskridning",
    "ljudskridnings": "ljudskridning",
    "ljudskriften": "ljudskrift",
    "ljudskriftens": "ljudskrift",
    "ljudskrifter": "ljudskrift",
    "ljudskrifterna": "ljudskrift",
    "ljudskrifternas": "ljudskrift",
    "ljudskrifters": "ljudskrift",
    "ljudskrifts": "ljudskrift",
    "ljudspring": "ljudspringa",
    "ljudspringan": "ljudspringa",
    "ljudspringans": "ljudspringa",
    "ljudspringas": "ljudspringa",
    "ljudspringe": "ljudspringa",
    "ljudspringor": "ljudspringa",
    "ljudspringorna": "ljudspringa",
    "ljudspringornas": "ljudspringa",
    "ljudspringors": "ljudspringa",
    "ljudsprings": "ljudspringa",
    "ljudstyrkan": "ljudstyrka",
    "ljudstyrkans": "ljudstyrka",
    "ljudstyrkas": "ljudstyrka",
    "ljudstyrke": "ljudstyrka",
    "ljudstyrkor": "ljudstyrka",
    "ljudstyrkorna": "ljudstyrka",
    "ljudstyrkornas": "ljudstyrka",
    "ljudstyrkors": "ljudstyrka",
    "ljudsymboliken": "ljudsymbolik",
    "ljudsymbolikens": "ljudsymbolik",
    "ljudsymboliks": "ljudsymbolik",
    "ljudsystemen": "ljudsystem",
    "ljudsystemens": "ljudsystem",
    "ljudsystemet": "ljudsystem",
    "ljudsystemets": "ljudsystem",
    "ljudsystems": "ljudsystem",
    "ljudsätt": "ljudsätta",
    "ljudsättande": "ljudsätta",
    "ljudsättanden": "ljudsättande",
    "ljudsättandena": "ljudsättande",
    "ljudsättandenas": "ljudsättande",
    "ljudsättandens": "ljudsättande",
    "ljudsättandes": "ljudsättande",
    "ljudsättandet": "ljudsättande",
    "ljudsättandets": "ljudsättande",
    "ljudsättas": "ljudsätta",
    "ljudsätter": "ljudsätta",
    "ljudsättes": "ljudsätta",
    "ljudsätts": "ljudsätta",
    "ljudteknikern": "ljudtekniker",
    "ljudteknikerna": "ljudtekniker",
    "ljudteknikernas": "ljudtekniker",
    "ljudteknikerns": "ljudtekniker",
    "ljudteknikers": "ljudtekniker",
    "ljudupptagningar": "ljudupptagning",
    "ljudupptagningarna": "ljudupptagning",
    "ljudupptagningarnas": "ljudupptagning",
    "ljudupptagningars": "ljudupptagning",
    "ljudupptagningen": "ljudupptagning",
    "ljudupptagningens": "ljudupptagning",
    "ljudupptagnings": "ljudupptagning",
    "ljudvallar": "ljudvall",
    "ljudvallarna": "ljudvall",
    "ljudvallarnas": "ljudvall",
    "ljudvallars": "ljudvall",
    "ljudvallen": "ljudvall",
    "ljudvallens": "ljudvall",
    "ljudvalls": "ljudvall",
    "ljudvågen": "ljudvåg",
    "ljudvågens": "ljudvåg",
    "ljudvågor": "ljudvåg",
    "ljudvågorna": "ljudvåg",
    "ljudvågornas": "ljudvåg",
    "ljudvågors": "ljudvåg",
    "ljudvågs": "ljudvåg",
    "ljudåtergivningar": "ljudåtergivning",
    "ljudåtergivningarna": "ljudåtergivning",
    "ljudåtergivningarnas": "ljudåtergivning",
    "ljudåtergivningars": "ljudåtergivning",
    "ljudåtergivningen": "ljudåtergivning",
    "ljudåtergivningens": "ljudåtergivning",
    "ljudåtergivnings": "ljudåtergivning",
    "ljudöverföringar": "ljudöverföring",
    "ljudöverföringarna": "ljudöverföring",
    "ljudöverföringarnas": "ljudöverföring",
    "ljudöverföringars": "ljudöverföring",
    "ljudöverföringen": "ljudöverföring",
    "ljudöverföringens": "ljudöverföring",
    "ljudöverförings": "ljudöverföring",
    "ljug": "ljuga",
    "ljugande": "ljuga",
    "ljuganden": "ljugande",
    "ljugandena": "ljugande",
    "ljugandenas": "ljugande",
    "ljugandens": "ljugande",
    "ljugandes": "ljugande",
    "ljugandet": "ljugande",
    "ljugandets": "ljugande",
    "ljugarbänkar": "ljugarbänk",
    "ljugarbänkarna": "ljugarbänk",
    "ljugarbänkarnas": "ljugarbänk",
    "ljugarbänkars": "ljugarbänk",
    "ljugarbänken": "ljugarbänk",
    "ljugarbänkens": "ljugarbänk",
    "ljugarbänks": "ljugarbänk",
    "ljugas": "ljuga",
    "ljuge": "ljuga",
    "ljugen": "ljuga",
    "ljugens": "ljuga",
    "ljuger": "ljuga",
    "ljuges": "ljuga",
    "ljuget": "ljuga",
    "ljugets": "ljuga",
    "ljugit": "ljuga",
    "ljugits": "ljuga",
    "ljugna": "ljuga",
    "ljugnas": "ljuga",
    "ljugne": "ljuga",
    "ljugnes": "ljuga",
    "ljugs": "ljuga",
    "ljumheten": "ljumhet",
    "ljumhetens": "ljumhet",
    "ljumheter": "ljumhet",
    "ljumheterna": "ljumhet",
    "ljumheternas": "ljumhet",
    "ljumheters": "ljumhet",
    "ljumhets": "ljumhet",
    "ljumma": "ljum",
    "ljummade": "ljumma",
    "ljummades": "ljumma",
    "ljummande": "ljumma",
    "ljummanden": "ljummande",
    "ljummandena": "ljummande",
    "ljummandenas": "ljummande",
    "ljummandens": "ljummande",
    "ljummandes": "ljummande",
    "ljummandet": "ljummande",
    "ljummandets": "ljummande",
    "ljummar": "ljumma",
    "ljummare": "ljum",
    "ljummares": "ljum",
    "ljummas": "ljumma",
    "ljummast": "ljum",
    "ljummaste": "ljum",
    "ljummastes": "ljum",
    "ljummasts": "ljum",
    "ljummat": "ljumma",
    "ljummats": "ljumma",
    "ljumme": "ljum",
    "ljummenheten": "ljummenhet",
    "ljummenhetens": "ljummenhet",
    "ljummenhets": "ljummenhet",
    "ljummens": "ljummen",
    "ljummes": "ljum",
    "ljummet": "ljummen",
    "ljummets": "ljummen",
    "ljumna": "ljummen",
    "ljumnare": "ljummen",
    "ljumnares": "ljummen",
    "ljumnas": "ljummen",
    "ljumnast": "ljummen",
    "ljumnaste": "ljummen",
    "ljumnastes": "ljummen",
    "ljumnasts": "ljummen",
    "ljumne": "ljummen",
    "ljumnes": "ljummen",
    "ljums": "ljum",
    "ljumsk": "ljumske",
    "ljumskar": "ljumske",
    "ljumskarna": "ljumske",
    "ljumskarnas": "ljumske",
    "ljumskars": "ljumske",
    "ljumskbråcken": "ljumskbråck",
    "ljumskbråckens": "ljumskbråck",
    "ljumskbråcket": "ljumskbråck",
    "ljumskbråckets": "ljumskbråck",
    "ljumskbråcks": "ljumskbråck",
    "ljumsken": "ljumske",
    "ljumskens": "ljumske",
    "ljumskes": "ljumske",
    "ljumsktrakten": "ljumsktrakt",
    "ljumsktraktens": "ljumsktrakt",
    "ljumsktrakter": "ljumsktrakt",
    "ljumsktrakterna": "ljumsktrakt",
    "ljumsktrakternas": "ljumsktrakt",
    "ljumsktrakters": "ljumsktrakt",
    "ljumsktrakts": "ljumsktrakt",
    "ljumt": "ljum",
    "ljumts": "ljum",
    "ljung": "ljunga",
    "ljungade": "ljunga",
    "ljungades": "ljunga",
    "ljungande": "ljunga",
    "ljunganden": "ljungande",
    "ljungandena": "ljungande",
    "ljungandenas": "ljungande",
    "ljungandens": "ljungande",
    "ljungandes": "ljungande",
    "ljungandet": "ljungande",
    "ljungandets": "ljungande",
    "ljungar": "ljunga",
    "ljungas": "ljunga",
    "ljungat": "ljunga",
    "ljungats": "ljunga",
    "ljungeldar": "ljungeld",
    "ljungeldarna": "ljungeld",
    "ljungeldarnas": "ljungeld",
    "ljungeldars": "ljungeld",
    "ljungelden": "ljungeld",
    "ljungeldens": "ljungeld",
    "ljungelds": "ljungeld",
    "ljungen": "ljung",
    "ljungens": "ljung",
    "ljungpipar": "ljungpipare",
    "ljungpiparen": "ljungpipare",
    "ljungpiparens": "ljungpipare",
    "ljungpipares": "ljungpipare",
    "ljungpiparna": "ljungpipare",
    "ljungpiparnas": "ljungpipare",
    "ljungväxten": "ljungväxt",
    "ljungväxtens": "ljungväxt",
    "ljungväxter": "ljungväxt",
    "ljungväxterna": "ljungväxt",
    "ljungväxternas": "ljungväxt",
    "ljungväxters": "ljungväxt",
    "ljungväxts": "ljungväxt",
    "ljusa": "ljus",
    "ljusalfen": "ljusalf",
    "ljusalfens": "ljusalf",
    "ljusalfer": "ljusalf",
    "ljusalferna": "ljusalf",
    "ljusalfernas": "ljusalf",
    "ljusalfers": "ljusalf",
    "ljusalfs": "ljusalf",
    "ljusalven": "ljusalv",
    "ljusalvens": "ljusalv",
    "ljusalver": "ljusalv",
    "ljusalverna": "ljusalv",
    "ljusalvernas": "ljusalv",
    "ljusalvers": "ljusalv",
    "ljusalvs": "ljusalv",
    "ljusare": "ljus",
    "ljusares": "ljus",
    "ljusas": "ljus",
    "ljusast": "ljus",
    "ljusaste": "ljus",
    "ljusastes": "ljus",
    "ljusasts": "ljus",
    "ljusbehandlingar": "ljusbehandling",
    "ljusbehandlingarna": "ljusbehandling",
    "ljusbehandlingarnas": "ljusbehandling",
    "ljusbehandlingars": "ljusbehandling",
    "ljusbehandlingen": "ljusbehandling",
    "ljusbehandlingens": "ljusbehandling",
    "ljusbehandlings": "ljusbehandling",
    "ljusbeständiga": "ljusbeständig",
    "ljusbeständigare": "ljusbeständig",
    "ljusbeständigares": "ljusbeständig",
    "ljusbeständigas": "ljusbeständig",
    "ljusbeständigast": "ljusbeständig",
    "ljusbeständigaste": "ljusbeständig",
    "ljusbeständigastes": "ljusbeständig",
    "ljusbeständigasts": "ljusbeständig",
    "ljusbeständige": "ljusbeständig",
    "ljusbeständiges": "ljusbeständig",
    "ljusbeständigheten": "ljusbeständighet",
    "ljusbeständighetens": "ljusbeständighet",
    "ljusbeständighets": "ljusbeständighet",
    "ljusbeständigs": "ljusbeständig",
    "ljusbeständigt": "ljusbeständig",
    "ljusbeständigts": "ljusbeständig",
    "ljusbilden": "ljusbild",
    "ljusbildens": "ljusbild",
    "ljusbilder": "ljusbild",
    "ljusbilderna": "ljusbild",
    "ljusbildernas": "ljusbild",
    "ljusbilders": "ljusbild",
    "ljusbilds": "ljusbild",
    "ljusblinda": "ljusblind",
    "ljusblindare": "ljusblind",
    "ljusblindares": "ljusblind",
    "ljusblindas": "ljusblind",
    "ljusblindast": "ljusblind",
    "ljusblindaste": "ljusblind",
    "ljusblindastes": "ljusblind",
    "ljusblindasts": "ljusblind",
    "ljusblinde": "ljusblind",
    "ljusblindes": "ljusblind",
    "ljusblindheten": "ljusblindhet",
    "ljusblindhetens": "ljusblindhet",
    "ljusblindhets": "ljusblindhet",
    "ljusblinds": "ljusblind",
    "ljusblint": "ljusblind",
    "ljusblints": "ljusblind",
    "ljusblixtar": "ljusblixt",
    "ljusblixtarna": "ljusblixt",
    "ljusblixtarnas": "ljusblixt",
    "ljusblixtars": "ljusblixt",
    "ljusblixten": "ljusblixt",
    "ljusblixtens": "ljusblixt",
    "ljusblixts": "ljusblixt",
    "ljusblåa": "ljusblå",
    "ljusblåare": "ljusblå",
    "ljusblåares": "ljusblå",
    "ljusblåas": "ljusblå",
    "ljusblåast": "ljusblå",
    "ljusblåaste": "ljusblå",
    "ljusblåastes": "ljusblå",
    "ljusblåasts": "ljusblå",
    "ljusblåe": "ljusblå",
    "ljusblåes": "ljusblå",
    "ljusblås": "ljusblå",
    "ljusblått": "ljusblå",
    "ljusblåtts": "ljusblå",
    "ljusbristen": "ljusbrist",
    "ljusbristens": "ljusbrist",
    "ljusbrists": "ljusbrist",
    "ljusbruna": "ljusbrun",
    "ljusbrunare": "ljusbrun",
    "ljusbrunares": "ljusbrun",
    "ljusbrunas": "ljusbrun",
    "ljusbrunast": "ljusbrun",
    "ljusbrunaste": "ljusbrun",
    "ljusbrunastes": "ljusbrun",
    "ljusbrunasts": "ljusbrun",
    "ljusbrune": "ljusbrun",
    "ljusbrunes": "ljusbrun",
    "ljusbrunnar": "ljusbrunn",
    "ljusbrunnarna": "ljusbrunn",
    "ljusbrunnarnas": "ljusbrunn",
    "ljusbrunnars": "ljusbrunn",
    "ljusbrunnen": "ljusbrunn",
    "ljusbrunnens": "ljusbrunn",
    "ljusbrunns": "ljusbrunn",
    "ljusbruns": "ljusbrun",
    "ljusbrunt": "ljusbrun",
    "ljusbrunts": "ljusbrun",
    "ljusbrytningar": "ljusbrytning",
    "ljusbrytningarna": "ljusbrytning",
    "ljusbrytningarnas": "ljusbrytning",
    "ljusbrytningars": "ljusbrytning",
    "ljusbrytningen": "ljusbrytning",
    "ljusbrytningens": "ljusbrytning",
    "ljusbrytnings": "ljusbrytning",
    "ljusbåg": "ljusbåge",
    "ljusbågar": "ljusbåge",
    "ljusbågarna": "ljusbåge",
    "ljusbågarnas": "ljusbåge",
    "ljusbågars": "ljusbåge",
    "ljusbågen": "ljusbåge",
    "ljusbågens": "ljusbåge",
    "ljusbåges": "ljusbåge",
    "ljusbågs": "ljusbåge",
    "ljusdunkels": "ljusdunkel",
    "ljusdunklet": "ljusdunkel",
    "ljusdunklets": "ljusdunkel",
    "ljuse": "ljus",
    "ljusen": "ljus",
    "ljusenergien": "ljusenergi",
    "ljusenergiens": "ljusenergi",
    "ljusenergin": "ljusenergi",
    "ljusenergins": "ljusenergi",
    "ljusenergis": "ljusenergi",
    "ljusens": "ljus",
    "ljuses": "ljus",
    "ljuset": "ljus",
    "ljusets": "ljus",
    "ljusfenomenen": "ljusfenomen",
    "ljusfenomenens": "ljusfenomen",
    "ljusfenomenet": "ljusfenomen",
    "ljusfenomenets": "ljusfenomen",
    "ljusfenomens": "ljusfenomen",
    "ljusfilterna": "ljusfilter",
    "ljusfilternas": "ljusfilter",
    "ljusfilters": "ljusfilter",
    "ljusfiltren": "ljusfilter",
    "ljusfiltrens": "ljusfilter",
    "ljusfiltret": "ljusfilter",
    "ljusfiltrets": "ljusfilter",
    "ljusfläckade": "ljusfläckad",
    "ljusfläckades": "ljusfläckad",
    "ljusfläckads": "ljusfläckad",
    "ljusfläckar": "ljusfläck",
    "ljusfläckarna": "ljusfläck",
    "ljusfläckarnas": "ljusfläck",
    "ljusfläckars": "ljusfläck",
    "ljusfläckat": "ljusfläckad",
    "ljusfläckats": "ljusfläckad",
    "ljusfläcken": "ljusfläck",
    "ljusfläckens": "ljusfläck",
    "ljusfläcks": "ljusfläck",
    "ljusflöden": "ljusflöde",
    "ljusflödena": "ljusflöde",
    "ljusflödenas": "ljusflöde",
    "ljusflödens": "ljusflöde",
    "ljusflödes": "ljusflöde",
    "ljusflödet": "ljusflöde",
    "ljusflödets": "ljusflöde",
    "ljusförhållanden": "ljusförhållande",
    "ljusförhållandena": "ljusförhållande",
    "ljusförhållandenas": "ljusförhållande",
    "ljusförhållandens": "ljusförhållande",
    "ljusförhållandes": "ljusförhållande",
    "ljusförhållandet": "ljusförhållande",
    "ljusförhållandets": "ljusförhållande",
    "ljusgestalten": "ljusgestalt",
    "ljusgestaltens": "ljusgestalt",
    "ljusgestalter": "ljusgestalt",
    "ljusgestalterna": "ljusgestalt",
    "ljusgestalternas": "ljusgestalt",
    "ljusgestalters": "ljusgestalt",
    "ljusgestalts": "ljusgestalt",
    "ljusglimtar": "ljusglimt",
    "ljusglimtarna": "ljusglimt",
    "ljusglimtarnas": "ljusglimt",
    "ljusglimtars": "ljusglimt",
    "ljusglimten": "ljusglimt",
    "ljusglimtens": "ljusglimt",
    "ljusglimts": "ljusglimt",
    "ljusgråa": "ljusgrå",
    "ljusgråare": "ljusgrå",
    "ljusgråares": "ljusgrå",
    "ljusgråas": "ljusgrå",
    "ljusgråast": "ljusgrå",
    "ljusgråaste": "ljusgrå",
    "ljusgråastes": "ljusgrå",
    "ljusgråasts": "ljusgrå",
    "ljusgråe": "ljusgrå",
    "ljusgråes": "ljusgrå",
    "ljusgrås": "ljusgrå",
    "ljusgrått": "ljusgrå",
    "ljusgråtts": "ljusgrå",
    "ljusgröna": "ljusgrön",
    "ljusgrönare": "ljusgrön",
    "ljusgrönares": "ljusgrön",
    "ljusgrönas": "ljusgrön",
    "ljusgrönast": "ljusgrön",
    "ljusgrönaste": "ljusgrön",
    "ljusgrönastes": "ljusgrön",
    "ljusgrönasts": "ljusgrön",
    "ljusgröne": "ljusgrön",
    "ljusgrönes": "ljusgrön",
    "ljusgröns": "ljusgrön",
    "ljusgrönt": "ljusgrön",
    "ljusgrönts": "ljusgrön",
    "ljusgula": "ljusgul",
    "ljusgulare": "ljusgul",
    "ljusgulares": "ljusgul",
    "ljusgulas": "ljusgul",
    "ljusgulast": "ljusgul",
    "ljusgulaste": "ljusgul",
    "ljusgulastes": "ljusgul",
    "ljusgulasts": "ljusgul",
    "ljusgule": "ljusgul",
    "ljusgules": "ljusgul",
    "ljusguls": "ljusgul",
    "ljusgult": "ljusgul",
    "ljusgults": "ljusgul",
    "ljusgårdar": "ljusgård",
    "ljusgårdarna": "ljusgård",
    "ljusgårdarnas": "ljusgård",
    "ljusgårdars": "ljusgård",
    "ljusgården": "ljusgård",
    "ljusgårdens": "ljusgård",
    "ljusgårds": "ljusgård",
    "ljushastigheten": "ljushastighet",
    "ljushastighetens": "ljushastighet",
    "ljushastigheter": "ljushastighet",
    "ljushastigheterna": "ljushastighet",
    "ljushastigheternas": "ljushastighet",
    "ljushastigheters": "ljushastighet",
    "ljushastighets": "ljushastighet",
    "ljusheten": "ljushet",
    "ljushetens": "ljushet",
    "ljushets": "ljushet",
    "ljushuggningar": "ljushuggning",
    "ljushuggningarna": "ljushuggning",
    "ljushuggningarnas": "ljushuggning",
    "ljushuggningars": "ljushuggning",
    "ljushuggningen": "ljushuggning",
    "ljushuggningens": "ljushuggning",
    "ljushuggnings": "ljushuggning",
    "ljushuvuden": "ljushuvud",
    "ljushuvudena": "ljushuvud",
    "ljushuvudenas": "ljushuvud",
    "ljushuvudens": "ljushuvud",
    "ljushuvudet": "ljushuvud",
    "ljushuvudets": "ljushuvud",
    "ljushuvuds": "ljushuvud",
    "ljushyade": "ljushyad",
    "ljushyades": "ljushyad",
    "ljushyads": "ljushyad",
    "ljushyat": "ljushyad",
    "ljushyats": "ljushyad",
    "ljushyllta": "ljushyllt",
    "ljushylltare": "ljushyllt",
    "ljushylltares": "ljushyllt",
    "ljushylltas": "ljushyllt",
    "ljushylltast": "ljushyllt",
    "ljushylltaste": "ljushyllt",
    "ljushylltastes": "ljushyllt",
    "ljushylltasts": "ljushyllt",
    "ljushyllte": "ljushyllt",
    "ljushylltes": "ljushyllt",
    "ljushylltheten": "ljushyllthet",
    "ljushyllthetens": "ljushyllthet",
    "ljushyllthets": "ljushyllthet",
    "ljushyllts": "ljushyllt",
    "ljushållar": "ljushållare",
    "ljushållaren": "ljushållare",
    "ljushållarens": "ljushållare",
    "ljushållares": "ljushållare",
    "ljushållarna": "ljushållare",
    "ljushållarnas": "ljushållare",
    "ljushåriga": "ljushårig",
    "ljushårigare": "ljushårig",
    "ljushårigares": "ljushårig",
    "ljushårigas": "ljushårig",
    "ljushårigast": "ljushårig",
    "ljushårigaste": "ljushårig",
    "ljushårigastes": "ljushårig",
    "ljushårigasts": "ljushårig",
    "ljushårige": "ljushårig",
    "ljushåriges": "ljushårig",
    "ljushårigheten": "ljushårighet",
    "ljushårighetens": "ljushårighet",
    "ljushårighets": "ljushårighet",
    "ljushårigs": "ljushårig",
    "ljushårigt": "ljushårig",
    "ljushårigts": "ljushårig",
    "ljuskopierad": "ljuskopiera",
    "ljuskopierade": "ljuskopiera",
    "ljuskopierades": "ljuskopiera",
    "ljuskopierads": "ljuskopiera",
    "ljuskopierande": "ljuskopiera",
    "ljuskopieranden": "ljuskopierande",
    "ljuskopierandena": "ljuskopierande",
    "ljuskopierandenas": "ljuskopierande",
    "ljuskopierandens": "ljuskopierande",
    "ljuskopierandes": "ljuskopierande",
    "ljuskopierandet": "ljuskopierande",
    "ljuskopierandets": "ljuskopierande",
    "ljuskopierar": "ljuskopiera",
    "ljuskopieras": "ljuskopiera",
    "ljuskopierat": "ljuskopiera",
    "ljuskopierats": "ljuskopiera",
    "ljuskopierbara": "ljuskopierbar",
    "ljuskopierbarare": "ljuskopierbar",
    "ljuskopierbarares": "ljuskopierbar",
    "ljuskopierbaras": "ljuskopierbar",
    "ljuskopierbarast": "ljuskopierbar",
    "ljuskopierbaraste": "ljuskopierbar",
    "ljuskopierbarastes": "ljuskopierbar",
    "ljuskopierbarasts": "ljuskopierbar",
    "ljuskopierbare": "ljuskopierbar",
    "ljuskopierbares": "ljuskopierbar",
    "ljuskopierbarheten": "ljuskopierbarhet",
    "ljuskopierbarhetens": "ljuskopierbarhet",
    "ljuskopierbarhets": "ljuskopierbarhet",
    "ljuskopierbars": "ljuskopierbar",
    "ljuskopierbart": "ljuskopierbar",
    "ljuskopierbarts": "ljuskopierbar",
    "ljuskopieringar": "ljuskopiering",
    "ljuskopieringarna": "ljuskopiering",
    "ljuskopieringarnas": "ljuskopiering",
    "ljuskopieringars": "ljuskopiering",
    "ljuskopieringen": "ljuskopiering",
    "ljuskopieringens": "ljuskopiering",
    "ljuskopierings": "ljuskopiering",
    "ljuskransar": "ljuskrans",
    "ljuskransarna": "ljuskrans",
    "ljuskransarnas": "ljuskrans",
    "ljuskransars": "ljuskrans",
    "ljuskransen": "ljuskrans",
    "ljuskransens": "ljuskrans",
    "ljuskretsar": "ljuskrets",
    "ljuskretsarna": "ljuskrets",
    "ljuskretsarnas": "ljuskrets",
    "ljuskretsars": "ljuskrets",
    "ljuskretsen": "ljuskrets",
    "ljuskretsens": "ljuskrets",
    "ljuskronan": "ljuskrona",
    "ljuskronans": "ljuskrona",
    "ljuskronas": "ljuskrona",
    "ljuskrone": "ljuskrona",
    "ljuskronor": "ljuskrona",
    "ljuskronorna": "ljuskrona",
    "ljuskronornas": "ljuskrona",
    "ljuskronors": "ljuskrona",
    "ljuskvanta": "ljuskvantum",
    "ljuskvantana": "ljuskvantum",
    "ljuskvantanas": "ljuskvantum",
    "ljuskvantas": "ljuskvantum",
    "ljuskvantumen": "ljuskvantum",
    "ljuskvantumens": "ljuskvantum",
    "ljuskvantumet": "ljuskvantum",
    "ljuskvantumets": "ljuskvantum",
    "ljuskvantums": "ljuskvantum",
    "ljuskägel": "ljuskägla",
    "ljuskäglan": "ljuskägla",
    "ljuskäglans": "ljuskägla",
    "ljuskäglas": "ljuskägla",
    "ljuskägle": "ljuskägla",
    "ljuskäglor": "ljuskägla",
    "ljuskäglorna": "ljuskägla",
    "ljuskäglornas": "ljuskägla",
    "ljuskäglors": "ljuskägla",
    "ljuskäll": "ljuskälla",
    "ljuskällan": "ljuskälla",
    "ljuskällans": "ljuskälla",
    "ljuskällas": "ljuskälla",
    "ljuskälle": "ljuskälla",
    "ljuskällor": "ljuskälla",
    "ljuskällorna": "ljuskälla",
    "ljuskällornas": "ljuskälla",
    "ljuskällors": "ljuskälla",
    "ljuskälls": "ljuskälla",
    "ljuskänsliga": "ljuskänslig",
    "ljuskänsligare": "ljuskänslig",
    "ljuskänsligares": "ljuskänslig",
    "ljuskänsligas": "ljuskänslig",
    "ljuskänsligast": "ljuskänslig",
    "ljuskänsligaste": "ljuskänslig",
    "ljuskänsligastes": "ljuskänslig",
    "ljuskänsligasts": "ljuskänslig",
    "ljuskänslige": "ljuskänslig",
    "ljuskänsliges": "ljuskänslig",
    "ljuskänsligheten": "ljuskänslighet",
    "ljuskänslighetens": "ljuskänslighet",
    "ljuskänsligheter": "ljuskänslighet",
    "ljuskänsligheterna": "ljuskänslighet",
    "ljuskänsligheternas": "ljuskänslighet",
    "ljuskänsligheters": "ljuskänslighet",
    "ljuskänslighets": "ljuskänslighet",
    "ljuskänsligs": "ljuskänslig",
    "ljuskänsligt": "ljuskänslig",
    "ljuskänsligts": "ljuskänslig",
    "ljuslagda": "ljuslagd",
    "ljuslagdare": "ljuslagd",
    "ljuslagdares": "ljuslagd",
    "ljuslagdas": "ljuslagd",
    "ljuslagdast": "ljuslagd",
    "ljuslagdaste": "ljuslagd",
    "ljuslagdastes": "ljuslagd",
    "ljuslagdasts": "ljuslagd",
    "ljuslagde": "ljuslagd",
    "ljuslagdes": "ljuslagd",
    "ljuslagdheten": "ljuslagdhet",
    "ljuslagdhetens": "ljuslagdhet",
    "ljuslagdhets": "ljuslagdhet",
    "ljuslagds": "ljuslagd",
    "ljuslagt": "ljuslagd",
    "ljuslagts": "ljuslagd",
    "ljuslisten": "ljuslist",
    "ljuslistens": "ljuslist",
    "ljuslister": "ljuslist",
    "ljuslisterna": "ljuslist",
    "ljuslisternas": "ljuslist",
    "ljuslisters": "ljuslist",
    "ljuslists": "ljuslist",
    "ljuslockiga": "ljuslockig",
    "ljuslockigare": "ljuslockig",
    "ljuslockigares": "ljuslockig",
    "ljuslockigas": "ljuslockig",
    "ljuslockigast": "ljuslockig",
    "ljuslockigaste": "ljuslockig",
    "ljuslockigastes": "ljuslockig",
    "ljuslockigasts": "ljuslockig",
    "ljuslockige": "ljuslockig",
    "ljuslockiges": "ljuslockig",
    "ljuslockigheten": "ljuslockighet",
    "ljuslockighetens": "ljuslockighet",
    "ljuslockighets": "ljuslockighet",
    "ljuslockigs": "ljuslockig",
    "ljuslockigt": "ljuslockig",
    "ljuslockigts": "ljuslockig",
    "ljuslykt": "ljuslykta",
    "ljuslyktan": "ljuslykta",
    "ljuslyktans": "ljuslykta",
    "ljuslyktas": "ljuslykta",
    "ljuslykte": "ljuslykta",
    "ljuslyktor": "ljuslykta",
    "ljuslyktorna": "ljuslykta",
    "ljuslyktornas": "ljuslykta",
    "ljuslyktors": "ljuslykta",
    "ljuslykts": "ljuslykta",
    "ljuslätta": "ljuslätt",
    "ljuslättare": "ljuslätt",
    "ljuslättares": "ljuslätt",
    "ljuslättas": "ljuslätt",
    "ljuslättast": "ljuslätt",
    "ljuslättaste": "ljuslätt",
    "ljuslättastes": "ljuslätt",
    "ljuslättasts": "ljuslätt",
    "ljuslätte": "ljuslätt",
    "ljuslättes": "ljuslätt",
    "ljuslättheten": "ljuslätthet",
    "ljuslätthetens": "ljuslätthet",
    "ljuslätthets": "ljuslätthet",
    "ljuslätts": "ljuslätt",
    "ljusmikroskopen": "ljusmikroskop",
    "ljusmikroskopens": "ljusmikroskop",
    "ljusmikroskopet": "ljusmikroskop",
    "ljusmikroskopets": "ljusmikroskop",
    "ljusmikroskops": "ljusmikroskop",
    "ljusmässiga": "ljusmässig",
    "ljusmässigare": "ljusmässig",
    "ljusmässigares": "ljusmässig",
    "ljusmässigas": "ljusmässig",
    "ljusmässigast": "ljusmässig",
    "ljusmässigaste": "ljusmässig",
    "ljusmässigastes": "ljusmässig",
    "ljusmässigasts": "ljusmässig",
    "ljusmässige": "ljusmässig",
    "ljusmässiges": "ljusmässig",
    "ljusmässigs": "ljusmässig",
    "ljusmässigt": "ljusmässig",
    "ljusmässigts": "ljusmässig",
    "ljusnade": "ljusna",
    "ljusnades": "ljusna",
    "ljusnande": "ljusna",
    "ljusnanden": "ljusnande",
    "ljusnandena": "ljusnande",
    "ljusnandenas": "ljusnande",
    "ljusnandens": "ljusnande",
    "ljusnandes": "ljusnande",
    "ljusnandet": "ljusnande",
    "ljusnandets": "ljusnande",
    "ljusnar": "ljusna",
    "ljusnas": "ljusna",
    "ljusnat": "ljusna",
    "ljusnats": "ljusna",
    "ljusningar": "ljusning",
    "ljusningarna": "ljusning",
    "ljusningarnas": "ljusning",
    "ljusningars": "ljusning",
    "ljusningen": "ljusning",
    "ljusningens": "ljusning",
    "ljusnings": "ljusning",
    "ljusnäten": "ljusnät",
    "ljusnätens": "ljusnät",
    "ljusnätet": "ljusnät",
    "ljusnätets": "ljusnät",
    "ljusnäts": "ljusnät",
    "ljusorgeln": "ljusorgel",
    "ljusorgelns": "ljusorgel",
    "ljusorgels": "ljusorgel",
    "ljusorglar": "ljusorgel",
    "ljusorglarna": "ljusorgel",
    "ljusorglarnas": "ljusorgel",
    "ljusorglars": "ljusorgel",
    "ljuspartikeln": "ljuspartikel",
    "ljuspartikelns": "ljuspartikel",
    "ljuspartikels": "ljuspartikel",
    "ljuspartiklar": "ljuspartikel",
    "ljuspartiklarna": "ljuspartikel",
    "ljuspartiklarnas": "ljuspartikel",
    "ljuspartiklars": "ljuspartikel",
    "ljuspenn": "ljuspenna",
    "ljuspennan": "ljuspenna",
    "ljuspennans": "ljuspenna",
    "ljuspennas": "ljuspenna",
    "ljuspenne": "ljuspenna",
    "ljuspennor": "ljuspenna",
    "ljuspennorna": "ljuspenna",
    "ljuspennornas": "ljuspenna",
    "ljuspennors": "ljuspenna",
    "ljuspenns": "ljuspenna",
    "ljuspunkten": "ljuspunkt",
    "ljuspunktens": "ljuspunkt",
    "ljuspunkter": "ljuspunkt",
    "ljuspunkterna": "ljuspunkt",
    "ljuspunkternas": "ljuspunkt",
    "ljuspunkters": "ljuspunkt",
    "ljuspunkts": "ljuspunkt",
    "ljusrampen": "ljusramp",
    "ljusrampens": "ljusramp",
    "ljusramper": "ljusramp",
    "ljusramperna": "ljusramp",
    "ljusrampernas": "ljusramp",
    "ljusrampers": "ljusramp",
    "ljusramps": "ljusramp",
    "ljusreklamen": "ljusreklam",
    "ljusreklamens": "ljusreklam",
    "ljusreklams": "ljusreklam",
    "ljusröda": "ljusröd",
    "ljusrödare": "ljusröd",
    "ljusrödares": "ljusröd",
    "ljusrödas": "ljusröd",
    "ljusrödast": "ljusröd",
    "ljusrödaste": "ljusröd",
    "ljusrödastes": "ljusröd",
    "ljusrödasts": "ljusröd",
    "ljusröde": "ljusröd",
    "ljusrödes": "ljusröd",
    "ljusröds": "ljusröd",
    "ljusrött": "ljusröd",
    "ljusrötts": "ljusröd",
    "ljussignalen": "ljussignal",
    "ljussignalens": "ljussignal",
    "ljussignaler": "ljussignal",
    "ljussignalerna": "ljussignal",
    "ljussignalernas": "ljussignal",
    "ljussignalers": "ljussignal",
    "ljussignals": "ljussignal",
    "ljusskenen": "ljussken",
    "ljusskenens": "ljussken",
    "ljusskenet": "ljussken",
    "ljusskenets": "ljussken",
    "ljusskens": "ljussken",
    "ljusskygga": "ljusskygg",
    "ljusskyggare": "ljusskygg",
    "ljusskyggares": "ljusskygg",
    "ljusskyggas": "ljusskygg",
    "ljusskyggast": "ljusskygg",
    "ljusskyggaste": "ljusskygg",
    "ljusskyggastes": "ljusskygg",
    "ljusskyggasts": "ljusskygg",
    "ljusskygge": "ljusskygg",
    "ljusskygges": "ljusskygg",
    "ljusskyggheten": "ljusskygghet",
    "ljusskygghetens": "ljusskygghet",
    "ljusskyggheter": "ljusskygghet",
    "ljusskyggheterna": "ljusskygghet",
    "ljusskyggheternas": "ljusskygghet",
    "ljusskyggheters": "ljusskygghet",
    "ljusskygghets": "ljusskygghet",
    "ljusskyggs": "ljusskygg",
    "ljusskyggt": "ljusskygg",
    "ljusskyggts": "ljusskygg",
    "ljusslingan": "ljusslinga",
    "ljusslingans": "ljusslinga",
    "ljusslingas": "ljusslinga",
    "ljusslinge": "ljusslinga",
    "ljusslingor": "ljusslinga",
    "ljusslingorna": "ljusslinga",
    "ljusslingornas": "ljusslinga",
    "ljusslingors": "ljusslinga",
    "ljussläckar": "ljussläckare",
    "ljussläckaren": "ljussläckare",
    "ljussläckarens": "ljussläckare",
    "ljussläckares": "ljussläckare",
    "ljussläckarna": "ljussläckare",
    "ljussläckarnas": "ljussläckare",
    "ljusstak": "ljusstake",
    "ljusstakar": "ljusstake",
    "ljusstakarna": "ljusstake",
    "ljusstakarnas": "ljusstake",
    "ljusstakars": "ljusstake",
    "ljusstaken": "ljusstake",
    "ljusstakens": "ljusstake",
    "ljusstakes": "ljusstake",
    "ljusstaks": "ljusstake",
    "ljusstarka": "ljusstark",
    "ljusstarkare": "ljusstark",
    "ljusstarkares": "ljusstark",
    "ljusstarkas": "ljusstark",
    "ljusstarkast": "ljusstark",
    "ljusstarkaste": "ljusstark",
    "ljusstarkastes": "ljusstark",
    "ljusstarkasts": "ljusstark",
    "ljusstarke": "ljusstark",
    "ljusstarkes": "ljusstark",
    "ljusstarks": "ljusstark",
    "ljusstarkt": "ljusstark",
    "ljusstarkts": "ljusstark",
    "ljusstrål": "ljusstråle",
    "ljusstrålar": "ljusstråle",
    "ljusstrålarna": "ljusstråle",
    "ljusstrålarnas": "ljusstråle",
    "ljusstrålars": "ljusstråle",
    "ljusstrålen": "ljusstråle",
    "ljusstrålens": "ljusstråle",
    "ljusstråles": "ljusstråle",
    "ljusstrålningar": "ljusstrålning",
    "ljusstrålningarna": "ljusstrålning",
    "ljusstrålningarnas": "ljusstrålning",
    "ljusstrålningars": "ljusstrålning",
    "ljusstrålningen": "ljusstrålning",
    "ljusstrålningens": "ljusstrålning",
    "ljusstrålnings": "ljusstrålning",
    "ljusstråls": "ljusstråle",
    "ljusstyrkan": "ljusstyrka",
    "ljusstyrkans": "ljusstyrka",
    "ljusstyrkas": "ljusstyrka",
    "ljusstyrke": "ljusstyrka",
    "ljusstyrkor": "ljusstyrka",
    "ljusstyrkorna": "ljusstyrka",
    "ljusstyrkornas": "ljusstyrka",
    "ljusstyrkors": "ljusstyrka",
    "ljussvaga": "ljussvag",
    "ljussvagare": "ljussvag",
    "ljussvagares": "ljussvag",
    "ljussvagas": "ljussvag",
    "ljussvagast": "ljussvag",
    "ljussvagaste": "ljussvag",
    "ljussvagastes": "ljussvag",
    "ljussvagasts": "ljussvag",
    "ljussvage": "ljussvag",
    "ljussvages": "ljussvag",
    "ljussvagheten": "ljussvaghet",
    "ljussvaghetens": "ljussvaghet",
    "ljussvaghets": "ljussvaghet",
    "ljussvags": "ljussvag",
    "ljussvagt": "ljussvag",
    "ljussvagts": "ljussvag",
    "ljussättningar": "ljussättning",
    "ljussättningarna": "ljussättning",
    "ljussättningarnas": "ljussättning",
    "ljussättningars": "ljussättning",
    "ljussättningen": "ljussättning",
    "ljussättningens": "ljussättning",
    "ljussättnings": "ljussättning",
    "ljust": "ljus",
    "ljuster": "ljustra",
    "ljusterapien": "ljusterapi",
    "ljusterapiens": "ljusterapi",
    "ljusterapilamp": "ljusterapilampa",
    "ljusterapilampan": "ljusterapilampa",
    "ljusterapilampans": "ljusterapilampa",
    "ljusterapilampas": "ljusterapilampa",
    "ljusterapilampe": "ljusterapilampa",
    "ljusterapilampor": "ljusterapilampa",
    "ljusterapilamporna": "ljusterapilampa",
    "ljusterapilampornas": "ljusterapilampa",
    "ljusterapilampors": "ljusterapilampa",
    "ljusterapilamps": "ljusterapilampa",
    "ljusterapin": "ljusterapi",
    "ljusterapins": "ljusterapi",
    "ljusterapis": "ljusterapi",
    "ljusterna": "ljuster",
    "ljusternas": "ljuster",
    "ljusters": "ljuster",
    "ljustrad": "ljustra",
    "ljustrade": "ljustra",
    "ljustrades": "ljustra",
    "ljustrads": "ljustra",
    "ljustrande": "ljustra",
    "ljustranden": "ljustrande",
    "ljustrandena": "ljustrande",
    "ljustrandenas": "ljustrande",
    "ljustrandens": "ljustrande",
    "ljustrandes": "ljustrande",
    "ljustrandet": "ljustrande",
    "ljustrandets": "ljustrande",
    "ljustrar": "ljustra",
    "ljustras": "ljustra",
    "ljustrat": "ljustra",
    "ljustrats": "ljustra",
    "ljustren": "ljuster",
    "ljustrens": "ljuster",
    "ljustret": "ljuster",
    "ljustrets": "ljuster",
    "ljustrycken": "ljustryck",
    "ljustryckens": "ljustryck",
    "ljustrycket": "ljustryck",
    "ljustryckets": "ljustryck",
    "ljustrycks": "ljustryck",
    "ljusts": "ljus",
    "ljustut": "ljustuta",
    "ljustutan": "ljustuta",
    "ljustutans": "ljustuta",
    "ljustutas": "ljustuta",
    "ljustute": "ljustuta",
    "ljustutor": "ljustuta",
    "ljustutorna": "ljustuta",
    "ljustutornas": "ljustuta",
    "ljustutors": "ljustuta",
    "ljustuts": "ljustuta",
    "ljusutstrålningar": "ljusutstrålning",
    "ljusutstrålningarna": "ljusutstrålning",
    "ljusutstrålningarnas": "ljusutstrålning",
    "ljusutstrålningars": "ljusutstrålning",
    "ljusutstrålningen": "ljusutstrålning",
    "ljusutstrålningens": "ljusutstrålning",
    "ljusutstrålnings": "ljusutstrålning",
    "ljusvallen": "ljusvall",
    "ljusvallens": "ljusvall",
    "ljusvalls": "ljusvall",
    "ljusvågen": "ljusvåg",
    "ljusvågens": "ljusvåg",
    "ljusvågor": "ljusvåg",
    "ljusvågorna": "ljusvåg",
    "ljusvågornas": "ljusvåg",
    "ljusvågors": "ljusvåg",
    "ljusvågs": "ljusvåg",
    "ljusåren": "ljusår",
    "ljusårens": "ljusår",
    "ljusåret": "ljusår",
    "ljusårets": "ljusår",
    "ljusårs": "ljusår",
    "ljuva": "ljuv",
    "ljuvare": "ljuv",
    "ljuvares": "ljuv",
    "ljuvas": "ljuv",
    "ljuvast": "ljuv",
    "ljuvaste": "ljuv",
    "ljuvastes": "ljuv",
    "ljuvasts": "ljuv",
    "ljuve": "ljuv",
    "ljuves": "ljuv",
    "ljuvheten": "ljuvhet",
    "ljuvhetens": "ljuvhet",
    "ljuvheter": "ljuvhet",
    "ljuvheterna": "ljuvhet",
    "ljuvheternas": "ljuvhet",
    "ljuvheters": "ljuvhet",
    "ljuvhets": "ljuvhet",
    "ljuvliga": "ljuvlig",
    "ljuvligare": "ljuvlig",
    "ljuvligares": "ljuvlig",
    "ljuvligas": "ljuvlig",
    "ljuvligast": "ljuvlig",
    "ljuvligaste": "ljuvlig",
    "ljuvligastes": "ljuvlig",
    "ljuvligasts": "ljuvlig",
    "ljuvlige": "ljuvlig",
    "ljuvliges": "ljuvlig",
    "ljuvligheten": "ljuvlighet",
    "ljuvlighetens": "ljuvlighet",
    "ljuvligheter": "ljuvlighet",
    "ljuvligheterna": "ljuvlighet",
    "ljuvligheternas": "ljuvlighet",
    "ljuvligheters": "ljuvlighet",
    "ljuvlighets": "ljuvlighet",
    "ljuvligs": "ljuvlig",
    "ljuvligt": "ljuvlig",
    "ljuvligts": "ljuvlig",
    "ljuvs": "ljuv",
    "ljuvt": "ljuv",
    "ljuvts": "ljuv",
    "ljöd": "ljuda",
    "ljöde": "ljuda",
    "ljödes": "ljuda",
    "ljöds": "ljuda",
    "ljög": "ljuga",
    "ljöge": "ljuga",
    "ljöges": "ljuga",
    "ljögs": "ljuga",
    "loafersen": "loafers",
    "loafersens": "loafers",
    "loar": "lo",
    "loarna": "lo",
    "loarnas": "lo",
    "loars": "lo",
    "lobb": "lobba",
    "lobbad": "lobba",
    "lobbade": "lobba",
    "lobbades": "lobba",
    "lobbads": "lobba",
    "lobbande": "lobba",
    "lobbanden": "lobbande",
    "lobbandena": "lobbande",
    "lobbandenas": "lobbande",
    "lobbandens": "lobbande",
    "lobbandes": "lobbande",
    "lobbandet": "lobbande",
    "lobbandets": "lobbande",
    "lobbar": "lobba",
    "lobbarna": "lobb",
    "lobbarnas": "lobb",
    "lobbars": "lobb",
    "lobbas": "lobba",
    "lobbat": "lobba",
    "lobbats": "lobba",
    "lobben": "lobb",
    "lobbens": "lobb",
    "lobbs": "lobb",
    "lobbyer": "lobby",
    "lobbyerna": "lobby",
    "lobbyernas": "lobby",
    "lobbyers": "lobby",
    "lobbyinsatsen": "lobbyinsats",
    "lobbyinsatsens": "lobbyinsats",
    "lobbyinsatser": "lobbyinsats",
    "lobbyinsatserna": "lobbyinsats",
    "lobbyinsatsernas": "lobbyinsats",
    "lobbyinsatsers": "lobbyinsats",
    "lobbyn": "lobby",
    "lobbyns": "lobby",
    "lobbys": "lobby",
    "lobbyverksamheten": "lobbyverksamhet",
    "lobbyverksamhetens": "lobbyverksamhet",
    "lobbyverksamheter": "lobbyverksamhet",
    "lobbyverksamheterna": "lobbyverksamhet",
    "lobbyverksamheternas": "lobbyverksamhet",
    "lobbyverksamheters": "lobbyverksamhet",
    "lobbyverksamhets": "lobbyverksamhet",
    "lobeli": "lobelia",
    "lobelian": "lobelia",
    "lobelians": "lobelia",
    "lobelias": "lobelia",
    "lobelie": "lobelia",
    "lobelior": "lobelia",
    "lobeliorna": "lobelia",
    "lobeliornas": "lobelia",
    "lobeliors": "lobelia",
    "lobelis": "lobelia",
    "loben": "lob",
    "lobens": "lob",
    "lober": "lob",
    "loberna": "lob",
    "lobernas": "lob",
    "lobers": "lob",
    "lobotomien": "lobotomi",
    "lobotomiens": "lobotomi",
    "lobotomier": "lobotomi",
    "lobotomierna": "lobotomi",
    "lobotomiernas": "lobotomi",
    "lobotomiers": "lobotomi",
    "lobotomin": "lobotomi",
    "lobotomins": "lobotomi",
    "lobotomis": "lobotomi",
    "lobs": "lob",
    "lock": "locka",
    "lockad": "locka",
    "lockade": "locka",
    "lockades": "locka",
    "lockads": "locka",
    "lockande": "locka",
    "lockanden": "lockande",
    "lockandena": "lockande",
    "lockandenas": "lockande",
    "lockandens": "lockande",
    "lockandes": "lockande",
    "lockandet": "lockande",
    "lockandets": "lockande",
    "lockar": "locka",
    "lockarna": "lock",
    "lockarnas": "lock",
    "lockars": "lock",
    "lockas": "locka",
    "lockat": "locka",
    "lockats": "locka",
    "lockbeten": "lockbete",
    "lockbetena": "lockbete",
    "lockbetenas": "lockbete",
    "lockbetens": "lockbete",
    "lockbetes": "lockbete",
    "lockbetet": "lockbete",
    "lockbetets": "lockbete",
    "lockdjuren": "lockdjur",
    "lockdjurens": "lockdjur",
    "lockdjuret": "lockdjur",
    "lockdjurets": "lockdjur",
    "lockdjurs": "lockdjur",
    "lockelsen": "lockelse",
    "lockelsens": "lockelse",
    "lockelser": "lockelse",
    "lockelserna": "lockelse",
    "lockelsernas": "lockelse",
    "lockelsers": "lockelse",
    "lockelses": "lockelse",
    "locken": "lock",
    "lockens": "lock",
    "locket": "lock",
    "lockets": "lock",
    "lockfärgen": "lockfärg",
    "lockfärgens": "lockfärg",
    "lockfärger": "lockfärg",
    "lockfärgerna": "lockfärg",
    "lockfärgernas": "lockfärg",
    "lockfärgers": "lockfärg",
    "lockfärgs": "lockfärg",
    "lockfågeln": "lockfågel",
    "lockfågelns": "lockfågel",
    "lockfågels": "lockfågel",
    "lockfåglar": "lockfågel",
    "lockfåglarna": "lockfågel",
    "lockfåglarnas": "lockfågel",
    "lockfåglars": "lockfågel",
    "lockiga": "lockig",
    "lockigare": "lockig",
    "lockigares": "lockig",
    "lockigas": "lockig",
    "lockigast": "lockig",
    "lockigaste": "lockig",
    "lockigastes": "lockig",
    "lockigasts": "lockig",
    "lockige": "lockig",
    "lockiges": "lockig",
    "lockigheten": "lockighet",
    "lockighetens": "lockighet",
    "lockighets": "lockighet",
    "lockigs": "lockig",
    "lockigt": "lockig",
    "lockigts": "lockig",
    "lockout": "lockouta",
    "lockoutad": "lockouta",
    "lockoutade": "lockouta",
    "lockoutades": "lockouta",
    "lockoutads": "lockouta",
    "lockoutande": "lockouta",
    "lockoutanden": "lockoutande",
    "lockoutandena": "lockoutande",
    "lockoutandenas": "lockoutande",
    "lockoutandens": "lockoutande",
    "lockoutandes": "lockoutande",
    "lockoutandet": "lockoutande",
    "lockoutandets": "lockoutande",
    "lockoutar": "lockouta",
    "lockoutas": "lockouta",
    "lockoutat": "lockouta",
    "lockoutats": "lockouta",
    "lockouten": "lockout",
    "lockoutens": "lockout",
    "lockouter": "lockout",
    "lockouterna": "lockout",
    "lockouternas": "lockout",
    "lockouters": "lockout",
    "lockouts": "lockout",
    "lockprisen": "lockpris",
    "lockprisens": "lockpris",
    "lockpriser": "lockpris",
    "lockpriserna": "lockpris",
    "lockprisernas": "lockpris",
    "lockprisers": "lockpris",
    "lockpriset": "lockpris",
    "lockprisets": "lockpris",
    "lockropen": "lockrop",
    "lockropens": "lockrop",
    "lockropet": "lockrop",
    "lockropets": "lockrop",
    "lockrops": "lockrop",
    "locks": "lock",
    "locktänger": "locktång",
    "locktängerna": "locktång",
    "locktängernas": "locktång",
    "locktängers": "locktång",
    "locktången": "locktång",
    "locktångens": "locktång",
    "locktångs": "locktång",
    "lod": "loda",
    "lodad": "loda",
    "lodade": "loda",
    "lodades": "loda",
    "lodads": "loda",
    "lodande": "loda",
    "lodanden": "lodande",
    "lodandena": "lodande",
    "lodandenas": "lodande",
    "lodandens": "lodande",
    "lodandes": "lodande",
    "lodandet": "lodande",
    "lodandets": "lodande",
    "lodar": "lodare",
    "lodaren": "lodare",
    "lodarens": "lodare",
    "lodares": "lodare",
    "lodarna": "lodare",
    "lodarnas": "lodare",
    "lodas": "loda",
    "lodat": "loda",
    "lodats": "loda",
    "lodbara": "lodbar",
    "lodbarare": "lodbar",
    "lodbarares": "lodbar",
    "lodbaras": "lodbar",
    "lodbarast": "lodbar",
    "lodbaraste": "lodbar",
    "lodbarastes": "lodbar",
    "lodbarasts": "lodbar",
    "lodbare": "lodbar",
    "lodbares": "lodbar",
    "lodbarheten": "lodbarhet",
    "lodbarhetens": "lodbarhet",
    "lodbarhets": "lodbarhet",
    "lodbars": "lodbar",
    "lodbart": "lodbar",
    "lodbarts": "lodbar",
    "lodböss": "lodbössa",
    "lodbössan": "lodbössa",
    "lodbössans": "lodbössa",
    "lodbössas": "lodbössa",
    "lodbösse": "lodbössa",
    "lodbössor": "lodbössa",
    "lodbössorna": "lodbössa",
    "lodbössornas": "lodbössa",
    "lodbössors": "lodbössa",
    "loden": "lod",
    "lodenet": "loden",
    "lodenets": "loden",
    "lodenrockar": "lodenrock",
    "lodenrockarna": "lodenrock",
    "lodenrockarnas": "lodenrock",
    "lodenrockars": "lodenrock",
    "lodenrocken": "lodenrock",
    "lodenrockens": "lodenrock",
    "lodenrocks": "lodenrock",
    "lodens": "loden",
    "lodet": "lod",
    "lodets": "lod",
    "lodisar": "lodis",
    "lodisarna": "lodis",
    "lodisarnas": "lodis",
    "lodisars": "lodis",
    "lodisen": "lodis",
    "lodisens": "lodis",
    "lodjuren": "lodjur",
    "lodjurens": "lodjur",
    "lodjuret": "lodjur",
    "lodjurets": "lodjur",
    "lodjurs": "lodjur",
    "lodleds": "lodled",
    "lodlin": "lodlina",
    "lodlinan": "lodlina",
    "lodlinans": "lodlina",
    "lodlinas": "lodlina",
    "lodline": "lodlina",
    "lodlinjen": "lodlinje",
    "lodlinjens": "lodlinje",
    "lodlinjer": "lodlinje",
    "lodlinjerna": "lodlinje",
    "lodlinjernas": "lodlinje",
    "lodlinjers": "lodlinje",
    "lodlinjes": "lodlinje",
    "lodlinor": "lodlina",
    "lodlinorna": "lodlina",
    "lodlinornas": "lodlina",
    "lodlinors": "lodlina",
    "lodlins": "lodlina",
    "lodplanen": "lodplan",
    "lodplanens": "lodplan",
    "lodplanet": "lodplan",
    "lodplanets": "lodplan",
    "lodplans": "lodplan",
    "lodräta": "lodrät",
    "lodrätare": "lodrät",
    "lodrätares": "lodrät",
    "lodrätas": "lodrät",
    "lodrätast": "lodrät",
    "lodrätaste": "lodrät",
    "lodrätastes": "lodrät",
    "lodrätasts": "lodrät",
    "lodräte": "lodrät",
    "lodrätes": "lodrät",
    "lodräts": "lodrät",
    "lodrätt": "lodrät",
    "lodrätts": "lodrät",
    "lods": "lod",
    "lodskotten": "lodskott",
    "lodskottens": "lodskott",
    "lodskottet": "lodskott",
    "lodskottets": "lodskott",
    "lodskotts": "lodskott",
    "lodstrecken": "lodstreck",
    "lodstreckens": "lodstreck",
    "lodstrecket": "lodstreck",
    "lodstreckets": "lodstreck",
    "lodstrecks": "lodstreck",
    "loftbodar": "loftbod",
    "loftbodarna": "loftbod",
    "loftbodarnas": "loftbod",
    "loftbodars": "loftbod",
    "loftboden": "loftbod",
    "loftbodens": "loftbod",
    "loftbods": "loftbod",
    "loften": "loft",
    "loftens": "loft",
    "loftet": "loft",
    "loftets": "loft",
    "loftgångar": "loftgång",
    "loftgångarna": "loftgång",
    "loftgångarnas": "loftgång",
    "loftgångars": "loftgång",
    "loftgången": "loftgång",
    "loftgångens": "loftgång",
    "loftgångs": "loftgång",
    "lofts": "loft",
    "log": "loge",
    "logar": "loge",
    "logaritmen": "logaritm",
    "logaritmens": "logaritm",
    "logaritmer": "logaritm",
    "logaritmerna": "logaritm",
    "logaritmernas": "logaritm",
    "logaritmers": "logaritm",
    "logaritmiska": "logaritmisk",
    "logaritmiskare": "logaritmisk",
    "logaritmiskares": "logaritmisk",
    "logaritmiskas": "logaritmisk",
    "logaritmiskast": "logaritmisk",
    "logaritmiskaste": "logaritmisk",
    "logaritmiskastes": "logaritmisk",
    "logaritmiskasts": "logaritmisk",
    "logaritmiske": "logaritmisk",
    "logaritmiskes": "logaritmisk",
    "logaritmisks": "logaritmisk",
    "logaritmiskt": "logaritmisk",
    "logaritmiskts": "logaritmisk",
    "logaritms": "logaritm",
    "logaritmsystemen": "logaritmsystem",
    "logaritmsystemens": "logaritmsystem",
    "logaritmsystemet": "logaritmsystem",
    "logaritmsystemets": "logaritmsystem",
    "logaritmsystems": "logaritmsystem",
    "logarna": "loge",
    "logarnas": "loge",
    "logars": "loge",
    "loge": "le",
    "logementen": "logement",
    "logementens": "logement",
    "logementet": "logement",
    "logementets": "logement",
    "logements": "logement",
    "logen": "loge",
    "logens": "loge",
    "loger": "loge",
    "logerad": "logera",
    "logerade": "logera",
    "logerades": "logera",
    "logerads": "logera",
    "logerande": "logera",
    "logeranden": "logerande",
    "logerandena": "logerande",
    "logerandenas": "logerande",
    "logerandens": "logerande",
    "logerandes": "logerande",
    "logerandet": "logerande",
    "logerandets": "logerande",
    "logerar": "logera",
    "logeras": "logera",
    "logerat": "logera",
    "logerats": "logera",
    "logerbara": "logerbar",
    "logerbarare": "logerbar",
    "logerbarares": "logerbar",
    "logerbaras": "logerbar",
    "logerbarast": "logerbar",
    "logerbaraste": "logerbar",
    "logerbarastes": "logerbar",
    "logerbarasts": "logerbar",
    "logerbare": "logerbar",
    "logerbares": "logerbar",
    "logerbarheten": "logerbarhet",
    "logerbarhetens": "logerbarhet",
    "logerbarhets": "logerbarhet",
    "logerbars": "logerbar",
    "logerbart": "logerbar",
    "logerbarts": "logerbar",
    "logeringar": "logering",
    "logeringarna": "logering",
    "logeringarnas": "logering",
    "logeringars": "logering",
    "logeringen": "logering",
    "logeringens": "logering",
    "logerings": "logering",
    "logerna": "loge",
    "logernas": "loge",
    "logers": "loge",
    "loges": "loge",
    "logg": "logga",
    "loggad": "logga",
    "loggade": "logga",
    "loggades": "logga",
    "loggads": "logga",
    "loggan": "logga",
    "loggande": "logga",
    "logganden": "loggande",
    "loggandena": "loggande",
    "loggandenas": "loggande",
    "loggandens": "loggande",
    "loggandes": "loggande",
    "loggandet": "loggande",
    "loggandets": "loggande",
    "loggans": "logga",
    "loggar": "logga",
    "loggarna": "logg",
    "loggarnas": "logg",
    "loggars": "logg",
    "loggas": "logga",
    "loggat": "logga",
    "loggats": "logga",
    "loggboken": "loggbok",
    "loggbokens": "loggbok",
    "loggboks": "loggbok",
    "loggböcker": "loggbok",
    "loggböckerna": "loggbok",
    "loggböckernas": "loggbok",
    "loggböckers": "loggbok",
    "loggen": "logg",
    "loggens": "logg",
    "loggertar": "loggert",
    "loggertarna": "loggert",
    "loggertarnas": "loggert",
    "loggertars": "loggert",
    "loggerten": "loggert",
    "loggertens": "loggert",
    "loggerts": "loggert",
    "loggertsegels": "loggertsegel",
    "loggertseglen": "loggertsegel",
    "loggertseglens": "loggertsegel",
    "loggertseglet": "loggertsegel",
    "loggertseglets": "loggertsegel",
    "loggi": "loggia",
    "loggian": "loggia",
    "loggians": "loggia",
    "loggias": "loggia",
    "loggie": "loggia",
    "loggior": "loggia",
    "loggiorna": "loggia",
    "loggiornas": "loggia",
    "loggiors": "loggia",
    "loggis": "loggia",
    "logglasen": "logglas",
    "logglasens": "logglas",
    "logglaset": "logglas",
    "logglasets": "logglas",
    "loggor": "logga",
    "loggorna": "logga",
    "loggornas": "logga",
    "loggors": "logga",
    "loggs": "logg",
    "loggskädd": "loggskädda",
    "loggskäddan": "loggskädda",
    "loggskäddans": "loggskädda",
    "loggskäddas": "loggskädda",
    "loggskädde": "loggskädda",
    "loggskäddor": "loggskädda",
    "loggskäddorna": "loggskädda",
    "loggskäddornas": "loggskädda",
    "loggskäddors": "loggskädda",
    "loggskädds": "loggskädda",
    "logier": "logi",
    "logierna": "logi",
    "logiernas": "logi",
    "logiers": "logi",
    "logiet": "logi",
    "logiets": "logi",
    "logiken": "logik",
    "logikens": "logik",
    "logikern": "logiker",
    "logikerna": "logiker",
    "logikernas": "logiker",
    "logikerns": "logiker",
    "logikers": "logiker",
    "logiks": "logik",
    "login": "logi",
    "logina": "logi",
    "loginas": "logi",
    "logins": "logi",
    "logis": "logi",
    "logiska": "logisk",
    "logiskare": "logisk",
    "logiskares": "logisk",
    "logiskas": "logisk",
    "logiskast": "logisk",
    "logiskaste": "logisk",
    "logiskastes": "logisk",
    "logiskasts": "logisk",
    "logiske": "logisk",
    "logiskes": "logisk",
    "logisks": "logisk",
    "logiskt": "logisk",
    "logiskts": "logisk",
    "logistiken": "logistik",
    "logistikens": "logistik",
    "logistiks": "logistik",
    "logit": "logi",
    "logits": "logi",
    "logografiska": "logografisk",
    "logografiskare": "logografisk",
    "logografiskares": "logografisk",
    "logografiskas": "logografisk",
    "logografiskast": "logografisk",
    "logografiskaste": "logografisk",
    "logografiskastes": "logografisk",
    "logografiskasts": "logografisk",
    "logografiske": "logografisk",
    "logografiskes": "logografisk",
    "logografisks": "logografisk",
    "logografiskt": "logografisk",
    "logografiskts": "logografisk",
    "logogrammen": "logogram",
    "logogrammens": "logogram",
    "logogrammet": "logogram",
    "logogrammets": "logogram",
    "logograms": "logogram",
    "logopeden": "logoped",
    "logopedens": "logoped",
    "logopeder": "logoped",
    "logopederna": "logoped",
    "logopedernas": "logoped",
    "logopeders": "logoped",
    "logopedien": "logopedi",
    "logopediens": "logopedi",
    "logopedin": "logopedi",
    "logopedins": "logopedi",
    "logopedis": "logopedi",
    "logopediska": "logopedisk",
    "logopediskare": "logopedisk",
    "logopediskares": "logopedisk",
    "logopediskas": "logopedisk",
    "logopediskast": "logopedisk",
    "logopediskaste": "logopedisk",
    "logopediskastes": "logopedisk",
    "logopediskasts": "logopedisk",
    "logopediske": "logopedisk",
    "logopediskes": "logopedisk",
    "logopedisks": "logopedisk",
    "logopediskt": "logopedisk",
    "logopediskts": "logopedisk",
    "logopeds": "logoped",
    "logotypen": "logotyp",
    "logotypens": "logotyp",
    "logotyper": "logotyp",
    "logotyperna": "logotyp",
    "logotypernas": "logotyp",
    "logotypers": "logotyp",
    "logotyps": "logotyp",
    "logs": "loge",
    "loja": "loj",
    "lojala": "lojal",
    "lojalare": "lojal",
    "lojalares": "lojal",
    "lojalas": "lojal",
    "lojalast": "lojal",
    "lojalaste": "lojal",
    "lojalastes": "lojal",
    "lojalasts": "lojal",
    "lojale": "lojal",
    "lojales": "lojal",
    "lojaliteten": "lojalitet",
    "lojalitetens": "lojalitet",
    "lojaliteter": "lojalitet",
    "lojaliteterna": "lojalitet",
    "lojaliteternas": "lojalitet",
    "lojaliteters": "lojalitet",
    "lojalitets": "lojalitet",
    "lojalitetsbanden": "lojalitetsband",
    "lojalitetsbandens": "lojalitetsband",
    "lojalitetsbandet": "lojalitetsband",
    "lojalitetsbandets": "lojalitetsband",
    "lojalitetsbands": "lojalitetsband",
    "lojalitetsförklaringar": "lojalitetsförklaring",
    "lojalitetsförklaringarna": "lojalitetsförklaring",
    "lojalitetsförklaringarnas": "lojalitetsförklaring",
    "lojalitetsförklaringars": "lojalitetsförklaring",
    "lojalitetsförklaringen": "lojalitetsförklaring",
    "lojalitetsförklaringens": "lojalitetsförklaring",
    "lojalitetsförklarings": "lojalitetsförklaring",
    "lojals": "lojal",
    "lojalt": "lojal",
    "lojalts": "lojal",
    "lojare": "loj",
    "lojares": "loj",
    "lojas": "loj",
    "lojast": "loj",
    "lojaste": "loj",
    "lojastes": "loj",
    "lojasts": "loj",
    "loje": "loj",
    "lojes": "loj",
    "lojheten": "lojhet",
    "lojhetens": "lojhet",
    "lojhets": "lojhet",
    "lojs": "loj",
    "lojt": "loj",
    "lojts": "loj",
    "lok": "loka",
    "lokala": "lokal",
    "lokalare": "lokal",
    "lokalares": "lokal",
    "lokalas": "lokal",
    "lokalast": "lokal",
    "lokalaste": "lokal",
    "lokalastes": "lokal",
    "lokalasts": "lokal",
    "lokalavdelningar": "lokalavdelning",
    "lokalavdelningarna": "lokalavdelning",
    "lokalavdelningarnas": "lokalavdelning",
    "lokalavdelningars": "lokalavdelning",
    "lokalavdelningen": "lokalavdelning",
    "lokalavdelningens": "lokalavdelning",
    "lokalavdelnings": "lokalavdelning",
    "lokalbedöv": "lokalbedöva",
    "lokalbedövad": "lokalbedöva",
    "lokalbedövade": "lokalbedöva",
    "lokalbedövades": "lokalbedöva",
    "lokalbedövads": "lokalbedöva",
    "lokalbedövande": "lokalbedöva",
    "lokalbedövanden": "lokalbedövande",
    "lokalbedövandena": "lokalbedövande",
    "lokalbedövandenas": "lokalbedövande",
    "lokalbedövandens": "lokalbedövande",
    "lokalbedövandes": "lokalbedövande",
    "lokalbedövandet": "lokalbedövande",
    "lokalbedövandets": "lokalbedövande",
    "lokalbedövar": "lokalbedöva",
    "lokalbedövas": "lokalbedöva",
    "lokalbedövat": "lokalbedöva",
    "lokalbedövats": "lokalbedöva",
    "lokalbedövningar": "lokalbedövning",
    "lokalbedövningarna": "lokalbedövning",
    "lokalbedövningarnas": "lokalbedövning",
    "lokalbedövningars": "lokalbedövning",
    "lokalbedövningen": "lokalbedövning",
    "lokalbedövningens": "lokalbedövning",
    "lokalbedövnings": "lokalbedövning",
    "lokalbefolkningar": "lokalbefolkning",
    "lokalbefolkningarna": "lokalbefolkning",
    "lokalbefolkningarnas": "lokalbefolkning",
    "lokalbefolkningars": "lokalbefolkning",
    "lokalbefolkningen": "lokalbefolkning",
    "lokalbefolkningens": "lokalbefolkning",
    "lokalbefolknings": "lokalbefolkning",
    "lokalchefen": "lokalchef",
    "lokalchefens": "lokalchef",
    "lokalchefer": "lokalchef",
    "lokalcheferna": "lokalchef",
    "lokalchefernas": "lokalchef",
    "lokalchefers": "lokalchef",
    "lokalchefs": "lokalchef",
    "lokale": "lokal",
    "lokalen": "lokal",
    "lokalens": "lokal",
    "lokaler": "lokal",
    "lokalerna": "lokal",
    "lokalernas": "lokal",
    "lokalers": "lokal",
    "lokales": "lokal",
    "lokalfärgen": "lokalfärg",
    "lokalfärgens": "lokalfärg",
    "lokalfärger": "lokalfärg",
    "lokalfärgerna": "lokalfärg",
    "lokalfärgernas": "lokalfärg",
    "lokalfärgers": "lokalfärg",
    "lokalfärgs": "lokalfärg",
    "lokalförsvaret": "lokalförsvar",
    "lokalförsvarets": "lokalförsvar",
    "lokalförsvars": "lokalförsvar",
    "lokalintressen": "lokalintresse",
    "lokalintressena": "lokalintresse",
    "lokalintressenas": "lokalintresse",
    "lokalintressens": "lokalintresse",
    "lokalintresses": "lokalintresse",
    "lokalintresset": "lokalintresse",
    "lokalintressets": "lokalintresse",
    "lokaliserad": "lokalisera",
    "lokaliserade": "lokalisera",
    "lokaliserades": "lokalisera",
    "lokaliserads": "lokalisera",
    "lokaliserande": "lokalisera",
    "lokaliseranden": "lokaliserande",
    "lokaliserandena": "lokaliserande",
    "lokaliserandenas": "lokaliserande",
    "lokaliserandens": "lokaliserande",
    "lokaliserandes": "lokaliserande",
    "lokaliserandet": "lokaliserande",
    "lokaliserandets": "lokaliserande",
    "lokaliserar": "lokalisera",
    "lokaliseras": "lokalisera",
    "lokaliserat": "lokalisera",
    "lokaliserats": "lokalisera",
    "lokaliserbara": "lokaliserbar",
    "lokaliserbarare": "lokaliserbar",
    "lokaliserbarares": "lokaliserbar",
    "lokaliserbaras": "lokaliserbar",
    "lokaliserbarast": "lokaliserbar",
    "lokaliserbaraste": "lokaliserbar",
    "lokaliserbarastes": "lokaliserbar",
    "lokaliserbarasts": "lokaliserbar",
    "lokaliserbare": "lokaliserbar",
    "lokaliserbares": "lokaliserbar",
    "lokaliserbarheten": "lokaliserbarhet",
    "lokaliserbarhetens": "lokaliserbarhet",
    "lokaliserbarhets": "lokaliserbarhet",
    "lokaliserbars": "lokaliserbar",
    "lokaliserbart": "lokaliserbar",
    "lokaliserbarts": "lokaliserbar",
    "lokaliseringar": "lokalisering",
    "lokaliseringarna": "lokalisering",
    "lokaliseringarnas": "lokalisering",
    "lokaliseringars": "lokalisering",
    "lokaliseringen": "lokalisering",
    "lokaliseringens": "lokalisering",
    "lokaliserings": "lokalisering",
    "lokaliseringspolitiken": "lokaliseringspolitik",
    "lokaliseringspolitikens": "lokaliseringspolitik",
    "lokaliseringspolitiks": "lokaliseringspolitik",
    "lokaliseringspolitiska": "lokaliseringspolitisk",
    "lokaliseringspolitiskas": "lokaliseringspolitisk",
    "lokaliseringspolitiske": "lokaliseringspolitisk",
    "lokaliseringspolitiskes": "lokaliseringspolitisk",
    "lokaliseringspolitisks": "lokaliseringspolitisk",
    "lokaliseringspolitiskt": "lokaliseringspolitisk",
    "lokaliseringspolitiskts": "lokaliseringspolitisk",
    "lokaliseringsstöden": "lokaliseringsstöd",
    "lokaliseringsstödens": "lokaliseringsstöd",
    "lokaliseringsstödet": "lokaliseringsstöd",
    "lokaliseringsstödets": "lokaliseringsstöd",
    "lokaliseringsstöds": "lokaliseringsstöd",
    "lokaliteten": "lokalitet",
    "lokalitetens": "lokalitet",
    "lokaliteter": "lokalitet",
    "lokaliteterna": "lokalitet",
    "lokaliteternas": "lokalitet",
    "lokaliteters": "lokalitet",
    "lokalitets": "lokalitet",
    "lokalkontoren": "lokalkontor",
    "lokalkontorens": "lokalkontor",
    "lokalkontoret": "lokalkontor",
    "lokalkontorets": "lokalkontor",
    "lokalkontors": "lokalkontor",
    "lokalkännedomar": "lokalkännedom",
    "lokalkännedomarna": "lokalkännedom",
    "lokalkännedomarnas": "lokalkännedom",
    "lokalkännedomars": "lokalkännedom",
    "lokalkännedomen": "lokalkännedom",
    "lokalkännedomens": "lokalkännedom",
    "lokalkännedoms": "lokalkännedom",
    "lokalmässiga": "lokalmässig",
    "lokalmässigare": "lokalmässig",
    "lokalmässigares": "lokalmässig",
    "lokalmässigas": "lokalmässig",
    "lokalmässigast": "lokalmässig",
    "lokalmässigaste": "lokalmässig",
    "lokalmässigastes": "lokalmässig",
    "lokalmässigasts": "lokalmässig",
    "lokalmässige": "lokalmässig",
    "lokalmässiges": "lokalmässig",
    "lokalmässigs": "lokalmässig",
    "lokalmässigt": "lokalmässig",
    "lokalmässigts": "lokalmässig",
    "lokalombuden": "lokalombud",
    "lokalombudens": "lokalombud",
    "lokalombudet": "lokalombud",
    "lokalombudets": "lokalombud",
    "lokalombuds": "lokalombud",
    "lokalpatrioten": "lokalpatriot",
    "lokalpatriotens": "lokalpatriot",
    "lokalpatrioter": "lokalpatriot",
    "lokalpatrioterna": "lokalpatriot",
    "lokalpatrioternas": "lokalpatriot",
    "lokalpatrioters": "lokalpatriot",
    "lokalpatriots": "lokalpatriot",
    "lokalpolitiken": "lokalpolitik",
    "lokalpolitikens": "lokalpolitik",
    "lokalpolitikern": "lokalpolitiker",
    "lokalpolitikerna": "lokalpolitiker",
    "lokalpolitikernas": "lokalpolitiker",
    "lokalpolitikerns": "lokalpolitiker",
    "lokalpolitikers": "lokalpolitiker",
    "lokalpolitiks": "lokalpolitik",
    "lokalpolitiska": "lokalpolitisk",
    "lokalpolitiskas": "lokalpolitisk",
    "lokalpolitiske": "lokalpolitisk",
    "lokalpolitiskes": "lokalpolitisk",
    "lokalpolitisks": "lokalpolitisk",
    "lokalpolitiskt": "lokalpolitisk",
    "lokalpolitiskts": "lokalpolitisk",
    "lokalpressen": "lokalpress",
    "lokalpressens": "lokalpress",
    "lokalradion": "lokalradio",
    "lokalradions": "lokalradio",
    "lokalradios": "lokalradio",
    "lokalredaktören": "lokalredaktör",
    "lokalredaktörens": "lokalredaktör",
    "lokalredaktörer": "lokalredaktör",
    "lokalredaktörerna": "lokalredaktör",
    "lokalredaktörernas": "lokalredaktör",
    "lokalredaktörers": "lokalredaktör",
    "lokalredaktörn": "lokalredaktör",
    "lokalredaktörns": "lokalredaktör",
    "lokalredaktörs": "lokalredaktör",
    "lokals": "lokal",
    "lokalsamhällen": "lokalsamhälle",
    "lokalsamhällena": "lokalsamhälle",
    "lokalsamhällenas": "lokalsamhälle",
    "lokalsamhällens": "lokalsamhälle",
    "lokalsamhälles": "lokalsamhälle",
    "lokalsamhället": "lokalsamhälle",
    "lokalsamhällets": "lokalsamhälle",
    "lokalsamhälls": "lokalsamhälle",
    "lokalsamtalen": "lokalsamtal",
    "lokalsamtalens": "lokalsamtal",
    "lokalsamtalet": "lokalsamtal",
    "lokalsamtalets": "lokalsamtal",
    "lokalsamtals": "lokalsamtal",
    "lokalsinnes": "lokalsinne",
    "lokalsinnet": "lokalsinne",
    "lokalsinnets": "lokalsinne",
    "lokalt": "lokal",
    "lokaltelefonen": "lokaltelefon",
    "lokaltelefonens": "lokaltelefon",
    "lokaltelefoner": "lokaltelefon",
    "lokaltelefonerna": "lokaltelefon",
    "lokaltelefonernas": "lokaltelefon",
    "lokaltelefoners": "lokaltelefon",
    "lokaltelefons": "lokaltelefon",
    "lokaltiden": "lokaltid",
    "lokaltidens": "lokaltid",
    "lokaltider": "lokaltid",
    "lokaltiderna": "lokaltid",
    "lokaltidernas": "lokaltid",
    "lokaltiders": "lokaltid",
    "lokaltids": "lokaltid",
    "lokaltrafiken": "lokaltrafik",
    "lokaltrafikens": "lokaltrafik",
    "lokaltrafiks": "lokaltrafik",
    "lokalts": "lokal",
    "lokaltågen": "lokaltåg",
    "lokaltågens": "lokaltåg",
    "lokaltåget": "lokaltåg",
    "lokaltågets": "lokaltåg",
    "lokaltågs": "lokaltåg",
    "lokalvårdar": "lokalvårdare",
    "lokalvårdaren": "lokalvårdare",
    "lokalvårdarens": "lokalvårdare",
    "lokalvårdares": "lokalvårdare",
    "lokalvårdarna": "lokalvårdare",
    "lokalvårdarnas": "lokalvårdare",
    "lokalvården": "lokalvård",
    "lokalvårdens": "lokalvård",
    "lokalvårds": "lokalvård",
    "lokan": "loka",
    "lokans": "loka",
    "lokas": "loka",
    "lokativen": "lokativ",
    "lokativens": "lokativ",
    "lokativer": "lokativ",
    "lokativerna": "lokativ",
    "lokativernas": "lokativ",
    "lokativers": "lokativ",
    "lokativs": "lokativ",
    "lokatten": "lokatt",
    "lokattens": "lokatt",
    "lokatter": "lokatt",
    "lokatterna": "lokatt",
    "lokatternas": "lokatt",
    "lokatters": "lokatt",
    "lokatts": "lokatt",
    "loke": "loka",
    "loken": "lok",
    "lokens": "lok",
    "loket": "lok",
    "lokets": "lok",
    "lokförar": "lokförare",
    "lokföraren": "lokförare",
    "lokförarens": "lokförare",
    "lokförares": "lokförare",
    "lokförarna": "lokförare",
    "lokförarnas": "lokförare",
    "lokomobilen": "lokomobil",
    "lokomobilens": "lokomobil",
    "lokomobiler": "lokomobil",
    "lokomobilerna": "lokomobil",
    "lokomobilernas": "lokomobil",
    "lokomobilers": "lokomobil",
    "lokomobils": "lokomobil",
    "lokomotiven": "lokomotiv",
    "lokomotivens": "lokomotiv",
    "lokomotivet": "lokomotiv",
    "lokomotivets": "lokomotiv",
    "lokomotivs": "lokomotiv",
    "lokomotorer": "lokomotor",
    "lokomotorerna": "lokomotor",
    "lokomotorernas": "lokomotor",
    "lokomotorers": "lokomotor",
    "lokomotorn": "lokomotor",
    "lokomotorns": "lokomotor",
    "lokomotors": "lokomotor",
    "lokor": "loka",
    "lokorna": "loka",
    "lokornas": "loka",
    "lokors": "loka",
    "loks": "loka",
    "lokusen": "lokus",
    "lokusens": "lokus",
    "lokuset": "lokus",
    "lokusets": "lokus",
    "loll": "lolla",
    "lollan": "lolla",
    "lollans": "lolla",
    "lollas": "lolla",
    "lolle": "lolla",
    "lollor": "lolla",
    "lollorna": "lolla",
    "lollornas": "lolla",
    "lollors": "lolla",
    "lolls": "lolla",
    "lomade": "loma",
    "lomades": "loma",
    "lomande": "loma",
    "lomanden": "lomande",
    "lomandena": "lomande",
    "lomandenas": "lomande",
    "lomandens": "lomande",
    "lomandes": "lomande",
    "lomandet": "lomande",
    "lomandets": "lomande",
    "lomar": "loma",
    "lomas": "loma",
    "lomat": "loma",
    "lomats": "loma",
    "lomhörda": "lomhörd",
    "lomhördare": "lomhörd",
    "lomhördares": "lomhörd",
    "lomhördas": "lomhörd",
    "lomhördast": "lomhörd",
    "lomhördaste": "lomhörd",
    "lomhördastes": "lomhörd",
    "lomhördasts": "lomhörd",
    "lomhörde": "lomhörd",
    "lomhördes": "lomhörd",
    "lomhördheten": "lomhördhet",
    "lomhördhetens": "lomhördhet",
    "lomhördhets": "lomhördhet",
    "lomhörds": "lomhörd",
    "lomhört": "lomhörd",
    "lomhörts": "lomhörd",
    "lommade": "lomma",
    "lommades": "lomma",
    "lommande": "lomma",
    "lommanden": "lommande",
    "lommandena": "lommande",
    "lommandenas": "lommande",
    "lommandens": "lommande",
    "lommandes": "lommande",
    "lommandet": "lommande",
    "lommandets": "lommande",
    "lommar": "lomma",
    "lommarna": "lom",
    "lommarnas": "lom",
    "lommars": "lom",
    "lommas": "lomma",
    "lommat": "lomma",
    "lommats": "lomma",
    "lommen": "lomme",
    "lommens": "lomme",
    "lommes": "lomme",
    "loms": "lom",
    "lon": "lo",
    "longituden": "longitud",
    "longitudens": "longitud",
    "longituder": "longitud",
    "longituderna": "longitud",
    "longitudernas": "longitud",
    "longituders": "longitud",
    "longitudinala": "longitudinal",
    "longitudinalare": "longitudinal",
    "longitudinalares": "longitudinal",
    "longitudinalas": "longitudinal",
    "longitudinalast": "longitudinal",
    "longitudinalaste": "longitudinal",
    "longitudinalastes": "longitudinal",
    "longitudinalasts": "longitudinal",
    "longitudinale": "longitudinal",
    "longitudinales": "longitudinal",
    "longitudinals": "longitudinal",
    "longitudinalt": "longitudinal",
    "longitudinalts": "longitudinal",
    "longitudinella": "longitudinell",
    "longitudinellare": "longitudinell",
    "longitudinellares": "longitudinell",
    "longitudinellas": "longitudinell",
    "longitudinellast": "longitudinell",
    "longitudinellaste": "longitudinell",
    "longitudinellastes": "longitudinell",
    "longitudinellasts": "longitudinell",
    "longitudinelle": "longitudinell",
    "longitudinelles": "longitudinell",
    "longitudinells": "longitudinell",
    "longitudinellt": "longitudinell",
    "longitudinellts": "longitudinell",
    "longituds": "longitud",
    "longören": "longör",
    "longörens": "longör",
    "longörer": "longör",
    "longörerna": "longör",
    "longörernas": "longör",
    "longörers": "longör",
    "longörs": "longör",
    "lons": "lo",
    "lookar": "look",
    "lookarna": "look",
    "lookarnas": "look",
    "lookars": "look",
    "looken": "look",
    "lookens": "look",
    "looks": "look",
    "loopar": "loop",
    "looparna": "loop",
    "looparnas": "loop",
    "loopars": "loop",
    "loopen": "loop",
    "loopens": "loop",
    "loopingar": "looping",
    "loopingarna": "looping",
    "loopingarnas": "looping",
    "loopingars": "looping",
    "loopingen": "looping",
    "loopingens": "looping",
    "loopings": "looping",
    "loops": "loop",
    "lopp": "loppa",
    "loppad": "loppa",
    "loppade": "loppa",
    "loppades": "loppa",
    "loppads": "loppa",
    "loppan": "loppa",
    "loppande": "loppa",
    "loppanden": "loppande",
    "loppandena": "loppande",
    "loppandenas": "loppande",
    "loppandens": "loppande",
    "loppandes": "loppande",
    "loppandet": "loppande",
    "loppandets": "loppande",
    "loppans": "loppa",
    "loppar": "loppa",
    "loppas": "loppa",
    "loppat": "loppa",
    "loppats": "loppa",
    "loppcirkusar": "loppcirkus",
    "loppcirkusarna": "loppcirkus",
    "loppcirkusarnas": "loppcirkus",
    "loppcirkusars": "loppcirkus",
    "loppcirkusen": "loppcirkus",
    "loppcirkusens": "loppcirkus",
    "loppe": "loppa",
    "loppen": "lopp",
    "loppens": "lopp",
    "loppet": "lopp",
    "loppets": "lopp",
    "loppforskar": "loppforskare",
    "loppforskaren": "loppforskare",
    "loppforskarens": "loppforskare",
    "loppforskares": "loppforskare",
    "loppforskarna": "loppforskare",
    "loppforskarnas": "loppforskare",
    "loppisar": "loppis",
    "loppisarna": "loppis",
    "loppisarnas": "loppis",
    "loppisars": "loppis",
    "loppisen": "loppis",
    "loppisens": "loppis",
    "loppmarknaden": "loppmarknad",
    "loppmarknadens": "loppmarknad",
    "loppmarknader": "loppmarknad",
    "loppmarknaderna": "loppmarknad",
    "loppmarknadernas": "loppmarknad",
    "loppmarknaders": "loppmarknad",
    "loppmarknads": "loppmarknad",
    "loppor": "loppa",
    "lopporna": "loppa",
    "loppornas": "loppa",
    "loppors": "loppa",
    "lopps": "loppa",
    "loppspelen": "loppspel",
    "loppspelens": "loppspel",
    "loppspelet": "loppspel",
    "loppspelets": "loppspel",
    "loppspels": "loppspel",
    "loranen": "loran",
    "loranens": "loran",
    "lorans": "loran",
    "lorden": "lord",
    "lordens": "lord",
    "lorder": "lord",
    "lorderna": "lord",
    "lordernas": "lord",
    "lorders": "lord",
    "lordkanslerer": "lordkansler",
    "lordkanslererna": "lordkansler",
    "lordkanslerernas": "lordkansler",
    "lordkanslerers": "lordkansler",
    "lordkanslern": "lordkansler",
    "lordkanslerns": "lordkansler",
    "lordkanslers": "lordkansler",
    "lords": "lord",
    "lornjetten": "lornjett",
    "lornjettens": "lornjett",
    "lornjetter": "lornjett",
    "lornjetterna": "lornjett",
    "lornjetternas": "lornjett",
    "lornjetters": "lornjett",
    "lornjetts": "lornjett",
    "lortar": "lort",
    "lortarna": "lort",
    "lortarnas": "lort",
    "lortars": "lort",
    "lorten": "lort",
    "lortens": "lort",
    "lortiga": "lortig",
    "lortigare": "lortig",
    "lortigares": "lortig",
    "lortigas": "lortig",
    "lortigast": "lortig",
    "lortigaste": "lortig",
    "lortigastes": "lortig",
    "lortigasts": "lortig",
    "lortige": "lortig",
    "lortiges": "lortig",
    "lortigheten": "lortighet",
    "lortighetens": "lortighet",
    "lortighets": "lortighet",
    "lortigs": "lortig",
    "lortigt": "lortig",
    "lortigts": "lortig",
    "lorts": "lort",
    "losern": "loser",
    "loserns": "loser",
    "losers": "loser",
    "losersarna": "loser",
    "losersarnas": "loser",
    "losersen": "loser",
    "losersens": "loser",
    "loserstilar": "loserstil",
    "loserstilarna": "loserstil",
    "loserstilarnas": "loserstil",
    "loserstilars": "loserstil",
    "loserstilen": "loserstil",
    "loserstilens": "loserstil",
    "loserstils": "loserstil",
    "loservärldar": "loservärld",
    "loservärldarna": "loservärld",
    "loservärldarnas": "loservärld",
    "loservärldars": "loservärld",
    "loservärlden": "loservärld",
    "loservärldens": "loservärld",
    "loservärlds": "loservärld",
    "losk": "loska",
    "loskade": "loska",
    "loskades": "loska",
    "loskan": "loska",
    "loskande": "loska",
    "loskanden": "loskande",
    "loskandena": "loskande",
    "loskandenas": "loskande",
    "loskandens": "loskande",
    "loskandes": "loskande",
    "loskandet": "loskande",
    "loskandets": "loskande",
    "loskans": "loska",
    "loskar": "loska",
    "loskas": "loska",
    "loskat": "loska",
    "loskats": "loska",
    "loske": "loska",
    "loskor": "loska",
    "loskorna": "loska",
    "loskornas": "loska",
    "loskors": "loska",
    "loss": "lossa",
    "lossad": "lossa",
    "lossade": "lossa",
    "lossades": "lossa",
    "lossads": "lossa",
    "lossande": "lossa",
    "lossanden": "lossande",
    "lossandena": "lossande",
    "lossandenas": "lossande",
    "lossandens": "lossande",
    "lossandes": "lossande",
    "lossandet": "lossande",
    "lossandets": "lossande",
    "lossar": "lossa",
    "lossas": "lossa",
    "lossat": "lossa",
    "lossats": "lossa",
    "lossnade": "lossna",
    "lossnades": "lossna",
    "lossnande": "lossna",
    "lossnanden": "lossnande",
    "lossnandena": "lossnande",
    "lossnandenas": "lossnande",
    "lossnandens": "lossnande",
    "lossnandes": "lossnande",
    "lossnandet": "lossnande",
    "lossnandets": "lossnande",
    "lossnar": "lossna",
    "lossnas": "lossna",
    "lossnat": "lossna",
    "lossnats": "lossna",
    "lossningar": "lossning",
    "lossningarna": "lossning",
    "lossningarnas": "lossning",
    "lossningars": "lossning",
    "lossningen": "lossning",
    "lossningens": "lossning",
    "lossnings": "lossning",
    "lost": "losta",
    "lostan": "losta",
    "lostans": "losta",
    "lostas": "losta",
    "loste": "losta",
    "lostor": "losta",
    "lostorna": "losta",
    "lostornas": "losta",
    "lostors": "losta",
    "lots": "lotsa",
    "lotsad": "lotsa",
    "lotsade": "lotsa",
    "lotsades": "lotsa",
    "lotsads": "lotsa",
    "lotsande": "lotsa",
    "lotsanden": "lotsande",
    "lotsandena": "lotsande",
    "lotsandenas": "lotsande",
    "lotsandens": "lotsande",
    "lotsandes": "lotsande",
    "lotsandet": "lotsande",
    "lotsandets": "lotsande",
    "lotsar": "lotsa",
    "lotsarna": "lots",
    "lotsarnas": "lots",
    "lotsars": "lots",
    "lotsas": "lotsa",
    "lotsat": "lotsa",
    "lotsats": "lotsa",
    "lotsdistrikten": "lotsdistrikt",
    "lotsdistriktens": "lotsdistrikt",
    "lotsdistriktet": "lotsdistrikt",
    "lotsdistriktets": "lotsdistrikt",
    "lotsdistrikts": "lotsdistrikt",
    "lotsen": "lots",
    "lotsens": "lots",
    "lotshjälpar": "lotshjälp",
    "lotshjälparna": "lotshjälp",
    "lotshjälparnas": "lotshjälp",
    "lotshjälpars": "lotshjälp",
    "lotshjälpen": "lotshjälp",
    "lotshjälpens": "lotshjälp",
    "lotshjälps": "lotshjälp",
    "lotsleden": "lotsled",
    "lotsledens": "lotsled",
    "lotsleder": "lotsled",
    "lotslederna": "lotsled",
    "lotsledernas": "lotsled",
    "lotsleders": "lotsled",
    "lotsleds": "lotsled",
    "lotsningar": "lotsning",
    "lotsningarna": "lotsning",
    "lotsningarnas": "lotsning",
    "lotsningars": "lotsning",
    "lotsningen": "lotsning",
    "lotsningens": "lotsning",
    "lotsnings": "lotsning",
    "lotsplatsen": "lotsplats",
    "lotsplatsens": "lotsplats",
    "lotsplatser": "lotsplats",
    "lotsplatserna": "lotsplats",
    "lotsplatsernas": "lotsplats",
    "lotsplatsers": "lotsplats",
    "lotsplikten": "lotsplikt",
    "lotspliktens": "lotsplikt",
    "lotsplikts": "lotsplikt",
    "lotssignalen": "lotssignal",
    "lotssignalens": "lotssignal",
    "lotssignaler": "lotssignal",
    "lotssignalerna": "lotssignal",
    "lotssignalernas": "lotssignal",
    "lotssignalers": "lotssignal",
    "lotssignals": "lotssignal",
    "lott": "lotta",
    "lottad": "lotta",
    "lottade": "lottad",
    "lottades": "lottad",
    "lottads": "lottad",
    "lottakåren": "lottakår",
    "lottakårens": "lottakår",
    "lottakårer": "lottakår",
    "lottakårerna": "lottakår",
    "lottakårernas": "lottakår",
    "lottakårers": "lottakår",
    "lottakårs": "lottakår",
    "lottan": "lotta",
    "lottande": "lotta",
    "lottanden": "lottande",
    "lottandena": "lottande",
    "lottandenas": "lottande",
    "lottandens": "lottande",
    "lottandes": "lottande",
    "lottandet": "lottande",
    "lottandets": "lottande",
    "lottar": "lotta",
    "lottarörelsen": "lottarörelse",
    "lottarörelsens": "lottarörelse",
    "lottarörelser": "lottarörelse",
    "lottarörelserna": "lottarörelse",
    "lottarörelsernas": "lottarörelse",
    "lottarörelsers": "lottarörelse",
    "lottarörelses": "lottarörelse",
    "lottas": "lotta",
    "lottat": "lottad",
    "lottats": "lottad",
    "lottdragningar": "lottdragning",
    "lottdragningarna": "lottdragning",
    "lottdragningarnas": "lottdragning",
    "lottdragningars": "lottdragning",
    "lottdragningen": "lottdragning",
    "lottdragningens": "lottdragning",
    "lottdragnings": "lottdragning",
    "lotte": "lotta",
    "lotten": "lott",
    "lottens": "lott",
    "lotter": "lott",
    "lotterier": "lotteri",
    "lotterierna": "lotteri",
    "lotteriernas": "lotteri",
    "lotteriers": "lotteri",
    "lotteriet": "lotteri",
    "lotteriets": "lotteri",
    "lotteris": "lotteri",
    "lotterit": "lotteri",
    "lotterits": "lotteri",
    "lotterivinnar": "lotterivinnare",
    "lotterivinnaren": "lotterivinnare",
    "lotterivinnarens": "lotterivinnare",
    "lotterivinnares": "lotterivinnare",
    "lotterivinnarna": "lotterivinnare",
    "lotterivinnarnas": "lotterivinnare",
    "lotterna": "lott",
    "lotternas": "lott",
    "lotters": "lott",
    "lottlösa": "lottlös",
    "lottlösare": "lottlös",
    "lottlösares": "lottlös",
    "lottlösas": "lottlös",
    "lottlösast": "lottlös",
    "lottlösaste": "lottlös",
    "lottlösastes": "lottlös",
    "lottlösasts": "lottlös",
    "lottlöse": "lottlös",
    "lottlöses": "lottlös",
    "lottlösheten": "lottlöshet",
    "lottlöshetens": "lottlöshet",
    "lottlöshets": "lottlöshet",
    "lottlöst": "lottlös",
    "lottlösts": "lottlös",
    "lottor": "lotta",
    "lottornas": "lotta",
    "lottos": "lotto",
    "lottot": "lotto",
    "lottots": "lotto",
    "lottovinsten": "lottovinst",
    "lottovinstens": "lottovinst",
    "lottovinster": "lottovinst",
    "lottovinsterna": "lottovinst",
    "lottovinsternas": "lottovinst",
    "lottovinsters": "lottovinst",
    "lottovinsts": "lottovinst",
    "lotts": "lotta",
    "lottsedeln": "lottsedel",
    "lottsedelns": "lottsedel",
    "lottsedels": "lottsedel",
    "lottsedlar": "lottsedel",
    "lottsedlarna": "lottsedel",
    "lottsedlarnas": "lottsedel",
    "lottsedlars": "lottsedel",
    "lotusar": "lotus",
    "lotusarna": "lotus",
    "lotusarnas": "lotus",
    "lotusars": "lotus",
    "lotusen": "lotus",
    "lotusens": "lotus",
    "lotusställningar": "lotusställning",
    "lotusställningarna": "lotusställning",
    "lotusställningarnas": "lotusställning",
    "lotusställningars": "lotusställning",
    "lotusställningen": "lotusställning",
    "lotusställningens": "lotusställning",
    "lotusställnings": "lotusställning",
    "lov": "love",
    "lovad": "lova",
    "lovade": "lova",
    "lovades": "lova",
    "lovads": "lova",
    "lovande": "lova",
    "lovanden": "lovande",
    "lovandena": "lovande",
    "lovandenas": "lovande",
    "lovandens": "lovande",
    "lovandes": "lovande",
    "lovandet": "lovande",
    "lovandets": "lovande",
    "lovar": "love",
    "lovarna": "love",
    "lovarnas": "love",
    "lovars": "love",
    "lovarts": "lovart",
    "lovas": "lova",
    "lovat": "lova",
    "lovats": "lova",
    "loven": "love",
    "lovens": "love",
    "loves": "love",
    "lovet": "lov",
    "lovets": "lov",
    "lovgiriga": "lovgirig",
    "lovgirigare": "lovgirig",
    "lovgirigares": "lovgirig",
    "lovgirigas": "lovgirig",
    "lovgirigast": "lovgirig",
    "lovgirigaste": "lovgirig",
    "lovgirigastes": "lovgirig",
    "lovgirigasts": "lovgirig",
    "lovgirige": "lovgirig",
    "lovgiriges": "lovgirig",
    "lovgirigheten": "lovgirighet",
    "lovgirighetens": "lovgirighet",
    "lovgirighets": "lovgirighet",
    "lovgirigs": "lovgirig",
    "lovgirigt": "lovgirig",
    "lovgirigts": "lovgirig",
    "lovliga": "lovlig",
    "lovligare": "lovlig",
    "lovligares": "lovlig",
    "lovligas": "lovlig",
    "lovligast": "lovlig",
    "lovligaste": "lovlig",
    "lovligastes": "lovlig",
    "lovligasts": "lovlig",
    "lovlige": "lovlig",
    "lovliges": "lovlig",
    "lovligheten": "lovlighet",
    "lovlighetens": "lovlighet",
    "lovlighets": "lovlighet",
    "lovligs": "lovlig",
    "lovligt": "lovlig",
    "lovligts": "lovlig",
    "lovord": "lovorda",
    "lovordad": "lovorda",
    "lovordade": "lovorda",
    "lovordades": "lovorda",
    "lovordads": "lovorda",
    "lovordande": "lovorda",
    "lovordanden": "lovordande",
    "lovordandena": "lovordande",
    "lovordandenas": "lovordande",
    "lovordandens": "lovordande",
    "lovordandes": "lovordande",
    "lovordandet": "lovordande",
    "lovordandets": "lovordande",
    "lovordar": "lovorda",
    "lovordas": "lovorda",
    "lovordat": "lovorda",
    "lovordats": "lovorda",
    "lovorden": "lovord",
    "lovordens": "lovord",
    "lovordet": "lovord",
    "lovordets": "lovord",
    "lovords": "lovord",
    "lovpris": "lovprisa",
    "lovprisad": "lovprisa",
    "lovprisade": "lovprisa",
    "lovprisades": "lovprisa",
    "lovprisads": "lovprisa",
    "lovprisande": "lovprisa",
    "lovprisanden": "lovprisande",
    "lovprisandena": "lovprisande",
    "lovprisandenas": "lovprisande",
    "lovprisandens": "lovprisande",
    "lovprisandes": "lovprisande",
    "lovprisandet": "lovprisande",
    "lovprisandets": "lovprisande",
    "lovprisar": "lovprisa",
    "lovprisas": "lovprisa",
    "lovprisat": "lovprisa",
    "lovprisats": "lovprisa",
    "lovpsalmen": "lovpsalm",
    "lovpsalmens": "lovpsalm",
    "lovpsalmer": "lovpsalm",
    "lovpsalmerna": "lovpsalm",
    "lovpsalmernas": "lovpsalm",
    "lovpsalmers": "lovpsalm",
    "lovpsalms": "lovpsalm",
    "lovs": "love",
    "lovsjung": "lovsjunga",
    "lovsjungande": "lovsjunga",
    "lovsjunganden": "lovsjungande",
    "lovsjungandena": "lovsjungande",
    "lovsjungandenas": "lovsjungande",
    "lovsjungandens": "lovsjungande",
    "lovsjungandes": "lovsjungande",
    "lovsjungandet": "lovsjungande",
    "lovsjungandets": "lovsjungande",
    "lovsjungas": "lovsjunga",
    "lovsjunge": "lovsjunga",
    "lovsjungen": "lovsjunga",
    "lovsjungens": "lovsjunga",
    "lovsjunger": "lovsjunga",
    "lovsjunges": "lovsjunga",
    "lovsjunget": "lovsjunga",
    "lovsjungets": "lovsjunga",
    "lovsjungit": "lovsjunga",
    "lovsjungits": "lovsjunga",
    "lovsjungna": "lovsjunga",
    "lovsjungnas": "lovsjunga",
    "lovsjungne": "lovsjunga",
    "lovsjungnes": "lovsjunga",
    "lovsjungs": "lovsjunga",
    "lovsjöng": "lovsjunga",
    "lovsjönge": "lovsjunga",
    "lovsjönges": "lovsjunga",
    "lovsjöngs": "lovsjunga",
    "lovsången": "lovsång",
    "lovsångens": "lovsång",
    "lovsånger": "lovsång",
    "lovsångerna": "lovsång",
    "lovsångernas": "lovsång",
    "lovsångers": "lovsång",
    "lovsångs": "lovsång",
    "lovtalen": "lovtal",
    "lovtalens": "lovtal",
    "lovtalet": "lovtal",
    "lovtalets": "lovtal",
    "lovtals": "lovtal",
    "lovvärda": "lovvärd",
    "lovvärdare": "lovvärd",
    "lovvärdares": "lovvärd",
    "lovvärdas": "lovvärd",
    "lovvärdast": "lovvärd",
    "lovvärdaste": "lovvärd",
    "lovvärdastes": "lovvärd",
    "lovvärdasts": "lovvärd",
    "lovvärde": "lovvärd",
    "lovvärdes": "lovvärd",
    "lovvärdheten": "lovvärdhet",
    "lovvärdhetens": "lovvärdhet",
    "lovvärdhets": "lovvärdhet",
    "lovvärds": "lovvärd",
    "lovvärt": "lovvärd",
    "lovvärts": "lovvärd",
    "loxodromen": "loxodrom",
    "loxodromens": "loxodrom",
    "loxodromer": "loxodrom",
    "loxodromerna": "loxodrom",
    "loxodromernas": "loxodrom",
    "loxodromers": "loxodrom",
    "loxodroms": "loxodrom",
    "ls": "l",
    "lubb": "lubba",
    "lubbade": "lubba",
    "lubbades": "lubba",
    "lubbande": "lubba",
    "lubbanden": "lubbande",
    "lubbandena": "lubbande",
    "lubbandenas": "lubbande",
    "lubbandens": "lubbande",
    "lubbandes": "lubbande",
    "lubbandet": "lubbande",
    "lubbandets": "lubbande",
    "lubbar": "lubba",
    "lubbarna": "lubb",
    "lubbarnas": "lubb",
    "lubbars": "lubb",
    "lubbas": "lubba",
    "lubbat": "lubba",
    "lubbats": "lubba",
    "lubben": "lubb",
    "lubbens": "lubb",
    "lubbs": "lubb",
    "lubrikatorer": "lubrikator",
    "lubrikatorerna": "lubrikator",
    "lubrikatorernas": "lubrikator",
    "lubrikatorers": "lubrikator",
    "lubrikatorn": "lubrikator",
    "lubrikatorns": "lubrikator",
    "lubrikators": "lubrikator",
    "luciafesten": "luciafest",
    "luciafestens": "luciafest",
    "luciafester": "luciafest",
    "luciafesterna": "luciafest",
    "luciafesternas": "luciafest",
    "luciafesters": "luciafest",
    "luciafests": "luciafest",
    "luciakransar": "luciakrans",
    "luciakransarna": "luciakrans",
    "luciakransarnas": "luciakrans",
    "luciakransars": "luciakrans",
    "luciakransen": "luciakrans",
    "luciakransens": "luciakrans",
    "luciakronan": "luciakrona",
    "luciakronans": "luciakrona",
    "luciakronas": "luciakrona",
    "luciakrone": "luciakrona",
    "luciakronor": "luciakrona",
    "luciakronorna": "luciakrona",
    "luciakronornas": "luciakrona",
    "luciakronors": "luciakrona",
    "luciamorgnar": "luciamorgon",
    "luciamorgnarna": "luciamorgon",
    "luciamorgnarnas": "luciamorgon",
    "luciamorgnars": "luciamorgon",
    "luciamorgonen": "luciamorgon",
    "luciamorgonens": "luciamorgon",
    "luciamorgons": "luciamorgon",
    "luciamornar": "luciamorgon",
    "luciamornarna": "luciamorgon",
    "luciamornarnas": "luciamorgon",
    "luciamornars": "luciamorgon",
    "lucian": "lucia",
    "lucians": "lucia",
    "lucias": "lucia",
    "luciasången": "luciasång",
    "luciasångens": "luciasång",
    "luciasånger": "luciasång",
    "luciasångerna": "luciasång",
    "luciasångernas": "luciasång",
    "luciasångers": "luciasång",
    "luciasångs": "luciasång",
    "luciatågen": "luciatåg",
    "luciatågens": "luciatåg",
    "luciatåget": "luciatåg",
    "luciatågets": "luciatåg",
    "luciatågs": "luciatåg",
    "lucior": "lucia",
    "luciorna": "lucia",
    "luciornas": "lucia",
    "luciors": "lucia",
    "luck": "lucka",
    "luckan": "lucka",
    "luckans": "lucka",
    "luckas": "lucka",
    "lucke": "lucka",
    "lucker": "luckra",
    "luckerheten": "luckerhet",
    "luckerhetens": "luckerhet",
    "luckerhets": "luckerhet",
    "luckers": "lucker",
    "luckert": "lucker",
    "luckerts": "lucker",
    "luckor": "lucka",
    "luckorna": "lucka",
    "luckornas": "lucka",
    "luckors": "lucka",
    "luckra": "lucker",
    "luckrad": "luckra",
    "luckrade": "luckra",
    "luckrades": "luckra",
    "luckrads": "luckra",
    "luckrande": "luckra",
    "luckranden": "luckrande",
    "luckrandena": "luckrande",
    "luckrandenas": "luckrande",
    "luckrandens": "luckrande",
    "luckrandes": "luckrande",
    "luckrandet": "luckrande",
    "luckrandets": "luckrande",
    "luckrar": "luckra",
    "luckrare": "lucker",
    "luckrares": "lucker",
    "luckras": "luckra",
    "luckrast": "lucker",
    "luckraste": "lucker",
    "luckrastes": "lucker",
    "luckrasts": "lucker",
    "luckrat": "luckra",
    "luckrats": "luckra",
    "luckre": "lucker",
    "luckres": "lucker",
    "lucks": "lucka",
    "luddade": "ludda",
    "luddades": "ludda",
    "luddande": "ludda",
    "luddanden": "luddande",
    "luddandena": "luddande",
    "luddandenas": "luddande",
    "luddandens": "luddande",
    "luddandes": "luddande",
    "luddandet": "luddande",
    "luddandets": "luddande",
    "luddar": "ludda",
    "luddas": "ludda",
    "luddat": "ludda",
    "luddats": "ludda",
    "luddbråken": "luddbråk",
    "luddbråkens": "luddbråk",
    "luddbråket": "luddbråk",
    "luddbråkets": "luddbråk",
    "luddbråks": "luddbråk",
    "ludden": "ludd",
    "luddens": "ludd",
    "luddet": "ludd",
    "luddets": "ludd",
    "luddfria": "luddfri",
    "luddfriare": "luddfri",
    "luddfriares": "luddfri",
    "luddfrias": "luddfri",
    "luddfriast": "luddfri",
    "luddfriaste": "luddfri",
    "luddfriastes": "luddfri",
    "luddfriasts": "luddfri",
    "luddfrie": "luddfri",
    "luddfries": "luddfri",
    "luddfris": "luddfri",
    "luddfritt": "luddfri",
    "luddfritts": "luddfri",
    "luddiga": "luddig",
    "luddigare": "luddig",
    "luddigares": "luddig",
    "luddigas": "luddig",
    "luddigast": "luddig",
    "luddigaste": "luddig",
    "luddigastes": "luddig",
    "luddigasts": "luddig",
    "luddige": "luddig",
    "luddiges": "luddig",
    "luddigheten": "luddighet",
    "luddighetens": "luddighet",
    "luddigheter": "luddighet",
    "luddigheterna": "luddighet",
    "luddigheternas": "luddighet",
    "luddigheters": "luddighet",
    "luddighets": "luddighet",
    "luddigs": "luddig",
    "luddigt": "luddig",
    "luddigts": "luddig",
    "ludds": "ludd",
    "ludenheten": "ludenhet",
    "ludenhetens": "ludenhet",
    "ludenhets": "ludenhet",
    "ludens": "luden",
    "luderna": "luder",
    "ludernas": "luder",
    "luders": "luder",
    "ludet": "luden",
    "ludets": "luden",
    "ludna": "luden",
    "ludnare": "luden",
    "ludnares": "luden",
    "ludnas": "luden",
    "ludnast": "luden",
    "ludnaste": "luden",
    "ludnastes": "luden",
    "ludnasts": "luden",
    "ludne": "luden",
    "ludnes": "luden",
    "ludren": "luder",
    "ludrens": "luder",
    "ludret": "luder",
    "ludrets": "luder",
    "luetiska": "luetisk",
    "luetiskare": "luetisk",
    "luetiskares": "luetisk",
    "luetiskas": "luetisk",
    "luetiskast": "luetisk",
    "luetiskaste": "luetisk",
    "luetiskastes": "luetisk",
    "luetiskasts": "luetisk",
    "luetiske": "luetisk",
    "luetiskes": "luetisk",
    "luetisks": "luetisk",
    "luetiskt": "luetisk",
    "luetiskts": "luetisk",
    "luffad": "luffa",
    "luffade": "luffa",
    "luffades": "luffa",
    "luffads": "luffa",
    "luffande": "luffa",
    "luffanden": "luffande",
    "luffandena": "luffande",
    "luffandenas": "luffande",
    "luffandens": "luffande",
    "luffandes": "luffande",
    "luffandet": "luffande",
    "luffandets": "luffande",
    "luffar": "luffare",
    "luffaransikten": "luffaransikte",
    "luffaransiktena": "luffaransikte",
    "luffaransiktenas": "luffaransikte",
    "luffaransiktens": "luffaransikte",
    "luffaransiktes": "luffaransikte",
    "luffaransiktet": "luffaransikte",
    "luffaransiktets": "luffaransikte",
    "luffaransikts": "luffaransikte",
    "luffaren": "luffare",
    "luffarens": "luffare",
    "luffares": "luffare",
    "luffarna": "luffare",
    "luffarnas": "luffare",
    "luffarschacket": "luffarschack",
    "luffarschackets": "luffarschack",
    "luffarschacks": "luffarschack",
    "luffas": "luffa",
    "luffat": "luffa",
    "luffats": "luffa",
    "luffen": "luff",
    "luffens": "luff",
    "luffs": "luff",
    "lufs": "lufsa",
    "lufsade": "lufsa",
    "lufsades": "lufsa",
    "lufsande": "lufsa",
    "lufsanden": "lufsande",
    "lufsandena": "lufsande",
    "lufsandenas": "lufsande",
    "lufsandens": "lufsande",
    "lufsandes": "lufsande",
    "lufsandet": "lufsande",
    "lufsandets": "lufsande",
    "lufsar": "lufsa",
    "lufsas": "lufsa",
    "lufsat": "lufsa",
    "lufsats": "lufsa",
    "lufsiga": "lufsig",
    "lufsigare": "lufsig",
    "lufsigares": "lufsig",
    "lufsigas": "lufsig",
    "lufsigast": "lufsig",
    "lufsigaste": "lufsig",
    "lufsigastes": "lufsig",
    "lufsigasts": "lufsig",
    "lufsige": "lufsig",
    "lufsiges": "lufsig",
    "lufsigheten": "lufsighet",
    "lufsighetens": "lufsighet",
    "lufsighets": "lufsighet",
    "lufsigs": "lufsig",
    "lufsigt": "lufsig",
    "lufsigts": "lufsig",
    "luft": "lufta",
    "luftad": "lufta",
    "luftade": "lufta",
    "luftades": "lufta",
    "luftads": "lufta",
    "luftaffären": "luftaffär",
    "luftaffärens": "luftaffär",
    "luftaffärer": "luftaffär",
    "luftaffärerna": "luftaffär",
    "luftaffärernas": "luftaffär",
    "luftaffärers": "luftaffär",
    "luftaffärs": "luftaffär",
    "luftakrobaten": "luftakrobat",
    "luftakrobatens": "luftakrobat",
    "luftakrobater": "luftakrobat",
    "luftakrobaterna": "luftakrobat",
    "luftakrobaternas": "luftakrobat",
    "luftakrobaters": "luftakrobat",
    "luftakrobats": "luftakrobat",
    "luftandar": "luftande",
    "luftandarna": "luftande",
    "luftandarnas": "luftande",
    "luftandars": "luftande",
    "luftande": "lufta",
    "luftanden": "luftande",
    "luftandena": "luftande",
    "luftandenas": "luftande",
    "luftandens": "luftande",
    "luftandes": "luftande",
    "luftandet": "luftande",
    "luftandets": "luftande",
    "luftanfallen": "luftanfall",
    "luftanfallens": "luftanfall",
    "luftanfallet": "luftanfall",
    "luftanfallets": "luftanfall",
    "luftanfalls": "luftanfall",
    "luftar": "lufta",
    "luftas": "lufta",
    "luftat": "lufta",
    "luftats": "lufta",
    "luftattacken": "luftattack",
    "luftattackens": "luftattack",
    "luftattacker": "luftattack",
    "luftattackerna": "luftattack",
    "luftattackernas": "luftattack",
    "luftattackers": "luftattack",
    "luftattacks": "luftattack",
    "luftballongen": "luftballong",
    "luftballongens": "luftballong",
    "luftballonger": "luftballong",
    "luftballongerna": "luftballong",
    "luftballongernas": "luftballong",
    "luftballongers": "luftballong",
    "luftballongs": "luftballong",
    "luftbevakningar": "luftbevakning",
    "luftbevakningarna": "luftbevakning",
    "luftbevakningarnas": "luftbevakning",
    "luftbevakningars": "luftbevakning",
    "luftbevakningen": "luftbevakning",
    "luftbevakningens": "luftbevakning",
    "luftbevaknings": "luftbevakning",
    "luftbollar": "luftboll",
    "luftbollarna": "luftboll",
    "luftbollarnas": "luftboll",
    "luftbollars": "luftboll",
    "luftbollen": "luftboll",
    "luftbollens": "luftboll",
    "luftbolls": "luftboll",
    "luftbroar": "luftbro",
    "luftbroarna": "luftbro",
    "luftbroarnas": "luftbro",
    "luftbroars": "luftbro",
    "luftbron": "luftbro",
    "luftbrons": "luftbro",
    "luftbros": "luftbro",
    "luftbubbel": "luftbubbla",
    "luftbubblan": "luftbubbla",
    "luftbubblans": "luftbubbla",
    "luftbubblas": "luftbubbla",
    "luftbubble": "luftbubbla",
    "luftbubblor": "luftbubbla",
    "luftbubblorna": "luftbubbla",
    "luftbubblornas": "luftbubbla",
    "luftbubblors": "luftbubbla",
    "luftburens": "luftburen",
    "luftburet": "luftburen",
    "luftburets": "luftburen",
    "luftburna": "luftburen",
    "luftburnare": "luftburen",
    "luftburnares": "luftburen",
    "luftburnas": "luftburen",
    "luftburnast": "luftburen",
    "luftburnaste": "luftburen",
    "luftburnastes": "luftburen",
    "luftburnasts": "luftburen",
    "luftburne": "luftburen",
    "luftburnes": "luftburen",
    "luftböss": "luftbössa",
    "luftbössan": "luftbössa",
    "luftbössans": "luftbössa",
    "luftbössas": "luftbössa",
    "luftbösse": "luftbössa",
    "luftbössor": "luftbössa",
    "luftbössorna": "luftbössa",
    "luftbössornas": "luftbössa",
    "luftbössors": "luftbössa",
    "luftdragen": "luftdrag",
    "luftdragens": "luftdrag",
    "luftdraget": "luftdrag",
    "luftdragets": "luftdrag",
    "luftdrags": "luftdrag",
    "luftembolien": "luftemboli",
    "luftemboliens": "luftemboli",
    "luftembolier": "luftemboli",
    "luftembolierna": "luftemboli",
    "luftemboliernas": "luftemboli",
    "luftemboliers": "luftemboli",
    "luftembolin": "luftemboli",
    "luftembolins": "luftemboli",
    "luftembolis": "luftemboli",
    "luften": "luft",
    "luftens": "luft",
    "lufter": "luft",
    "lufterna": "luft",
    "lufternas": "luft",
    "lufters": "luft",
    "luftfarkosten": "luftfarkost",
    "luftfarkostens": "luftfarkost",
    "luftfarkoster": "luftfarkost",
    "luftfarkosterna": "luftfarkost",
    "luftfarkosternas": "luftfarkost",
    "luftfarkosters": "luftfarkost",
    "luftfarkosts": "luftfarkost",
    "luftfarten": "luftfart",
    "luftfartens": "luftfart",
    "luftfarts": "luftfart",
    "luftfartsmyndigheten": "luftfartsmyndighet",
    "luftfartsmyndighetens": "luftfartsmyndighet",
    "luftfartsmyndigheter": "luftfartsmyndighet",
    "luftfartsmyndigheterna": "luftfartsmyndighet",
    "luftfartsmyndigheternas": "luftfartsmyndighet",
    "luftfartsmyndigheters": "luftfartsmyndighet",
    "luftfartsmyndighets": "luftfartsmyndighet",
    "luftfartygen": "luftfartyg",
    "luftfartygens": "luftfartyg",
    "luftfartyget": "luftfartyg",
    "luftfartygets": "luftfartyg",
    "luftfartygs": "luftfartyg",
    "luftfilterna": "luftfilter",
    "luftfilternas": "luftfilter",
    "luftfilters": "luftfilter",
    "luftfiltren": "luftfilter",
    "luftfiltrens": "luftfilter",
    "luftfiltret": "luftfilter",
    "luftfiltrets": "luftfilter",
    "luftfjädringar": "luftfjädring",
    "luftfjädringarna": "luftfjädring",
    "luftfjädringarnas": "luftfjädring",
    "luftfjädringars": "luftfjädring",
    "luftfjädringen": "luftfjädring",
    "luftfjädringens": "luftfjädring",
    "luftfjädrings": "luftfjädring",
    "luftflott": "luftflotta",
    "luftflottan": "luftflotta",
    "luftflottans": "luftflotta",
    "luftflottas": "luftflotta",
    "luftflotte": "luftflotta",
    "luftflottor": "luftflotta",
    "luftflottorna": "luftflotta",
    "luftflottornas": "luftflotta",
    "luftflottors": "luftflotta",
    "luftflotts": "luftflotta",
    "luftfuktar": "luftfuktare",
    "luftfuktaren": "luftfuktare",
    "luftfuktarens": "luftfuktare",
    "luftfuktares": "luftfuktare",
    "luftfuktarna": "luftfuktare",
    "luftfuktarnas": "luftfuktare",
    "luftfuktigheten": "luftfuktighet",
    "luftfuktighetens": "luftfuktighet",
    "luftfuktigheter": "luftfuktighet",
    "luftfuktigheterna": "luftfuktighet",
    "luftfuktigheternas": "luftfuktighet",
    "luftfuktigheters": "luftfuktighet",
    "luftfuktighets": "luftfuktighet",
    "luftfärden": "luftfärd",
    "luftfärdens": "luftfärd",
    "luftfärder": "luftfärd",
    "luftfärderna": "luftfärd",
    "luftfärdernas": "luftfärd",
    "luftfärders": "luftfärd",
    "luftfärds": "luftfärd",
    "luftföroreningar": "luftförorening",
    "luftföroreningarna": "luftförorening",
    "luftföroreningarnas": "luftförorening",
    "luftföroreningars": "luftförorening",
    "luftföroreningen": "luftförorening",
    "luftföroreningens": "luftförorening",
    "luftförorenings": "luftförorening",
    "luftförsvaret": "luftförsvar",
    "luftförsvarets": "luftförsvar",
    "luftförsvars": "luftförsvar",
    "luftgapen": "luftgap",
    "luftgapens": "luftgap",
    "luftgapet": "luftgap",
    "luftgapets": "luftgap",
    "luftgaps": "luftgap",
    "luftgevären": "luftgevär",
    "luftgevärens": "luftgevär",
    "luftgeväret": "luftgevär",
    "luftgevärets": "luftgevär",
    "luftgevärs": "luftgevär",
    "luftgevärsskjutningar": "luftgevärsskjutning",
    "luftgevärsskjutningarna": "luftgevärsskjutning",
    "luftgevärsskjutningarnas": "luftgevärsskjutning",
    "luftgevärsskjutningars": "luftgevärsskjutning",
    "luftgevärsskjutningen": "luftgevärsskjutning",
    "luftgevärsskjutningens": "luftgevärsskjutning",
    "luftgevärsskjutnings": "luftgevärsskjutning",
    "luftgropar": "luftgrop",
    "luftgroparna": "luftgrop",
    "luftgroparnas": "luftgrop",
    "luftgropars": "luftgrop",
    "luftgropen": "luftgrop",
    "luftgropens": "luftgrop",
    "luftgrops": "luftgrop",
    "luftgummihjulen": "luftgummihjul",
    "luftgummihjulens": "luftgummihjul",
    "luftgummihjulet": "luftgummihjul",
    "luftgummihjulets": "luftgummihjul",
    "luftgummihjuls": "luftgummihjul",
    "lufthaven": "lufthav",
    "lufthavens": "lufthav",
    "lufthavet": "lufthav",
    "lufthavets": "lufthav",
    "lufthavs": "lufthav",
    "luftherraväldes": "luftherravälde",
    "luftherraväldet": "luftherravälde",
    "luftherraväldets": "luftherravälde",
    "luftiga": "luftig",
    "luftigare": "luftig",
    "luftigares": "luftig",
    "luftigas": "luftig",
    "luftigast": "luftig",
    "luftigaste": "luftig",
    "luftigastes": "luftig",
    "luftigasts": "luftig",
    "luftige": "luftig",
    "luftiges": "luftig",
    "luftigheten": "luftighet",
    "luftighetens": "luftighet",
    "luftigheter": "luftighet",
    "luftigheterna": "luftighet",
    "luftigheternas": "luftighet",
    "luftigheters": "luftighet",
    "luftighets": "luftighet",
    "luftigs": "luftig",
    "luftigt": "luftig",
    "luftigts": "luftig",
    "luftkompressorer": "luftkompressor",
    "luftkompressorerna": "luftkompressor",
    "luftkompressorernas": "luftkompressor",
    "luftkompressorers": "luftkompressor",
    "luftkompressorn": "luftkompressor",
    "luftkompressorns": "luftkompressor",
    "luftkompressors": "luftkompressor",
    "luftkonditionerade": "luftkonditionerad",
    "luftkonditionerades": "luftkonditionerad",
    "luftkonditionerads": "luftkonditionerad",
    "luftkonditionerat": "luftkonditionerad",
    "luftkonditionerats": "luftkonditionerad",
    "luftkonditioneringar": "luftkonditionering",
    "luftkonditioneringarna": "luftkonditionering",
    "luftkonditioneringarnas": "luftkonditionering",
    "luftkonditioneringars": "luftkonditionering",
    "luftkonditioneringen": "luftkonditionering",
    "luftkonditioneringens": "luftkonditionering",
    "luftkonditionerings": "luftkonditionering",
    "luftkuben": "luftkub",
    "luftkubens": "luftkub",
    "luftkuber": "luftkub",
    "luftkuberna": "luftkub",
    "luftkubernas": "luftkub",
    "luftkubers": "luftkub",
    "luftkubs": "luftkub",
    "luftkuddar": "luftkudde",
    "luftkuddarna": "luftkudde",
    "luftkuddarnas": "luftkudde",
    "luftkuddars": "luftkudde",
    "luftkuddefarkosten": "luftkuddefarkost",
    "luftkuddefarkostens": "luftkuddefarkost",
    "luftkuddefarkoster": "luftkuddefarkost",
    "luftkuddefarkosterna": "luftkuddefarkost",
    "luftkuddefarkosternas": "luftkuddefarkost",
    "luftkuddefarkosters": "luftkuddefarkost",
    "luftkuddefarkosts": "luftkuddefarkost",
    "luftkudden": "luftkudde",
    "luftkuddens": "luftkudde",
    "luftkuddes": "luftkudde",
    "luftkylda": "luftkyld",
    "luftkyldare": "luftkyld",
    "luftkyldares": "luftkyld",
    "luftkyldas": "luftkyld",
    "luftkyldast": "luftkyld",
    "luftkyldaste": "luftkyld",
    "luftkyldastes": "luftkyld",
    "luftkyldasts": "luftkyld",
    "luftkylde": "luftkyld",
    "luftkyldes": "luftkyld",
    "luftkylds": "luftkyld",
    "luftkylt": "luftkyld",
    "luftkylts": "luftkyld",
    "luftlagerna": "luftlager",
    "luftlagernas": "luftlager",
    "luftlagers": "luftlager",
    "luftlagren": "luftlager",
    "luftlagrens": "luftlager",
    "luftlagret": "luftlager",
    "luftlagrets": "luftlager",
    "luftlandsatt": "luftlandsätta",
    "luftlandsatta": "luftlandsätta",
    "luftlandsattas": "luftlandsätta",
    "luftlandsatte": "luftlandsätta",
    "luftlandsattes": "luftlandsätta",
    "luftlandsatts": "luftlandsätta",
    "luftlandsätt": "luftlandsätta",
    "luftlandsättande": "luftlandsätta",
    "luftlandsättanden": "luftlandsättande",
    "luftlandsättandena": "luftlandsättande",
    "luftlandsättandenas": "luftlandsättande",
    "luftlandsättandens": "luftlandsättande",
    "luftlandsättandes": "luftlandsättande",
    "luftlandsättandet": "luftlandsättande",
    "luftlandsättandets": "luftlandsättande",
    "luftlandsättas": "luftlandsätta",
    "luftlandsätter": "luftlandsätta",
    "luftlandsättes": "luftlandsätta",
    "luftlandsätts": "luftlandsätta",
    "luftleden": "luftled",
    "luftledens": "luftled",
    "luftleder": "luftled",
    "luftlederna": "luftled",
    "luftledernas": "luftled",
    "luftleders": "luftled",
    "luftledningar": "luftledning",
    "luftledningarna": "luftledning",
    "luftledningarnas": "luftledning",
    "luftledningars": "luftledning",
    "luftledningen": "luftledning",
    "luftledningens": "luftledning",
    "luftlednings": "luftledning",
    "luftleds": "luftled",
    "luftmadrassen": "luftmadrass",
    "luftmadrassens": "luftmadrass",
    "luftmadrasser": "luftmadrass",
    "luftmadrasserna": "luftmadrass",
    "luftmadrassernas": "luftmadrass",
    "luftmadrassers": "luftmadrass",
    "luftmask": "luftmaska",
    "luftmaskan": "luftmaska",
    "luftmaskans": "luftmaska",
    "luftmaskas": "luftmaska",
    "luftmaske": "luftmaska",
    "luftmaskor": "luftmaska",
    "luftmaskorna": "luftmaska",
    "luftmaskornas": "luftmaska",
    "luftmaskors": "luftmaska",
    "luftmassan": "luftmassa",
    "luftmassans": "luftmassa",
    "luftmassas": "luftmassa",
    "luftmasse": "luftmassa",
    "luftmassor": "luftmassa",
    "luftmassorna": "luftmassa",
    "luftmassornas": "luftmassa",
    "luftmassors": "luftmassa",
    "luftmasten": "luftmast",
    "luftmastens": "luftmast",
    "luftmaster": "luftmast",
    "luftmasterna": "luftmast",
    "luftmasternas": "luftmast",
    "luftmasters": "luftmast",
    "luftmasts": "luftmast",
    "luftmotståndet": "luftmotstånd",
    "luftmotståndets": "luftmotstånd",
    "luftmotstånds": "luftmotstånd",
    "luftmängden": "luftmängd",
    "luftmängdens": "luftmängd",
    "luftmängder": "luftmängd",
    "luftmängderna": "luftmängd",
    "luftmängdernas": "luftmängd",
    "luftmängders": "luftmängd",
    "luftmängds": "luftmängd",
    "luftombyten": "luftombyte",
    "luftombytena": "luftombyte",
    "luftombytenas": "luftombyte",
    "luftombytens": "luftombyte",
    "luftombytes": "luftombyte",
    "luftombytet": "luftombyte",
    "luftombytets": "luftombyte",
    "luftperspektiven": "luftperspektiv",
    "luftperspektivens": "luftperspektiv",
    "luftperspektivet": "luftperspektiv",
    "luftperspektivets": "luftperspektiv",
    "luftperspektivs": "luftperspektiv",
    "luftpistolen": "luftpistol",
    "luftpistolens": "luftpistol",
    "luftpistoler": "luftpistol",
    "luftpistolerna": "luftpistol",
    "luftpistolernas": "luftpistol",
    "luftpistolers": "luftpistol",
    "luftpistols": "luftpistol",
    "luftpistolseten": "luftpistolset",
    "luftpistolsetens": "luftpistolset",
    "luftpistolsetet": "luftpistolset",
    "luftpistolsetets": "luftpistolset",
    "luftpistolsets": "luftpistolset",
    "luftposten": "luftpost",
    "luftpostens": "luftpost",
    "luftposts": "luftpost",
    "luftpropellern": "luftpropeller",
    "luftpropellerns": "luftpropeller",
    "luftpropellers": "luftpropeller",
    "luftpropellrar": "luftpropeller",
    "luftpropellrarna": "luftpropeller",
    "luftpropellrarnas": "luftpropeller",
    "luftpropellrars": "luftpropeller",
    "luftpumpar": "luftpump",
    "luftpumparna": "luftpump",
    "luftpumparnas": "luftpump",
    "luftpumpars": "luftpump",
    "luftpumpen": "luftpump",
    "luftpumpens": "luftpump",
    "luftpumps": "luftpump",
    "luftrenar": "luftrenare",
    "luftrenaren": "luftrenare",
    "luftrenarens": "luftrenare",
    "luftrenares": "luftrenare",
    "luftrenarna": "luftrenare",
    "luftrenarnas": "luftrenare",
    "luftroten": "luftrot",
    "luftrotens": "luftrot",
    "luftrots": "luftrot",
    "luftrummen": "luftrum",
    "luftrummens": "luftrum",
    "luftrummet": "luftrum",
    "luftrummets": "luftrum",
    "luftrums": "luftrum",
    "luftrumsringar": "luftrumsring",
    "luftrumsringarna": "luftrumsring",
    "luftrumsringarnas": "luftrumsring",
    "luftrumsringars": "luftrumsring",
    "luftrumsringen": "luftrumsring",
    "luftrumsringens": "luftrumsring",
    "luftrumsrings": "luftrumsring",
    "luftrören": "luftrör",
    "luftrörens": "luftrör",
    "luftröret": "luftrör",
    "luftrörets": "luftrör",
    "luftrörs": "luftrör",
    "luftrörskatarren": "luftrörskatarr",
    "luftrörskatarrens": "luftrörskatarr",
    "luftrörskatarrer": "luftrörskatarr",
    "luftrörskatarrerna": "luftrörskatarr",
    "luftrörskatarrernas": "luftrörskatarr",
    "luftrörskatarrers": "luftrörskatarr",
    "luftrörskatarrs": "luftrörskatarr",
    "luftrötter": "luftrot",
    "luftrötterna": "luftrot",
    "luftrötternas": "luftrot",
    "luftrötters": "luftrot",
    "lufts": "luft",
    "luftskall": "luftskalle",
    "luftskallar": "luftskalle",
    "luftskallarna": "luftskalle",
    "luftskallarnas": "luftskalle",
    "luftskallars": "luftskalle",
    "luftskallen": "luftskalle",
    "luftskallens": "luftskalle",
    "luftskalles": "luftskalle",
    "luftskalls": "luftskalle",
    "luftskeppen": "luftskepp",
    "luftskeppens": "luftskepp",
    "luftskeppet": "luftskepp",
    "luftskeppets": "luftskepp",
    "luftskepps": "luftskepp",
    "luftskikten": "luftskikt",
    "luftskiktens": "luftskikt",
    "luftskiktet": "luftskikt",
    "luftskiktets": "luftskikt",
    "luftskikts": "luftskikt",
    "luftskyttes": "luftskytte",
    "luftskyttet": "luftskytte",
    "luftskyttets": "luftskytte",
    "luftslotten": "luftslott",
    "luftslottens": "luftslott",
    "luftslottet": "luftslott",
    "luftslottets": "luftslott",
    "luftslotts": "luftslott",
    "luftslussar": "luftsluss",
    "luftslussarna": "luftsluss",
    "luftslussarnas": "luftsluss",
    "luftslussars": "luftsluss",
    "luftslussen": "luftsluss",
    "luftslussens": "luftsluss",
    "luftsmörjar": "luftsmörjare",
    "luftsmörjaren": "luftsmörjare",
    "luftsmörjarens": "luftsmörjare",
    "luftsmörjares": "luftsmörjare",
    "luftsmörjarna": "luftsmörjare",
    "luftsmörjarnas": "luftsmörjare",
    "luftspärrar": "luftspärr",
    "luftspärrarna": "luftspärr",
    "luftspärrarnas": "luftspärr",
    "luftspärrars": "luftspärr",
    "luftspärren": "luftspärr",
    "luftspärrens": "luftspärr",
    "luftspärrs": "luftspärr",
    "luftstrup": "luftstrupe",
    "luftstrupar": "luftstrupe",
    "luftstruparna": "luftstrupe",
    "luftstruparnas": "luftstrupe",
    "luftstrupars": "luftstrupe",
    "luftstrupen": "luftstrupe",
    "luftstrupens": "luftstrupe",
    "luftstrupes": "luftstrupe",
    "luftstrups": "luftstrupe",
    "luftströmmar": "luftström",
    "luftströmmarna": "luftström",
    "luftströmmarnas": "luftström",
    "luftströmmars": "luftström",
    "luftströmmen": "luftström",
    "luftströmmens": "luftström",
    "luftströms": "luftström",
    "luftsäckar": "luftsäck",
    "luftsäckarna": "luftsäck",
    "luftsäckarnas": "luftsäck",
    "luftsäckars": "luftsäck",
    "luftsäcken": "luftsäck",
    "luftsäckens": "luftsäck",
    "luftsäcks": "luftsäck",
    "lufttemperaturen": "lufttemperatur",
    "lufttemperaturens": "lufttemperatur",
    "lufttemperaturer": "lufttemperatur",
    "lufttemperaturerna": "lufttemperatur",
    "lufttemperaturernas": "lufttemperatur",
    "lufttemperaturers": "lufttemperatur",
    "lufttemperaturs": "lufttemperatur",
    "lufttillförseln": "lufttillförsel",
    "lufttillförselns": "lufttillförsel",
    "lufttillförsels": "lufttillförsel",
    "lufttomheten": "lufttomhet",
    "lufttomhetens": "lufttomhet",
    "lufttomhets": "lufttomhet",
    "lufttomma": "lufttom",
    "lufttommare": "lufttom",
    "lufttommares": "lufttom",
    "lufttommas": "lufttom",
    "lufttommast": "lufttom",
    "lufttommaste": "lufttom",
    "lufttommastes": "lufttom",
    "lufttommasts": "lufttom",
    "lufttomme": "lufttom",
    "lufttommes": "lufttom",
    "lufttoms": "lufttom",
    "lufttomt": "lufttom",
    "lufttomts": "lufttom",
    "lufttork": "lufttorka",
    "lufttorkad": "lufttorka",
    "lufttorkade": "lufttorka",
    "lufttorkades": "lufttorka",
    "lufttorkads": "lufttorka",
    "lufttorkande": "lufttorka",
    "lufttorkanden": "lufttorkande",
    "lufttorkandena": "lufttorkande",
    "lufttorkandenas": "lufttorkande",
    "lufttorkandens": "lufttorkande",
    "lufttorkandes": "lufttorkande",
    "lufttorkandet": "lufttorkande",
    "lufttorkandets": "lufttorkande",
    "lufttorkar": "lufttorka",
    "lufttorkas": "lufttorka",
    "lufttorkat": "lufttorka",
    "lufttorkats": "lufttorka",
    "lufttrum": "lufttrumma",
    "lufttrumman": "lufttrumma",
    "lufttrummans": "lufttrumma",
    "lufttrummas": "lufttrumma",
    "lufttrumme": "lufttrumma",
    "lufttrummor": "lufttrumma",
    "lufttrummorna": "lufttrumma",
    "lufttrummornas": "lufttrumma",
    "lufttrummors": "lufttrumma",
    "lufttrums": "lufttrumma",
    "lufttrycken": "lufttryck",
    "lufttryckens": "lufttryck",
    "lufttrycket": "lufttryck",
    "lufttryckets": "lufttryck",
    "lufttrycks": "lufttryck",
    "lufttrycksförändringar": "lufttrycksförändring",
    "lufttrycksförändringarna": "lufttrycksförändring",
    "lufttrycksförändringarnas": "lufttrycksförändring",
    "lufttrycksförändringars": "lufttrycksförändring",
    "lufttrycksförändringen": "lufttrycksförändring",
    "lufttrycksförändringens": "lufttrycksförändring",
    "lufttrycksförändrings": "lufttrycksförändring",
    "lufttrycksmätar": "lufttrycksmätare",
    "lufttrycksmätaren": "lufttrycksmätare",
    "lufttrycksmätarens": "lufttrycksmätare",
    "lufttrycksmätares": "lufttrycksmätare",
    "lufttrycksmätarna": "lufttrycksmätare",
    "lufttrycksmätarnas": "lufttrycksmätare",
    "lufttäta": "lufttät",
    "lufttätare": "lufttät",
    "lufttätares": "lufttät",
    "lufttätas": "lufttät",
    "lufttätast": "lufttät",
    "lufttätaste": "lufttät",
    "lufttätastes": "lufttät",
    "lufttätasts": "lufttät",
    "lufttäte": "lufttät",
    "lufttätes": "lufttät",
    "lufttätheten": "lufttäthet",
    "lufttäthetens": "lufttäthet",
    "lufttäthets": "lufttäthet",
    "lufttäts": "lufttät",
    "lufttätt": "lufttät",
    "lufttätts": "lufttät",
    "luftvapenkul": "luftvapenkula",
    "luftvapenkulan": "luftvapenkula",
    "luftvapenkulans": "luftvapenkula",
    "luftvapenkulas": "luftvapenkula",
    "luftvapenkule": "luftvapenkula",
    "luftvapenkulor": "luftvapenkula",
    "luftvapenkulorna": "luftvapenkula",
    "luftvapenkulornas": "luftvapenkula",
    "luftvapenkulors": "luftvapenkula",
    "luftvapenkuls": "luftvapenkula",
    "luftvapens": "luftvapen",
    "luftvapnen": "luftvapen",
    "luftvapnens": "luftvapen",
    "luftvapnet": "luftvapen",
    "luftvapnets": "luftvapen",
    "luftventilen": "luftventil",
    "luftventilens": "luftventil",
    "luftventiler": "luftventil",
    "luftventilerna": "luftventil",
    "luftventilernas": "luftventil",
    "luftventilers": "luftventil",
    "luftventils": "luftventil",
    "luftvägar": "luftväg",
    "luftvägarna": "luftväg",
    "luftvägarnas": "luftväg",
    "luftvägars": "luftväg",
    "luftvägen": "luftväg",
    "luftvägens": "luftväg",
    "luftvägs": "luftväg",
    "luftvärmepumpar": "luftvärmepump",
    "luftvärmepumparna": "luftvärmepump",
    "luftvärmepumparnas": "luftvärmepump",
    "luftvärmepumpars": "luftvärmepump",
    "luftvärmepumpen": "luftvärmepump",
    "luftvärmepumpens": "luftvärmepump",
    "luftvärmepumps": "luftvärmepump",
    "luftvärnen": "luftvärn",
    "luftvärnens": "luftvärn",
    "luftvärnet": "luftvärn",
    "luftvärnets": "luftvärn",
    "luftvärns": "luftvärn",
    "luftvärnskanonen": "luftvärnskanon",
    "luftvärnskanonens": "luftvärnskanon",
    "luftvärnskanoner": "luftvärnskanon",
    "luftvärnskanonerna": "luftvärnskanon",
    "luftvärnskanonernas": "luftvärnskanon",
    "luftvärnskanoners": "luftvärnskanon",
    "luftvärnskanons": "luftvärnskanon",
    "luftvärnsrobotar": "luftvärnsrobot",
    "luftvärnsrobotarna": "luftvärnsrobot",
    "luftvärnsrobotarnas": "luftvärnsrobot",
    "luftvärnsrobotars": "luftvärnsrobot",
    "luftvärnsroboten": "luftvärnsrobot",
    "luftvärnsrobotens": "luftvärnsrobot",
    "luftvärnsrobots": "luftvärnsrobot",
    "luftväxlingar": "luftväxling",
    "luftväxlingarna": "luftväxling",
    "luftväxlingarnas": "luftväxling",
    "luftväxlingars": "luftväxling",
    "luftväxlingen": "luftväxling",
    "luftväxlingens": "luftväxling",
    "luftväxlings": "luftväxling",
    "luftvågen": "luftvåg",
    "luftvågens": "luftvåg",
    "luftvågor": "luftvåg",
    "luftvågorna": "luftvåg",
    "luftvågornas": "luftvåg",
    "luftvågors": "luftvåg",
    "luftvågs": "luftvåg",
    "lugg": "lugga",
    "luggad": "lugga",
    "luggade": "lugga",
    "luggades": "luggas",
    "luggads": "lugga",
    "luggande": "lugga",
    "lugganden": "luggande",
    "luggandena": "luggande",
    "luggandenas": "luggande",
    "luggandens": "luggande",
    "luggandes": "luggande",
    "luggandet": "luggande",
    "luggandets": "luggande",
    "luggar": "lugga",
    "luggarna": "lugg",
    "luggarnas": "lugg",
    "luggars": "lugg",
    "luggas": "lugga",
    "luggat": "lugga",
    "luggats": "luggas",
    "luggen": "lugg",
    "luggens": "lugg",
    "luggiga": "luggig",
    "luggigare": "luggig",
    "luggigares": "luggig",
    "luggigas": "luggig",
    "luggigast": "luggig",
    "luggigaste": "luggig",
    "luggigastes": "luggig",
    "luggigasts": "luggig",
    "luggige": "luggig",
    "luggiges": "luggig",
    "luggigheten": "luggighet",
    "luggighetens": "luggighet",
    "luggighets": "luggighet",
    "luggigs": "luggig",
    "luggigt": "luggig",
    "luggigts": "luggig",
    "luggs": "lugg",
    "luggslitenheten": "luggslitenhet",
    "luggslitenhetens": "luggslitenhet",
    "luggslitenhets": "luggslitenhet",
    "luggslitens": "luggsliten",
    "luggslitet": "luggsliten",
    "luggslitets": "luggsliten",
    "luggslitna": "luggsliten",
    "luggslitnare": "luggsliten",
    "luggslitnares": "luggsliten",
    "luggslitnas": "luggsliten",
    "luggslitnast": "luggsliten",
    "luggslitnaste": "luggsliten",
    "luggslitnastes": "luggsliten",
    "luggslitnasts": "luggsliten",
    "luggslitne": "luggsliten",
    "luggslitnes": "luggsliten",
    "lugn": "lugna",
    "lugna": "lugn",
    "lugnad": "lugna",
    "lugnade": "lugna",
    "lugnades": "lugna",
    "lugnads": "lugna",
    "lugnande": "lugna",
    "lugnanden": "lugnande",
    "lugnandena": "lugnande",
    "lugnandenas": "lugnande",
    "lugnandens": "lugnande",
    "lugnandes": "lugnande",
    "lugnandet": "lugnande",
    "lugnandets": "lugnande",
    "lugnar": "lugna",
    "lugnare": "lugn",
    "lugnares": "lugn",
    "lugnas": "lugna",
    "lugnast": "lugn",
    "lugnaste": "lugn",
    "lugnastes": "lugn",
    "lugnasts": "lugn",
    "lugnat": "lugna",
    "lugnats": "lugna",
    "lugne": "lugn",
    "lugnes": "lugn",
    "lugnet": "lugn",
    "lugnets": "lugn",
    "lugnheten": "lugnhet",
    "lugnhetens": "lugnhet",
    "lugnhets": "lugnhet",
    "lugns": "lugn",
    "lugnt": "lugn",
    "lugnts": "lugn",
    "lugnvattens": "lugnvatten",
    "lugnvattnen": "lugnvatten",
    "lugnvattnens": "lugnvatten",
    "lugnvattnet": "lugnvatten",
    "lugnvattnets": "lugnvatten",
    "lugubers": "luguber",
    "lugubert": "luguber",
    "luguberts": "luguber",
    "lugubra": "luguber",
    "lugubrare": "luguber",
    "lugubrares": "luguber",
    "lugubras": "luguber",
    "lugubrast": "luguber",
    "lugubraste": "luguber",
    "lugubrastes": "luguber",
    "lugubrasts": "luguber",
    "lugubre": "luguber",
    "lugubres": "luguber",
    "lukrativa": "lukrativ",
    "lukrativare": "lukrativ",
    "lukrativares": "lukrativ",
    "lukrativas": "lukrativ",
    "lukrativast": "lukrativ",
    "lukrativaste": "lukrativ",
    "lukrativastes": "lukrativ",
    "lukrativasts": "lukrativ",
    "lukrative": "lukrativ",
    "lukratives": "lukrativ",
    "lukrativs": "lukrativ",
    "lukrativt": "lukrativ",
    "lukrativts": "lukrativ",
    "lukt": "lukta",
    "luktad": "lukta",
    "luktade": "lukta",
    "luktades": "lukta",
    "luktads": "lukta",
    "luktande": "lukta",
    "luktanden": "luktande",
    "luktandena": "luktande",
    "luktandenas": "luktande",
    "luktandens": "luktande",
    "luktandes": "luktande",
    "luktandet": "luktande",
    "luktandets": "luktande",
    "luktar": "lukta",
    "luktas": "lukta",
    "luktat": "lukta",
    "luktats": "lukta",
    "luktborttagar": "luktborttagare",
    "luktborttagaren": "luktborttagare",
    "luktborttagarens": "luktborttagare",
    "luktborttagares": "luktborttagare",
    "luktborttagarna": "luktborttagare",
    "luktborttagarnas": "luktborttagare",
    "lukten": "lukt",
    "luktens": "lukt",
    "lukter": "lukt",
    "lukterna": "lukt",
    "lukternas": "lukt",
    "lukters": "lukt",
    "luktflask": "luktflaska",
    "luktflaskan": "luktflaska",
    "luktflaskans": "luktflaska",
    "luktflaskas": "luktflaska",
    "luktflaske": "luktflaska",
    "luktflaskor": "luktflaska",
    "luktflaskorna": "luktflaska",
    "luktflaskornas": "luktflaska",
    "luktflaskors": "luktflaska",
    "luktfria": "luktfri",
    "luktfriare": "luktfri",
    "luktfriares": "luktfri",
    "luktfrias": "luktfri",
    "luktfriast": "luktfri",
    "luktfriaste": "luktfri",
    "luktfriastes": "luktfri",
    "luktfriasts": "luktfri",
    "luktfrie": "luktfri",
    "luktfries": "luktfri",
    "luktfris": "luktfri",
    "luktfritt": "luktfri",
    "luktfritts": "luktfri",
    "luktnerven": "luktnerv",
    "luktnervens": "luktnerv",
    "luktnerver": "luktnerv",
    "luktnerverna": "luktnerv",
    "luktnervernas": "luktnerv",
    "luktnervers": "luktnerv",
    "luktnervs": "luktnerv",
    "lukts": "lukt",
    "luktsaltet": "luktsalt",
    "luktsaltets": "luktsalt",
    "luktsalts": "luktsalt",
    "luktsinnen": "luktsinne",
    "luktsinnena": "luktsinne",
    "luktsinnenas": "luktsinne",
    "luktsinnens": "luktsinne",
    "luktsinnes": "luktsinne",
    "luktsinnet": "luktsinne",
    "luktsinnets": "luktsinne",
    "luktvattens": "luktvatten",
    "luktvattnen": "luktvatten",
    "luktvattnens": "luktvatten",
    "luktvattnet": "luktvatten",
    "luktvattnets": "luktvatten",
    "luktvialen": "luktvial",
    "luktvialens": "luktvial",
    "luktvialer": "luktvial",
    "luktvialerna": "luktvial",
    "luktvialernas": "luktvial",
    "luktvialers": "luktvial",
    "luktvials": "luktvial",
    "luktviolen": "luktviol",
    "luktviolens": "luktviol",
    "luktvioler": "luktviol",
    "luktviolerna": "luktviol",
    "luktviolernas": "luktviol",
    "luktviolers": "luktviol",
    "luktviols": "luktviol",
    "luktärten": "luktärt",
    "luktärtens": "luktärt",
    "luktärter": "luktärt",
    "luktärterna": "luktärt",
    "luktärternas": "luktärt",
    "luktärters": "luktärt",
    "luktärts": "luktärt",
    "lukulliska": "lukullisk",
    "lukulliskare": "lukullisk",
    "lukulliskares": "lukullisk",
    "lukulliskas": "lukullisk",
    "lukulliskast": "lukullisk",
    "lukulliskaste": "lukullisk",
    "lukulliskastes": "lukullisk",
    "lukulliskasts": "lukullisk",
    "lukulliske": "lukullisk",
    "lukulliskes": "lukullisk",
    "lukullisks": "lukullisk",
    "lukulliskt": "lukullisk",
    "lukulliskts": "lukullisk",
    "lull": "lulla",
    "lullad": "lulla",
    "lullade": "lulla",
    "lullades": "lulla",
    "lullads": "lulla",
    "lullande": "lulla",
    "lullanden": "lullande",
    "lullandena": "lullande",
    "lullandenas": "lullande",
    "lullandens": "lullande",
    "lullandes": "lullande",
    "lullandet": "lullande",
    "lullandets": "lullande",
    "lullar": "lulla",
    "lullas": "lulla",
    "lullat": "lulla",
    "lullats": "lulla",
    "lulliga": "lullig",
    "lulligare": "lullig",
    "lulligares": "lullig",
    "lulligas": "lullig",
    "lulligast": "lullig",
    "lulligaste": "lullig",
    "lulligastes": "lullig",
    "lulligasts": "lullig",
    "lullige": "lullig",
    "lulliges": "lullig",
    "lulligheten": "lullighet",
    "lullighetens": "lullighet",
    "lullighets": "lullighet",
    "lulligs": "lullig",
    "lulligt": "lullig",
    "lulligts": "lullig",
    "lullullet": "lullull",
    "lullullets": "lullull",
    "lullulls": "lullull",
    "luman": "luma",
    "lumans": "luma",
    "lumas": "luma",
    "lumbagon": "lumbago",
    "lumbagons": "lumbago",
    "lumbagos": "lumbago",
    "lumbala": "lumbal",
    "lumbalare": "lumbal",
    "lumbalares": "lumbal",
    "lumbalas": "lumbal",
    "lumbalast": "lumbal",
    "lumbalaste": "lumbal",
    "lumbalastes": "lumbal",
    "lumbalasts": "lumbal",
    "lumbalbedövningar": "lumbalbedövning",
    "lumbalbedövningarna": "lumbalbedövning",
    "lumbalbedövningarnas": "lumbalbedövning",
    "lumbalbedövningars": "lumbalbedövning",
    "lumbalbedövningen": "lumbalbedövning",
    "lumbalbedövningens": "lumbalbedövning",
    "lumbalbedövnings": "lumbalbedövning",
    "lumbale": "lumbal",
    "lumbales": "lumbal",
    "lumbalpunktionen": "lumbalpunktion",
    "lumbalpunktionens": "lumbalpunktion",
    "lumbalpunktioner": "lumbalpunktion",
    "lumbalpunktionerna": "lumbalpunktion",
    "lumbalpunktionernas": "lumbalpunktion",
    "lumbalpunktioners": "lumbalpunktion",
    "lumbalpunktions": "lumbalpunktion",
    "lumbals": "lumbal",
    "lumbalt": "lumbal",
    "lumbalts": "lumbal",
    "lumberjack": "lumberjacka",
    "lumberjackan": "lumberjacka",
    "lumberjackans": "lumberjacka",
    "lumberjackas": "lumberjacka",
    "lumberjacke": "lumberjacka",
    "lumberjackor": "lumberjacka",
    "lumberjackorna": "lumberjacka",
    "lumberjackornas": "lumberjacka",
    "lumberjackors": "lumberjacka",
    "lumberjacks": "lumberjacka",
    "lumenen": "lumen",
    "lumenens": "lumen",
    "lumenet": "lumen",
    "lumenets": "lumen",
    "lumens": "lumen",
    "luminiscensen": "luminiscens",
    "luminiscensens": "luminiscens",
    "luminösa": "luminös",
    "luminösare": "luminös",
    "luminösares": "luminös",
    "luminösas": "luminös",
    "luminösast": "luminös",
    "luminösaste": "luminös",
    "luminösastes": "luminös",
    "luminösasts": "luminös",
    "luminöse": "luminös",
    "luminöses": "luminös",
    "luminöst": "luminös",
    "luminösts": "luminös",
    "lummern": "lummer",
    "lummerns": "lummer",
    "lummers": "lummer",
    "lummerväxten": "lummerväxt",
    "lummerväxtens": "lummerväxt",
    "lummerväxter": "lummerväxt",
    "lummerväxterna": "lummerväxt",
    "lummerväxternas": "lummerväxt",
    "lummerväxters": "lummerväxt",
    "lummerväxts": "lummerväxt",
    "lummiga": "lummig",
    "lummigare": "lummig",
    "lummigares": "lummig",
    "lummigas": "lummig",
    "lummigast": "lummig",
    "lummigaste": "lummig",
    "lummigastes": "lummig",
    "lummigasts": "lummig",
    "lummige": "lummig",
    "lummiges": "lummig",
    "lummigheten": "lummighet",
    "lummighetens": "lummighet",
    "lummighets": "lummighet",
    "lummigs": "lummig",
    "lummigt": "lummig",
    "lummigts": "lummig",
    "lumnen": "lumen",
    "lumnens": "lumen",
    "lumnet": "lumen",
    "lumnets": "lumen",
    "lumor": "luma",
    "lumorna": "luma",
    "lumornas": "luma",
    "lumors": "luma",
    "lump": "lumpa",
    "lumpade": "lumpa",
    "lumpades": "lumpa",
    "lumpande": "lumpa",
    "lumpanden": "lumpande",
    "lumpandena": "lumpande",
    "lumpandenas": "lumpande",
    "lumpandens": "lumpande",
    "lumpandes": "lumpande",
    "lumpandet": "lumpande",
    "lumpandets": "lumpande",
    "lumpar": "lumpa",
    "lumpas": "lumpa",
    "lumpat": "lumpa",
    "lumpats": "lumpa",
    "lumpen": "lump",
    "lumpenheten": "lumpenhet",
    "lumpenhetens": "lumpenhet",
    "lumpenhets": "lumpenhet",
    "lumpens": "lumpen",
    "lumpet": "lumpen",
    "lumpets": "lumpen",
    "lumpfiskar": "lumpfisk",
    "lumpfiskarna": "lumpfisk",
    "lumpfiskarnas": "lumpfisk",
    "lumpfiskars": "lumpfisk",
    "lumpfisken": "lumpfisk",
    "lumpfiskens": "lumpfisk",
    "lumpfisks": "lumpfisk",
    "lumpiga": "lumpig",
    "lumpigare": "lumpig",
    "lumpigares": "lumpig",
    "lumpigas": "lumpig",
    "lumpigast": "lumpig",
    "lumpigaste": "lumpig",
    "lumpigastes": "lumpig",
    "lumpigasts": "lumpig",
    "lumpige": "lumpig",
    "lumpiges": "lumpig",
    "lumpigheten": "lumpighet",
    "lumpighetens": "lumpighet",
    "lumpighets": "lumpighet",
    "lumpigs": "lumpig",
    "lumpigt": "lumpig",
    "lumpigts": "lumpig",
    "lumpna": "lumpen",
    "lumpnare": "lumpen",
    "lumpnares": "lumpen",
    "lumpnas": "lumpen",
    "lumpnast": "lumpen",
    "lumpnaste": "lumpen",
    "lumpnastes": "lumpen",
    "lumpnasts": "lumpen",
    "lumpne": "lumpen",
    "lumpnes": "lumpen",
    "lumpor": "lump",
    "lumporna": "lump",
    "lumpornas": "lump",
    "lumpors": "lump",
    "lumppapperet": "lumppapper",
    "lumppapperets": "lumppapper",
    "lumppappers": "lumppapper",
    "lumppappret": "lumppapper",
    "lumppapprets": "lumppapper",
    "lumps": "lump",
    "lumpullen": "lumpull",
    "lumpullens": "lumpull",
    "lumpulls": "lumpull",
    "lunara": "lunar",
    "lunarare": "lunar",
    "lunarares": "lunar",
    "lunaras": "lunar",
    "lunarast": "lunar",
    "lunaraste": "lunar",
    "lunarastes": "lunar",
    "lunarasts": "lunar",
    "lunare": "lunar",
    "lunares": "lunar",
    "lunariska": "lunarisk",
    "lunariskare": "lunarisk",
    "lunariskares": "lunarisk",
    "lunariskas": "lunarisk",
    "lunariskast": "lunarisk",
    "lunariskaste": "lunarisk",
    "lunariskastes": "lunarisk",
    "lunariskasts": "lunarisk",
    "lunariske": "lunarisk",
    "lunariskes": "lunarisk",
    "lunarisks": "lunarisk",
    "lunariskt": "lunarisk",
    "lunariskts": "lunarisk",
    "lunars": "lunar",
    "lunart": "lunar",
    "lunarts": "lunar",
    "lunationen": "lunation",
    "lunationens": "lunation",
    "lunationer": "lunation",
    "lunationerna": "lunation",
    "lunationernas": "lunation",
    "lunationers": "lunation",
    "lunations": "lunation",
    "lunchade": "luncha",
    "lunchades": "luncha",
    "lunchande": "luncha",
    "lunchanden": "lunchande",
    "lunchandena": "lunchande",
    "lunchandenas": "lunchande",
    "lunchandens": "lunchande",
    "lunchandes": "lunchande",
    "lunchandet": "lunchande",
    "lunchandets": "lunchande",
    "lunchar": "lunchare",
    "luncharen": "lunchare",
    "luncharens": "lunchare",
    "lunchares": "lunchare",
    "luncharna": "lunchare",
    "luncharnas": "lunchare",
    "lunchas": "luncha",
    "lunchat": "luncha",
    "lunchats": "luncha",
    "lunchborden": "lunchbord",
    "lunchbordens": "lunchbord",
    "lunchbordet": "lunchbord",
    "lunchbordets": "lunchbord",
    "lunchbords": "lunchbord",
    "lunchen": "lunch",
    "lunchens": "lunch",
    "luncher": "lunch",
    "luncherna": "lunch",
    "lunchernas": "lunch",
    "lunchers": "lunch",
    "lunchlåd": "lunchlåda",
    "lunchlådan": "lunchlåda",
    "lunchlådans": "lunchlåda",
    "lunchlådas": "lunchlåda",
    "lunchlåde": "lunchlåda",
    "lunchlådor": "lunchlåda",
    "lunchlådorna": "lunchlåda",
    "lunchlådornas": "lunchlåda",
    "lunchlådors": "lunchlåda",
    "lunchlåds": "lunchlåda",
    "lunchrasten": "lunchrast",
    "lunchrastens": "lunchrast",
    "lunchraster": "lunchrast",
    "lunchrasterna": "lunchrast",
    "lunchrasternas": "lunchrast",
    "lunchrasters": "lunchrast",
    "lunchrasts": "lunchrast",
    "lunchrestaurangen": "lunchrestaurang",
    "lunchrestaurangens": "lunchrestaurang",
    "lunchrestauranger": "lunchrestaurang",
    "lunchrestaurangerna": "lunchrestaurang",
    "lunchrestaurangernas": "lunchrestaurang",
    "lunchrestaurangers": "lunchrestaurang",
    "lunchrestaurangs": "lunchrestaurang",
    "lunchrummen": "lunchrum",
    "lunchrummens": "lunchrum",
    "lunchrummet": "lunchrum",
    "lunchrummets": "lunchrum",
    "lunchrums": "lunchrum",
    "lunchrusningar": "lunchrusning",
    "lunchrusningarna": "lunchrusning",
    "lunchrusningarnas": "lunchrusning",
    "lunchrusningars": "lunchrusning",
    "lunchrusningen": "lunchrusning",
    "lunchrusningens": "lunchrusning",
    "lunchrusnings": "lunchrusning",
    "lunchs": "lunch",
    "lunchställen": "lunchställe",
    "lunchställena": "lunchställe",
    "lunchställenas": "lunchställe",
    "lunchställens": "lunchställe",
    "lunchställes": "lunchställe",
    "lunchstället": "lunchställe",
    "lunchställets": "lunchställe",
    "lunchtiden": "lunchtid",
    "lunchtidens": "lunchtid",
    "lunchtider": "lunchtid",
    "lunchtiderna": "lunchtid",
    "lunchtidernas": "lunchtid",
    "lunchtiders": "lunchtid",
    "lunchtids": "lunchtid",
    "lunchtim": "lunchtimme",
    "lunchtimmar": "lunchtimme",
    "lunchtimmarna": "lunchtimme",
    "lunchtimmarnas": "lunchtimme",
    "lunchtimmars": "lunchtimme",
    "lunchtimmen": "lunchtimme",
    "lunchtimmens": "lunchtimme",
    "lunchtimmes": "lunchtimme",
    "lunchtims": "lunchtimme",
    "lundar": "lund",
    "lundarna": "lund",
    "lundarnas": "lund",
    "lundars": "lund",
    "lunden": "lund",
    "lundens": "lund",
    "lundensiska": "lundensisk",
    "lundensiskare": "lundensisk",
    "lundensiskares": "lundensisk",
    "lundensiskas": "lundensisk",
    "lundensiskast": "lundensisk",
    "lundensiskaste": "lundensisk",
    "lundensiskastes": "lundensisk",
    "lundensiskasts": "lundensisk",
    "lundensiske": "lundensisk",
    "lundensiskes": "lundensisk",
    "lundensisks": "lundensisk",
    "lundensiskt": "lundensisk",
    "lundensiskts": "lundensisk",
    "lunder": "lund",
    "lunderna": "lund",
    "lundernas": "lund",
    "lunders": "lund",
    "lunds": "lund",
    "lunetten": "lunett",
    "lunettens": "lunett",
    "lunetter": "lunett",
    "lunetterna": "lunett",
    "lunetternas": "lunett",
    "lunetters": "lunett",
    "lunetts": "lunett",
    "lung": "lunga",
    "lungan": "lunga",
    "lungans": "lunga",
    "lungas": "lunga",
    "lungblås": "lungblåsa",
    "lungblåsan": "lungblåsa",
    "lungblåsans": "lungblåsa",
    "lungblåsas": "lungblåsa",
    "lungblåse": "lungblåsa",
    "lungblåsor": "lungblåsa",
    "lungblåsorna": "lungblåsa",
    "lungblåsornas": "lungblåsa",
    "lungblåsors": "lungblåsa",
    "lungbranden": "lungbrand",
    "lungbrandens": "lungbrand",
    "lungbrands": "lungbrand",
    "lungbyten": "lungbyte",
    "lungbytena": "lungbyte",
    "lungbytenas": "lungbyte",
    "lungbytens": "lungbyte",
    "lungbytes": "lungbyte",
    "lungbytet": "lungbyte",
    "lungbytets": "lungbyte",
    "lungcancern": "lungcancer",
    "lungcancerns": "lungcancer",
    "lungcancers": "lungcancer",
    "lunge": "lunga",
    "lungembolien": "lungemboli",
    "lungemboliens": "lungemboli",
    "lungembolier": "lungemboli",
    "lungembolierna": "lungemboli",
    "lungemboliernas": "lungemboli",
    "lungemboliers": "lungemboli",
    "lungembolin": "lungemboli",
    "lungembolins": "lungemboli",
    "lungembolis": "lungemboli",
    "lungfiskar": "lungfisk",
    "lungfiskarna": "lungfisk",
    "lungfiskarnas": "lungfisk",
    "lungfiskars": "lungfisk",
    "lungfisken": "lungfisk",
    "lungfiskens": "lungfisk",
    "lungfisks": "lungfisk",
    "lunginflammationen": "lunginflammation",
    "lunginflammationens": "lunginflammation",
    "lunginflammationer": "lunginflammation",
    "lunginflammationerna": "lunginflammation",
    "lunginflammationernas": "lunginflammation",
    "lunginflammationers": "lunginflammation",
    "lunginflammations": "lunginflammation",
    "lungkatarren": "lungkatarr",
    "lungkatarrens": "lungkatarr",
    "lungkatarrer": "lungkatarr",
    "lungkatarrerna": "lungkatarr",
    "lungkatarrernas": "lungkatarr",
    "lungkatarrers": "lungkatarr",
    "lungkatarrs": "lungkatarr",
    "lungloben": "lunglob",
    "lunglobens": "lunglob",
    "lunglober": "lunglob",
    "lungloberna": "lunglob",
    "lunglobernas": "lunglob",
    "lunglobers": "lunglob",
    "lunglobs": "lunglob",
    "lungmoset": "lungmos",
    "lungmosets": "lungmos",
    "lungor": "lunga",
    "lungorna": "lunga",
    "lungornas": "lunga",
    "lungors": "lunga",
    "lungpulsådern": "lungpulsåder",
    "lungpulsåderns": "lungpulsåder",
    "lungpulsåders": "lungpulsåder",
    "lungpulsådra": "lungpulsåder",
    "lungpulsådran": "lungpulsåder",
    "lungpulsådrans": "lungpulsåder",
    "lungpulsådras": "lungpulsåder",
    "lungpulsådre": "lungpulsåder",
    "lungpulsådror": "lungpulsåder",
    "lungpulsådrorna": "lungpulsåder",
    "lungpulsådrornas": "lungpulsåder",
    "lungpulsådrors": "lungpulsåder",
    "lungroten": "lungrot",
    "lungrotens": "lungrot",
    "lungrots": "lungrot",
    "lungrötan": "lungröta",
    "lungrötans": "lungröta",
    "lungrötas": "lungröta",
    "lungröte": "lungröta",
    "lungrötter": "lungrot",
    "lungrötterna": "lungrot",
    "lungrötternas": "lungrot",
    "lungrötters": "lungrot",
    "lungs": "lunga",
    "lungsiktiga": "lungsiktig",
    "lungsiktigare": "lungsiktig",
    "lungsiktigares": "lungsiktig",
    "lungsiktigas": "lungsiktig",
    "lungsiktigast": "lungsiktig",
    "lungsiktigaste": "lungsiktig",
    "lungsiktigastes": "lungsiktig",
    "lungsiktigasts": "lungsiktig",
    "lungsiktige": "lungsiktig",
    "lungsiktiges": "lungsiktig",
    "lungsiktigs": "lungsiktig",
    "lungsiktigt": "lungsiktig",
    "lungsiktigts": "lungsiktig",
    "lungsjuka": "lungsjuk",
    "lungsjukan": "lungsjuka",
    "lungsjukans": "lungsjuka",
    "lungsjukare": "lungsjuk",
    "lungsjukares": "lungsjuk",
    "lungsjukas": "lungsjuka",
    "lungsjukast": "lungsjuk",
    "lungsjukaste": "lungsjuk",
    "lungsjukastes": "lungsjuk",
    "lungsjukasts": "lungsjuk",
    "lungsjukdomar": "lungsjukdom",
    "lungsjukdomarna": "lungsjukdom",
    "lungsjukdomarnas": "lungsjukdom",
    "lungsjukdomars": "lungsjukdom",
    "lungsjukdomen": "lungsjukdom",
    "lungsjukdomens": "lungsjukdom",
    "lungsjukdoms": "lungsjukdom",
    "lungsjuke": "lungsjuka",
    "lungsjukes": "lungsjuk",
    "lungsjukheten": "lungsjukhet",
    "lungsjukhetens": "lungsjukhet",
    "lungsjukhets": "lungsjukhet",
    "lungsjuks": "lungsjuka",
    "lungsjukt": "lungsjuk",
    "lungsjukts": "lungsjuk",
    "lungsnäck": "lungsnäcka",
    "lungsnäckan": "lungsnäcka",
    "lungsnäckans": "lungsnäcka",
    "lungsnäckas": "lungsnäcka",
    "lungsnäcke": "lungsnäcka",
    "lungsnäckor": "lungsnäcka",
    "lungsnäckorna": "lungsnäcka",
    "lungsnäckornas": "lungsnäcka",
    "lungsnäckors": "lungsnäcka",
    "lungsnäcks": "lungsnäcka",
    "lungsoten": "lungsot",
    "lungsotens": "lungsot",
    "lungsots": "lungsot",
    "lungsäckar": "lungsäck",
    "lungsäckarna": "lungsäck",
    "lungsäckarnas": "lungsäck",
    "lungsäckars": "lungsäck",
    "lungsäcken": "lungsäck",
    "lungsäckens": "lungsäck",
    "lungsäcks": "lungsäck",
    "lungsäcksinflammationen": "lungsäcksinflammation",
    "lungsäcksinflammationens": "lungsäcksinflammation",
    "lungsäcksinflammationer": "lungsäcksinflammation",
    "lungsäcksinflammationerna": "lungsäcksinflammation",
    "lungsäcksinflammationernas": "lungsäcksinflammation",
    "lungsäcksinflammationers": "lungsäcksinflammation",
    "lungsäcksinflammations": "lungsäcksinflammation",
    "lungtuberkulosen": "lungtuberkulos",
    "lungtuberkulosens": "lungtuberkulos",
    "lungvävnaden": "lungvävnad",
    "lungvävnadens": "lungvävnad",
    "lungvävnader": "lungvävnad",
    "lungvävnaderna": "lungvävnad",
    "lungvävnadernas": "lungvävnad",
    "lungvävnaders": "lungvävnad",
    "lungvävnads": "lungvävnad",
    "lungödemen": "lungödem",
    "lungödemens": "lungödem",
    "lungödemet": "lungödem",
    "lungödemets": "lungödem",
    "lungödems": "lungödem",
    "lungörten": "lungört",
    "lungörtens": "lungört",
    "lungörter": "lungört",
    "lungörterna": "lungört",
    "lungörternas": "lungört",
    "lungörters": "lungört",
    "lungörts": "lungört",
    "lunkade": "lunka",
    "lunkades": "lunka",
    "lunkande": "lunka",
    "lunkanden": "lunkande",
    "lunkandena": "lunkande",
    "lunkandenas": "lunkande",
    "lunkandens": "lunkande",
    "lunkandes": "lunkande",
    "lunkandet": "lunkande",
    "lunkandets": "lunkande",
    "lunkar": "lunka",
    "lunkas": "lunka",
    "lunkat": "lunka",
    "lunkats": "lunka",
    "lunken": "lunk",
    "lunkens": "lunk",
    "lunks": "lunk",
    "lunn": "lunne",
    "lunnad": "lunna",
    "lunnade": "lunna",
    "lunnades": "lunna",
    "lunnads": "lunna",
    "lunnande": "lunna",
    "lunnanden": "lunnande",
    "lunnandena": "lunnande",
    "lunnandenas": "lunnande",
    "lunnandens": "lunnande",
    "lunnandes": "lunnande",
    "lunnandet": "lunnande",
    "lunnandets": "lunnande",
    "lunnar": "lunne",
    "lunnarna": "lunne",
    "lunnarnas": "lunne",
    "lunnars": "lunne",
    "lunnas": "lunna",
    "lunnat": "lunna",
    "lunnats": "lunna",
    "lunnefågeln": "lunnefågel",
    "lunnefågelns": "lunnefågel",
    "lunnefågels": "lunnefågel",
    "lunnefåglar": "lunnefågel",
    "lunnefåglarna": "lunnefågel",
    "lunnefåglarnas": "lunnefågel",
    "lunnefåglars": "lunnefågel",
    "lunnen": "lunne",
    "lunnens": "lunne",
    "lunnes": "lunne",
    "lunnkälk": "lunnkälke",
    "lunnkälkar": "lunnkälke",
    "lunnkälkarna": "lunnkälke",
    "lunnkälkarnas": "lunnkälke",
    "lunnkälkars": "lunnkälke",
    "lunnkälken": "lunnkälke",
    "lunnkälkens": "lunnkälke",
    "lunnkälkes": "lunnkälke",
    "lunnkälks": "lunnkälke",
    "lunns": "lunne",
    "lunsar": "luns",
    "lunsarna": "luns",
    "lunsarnas": "luns",
    "lunsars": "luns",
    "lunsen": "luns",
    "lunsens": "luns",
    "lunsiga": "lunsig",
    "lunsigare": "lunsig",
    "lunsigares": "lunsig",
    "lunsigas": "lunsig",
    "lunsigast": "lunsig",
    "lunsigaste": "lunsig",
    "lunsigastes": "lunsig",
    "lunsigasts": "lunsig",
    "lunsige": "lunsig",
    "lunsiges": "lunsig",
    "lunsigheten": "lunsighet",
    "lunsighetens": "lunsighet",
    "lunsighets": "lunsighet",
    "lunsigs": "lunsig",
    "lunsigt": "lunsig",
    "lunsigts": "lunsig",
    "lunt": "lunta",
    "luntade": "lunta",
    "luntades": "lunta",
    "luntan": "lunta",
    "luntande": "lunta",
    "luntanden": "luntande",
    "luntandena": "luntande",
    "luntandenas": "luntande",
    "luntandens": "luntande",
    "luntandes": "luntande",
    "luntandet": "luntande",
    "luntandets": "luntande",
    "luntans": "lunta",
    "luntar": "lunta",
    "luntas": "lunta",
    "luntat": "lunta",
    "luntats": "lunta",
    "lunte": "lunta",
    "luntlåsen": "luntlås",
    "luntlåsens": "luntlås",
    "luntlåset": "luntlås",
    "luntlåsets": "luntlås",
    "luntor": "lunta",
    "luntorna": "lunta",
    "luntornas": "lunta",
    "luntors": "lunta",
    "lunts": "lunta",
    "lupe": "löpa",
    "lupen": "löpa",
    "lupens": "löpa",
    "lupes": "löpa",
    "lupet": "löpa",
    "lupets": "löpa",
    "lupinen": "lupin",
    "lupinens": "lupin",
    "lupiner": "lupin",
    "lupinerna": "lupin",
    "lupinernas": "lupin",
    "lupiners": "lupin",
    "lupins": "lupin",
    "lupit": "löpa",
    "lupits": "löpa",
    "lupna": "löpa",
    "lupnas": "löpa",
    "lupne": "löpa",
    "lupnes": "löpa",
    "luppen": "lupp",
    "luppens": "lupp",
    "lupper": "lupp",
    "lupperna": "lupp",
    "luppernas": "lupp",
    "luppers": "lupp",
    "lupps": "lupp",
    "lupusen": "lupus",
    "lupusens": "lupus",
    "lur": "lura",
    "lurad": "lura",
    "lurade": "lura",
    "lurades": "luras",
    "lurads": "lura",
    "lurande": "lura",
    "luranden": "lurande",
    "lurandena": "lurande",
    "lurandenas": "lurande",
    "lurandens": "lurande",
    "lurandes": "lurande",
    "lurandet": "lurande",
    "lurandets": "lurande",
    "lurar": "lura",
    "lurarna": "lur",
    "lurarnas": "lur",
    "lurars": "lur",
    "luras": "lura",
    "lurat": "lura",
    "lurats": "luras",
    "luren": "lur",
    "lurendrejar": "lurendrejare",
    "lurendrejaren": "lurendrejare",
    "lurendrejarens": "lurendrejare",
    "lurendrejares": "lurendrejare",
    "lurendrejarna": "lurendrejare",
    "lurendrejarnas": "lurendrejare",
    "lurendrejerier": "lurendrejeri",
    "lurendrejerierna": "lurendrejeri",
    "lurendrejeriernas": "lurendrejeri",
    "lurendrejeriers": "lurendrejeri",
    "lurendrejeriet": "lurendrejeri",
    "lurendrejeriets": "lurendrejeri",
    "lurendrejeris": "lurendrejeri",
    "lurendrejerit": "lurendrejeri",
    "lurendrejerits": "lurendrejeri",
    "lurens": "lur",
    "lurifaxar": "lurifax",
    "lurifaxarna": "lurifax",
    "lurifaxarnas": "lurifax",
    "lurifaxars": "lurifax",
    "lurifaxen": "lurifax",
    "lurifaxens": "lurifax",
    "luriga": "lurig",
    "lurigare": "lurig",
    "lurigares": "lurig",
    "lurigas": "lurig",
    "lurigast": "lurig",
    "lurigaste": "lurig",
    "lurigastes": "lurig",
    "lurigasts": "lurig",
    "lurige": "lurig",
    "luriges": "lurig",
    "lurigheten": "lurighet",
    "lurighetens": "lurighet",
    "lurigheter": "lurighet",
    "lurigheterna": "lurighet",
    "lurigheternas": "lurighet",
    "lurigheters": "lurighet",
    "lurighets": "lurighet",
    "lurigs": "lurig",
    "lurigt": "lurig",
    "lurigts": "lurig",
    "lurkar": "lurk",
    "lurkarna": "lurk",
    "lurkarnas": "lurk",
    "lurkars": "lurk",
    "lurken": "lurk",
    "lurkens": "lurk",
    "lurks": "lurk",
    "lurpass": "lurpassa",
    "lurpassad": "lurpassa",
    "lurpassade": "lurpassa",
    "lurpassades": "lurpassa",
    "lurpassads": "lurpassa",
    "lurpassande": "lurpassa",
    "lurpassanden": "lurpassande",
    "lurpassandena": "lurpassande",
    "lurpassandenas": "lurpassande",
    "lurpassandens": "lurpassande",
    "lurpassandes": "lurpassande",
    "lurpassandet": "lurpassande",
    "lurpassandets": "lurpassande",
    "lurpassar": "lurpassa",
    "lurpassas": "lurpassa",
    "lurpassat": "lurpassa",
    "lurpassats": "lurpassa",
    "lurs": "lur",
    "lurviga": "lurvig",
    "lurvigare": "lurvig",
    "lurvigares": "lurvig",
    "lurvigas": "lurvig",
    "lurvigast": "lurvig",
    "lurvigaste": "lurvig",
    "lurvigastes": "lurvig",
    "lurvigasts": "lurvig",
    "lurvige": "lurvig",
    "lurviges": "lurvig",
    "lurvigheten": "lurvighet",
    "lurvighetens": "lurvighet",
    "lurvighets": "lurvighet",
    "lurvigs": "lurvig",
    "lurvigt": "lurvig",
    "lurvigts": "lurvig",
    "lusade": "lusa",
    "lusades": "lusa",
    "lusande": "lusa",
    "lusanden": "lusande",
    "lusandena": "lusande",
    "lusandenas": "lusande",
    "lusandens": "lusande",
    "lusandes": "lusande",
    "lusandet": "lusande",
    "lusandets": "lusande",
    "lusar": "lusa",
    "lusas": "lusa",
    "lusat": "lusa",
    "lusats": "lusa",
    "lusekoft": "lusekofta",
    "lusekoftan": "lusekofta",
    "lusekoftans": "lusekofta",
    "lusekoftas": "lusekofta",
    "lusekofte": "lusekofta",
    "lusekoftor": "lusekofta",
    "lusekoftorna": "lusekofta",
    "lusekoftornas": "lusekofta",
    "lusekoftors": "lusekofta",
    "lusekofts": "lusekofta",
    "lusen": "lus",
    "lusens": "lus",
    "lusernen": "lusern",
    "lusernens": "lusern",
    "luserner": "lusern",
    "lusernerna": "lusern",
    "lusernernas": "lusern",
    "luserners": "lusern",
    "luserngrönmjölen": "luserngrönmjöl",
    "luserngrönmjölens": "luserngrönmjöl",
    "luserngrönmjölet": "luserngrönmjöl",
    "luserngrönmjölets": "luserngrönmjöl",
    "luserngrönmjöls": "luserngrönmjöl",
    "luserns": "lusern",
    "lusfattiga": "lusfattig",
    "lusfattigare": "lusfattig",
    "lusfattigares": "lusfattig",
    "lusfattigas": "lusfattig",
    "lusfattigast": "lusfattig",
    "lusfattigaste": "lusfattig",
    "lusfattigastes": "lusfattig",
    "lusfattigasts": "lusfattig",
    "lusfattige": "lusfattig",
    "lusfattiges": "lusfattig",
    "lusfattigs": "lusfattig",
    "lusfattigt": "lusfattig",
    "lusfattigts": "lusfattig",
    "lushundar": "lushund",
    "lushundarna": "lushund",
    "lushundarnas": "lushund",
    "lushundars": "lushund",
    "lushunden": "lushund",
    "lushundens": "lushund",
    "lushunds": "lushund",
    "lusiga": "lusig",
    "lusigare": "lusig",
    "lusigares": "lusig",
    "lusigas": "lusig",
    "lusigast": "lusig",
    "lusigaste": "lusig",
    "lusigastes": "lusig",
    "lusigasts": "lusig",
    "lusige": "lusig",
    "lusiges": "lusig",
    "lusigs": "lusig",
    "lusigt": "lusig",
    "lusigts": "lusig",
    "lusk": "luska",
    "luskade": "luska",
    "luskades": "luska",
    "luskande": "luska",
    "luskanden": "luskande",
    "luskandena": "luskande",
    "luskandenas": "luskande",
    "luskandens": "luskande",
    "luskandes": "luskande",
    "luskandet": "luskande",
    "luskandets": "luskande",
    "luskar": "luska",
    "luskas": "luska",
    "luskat": "luska",
    "luskats": "luska",
    "luskungar": "luskung",
    "luskungarna": "luskung",
    "luskungarnas": "luskung",
    "luskungars": "luskung",
    "luskungen": "luskung",
    "luskungens": "luskung",
    "luskungs": "luskung",
    "lusläs": "lusläsa",
    "lusläsande": "lusläsa",
    "lusläsanden": "lusläsande",
    "lusläsandena": "lusläsande",
    "lusläsandenas": "lusläsande",
    "lusläsandens": "lusläsande",
    "lusläsandes": "lusläsande",
    "lusläsandet": "lusläsande",
    "lusläsandets": "lusläsande",
    "lusläsas": "lusläsa",
    "lusläser": "lusläsa",
    "lusläses": "lusläsa",
    "lusläst": "lusläsa",
    "luslästa": "lusläsa",
    "luslästas": "lusläsa",
    "lusläste": "lusläsa",
    "luslästes": "lusläsa",
    "luslästs": "lusläsa",
    "luspanka": "luspank",
    "luspankare": "luspank",
    "luspankares": "luspank",
    "luspankas": "luspank",
    "luspankast": "luspank",
    "luspankaste": "luspank",
    "luspankastes": "luspank",
    "luspankasts": "luspank",
    "luspanke": "luspank",
    "luspankes": "luspank",
    "luspankheten": "luspankhet",
    "luspankhetens": "luspankhet",
    "luspankhets": "luspankhet",
    "luspanks": "luspank",
    "luspankt": "luspank",
    "luspankts": "luspank",
    "luspudeln": "luspudel",
    "luspudelns": "luspudel",
    "luspudels": "luspudel",
    "luspudlar": "luspudel",
    "luspudlarna": "luspudel",
    "luspudlarnas": "luspudel",
    "luspudlars": "luspudel",
    "lussade": "lussa",
    "lussades": "lussa",
    "lussande": "lussa",
    "lussanden": "lussande",
    "lussandena": "lussande",
    "lussandenas": "lussande",
    "lussandens": "lussande",
    "lussandes": "lussande",
    "lussandet": "lussande",
    "lussandets": "lussande",
    "lussar": "lussa",
    "lussas": "lussa",
    "lussat": "lussa",
    "lussats": "lussa",
    "lussebull": "lussebulle",
    "lussebullan": "lussebulla",
    "lussebullans": "lussebulla",
    "lussebullar": "lussebulle",
    "lussebullarna": "lussebulle",
    "lussebullarnas": "lussebulle",
    "lussebullars": "lussebulle",
    "lussebullas": "lussebulla",
    "lussebulle": "lussebulla",
    "lussebullen": "lussebulle",
    "lussebullens": "lussebulle",
    "lussebulles": "lussebulle",
    "lussebullor": "lussebulla",
    "lussebullorna": "lussebulla",
    "lussebullornas": "lussebulla",
    "lussebullors": "lussebulla",
    "lussebulls": "lussebulle",
    "lussefesten": "lussefest",
    "lussefestens": "lussefest",
    "lussefester": "lussefest",
    "lussefesterna": "lussefest",
    "lussefesternas": "lussefest",
    "lussefesters": "lussefest",
    "lussefests": "lussefest",
    "lussekatten": "lussekatt",
    "lussekattens": "lussekatt",
    "lussekatter": "lussekatt",
    "lussekatterna": "lussekatt",
    "lussekatternas": "lussekatt",
    "lussekatters": "lussekatt",
    "lussekatts": "lussekatt",
    "lusses": "lusse",
    "lustan": "lusta",
    "lustans": "lusta",
    "lustar": "lust",
    "lustarna": "lust",
    "lustarnas": "lust",
    "lustars": "lust",
    "lustas": "lusta",
    "lustbarheten": "lustbarhet",
    "lustbarhetens": "lustbarhet",
    "lustbarheter": "lustbarhet",
    "lustbarheterna": "lustbarhet",
    "lustbarheternas": "lustbarhet",
    "lustbarheters": "lustbarhet",
    "lustbarhets": "lustbarhet",
    "lustbehoven": "lustbehov",
    "lustbehovens": "lustbehov",
    "lustbehovet": "lustbehov",
    "lustbehovets": "lustbehov",
    "lustbehovs": "lustbehov",
    "lustbetonade": "lustbetonad",
    "lustbetonades": "lustbetonad",
    "lustbetonads": "lustbetonad",
    "lustbetonat": "lustbetonad",
    "lustbetonats": "lustbetonad",
    "lustcentra": "lustcentrum",
    "lustcentrana": "lustcentrum",
    "lustcentranas": "lustcentrum",
    "lustcentras": "lustcentrum",
    "lustcentrer": "lustcentrum",
    "lustcentrerna": "lustcentrum",
    "lustcentrernas": "lustcentrum",
    "lustcentrers": "lustcentrum",
    "lustcentret": "lustcentrum",
    "lustcentrets": "lustcentrum",
    "lustcentrumen": "lustcentrum",
    "lustcentrumens": "lustcentrum",
    "lustcentrumet": "lustcentrum",
    "lustcentrumets": "lustcentrum",
    "lustcentrums": "lustcentrum",
    "lusteliga": "lustelig",
    "lusteligare": "lustelig",
    "lusteligares": "lustelig",
    "lusteligas": "lustelig",
    "lusteligast": "lustelig",
    "lusteligaste": "lustelig",
    "lusteligastes": "lustelig",
    "lusteligasts": "lustelig",
    "lustelige": "lustelig",
    "lusteliges": "lustelig",
    "lusteligheten": "lustelighet",
    "lustelighetens": "lustelighet",
    "lustelighets": "lustelighet",
    "lusteligs": "lustelig",
    "lusteligt": "lustelig",
    "lusteligts": "lustelig",
    "lusten": "lust",
    "lustens": "lust",
    "lustfyllda": "lustfylld",
    "lustfylldare": "lustfylld",
    "lustfylldares": "lustfylld",
    "lustfylldas": "lustfylld",
    "lustfylldast": "lustfylld",
    "lustfylldaste": "lustfylld",
    "lustfylldastes": "lustfylld",
    "lustfylldasts": "lustfylld",
    "lustfyllde": "lustfylld",
    "lustfylldes": "lustfylld",
    "lustfylldheten": "lustfylldhet",
    "lustfylldhetens": "lustfylldhet",
    "lustfylldhets": "lustfylldhet",
    "lustfyllds": "lustfylld",
    "lustfyllt": "lustfylld",
    "lustfyllts": "lustfylld",
    "lustgasen": "lustgas",
    "lustgasens": "lustgas",
    "lustgaser": "lustgas",
    "lustgaserna": "lustgas",
    "lustgasernas": "lustgas",
    "lustgasers": "lustgas",
    "lustgårdar": "lustgård",
    "lustgårdarna": "lustgård",
    "lustgårdarnas": "lustgård",
    "lustgårdars": "lustgård",
    "lustgården": "lustgård",
    "lustgårdens": "lustgård",
    "lustgårds": "lustgård",
    "lusthusen": "lusthus",
    "lusthusens": "lusthus",
    "lusthuset": "lusthus",
    "lusthusets": "lusthus",
    "lustiga": "lustig",
    "lustigare": "lustig",
    "lustigares": "lustig",
    "lustigas": "lustig",
    "lustigast": "lustig",
    "lustigaste": "lustig",
    "lustigastes": "lustig",
    "lustigasts": "lustig",
    "lustige": "lustig",
    "lustiges": "lustig",
    "lustigheten": "lustighet",
    "lustighetens": "lustighet",
    "lustigheter": "lustighet",
    "lustigheterna": "lustighet",
    "lustigheternas": "lustighet",
    "lustigheters": "lustighet",
    "lustighets": "lustighet",
    "lustigkurr": "lustigkurre",
    "lustigkurrar": "lustigkurre",
    "lustigkurrarna": "lustigkurre",
    "lustigkurrarnas": "lustigkurre",
    "lustigkurrars": "lustigkurre",
    "lustigkurren": "lustigkurre",
    "lustigkurrens": "lustigkurre",
    "lustigkurres": "lustigkurre",
    "lustigkurrs": "lustigkurre",
    "lustigs": "lustig",
    "lustigt": "lustig",
    "lustigts": "lustig",
    "lustimpulsen": "lustimpuls",
    "lustimpulsens": "lustimpuls",
    "lustimpulser": "lustimpuls",
    "lustimpulserna": "lustimpuls",
    "lustimpulsernas": "lustimpuls",
    "lustimpulsers": "lustimpuls",
    "lustjakten": "lustjakt",
    "lustjaktens": "lustjakt",
    "lustjakter": "lustjakt",
    "lustjakterna": "lustjakt",
    "lustjakternas": "lustjakt",
    "lustjakters": "lustjakt",
    "lustjakts": "lustjakt",
    "lustkänsl": "lustkänsla",
    "lustkänslan": "lustkänsla",
    "lustkänslans": "lustkänsla",
    "lustkänslas": "lustkänsla",
    "lustkänsle": "lustkänsla",
    "lustkänslo": "lustkänsla",
    "lustkänslor": "lustkänsla",
    "lustkänslorna": "lustkänsla",
    "lustkänslornas": "lustkänsla",
    "lustkänslors": "lustkänsla",
    "lustlögnar": "lustlögnare",
    "lustlögnaren": "lustlögnare",
    "lustlögnarens": "lustlögnare",
    "lustlögnares": "lustlögnare",
    "lustlögnarna": "lustlögnare",
    "lustlögnarnas": "lustlögnare",
    "lustmorden": "lustmord",
    "lustmordens": "lustmord",
    "lustmordet": "lustmord",
    "lustmordets": "lustmord",
    "lustmords": "lustmord",
    "lustmördar": "lustmördare",
    "lustmördaren": "lustmördare",
    "lustmördarens": "lustmördare",
    "lustmördares": "lustmördare",
    "lustmördarna": "lustmördare",
    "lustmördarnas": "lustmördare",
    "lusts": "lust",
    "lustslotten": "lustslott",
    "lustslottens": "lustslott",
    "lustslottet": "lustslott",
    "lustslottets": "lustslott",
    "lustslotts": "lustslott",
    "lustspelen": "lustspel",
    "lustspelens": "lustspel",
    "lustspelet": "lustspel",
    "lustspelets": "lustspel",
    "lustspels": "lustspel",
    "lustupplevelsen": "lustupplevelse",
    "lustupplevelsens": "lustupplevelse",
    "lustupplevelser": "lustupplevelse",
    "lustupplevelserna": "lustupplevelse",
    "lustupplevelsernas": "lustupplevelse",
    "lustupplevelsers": "lustupplevelse",
    "lustupplevelses": "lustupplevelse",
    "lut": "luta",
    "lutad": "luta",
    "lutade": "luta",
    "lutades": "luta",
    "lutads": "luta",
    "lutan": "luta",
    "lutande": "luta",
    "lutanden": "lutande",
    "lutandena": "lutande",
    "lutandenas": "lutande",
    "lutandens": "lutande",
    "lutandes": "lutande",
    "lutandet": "lutande",
    "lutandets": "lutande",
    "lutans": "luta",
    "lutar": "luta",
    "lutarna": "lut",
    "lutarnas": "lut",
    "lutars": "lut",
    "lutas": "luta",
    "lutat": "luta",
    "lutats": "luta",
    "lute": "luta",
    "luteiniserad": "luteinisera",
    "luteiniserade": "luteinisera",
    "luteiniserades": "luteinisera",
    "luteiniserads": "luteinisera",
    "luteiniserande": "luteinisera",
    "luteiniseranden": "luteiniserande",
    "luteiniserandena": "luteiniserande",
    "luteiniserandenas": "luteiniserande",
    "luteiniserandens": "luteiniserande",
    "luteiniserandes": "luteiniserande",
    "luteiniserandet": "luteiniserande",
    "luteiniserandets": "luteiniserande",
    "luteiniserar": "luteinisera",
    "luteiniseras": "luteinisera",
    "luteiniserat": "luteinisera",
    "luteiniserats": "luteinisera",
    "luteiniserbara": "luteiniserbar",
    "luteiniserbarare": "luteiniserbar",
    "luteiniserbarares": "luteiniserbar",
    "luteiniserbaras": "luteiniserbar",
    "luteiniserbarast": "luteiniserbar",
    "luteiniserbaraste": "luteiniserbar",
    "luteiniserbarastes": "luteiniserbar",
    "luteiniserbarasts": "luteiniserbar",
    "luteiniserbare": "luteiniserbar",
    "luteiniserbares": "luteiniserbar",
    "luteiniserbarheten": "luteiniserbarhet",
    "luteiniserbarhetens": "luteiniserbarhet",
    "luteiniserbarhets": "luteiniserbarhet",
    "luteiniserbars": "luteiniserbar",
    "luteiniserbart": "luteiniserbar",
    "luteiniserbarts": "luteiniserbar",
    "luteiniseringar": "luteinisering",
    "luteiniseringarna": "luteinisering",
    "luteiniseringarnas": "luteinisering",
    "luteiniseringars": "luteinisering",
    "luteiniseringen": "luteinisering",
    "luteiniseringens": "luteinisering",
    "luteiniserings": "luteinisering",
    "luten": "lut",
    "lutens": "lut",
    "lutet": "lut",
    "lutetiet": "lutetium",
    "lutetiets": "lutetium",
    "lutetiumet": "lutetium",
    "lutetiumets": "lutetium",
    "lutetiums": "lutetium",
    "lutets": "lut",
    "lutfiskar": "lutfisk",
    "lutfiskarna": "lutfisk",
    "lutfiskarnas": "lutfisk",
    "lutfiskars": "lutfisk",
    "lutfisken": "lutfisk",
    "lutfiskens": "lutfisk",
    "lutfisks": "lutfisk",
    "lutheranen": "lutheran",
    "lutheranens": "lutheran",
    "lutheraner": "lutheran",
    "lutheranerna": "lutheran",
    "lutheranernas": "lutheran",
    "lutheraners": "lutheran",
    "lutheranismen": "lutheranism",
    "lutheranismens": "lutheranism",
    "lutheranismer": "lutheranism",
    "lutheranismerna": "lutheranism",
    "lutheranismernas": "lutheranism",
    "lutheranismers": "lutheranism",
    "lutheranisms": "lutheranism",
    "lutherans": "lutheran",
    "lutherdomar": "lutherdom",
    "lutherdomarna": "lutherdom",
    "lutherdomarnas": "lutherdom",
    "lutherdomars": "lutherdom",
    "lutherdomen": "lutherdom",
    "lutherdomens": "lutherdom",
    "lutherdoms": "lutherdom",
    "lutherska": "luthersk",
    "lutherskare": "luthersk",
    "lutherskares": "luthersk",
    "lutherskas": "luthersk",
    "lutherskast": "luthersk",
    "lutherskaste": "luthersk",
    "lutherskastes": "luthersk",
    "lutherskasts": "luthersk",
    "lutherske": "luthersk",
    "lutherskes": "luthersk",
    "luthersks": "luthersk",
    "lutherskt": "luthersk",
    "lutherskts": "luthersk",
    "lutningar": "lutning",
    "lutningarna": "lutning",
    "lutningarnas": "lutning",
    "lutningars": "lutning",
    "lutningen": "lutning",
    "lutningens": "lutning",
    "lutnings": "lutning",
    "lutningsmätar": "lutningsmätare",
    "lutningsmätaren": "lutningsmätare",
    "lutningsmätarens": "lutningsmätare",
    "lutningsmätares": "lutningsmätare",
    "lutningsmätarna": "lutningsmätare",
    "lutningsmätarnas": "lutningsmätare",
    "lutningsstrecken": "lutningsstreck",
    "lutningsstreckens": "lutningsstreck",
    "lutningsstrecket": "lutningsstreck",
    "lutningsstreckets": "lutningsstreck",
    "lutningsstrecks": "lutningsstreck",
    "lutningsvariationen": "lutningsvariation",
    "lutningsvariationens": "lutningsvariation",
    "lutningsvariationer": "lutningsvariation",
    "lutningsvariationerna": "lutningsvariation",
    "lutningsvariationernas": "lutningsvariation",
    "lutningsvariationers": "lutningsvariation",
    "lutningsvariations": "lutningsvariation",
    "lutor": "luta",
    "lutorna": "luta",
    "lutornas": "luta",
    "lutors": "luta",
    "luts": "luta",
    "lutsångar": "lutsångare",
    "lutsångaren": "lutsångare",
    "lutsångarens": "lutsångare",
    "lutsångares": "lutsångare",
    "lutsångarna": "lutsångare",
    "lutsångarnas": "lutsångare",
    "lutter": "luttra",
    "luttrad": "luttra",
    "luttrade": "luttrad",
    "luttrades": "luttrad",
    "luttrads": "luttrad",
    "luttrande": "luttra",
    "luttranden": "luttrande",
    "luttrandena": "luttrande",
    "luttrandenas": "luttrande",
    "luttrandens": "luttrande",
    "luttrandes": "luttrande",
    "luttrandet": "luttrande",
    "luttrandets": "luttrande",
    "luttrar": "luttra",
    "luttras": "luttra",
    "luttrat": "luttrad",
    "luttrats": "luttrad",
    "luv": "luva",
    "luvan": "luva",
    "luvans": "luva",
    "luvar": "luv",
    "luvarna": "luv",
    "luvarnas": "luv",
    "luvars": "luv",
    "luvas": "luva",
    "luve": "luva",
    "luven": "luv",
    "luvens": "luv",
    "luvor": "luva",
    "luvorna": "luva",
    "luvornas": "luva",
    "luvors": "luva",
    "luvs": "luva",
    "luxationen": "luxation",
    "luxationens": "luxation",
    "luxationer": "luxation",
    "luxationerna": "luxation",
    "luxationernas": "luxation",
    "luxationers": "luxation",
    "luxations": "luxation",
    "luxemburgar": "luxemburgare",
    "luxemburgaren": "luxemburgare",
    "luxemburgarens": "luxemburgare",
    "luxemburgares": "luxemburgare",
    "luxemburgarna": "luxemburgare",
    "luxemburgarnas": "luxemburgare",
    "luxemburgska": "luxemburgsk",
    "luxemburgskan": "luxemburgska",
    "luxemburgskans": "luxemburgska",
    "luxemburgskare": "luxemburgsk",
    "luxemburgskares": "luxemburgsk",
    "luxemburgskas": "luxemburgska",
    "luxemburgskast": "luxemburgsk",
    "luxemburgskaste": "luxemburgsk",
    "luxemburgskastes": "luxemburgsk",
    "luxemburgskasts": "luxemburgsk",
    "luxemburgske": "luxemburgska",
    "luxemburgskes": "luxemburgsk",
    "luxemburgskor": "luxemburgska",
    "luxemburgskorna": "luxemburgska",
    "luxemburgskornas": "luxemburgska",
    "luxemburgskors": "luxemburgska",
    "luxemburgsks": "luxemburgsk",
    "luxemburgskt": "luxemburgsk",
    "luxemburgskts": "luxemburgsk",
    "luxen": "lux",
    "luxens": "lux",
    "luxmetern": "luxmeter",
    "luxmeterns": "luxmeter",
    "luxmeters": "luxmeter",
    "luxmetrar": "luxmeter",
    "luxmetrarna": "luxmeter",
    "luxmetrarnas": "luxmeter",
    "luxmetrars": "luxmeter",
    "luxuösa": "luxuös",
    "luxuösare": "luxuös",
    "luxuösares": "luxuös",
    "luxuösas": "luxuös",
    "luxuösast": "luxuös",
    "luxuösaste": "luxuös",
    "luxuösastes": "luxuös",
    "luxuösasts": "luxuös",
    "luxuöse": "luxuös",
    "luxuöses": "luxuös",
    "luxuöst": "luxuös",
    "luxuösts": "luxuös",
    "ly": "lya",
    "lyan": "lya",
    "lyans": "lya",
    "lyas": "lya",
    "lyceer": "lyceum",
    "lyceerna": "lyceum",
    "lyceernas": "lyceum",
    "lyceers": "lyceum",
    "lyceet": "lyceum",
    "lyceets": "lyceum",
    "lycei": "lyceum",
    "lyceums": "lyceum",
    "lyck": "lycka",
    "lyckade": "lyckad",
    "lyckades": "lyckas",
    "lyckads": "lyckad",
    "lyckan": "lycka",
    "lyckans": "lycka",
    "lyckas": "lycka",
    "lyckat": "lyckad",
    "lyckats": "lyckas",
    "lycke": "lycka",
    "lyckliga": "lycklig",
    "lyckligare": "lycklig",
    "lyckligares": "lycklig",
    "lyckligas": "lycklig",
    "lyckligast": "lycklig",
    "lyckligaste": "lycklig",
    "lyckligastes": "lycklig",
    "lyckligasts": "lycklig",
    "lycklige": "lycklig",
    "lyckliges": "lycklig",
    "lyckligheten": "lycklighet",
    "lycklighetens": "lycklighet",
    "lyckligheter": "lycklighet",
    "lyckligheterna": "lycklighet",
    "lyckligheternas": "lycklighet",
    "lyckligheters": "lycklighet",
    "lycklighets": "lycklighet",
    "lyckligs": "lycklig",
    "lyckligt": "lycklig",
    "lyckligts": "lycklig",
    "lycko": "lycka",
    "lyckohjulen": "lyckohjul",
    "lyckohjulens": "lyckohjul",
    "lyckohjulet": "lyckohjul",
    "lyckohjulets": "lyckohjul",
    "lyckohjuls": "lyckohjul",
    "lyckokasten": "lyckokast",
    "lyckokastens": "lyckokast",
    "lyckokastet": "lyckokast",
    "lyckokastets": "lyckokast",
    "lyckokasts": "lyckokast",
    "lyckoklövern": "lyckoklöver",
    "lyckoklöverna": "lyckoklöver",
    "lyckoklövernas": "lyckoklöver",
    "lyckoklöverns": "lyckoklöver",
    "lyckoklövers": "lyckoklöver",
    "lyckopillerna": "lyckopiller",
    "lyckopillernas": "lyckopiller",
    "lyckopillers": "lyckopiller",
    "lyckopillren": "lyckopiller",
    "lyckopillrens": "lyckopiller",
    "lyckopillret": "lyckopiller",
    "lyckopillrets": "lyckopiller",
    "lyckor": "lycka",
    "lyckoriken": "lyckorike",
    "lyckorikena": "lyckorike",
    "lyckorikenas": "lyckorike",
    "lyckorikens": "lyckorike",
    "lyckorikes": "lyckorike",
    "lyckoriket": "lyckorike",
    "lyckorikets": "lyckorike",
    "lyckorna": "lycka",
    "lyckornas": "lycka",
    "lyckors": "lycka",
    "lyckorusen": "lyckorus",
    "lyckorusens": "lyckorus",
    "lyckoruset": "lyckorus",
    "lyckorusets": "lyckorus",
    "lyckosamheten": "lyckosamhet",
    "lyckosamhetens": "lyckosamhet",
    "lyckosamhets": "lyckosamhet",
    "lyckosamma": "lyckosam",
    "lyckosammare": "lyckosam",
    "lyckosammares": "lyckosam",
    "lyckosammas": "lyckosam",
    "lyckosammast": "lyckosam",
    "lyckosammaste": "lyckosam",
    "lyckosammastes": "lyckosam",
    "lyckosammasts": "lyckosam",
    "lyckosamme": "lyckosam",
    "lyckosammes": "lyckosam",
    "lyckosams": "lyckosam",
    "lyckosamt": "lyckosam",
    "lyckosamts": "lyckosam",
    "lyckoslantar": "lyckoslant",
    "lyckoslantarna": "lyckoslant",
    "lyckoslantarnas": "lyckoslant",
    "lyckoslantars": "lyckoslant",
    "lyckoslanten": "lyckoslant",
    "lyckoslantens": "lyckoslant",
    "lyckoslants": "lyckoslant",
    "lyckostjärnan": "lyckostjärna",
    "lyckostjärnans": "lyckostjärna",
    "lyckostjärnas": "lyckostjärna",
    "lyckostjärne": "lyckostjärna",
    "lyckostjärnor": "lyckostjärna",
    "lyckostjärnorna": "lyckostjärna",
    "lyckostjärnornas": "lyckostjärna",
    "lyckostjärnors": "lyckostjärna",
    "lyckotalen": "lyckotal",
    "lyckotalens": "lyckotal",
    "lyckotalet": "lyckotal",
    "lyckotalets": "lyckotal",
    "lyckotals": "lyckotal",
    "lyckoåren": "lyckoår",
    "lyckoårens": "lyckoår",
    "lyckoåret": "lyckoår",
    "lyckoårets": "lyckoår",
    "lyckoårs": "lyckoår",
    "lycks": "lycka",
    "lycksaliga": "lycksalig",
    "lycksaligare": "lycksalig",
    "lycksaligares": "lycksalig",
    "lycksaligas": "lycksalig",
    "lycksaligast": "lycksalig",
    "lycksaligaste": "lycksalig",
    "lycksaligastes": "lycksalig",
    "lycksaligasts": "lycksalig",
    "lycksalige": "lycksalig",
    "lycksaliges": "lycksalig",
    "lycksaligheten": "lycksalighet",
    "lycksalighetens": "lycksalighet",
    "lycksalighets": "lycksalighet",
    "lycksaligs": "lycksalig",
    "lycksaligt": "lycksalig",
    "lycksaligts": "lycksalig",
    "lycksökar": "lycksökare",
    "lycksökaren": "lycksökare",
    "lycksökarens": "lycksökare",
    "lycksökares": "lycksökare",
    "lycksökarna": "lycksökare",
    "lycksökarnas": "lycksökare",
    "lyckträffar": "lyckträff",
    "lyckträffarna": "lyckträff",
    "lyckträffarnas": "lyckträff",
    "lyckträffars": "lyckträff",
    "lyckträffen": "lyckträff",
    "lyckträffens": "lyckträff",
    "lyckträffs": "lyckträff",
    "lyckönsk": "lyckönska",
    "lyckönskad": "lyckönska",
    "lyckönskade": "lyckönska",
    "lyckönskades": "lyckönska",
    "lyckönskads": "lyckönska",
    "lyckönskande": "lyckönska",
    "lyckönskanden": "lyckönskande",
    "lyckönskandena": "lyckönskande",
    "lyckönskandenas": "lyckönskande",
    "lyckönskandens": "lyckönskande",
    "lyckönskandes": "lyckönskande",
    "lyckönskandet": "lyckönskande",
    "lyckönskandets": "lyckönskande",
    "lyckönskans": "lyckönskan",
    "lyckönskar": "lyckönska",
    "lyckönskas": "lyckönska",
    "lyckönskat": "lyckönska",
    "lyckönskats": "lyckönska",
    "lyckönskningar": "lyckönskning",
    "lyckönskningarna": "lyckönskning",
    "lyckönskningarnas": "lyckönskning",
    "lyckönskningars": "lyckönskning",
    "lyckönskningen": "lyckönskning",
    "lyckönskningens": "lyckönskning",
    "lyckönsknings": "lyckönskning",
    "lyd": "lyda",
    "lydaktiga": "lydaktig",
    "lydaktigare": "lydaktig",
    "lydaktigares": "lydaktig",
    "lydaktigas": "lydaktig",
    "lydaktigast": "lydaktig",
    "lydaktigaste": "lydaktig",
    "lydaktigastes": "lydaktig",
    "lydaktigasts": "lydaktig",
    "lydaktige": "lydaktig",
    "lydaktiges": "lydaktig",
    "lydaktigheten": "lydaktighet",
    "lydaktighetens": "lydaktighet",
    "lydaktighets": "lydaktighet",
    "lydaktigs": "lydaktig",
    "lydaktigt": "lydaktig",
    "lydaktigts": "lydaktig",
    "lydande": "lyda",
    "lydanden": "lydande",
    "lydandena": "lydande",
    "lydandenas": "lydande",
    "lydandens": "lydande",
    "lydandes": "lydande",
    "lydandet": "lydande",
    "lydandets": "lydande",
    "lydas": "lyda",
    "lydd": "lyda",
    "lydda": "lyda",
    "lyddas": "lyda",
    "lydde": "lyda",
    "lyddes": "lyda",
    "lydds": "lyda",
    "lyde": "lyda",
    "lydelsen": "lydelse",
    "lydelsens": "lydelse",
    "lydelser": "lydelse",
    "lydelserna": "lydelse",
    "lydelsernas": "lydelse",
    "lydelsers": "lydelse",
    "lydelses": "lydelse",
    "lyder": "lyda",
    "lydes": "lyda",
    "lydfolken": "lydfolk",
    "lydfolkens": "lydfolk",
    "lydfolket": "lydfolk",
    "lydfolkets": "lydfolk",
    "lydfolks": "lydfolk",
    "lydiga": "lydig",
    "lydigare": "lydig",
    "lydigares": "lydig",
    "lydigas": "lydig",
    "lydigast": "lydig",
    "lydigaste": "lydig",
    "lydigastes": "lydig",
    "lydigasts": "lydig",
    "lydige": "lydig",
    "lydiges": "lydig",
    "lydigs": "lydig",
    "lydigt": "lydig",
    "lydigts": "lydig",
    "lydkonungar": "lydkonung",
    "lydkonungarna": "lydkonung",
    "lydkonungarnas": "lydkonung",
    "lydkonungars": "lydkonung",
    "lydkonungen": "lydkonung",
    "lydkonungens": "lydkonung",
    "lydkonungs": "lydkonung",
    "lydkungar": "lydkung",
    "lydkungarna": "lydkung",
    "lydkungarnas": "lydkung",
    "lydkungars": "lydkung",
    "lydkungen": "lydkung",
    "lydkungens": "lydkung",
    "lydkungs": "lydkung",
    "lydnaden": "lydnad",
    "lydnadens": "lydnad",
    "lydnader": "lydnad",
    "lydnaderna": "lydnad",
    "lydnadernas": "lydnad",
    "lydnaders": "lydnad",
    "lydnads": "lydnad",
    "lydnadsbrotten": "lydnadsbrott",
    "lydnadsbrottens": "lydnadsbrott",
    "lydnadsbrottet": "lydnadsbrott",
    "lydnadsbrottets": "lydnadsbrott",
    "lydnadsbrotts": "lydnadsbrott",
    "lyds": "lyda",
    "lydstaten": "lydstat",
    "lydstatens": "lydstat",
    "lydstater": "lydstat",
    "lydstaterna": "lydstat",
    "lydstaternas": "lydstat",
    "lydstaters": "lydstat",
    "lydstats": "lydstat",
    "lye": "lya",
    "lyet": "ly",
    "lyets": "ly",
    "lyft": "lyfta",
    "lyftande": "lyfta",
    "lyftanden": "lyftande",
    "lyftandena": "lyftande",
    "lyftandenas": "lyftande",
    "lyftandens": "lyftande",
    "lyftandes": "lyftande",
    "lyftandet": "lyftande",
    "lyftandets": "lyftande",
    "lyftanordningar": "lyftanordning",
    "lyftanordningarna": "lyftanordning",
    "lyftanordningarnas": "lyftanordning",
    "lyftanordningars": "lyftanordning",
    "lyftanordningen": "lyftanordning",
    "lyftanordningens": "lyftanordning",
    "lyftanordnings": "lyftanordning",
    "lyftarmar": "lyftarm",
    "lyftarmarna": "lyftarm",
    "lyftarmarnas": "lyftarm",
    "lyftarmars": "lyftarm",
    "lyftarmen": "lyftarm",
    "lyftarmens": "lyftarm",
    "lyftarms": "lyftarm",
    "lyftas": "lyfta",
    "lyftblocken": "lyftblock",
    "lyftblockens": "lyftblock",
    "lyftblocket": "lyftblock",
    "lyftblockets": "lyftblock",
    "lyftblocks": "lyftblock",
    "lyftbroar": "lyftbro",
    "lyftbroarna": "lyftbro",
    "lyftbroarnas": "lyftbro",
    "lyftbroars": "lyftbro",
    "lyftbron": "lyftbro",
    "lyftbrons": "lyftbro",
    "lyftbros": "lyftbro",
    "lyfte": "lyfta",
    "lyften": "lyft",
    "lyftens": "lyft",
    "lyfter": "lyfta",
    "lyftes": "lyfta",
    "lyftet": "lyft",
    "lyftets": "lyft",
    "lyfthöjden": "lyfthöjd",
    "lyfthöjdens": "lyfthöjd",
    "lyfthöjder": "lyfthöjd",
    "lyfthöjderna": "lyfthöjd",
    "lyfthöjdernas": "lyfthöjd",
    "lyfthöjders": "lyfthöjd",
    "lyfthöjds": "lyfthöjd",
    "lyftkapaciteten": "lyftkapacitet",
    "lyftkapacitetens": "lyftkapacitet",
    "lyftkapaciteter": "lyftkapacitet",
    "lyftkapaciteterna": "lyftkapacitet",
    "lyftkapaciteternas": "lyftkapacitet",
    "lyftkapaciteters": "lyftkapacitet",
    "lyftkapacitets": "lyftkapacitet",
    "lyftkraften": "lyftkraft",
    "lyftkraftens": "lyftkraft",
    "lyftkrafter": "lyftkraft",
    "lyftkrafterna": "lyftkraft",
    "lyftkrafternas": "lyftkraft",
    "lyftkrafters": "lyftkraft",
    "lyftkrafts": "lyftkraft",
    "lyftkranar": "lyftkran",
    "lyftkranarna": "lyftkran",
    "lyftkranarnas": "lyftkran",
    "lyftkranars": "lyftkran",
    "lyftkranen": "lyftkran",
    "lyftkranens": "lyftkran",
    "lyftkrans": "lyftkran",
    "lyftkrokar": "lyftkrok",
    "lyftkrokarna": "lyftkrok",
    "lyftkrokarnas": "lyftkrok",
    "lyftkrokars": "lyftkrok",
    "lyftkroken": "lyftkrok",
    "lyftkrokens": "lyftkrok",
    "lyftkroks": "lyftkrok",
    "lyftningar": "lyftning",
    "lyftningarna": "lyftning",
    "lyftningarnas": "lyftning",
    "lyftningars": "lyftning",
    "lyftningen": "lyftning",
    "lyftningens": "lyftning",
    "lyftnings": "lyftning",
    "lyftpunkten": "lyftpunkt",
    "lyftpunktens": "lyftpunkt",
    "lyftpunkter": "lyftpunkt",
    "lyftpunkterna": "lyftpunkt",
    "lyftpunkternas": "lyftpunkt",
    "lyftpunkters": "lyftpunkt",
    "lyftpunkts": "lyftpunkt",
    "lyfts": "lyfta",
    "lyftsaxar": "lyftsax",
    "lyftsaxarna": "lyftsax",
    "lyftsaxarnas": "lyftsax",
    "lyftsaxars": "lyftsax",
    "lyftsaxen": "lyftsax",
    "lyftsaxens": "lyftsax",
    "lyftskydden": "lyftskydd",
    "lyftskyddens": "lyftskydd",
    "lyftskyddet": "lyftskydd",
    "lyftskyddets": "lyftskydd",
    "lyftskydds": "lyftskydd",
    "lyftverken": "lyftverk",
    "lyftverkens": "lyftverk",
    "lyftverket": "lyftverk",
    "lyftverkets": "lyftverk",
    "lyftverks": "lyftverk",
    "lyhörda": "lyhörd",
    "lyhördare": "lyhörd",
    "lyhördares": "lyhörd",
    "lyhördas": "lyhörd",
    "lyhördast": "lyhörd",
    "lyhördaste": "lyhörd",
    "lyhördastes": "lyhörd",
    "lyhördasts": "lyhörd",
    "lyhörde": "lyhörd",
    "lyhördes": "lyhörd",
    "lyhördheten": "lyhördhet",
    "lyhördhetens": "lyhördhet",
    "lyhördhets": "lyhördhet",
    "lyhörds": "lyhörd",
    "lyhört": "lyhörd",
    "lyhörts": "lyhörd",
    "lykt": "lykta",
    "lyktad": "lykta",
    "lyktade": "lykta",
    "lyktades": "lykta",
    "lyktads": "lykta",
    "lyktan": "lykta",
    "lyktande": "lykta",
    "lyktanden": "lyktande",
    "lyktandena": "lyktande",
    "lyktandenas": "lyktande",
    "lyktandens": "lyktande",
    "lyktandes": "lyktande",
    "lyktandet": "lyktande",
    "lyktandets": "lyktande",
    "lyktans": "lykta",
    "lyktar": "lykta",
    "lyktas": "lykta",
    "lyktat": "lykta",
    "lyktats": "lykta",
    "lyktbärar": "lyktbärare",
    "lyktbäraren": "lyktbärare",
    "lyktbärarens": "lyktbärare",
    "lyktbärares": "lyktbärare",
    "lyktbärarna": "lyktbärare",
    "lyktbärarnas": "lyktbärare",
    "lyktbären": "lyktbär",
    "lyktbärens": "lyktbär",
    "lyktbäret": "lyktbär",
    "lyktbärets": "lyktbär",
    "lyktbärs": "lyktbär",
    "lykte": "lykta",
    "lyktglasen": "lyktglas",
    "lyktglasens": "lyktglas",
    "lyktglaset": "lyktglas",
    "lyktglasets": "lyktglas",
    "lyktgubb": "lyktgubbe",
    "lyktgubbar": "lyktgubbe",
    "lyktgubbarna": "lyktgubbe",
    "lyktgubbarnas": "lyktgubbe",
    "lyktgubbars": "lyktgubbe",
    "lyktgubben": "lyktgubbe",
    "lyktgubbens": "lyktgubbe",
    "lyktgubbes": "lyktgubbe",
    "lyktgubbs": "lyktgubbe",
    "lyktor": "lykta",
    "lyktorna": "lykta",
    "lyktornas": "lykta",
    "lyktors": "lykta",
    "lyktraden": "lyktrad",
    "lyktradens": "lyktrad",
    "lyktrader": "lyktrad",
    "lyktraderna": "lyktrad",
    "lyktradernas": "lyktrad",
    "lyktraders": "lyktrad",
    "lyktrads": "lyktrad",
    "lykts": "lykta",
    "lyktstolp": "lyktstolpe",
    "lyktstolpar": "lyktstolpe",
    "lyktstolparna": "lyktstolpe",
    "lyktstolparnas": "lyktstolpe",
    "lyktstolpars": "lyktstolpe",
    "lyktstolpen": "lyktstolpe",
    "lyktstolpens": "lyktstolpe",
    "lyktstolpes": "lyktstolpe",
    "lyktstolps": "lyktstolpe",
    "lymfan": "lymfa",
    "lymfans": "lymfa",
    "lymfas": "lymfa",
    "lymfatiska": "lymfatisk",
    "lymfatiskare": "lymfatisk",
    "lymfatiskares": "lymfatisk",
    "lymfatiskas": "lymfatisk",
    "lymfatiskast": "lymfatisk",
    "lymfatiskaste": "lymfatisk",
    "lymfatiskastes": "lymfatisk",
    "lymfatiskasts": "lymfatisk",
    "lymfatiske": "lymfatisk",
    "lymfatiskes": "lymfatisk",
    "lymfatisks": "lymfatisk",
    "lymfatiskt": "lymfatisk",
    "lymfatiskts": "lymfatisk",
    "lymfkärlen": "lymfkärl",
    "lymfkärlens": "lymfkärl",
    "lymfkärlet": "lymfkärl",
    "lymfkärlets": "lymfkärl",
    "lymfkärls": "lymfkärl",
    "lymfkörteln": "lymfkörtel",
    "lymfkörtelns": "lymfkörtel",
    "lymfkörtels": "lymfkörtel",
    "lymfkörtlar": "lymfkörtel",
    "lymfkörtlarna": "lymfkörtel",
    "lymfkörtlarnas": "lymfkörtel",
    "lymfkörtlars": "lymfkörtel",
    "lymfocyten": "lymfocyt",
    "lymfocytens": "lymfocyt",
    "lymfocyter": "lymfocyt",
    "lymfocyterna": "lymfocyt",
    "lymfocyternas": "lymfocyt",
    "lymfocyters": "lymfocyt",
    "lymfocyts": "lymfocyt",
    "lymlar": "lymmel",
    "lymlarna": "lymmel",
    "lymlarnas": "lymmel",
    "lymlars": "lymmel",
    "lymmelaktiga": "lymmelaktig",
    "lymmelaktigare": "lymmelaktig",
    "lymmelaktigares": "lymmelaktig",
    "lymmelaktigas": "lymmelaktig",
    "lymmelaktigast": "lymmelaktig",
    "lymmelaktigaste": "lymmelaktig",
    "lymmelaktigastes": "lymmelaktig",
    "lymmelaktigasts": "lymmelaktig",
    "lymmelaktige": "lymmelaktig",
    "lymmelaktiges": "lymmelaktig",
    "lymmelaktigheten": "lymmelaktighet",
    "lymmelaktighetens": "lymmelaktighet",
    "lymmelaktighets": "lymmelaktighet",
    "lymmelaktigs": "lymmelaktig",
    "lymmelaktigt": "lymmelaktig",
    "lymmelaktigts": "lymmelaktig",
    "lymmeln": "lymmel",
    "lymmelns": "lymmel",
    "lymmels": "lymmel",
    "lymmlar": "lymmel",
    "lymmlarna": "lymmel",
    "lymmlarnas": "lymmel",
    "lymmlars": "lymmel",
    "lynch": "lyncha",
    "lynchad": "lyncha",
    "lynchade": "lyncha",
    "lynchades": "lyncha",
    "lynchads": "lyncha",
    "lynchande": "lyncha",
    "lynchanden": "lynchande",
    "lynchandena": "lynchande",
    "lynchandenas": "lynchande",
    "lynchandens": "lynchande",
    "lynchandes": "lynchande",
    "lynchandet": "lynchande",
    "lynchandets": "lynchande",
    "lynchar": "lyncha",
    "lynchas": "lyncha",
    "lynchat": "lyncha",
    "lynchats": "lyncha",
    "lynchningar": "lynchning",
    "lynchningarna": "lynchning",
    "lynchningarnas": "lynchning",
    "lynchningars": "lynchning",
    "lynchningen": "lynchning",
    "lynchningens": "lynchning",
    "lynchnings": "lynchning",
    "lynetten": "lynett",
    "lynettens": "lynett",
    "lynetter": "lynett",
    "lynetterna": "lynett",
    "lynetternas": "lynett",
    "lynetters": "lynett",
    "lynetts": "lynett",
    "lynnen": "lynne",
    "lynnena": "lynne",
    "lynnenas": "lynne",
    "lynnens": "lynne",
    "lynnes": "lynne",
    "lynnesutbrotten": "lynnesutbrott",
    "lynnesutbrottens": "lynnesutbrott",
    "lynnesutbrottet": "lynnesutbrott",
    "lynnesutbrottets": "lynnesutbrott",
    "lynnesutbrotts": "lynnesutbrott",
    "lynnet": "lynne",
    "lynnets": "lynne",
    "lynniga": "lynnig",
    "lynnigare": "lynnig",
    "lynnigares": "lynnig",
    "lynnigas": "lynnig",
    "lynnigast": "lynnig",
    "lynnigaste": "lynnig",
    "lynnigastes": "lynnig",
    "lynnigasts": "lynnig",
    "lynnige": "lynnig",
    "lynniges": "lynnig",
    "lynnigheten": "lynnighet",
    "lynnighetens": "lynnighet",
    "lynnighets": "lynnighet",
    "lynnigs": "lynnig",
    "lynnigt": "lynnig",
    "lynnigts": "lynnig",
    "lyor": "lya",
    "lyorna": "lya",
    "lyornas": "lya",
    "lyors": "lya",
    "lyr": "lyra",
    "lyrad": "lyra",
    "lyrade": "lyra",
    "lyrades": "lyra",
    "lyrads": "lyra",
    "lyran": "lyra",
    "lyrande": "lyra",
    "lyranden": "lyrande",
    "lyrandena": "lyrande",
    "lyrandenas": "lyrande",
    "lyrandens": "lyrande",
    "lyrandes": "lyrande",
    "lyrandet": "lyrande",
    "lyrandets": "lyrande",
    "lyrans": "lyra",
    "lyrar": "lyra",
    "lyras": "lyra",
    "lyrat": "lyra",
    "lyrats": "lyra",
    "lyre": "lyra",
    "lyrformade": "lyrformad",
    "lyrformades": "lyrformad",
    "lyrformads": "lyrformad",
    "lyrformat": "lyrformad",
    "lyrformats": "lyrformad",
    "lyrfågeln": "lyrfågel",
    "lyrfågelns": "lyrfågel",
    "lyrfågels": "lyrfågel",
    "lyrfåglar": "lyrfågel",
    "lyrfåglarna": "lyrfågel",
    "lyrfåglarnas": "lyrfågel",
    "lyrfåglars": "lyrfågel",
    "lyriken": "lyrik",
    "lyrikens": "lyrik",
    "lyrikern": "lyriker",
    "lyrikerna": "lyriker",
    "lyrikernas": "lyriker",
    "lyrikerns": "lyriker",
    "lyrikers": "lyriker",
    "lyriks": "lyrik",
    "lyrikälskar": "lyrikälskare",
    "lyrikälskaren": "lyrikälskare",
    "lyrikälskarens": "lyrikälskare",
    "lyrikälskares": "lyrikälskare",
    "lyrikälskarna": "lyrikälskare",
    "lyrikälskarnas": "lyrikälskare",
    "lyriska": "lyrisk",
    "lyriskare": "lyrisk",
    "lyriskares": "lyrisk",
    "lyriskas": "lyrisk",
    "lyriskast": "lyrisk",
    "lyriskaste": "lyrisk",
    "lyriskastes": "lyrisk",
    "lyriskasts": "lyrisk",
    "lyriske": "lyrisk",
    "lyriskes": "lyrisk",
    "lyrisks": "lyrisk",
    "lyriskt": "lyrisk",
    "lyriskts": "lyrisk",
    "lyror": "lyra",
    "lyrorna": "lyra",
    "lyrornas": "lyra",
    "lyrors": "lyra",
    "lyrs": "lyra",
    "lyrtorskar": "lyrtorsk",
    "lyrtorskarna": "lyrtorsk",
    "lyrtorskarnas": "lyrtorsk",
    "lyrtorskars": "lyrtorsk",
    "lyrtorsken": "lyrtorsk",
    "lyrtorskens": "lyrtorsk",
    "lyrtorsks": "lyrtorsk",
    "lys": "lyse",
    "lysande": "lysa",
    "lysanden": "lysande",
    "lysandena": "lysande",
    "lysandenas": "lysande",
    "lysandens": "lysande",
    "lysandes": "lysande",
    "lysandet": "lysande",
    "lysandets": "lysande",
    "lysas": "lysa",
    "lysbojar": "lysboj",
    "lysbojarna": "lysboj",
    "lysbojarnas": "lysboj",
    "lysbojars": "lysboj",
    "lysbojen": "lysboj",
    "lysbojens": "lysboj",
    "lysbojs": "lysboj",
    "lysbomben": "lysbomb",
    "lysbombens": "lysbomb",
    "lysbomber": "lysbomb",
    "lysbomberna": "lysbomb",
    "lysbombernas": "lysbomb",
    "lysbombers": "lysbomb",
    "lysbombs": "lysbomb",
    "lysdioden": "lysdiod",
    "lysdiodens": "lysdiod",
    "lysdioder": "lysdiod",
    "lysdioderna": "lysdiod",
    "lysdiodernas": "lysdiod",
    "lysdioders": "lysdiod",
    "lysdiods": "lysdiod",
    "lysen": "lyse",
    "lysena": "lyse",
    "lysenas": "lyse",
    "lysens": "lyse",
    "lyser": "lysa",
    "lyses": "lyse",
    "lyset": "lyse",
    "lysets": "lyse",
    "lysgasen": "lysgas",
    "lysgasens": "lysgas",
    "lysgaser": "lysgas",
    "lysgaserna": "lysgas",
    "lysgasernas": "lysgas",
    "lysgasers": "lysgas",
    "lysiner": "lysin",
    "lysinerna": "lysin",
    "lysinernas": "lysin",
    "lysiners": "lysin",
    "lysinet": "lysin",
    "lysinets": "lysin",
    "lysins": "lysin",
    "lyskraften": "lyskraft",
    "lyskraftens": "lyskraft",
    "lyskrafts": "lyskraft",
    "lysmaskar": "lysmask",
    "lysmaskarna": "lysmask",
    "lysmaskarnas": "lysmask",
    "lysmaskars": "lysmask",
    "lysmasken": "lysmask",
    "lysmaskens": "lysmask",
    "lysmasks": "lysmask",
    "lysningar": "lysning",
    "lysningarna": "lysning",
    "lysningarnas": "lysning",
    "lysningars": "lysning",
    "lysningen": "lysning",
    "lysningens": "lysning",
    "lysnings": "lysning",
    "lysolen": "lysol",
    "lysolens": "lysol",
    "lysols": "lysol",
    "lysosomen": "lysosom",
    "lysosomens": "lysosom",
    "lysosomer": "lysosom",
    "lysosomerna": "lysosom",
    "lysosomernas": "lysosom",
    "lysosomers": "lysosom",
    "lysosoms": "lysosom",
    "lysozymen": "lysozym",
    "lysozymens": "lysozym",
    "lysozymer": "lysozym",
    "lysozymerna": "lysozym",
    "lysozymernas": "lysozym",
    "lysozymers": "lysozym",
    "lysozymet": "lysozym",
    "lysozymets": "lysozym",
    "lysozyms": "lysozym",
    "lyspatronen": "lyspatron",
    "lyspatronens": "lyspatron",
    "lyspatroner": "lyspatron",
    "lyspatronerna": "lyspatron",
    "lyspatronernas": "lyspatron",
    "lyspatroners": "lyspatron",
    "lyspatrons": "lyspatron",
    "lyspistolen": "lyspistol",
    "lyspistolens": "lyspistol",
    "lyspistoler": "lyspistol",
    "lyspistolerna": "lyspistol",
    "lyspistolernas": "lyspistol",
    "lyspistolers": "lyspistol",
    "lyspistols": "lyspistol",
    "lysraketen": "lysraket",
    "lysraketens": "lysraket",
    "lysraketer": "lysraket",
    "lysraketerna": "lysraket",
    "lysraketernas": "lysraket",
    "lysraketers": "lysraket",
    "lysrakets": "lysraket",
    "lysräk": "lysräka",
    "lysräkan": "lysräka",
    "lysräkans": "lysräka",
    "lysräkas": "lysräka",
    "lysräke": "lysräka",
    "lysräkor": "lysräka",
    "lysräkorna": "lysräka",
    "lysräkornas": "lysräka",
    "lysräkors": "lysräka",
    "lysräks": "lysräka",
    "lysrören": "lysrör",
    "lysrörens": "lysrör",
    "lysröret": "lysrör",
    "lysrörets": "lysrör",
    "lysrörs": "lysrör",
    "lysrörsarmaturen": "lysrörsarmatur",
    "lysrörsarmaturens": "lysrörsarmatur",
    "lysrörsarmaturer": "lysrörsarmatur",
    "lysrörsarmaturerna": "lysrörsarmatur",
    "lysrörsarmaturernas": "lysrörsarmatur",
    "lysrörsarmaturers": "lysrörsarmatur",
    "lysrörsarmaturs": "lysrörsarmatur",
    "lysrörslamp": "lysrörslampa",
    "lysrörslampan": "lysrörslampa",
    "lysrörslampans": "lysrörslampa",
    "lysrörslampas": "lysrörslampa",
    "lysrörslampe": "lysrörslampa",
    "lysrörslampor": "lysrörslampa",
    "lysrörslamporna": "lysrörslampa",
    "lysrörslampornas": "lysrörslampa",
    "lysrörslampors": "lysrörslampa",
    "lysrörslamps": "lysrörslampa",
    "lyssatsen": "lyssats",
    "lyssatsens": "lyssats",
    "lyssatser": "lyssats",
    "lyssatserna": "lyssats",
    "lyssatsernas": "lyssats",
    "lyssatsers": "lyssats",
    "lyssende": "lyss",
    "lyssendes": "lyss",
    "lyssnade": "lyssna",
    "lyssnades": "lyssna",
    "lyssnande": "lyssna",
    "lyssnanden": "lyssnande",
    "lyssnandena": "lyssnande",
    "lyssnandenas": "lyssnande",
    "lyssnandens": "lyssnande",
    "lyssnandes": "lyssnande",
    "lyssnandet": "lyssnande",
    "lyssnandets": "lyssnande",
    "lyssnar": "lyssnare",
    "lyssnarapparaten": "lyssnarapparat",
    "lyssnarapparatens": "lyssnarapparat",
    "lyssnarapparater": "lyssnarapparat",
    "lyssnarapparaterna": "lyssnarapparat",
    "lyssnarapparaternas": "lyssnarapparat",
    "lyssnarapparaters": "lyssnarapparat",
    "lyssnarapparats": "lyssnarapparat",
    "lyssnaren": "lyssnare",
    "lyssnarens": "lyssnare",
    "lyssnares": "lyssnare",
    "lyssnarna": "lyssnare",
    "lyssnarnas": "lyssnare",
    "lyssnarposten": "lyssnarpost",
    "lyssnarpostens": "lyssnarpost",
    "lyssnarposter": "lyssnarpost",
    "lyssnarposterna": "lyssnarpost",
    "lyssnarposternas": "lyssnarpost",
    "lyssnarposters": "lyssnarpost",
    "lyssnarposts": "lyssnarpost",
    "lyssnarskar": "lyssnarskara",
    "lyssnarskaran": "lyssnarskara",
    "lyssnarskarans": "lyssnarskara",
    "lyssnarskaras": "lyssnarskara",
    "lyssnarskare": "lyssnarskara",
    "lyssnarskaror": "lyssnarskara",
    "lyssnarskarorna": "lyssnarskara",
    "lyssnarskarornas": "lyssnarskara",
    "lyssnarskarors": "lyssnarskara",
    "lyssnarskars": "lyssnarskara",
    "lyssnas": "lyssna",
    "lyssnat": "lyssna",
    "lyssnats": "lyssna",
    "lyst": "lysa",
    "lysta": "lysa",
    "lystas": "lysa",
    "lyste": "lysa",
    "lystenheten": "lystenhet",
    "lystenhetens": "lystenhet",
    "lystenhets": "lystenhet",
    "lystens": "lysten",
    "lysterfärgen": "lysterfärg",
    "lysterfärgens": "lysterfärg",
    "lysterfärger": "lysterfärg",
    "lysterfärgerna": "lysterfärg",
    "lysterfärgernas": "lysterfärg",
    "lysterfärgers": "lysterfärg",
    "lysterfärgs": "lysterfärg",
    "lystergarnen": "lystergarn",
    "lystergarnens": "lystergarn",
    "lystergarner": "lystergarn",
    "lystergarnerna": "lystergarn",
    "lystergarnernas": "lystergarn",
    "lystergarners": "lystergarn",
    "lystergarnet": "lystergarn",
    "lystergarnets": "lystergarn",
    "lystergarns": "lystergarn",
    "lystern": "lyster",
    "lysterns": "lyster",
    "lysters": "lyster",
    "lystes": "lysa",
    "lystet": "lysten",
    "lystets": "lysten",
    "lystmäten": "lystmäte",
    "lystmätena": "lystmäte",
    "lystmätenas": "lystmäte",
    "lystmätens": "lystmäte",
    "lystmätes": "lystmäte",
    "lystmätet": "lystmäte",
    "lystmätets": "lystmäte",
    "lystna": "lysten",
    "lystnaden": "lystnad",
    "lystnadens": "lystnad",
    "lystnader": "lystnad",
    "lystnaderna": "lystnad",
    "lystnadernas": "lystnad",
    "lystnaders": "lystnad",
    "lystnads": "lystnad",
    "lystnare": "lysten",
    "lystnares": "lysten",
    "lystnas": "lysten",
    "lystnast": "lysten",
    "lystnaste": "lysten",
    "lystnastes": "lysten",
    "lystnasts": "lysten",
    "lystne": "lysten",
    "lystnes": "lysten",
    "lystrade": "lystra",
    "lystrades": "lystra",
    "lystrande": "lystra",
    "lystranden": "lystrande",
    "lystrandena": "lystrande",
    "lystrandenas": "lystrande",
    "lystrandens": "lystrande",
    "lystrandes": "lystrande",
    "lystrandet": "lystrande",
    "lystrandets": "lystrande",
    "lystrar": "lystra",
    "lystrarna": "lyster",
    "lystrarnas": "lyster",
    "lystrars": "lyster",
    "lystras": "lystra",
    "lystrat": "lystra",
    "lystrats": "lystra",
    "lystrer": "lyster",
    "lystrerna": "lyster",
    "lystrernas": "lyster",
    "lystrers": "lyster",
    "lystringar": "lystring",
    "lystringarna": "lystring",
    "lystringarnas": "lystring",
    "lystringars": "lystring",
    "lystringen": "lystring",
    "lystringens": "lystring",
    "lystrings": "lystring",
    "lysts": "lysa",
    "lysveden": "lysved",
    "lysvedens": "lysved",
    "lysveds": "lysved",
    "lysämnen": "lysämne",
    "lysämnena": "lysämne",
    "lysämnenas": "lysämne",
    "lysämnens": "lysämne",
    "lysämnes": "lysämne",
    "lysämnet": "lysämne",
    "lysämnets": "lysämne",
    "lyt": "ly",
    "lyten": "lyte",
    "lytena": "lyte",
    "lytenas": "lyte",
    "lytens": "lyte",
    "lytes": "lyte",
    "lyteskomiken": "lyteskomik",
    "lyteskomikens": "lyteskomik",
    "lyteskomiks": "lyteskomik",
    "lytet": "lyte",
    "lytets": "lyte",
    "lyts": "ly",
    "lytt": "lyda",
    "lytta": "lytt",
    "lyttare": "lytt",
    "lyttares": "lytt",
    "lyttas": "lytt",
    "lyttast": "lytt",
    "lyttaste": "lytt",
    "lyttastes": "lytt",
    "lyttasts": "lytt",
    "lytte": "lytt",
    "lyttes": "lytt",
    "lyttheten": "lytthet",
    "lytthetens": "lytthet",
    "lytthets": "lytthet",
    "lytts": "lytt",
    "lyxade": "lyxa",
    "lyxades": "lyxa",
    "lyxande": "lyxa",
    "lyxanden": "lyxande",
    "lyxandena": "lyxande",
    "lyxandenas": "lyxande",
    "lyxandens": "lyxande",
    "lyxandes": "lyxande",
    "lyxandet": "lyxande",
    "lyxandets": "lyxande",
    "lyxar": "lyxa",
    "lyxartikeln": "lyxartikel",
    "lyxartikelns": "lyxartikel",
    "lyxartikels": "lyxartikel",
    "lyxartiklar": "lyxartikel",
    "lyxartiklarna": "lyxartikel",
    "lyxartiklarnas": "lyxartikel",
    "lyxartiklars": "lyxartikel",
    "lyxas": "lyxa",
    "lyxat": "lyxa",
    "lyxats": "lyxa",
    "lyxbilar": "lyxbil",
    "lyxbilarna": "lyxbil",
    "lyxbilarnas": "lyxbil",
    "lyxbilars": "lyxbil",
    "lyxbilen": "lyxbil",
    "lyxbilens": "lyxbil",
    "lyxbils": "lyxbil",
    "lyxen": "lyx",
    "lyxens": "lyx",
    "lyxfäll": "lyxfälla",
    "lyxfällan": "lyxfälla",
    "lyxfällans": "lyxfälla",
    "lyxfällas": "lyxfälla",
    "lyxfälle": "lyxfälla",
    "lyxfällor": "lyxfälla",
    "lyxfällorna": "lyxfälla",
    "lyxfällornas": "lyxfälla",
    "lyxfällors": "lyxfälla",
    "lyxfälls": "lyxfälla",
    "lyxförpackningar": "lyxförpackning",
    "lyxförpackningarna": "lyxförpackning",
    "lyxförpackningarnas": "lyxförpackning",
    "lyxförpackningars": "lyxförpackning",
    "lyxförpackningen": "lyxförpackning",
    "lyxförpackningens": "lyxförpackning",
    "lyxförpacknings": "lyxförpackning",
    "lyxgårdar": "lyxgård",
    "lyxgårdarna": "lyxgård",
    "lyxgårdarnas": "lyxgård",
    "lyxgårdars": "lyxgård",
    "lyxgården": "lyxgård",
    "lyxgårdens": "lyxgård",
    "lyxgårds": "lyxgård",
    "lyxhotellen": "lyxhotell",
    "lyxhotellens": "lyxhotell",
    "lyxhotellet": "lyxhotell",
    "lyxhotellets": "lyxhotell",
    "lyxhotells": "lyxhotell",
    "lyxhustrun": "lyxhustru",
    "lyxhustruns": "lyxhustru",
    "lyxhustrur": "lyxhustru",
    "lyxhustrurna": "lyxhustru",
    "lyxhustrurnas": "lyxhustru",
    "lyxhustrurs": "lyxhustru",
    "lyxhustrus": "lyxhustru",
    "lyxiga": "lyxig",
    "lyxigare": "lyxig",
    "lyxigares": "lyxig",
    "lyxigas": "lyxig",
    "lyxigast": "lyxig",
    "lyxigaste": "lyxig",
    "lyxigastes": "lyxig",
    "lyxigasts": "lyxig",
    "lyxige": "lyxig",
    "lyxiges": "lyxig",
    "lyxigheten": "lyxighet",
    "lyxighetens": "lyxighet",
    "lyxigheter": "lyxighet",
    "lyxigheterna": "lyxighet",
    "lyxigheternas": "lyxighet",
    "lyxigheters": "lyxighet",
    "lyxighets": "lyxighet",
    "lyxigs": "lyxig",
    "lyxigt": "lyxig",
    "lyxigts": "lyxig",
    "lyxkonsumtionen": "lyxkonsumtion",
    "lyxkonsumtionens": "lyxkonsumtion",
    "lyxkonsumtioner": "lyxkonsumtion",
    "lyxkonsumtionerna": "lyxkonsumtion",
    "lyxkonsumtionernas": "lyxkonsumtion",
    "lyxkonsumtioners": "lyxkonsumtion",
    "lyxkonsumtions": "lyxkonsumtion",
    "lyxkryssar": "lyxkryssare",
    "lyxkryssaren": "lyxkryssare",
    "lyxkryssarens": "lyxkryssare",
    "lyxkryssares": "lyxkryssare",
    "lyxkryssarna": "lyxkryssare",
    "lyxkryssarnas": "lyxkryssare",
    "lyxkryssningar": "lyxkryssning",
    "lyxkryssningarna": "lyxkryssning",
    "lyxkryssningarnas": "lyxkryssning",
    "lyxkryssningars": "lyxkryssning",
    "lyxkryssningen": "lyxkryssning",
    "lyxkryssningens": "lyxkryssning",
    "lyxkryssnings": "lyxkryssning",
    "lyxliven": "lyxliv",
    "lyxlivens": "lyxliv",
    "lyxlivet": "lyxliv",
    "lyxlivets": "lyxliv",
    "lyxlivs": "lyxliv",
    "lyxlägenheten": "lyxlägenhet",
    "lyxlägenhetens": "lyxlägenhet",
    "lyxlägenheter": "lyxlägenhet",
    "lyxlägenheterna": "lyxlägenhet",
    "lyxlägenheternas": "lyxlägenhet",
    "lyxlägenheters": "lyxlägenhet",
    "lyxlägenhets": "lyxlägenhet",
    "lyxmaten": "lyxmat",
    "lyxmatens": "lyxmat",
    "lyxmats": "lyxmat",
    "lyxproblemen": "lyxproblem",
    "lyxproblemens": "lyxproblem",
    "lyxproblemet": "lyxproblem",
    "lyxproblemets": "lyxproblem",
    "lyxproblems": "lyxproblem",
    "lyxrenoverad": "lyxrenovera",
    "lyxrenoverade": "lyxrenovera",
    "lyxrenoverades": "lyxrenovera",
    "lyxrenoverads": "lyxrenovera",
    "lyxrenoverande": "lyxrenovera",
    "lyxrenoveranden": "lyxrenoverande",
    "lyxrenoverandena": "lyxrenoverande",
    "lyxrenoverandenas": "lyxrenoverande",
    "lyxrenoverandens": "lyxrenoverande",
    "lyxrenoverandes": "lyxrenoverande",
    "lyxrenoverandet": "lyxrenoverande",
    "lyxrenoverandets": "lyxrenoverande",
    "lyxrenoverar": "lyxrenovera",
    "lyxrenoveras": "lyxrenovera",
    "lyxrenoverat": "lyxrenovera",
    "lyxrenoverats": "lyxrenovera",
    "lyxrenoverbara": "lyxrenoverbar",
    "lyxrenoverbarare": "lyxrenoverbar",
    "lyxrenoverbarares": "lyxrenoverbar",
    "lyxrenoverbaras": "lyxrenoverbar",
    "lyxrenoverbarast": "lyxrenoverbar",
    "lyxrenoverbaraste": "lyxrenoverbar",
    "lyxrenoverbarastes": "lyxrenoverbar",
    "lyxrenoverbarasts": "lyxrenoverbar",
    "lyxrenoverbare": "lyxrenoverbar",
    "lyxrenoverbares": "lyxrenoverbar",
    "lyxrenoverbarheten": "lyxrenoverbarhet",
    "lyxrenoverbarhetens": "lyxrenoverbarhet",
    "lyxrenoverbarhets": "lyxrenoverbarhet",
    "lyxrenoverbars": "lyxrenoverbar",
    "lyxrenoverbart": "lyxrenoverbar",
    "lyxrenoverbarts": "lyxrenoverbar",
    "lyxrenoveringar": "lyxrenovering",
    "lyxrenoveringarna": "lyxrenovering",
    "lyxrenoveringarnas": "lyxrenovering",
    "lyxrenoveringars": "lyxrenovering",
    "lyxrenoveringen": "lyxrenovering",
    "lyxrenoveringens": "lyxrenovering",
    "lyxrenoverings": "lyxrenovering",
    "lyxskatten": "lyxskatt",
    "lyxskattens": "lyxskatt",
    "lyxskatter": "lyxskatt",
    "lyxskatterna": "lyxskatt",
    "lyxskatternas": "lyxskatt",
    "lyxskatters": "lyxskatt",
    "lyxskatts": "lyxskatt",
    "lyxskink": "lyxskinka",
    "lyxskinkan": "lyxskinka",
    "lyxskinkans": "lyxskinka",
    "lyxskinkas": "lyxskinka",
    "lyxskinke": "lyxskinka",
    "lyxskinkor": "lyxskinka",
    "lyxskinkorna": "lyxskinka",
    "lyxskinkornas": "lyxskinka",
    "lyxskinkors": "lyxskinka",
    "lyxskinks": "lyxskinka",
    "lyxsmörgåsar": "lyxsmörgås",
    "lyxsmörgåsarna": "lyxsmörgås",
    "lyxsmörgåsarnas": "lyxsmörgås",
    "lyxsmörgåsars": "lyxsmörgås",
    "lyxsmörgåsen": "lyxsmörgås",
    "lyxsmörgåsens": "lyxsmörgås",
    "lyxtelegrammen": "lyxtelegram",
    "lyxtelegrammens": "lyxtelegram",
    "lyxtelegrammet": "lyxtelegram",
    "lyxtelegrammets": "lyxtelegram",
    "lyxtelegrams": "lyxtelegram",
    "lyxvar": "lyxvara",
    "lyxvaran": "lyxvara",
    "lyxvarans": "lyxvara",
    "lyxvaras": "lyxvara",
    "lyxvare": "lyxvara",
    "lyxvaror": "lyxvara",
    "lyxvarorna": "lyxvara",
    "lyxvarornas": "lyxvara",
    "lyxvarors": "lyxvara",
    "lyxvars": "lyxvara",
    "lyxvillan": "lyxvilla",
    "lyxvillans": "lyxvilla",
    "lyxvillas": "lyxvilla",
    "lyxville": "lyxvilla",
    "lyxvillor": "lyxvilla",
    "lyxvillorna": "lyxvilla",
    "lyxvillornas": "lyxvilla",
    "lyxvillors": "lyxvilla",
    "lyxvåningar": "lyxvåning",
    "lyxvåningarna": "lyxvåning",
    "lyxvåningarnas": "lyxvåning",
    "lyxvåningars": "lyxvåning",
    "lyxvåningen": "lyxvåning",
    "lyxvåningens": "lyxvåning",
    "lyxvånings": "lyxvåning",
    "lángosar": "lángos",
    "lángosarna": "lángos",
    "lángosarnas": "lángos",
    "lángosars": "lángos",
    "lángosen": "lángos",
    "lángosens": "lángos",
    "läade": "läa",
    "läades": "läa",
    "läande": "läa",
    "läanden": "läande",
    "läandena": "läande",
    "läandenas": "läande",
    "läandens": "läande",
    "läandes": "läande",
    "läandet": "läande",
    "läandets": "läande",
    "läar": "läa",
    "läas": "läa",
    "läat": "läa",
    "läats": "läa",
    "läbb": "läbba",
    "läbban": "läbba",
    "läbbans": "läbba",
    "läbbas": "läbba",
    "läbbe": "läbba",
    "läbbor": "läbba",
    "läbborna": "läbba",
    "läbbornas": "läbba",
    "läbbors": "läbba",
    "läbbs": "läbba",
    "läck": "läcka",
    "läckagen": "läckage",
    "läckagens": "läckage",
    "läckageproblemen": "läckageproblem",
    "läckageproblemens": "läckageproblem",
    "läckageproblemet": "läckageproblem",
    "läckageproblemets": "läckageproblem",
    "läckageproblems": "läckageproblem",
    "läckages": "läckage",
    "läckaget": "läckage",
    "läckagets": "läckage",
    "läckan": "läcka",
    "läckande": "läcka",
    "läckanden": "läckande",
    "läckandena": "läckande",
    "läckandenas": "läckande",
    "läckandens": "läckande",
    "läckandes": "läckande",
    "läckandet": "läckande",
    "läckandets": "läckande",
    "läckans": "läcka",
    "läckas": "läcka",
    "läcke": "läcka",
    "läcker": "läcka",
    "läckerbitar": "läckerbit",
    "läckerbitarna": "läckerbit",
    "läckerbitarnas": "läckerbit",
    "läckerbitars": "läckerbit",
    "läckerbiten": "läckerbit",
    "läckerbitens": "läckerbit",
    "läckerbits": "läckerbit",
    "läckergommar": "läckergom",
    "läckergommarna": "läckergom",
    "läckergommarnas": "läckergom",
    "läckergommars": "läckergom",
    "läckergommen": "läckergom",
    "läckergommens": "läckergom",
    "läckergoms": "läckergom",
    "läckerheten": "läckerhet",
    "läckerhetens": "läckerhet",
    "läckerheter": "läckerhet",
    "läckerheterna": "läckerhet",
    "läckerheternas": "läckerhet",
    "läckerheters": "läckerhet",
    "läckerhets": "läckerhet",
    "läckers": "läcker",
    "läckert": "läcker",
    "läckerts": "läcker",
    "läckes": "läcka",
    "läckor": "läcka",
    "läckorna": "läcka",
    "läckornas": "läcka",
    "läckors": "läcka",
    "läckra": "läcker",
    "läckrare": "läcker",
    "läckrares": "läcker",
    "läckras": "läcker",
    "läckrast": "läcker",
    "läckraste": "läcker",
    "läckrastes": "läcker",
    "läckrasts": "läcker",
    "läckre": "läcker",
    "läckres": "läcker",
    "läcks": "läcka",
    "läckt": "läcka",
    "läckta": "läcka",
    "läcktas": "läcka",
    "läckte": "läcka",
    "läcktes": "läcka",
    "läckts": "läcka",
    "läderad": "lädera",
    "läderade": "lädera",
    "läderades": "lädera",
    "läderads": "lädera",
    "läderande": "lädera",
    "läderanden": "läderande",
    "läderandena": "läderande",
    "läderandenas": "läderande",
    "läderandens": "läderande",
    "läderandes": "läderande",
    "läderandet": "läderande",
    "läderandets": "läderande",
    "läderar": "lädera",
    "läderartade": "läderartad",
    "läderartades": "läderartad",
    "läderartads": "läderartad",
    "läderartat": "läderartad",
    "läderartats": "läderartad",
    "läderas": "lädera",
    "läderat": "lädera",
    "läderats": "lädera",
    "läderbara": "läderbar",
    "läderbarare": "läderbar",
    "läderbarares": "läderbar",
    "läderbaras": "läderbar",
    "läderbarast": "läderbar",
    "läderbaraste": "läderbar",
    "läderbarastes": "läderbar",
    "läderbarasts": "läderbar",
    "läderbare": "läderbar",
    "läderbares": "läderbar",
    "läderbarheten": "läderbarhet",
    "läderbarhetens": "läderbarhet",
    "läderbarhets": "läderbarhet",
    "läderbars": "läderbar",
    "läderbart": "läderbar",
    "läderbarts": "läderbar",
    "läderbruna": "läderbrun",
    "läderbrunare": "läderbrun",
    "läderbrunares": "läderbrun",
    "läderbrunas": "läderbrun",
    "läderbrunast": "läderbrun",
    "läderbrunaste": "läderbrun",
    "läderbrunastes": "läderbrun",
    "läderbrunasts": "läderbrun",
    "läderbrune": "läderbrun",
    "läderbrunes": "läderbrun",
    "läderbruns": "läderbrun",
    "läderbrunt": "läderbrun",
    "läderbrunts": "läderbrun",
    "läderfodralen": "läderfodral",
    "läderfodralens": "läderfodral",
    "läderfodralet": "läderfodral",
    "läderfodralets": "läderfodral",
    "läderfodrals": "läderfodral",
    "läderhuden": "läderhud",
    "läderhudens": "läderhud",
    "läderhuds": "läderhud",
    "läderingar": "lädering",
    "läderingarna": "lädering",
    "läderingarnas": "lädering",
    "läderingars": "lädering",
    "läderingen": "lädering",
    "läderingens": "lädering",
    "läderings": "lädering",
    "läderjack": "läderjacka",
    "läderjackan": "läderjacka",
    "läderjackans": "läderjacka",
    "läderjackas": "läderjacka",
    "läderjacke": "läderjacka",
    "läderjackor": "läderjacka",
    "läderjackorna": "läderjacka",
    "läderjackornas": "läderjacka",
    "läderjackors": "läderjacka",
    "läderjacks": "läderjacka",
    "läderkul": "läderkula",
    "läderkulan": "läderkula",
    "läderkulans": "läderkula",
    "läderkulas": "läderkula",
    "läderkule": "läderkula",
    "läderkulor": "läderkula",
    "läderkulorna": "läderkula",
    "läderkulornas": "läderkula",
    "läderkulors": "läderkula",
    "läderkuls": "läderkula",
    "läderlappar": "läderlapp",
    "läderlapparna": "läderlapp",
    "läderlapparnas": "läderlapp",
    "läderlappars": "läderlapp",
    "läderlappen": "läderlapp",
    "läderlappens": "läderlapp",
    "läderlapps": "läderlapp",
    "läders": "läder",
    "läderslid": "läderslida",
    "läderslidan": "läderslida",
    "läderslidans": "läderslida",
    "läderslidas": "läderslida",
    "läderslide": "läderslida",
    "läderslidor": "läderslida",
    "läderslidorna": "läderslida",
    "läderslidornas": "läderslida",
    "läderslidors": "läderslida",
    "läderslids": "läderslida",
    "lädret": "läder",
    "lädrets": "läder",
    "lägdan": "lägda",
    "lägdans": "lägda",
    "lägdas": "lägda",
    "lägde": "lägda",
    "lägdor": "lägda",
    "lägdorna": "lägda",
    "lägdornas": "lägda",
    "lägdors": "lägda",
    "lägeln": "lägel",
    "lägelns": "lägel",
    "lägels": "lägel",
    "lägen": "läge",
    "lägena": "läge",
    "lägenas": "läge",
    "lägenheten": "lägenhet",
    "lägenhetens": "lägenhet",
    "lägenheter": "lägenhet",
    "lägenheterna": "lägenhet",
    "lägenheternas": "lägenhet",
    "lägenheters": "lägenhet",
    "lägenhets": "lägenhet",
    "lägenhetsbranden": "lägenhetsbrand",
    "lägenhetsbrandens": "lägenhetsbrand",
    "lägenhetsbrands": "lägenhetsbrand",
    "lägenhetsbränder": "lägenhetsbrand",
    "lägenhetsbränderna": "lägenhetsbrand",
    "lägenhetsbrändernas": "lägenhetsbrand",
    "lägenhetsbränders": "lägenhetsbrand",
    "lägenhetsbyten": "lägenhetsbyte",
    "lägenhetsbytena": "lägenhetsbyte",
    "lägenhetsbytenas": "lägenhetsbyte",
    "lägenhetsbytens": "lägenhetsbyte",
    "lägenhetsbytes": "lägenhetsbyte",
    "lägenhetsbytet": "lägenhetsbyte",
    "lägenhetsbytets": "lägenhetsbyte",
    "lägenhetshotellen": "lägenhetshotell",
    "lägenhetshotellens": "lägenhetshotell",
    "lägenhetshotellet": "lägenhetshotell",
    "lägenhetshotellets": "lägenhetshotell",
    "lägenhetshotells": "lägenhetshotell",
    "lägenhetsinnehavar": "lägenhetsinnehavare",
    "lägenhetsinnehavaren": "lägenhetsinnehavare",
    "lägenhetsinnehavarens": "lägenhetsinnehavare",
    "lägenhetsinnehavares": "lägenhetsinnehavare",
    "lägenhetsinnehavarna": "lägenhetsinnehavare",
    "lägenhetsinnehavarnas": "lägenhetsinnehavare",
    "lägens": "läge",
    "lägerbålen": "lägerbål",
    "lägerbålens": "lägerbål",
    "lägerbålet": "lägerbål",
    "lägerbålets": "lägerbål",
    "lägerbåls": "lägerbål",
    "lägereldar": "lägereld",
    "lägereldarna": "lägereld",
    "lägereldarnas": "lägereld",
    "lägereldars": "lägereld",
    "lägerelden": "lägereld",
    "lägereldens": "lägereld",
    "lägerelds": "lägereld",
    "lägerlivet": "lägerliv",
    "lägerlivets": "lägerliv",
    "lägerlivs": "lägerliv",
    "lägerna": "läger",
    "lägernas": "läger",
    "lägers": "läger",
    "lägerskolan": "lägerskola",
    "lägerskolans": "lägerskola",
    "lägerskolas": "lägerskola",
    "lägerskole": "lägerskola",
    "lägerskolor": "lägerskola",
    "lägerskolorna": "lägerskola",
    "lägerskolornas": "lägerskola",
    "lägerskolors": "lägerskola",
    "läges": "läge",
    "lägesbestämningar": "lägesbestämning",
    "lägesbestämningarna": "lägesbestämning",
    "lägesbestämningarnas": "lägesbestämning",
    "lägesbestämningars": "lägesbestämning",
    "lägesbestämningen": "lägesbestämning",
    "lägesbestämningens": "lägesbestämning",
    "lägesbestämnings": "lägesbestämning",
    "lägesenergien": "lägesenergi",
    "lägesenergiens": "lägesenergi",
    "lägesenergin": "lägesenergi",
    "lägesenergins": "lägesenergi",
    "lägesenergis": "lägesenergi",
    "lägesförändringar": "lägesförändring",
    "lägesförändringarna": "lägesförändring",
    "lägesförändringarnas": "lägesförändring",
    "lägesförändringars": "lägesförändring",
    "lägesförändringen": "lägesförändring",
    "lägesförändringens": "lägesförändring",
    "lägesförändrings": "lägesförändring",
    "lägesrapporten": "lägesrapport",
    "lägesrapportens": "lägesrapport",
    "lägesrapporter": "lägesrapport",
    "lägesrapporterna": "lägesrapport",
    "lägesrapporternas": "lägesrapport",
    "lägesrapporters": "lägesrapport",
    "lägesrapports": "lägesrapport",
    "lägessinnen": "lägessinne",
    "lägessinnena": "lägessinne",
    "lägessinnenas": "lägessinne",
    "lägessinnens": "lägessinne",
    "lägessinnes": "lägessinne",
    "lägessinnet": "lägessinne",
    "lägessinnets": "lägessinne",
    "läget": "läge",
    "lägets": "läge",
    "lägg": "lägga",
    "läggande": "lägga",
    "lägganden": "läggande",
    "läggandena": "läggande",
    "läggandenas": "läggande",
    "läggandens": "läggande",
    "läggandes": "läggande",
    "läggandet": "läggande",
    "läggandets": "läggande",
    "läggar": "lägg",
    "läggarna": "lägg",
    "läggarnas": "lägg",
    "läggars": "lägg",
    "läggas": "lägga",
    "läggen": "lägg",
    "läggens": "lägg",
    "lägger": "lägga",
    "lägges": "lägga",
    "lägget": "lägg",
    "läggets": "lägg",
    "läggningar": "läggning",
    "läggningarna": "läggning",
    "läggningarnas": "läggning",
    "läggningars": "läggning",
    "läggningen": "läggning",
    "läggningens": "läggning",
    "läggnings": "läggning",
    "läggs": "lägga",
    "läggspelen": "läggspel",
    "läggspelens": "läggspel",
    "läggspelet": "läggspel",
    "läggspelets": "läggspel",
    "läggspels": "läggspel",
    "läglar": "lägel",
    "läglarna": "lägel",
    "läglarnas": "lägel",
    "läglars": "lägel",
    "lägliga": "läglig",
    "lägligare": "läglig",
    "lägligares": "läglig",
    "lägligas": "läglig",
    "lägligast": "läglig",
    "lägligaste": "läglig",
    "lägligastes": "läglig",
    "lägligasts": "läglig",
    "läglige": "läglig",
    "lägliges": "läglig",
    "lägligheten": "läglighet",
    "läglighetens": "läglighet",
    "läglighets": "läglighet",
    "lägligs": "läglig",
    "lägligt": "läglig",
    "lägligts": "läglig",
    "lägrad": "lägra",
    "lägrade": "lägra",
    "lägrades": "lägra",
    "lägrads": "lägra",
    "lägrande": "lägra",
    "lägranden": "lägrande",
    "lägrandena": "lägrande",
    "lägrandenas": "lägrande",
    "lägrandens": "lägrande",
    "lägrandes": "lägrande",
    "lägrandet": "lägrande",
    "lägrandets": "lägrande",
    "lägrar": "lägra",
    "lägras": "lägra",
    "lägrat": "lägra",
    "lägrats": "lägra",
    "lägre": "låg",
    "lägren": "läger",
    "lägrens": "läger",
    "lägres": "låg",
    "lägret": "läger",
    "lägrets": "läger",
    "lägst": "låg",
    "lägsta": "låg",
    "lägstas": "låg",
    "lägste": "låg",
    "lägstes": "låg",
    "lägsts": "låg",
    "läk": "läka",
    "läkande": "läka",
    "läkanden": "läkande",
    "läkandena": "läkande",
    "läkandenas": "läkande",
    "läkandens": "läkande",
    "läkandes": "läkande",
    "läkandet": "läkande",
    "läkandets": "läkande",
    "läkar": "läkare",
    "läkarboken": "läkarbok",
    "läkarbokens": "läkarbok",
    "läkarboks": "läkarbok",
    "läkarböcker": "läkarbok",
    "läkarböckerna": "läkarbok",
    "läkarböckernas": "läkarbok",
    "läkarböckers": "läkarbok",
    "läkarcentralen": "läkarcentral",
    "läkarcentralens": "läkarcentral",
    "läkarcentraler": "läkarcentral",
    "läkarcentralerna": "läkarcentral",
    "läkarcentralernas": "läkarcentral",
    "läkarcentralers": "läkarcentral",
    "läkarcentrals": "läkarcentral",
    "läkardottern": "läkardotter",
    "läkardotterns": "läkardotter",
    "läkardotters": "läkardotter",
    "läkardöttrar": "läkardotter",
    "läkardöttrarna": "läkardotter",
    "läkardöttrarnas": "läkardotter",
    "läkardöttrars": "läkardotter",
    "läkaren": "läkare",
    "läkarens": "läkare",
    "läkares": "läkare",
    "läkarhjälpar": "läkarhjälp",
    "läkarhjälparna": "läkarhjälp",
    "läkarhjälparnas": "läkarhjälp",
    "läkarhjälpars": "läkarhjälp",
    "läkarhjälpen": "läkarhjälp",
    "läkarhjälpens": "läkarhjälp",
    "läkarhjälps": "läkarhjälp",
    "läkarhusen": "läkarhus",
    "läkarhusens": "läkarhus",
    "läkarhuset": "läkarhus",
    "läkarhusets": "läkarhus",
    "läkarintygen": "läkarintyg",
    "läkarintygens": "läkarintyg",
    "läkarintyget": "läkarintyg",
    "läkarintygets": "läkarintyg",
    "läkarintygs": "läkarintyg",
    "läkarkåren": "läkarkår",
    "läkarkårens": "läkarkår",
    "läkarkårer": "läkarkår",
    "läkarkårerna": "läkarkår",
    "läkarkårernas": "läkarkår",
    "läkarkårers": "läkarkår",
    "läkarkårs": "läkarkår",
    "läkarmottagningar": "läkarmottagning",
    "läkarmottagningarna": "läkarmottagning",
    "läkarmottagningarnas": "läkarmottagning",
    "läkarmottagningars": "läkarmottagning",
    "läkarmottagningen": "läkarmottagning",
    "läkarmottagningens": "läkarmottagning",
    "läkarmottagnings": "läkarmottagning",
    "läkarna": "läkare",
    "läkarnas": "läkare",
    "läkarordinationen": "läkarordination",
    "läkarordinationens": "läkarordination",
    "läkarordinationer": "läkarordination",
    "läkarordinationerna": "läkarordination",
    "läkarordinationernas": "läkarordination",
    "läkarordinationers": "läkarordination",
    "läkarordinations": "läkarordination",
    "läkarpraktiken": "läkarpraktik",
    "läkarpraktikens": "läkarpraktik",
    "läkarpraktiker": "läkarpraktik",
    "läkarpraktikerna": "läkarpraktik",
    "läkarpraktikernas": "läkarpraktik",
    "läkarpraktikers": "läkarpraktik",
    "läkarpraktiks": "läkarpraktik",
    "läkarrecepten": "läkarrecept",
    "läkarreceptens": "läkarrecept",
    "läkarreceptet": "läkarrecept",
    "läkarreceptets": "läkarrecept",
    "läkarrecepts": "läkarrecept",
    "läkarrockar": "läkarrock",
    "läkarrockarna": "läkarrock",
    "läkarrockarnas": "läkarrock",
    "läkarrockars": "läkarrock",
    "läkarrocken": "läkarrock",
    "läkarrockens": "läkarrock",
    "läkarrocks": "läkarrock",
    "läkarsekreterar": "läkarsekreterare",
    "läkarsekreteraren": "läkarsekreterare",
    "läkarsekreterarens": "läkarsekreterare",
    "läkarsekreterares": "läkarsekreterare",
    "läkarsekreterarna": "läkarsekreterare",
    "läkarsekreterarnas": "läkarsekreterare",
    "läkarundersök": "läkarundersöka",
    "läkarundersökande": "läkarundersöka",
    "läkarundersökanden": "läkarundersökande",
    "läkarundersökandena": "läkarundersökande",
    "läkarundersökandenas": "läkarundersökande",
    "läkarundersökandens": "läkarundersökande",
    "läkarundersökandes": "läkarundersökande",
    "läkarundersökandet": "läkarundersökande",
    "läkarundersökandets": "läkarundersökande",
    "läkarundersökas": "läkarundersöka",
    "läkarundersöker": "läkarundersöka",
    "läkarundersökes": "läkarundersöka",
    "läkarundersökningar": "läkarundersökning",
    "läkarundersökningarna": "läkarundersökning",
    "läkarundersökningarnas": "läkarundersökning",
    "läkarundersökningars": "läkarundersökning",
    "läkarundersökningen": "läkarundersökning",
    "läkarundersökningens": "läkarundersökning",
    "läkarundersöknings": "läkarundersökning",
    "läkarundersöks": "läkarundersöka",
    "läkarundersökt": "läkarundersöka",
    "läkarundersökta": "läkarundersöka",
    "läkarundersöktas": "läkarundersöka",
    "läkarundersökte": "läkarundersöka",
    "läkarundersöktes": "läkarundersöka",
    "läkarundersökts": "läkarundersöka",
    "läkarvetenskapen": "läkarvetenskap",
    "läkarvetenskapens": "läkarvetenskap",
    "läkarvetenskaps": "läkarvetenskap",
    "läkarvården": "läkarvård",
    "läkarvårdens": "läkarvård",
    "läkarvårds": "läkarvård",
    "läkas": "läka",
    "läkedomar": "läkedom",
    "läkedomarna": "läkedom",
    "läkedomarnas": "läkedom",
    "läkedomars": "läkedom",
    "läkedomen": "läkedom",
    "läkedomens": "läkedom",
    "läkedoms": "läkedom",
    "läkekonsten": "läkekonst",
    "läkekonstens": "läkekonst",
    "läkekonsts": "läkekonst",
    "läkemedels": "läkemedel",
    "läkemedelsbolagen": "läkemedelsbolag",
    "läkemedelsbolagens": "läkemedelsbolag",
    "läkemedelsbolaget": "läkemedelsbolag",
    "läkemedelsbolagets": "läkemedelsbolag",
    "läkemedelsbolags": "läkemedelsbolag",
    "läkemedelsföretagen": "läkemedelsföretag",
    "läkemedelsföretagens": "läkemedelsföretag",
    "läkemedelsföretaget": "läkemedelsföretag",
    "läkemedelsföretagets": "läkemedelsföretag",
    "läkemedelsföretags": "läkemedelsföretag",
    "läkemedelskontrollen": "läkemedelskontroll",
    "läkemedelskontrollens": "läkemedelskontroll",
    "läkemedelskontroller": "läkemedelskontroll",
    "läkemedelskontrollerna": "läkemedelskontroll",
    "läkemedelskontrollernas": "läkemedelskontroll",
    "läkemedelskontrollers": "läkemedelskontroll",
    "läkemedelskontrolls": "läkemedelskontroll",
    "läkemedelslagar": "läkemedelslag",
    "läkemedelslagarna": "läkemedelslag",
    "läkemedelslagarnas": "läkemedelslag",
    "läkemedelslagars": "läkemedelslag",
    "läkemedelslagen": "läkemedelslag",
    "läkemedelslagens": "läkemedelslag",
    "läkemedelslags": "läkemedelslag",
    "läkemedlen": "läkemedel",
    "läkemedlens": "läkemedel",
    "läkemedlet": "läkemedel",
    "läkemedlets": "läkemedel",
    "läkepedagogiken": "läkepedagogik",
    "läkepedagogikens": "läkepedagogik",
    "läkepedagogiks": "läkepedagogik",
    "läker": "läka",
    "läkes": "läka",
    "läkeväxten": "läkeväxt",
    "läkeväxtens": "läkeväxt",
    "läkeväxter": "läkeväxt",
    "läkeväxterna": "läkeväxt",
    "läkeväxternas": "läkeväxt",
    "läkeväxters": "läkeväxt",
    "läkeväxts": "läkeväxt",
    "läkköttet": "läkkött",
    "läkköttets": "läkkött",
    "läkkötts": "läkkött",
    "läkningar": "läkning",
    "läkningarna": "läkning",
    "läkningarnas": "läkning",
    "läkningars": "läkning",
    "läkningen": "läkning",
    "läkningens": "läkning",
    "läknings": "läkning",
    "läks": "läka",
    "läkt": "läka",
    "läkta": "läka",
    "läktar": "läktare",
    "läktaren": "läktare",
    "läktarens": "läktare",
    "läktares": "läktare",
    "läktarna": "läktare",
    "läktarnas": "läktare",
    "läktarvåldet": "läktarvåld",
    "läktarvåldets": "läktarvåld",
    "läktarvålds": "läktarvåld",
    "läktas": "läka",
    "läkte": "läka",
    "läkten": "läkt",
    "läktens": "läkt",
    "läkter": "läkt",
    "läkterna": "läkt",
    "läkternas": "läkt",
    "läkters": "läkt",
    "läktes": "läka",
    "läktrad": "läktra",
    "läktrade": "läktra",
    "läktrades": "läktra",
    "läktrads": "läktra",
    "läktrande": "läktra",
    "läktranden": "läktrande",
    "läktrandena": "läktrande",
    "läktrandenas": "läktrande",
    "läktrandens": "läktrande",
    "läktrandes": "läktrande",
    "läktrandet": "läktrande",
    "läktrandets": "läktrande",
    "läktrar": "läktra",
    "läktras": "läktra",
    "läktrat": "läktra",
    "läktrats": "läktra",
    "läkts": "läkt",
    "lämlar": "lämmel",
    "lämlarna": "lämmel",
    "lämlarnas": "lämmel",
    "lämlars": "lämmel",
    "lämmar": "läm",
    "lämmarna": "läm",
    "lämmarnas": "läm",
    "lämmars": "läm",
    "lämmeln": "lämmel",
    "lämmelns": "lämmel",
    "lämmels": "lämmel",
    "lämmeltågen": "lämmeltåg",
    "lämmeltågens": "lämmeltåg",
    "lämmeltåget": "lämmeltåg",
    "lämmeltågets": "lämmeltåg",
    "lämmeltågs": "lämmeltåg",
    "lämmelåren": "lämmelår",
    "lämmelårens": "lämmelår",
    "lämmelåret": "lämmelår",
    "lämmelårets": "lämmelår",
    "lämmelårs": "lämmelår",
    "lämmen": "läm",
    "lämmens": "läm",
    "lämmlar": "lämmel",
    "lämmlarna": "lämmel",
    "lämmlarnas": "lämmel",
    "lämmlars": "lämmel",
    "lämn": "lämna",
    "lämnad": "lämna",
    "lämnade": "lämna",
    "lämnades": "lämna",
    "lämnads": "lämna",
    "lämnande": "lämna",
    "lämnanden": "lämnande",
    "lämnandena": "lämnande",
    "lämnandenas": "lämnande",
    "lämnandens": "lämnande",
    "lämnandes": "lämnande",
    "lämnandet": "lämnande",
    "lämnandets": "lämnande",
    "lämnar": "lämna",
    "lämnas": "lämna",
    "lämnat": "lämna",
    "lämnats": "lämna",
    "lämningar": "lämning",
    "lämningarna": "lämning",
    "lämningarnas": "lämning",
    "lämningars": "lämning",
    "lämningen": "lämning",
    "lämningens": "lämning",
    "lämnings": "lämning",
    "lämp": "lämpa",
    "lämpad": "lämpa",
    "lämpade": "lämpad",
    "lämpades": "lämpad",
    "lämpads": "lämpad",
    "lämpande": "lämpa",
    "lämpanden": "lämpande",
    "lämpandena": "lämpande",
    "lämpandenas": "lämpande",
    "lämpandens": "lämpande",
    "lämpandes": "lämpande",
    "lämpandet": "lämpande",
    "lämpandets": "lämpande",
    "lämpar": "lämpare",
    "lämparen": "lämpare",
    "lämparens": "lämpare",
    "lämpares": "lämpare",
    "lämparna": "lämpare",
    "lämparnas": "lämpare",
    "lämpas": "lämpa",
    "lämpat": "lämpad",
    "lämpats": "lämpad",
    "lämpliga": "lämplig",
    "lämpligare": "lämplig",
    "lämpligares": "lämplig",
    "lämpligas": "lämplig",
    "lämpligast": "lämplig",
    "lämpligaste": "lämplig",
    "lämpligastes": "lämplig",
    "lämpligasts": "lämplig",
    "lämplige": "lämplig",
    "lämpliges": "lämplig",
    "lämpligheten": "lämplighet",
    "lämplighetens": "lämplighet",
    "lämpligheter": "lämplighet",
    "lämpligheterna": "lämplighet",
    "lämpligheternas": "lämplighet",
    "lämpligheters": "lämplighet",
    "lämplighets": "lämplighet",
    "lämplighetsintygen": "lämplighetsintyg",
    "lämplighetsintygens": "lämplighetsintyg",
    "lämplighetsintyget": "lämplighetsintyg",
    "lämplighetsintygets": "lämplighetsintyg",
    "lämplighetsintygs": "lämplighetsintyg",
    "lämpligs": "lämplig",
    "lämpligt": "lämplig",
    "lämpligts": "lämplig",
    "lämporna": "lämpor",
    "lämpornas": "lämpor",
    "lämpors": "lämpor",
    "läms": "läm",
    "länd": "lända",
    "ländande": "lända",
    "ländanden": "ländande",
    "ländandena": "ländande",
    "ländandenas": "ländande",
    "ländandens": "ländande",
    "ländandes": "ländande",
    "ländandet": "ländande",
    "ländandets": "ländande",
    "ländas": "lända",
    "lände": "lända",
    "länden": "länd",
    "ländens": "länd",
    "länder": "lända",
    "ländergruppen": "ländergrupp",
    "ländergruppens": "ländergrupp",
    "ländergrupper": "ländergrupp",
    "ländergrupperna": "ländergrupp",
    "ländergruppernas": "ländergrupp",
    "ländergruppers": "ländergrupp",
    "ländergrupps": "ländergrupp",
    "länderna": "länd",
    "ländernas": "länd",
    "länders": "länd",
    "ländervalen": "länderval",
    "ländervalens": "länderval",
    "ländervalet": "länderval",
    "ländervalets": "länderval",
    "ländervals": "länderval",
    "ländes": "lända",
    "ländkläden": "ländkläde",
    "ländklädena": "ländkläde",
    "ländklädenas": "ländkläde",
    "ländklädens": "ländkläde",
    "ländklädes": "ländkläde",
    "ländklädet": "ländkläde",
    "ländklädets": "ländkläde",
    "ländkläds": "ländkläde",
    "ländkot": "ländkota",
    "ländkotan": "ländkota",
    "ländkotans": "ländkota",
    "ländkotas": "ländkota",
    "ländkote": "ländkota",
    "ländkotor": "ländkota",
    "ländkotorna": "ländkota",
    "ländkotornas": "ländkota",
    "ländkotors": "ländkota",
    "ländkots": "ländkota",
    "länds": "lända",
    "ländstycken": "ländstycke",
    "ländstyckena": "ländstycke",
    "ländstyckenas": "ländstycke",
    "ländstyckens": "ländstycke",
    "ländstyckes": "ländstycke",
    "ländstycket": "ländstycke",
    "ländstyckets": "ländstycke",
    "ländstycks": "ländstycke",
    "länen": "län",
    "länens": "län",
    "länet": "län",
    "länets": "län",
    "läng": "länga",
    "längan": "länga",
    "längande": "länga",
    "länganden": "längande",
    "längandena": "längande",
    "längandenas": "längande",
    "längandens": "längande",
    "längandes": "längande",
    "längandet": "längande",
    "längandets": "längande",
    "längans": "länga",
    "längas": "länga",
    "längd": "länga",
    "längda": "länga",
    "längdas": "länga",
    "längdaxeln": "längdaxel",
    "längdaxelns": "längdaxel",
    "längdaxels": "längdaxel",
    "längdaxlar": "längdaxel",
    "längdaxlarna": "längdaxel",
    "längdaxlarnas": "längdaxel",
    "längdaxlars": "längdaxel",
    "längde": "länga",
    "längden": "längd",
    "längdenheten": "längdenhet",
    "längdenhetens": "längdenhet",
    "längdenheter": "längdenhet",
    "längdenheterna": "längdenhet",
    "längdenheternas": "längdenhet",
    "längdenheters": "längdenhet",
    "längdenhets": "längdenhet",
    "längdens": "längd",
    "längder": "längd",
    "längderna": "längd",
    "längdernas": "längd",
    "längders": "längd",
    "längdes": "längas",
    "längdgraden": "längdgrad",
    "längdgradens": "längdgrad",
    "längdgrader": "längdgrad",
    "längdgraderna": "längdgrad",
    "längdgradernas": "längdgrad",
    "längdgraders": "längdgrad",
    "längdgrads": "längdgrad",
    "längdhoppar": "längdhoppare",
    "längdhopparen": "längdhoppare",
    "längdhopparens": "längdhoppare",
    "längdhoppares": "längdhoppare",
    "längdhopparna": "längdhoppare",
    "längdhopparnas": "längdhoppare",
    "längdhoppen": "längdhopp",
    "längdhoppens": "längdhopp",
    "längdhoppet": "längdhopp",
    "längdhoppets": "längdhopp",
    "längdhopps": "längdhopp",
    "längdlöpningar": "längdlöpning",
    "längdlöpningarna": "längdlöpning",
    "längdlöpningarnas": "längdlöpning",
    "längdlöpningars": "längdlöpning",
    "längdlöpningen": "längdlöpning",
    "längdlöpningens": "längdlöpning",
    "längdlöpnings": "längdlöpning",
    "längdmarkeringar": "längdmarkering",
    "längdmarkeringarna": "längdmarkering",
    "längdmarkeringarnas": "längdmarkering",
    "längdmarkeringars": "längdmarkering",
    "längdmarkeringen": "längdmarkering",
    "längdmarkeringens": "längdmarkering",
    "längdmarkerings": "längdmarkering",
    "längdmetern": "längdmeter",
    "längdmeterna": "längdmeter",
    "längdmeternas": "längdmeter",
    "längdmeterns": "längdmeter",
    "längdmeters": "längdmeter",
    "längdmåtten": "längdmått",
    "längdmåttens": "längdmått",
    "längdmåttet": "längdmått",
    "längdmåttets": "längdmått",
    "längdmåtts": "längdmått",
    "längdprofilen": "längdprofil",
    "längdprofilens": "längdprofil",
    "längdprofiler": "längdprofil",
    "längdprofilerna": "längdprofil",
    "längdprofilernas": "längdprofil",
    "längdprofilers": "längdprofil",
    "längdprofils": "längdprofil",
    "längdriktningar": "längdriktning",
    "längdriktningarna": "längdriktning",
    "längdriktningarnas": "längdriktning",
    "längdriktningars": "längdriktning",
    "längdriktningen": "längdriktning",
    "längdriktningens": "längdriktning",
    "längdriktnings": "längdriktning",
    "längds": "längd",
    "längdsnitten": "längdsnitt",
    "längdsnittens": "längdsnitt",
    "längdsnittet": "längdsnitt",
    "längdsnittets": "längdsnitt",
    "längdsnitts": "längdsnitt",
    "längdsprick": "längdspricka",
    "längdsprickan": "längdspricka",
    "längdsprickans": "längdspricka",
    "längdsprickas": "längdspricka",
    "längdspricke": "längdspricka",
    "längdsprickor": "längdspricka",
    "längdsprickorna": "längdspricka",
    "längdsprickornas": "längdspricka",
    "längdsprickors": "längdspricka",
    "längdspricks": "längdspricka",
    "längdstrecken": "längdstreck",
    "längdstreckens": "längdstreck",
    "längdstrecket": "längdstreck",
    "längdstreckets": "längdstreck",
    "längdstrecks": "längdstreck",
    "längdteckens": "längdtecken",
    "längdtecknen": "längdtecken",
    "längdtecknens": "längdtecken",
    "längdtecknet": "längdtecken",
    "längdtecknets": "längdtecken",
    "längdutvidgningar": "längdutvidgning",
    "längdutvidgningarna": "längdutvidgning",
    "längdutvidgningarnas": "längdutvidgning",
    "längdutvidgningars": "längdutvidgning",
    "längdutvidgningen": "längdutvidgning",
    "längdutvidgningens": "längdutvidgning",
    "längdutvidgnings": "längdutvidgning",
    "längdåkningar": "längdåkning",
    "längdåkningarna": "längdåkning",
    "längdåkningarnas": "längdåkning",
    "längdåkningars": "längdåkning",
    "längdåkningen": "längdåkning",
    "längdåkningens": "längdåkning",
    "längdåknings": "längdåkning",
    "länge": "länga",
    "länger": "länga",
    "länges": "längas",
    "längor": "länga",
    "längorna": "länga",
    "längornas": "länga",
    "längors": "länga",
    "längre": "länge",
    "längres": "lång",
    "längs": "längas",
    "längsdalar": "längsdal",
    "längsdalarna": "längsdal",
    "längsdalarnas": "längsdal",
    "längsdalars": "längsdal",
    "längsdalen": "längsdal",
    "längsdalens": "längsdal",
    "längsdals": "längsdal",
    "längst": "länge",
    "längsta": "lång",
    "längstas": "lång",
    "längste": "lång",
    "längstes": "lång",
    "längstförflutens": "längstförfluten",
    "längstförflutet": "längstförfluten",
    "längstförflutets": "längstförfluten",
    "längstförflutna": "längstförfluten",
    "längstförflutnare": "längstförfluten",
    "längstförflutnares": "längstförfluten",
    "längstförflutnas": "längstförfluten",
    "längstförflutnast": "längstförfluten",
    "längstförflutnaste": "längstförfluten",
    "längstförflutnastes": "längstförfluten",
    "längstförflutnasts": "längstförfluten",
    "längstförflutne": "längstförfluten",
    "längstförflutnes": "längstförfluten",
    "längsts": "lång",
    "längt": "länga",
    "längtade": "längta",
    "längtades": "längta",
    "längtande": "längta",
    "längtanden": "längtande",
    "längtandena": "längtande",
    "längtandenas": "längtande",
    "längtandens": "längtande",
    "längtandes": "längtande",
    "längtandet": "längtande",
    "längtandets": "längtande",
    "längtans": "längtan",
    "längtansfulla": "längtansfull",
    "längtansfullare": "längtansfull",
    "längtansfullares": "längtansfull",
    "längtansfullas": "längtansfull",
    "längtansfullast": "längtansfull",
    "längtansfullaste": "längtansfull",
    "längtansfullastes": "längtansfull",
    "längtansfullasts": "längtansfull",
    "längtansfulle": "längtansfull",
    "längtansfulles": "längtansfull",
    "längtansfullheten": "längtansfullhet",
    "längtansfullhetens": "längtansfullhet",
    "längtansfullhets": "längtansfullhet",
    "längtansfulls": "längtansfull",
    "längtansfullt": "längtansfull",
    "längtansfullts": "längtansfull",
    "längtar": "längta",
    "längtas": "längta",
    "längtat": "längta",
    "längtats": "längta",
    "längts": "längas",
    "länk": "länka",
    "länkad": "länka",
    "länkade": "länka",
    "länkades": "länka",
    "länkads": "länka",
    "länkande": "länka",
    "länkanden": "länkande",
    "länkandena": "länkande",
    "länkandenas": "länkande",
    "länkandens": "länkande",
    "länkandes": "länkande",
    "länkandet": "länkande",
    "länkandets": "länkande",
    "länkar": "länka",
    "länkarna": "länk",
    "länkarnas": "länk",
    "länkars": "länk",
    "länkas": "länka",
    "länkat": "länka",
    "länkats": "länka",
    "länken": "länk",
    "länkens": "länk",
    "länkhjulen": "länkhjul",
    "länkhjulens": "länkhjul",
    "länkhjulet": "länkhjul",
    "länkhjulets": "länkhjul",
    "länkhjuls": "länkhjul",
    "länkrörelsen": "länkrörelse",
    "länkrörelsens": "länkrörelse",
    "länkrörelser": "länkrörelse",
    "länkrörelserna": "länkrörelse",
    "länkrörelsernas": "länkrörelse",
    "länkrörelsers": "länkrörelse",
    "länkrörelses": "länkrörelse",
    "länkrötan": "länkröta",
    "länkrötans": "länkröta",
    "länkrötas": "länkröta",
    "länkröte": "länkröta",
    "länks": "länk",
    "länkstationen": "länkstation",
    "länkstationens": "länkstation",
    "länkstationer": "länkstation",
    "länkstationerna": "länkstation",
    "länkstationernas": "länkstation",
    "länkstationers": "länkstation",
    "länkstations": "länkstation",
    "läns": "länsa",
    "länsad": "länsa",
    "länsade": "länsa",
    "länsades": "länsa",
    "länsads": "länsa",
    "länsande": "länsa",
    "länsanden": "länsande",
    "länsandena": "länsande",
    "länsandenas": "länsande",
    "länsandens": "länsande",
    "länsandes": "länsande",
    "länsandet": "länsande",
    "länsandets": "länsande",
    "länsar": "länsa",
    "länsarbetsdirektören": "länsarbetsdirektör",
    "länsarbetsdirektörens": "länsarbetsdirektör",
    "länsarbetsdirektörer": "länsarbetsdirektör",
    "länsarbetsdirektörerna": "länsarbetsdirektör",
    "länsarbetsdirektörernas": "länsarbetsdirektör",
    "länsarbetsdirektörers": "länsarbetsdirektör",
    "länsarbetsdirektörn": "länsarbetsdirektör",
    "länsarbetsdirektörns": "länsarbetsdirektör",
    "länsarbetsdirektörs": "länsarbetsdirektör",
    "länsarbetsnämnden": "länsarbetsnämnd",
    "länsarbetsnämndens": "länsarbetsnämnd",
    "länsarbetsnämnder": "länsarbetsnämnd",
    "länsarbetsnämnderna": "länsarbetsnämnd",
    "länsarbetsnämndernas": "länsarbetsnämnd",
    "länsarbetsnämnders": "länsarbetsnämnd",
    "länsarbetsnämnds": "länsarbetsnämnd",
    "länsarkitekten": "länsarkitekt",
    "länsarkitektens": "länsarkitekt",
    "länsarkitekter": "länsarkitekt",
    "länsarkitekterna": "länsarkitekt",
    "länsarkitekternas": "länsarkitekt",
    "länsarkitekters": "länsarkitekt",
    "länsarkitekts": "länsarkitekt",
    "länsarna": "läns",
    "länsarnas": "läns",
    "länsars": "läns",
    "länsas": "länsa",
    "länsat": "länsa",
    "länsats": "länsa",
    "länsbeteckningar": "länsbeteckning",
    "länsbeteckningarna": "länsbeteckning",
    "länsbeteckningarnas": "länsbeteckning",
    "länsbeteckningars": "länsbeteckning",
    "länsbeteckningen": "länsbeteckning",
    "länsbeteckningens": "länsbeteckning",
    "länsbetecknings": "länsbeteckning",
    "länsbokstaven": "länsbokstav",
    "länsbokstavens": "länsbokstav",
    "länsbokstavs": "länsbokstav",
    "länsbokstäver": "länsbokstav",
    "länsbokstäverna": "länsbokstav",
    "länsbokstävernas": "länsbokstav",
    "länsbokstävers": "länsbokstav",
    "länsen": "läns",
    "länsens": "läns",
    "länsherrar": "länsherre",
    "länsherrarna": "länsherre",
    "länsherrarnas": "länsherre",
    "länsherrars": "länsherre",
    "länsherren": "länsherre",
    "länsherrens": "länsherre",
    "länsherres": "länsherre",
    "länskoden": "länskod",
    "länskodens": "länskod",
    "länskoder": "länskod",
    "länskoderna": "länskod",
    "länskodernas": "länskod",
    "länskoders": "länskod",
    "länskods": "länskod",
    "länskriminalen": "länskriminal",
    "länskriminalens": "länskriminal",
    "länskriminals": "länskriminal",
    "länslasaretten": "länslasarett",
    "länslasarettens": "länslasarett",
    "länslasarettet": "länslasarett",
    "länslasarettets": "länslasarett",
    "länslasaretts": "länslasarett",
    "länsmannen": "länsman",
    "länsmannens": "länsman",
    "länsmans": "länsman",
    "länsmän": "länsman",
    "länsmännen": "länsman",
    "länsmännens": "länsman",
    "länsmäns": "länsman",
    "länspolisen": "länspolis",
    "länspolisens": "länspolis",
    "länspumpar": "länspump",
    "länspumparna": "länspump",
    "länspumparnas": "länspump",
    "länspumpars": "länspump",
    "länspumpen": "länspump",
    "länspumpens": "länspump",
    "länspumps": "länspump",
    "länsresidensen": "länsresidens",
    "länsresidensens": "länsresidens",
    "länsresidenset": "länsresidens",
    "länsresidensets": "länsresidens",
    "länsrätten": "länsrätt",
    "länsrättens": "länsrätt",
    "länsrätter": "länsrätt",
    "länsrätterna": "länsrätt",
    "länsrätternas": "länsrätt",
    "länsrätters": "länsrätt",
    "länsrätts": "länsrätt",
    "länsråden": "länsråd",
    "länsrådens": "länsråd",
    "länsrådet": "länsråd",
    "länsrådets": "länsråd",
    "länsråds": "länsråd",
    "länsskatterätten": "länsskatterätt",
    "länsskatterättens": "länsskatterätt",
    "länsskatterätter": "länsskatterätt",
    "länsskatterätterna": "länsskatterätt",
    "länsskatterätternas": "länsskatterätt",
    "länsskatterätters": "länsskatterätt",
    "länsskatterätts": "länsskatterätt",
    "länsskolnämnden": "länsskolnämnd",
    "länsskolnämndens": "länsskolnämnd",
    "länsskolnämnder": "länsskolnämnd",
    "länsskolnämnderna": "länsskolnämnd",
    "länsskolnämndernas": "länsskolnämnd",
    "länsskolnämnders": "länsskolnämnd",
    "länsskolnämnds": "länsskolnämnd",
    "länsstyrelsen": "länsstyrelse",
    "länsstyrelsens": "länsstyrelse",
    "länsstyrelser": "länsstyrelse",
    "länsstyrelserna": "länsstyrelse",
    "länsstyrelsernas": "länsstyrelse",
    "länsstyrelsers": "länsstyrelse",
    "länsstyrelses": "länsstyrelse",
    "länstolar": "länstol",
    "länstolarna": "länstol",
    "länstolarnas": "länstol",
    "länstolars": "länstol",
    "länstolen": "länstol",
    "länstolens": "länstol",
    "länstols": "länstol",
    "länsvakthavanden": "länsvakthavande",
    "länsvakthavandena": "länsvakthavande",
    "länsvakthavandenas": "länsvakthavande",
    "länsvakthavandens": "länsvakthavande",
    "länsvakthavandes": "länsvakthavande",
    "länsvägar": "länsväg",
    "länsvägarna": "länsväg",
    "länsvägarnas": "länsväg",
    "länsvägars": "länsväg",
    "länsvägen": "länsväg",
    "länsvägens": "länsväg",
    "länsvägs": "länsväg",
    "länsväsendet": "länsväsen",
    "länsväsendets": "länsväsen",
    "länsväsenet": "länsväsen",
    "länsväsenets": "länsväsen",
    "länsväsens": "länsväsen",
    "länsåklagar": "länsåklagare",
    "länsåklagaren": "länsåklagare",
    "länsåklagarens": "länsåklagare",
    "länsåklagares": "länsåklagare",
    "länsåklagarna": "länsåklagare",
    "länsåklagarnas": "länsåklagare",
    "länt": "lända",
    "läntagar": "läntagare",
    "läntagaren": "läntagare",
    "läntagarens": "läntagare",
    "läntagares": "läntagare",
    "läntagarna": "läntagare",
    "läntagarnas": "läntagare",
    "länts": "lända",
    "läppar": "läpp",
    "läpparna": "läpp",
    "läpparnas": "läpp",
    "läppars": "läpp",
    "läppavläsningar": "läppavläsning",
    "läppavläsningarna": "läppavläsning",
    "läppavläsningarnas": "läppavläsning",
    "läppavläsningars": "läppavläsning",
    "läppavläsningen": "läppavläsning",
    "läppavläsningens": "läppavläsning",
    "läppavläsnings": "läppavläsning",
    "läppen": "läpp",
    "läppens": "läpp",
    "läppglansen": "läppglans",
    "läppglansens": "läppglans",
    "läppjade": "läppja",
    "läppjades": "läppja",
    "läppjande": "läppja",
    "läppjanden": "läppjande",
    "läppjandena": "läppjande",
    "läppjandenas": "läppjande",
    "läppjandens": "läppjande",
    "läppjandes": "läppjande",
    "läppjandet": "läppjande",
    "läppjandets": "läppjande",
    "läppjar": "läppja",
    "läppjas": "läppja",
    "läppjat": "läppja",
    "läppjats": "läppja",
    "läppljuden": "läppljud",
    "läppljudens": "läppljud",
    "läppljudet": "läppljud",
    "läppljudets": "läppljud",
    "läppljuds": "läppljud",
    "läpprörelsen": "läpprörelse",
    "läpprörelsens": "läpprörelse",
    "läpprörelser": "läpprörelse",
    "läpprörelserna": "läpprörelse",
    "läpprörelsernas": "läpprörelse",
    "läpprörelsers": "läpprörelse",
    "läpprörelses": "läpprörelse",
    "läpps": "läpp",
    "läppsminker": "läppsmink",
    "läppsminkerna": "läppsmink",
    "läppsminkernas": "läppsmink",
    "läppsminkers": "läppsmink",
    "läppsminket": "läppsmink",
    "läppsminkets": "läppsmink",
    "läppsminks": "läppsmink",
    "läppsnuser": "läppsnus",
    "läppsnuserna": "läppsnus",
    "läppsnusernas": "läppsnus",
    "läppsnusers": "läppsnus",
    "läppsnuset": "läppsnus",
    "läppsnusets": "läppsnus",
    "läppstiften": "läppstift",
    "läppstiftens": "läppstift",
    "läppstiftet": "läppstift",
    "läppstiftets": "läppstift",
    "läppstifts": "läppstift",
    "lär": "lära",
    "läraktiga": "läraktig",
    "läraktigare": "läraktig",
    "läraktigares": "läraktig",
    "läraktigas": "läraktig",
    "läraktigast": "läraktig",
    "läraktigaste": "läraktig",
    "läraktigastes": "läraktig",
    "läraktigasts": "läraktig",
    "läraktige": "läraktig",
    "läraktiges": "läraktig",
    "läraktigheten": "läraktighet",
    "läraktighetens": "läraktighet",
    "läraktighets": "läraktighet",
    "läraktigs": "läraktig",
    "läraktigt": "läraktig",
    "läraktigts": "läraktig",
    "läran": "lära",
    "lärande": "lära",
    "läranden": "lärande",
    "lärandena": "lärande",
    "lärandenas": "lärande",
    "lärandens": "lärande",
    "lärandes": "lärande",
    "lärandet": "lärande",
    "lärandets": "lärande",
    "lärans": "lära",
    "lärar": "lärare",
    "läraren": "lärare",
    "lärarens": "lärare",
    "lärares": "lärare",
    "lärarfortbildningar": "lärarfortbildning",
    "lärarfortbildningarna": "lärarfortbildning",
    "lärarfortbildningarnas": "lärarfortbildning",
    "lärarfortbildningars": "lärarfortbildning",
    "lärarfortbildningen": "lärarfortbildning",
    "lärarfortbildningens": "lärarfortbildning",
    "lärarfortbildnings": "lärarfortbildning",
    "lärarhögskolan": "lärarhögskola",
    "lärarhögskolans": "lärarhögskola",
    "lärarhögskolas": "lärarhögskola",
    "lärarhögskole": "lärarhögskola",
    "lärarhögskolor": "lärarhögskola",
    "lärarhögskolorna": "lärarhögskola",
    "lärarhögskolornas": "lärarhögskola",
    "lärarhögskolors": "lärarhögskola",
    "lärarinnan": "lärarinna",
    "lärarinnans": "lärarinna",
    "lärarinnas": "lärarinna",
    "lärarinne": "lärarinna",
    "lärarinnor": "lärarinna",
    "lärarinnorna": "lärarinna",
    "lärarinnornas": "lärarinna",
    "lärarinnors": "lärarinna",
    "lärarkandidaten": "lärarkandidat",
    "lärarkandidatens": "lärarkandidat",
    "lärarkandidater": "lärarkandidat",
    "lärarkandidaterna": "lärarkandidat",
    "lärarkandidaternas": "lärarkandidat",
    "lärarkandidaters": "lärarkandidat",
    "lärarkandidats": "lärarkandidat",
    "lärarkåren": "lärarkår",
    "lärarkårens": "lärarkår",
    "lärarkårer": "lärarkår",
    "lärarkårerna": "lärarkår",
    "lärarkårernas": "lärarkår",
    "lärarkårers": "lärarkår",
    "lärarkårs": "lärarkår",
    "lärarledda": "lärarledd",
    "lärarleddare": "lärarledd",
    "lärarleddares": "lärarledd",
    "lärarleddas": "lärarledd",
    "lärarleddast": "lärarledd",
    "lärarleddaste": "lärarledd",
    "lärarleddastes": "lärarledd",
    "lärarleddasts": "lärarledd",
    "lärarledde": "lärarledd",
    "lärarleddes": "lärarledd",
    "lärarledds": "lärarledd",
    "lärarlett": "lärarledd",
    "lärarletts": "lärarledd",
    "lärarlinjen": "lärarlinje",
    "lärarlinjens": "lärarlinje",
    "lärarlinjer": "lärarlinje",
    "lärarlinjerna": "lärarlinje",
    "lärarlinjernas": "lärarlinje",
    "lärarlinjers": "lärarlinje",
    "lärarlinjes": "lärarlinje",
    "lärarlösa": "lärarlös",
    "lärarlösare": "lärarlös",
    "lärarlösares": "lärarlös",
    "lärarlösas": "lärarlös",
    "lärarlösast": "lärarlös",
    "lärarlösaste": "lärarlös",
    "lärarlösastes": "lärarlös",
    "lärarlösasts": "lärarlös",
    "lärarlöse": "lärarlös",
    "lärarlöses": "lärarlös",
    "lärarlösheten": "lärarlöshet",
    "lärarlöshetens": "lärarlöshet",
    "lärarlöshets": "lärarlöshet",
    "lärarlöst": "lärarlös",
    "lärarlösts": "lärarlös",
    "lärarna": "lärare",
    "lärarnas": "lärare",
    "lärarrollen": "lärarroll",
    "lärarrollens": "lärarroll",
    "lärarroller": "lärarroll",
    "lärarrollerna": "lärarroll",
    "lärarrollernas": "lärarroll",
    "lärarrollers": "lärarroll",
    "lärarrolls": "lärarroll",
    "lärarrummen": "lärarrum",
    "lärarrummens": "lärarrum",
    "lärarrummet": "lärarrum",
    "lärarrummets": "lärarrum",
    "lärarrums": "lärarrum",
    "lärartätheten": "lärartäthet",
    "lärartäthetens": "lärartäthet",
    "lärartätheter": "lärartäthet",
    "lärartätheterna": "lärartäthet",
    "lärartätheternas": "lärartäthet",
    "lärartätheters": "lärartäthet",
    "lärartäthets": "lärartäthet",
    "läras": "lära",
    "lärd": "lära",
    "lärda": "lärd",
    "lärdare": "lärd",
    "lärdares": "lärd",
    "lärdas": "lärd",
    "lärdast": "lärd",
    "lärdaste": "lärd",
    "lärdastes": "lärd",
    "lärdasts": "lärd",
    "lärde": "lärd",
    "lärdes": "lärd",
    "lärdheten": "lärdhet",
    "lärdhetens": "lärdhet",
    "lärdhets": "lärdhet",
    "lärdomar": "lärdom",
    "lärdomarna": "lärdom",
    "lärdomarnas": "lärdom",
    "lärdomars": "lärdom",
    "lärdomen": "lärdom",
    "lärdomens": "lärdom",
    "lärdoms": "lärdom",
    "lärdomshistorian": "lärdomshistoria",
    "lärdomshistorians": "lärdomshistoria",
    "lärdomshistorias": "lärdomshistoria",
    "lärdomshistorien": "lärdomshistoria",
    "lärdomshistoriens": "lärdomshistoria",
    "lärdomsproven": "lärdomsprov",
    "lärdomsprovens": "lärdomsprov",
    "lärdomsprovet": "lärdomsprov",
    "lärdomsprovets": "lärdomsprov",
    "lärdomsprovs": "lärdomsprov",
    "lärdomsskolan": "lärdomsskola",
    "lärdomsskolans": "lärdomsskola",
    "lärdomsskolas": "lärdomsskola",
    "lärdomsskole": "lärdomsskola",
    "lärdomsskolor": "lärdomsskola",
    "lärdomsskolorna": "lärdomsskola",
    "lärdomsskolornas": "lärdomsskola",
    "lärdomsskolors": "lärdomsskola",
    "lärdomsstaden": "lärdomsstad",
    "lärdomsstadens": "lärdomsstad",
    "lärdomsstads": "lärdomsstad",
    "lärdomsstäder": "lärdomsstad",
    "lärdomsstäderna": "lärdomsstad",
    "lärdomsstädernas": "lärdomsstad",
    "lärdomsstäders": "lärdomsstad",
    "lärds": "lärd",
    "läre": "lära",
    "läres": "lära",
    "lärftbindningar": "lärftbindning",
    "lärftbindningarna": "lärftbindning",
    "lärftbindningarnas": "lärftbindning",
    "lärftbindningars": "lärftbindning",
    "lärftbindningen": "lärftbindning",
    "lärftbindningens": "lärftbindning",
    "lärftbindnings": "lärftbindning",
    "lärften": "lärft",
    "lärftens": "lärft",
    "lärfter": "lärft",
    "lärfterna": "lärft",
    "lärfternas": "lärft",
    "lärfters": "lärft",
    "lärftet": "lärft",
    "lärftets": "lärft",
    "lärfts": "lärft",
    "lärjungar": "lärjunge",
    "lärjungarna": "lärjunge",
    "lärjungarnas": "lärjunge",
    "lärjungars": "lärjunge",
    "lärjungaskapet": "lärjungaskap",
    "lärjungaskapets": "lärjungaskap",
    "lärjungaskaps": "lärjungaskap",
    "lärjungen": "lärjunge",
    "lärjungens": "lärjunge",
    "lärjunges": "lärjunge",
    "lärk": "lärka",
    "lärkan": "lärka",
    "lärkans": "lärka",
    "lärkar": "lärk",
    "lärkarna": "lärk",
    "lärkarnas": "lärk",
    "lärkars": "lärk",
    "lärkas": "lärka",
    "lärke": "lärka",
    "lärken": "lärk",
    "lärkens": "lärk",
    "lärkfalkar": "lärkfalk",
    "lärkfalkarna": "lärkfalk",
    "lärkfalkarnas": "lärkfalk",
    "lärkfalkars": "lärkfalk",
    "lärkfalken": "lärkfalk",
    "lärkfalkens": "lärkfalk",
    "lärkfalks": "lärkfalk",
    "lärkor": "lärka",
    "lärkorna": "lärka",
    "lärkornas": "lärka",
    "lärkors": "lärka",
    "lärks": "lärka",
    "lärkträden": "lärkträd",
    "lärkträdens": "lärkträd",
    "lärkträdet": "lärkträd",
    "lärkträdets": "lärkträd",
    "lärkträds": "lärkträd",
    "lärkträet": "lärkträ",
    "lärkträets": "lärkträ",
    "lärkträs": "lärkträ",
    "lärkträt": "lärkträ",
    "lärkträts": "lärkträ",
    "lärkving": "lärkvinge",
    "lärkvingar": "lärkvinge",
    "lärkvingarna": "lärkvinge",
    "lärkvingarnas": "lärkvinge",
    "lärkvingars": "lärkvinge",
    "lärkvingen": "lärkvinge",
    "lärkvingens": "lärkvinge",
    "lärkvinges": "lärkvinge",
    "lärkvings": "lärkvinge",
    "lärlingar": "lärling",
    "lärlingarna": "lärling",
    "lärlingarnas": "lärling",
    "lärlingars": "lärling",
    "lärlingen": "lärling",
    "lärlingens": "lärling",
    "lärlings": "lärling",
    "lärlingssystemen": "lärlingssystem",
    "lärlingssystemens": "lärlingssystem",
    "lärlingssystemet": "lärlingssystem",
    "lärlingssystemets": "lärlingssystem",
    "lärlingssystems": "lärlingssystem",
    "lärlingsutbildningar": "lärlingsutbildning",
    "lärlingsutbildningarna": "lärlingsutbildning",
    "lärlingsutbildningarnas": "lärlingsutbildning",
    "lärlingsutbildningars": "lärlingsutbildning",
    "lärlingsutbildningen": "lärlingsutbildning",
    "lärlingsutbildningens": "lärlingsutbildning",
    "lärlingsutbildnings": "lärlingsutbildning",
    "läro": "lära",
    "läroanstalten": "läroanstalt",
    "läroanstaltens": "läroanstalt",
    "läroanstalter": "läroanstalt",
    "läroanstalterna": "läroanstalt",
    "läroanstalternas": "läroanstalt",
    "läroanstalters": "läroanstalt",
    "läroanstalts": "läroanstalt",
    "läroboken": "lärobok",
    "lärobokens": "lärobok",
    "läroboks": "lärobok",
    "läroboksaktiga": "läroboksaktig",
    "läroboksaktigare": "läroboksaktig",
    "läroboksaktigares": "läroboksaktig",
    "läroboksaktigas": "läroboksaktig",
    "läroboksaktigast": "läroboksaktig",
    "läroboksaktigaste": "läroboksaktig",
    "läroboksaktigastes": "läroboksaktig",
    "läroboksaktigasts": "läroboksaktig",
    "läroboksaktige": "läroboksaktig",
    "läroboksaktiges": "läroboksaktig",
    "läroboksaktigheten": "läroboksaktighet",
    "läroboksaktighetens": "läroboksaktighet",
    "läroboksaktighets": "läroboksaktighet",
    "läroboksaktigs": "läroboksaktig",
    "läroboksaktigt": "läroboksaktig",
    "läroboksaktigts": "läroboksaktig",
    "läroboksmässiga": "läroboksmässig",
    "läroboksmässigare": "läroboksmässig",
    "läroboksmässigares": "läroboksmässig",
    "läroboksmässigas": "läroboksmässig",
    "läroboksmässigast": "läroboksmässig",
    "läroboksmässigaste": "läroboksmässig",
    "läroboksmässigastes": "läroboksmässig",
    "läroboksmässigasts": "läroboksmässig",
    "läroboksmässige": "läroboksmässig",
    "läroboksmässiges": "läroboksmässig",
    "läroboksmässigs": "läroboksmässig",
    "läroboksmässigt": "läroboksmässig",
    "läroboksmässigts": "läroboksmässig",
    "läroboksnämnden": "läroboksnämnd",
    "läroboksnämndens": "läroboksnämnd",
    "läroboksnämnder": "läroboksnämnd",
    "läroboksnämnderna": "läroboksnämnd",
    "läroboksnämndernas": "läroboksnämnd",
    "läroboksnämnders": "läroboksnämnd",
    "läroboksnämnds": "läroboksnämnd",
    "lärobokssatsen": "lärobokssats",
    "lärobokssatsens": "lärobokssats",
    "lärobokssatser": "lärobokssats",
    "lärobokssatserna": "lärobokssats",
    "lärobokssatsernas": "lärobokssats",
    "lärobokssatsers": "lärobokssats",
    "lärobyggnaden": "lärobyggnad",
    "lärobyggnadens": "lärobyggnad",
    "lärobyggnader": "lärobyggnad",
    "lärobyggnaderna": "lärobyggnad",
    "lärobyggnadernas": "lärobyggnad",
    "lärobyggnaders": "lärobyggnad",
    "lärobyggnads": "lärobyggnad",
    "läroböcker": "lärobok",
    "läroböckerna": "lärobok",
    "läroböckernas": "lärobok",
    "läroböckers": "lärobok",
    "lärodikten": "lärodikt",
    "lärodiktens": "lärodikt",
    "lärodikter": "lärodikt",
    "lärodikterna": "lärodikt",
    "lärodikternas": "lärodikt",
    "lärodikters": "lärodikt",
    "lärodikts": "lärodikt",
    "lärofadern": "lärofader",
    "lärofaderns": "lärofader",
    "lärofaders": "lärofader",
    "lärofäder": "lärofader",
    "lärofäderna": "lärofader",
    "lärofädernas": "lärofader",
    "lärofäders": "lärofader",
    "läromedels": "läromedel",
    "läromedelspaketen": "läromedelspaket",
    "läromedelspaketens": "läromedelspaket",
    "läromedelspaketet": "läromedelspaket",
    "läromedelspaketets": "läromedelspaket",
    "läromedelspakets": "läromedelspaket",
    "läromedlen": "läromedel",
    "läromedlens": "läromedel",
    "läromedlet": "läromedel",
    "läromedlets": "läromedel",
    "läromässiga": "läromässig",
    "läromässigare": "läromässig",
    "läromässigares": "läromässig",
    "läromässigas": "läromässig",
    "läromässigast": "läromässig",
    "läromässigaste": "läromässig",
    "läromässigastes": "läromässig",
    "läromässigasts": "läromässig",
    "läromässige": "läromässig",
    "läromässiges": "läromässig",
    "läromässigs": "läromässig",
    "läromässigt": "läromässig",
    "läromässigts": "läromässig",
    "läromästar": "läromästare",
    "läromästaren": "läromästare",
    "läromästarens": "läromästare",
    "läromästares": "läromästare",
    "läromästarna": "läromästare",
    "läromästarnas": "läromästare",
    "läroplane": "läroplan",
    "läroplanen": "läroplan",
    "läroplanens": "läroplan",
    "läroplaner": "läroplan",
    "läroplanerna": "läroplan",
    "läroplanernas": "läroplan",
    "läroplaners": "läroplan",
    "läroplans": "läroplan",
    "läror": "lära",
    "lärorika": "lärorik",
    "lärorikare": "lärorik",
    "lärorikares": "lärorik",
    "lärorikas": "lärorik",
    "lärorikast": "lärorik",
    "lärorikaste": "lärorik",
    "lärorikastes": "lärorik",
    "lärorikasts": "lärorik",
    "lärorike": "lärorik",
    "lärorikes": "lärorik",
    "lärorikheten": "lärorikhet",
    "lärorikhetens": "lärorikhet",
    "lärorikhets": "lärorikhet",
    "läroriks": "lärorik",
    "lärorikt": "lärorik",
    "lärorikts": "lärorik",
    "lärorna": "lära",
    "lärornas": "lära",
    "lärors": "lära",
    "lärosalar": "lärosal",
    "lärosalarna": "lärosal",
    "lärosalarnas": "lärosal",
    "lärosalars": "lärosal",
    "lärosalen": "lärosal",
    "lärosalens": "lärosal",
    "lärosals": "lärosal",
    "lärosatsen": "lärosats",
    "lärosatsens": "lärosats",
    "lärosatser": "lärosats",
    "lärosatserna": "lärosats",
    "lärosatsernas": "lärosats",
    "lärosatsers": "lärosats",
    "lärostolar": "lärostol",
    "lärostolarna": "lärostol",
    "lärostolarnas": "lärostol",
    "lärostolars": "lärostol",
    "lärostolen": "lärostol",
    "lärostolens": "lärostol",
    "lärostols": "lärostol",
    "lärosäten": "lärosäte",
    "lärosätena": "lärosäte",
    "lärosätenas": "lärosäte",
    "lärosätens": "lärosäte",
    "lärosätes": "lärosäte",
    "lärosätet": "lärosäte",
    "lärosätets": "lärosäte",
    "läroverken": "läroverk",
    "läroverkens": "läroverk",
    "läroverket": "läroverk",
    "läroverkets": "läroverk",
    "läroverks": "läroverk",
    "läroämnen": "läroämne",
    "läroämnena": "läroämne",
    "läroämnenas": "läroämne",
    "läroämnens": "läroämne",
    "läroämnes": "läroämne",
    "läroämnet": "läroämne",
    "läroämnets": "läroämne",
    "läroåren": "läroår",
    "läroårens": "läroår",
    "läroåret": "läroår",
    "läroårets": "läroår",
    "läroårs": "läroår",
    "lärpengar": "lärpeng",
    "lärpengarna": "lärpeng",
    "lärpengarnas": "lärpeng",
    "lärpengars": "lärpeng",
    "lärpengen": "lärpeng",
    "lärpengens": "lärpeng",
    "lärpengs": "lärpeng",
    "lärs": "lära",
    "lärt": "lärd",
    "lärts": "lärd",
    "läs": "läsa",
    "läsande": "läsa",
    "läsanden": "läsande",
    "läsandena": "läsande",
    "läsandenas": "läsande",
    "läsandens": "läsande",
    "läsandes": "läsande",
    "läsandet": "läsande",
    "läsandets": "läsande",
    "läsapparaten": "läsapparat",
    "läsapparatens": "läsapparat",
    "läsapparater": "läsapparat",
    "läsapparaterna": "läsapparat",
    "läsapparaternas": "läsapparat",
    "läsapparaters": "läsapparat",
    "läsapparats": "läsapparat",
    "läsar": "läsare",
    "läsaren": "läsare",
    "läsarens": "läsare",
    "läsares": "läsare",
    "läsarna": "läsare",
    "läsarnas": "läsare",
    "läsarskar": "läsarskara",
    "läsarskaran": "läsarskara",
    "läsarskarans": "läsarskara",
    "läsarskaras": "läsarskara",
    "läsarskare": "läsarskara",
    "läsarskaror": "läsarskara",
    "läsarskarorna": "läsarskara",
    "läsarskarornas": "läsarskara",
    "läsarskarors": "läsarskara",
    "läsarskars": "läsarskara",
    "läsarten": "läsart",
    "läsartens": "läsart",
    "läsarter": "läsart",
    "läsarterna": "läsart",
    "läsarternas": "läsart",
    "läsarters": "läsart",
    "läsarts": "läsart",
    "läsas": "läsa",
    "läsbara": "läsbar",
    "läsbarare": "läsbar",
    "läsbarares": "läsbar",
    "läsbaras": "läsbar",
    "läsbarast": "läsbar",
    "läsbaraste": "läsbar",
    "läsbarastes": "läsbar",
    "läsbarasts": "läsbar",
    "läsbare": "läsbar",
    "läsbares": "läsbar",
    "läsbarheten": "läsbarhet",
    "läsbarhetens": "läsbarhet",
    "läsbarheter": "läsbarhet",
    "läsbarheterna": "läsbarhet",
    "läsbarheternas": "läsbarhet",
    "läsbarheters": "läsbarhet",
    "läsbarhets": "läsbarhet",
    "läsbarhetsindexen": "läsbarhetsindex",
    "läsbarhetsindexens": "läsbarhetsindex",
    "läsbarhetsindexet": "läsbarhetsindex",
    "läsbarhetsindexets": "läsbarhetsindex",
    "läsbarnen": "läsbarn",
    "läsbarnens": "läsbarn",
    "läsbarnet": "läsbarn",
    "läsbarnets": "läsbarn",
    "läsbarns": "läsbarn",
    "läsbars": "läsbar",
    "läsbart": "läsbar",
    "läsbarts": "läsbar",
    "läsbegåvade": "läsbegåvad",
    "läsbegåvades": "läsbegåvad",
    "läsbegåvads": "läsbegåvad",
    "läsbegåvat": "läsbegåvad",
    "läsbegåvats": "läsbegåvad",
    "läsbegåvningar": "läsbegåvning",
    "läsbegåvningarna": "läsbegåvning",
    "läsbegåvningarnas": "läsbegåvning",
    "läsbegåvningars": "läsbegåvning",
    "läsbegåvningen": "läsbegåvning",
    "läsbegåvningens": "läsbegåvning",
    "läsbegåvnings": "läsbegåvning",
    "läsdagar": "läsdag",
    "läsdagarna": "läsdag",
    "läsdagarnas": "läsdag",
    "läsdagars": "läsdag",
    "läsdagen": "läsdag",
    "läsdagens": "läsdag",
    "läsdags": "läsdag",
    "läsdraman": "läsdrama",
    "läsdramana": "läsdrama",
    "läsdramanas": "läsdrama",
    "läsdramans": "läsdrama",
    "läsdramas": "läsdrama",
    "läsdramat": "läsdrama",
    "läsdramats": "läsdrama",
    "läsdramer": "läsdrama",
    "läsdramerna": "läsdrama",
    "läsdramernas": "läsdrama",
    "läsdramers": "läsdrama",
    "läseboken": "läsebok",
    "läsebokens": "läsebok",
    "läseboks": "läsebok",
    "läseböcker": "läsebok",
    "läseböckerna": "läsebok",
    "läseböckernas": "läsebok",
    "läseböckers": "läsebok",
    "läsecirkeln": "läsecirkel",
    "läsecirkelns": "läsecirkel",
    "läsecirkels": "läsecirkel",
    "läsecirklar": "läsecirkel",
    "läsecirklarna": "läsecirkel",
    "läsecirklarnas": "läsecirkel",
    "läsecirklars": "läsecirkel",
    "läsekretsar": "läsekrets",
    "läsekretsarna": "läsekrets",
    "läsekretsarnas": "läsekrets",
    "läsekretsars": "läsekrets",
    "läsekretsen": "läsekrets",
    "läsekretsens": "läsekrets",
    "läser": "läsa",
    "läseriet": "läseri",
    "läseriets": "läseri",
    "läseris": "läseri",
    "läserit": "läseri",
    "läserits": "läseri",
    "läses": "läsa",
    "läsesalar": "läsesal",
    "läsesalarna": "läsesal",
    "läsesalarnas": "läsesal",
    "läsesalars": "läsesal",
    "läsesalen": "läsesal",
    "läsesalens": "läsesal",
    "läsesals": "läsesal",
    "läsfärdigheten": "läsfärdighet",
    "läsfärdighetens": "läsfärdighet",
    "läsfärdigheter": "läsfärdighet",
    "läsfärdigheterna": "läsfärdighet",
    "läsfärdigheternas": "läsfärdighet",
    "läsfärdigheters": "läsfärdighet",
    "läsfärdighets": "läsfärdighet",
    "läsförståelsen": "läsförståelse",
    "läsförståelsens": "läsförståelse",
    "läsförståelses": "läsförståelse",
    "läsglasen": "läsglas",
    "läsglasens": "läsglas",
    "läsglaset": "läsglas",
    "läsglasets": "läsglas",
    "läsglasögonen": "läsglasögon",
    "läsglasögonens": "läsglasögon",
    "läsglasögons": "läsglasögon",
    "läshuvuden": "läshuvud",
    "läshuvudena": "läshuvud",
    "läshuvudenas": "läshuvud",
    "läshuvudens": "läshuvud",
    "läshuvudet": "läshuvud",
    "läshuvudets": "läshuvud",
    "läshuvuds": "läshuvud",
    "läshörn": "läshörna",
    "läshörnan": "läshörna",
    "läshörnans": "läshörna",
    "läshörnas": "läshörna",
    "läshörne": "läshörna",
    "läshörnor": "läshörna",
    "läshörnorna": "läshörna",
    "läshörnornas": "läshörna",
    "läshörnors": "läshörna",
    "läshörns": "läshörna",
    "läsidan": "läsida",
    "läsidans": "läsida",
    "läsidas": "läsida",
    "läside": "läsida",
    "läsides": "läsida",
    "läsidor": "läsida",
    "läsidorna": "läsida",
    "läsidornas": "läsida",
    "läsidors": "läsida",
    "läsionen": "läsion",
    "läsionens": "läsion",
    "läsioner": "läsion",
    "läsionerna": "läsion",
    "läsionernas": "läsion",
    "läsioners": "läsion",
    "läsions": "läsion",
    "läsk": "läska",
    "läskad": "läska",
    "läskade": "läska",
    "läskades": "läska",
    "läskads": "läska",
    "läskamraten": "läskamrat",
    "läskamratens": "läskamrat",
    "läskamrater": "läskamrat",
    "läskamraterna": "läskamrat",
    "läskamraternas": "läskamrat",
    "läskamraters": "läskamrat",
    "läskamrats": "läskamrat",
    "läskande": "läska",
    "läskanden": "läskande",
    "läskandena": "läskande",
    "läskandenas": "läskande",
    "läskandens": "läskande",
    "läskandes": "läskande",
    "läskandet": "läskande",
    "läskandets": "läskande",
    "läskar": "läska",
    "läskas": "läska",
    "läskat": "läska",
    "läskats": "läska",
    "läskeblasken": "läskeblask",
    "läskeblaskens": "läskeblask",
    "läskeblasket": "läskeblask",
    "läskeblaskets": "läskeblask",
    "läskeblasks": "läskeblask",
    "läskedrycken": "läskedryck",
    "läskedryckens": "läskedryck",
    "läskedrycker": "läskedryck",
    "läskedryckerna": "läskedryck",
    "läskedryckernas": "läskedryck",
    "läskedryckers": "läskedryck",
    "läskedrycks": "läskedryck",
    "läskedrycksproducenten": "läskedrycksproducent",
    "läskedrycksproducentens": "läskedrycksproducent",
    "läskedrycksproducenter": "läskedrycksproducent",
    "läskedrycksproducenterna": "läskedrycksproducent",
    "läskedrycksproducenternas": "läskedrycksproducent",
    "läskedrycksproducenters": "läskedrycksproducent",
    "läskedrycksproducents": "läskedrycksproducent",
    "läsken": "läsk",
    "läskens": "läsk",
    "läskiga": "läskig",
    "läskigare": "läskig",
    "läskigares": "läskig",
    "läskigas": "läskig",
    "läskigast": "läskig",
    "läskigaste": "läskig",
    "läskigastes": "läskig",
    "läskigasts": "läskig",
    "läskige": "läskig",
    "läskiges": "läskig",
    "läskigheten": "läskighet",
    "läskighetens": "läskighet",
    "läskigheter": "läskighet",
    "läskigheterna": "läskighet",
    "läskigheternas": "läskighet",
    "läskigheters": "läskighet",
    "läskighets": "läskighet",
    "läskigs": "läskig",
    "läskigt": "läskig",
    "läskigts": "läskig",
    "läskjätteen": "läskjätte",
    "läskjätteens": "läskjätte",
    "läskjätteer": "läskjätte",
    "läskjätteerna": "läskjätte",
    "läskjätteernas": "läskjätte",
    "läskjätteers": "läskjätte",
    "läskjättes": "läskjätte",
    "läsklageren": "läsklager",
    "läsklagerens": "läsklager",
    "läsklageret": "läsklager",
    "läsklagerets": "läsklager",
    "läsklagers": "läsklager",
    "läsklassen": "läsklass",
    "läsklassens": "läsklass",
    "läsklasser": "läsklass",
    "läsklasserna": "läsklass",
    "läsklassernas": "läsklass",
    "läsklassers": "läsklass",
    "läskliniken": "läsklinik",
    "läsklinikens": "läsklinik",
    "läskliniker": "läsklinik",
    "läsklinikerna": "läsklinik",
    "läsklinikernas": "läsklinik",
    "läsklinikers": "läsklinik",
    "läskliniks": "läsklinik",
    "läskpapperen": "läskpapper",
    "läskpapperens": "läskpapper",
    "läskpapperet": "läskpapper",
    "läskpapperets": "läskpapper",
    "läskpapperna": "läskpapper",
    "läskpappernas": "läskpapper",
    "läskpappers": "läskpapper",
    "läskpappren": "läskpapper",
    "läskpapprens": "läskpapper",
    "läskpappret": "läskpapper",
    "läskpapprets": "läskpapper",
    "läsks": "läsk",
    "läskstänger": "läskstång",
    "läskstängerna": "läskstång",
    "läskstängernas": "läskstång",
    "läskstängers": "läskstång",
    "läskstången": "läskstång",
    "läskstångens": "läskstång",
    "läskstångs": "läskstång",
    "läskunniga": "läskunnig",
    "läskunnigare": "läskunnig",
    "läskunnigares": "läskunnig",
    "läskunnigas": "läskunnig",
    "läskunnigast": "läskunnig",
    "läskunnigaste": "läskunnig",
    "läskunnigastes": "läskunnig",
    "läskunnigasts": "läskunnig",
    "läskunnige": "läskunnig",
    "läskunniges": "läskunnig",
    "läskunnigheten": "läskunnighet",
    "läskunnighetens": "läskunnighet",
    "läskunnigheter": "läskunnighet",
    "läskunnigheterna": "läskunnighet",
    "läskunnigheternas": "läskunnighet",
    "läskunnigheters": "läskunnighet",
    "läskunnighets": "läskunnighet",
    "läskunnigs": "läskunnig",
    "läskunnigt": "läskunnig",
    "läskunnigts": "läskunnig",
    "läskänd": "läskända",
    "läskändan": "läskända",
    "läskändans": "läskända",
    "läskändar": "läskände",
    "läskändarna": "läskände",
    "läskändarnas": "läskände",
    "läskändars": "läskände",
    "läskändas": "läskända",
    "läskände": "läskända",
    "läskänden": "läskände",
    "läskändens": "läskände",
    "läskändes": "läskände",
    "läskändor": "läskända",
    "läskändorna": "läskända",
    "läskändornas": "läskända",
    "läskändors": "läskända",
    "läskänds": "läskända",
    "läslamp": "läslampa",
    "läslampan": "läslampa",
    "läslampans": "läslampa",
    "läslampas": "läslampa",
    "läslampe": "läslampa",
    "läslampor": "läslampa",
    "läslamporna": "läslampa",
    "läslampornas": "läslampa",
    "läslampors": "läslampa",
    "läslamps": "läslampa",
    "läsliga": "läslig",
    "läsligare": "läslig",
    "läsligares": "läslig",
    "läsligas": "läslig",
    "läsligast": "läslig",
    "läsligaste": "läslig",
    "läsligastes": "läslig",
    "läsligasts": "läslig",
    "läslige": "läslig",
    "läsliges": "läslig",
    "läsligheten": "läslighet",
    "läslighetens": "läslighet",
    "läslighets": "läslighet",
    "läsligs": "läslig",
    "läsligt": "läslig",
    "läsligts": "läslig",
    "läsningar": "läsning",
    "läsningarna": "läsning",
    "läsningarnas": "läsning",
    "läsningars": "läsning",
    "läsningen": "läsning",
    "läsningens": "läsning",
    "läsnings": "läsning",
    "läsp": "läspa",
    "läspade": "läspa",
    "läspades": "läspa",
    "läspande": "läspa",
    "läspanden": "läspande",
    "läspandena": "läspande",
    "läspandenas": "läspande",
    "läspandens": "läspande",
    "läspandes": "läspande",
    "läspandet": "läspande",
    "läspandets": "läspande",
    "läspar": "läspa",
    "läspas": "läspa",
    "läspat": "läspa",
    "läspats": "läspa",
    "läspenn": "läspenna",
    "läspennan": "läspenna",
    "läspennans": "läspenna",
    "läspennas": "läspenna",
    "läspenne": "läspenna",
    "läspennor": "läspenna",
    "läspennorna": "läspenna",
    "läspennornas": "läspenna",
    "läspennors": "läspenna",
    "läspenns": "läspenna",
    "läsplattan": "läsplatta",
    "läsplattans": "läsplatta",
    "läsplattas": "läsplatta",
    "läsplatte": "läsplatta",
    "läsplattor": "läsplatta",
    "läsplattorna": "läsplatta",
    "läsplattornas": "läsplatta",
    "läsplattors": "läsplatta",
    "läspljuden": "läspljud",
    "läspljudens": "läspljud",
    "läspljudet": "läspljud",
    "läspljudets": "läspljud",
    "läspljuds": "läspljud",
    "läsprästen": "läspräst",
    "läsprästens": "läspräst",
    "läspräster": "läspräst",
    "läsprästerna": "läspräst",
    "läsprästernas": "läspräst",
    "läsprästers": "läspräst",
    "läsprästs": "läspräst",
    "läsrummen": "läsrum",
    "läsrummens": "läsrum",
    "läsrummet": "läsrum",
    "läsrummets": "läsrum",
    "läsrums": "läsrum",
    "lässet": "läss",
    "lässets": "läss",
    "lässvaga": "lässvag",
    "lässvagare": "lässvag",
    "lässvagares": "lässvag",
    "lässvagas": "lässvag",
    "lässvagast": "lässvag",
    "lässvagaste": "lässvag",
    "lässvagastes": "lässvag",
    "lässvagasts": "lässvag",
    "lässvage": "lässvag",
    "lässvages": "lässvag",
    "lässvagheten": "lässvaghet",
    "lässvaghetens": "lässvaghet",
    "lässvaghets": "lässvaghet",
    "lässvags": "lässvag",
    "lässvagt": "lässvag",
    "lässvagts": "lässvag",
    "lässvårigheten": "lässvårighet",
    "lässvårighetens": "lässvårighet",
    "lässvårigheter": "lässvårighet",
    "lässvårigheterna": "lässvårighet",
    "lässvårigheternas": "lässvårighet",
    "lässvårigheters": "lässvårighet",
    "lässvårighets": "lässvårighet",
    "läst": "läsa",
    "lästa": "läsa",
    "lästadianen": "lästadian",
    "lästadianens": "lästadian",
    "lästadianer": "lästadian",
    "lästadianerna": "lästadian",
    "lästadianernas": "lästadian",
    "lästadianers": "lästadian",
    "lästadianismen": "lästadianism",
    "lästadianismens": "lästadianism",
    "lästadianismer": "lästadianism",
    "lästadianismerna": "lästadianism",
    "lästadianismernas": "lästadianism",
    "lästadianismers": "lästadianism",
    "lästadianisms": "lästadianism",
    "lästadians": "lästadian",
    "lästas": "läsa",
    "lästblocken": "lästblock",
    "lästblockens": "lästblock",
    "lästblocket": "lästblock",
    "lästblockets": "lästblock",
    "lästblocks": "lästblock",
    "läste": "läsa",
    "lästen": "läst",
    "lästens": "läst",
    "läster": "läst",
    "lästerna": "läst",
    "lästernas": "läst",
    "lästers": "läst",
    "lästes": "läsa",
    "lästs": "läst",
    "läsupplevelsen": "läsupplevelse",
    "läsupplevelsens": "läsupplevelse",
    "läsupplevelser": "läsupplevelse",
    "läsupplevelserna": "läsupplevelse",
    "läsupplevelsernas": "läsupplevelse",
    "läsupplevelsers": "läsupplevelse",
    "läsupplevelses": "läsupplevelse",
    "läsuttalen": "läsuttal",
    "läsuttalens": "läsuttal",
    "läsuttalet": "läsuttal",
    "läsuttalets": "läsuttal",
    "läsuttals": "läsuttal",
    "läsvärda": "läsvärd",
    "läsvärdare": "läsvärd",
    "läsvärdares": "läsvärd",
    "läsvärdas": "läsvärd",
    "läsvärdast": "läsvärd",
    "läsvärdaste": "läsvärd",
    "läsvärdastes": "läsvärd",
    "läsvärdasts": "läsvärd",
    "läsvärde": "läsvärd",
    "läsvärden": "läsvärde",
    "läsvärdena": "läsvärde",
    "läsvärdenas": "läsvärde",
    "läsvärdens": "läsvärde",
    "läsvärdes": "läsvärde",
    "läsvärdet": "läsvärde",
    "läsvärdets": "läsvärde",
    "läsvärdheten": "läsvärdhet",
    "läsvärdhetens": "läsvärdhet",
    "läsvärdheter": "läsvärdhet",
    "läsvärdheterna": "läsvärdhet",
    "läsvärdheternas": "läsvärdhet",
    "läsvärdheters": "läsvärdhet",
    "läsvärdhets": "läsvärdhet",
    "läsvärds": "läsvärd",
    "läsvärt": "läsvärd",
    "läsvärts": "läsvärd",
    "läsämnen": "läsämne",
    "läsämnena": "läsämne",
    "läsämnenas": "läsämne",
    "läsämnens": "läsämne",
    "läsämnes": "läsämne",
    "läsämnet": "läsämne",
    "läsämnets": "läsämne",
    "läsåren": "läsår",
    "läsårens": "läsår",
    "läsåret": "läsår",
    "läsårets": "läsår",
    "läsårs": "läsår",
    "lät": "låta",
    "läte": "låta",
    "läten": "läte",
    "lätena": "läte",
    "lätenas": "läte",
    "lätens": "läte",
    "lätes": "läte",
    "lätet": "läte",
    "lätets": "läte",
    "läts": "låta",
    "lätta": "lätt",
    "lättad": "lätta",
    "lättade": "lättad",
    "lättades": "lättad",
    "lättads": "lättad",
    "lättande": "lätta",
    "lättanden": "lättande",
    "lättandena": "lättande",
    "lättandenas": "lättande",
    "lättandens": "lättande",
    "lättandes": "lättande",
    "lättandet": "lättande",
    "lättandets": "lättande",
    "lättantändliga": "lättantändlig",
    "lättantändligare": "lättantändlig",
    "lättantändligares": "lättantändlig",
    "lättantändligas": "lättantändlig",
    "lättantändligast": "lättantändlig",
    "lättantändligaste": "lättantändlig",
    "lättantändligastes": "lättantändlig",
    "lättantändligasts": "lättantändlig",
    "lättantändlige": "lättantändlig",
    "lättantändliges": "lättantändlig",
    "lättantändligheten": "lättantändlighet",
    "lättantändlighetens": "lättantändlighet",
    "lättantändlighets": "lättantändlighet",
    "lättantändligs": "lättantändlig",
    "lättantändligt": "lättantändlig",
    "lättantändligts": "lättantändlig",
    "lättar": "lätta",
    "lättarbetade": "lättarbetad",
    "lättarbetades": "lättarbetad",
    "lättarbetads": "lättarbetad",
    "lättarbetat": "lättarbetad",
    "lättarbetats": "lättarbetad",
    "lättare": "lätt",
    "lättares": "lätt",
    "lättas": "lätta",
    "lättast": "lätt",
    "lättaste": "lätt",
    "lättastes": "lätt",
    "lättasts": "lätt",
    "lättat": "lättad",
    "lättats": "lättad",
    "lättbegripliga": "lättbegriplig",
    "lättbegripligare": "lättbegriplig",
    "lättbegripligares": "lättbegriplig",
    "lättbegripligas": "lättbegriplig",
    "lättbegripligast": "lättbegriplig",
    "lättbegripligaste": "lättbegriplig",
    "lättbegripligastes": "lättbegriplig",
    "lättbegripligasts": "lättbegriplig",
    "lättbegriplige": "lättbegriplig",
    "lättbegripliges": "lättbegriplig",
    "lättbegripligheten": "lättbegriplighet",
    "lättbegriplighetens": "lättbegriplighet",
    "lättbegriplighets": "lättbegriplighet",
    "lättbegripligs": "lättbegriplig",
    "lättbegripligt": "lättbegriplig",
    "lättbegripligts": "lättbegriplig",
    "lättbetongen": "lättbetong",
    "lättbetongens": "lättbetong",
    "lättbetongs": "lättbetong",
    "lättbeväpnade": "lättbeväpnad",
    "lättbeväpnades": "lättbeväpnad",
    "lättbeväpnads": "lättbeväpnad",
    "lättbeväpnat": "lättbeväpnad",
    "lättbeväpnats": "lättbeväpnad",
    "lättbrukade": "lättbrukad",
    "lättbrukades": "lättbrukad",
    "lättbrukads": "lättbrukad",
    "lättbrukat": "lättbrukad",
    "lättbrukats": "lättbrukad",
    "lättbruken": "lättbruk",
    "lättbrukens": "lättbruk",
    "lättbruket": "lättbruk",
    "lättbrukets": "lättbruk",
    "lättbruks": "lättbruk",
    "lätte": "lätt",
    "lätter": "lättra",
    "lättes": "lätt",
    "lättfattliga": "lättfattlig",
    "lättfattligare": "lättfattlig",
    "lättfattligares": "lättfattlig",
    "lättfattligas": "lättfattlig",
    "lättfattligast": "lättfattlig",
    "lättfattligaste": "lättfattlig",
    "lättfattligastes": "lättfattlig",
    "lättfattligasts": "lättfattlig",
    "lättfattlige": "lättfattlig",
    "lättfattliges": "lättfattlig",
    "lättfattligheten": "lättfattlighet",
    "lättfattlighetens": "lättfattlighet",
    "lättfattlighets": "lättfattlighet",
    "lättfattligs": "lättfattlig",
    "lättfattligt": "lättfattlig",
    "lättfattligts": "lättfattlig",
    "lättfilen": "lättfil",
    "lättfilens": "lättfil",
    "lättfils": "lättfil",
    "lättfixade": "lättfixad",
    "lättfixades": "lättfixad",
    "lättfixads": "lättfixad",
    "lättfixat": "lättfixad",
    "lättfixats": "lättfixad",
    "lättflyktiga": "lättflyktig",
    "lättflyktigare": "lättflyktig",
    "lättflyktigares": "lättflyktig",
    "lättflyktigas": "lättflyktig",
    "lättflyktigast": "lättflyktig",
    "lättflyktigaste": "lättflyktig",
    "lättflyktigastes": "lättflyktig",
    "lättflyktigasts": "lättflyktig",
    "lättflyktige": "lättflyktig",
    "lättflyktiges": "lättflyktig",
    "lättflyktigheten": "lättflyktighet",
    "lättflyktighetens": "lättflyktighet",
    "lättflyktighets": "lättflyktighet",
    "lättflyktigs": "lättflyktig",
    "lättflyktigt": "lättflyktig",
    "lättflyktigts": "lättflyktig",
    "lättfotade": "lättfotad",
    "lättfotades": "lättfotad",
    "lättfotads": "lättfotad",
    "lättfotat": "lättfotad",
    "lättfotats": "lättfotad",
    "lättframkomliga": "lättframkomlig",
    "lättframkomligare": "lättframkomlig",
    "lättframkomligares": "lättframkomlig",
    "lättframkomligas": "lättframkomlig",
    "lättframkomligast": "lättframkomlig",
    "lättframkomligaste": "lättframkomlig",
    "lättframkomligastes": "lättframkomlig",
    "lättframkomligasts": "lättframkomlig",
    "lättframkomlige": "lättframkomlig",
    "lättframkomliges": "lättframkomlig",
    "lättframkomligheten": "lättframkomlighet",
    "lättframkomlighetens": "lättframkomlighet",
    "lättframkomlighets": "lättframkomlighet",
    "lättframkomligs": "lättframkomlig",
    "lättframkomligt": "lättframkomlig",
    "lättframkomligts": "lättframkomlig",
    "lättfunna": "lättfunnen",
    "lättfunnare": "lättfunnen",
    "lättfunnares": "lättfunnen",
    "lättfunnas": "lättfunnen",
    "lättfunnast": "lättfunnen",
    "lättfunnaste": "lättfunnen",
    "lättfunnastes": "lättfunnen",
    "lättfunnasts": "lättfunnen",
    "lättfunne": "lättfunnen",
    "lättfunnens": "lättfunnen",
    "lättfunnes": "lättfunnen",
    "lättfunnet": "lättfunnen",
    "lättfunnets": "lättfunnen",
    "lättfärdiga": "lättfärdig",
    "lättfärdigare": "lättfärdig",
    "lättfärdigares": "lättfärdig",
    "lättfärdigas": "lättfärdig",
    "lättfärdigast": "lättfärdig",
    "lättfärdigaste": "lättfärdig",
    "lättfärdigastes": "lättfärdig",
    "lättfärdigasts": "lättfärdig",
    "lättfärdige": "lättfärdig",
    "lättfärdiges": "lättfärdig",
    "lättfärdigheten": "lättfärdighet",
    "lättfärdighetens": "lättfärdighet",
    "lättfärdigheter": "lättfärdighet",
    "lättfärdigheterna": "lättfärdighet",
    "lättfärdigheternas": "lättfärdighet",
    "lättfärdigheters": "lättfärdighet",
    "lättfärdighets": "lättfärdighet",
    "lättfärdigs": "lättfärdig",
    "lättfärdigt": "lättfärdig",
    "lättfärdigts": "lättfärdig",
    "lättfångade": "lättfångad",
    "lättfångades": "lättfångad",
    "lättfångads": "lättfångad",
    "lättfångat": "lättfångad",
    "lättfångats": "lättfångad",
    "lättfångens": "lättfången",
    "lättfånget": "lättfången",
    "lättfångets": "lättfången",
    "lättfångna": "lättfången",
    "lättfångnare": "lättfången",
    "lättfångnares": "lättfången",
    "lättfångnas": "lättfången",
    "lättfångnast": "lättfången",
    "lättfångnaste": "lättfången",
    "lättfångnastes": "lättfången",
    "lättfångnasts": "lättfången",
    "lättfångne": "lättfången",
    "lättfångnes": "lättfången",
    "lättförklarliga": "lättförklarlig",
    "lättförklarligare": "lättförklarlig",
    "lättförklarligares": "lättförklarlig",
    "lättförklarligas": "lättförklarlig",
    "lättförklarligast": "lättförklarlig",
    "lättförklarligaste": "lättförklarlig",
    "lättförklarligastes": "lättförklarlig",
    "lättförklarligasts": "lättförklarlig",
    "lättförklarlige": "lättförklarlig",
    "lättförklarliges": "lättförklarlig",
    "lättförklarligheten": "lättförklarlighet",
    "lättförklarlighetens": "lättförklarlighet",
    "lättförklarlighets": "lättförklarlighet",
    "lättförklarligs": "lättförklarlig",
    "lättförklarligt": "lättförklarlig",
    "lättförklarligts": "lättförklarlig",
    "lättförståeliga": "lättförståelig",
    "lättförståeligare": "lättförståelig",
    "lättförståeligares": "lättförståelig",
    "lättförståeligas": "lättförståelig",
    "lättförståeligast": "lättförståelig",
    "lättförståeligaste": "lättförståelig",
    "lättförståeligastes": "lättförståelig",
    "lättförståeligasts": "lättförståelig",
    "lättförståelige": "lättförståelig",
    "lättförståeliges": "lättförståelig",
    "lättförståeligheten": "lättförståelighet",
    "lättförståelighetens": "lättförståelighet",
    "lättförståelighets": "lättförståelighet",
    "lättförståeligs": "lättförståelig",
    "lättförståeligt": "lättförståelig",
    "lättförståeligts": "lättförståelig",
    "lättförsvarade": "lättförsvarad",
    "lättförsvarades": "lättförsvarad",
    "lättförsvarads": "lättförsvarad",
    "lättförsvarat": "lättförsvarad",
    "lättförsvarats": "lättförsvarad",
    "lättförtjänta": "lättförtjänt",
    "lättförtjäntare": "lättförtjänt",
    "lättförtjäntares": "lättförtjänt",
    "lättförtjäntas": "lättförtjänt",
    "lättförtjäntast": "lättförtjänt",
    "lättförtjäntaste": "lättförtjänt",
    "lättförtjäntastes": "lättförtjänt",
    "lättförtjäntasts": "lättförtjänt",
    "lättförtjänte": "lättförtjänt",
    "lättförtjäntes": "lättförtjänt",
    "lättförtjänts": "lättförtjänt",
    "lättgroggar": "lättgrogg",
    "lättgroggarna": "lättgrogg",
    "lättgroggarnas": "lättgrogg",
    "lättgroggars": "lättgrogg",
    "lättgroggen": "lättgrogg",
    "lättgroggens": "lättgrogg",
    "lättgroggs": "lättgrogg",
    "lätthanterliga": "lätthanterlig",
    "lätthanterligare": "lätthanterlig",
    "lätthanterligares": "lätthanterlig",
    "lätthanterligas": "lätthanterlig",
    "lätthanterligast": "lätthanterlig",
    "lätthanterligaste": "lätthanterlig",
    "lätthanterligastes": "lätthanterlig",
    "lätthanterligasts": "lätthanterlig",
    "lätthanterlige": "lätthanterlig",
    "lätthanterliges": "lätthanterlig",
    "lätthanterligheten": "lätthanterlighet",
    "lätthanterlighetens": "lätthanterlighet",
    "lätthanterlighets": "lätthanterlighet",
    "lätthanterligs": "lätthanterlig",
    "lätthanterligt": "lätthanterlig",
    "lätthanterligts": "lätthanterlig",
    "lättheten": "lätthet",
    "lätthetens": "lätthet",
    "lätthets": "lätthet",
    "lättillgängliga": "lättillgänglig",
    "lättillgängligare": "lättillgänglig",
    "lättillgängligares": "lättillgänglig",
    "lättillgängligas": "lättillgänglig",
    "lättillgängligast": "lättillgänglig",
    "lättillgängligaste": "lättillgänglig",
    "lättillgängligastes": "lättillgänglig",
    "lättillgängligasts": "lättillgänglig",
    "lättillgänglige": "lättillgänglig",
    "lättillgängliges": "lättillgänglig",
    "lättillgängligheten": "lättillgänglighet",
    "lättillgänglighetens": "lättillgänglighet",
    "lättillgänglighets": "lättillgänglighet",
    "lättillgängligs": "lättillgänglig",
    "lättillgängligt": "lättillgänglig",
    "lättillgängligts": "lättillgänglig",
    "lättingar": "lätting",
    "lättingarna": "lätting",
    "lättingarnas": "lätting",
    "lättingars": "lätting",
    "lättingen": "lätting",
    "lättingens": "lätting",
    "lättings": "lätting",
    "lättjan": "lättja",
    "lättjans": "lättja",
    "lättjas": "lättja",
    "lättjefulla": "lättjefull",
    "lättjefullare": "lättjefull",
    "lättjefullares": "lättjefull",
    "lättjefullas": "lättjefull",
    "lättjefullast": "lättjefull",
    "lättjefullaste": "lättjefull",
    "lättjefullastes": "lättjefull",
    "lättjefullasts": "lättjefull",
    "lättjefulle": "lättjefull",
    "lättjefulles": "lättjefull",
    "lättjefullheten": "lättjefullhet",
    "lättjefullhetens": "lättjefullhet",
    "lättjefullhets": "lättjefullhet",
    "lättjefulls": "lättjefull",
    "lättjefullt": "lättjefull",
    "lättjefullts": "lättjefull",
    "lättjordar": "lättjord",
    "lättjordarna": "lättjord",
    "lättjordarnas": "lättjord",
    "lättjordars": "lättjord",
    "lättjorden": "lättjord",
    "lättjordens": "lättjord",
    "lättjords": "lättjord",
    "lättklädda": "lättklädd",
    "lättkläddare": "lättklädd",
    "lättkläddares": "lättklädd",
    "lättkläddas": "lättklädd",
    "lättkläddast": "lättklädd",
    "lättkläddaste": "lättklädd",
    "lättkläddastes": "lättklädd",
    "lättkläddasts": "lättklädd",
    "lättklädde": "lättklädd",
    "lättkläddes": "lättklädd",
    "lättkläddheten": "lättkläddhet",
    "lättkläddhetens": "lättkläddhet",
    "lättkläddhets": "lättkläddhet",
    "lättklädds": "lättklädd",
    "lättklätt": "lättklädd",
    "lättklätts": "lättklädd",
    "lättklövar": "lättklöv",
    "lättklövarna": "lättklöv",
    "lättklövarnas": "lättklöv",
    "lättklövars": "lättklöv",
    "lättklöven": "lättklöv",
    "lättklövens": "lättklöv",
    "lättklövs": "lättklöv",
    "lättkokta": "lättkokt",
    "lättkoktare": "lättkokt",
    "lättkoktares": "lättkokt",
    "lättkoktas": "lättkokt",
    "lättkoktast": "lättkokt",
    "lättkoktaste": "lättkokt",
    "lättkoktastes": "lättkokt",
    "lättkoktasts": "lättkokt",
    "lättkokte": "lättkokt",
    "lättkoktes": "lättkokt",
    "lättkoktheten": "lättkokthet",
    "lättkokthetens": "lättkokthet",
    "lättkokthets": "lättkokthet",
    "lättkokts": "lättkokt",
    "lättköpta": "lättköpt",
    "lättköptare": "lättköpt",
    "lättköptares": "lättköpt",
    "lättköptas": "lättköpt",
    "lättköptast": "lättköpt",
    "lättköptaste": "lättköpt",
    "lättköptastes": "lättköpt",
    "lättköptasts": "lättköpt",
    "lättköpte": "lättköpt",
    "lättköptes": "lättköpt",
    "lättköptheten": "lättköpthet",
    "lättköpthetens": "lättköpthet",
    "lättköpthets": "lättköpthet",
    "lättköpts": "lättköpt",
    "lättledda": "lättledd",
    "lättleddare": "lättledd",
    "lättleddares": "lättledd",
    "lättleddas": "lättledd",
    "lättleddast": "lättledd",
    "lättleddaste": "lättledd",
    "lättleddastes": "lättledd",
    "lättleddasts": "lättledd",
    "lättledde": "lättledd",
    "lättleddes": "lättledd",
    "lättleddheten": "lättleddhet",
    "lättleddhetens": "lättleddhet",
    "lättleddhets": "lättleddhet",
    "lättledds": "lättledd",
    "lättlett": "lättledd",
    "lättletts": "lättledd",
    "lättlurade": "lättlurad",
    "lättlurades": "lättlurad",
    "lättlurads": "lättlurad",
    "lättlurat": "lättlurad",
    "lättlurats": "lättlurad",
    "lättlästa": "lättläst",
    "lättlästare": "lättläst",
    "lättlästares": "lättläst",
    "lättlästas": "lättläst",
    "lättlästast": "lättläst",
    "lättlästaste": "lättläst",
    "lättlästastes": "lättläst",
    "lättlästasts": "lättläst",
    "lättläste": "lättläst",
    "lättlästes": "lättläst",
    "lättlästheten": "lättlästhet",
    "lättlästhetens": "lättlästhet",
    "lättlästhets": "lättlästhet",
    "lättlästs": "lättläst",
    "lättlösliga": "lättlöslig",
    "lättlösligare": "lättlöslig",
    "lättlösligares": "lättlöslig",
    "lättlösligas": "lättlöslig",
    "lättlösligast": "lättlöslig",
    "lättlösligaste": "lättlöslig",
    "lättlösligastes": "lättlöslig",
    "lättlösligasts": "lättlöslig",
    "lättlöslige": "lättlöslig",
    "lättlösliges": "lättlöslig",
    "lättlösligheten": "lättlöslighet",
    "lättlöslighetens": "lättlöslighet",
    "lättlöslighets": "lättlöslighet",
    "lättlösligs": "lättlöslig",
    "lättlösligt": "lättlöslig",
    "lättlösligts": "lättlöslig",
    "lättlösta": "lättlöst",
    "lättlöstare": "lättlöst",
    "lättlöstares": "lättlöst",
    "lättlöstas": "lättlöst",
    "lättlöstast": "lättlöst",
    "lättlöstaste": "lättlöst",
    "lättlöstastes": "lättlöst",
    "lättlöstasts": "lättlöst",
    "lättlöste": "lättlöst",
    "lättlöstes": "lättlöst",
    "lättlöstheten": "lättlösthet",
    "lättlösthetens": "lättlösthet",
    "lättlösthets": "lättlösthet",
    "lättlösts": "lättlöst",
    "lättmanövrerade": "lättmanövrerad",
    "lättmanövrerades": "lättmanövrerad",
    "lättmanövrerads": "lättmanövrerad",
    "lättmanövrerat": "lättmanövrerad",
    "lättmanövrerats": "lättmanövrerad",
    "lättmargariner": "lättmargarin",
    "lättmargarinerna": "lättmargarin",
    "lättmargarinernas": "lättmargarin",
    "lättmargariners": "lättmargarin",
    "lättmargarinet": "lättmargarin",
    "lättmargarinets": "lättmargarin",
    "lättmargarins": "lättmargarin",
    "lättmatrosen": "lättmatros",
    "lättmatrosens": "lättmatros",
    "lättmatroser": "lättmatros",
    "lättmatroserna": "lättmatros",
    "lättmatrosernas": "lättmatros",
    "lättmatrosers": "lättmatros",
    "lättmetallen": "lättmetall",
    "lättmetallens": "lättmetall",
    "lättmetaller": "lättmetall",
    "lättmetallerna": "lättmetall",
    "lättmetallernas": "lättmetall",
    "lättmetallers": "lättmetall",
    "lättmetalls": "lättmetall",
    "lättmjölken": "lättmjölk",
    "lättmjölkens": "lättmjölk",
    "lättmjölks": "lättmjölk",
    "lättnade": "lättna",
    "lättnaden": "lättnad",
    "lättnadens": "lättnad",
    "lättnader": "lättnad",
    "lättnaderna": "lättnad",
    "lättnadernas": "lättnad",
    "lättnaders": "lättnad",
    "lättnades": "lättna",
    "lättnads": "lättnad",
    "lättnande": "lättna",
    "lättnanden": "lättnande",
    "lättnandena": "lättnande",
    "lättnandenas": "lättnande",
    "lättnandens": "lättnande",
    "lättnandes": "lättnande",
    "lättnandet": "lättnande",
    "lättnandets": "lättnande",
    "lättnar": "lättna",
    "lättnas": "lättna",
    "lättnat": "lättna",
    "lättnats": "lättna",
    "lättodlade": "lättodlad",
    "lättodlades": "lättodlad",
    "lättodlads": "lättodlad",
    "lättodlat": "lättodlad",
    "lättodlats": "lättodlad",
    "lättpratade": "lättpratad",
    "lättpratades": "lättpratad",
    "lättpratads": "lättpratad",
    "lättpratat": "lättpratad",
    "lättpratats": "lättpratad",
    "lättrad": "lättra",
    "lättrade": "lättra",
    "lättrades": "lättra",
    "lättrads": "lättra",
    "lättrande": "lättra",
    "lättranden": "lättrande",
    "lättrandena": "lättrande",
    "lättrandenas": "lättrande",
    "lättrandens": "lättrande",
    "lättrandes": "lättrande",
    "lättrandet": "lättrande",
    "lättrandets": "lättrande",
    "lättrar": "lättra",
    "lättras": "lättra",
    "lättrat": "lättra",
    "lättrats": "lättra",
    "lättretade": "lättretad",
    "lättretades": "lättretad",
    "lättretads": "lättretad",
    "lättretat": "lättretad",
    "lättretats": "lättretad",
    "lättretliga": "lättretlig",
    "lättretligare": "lättretlig",
    "lättretligares": "lättretlig",
    "lättretligas": "lättretlig",
    "lättretligast": "lättretlig",
    "lättretligaste": "lättretlig",
    "lättretligastes": "lättretlig",
    "lättretligasts": "lättretlig",
    "lättretlige": "lättretlig",
    "lättretliges": "lättretlig",
    "lättretligheten": "lättretlighet",
    "lättretlighetens": "lättretlighet",
    "lättretlighets": "lättretlighet",
    "lättretligs": "lättretlig",
    "lättretligt": "lättretlig",
    "lättretligts": "lättretlig",
    "lättrimmade": "lättrimmad",
    "lättrimmades": "lättrimmad",
    "lättrimmads": "lättrimmad",
    "lättrimmat": "lättrimmad",
    "lättrimmats": "lättrimmad",
    "lättroade": "lättroad",
    "lättroades": "lättroad",
    "lättroads": "lättroad",
    "lättroat": "lättroad",
    "lättroats": "lättroad",
    "lättrogenheten": "lättrogenhet",
    "lättrogenhetens": "lättrogenhet",
    "lättrogenhets": "lättrogenhet",
    "lättrogens": "lättrogen",
    "lättroget": "lättrogen",
    "lättrogets": "lättrogen",
    "lättrogna": "lättrogen",
    "lättrognare": "lättrogen",
    "lättrognares": "lättrogen",
    "lättrognas": "lättrogen",
    "lättrognast": "lättrogen",
    "lättrognaste": "lättrogen",
    "lättrognastes": "lättrogen",
    "lättrognasts": "lättrogen",
    "lättrogne": "lättrogen",
    "lättrognes": "lättrogen",
    "lättrullade": "lättrullad",
    "lättrullades": "lättrullad",
    "lättrullads": "lättrullad",
    "lättrullat": "lättrullad",
    "lättrullats": "lättrullad",
    "lättrökta": "lättrökt",
    "lättröktare": "lättrökt",
    "lättröktares": "lättrökt",
    "lättröktas": "lättrökt",
    "lättröktast": "lättrökt",
    "lättröktaste": "lättrökt",
    "lättröktastes": "lättrökt",
    "lättröktasts": "lättrökt",
    "lättrökte": "lättrökt",
    "lättröktes": "lättrökt",
    "lättrökts": "lättrökt",
    "lättrörda": "lättrörd",
    "lättrördare": "lättrörd",
    "lättrördares": "lättrörd",
    "lättrördas": "lättrörd",
    "lättrördast": "lättrörd",
    "lättrördaste": "lättrörd",
    "lättrördastes": "lättrörd",
    "lättrördasts": "lättrörd",
    "lättrörde": "lättrörd",
    "lättrördes": "lättrörd",
    "lättrördheten": "lättrördhet",
    "lättrördhetens": "lättrördhet",
    "lättrördhets": "lättrördhet",
    "lättrörds": "lättrörd",
    "lättrörliga": "lättrörlig",
    "lättrörligare": "lättrörlig",
    "lättrörligares": "lättrörlig",
    "lättrörligas": "lättrörlig",
    "lättrörligast": "lättrörlig",
    "lättrörligaste": "lättrörlig",
    "lättrörligastes": "lättrörlig",
    "lättrörligasts": "lättrörlig",
    "lättrörlige": "lättrörlig",
    "lättrörliges": "lättrörlig",
    "lättrörligheten": "lättrörlighet",
    "lättrörlighetens": "lättrörlighet",
    "lättrörlighets": "lättrörlighet",
    "lättrörligs": "lättrörlig",
    "lättrörligt": "lättrörlig",
    "lättrörligts": "lättrörlig",
    "lättrört": "lättrörd",
    "lättrörts": "lättrörd",
    "lätts": "lätt",
    "lättsaltade": "lättsaltad",
    "lättsaltades": "lättsaltad",
    "lättsaltads": "lättsaltad",
    "lättsaltat": "lättsaltad",
    "lättsaltats": "lättsaltad",
    "lättsamheten": "lättsamhet",
    "lättsamhetens": "lättsamhet",
    "lättsamheter": "lättsamhet",
    "lättsamheterna": "lättsamhet",
    "lättsamheternas": "lättsamhet",
    "lättsamheters": "lättsamhet",
    "lättsamhets": "lättsamhet",
    "lättsamma": "lättsam",
    "lättsammare": "lättsam",
    "lättsammares": "lättsam",
    "lättsammas": "lättsam",
    "lättsammast": "lättsam",
    "lättsammaste": "lättsam",
    "lättsammastes": "lättsam",
    "lättsammasts": "lättsam",
    "lättsamme": "lättsam",
    "lättsammes": "lättsam",
    "lättsams": "lättsam",
    "lättsamt": "lättsam",
    "lättsamts": "lättsam",
    "lättsinnes": "lättsinne",
    "lättsinnet": "lättsinne",
    "lättsinnets": "lättsinne",
    "lättsinniga": "lättsinnig",
    "lättsinnigare": "lättsinnig",
    "lättsinnigares": "lättsinnig",
    "lättsinnigas": "lättsinnig",
    "lättsinnigast": "lättsinnig",
    "lättsinnigaste": "lättsinnig",
    "lättsinnigastes": "lättsinnig",
    "lättsinnigasts": "lättsinnig",
    "lättsinnige": "lättsinnig",
    "lättsinniges": "lättsinnig",
    "lättsinnigheten": "lättsinnighet",
    "lättsinnighetens": "lättsinnighet",
    "lättsinnigheter": "lättsinnighet",
    "lättsinnigheterna": "lättsinnighet",
    "lättsinnigheternas": "lättsinnighet",
    "lättsinnigheters": "lättsinnighet",
    "lättsinnighets": "lättsinnighet",
    "lättsinnigs": "lättsinnig",
    "lättsinnigt": "lättsinnig",
    "lättsinnigts": "lättsinnig",
    "lättsjungens": "lättsjungen",
    "lättsjunget": "lättsjungen",
    "lättsjungets": "lättsjungen",
    "lättsjungna": "lättsjungen",
    "lättsjungnas": "lättsjungen",
    "lättsjungne": "lättsjungen",
    "lättsjungnes": "lättsjungen",
    "lättskrämda": "lättskrämd",
    "lättskrämdare": "lättskrämd",
    "lättskrämdares": "lättskrämd",
    "lättskrämdas": "lättskrämd",
    "lättskrämdast": "lättskrämd",
    "lättskrämdaste": "lättskrämd",
    "lättskrämdastes": "lättskrämd",
    "lättskrämdasts": "lättskrämd",
    "lättskrämde": "lättskrämd",
    "lättskrämdes": "lättskrämd",
    "lättskrämdheten": "lättskrämdhet",
    "lättskrämdhetens": "lättskrämdhet",
    "lättskrämdhets": "lättskrämdhet",
    "lättskrämds": "lättskrämd",
    "lättskrämt": "lättskrämd",
    "lättskrämts": "lättskrämd",
    "lättskötta": "lättskött",
    "lättsköttare": "lättskött",
    "lättsköttares": "lättskött",
    "lättsköttas": "lättskött",
    "lättsköttast": "lättskött",
    "lättsköttaste": "lättskött",
    "lättsköttastes": "lättskött",
    "lättsköttasts": "lättskött",
    "lättskötte": "lättskött",
    "lättsköttes": "lättskött",
    "lättsköttheten": "lättskötthet",
    "lättskötthetens": "lättskötthet",
    "lättskötthets": "lättskötthet",
    "lättskötts": "lättskött",
    "lättsmickrade": "lättsmickrad",
    "lättsmickrades": "lättsmickrad",
    "lättsmickrads": "lättsmickrad",
    "lättsmickrat": "lättsmickrad",
    "lättsmickrats": "lättsmickrad",
    "lättsmälta": "lättsmält",
    "lättsmältare": "lättsmält",
    "lättsmältares": "lättsmält",
    "lättsmältas": "lättsmält",
    "lättsmältast": "lättsmält",
    "lättsmältaste": "lättsmält",
    "lättsmältastes": "lättsmält",
    "lättsmältasts": "lättsmält",
    "lättsmälte": "lättsmält",
    "lättsmältes": "lättsmält",
    "lättsmältheten": "lättsmälthet",
    "lättsmälthetens": "lättsmälthet",
    "lättsmälthets": "lättsmälthet",
    "lättsmälts": "lättsmält",
    "lättspackels": "lättspackel",
    "lättspacklet": "lättspackel",
    "lättspacklets": "lättspackel",
    "lättstekta": "lättstekt",
    "lättstektare": "lättstekt",
    "lättstektares": "lättstekt",
    "lättstektas": "lättstekt",
    "lättstektast": "lättstekt",
    "lättstektaste": "lättstekt",
    "lättstektastes": "lättstekt",
    "lättstektasts": "lättstekt",
    "lättstekte": "lättstekt",
    "lättstektes": "lättstekt",
    "lättstektheten": "lättstekthet",
    "lättstekthetens": "lättstekthet",
    "lättstekthets": "lättstekthet",
    "lättstekts": "lättstekt",
    "lättstrukens": "lättstruken",
    "lättstruket": "lättstruken",
    "lättstrukets": "lättstruken",
    "lättstrukna": "lättstruken",
    "lättstruknas": "lättstruken",
    "lättstrukne": "lättstruken",
    "lättstruknes": "lättstruken",
    "lättstötta": "lättstött",
    "lättstöttare": "lättstött",
    "lättstöttares": "lättstött",
    "lättstöttas": "lättstött",
    "lättstöttast": "lättstött",
    "lättstöttaste": "lättstött",
    "lättstöttastes": "lättstött",
    "lättstöttasts": "lättstött",
    "lättstötte": "lättstött",
    "lättstöttes": "lättstött",
    "lättstöttheten": "lättstötthet",
    "lättstötthetens": "lättstötthet",
    "lättstötthets": "lättstötthet",
    "lättstötts": "lättstött",
    "lättuttalade": "lättuttalad",
    "lättuttalades": "lättuttalad",
    "lättuttalads": "lättuttalad",
    "lättuttalat": "lättuttalad",
    "lättuttalats": "lättuttalad",
    "lättvarianten": "lättvariant",
    "lättvariantens": "lättvariant",
    "lättvarianter": "lättvariant",
    "lättvarianterna": "lättvariant",
    "lättvarianternas": "lättvariant",
    "lättvarianters": "lättvariant",
    "lättvariants": "lättvariant",
    "lättvattenreaktorer": "lättvattenreaktor",
    "lättvattenreaktorerna": "lättvattenreaktor",
    "lättvattenreaktorernas": "lättvattenreaktor",
    "lättvattenreaktorers": "lättvattenreaktor",
    "lättvattenreaktorn": "lättvattenreaktor",
    "lättvattenreaktorns": "lättvattenreaktor",
    "lättvattenreaktors": "lättvattenreaktor",
    "lättviktar": "lättviktare",
    "lättviktaren": "lättviktare",
    "lättviktarens": "lättviktare",
    "lättviktares": "lättviktare",
    "lättviktarna": "lättviktare",
    "lättviktarnas": "lättviktare",
    "lättvikten": "lättvikt",
    "lättviktens": "lättvikt",
    "lättviktiga": "lättviktig",
    "lättviktigare": "lättviktig",
    "lättviktigares": "lättviktig",
    "lättviktigas": "lättviktig",
    "lättviktigast": "lättviktig",
    "lättviktigaste": "lättviktig",
    "lättviktigastes": "lättviktig",
    "lättviktigasts": "lättviktig",
    "lättviktige": "lättviktig",
    "lättviktiges": "lättviktig",
    "lättviktigheten": "lättviktighet",
    "lättviktighetens": "lättviktighet",
    "lättviktighets": "lättviktighet",
    "lättviktigs": "lättviktig",
    "lättviktigt": "lättviktig",
    "lättviktigts": "lättviktig",
    "lättvikts": "lättvikt",
    "lättviktsmotorcykeln": "lättviktsmotorcykel",
    "lättviktsmotorcykelns": "lättviktsmotorcykel",
    "lättviktsmotorcykels": "lättviktsmotorcykel",
    "lättviktsmotorcyklar": "lättviktsmotorcykel",
    "lättviktsmotorcyklarna": "lättviktsmotorcykel",
    "lättviktsmotorcyklarnas": "lättviktsmotorcykel",
    "lättviktsmotorcyklars": "lättviktsmotorcykel",
    "lättvindiga": "lättvindig",
    "lättvindigare": "lättvindig",
    "lättvindigares": "lättvindig",
    "lättvindigas": "lättvindig",
    "lättvindigast": "lättvindig",
    "lättvindigaste": "lättvindig",
    "lättvindigastes": "lättvindig",
    "lättvindigasts": "lättvindig",
    "lättvindige": "lättvindig",
    "lättvindiges": "lättvindig",
    "lättvindigheten": "lättvindighet",
    "lättvindighetens": "lättvindighet",
    "lättvindigheter": "lättvindighet",
    "lättvindigheterna": "lättvindighet",
    "lättvindigheternas": "lättvindighet",
    "lättvindigheters": "lättvindighet",
    "lättvindighets": "lättvindighet",
    "lättvindigs": "lättvindig",
    "lättvindigt": "lättvindig",
    "lättvindigts": "lättvindig",
    "lättviner": "lättvin",
    "lättvinerna": "lättvin",
    "lättvinernas": "lättvin",
    "lättviners": "lättvin",
    "lättvinet": "lättvin",
    "lättvinets": "lättvin",
    "lättvins": "lättvin",
    "lättvunna": "lättvunnen",
    "lättvunnare": "lättvunnen",
    "lättvunnares": "lättvunnen",
    "lättvunnas": "lättvunnen",
    "lättvunnast": "lättvunnen",
    "lättvunnaste": "lättvunnen",
    "lättvunnastes": "lättvunnen",
    "lättvunnasts": "lättvunnen",
    "lättvunne": "lättvunnen",
    "lättvunnens": "lättvunnen",
    "lättvunnes": "lättvunnen",
    "lättvunnet": "lättvunnen",
    "lättvunnets": "lättvunnen",
    "lättölen": "lättöl",
    "lättölens": "lättöl",
    "lättölet": "lättöl",
    "lättölets": "lättöl",
    "lättöls": "lättöl",
    "lättömda": "lättömd",
    "lättömdare": "lättömd",
    "lättömdares": "lättömd",
    "lättömdas": "lättömd",
    "lättömdast": "lättömd",
    "lättömdaste": "lättömd",
    "lättömdastes": "lättömd",
    "lättömdasts": "lättömd",
    "lättömde": "lättömd",
    "lättömdes": "lättömd",
    "lättömdheten": "lättömdhet",
    "lättömdhetens": "lättömdhet",
    "lättömdhets": "lättömdhet",
    "lättömds": "lättömd",
    "lättömt": "lättömd",
    "lättömts": "lättömd",
    "lättöverskådliga": "lättöverskådlig",
    "lättöverskådligare": "lättöverskådlig",
    "lättöverskådligares": "lättöverskådlig",
    "lättöverskådligas": "lättöverskådlig",
    "lättöverskådligast": "lättöverskådlig",
    "lättöverskådligaste": "lättöverskådlig",
    "lättöverskådligastes": "lättöverskådlig",
    "lättöverskådligasts": "lättöverskådlig",
    "lättöverskådlige": "lättöverskådlig",
    "lättöverskådliges": "lättöverskådlig",
    "lättöverskådligheten": "lättöverskådlighet",
    "lättöverskådlighetens": "lättöverskådlighet",
    "lättöverskådlighets": "lättöverskådlighet",
    "lättöverskådligs": "lättöverskådlig",
    "lättöverskådligt": "lättöverskådlig",
    "lättöverskådligts": "lättöverskådlig",
    "läx": "läxa",
    "läxan": "läxa",
    "läxans": "läxa",
    "läxas": "läxa",
    "läxe": "läxa",
    "läxförhören": "läxförhör",
    "läxförhörens": "läxförhör",
    "läxförhöret": "läxförhör",
    "läxförhörets": "läxförhör",
    "läxförhörs": "läxförhör",
    "läxor": "läxa",
    "läxorna": "läxa",
    "läxornas": "läxa",
    "läxors": "läxa",
    "läxproven": "läxprov",
    "läxprovens": "läxprov",
    "läxprovet": "läxprov",
    "läxprovets": "läxprov",
    "läxprovs": "läxprov",
    "låd": "låda",
    "lådan": "låda",
    "lådans": "låda",
    "lådas": "låda",
    "låde": "låda",
    "lådkameran": "lådkamera",
    "lådkamerans": "lådkamera",
    "lådkameras": "lådkamera",
    "lådkameror": "lådkamera",
    "lådkamerorna": "lådkamera",
    "lådkamerornas": "lådkamera",
    "lådkamerors": "lådkamera",
    "lådor": "låda",
    "lådorna": "låda",
    "lådornas": "låda",
    "lådors": "låda",
    "låds": "låda",
    "lådspikar": "lådspik",
    "lådspikarna": "lådspik",
    "lådspikarnas": "lådspik",
    "lådspikars": "lådspik",
    "lådspiken": "lådspik",
    "lådspikens": "lådspik",
    "lådspiks": "lådspik",
    "lådviner": "lådvin",
    "lådvinerna": "lådvin",
    "lådvinernas": "lådvin",
    "lådviners": "lådvin",
    "lådvinet": "lådvin",
    "lådvinets": "lådvin",
    "lådvins": "lådvin",
    "lådämnen": "lådämne",
    "lådämnena": "lådämne",
    "lådämnenas": "lådämne",
    "lådämnens": "lådämne",
    "lådämnes": "lådämne",
    "lådämnet": "lådämne",
    "lådämnets": "lådämne",
    "låg": "ligga",
    "låga": "låg",
    "lågade": "låga",
    "lågadeln": "lågadel",
    "lågadelns": "lågadel",
    "lågadels": "lågadel",
    "lågades": "låga",
    "lågan": "låga",
    "lågande": "låga",
    "låganden": "lågande",
    "lågandena": "lågande",
    "lågandenas": "lågande",
    "lågandens": "lågande",
    "lågandes": "lågande",
    "lågandet": "lågande",
    "lågandets": "lågande",
    "låganrikade": "låganrikad",
    "låganrikades": "låganrikad",
    "låganrikads": "låganrikad",
    "låganrikat": "låganrikad",
    "låganrikats": "låganrikad",
    "lågans": "låga",
    "lågar": "låga",
    "lågas": "låga",
    "lågat": "låga",
    "lågats": "låga",
    "lågavlönade": "lågavlönad",
    "lågavlönades": "lågavlönad",
    "lågavlönads": "lågavlönad",
    "lågavlönat": "lågavlönad",
    "lågavlönats": "lågavlönad",
    "lågbladen": "lågblad",
    "lågbladens": "lågblad",
    "lågbladet": "lågblad",
    "lågbladets": "lågblad",
    "lågblads": "lågblad",
    "lågbudgetresan": "lågbudgetresa",
    "lågbudgetresans": "lågbudgetresa",
    "lågbudgetresas": "lågbudgetresa",
    "lågbudgetrese": "lågbudgetresa",
    "lågbudgetresor": "lågbudgetresa",
    "lågbudgetresorna": "lågbudgetresa",
    "lågbudgetresornas": "lågbudgetresa",
    "lågbudgetresors": "lågbudgetresa",
    "lågbudgetturismen": "lågbudgetturism",
    "lågbudgetturismens": "lågbudgetturism",
    "lågbudgetturisms": "lågbudgetturism",
    "lågbudgetturisten": "lågbudgetturist",
    "lågbudgetturistens": "lågbudgetturist",
    "lågbudgetturister": "lågbudgetturist",
    "lågbudgetturisterna": "lågbudgetturist",
    "lågbudgetturisternas": "lågbudgetturist",
    "lågbudgetturisters": "lågbudgetturist",
    "lågbudgetturists": "lågbudgetturist",
    "låge": "låga",
    "låges": "låg",
    "lågfjällen": "lågfjäll",
    "lågfjällens": "lågfjäll",
    "lågfjället": "lågfjäll",
    "lågfjällets": "lågfjäll",
    "lågfjälls": "lågfjäll",
    "lågfluge": "lågflyga",
    "lågfluges": "lågflyga",
    "lågflugit": "lågflyga",
    "lågflugits": "lågflyga",
    "lågflyg": "lågflyga",
    "lågflygande": "lågflyga",
    "lågflyganden": "lågflygande",
    "lågflygandena": "lågflygande",
    "lågflygandenas": "lågflygande",
    "lågflygandens": "lågflygande",
    "lågflygandes": "lågflygande",
    "lågflygandet": "lågflygande",
    "lågflygandets": "lågflygande",
    "lågflygas": "lågflyga",
    "lågflyge": "lågflyga",
    "lågflyger": "lågflyga",
    "lågflyges": "lågflyga",
    "lågflygs": "lågflyga",
    "lågflög": "lågflyga",
    "lågflögs": "lågflyga",
    "lågfrekvensen": "lågfrekvens",
    "lågfrekvensens": "lågfrekvens",
    "lågfrekvenser": "lågfrekvens",
    "lågfrekvenserna": "lågfrekvens",
    "lågfrekvensernas": "lågfrekvens",
    "lågfrekvensers": "lågfrekvens",
    "lågfrekventa": "lågfrekvent",
    "lågfrekventare": "lågfrekvent",
    "lågfrekventares": "lågfrekvent",
    "lågfrekventas": "lågfrekvent",
    "lågfrekventast": "lågfrekvent",
    "lågfrekventaste": "lågfrekvent",
    "lågfrekventastes": "lågfrekvent",
    "lågfrekventasts": "lågfrekvent",
    "lågfrekvente": "lågfrekvent",
    "lågfrekventes": "lågfrekvent",
    "lågfrekvents": "lågfrekvent",
    "lågfärgen": "lågfärg",
    "lågfärgens": "lågfärg",
    "lågfärger": "lågfärg",
    "lågfärgerna": "lågfärg",
    "lågfärgernas": "lågfärg",
    "lågfärgers": "lågfärg",
    "lågfärgs": "lågfärg",
    "lågge": "ligga",
    "lågges": "ligga",
    "låghalta": "låghalt",
    "låghaltare": "låghalt",
    "låghaltares": "låghalt",
    "låghaltas": "låghalt",
    "låghaltast": "låghalt",
    "låghaltaste": "låghalt",
    "låghaltastes": "låghalt",
    "låghaltasts": "låghalt",
    "låghalte": "låghalt",
    "låghaltes": "låghalt",
    "låghalts": "låghalt",
    "lågheten": "låghet",
    "låghetens": "låghet",
    "lågheter": "låghet",
    "lågheterna": "låghet",
    "lågheternas": "låghet",
    "lågheters": "låghet",
    "låghets": "låghet",
    "låghjuliga": "låghjulig",
    "låghjuligare": "låghjulig",
    "låghjuligares": "låghjulig",
    "låghjuligas": "låghjulig",
    "låghjuligast": "låghjulig",
    "låghjuligaste": "låghjulig",
    "låghjuligastes": "låghjulig",
    "låghjuligasts": "låghjulig",
    "låghjulige": "låghjulig",
    "låghjuliges": "låghjulig",
    "låghjuligheten": "låghjulighet",
    "låghjulighetens": "låghjulighet",
    "låghjulighets": "låghjulighet",
    "låghjuligs": "låghjulig",
    "låghjuligt": "låghjulig",
    "låghjuligts": "låghjulig",
    "låghjulingar": "låghjuling",
    "låghjulingarna": "låghjuling",
    "låghjulingarnas": "låghjuling",
    "låghjulingars": "låghjuling",
    "låghjulingen": "låghjuling",
    "låghjulingens": "låghjuling",
    "låghjulings": "låghjuling",
    "låghusen": "låghus",
    "låghusens": "låghus",
    "låghuset": "låghus",
    "låghusets": "låghus",
    "låginkomsttagar": "låginkomsttagare",
    "låginkomsttagaren": "låginkomsttagare",
    "låginkomsttagarens": "låginkomsttagare",
    "låginkomsttagares": "låginkomsttagare",
    "låginkomsttagarna": "låginkomsttagare",
    "låginkomsttagarnas": "låginkomsttagare",
    "lågklackade": "lågklackad",
    "lågklackades": "lågklackad",
    "lågklackads": "lågklackad",
    "lågklackat": "lågklackad",
    "lågklackats": "lågklackad",
    "lågkonjunkturen": "lågkonjunktur",
    "lågkonjunkturens": "lågkonjunktur",
    "lågkonjunkturer": "lågkonjunktur",
    "lågkonjunkturerna": "lågkonjunktur",
    "lågkonjunkturernas": "lågkonjunktur",
    "lågkonjunkturers": "lågkonjunktur",
    "lågkonjunkturs": "lågkonjunktur",
    "lågkyrkliga": "lågkyrklig",
    "lågkyrkligare": "lågkyrklig",
    "lågkyrkligares": "lågkyrklig",
    "lågkyrkligas": "lågkyrklig",
    "lågkyrkligast": "lågkyrklig",
    "lågkyrkligaste": "lågkyrklig",
    "lågkyrkligastes": "lågkyrklig",
    "lågkyrkligasts": "lågkyrklig",
    "lågkyrklige": "lågkyrklig",
    "lågkyrkliges": "lågkyrklig",
    "lågkyrkligheten": "lågkyrklighet",
    "lågkyrklighetens": "lågkyrklighet",
    "lågkyrklighets": "lågkyrklighet",
    "lågkyrkligs": "lågkyrklig",
    "lågkyrkligt": "lågkyrklig",
    "lågkyrkligts": "lågkyrklig",
    "låglandet": "lågland",
    "låglandets": "lågland",
    "låglands": "lågland",
    "låglandsboskapen": "låglandsboskap",
    "låglandsboskapens": "låglandsboskap",
    "låglandsboskaps": "låglandsboskap",
    "låglandsrasen": "låglandsras",
    "låglandsrasens": "låglandsras",
    "låglandsraser": "låglandsras",
    "låglandsraserna": "låglandsras",
    "låglandsrasernas": "låglandsras",
    "låglandsrasers": "låglandsras",
    "låglänta": "låglänt",
    "lågläntare": "låglänt",
    "lågläntares": "låglänt",
    "lågläntas": "låglänt",
    "lågläntast": "låglänt",
    "lågläntaste": "låglänt",
    "lågläntastes": "låglänt",
    "lågläntasts": "låglänt",
    "låglänte": "låglänt",
    "lågläntes": "låglänt",
    "lågläntheten": "låglänthet",
    "låglänthetens": "låglänthet",
    "låglänthets": "låglänthet",
    "låglänts": "låglänt",
    "låglöneprofilen": "låglöneprofil",
    "låglöneprofilens": "låglöneprofil",
    "låglöneprofiler": "låglöneprofil",
    "låglöneprofilerna": "låglöneprofil",
    "låglöneprofilernas": "låglöneprofil",
    "låglöneprofilers": "låglöneprofil",
    "låglöneprofils": "låglöneprofil",
    "lågmoss": "lågmosse",
    "lågmossar": "lågmosse",
    "lågmossarna": "lågmosse",
    "lågmossarnas": "lågmosse",
    "lågmossars": "lågmosse",
    "lågmossen": "lågmosse",
    "lågmossens": "lågmosse",
    "lågmosses": "lågmosse",
    "lågmälda": "lågmäld",
    "lågmäldare": "lågmäld",
    "lågmäldares": "lågmäld",
    "lågmäldas": "lågmäld",
    "lågmäldast": "lågmäld",
    "lågmäldaste": "lågmäld",
    "lågmäldastes": "lågmäld",
    "lågmäldasts": "lågmäld",
    "lågmälde": "lågmäld",
    "lågmäldes": "lågmäld",
    "lågmäldheten": "lågmäldhet",
    "lågmäldhetens": "lågmäldhet",
    "lågmäldhets": "lågmäldhet",
    "lågmälds": "lågmäld",
    "lågmält": "lågmäld",
    "lågmälts": "lågmäld",
    "lågoddsar": "lågoddsare",
    "lågoddsaren": "lågoddsare",
    "lågoddsarens": "lågoddsare",
    "lågoddsares": "lågoddsare",
    "lågoddsarna": "lågoddsare",
    "lågoddsarnas": "lågoddsare",
    "lågor": "låga",
    "lågorna": "låga",
    "lågornas": "låga",
    "lågors": "låga",
    "lågprioriterad": "lågprioritera",
    "lågprioriterade": "lågprioritera",
    "lågprioriterades": "lågprioritera",
    "lågprioriterads": "lågprioritera",
    "lågprioriterande": "lågprioritera",
    "lågprioriteranden": "lågprioriterande",
    "lågprioriterandena": "lågprioriterande",
    "lågprioriterandenas": "lågprioriterande",
    "lågprioriterandens": "lågprioriterande",
    "lågprioriterandes": "lågprioriterande",
    "lågprioriterandet": "lågprioriterande",
    "lågprioriterandets": "lågprioriterande",
    "lågprioriterar": "lågprioritera",
    "lågprioriteras": "lågprioritera",
    "lågprioriterat": "lågprioritera",
    "lågprioriterats": "lågprioritera",
    "lågprioriterbara": "lågprioriterbar",
    "lågprioriterbarare": "lågprioriterbar",
    "lågprioriterbarares": "lågprioriterbar",
    "lågprioriterbaras": "lågprioriterbar",
    "lågprioriterbarast": "lågprioriterbar",
    "lågprioriterbaraste": "lågprioriterbar",
    "lågprioriterbarastes": "lågprioriterbar",
    "lågprioriterbarasts": "lågprioriterbar",
    "lågprioriterbare": "lågprioriterbar",
    "lågprioriterbares": "lågprioriterbar",
    "lågprioriterbarheten": "lågprioriterbarhet",
    "lågprioriterbarhetens": "lågprioriterbarhet",
    "lågprioriterbarhets": "lågprioriterbarhet",
    "lågprioriterbars": "lågprioriterbar",
    "lågprioriterbart": "lågprioriterbar",
    "lågprioriterbarts": "lågprioriterbar",
    "lågprisbolagen": "lågprisbolag",
    "lågprisbolagens": "lågprisbolag",
    "lågprisbolaget": "lågprisbolag",
    "lågprisbolagets": "lågprisbolag",
    "lågprisbolags": "lågprisbolag",
    "lågprisen": "lågpris",
    "lågprisens": "lågpris",
    "lågpriser": "lågpris",
    "lågpriserna": "lågpris",
    "lågprisernas": "lågpris",
    "lågprisers": "lågpris",
    "lågpriset": "lågpris",
    "lågprisets": "lågpris",
    "lågpriskonkurrensen": "lågpriskonkurrens",
    "lågpriskonkurrensens": "lågpriskonkurrens",
    "lågpriskorten": "lågpriskort",
    "lågpriskortens": "lågpriskort",
    "lågpriskortet": "lågpriskort",
    "lågpriskortets": "lågpriskort",
    "lågpriskorts": "lågpriskort",
    "lågproduktiva": "lågproduktiv",
    "lågproduktivare": "lågproduktiv",
    "lågproduktivares": "lågproduktiv",
    "lågproduktivas": "lågproduktiv",
    "lågproduktivast": "lågproduktiv",
    "lågproduktivaste": "lågproduktiv",
    "lågproduktivastes": "lågproduktiv",
    "lågproduktivasts": "lågproduktiv",
    "lågproduktive": "lågproduktiv",
    "lågproduktives": "lågproduktiv",
    "lågproduktivs": "lågproduktiv",
    "lågproduktivt": "lågproduktiv",
    "lågproduktivts": "lågproduktiv",
    "lågprosan": "lågprosa",
    "lågprosans": "lågprosa",
    "lågprosas": "lågprosa",
    "lågreliefen": "lågrelief",
    "lågreliefens": "lågrelief",
    "lågreliefer": "lågrelief",
    "lågrelieferna": "lågrelief",
    "lågreliefernas": "lågrelief",
    "lågreliefers": "lågrelief",
    "lågreliefs": "lågrelief",
    "lågs": "ligga",
    "lågsinnade": "lågsinnad",
    "lågsinnades": "lågsinnad",
    "lågsinnads": "lågsinnad",
    "lågsinnat": "lågsinnad",
    "lågsinnats": "lågsinnad",
    "lågsinta": "lågsint",
    "lågsintare": "lågsint",
    "lågsintares": "lågsint",
    "lågsintas": "lågsint",
    "lågsintast": "lågsint",
    "lågsintaste": "lågsint",
    "lågsintastes": "lågsint",
    "lågsintasts": "lågsint",
    "lågsinte": "lågsint",
    "lågsintes": "lågsint",
    "lågsintheten": "lågsinthet",
    "lågsinthetens": "lågsinthet",
    "lågsinthets": "lågsinthet",
    "lågsints": "lågsint",
    "lågskon": "lågsko",
    "lågskons": "lågsko",
    "lågskor": "lågsko",
    "lågskorna": "lågsko",
    "lågskornas": "lågsko",
    "lågskors": "lågsko",
    "lågskos": "lågsko",
    "lågslätten": "lågslätt",
    "lågslättens": "lågslätt",
    "lågslätter": "lågslätt",
    "lågslätterna": "lågslätt",
    "lågslätternas": "lågslätt",
    "lågslätters": "lågslätt",
    "lågslätts": "lågslätt",
    "lågsniffar": "lågsniff",
    "lågsniffarna": "lågsniff",
    "lågsniffarnas": "lågsniff",
    "lågsniffars": "lågsniff",
    "lågsniffen": "lågsniff",
    "lågsniffens": "lågsniff",
    "lågsniffs": "lågsniff",
    "lågspända": "lågspänd",
    "lågspändare": "lågspänd",
    "lågspändares": "lågspänd",
    "lågspändas": "lågspänd",
    "lågspändast": "lågspänd",
    "lågspändaste": "lågspänd",
    "lågspändastes": "lågspänd",
    "lågspändasts": "lågspänd",
    "lågspände": "lågspänd",
    "lågspändes": "lågspänd",
    "lågspänds": "lågspänd",
    "lågspänningar": "lågspänning",
    "lågspänningarna": "lågspänning",
    "lågspänningarnas": "lågspänning",
    "lågspänningars": "lågspänning",
    "lågspänningen": "lågspänning",
    "lågspänningens": "lågspänning",
    "lågspännings": "lågspänning",
    "lågspänt": "lågspänd",
    "lågspänts": "lågspänd",
    "lågstadie": "lågstadium",
    "lågstadielärar": "lågstadielärare",
    "lågstadieläraren": "lågstadielärare",
    "lågstadielärarens": "lågstadielärare",
    "lågstadielärares": "lågstadielärare",
    "lågstadielärarna": "lågstadielärare",
    "lågstadielärarnas": "lågstadielärare",
    "lågstadier": "lågstadium",
    "lågstadierna": "lågstadium",
    "lågstadiernas": "lågstadium",
    "lågstadiers": "lågstadium",
    "lågstadiet": "lågstadium",
    "lågstadiets": "lågstadium",
    "lågstadiums": "lågstadium",
    "lågstatusen": "lågstatus",
    "lågstatusens": "lågstatus",
    "lågsvavliga": "lågsvavlig",
    "lågsvavligare": "lågsvavlig",
    "lågsvavligares": "lågsvavlig",
    "lågsvavligas": "lågsvavlig",
    "lågsvavligast": "lågsvavlig",
    "lågsvavligaste": "lågsvavlig",
    "lågsvavligastes": "lågsvavlig",
    "lågsvavligasts": "lågsvavlig",
    "lågsvavlige": "lågsvavlig",
    "lågsvavliges": "lågsvavlig",
    "lågsvavligheten": "lågsvavlighet",
    "lågsvavlighetens": "lågsvavlighet",
    "lågsvavlighets": "lågsvavlighet",
    "lågsvavligs": "lågsvavlig",
    "lågsvavligt": "lågsvavlig",
    "lågsvavligts": "lågsvavlig",
    "lågsäsongen": "lågsäsong",
    "lågsäsongens": "lågsäsong",
    "lågsäsonger": "lågsäsong",
    "lågsäsongerna": "lågsäsong",
    "lågsäsongernas": "lågsäsong",
    "lågsäsongers": "lågsäsong",
    "lågsäsongs": "lågsäsong",
    "lågt": "låg",
    "lågtrycken": "lågtryck",
    "lågtryckens": "lågtryck",
    "lågtrycket": "lågtryck",
    "lågtryckets": "lågtryck",
    "lågtrycks": "lågtryck",
    "lågts": "låg",
    "lågtysk": "lågtyska",
    "lågtyska": "lågtysk",
    "lågtyskan": "lågtyska",
    "lågtyskans": "lågtyska",
    "lågtyskare": "lågtysk",
    "lågtyskares": "lågtysk",
    "lågtyskas": "lågtyska",
    "lågtyskast": "lågtysk",
    "lågtyskaste": "lågtysk",
    "lågtyskastes": "lågtysk",
    "lågtyskasts": "lågtysk",
    "lågtyske": "lågtysk",
    "lågtyskes": "lågtysk",
    "lågtysks": "lågtysk",
    "lågtyskt": "lågtysk",
    "lågtyskts": "lågtysk",
    "lågvattenmärken": "lågvattenmärke",
    "lågvattenmärkena": "lågvattenmärke",
    "lågvattenmärkenas": "lågvattenmärke",
    "lågvattenmärkens": "lågvattenmärke",
    "lågvattenmärkes": "lågvattenmärke",
    "lågvattenmärket": "lågvattenmärke",
    "lågvattenmärkets": "lågvattenmärke",
    "lågvattens": "lågvatten",
    "lågvattnen": "lågvatten",
    "lågvattnens": "lågvatten",
    "lågvattnet": "lågvatten",
    "lågvattnets": "lågvatten",
    "lågvuxenheten": "lågvuxenhet",
    "lågvuxenhetens": "lågvuxenhet",
    "lågvuxenhets": "lågvuxenhet",
    "lågvuxens": "lågvuxen",
    "lågvuxet": "lågvuxen",
    "lågvuxets": "lågvuxen",
    "lågvuxna": "lågvuxen",
    "lågvuxnare": "lågvuxen",
    "lågvuxnares": "lågvuxen",
    "lågvuxnas": "lågvuxen",
    "lågvuxnast": "lågvuxen",
    "lågvuxnaste": "lågvuxen",
    "lågvuxnastes": "lågvuxen",
    "lågvuxnasts": "lågvuxen",
    "lågvuxne": "lågvuxen",
    "lågvuxnes": "lågvuxen",
    "lågvärdiga": "lågvärdig",
    "lågvärdigare": "lågvärdig",
    "lågvärdigares": "lågvärdig",
    "lågvärdigas": "lågvärdig",
    "lågvärdigast": "lågvärdig",
    "lågvärdigaste": "lågvärdig",
    "lågvärdigastes": "lågvärdig",
    "lågvärdigasts": "lågvärdig",
    "lågvärdige": "lågvärdig",
    "lågvärdiges": "lågvärdig",
    "lågvärdigheten": "lågvärdighet",
    "lågvärdighetens": "lågvärdighet",
    "lågvärdighets": "lågvärdighet",
    "lågvärdigs": "lågvärdig",
    "lågvärdigt": "lågvärdig",
    "lågvärdigts": "lågvärdig",
    "lågväxta": "lågväxt",
    "lågväxtare": "lågväxt",
    "lågväxtares": "lågväxt",
    "lågväxtas": "lågväxt",
    "lågväxtast": "lågväxt",
    "lågväxtaste": "lågväxt",
    "lågväxtastes": "lågväxt",
    "lågväxtasts": "lågväxt",
    "lågväxte": "lågväxt",
    "lågväxtes": "lågväxt",
    "lågväxtheten": "lågväxthet",
    "lågväxthetens": "lågväxthet",
    "lågväxthets": "lågväxthet",
    "lågväxts": "lågväxt",
    "lån": "låna",
    "lånad": "låna",
    "lånade": "låna",
    "lånades": "låna",
    "lånads": "låna",
    "lånande": "låna",
    "lånanden": "lånande",
    "lånandena": "lånande",
    "lånandenas": "lånande",
    "lånandens": "lånande",
    "lånandes": "lånande",
    "lånandet": "lånande",
    "lånandets": "lånande",
    "lånar": "låna",
    "lånas": "låna",
    "lånat": "låna",
    "lånats": "låna",
    "låneansökans": "låneansökan",
    "låneansökningar": "låneansökning",
    "låneansökningarna": "låneansökning",
    "låneansökningarnas": "låneansökning",
    "låneansökningars": "låneansökning",
    "låneansökningen": "låneansökning",
    "låneansökningens": "låneansökning",
    "låneansöknings": "låneansökning",
    "lånebiblioteken": "lånebibliotek",
    "lånebibliotekens": "lånebibliotek",
    "lånebiblioteket": "lånebibliotek",
    "lånebibliotekets": "lånebibliotek",
    "lånebiblioteks": "lånebibliotek",
    "låneexpeditionen": "låneexpedition",
    "låneexpeditionens": "låneexpedition",
    "låneexpeditioner": "låneexpedition",
    "låneexpeditionerna": "låneexpedition",
    "låneexpeditionernas": "låneexpedition",
    "låneexpeditioners": "låneexpedition",
    "låneexpeditions": "låneexpedition",
    "lånefesten": "lånefest",
    "lånefestens": "lånefest",
    "lånefester": "lånefest",
    "lånefesterna": "lånefest",
    "lånefesternas": "lånefest",
    "lånefesters": "lånefest",
    "lånefests": "lånefest",
    "låneformen": "låneform",
    "låneformens": "låneform",
    "låneformer": "låneform",
    "låneformerna": "låneform",
    "låneformernas": "låneform",
    "låneformers": "låneform",
    "låneforms": "låneform",
    "lånegarantien": "lånegaranti",
    "lånegarantiens": "lånegaranti",
    "lånegarantier": "lånegaranti",
    "lånegarantierna": "lånegaranti",
    "lånegarantiernas": "lånegaranti",
    "lånegarantiers": "lånegaranti",
    "lånegarantin": "lånegaranti",
    "lånegarantins": "lånegaranti",
    "lånegarantis": "lånegaranti",
    "lånekontoren": "lånekontor",
    "lånekontorens": "lånekontor",
    "lånekontoret": "lånekontor",
    "lånekontorets": "lånekontor",
    "lånekontors": "lånekontor",
    "lånekorten": "lånekort",
    "lånekortens": "lånekort",
    "lånekortet": "lånekort",
    "lånekortets": "lånekort",
    "lånekorts": "lånekort",
    "låneköer": "lånekö",
    "låneköerna": "lånekö",
    "låneköernas": "lånekö",
    "låneköers": "lånekö",
    "lånekön": "lånekö",
    "låneköns": "lånekö",
    "låneköpen": "låneköp",
    "låneköpens": "låneköp",
    "låneköpet": "låneköp",
    "låneköpets": "låneköp",
    "låneköps": "låneköp",
    "lånekös": "lånekö",
    "lånelöften": "lånelöfte",
    "lånelöftena": "lånelöfte",
    "lånelöftenas": "lånelöfte",
    "lånelöftens": "lånelöfte",
    "lånelöftes": "lånelöfte",
    "lånelöftet": "lånelöfte",
    "lånelöftets": "lånelöfte",
    "lånen": "lån",
    "lånens": "lån",
    "lånet": "lån",
    "lånetaken": "lånetak",
    "lånetakens": "lånetak",
    "lånetaket": "lånetak",
    "lånetakets": "lånetak",
    "lånetaks": "lånetak",
    "lånets": "lån",
    "lånfångens": "lånfången",
    "lånfånget": "lånfången",
    "lånfångets": "lånfången",
    "lånfångna": "lånfången",
    "lånfångnare": "lånfången",
    "lånfångnares": "lånfången",
    "lånfångnas": "lånfången",
    "lånfångnast": "lånfången",
    "lånfångnaste": "lånfången",
    "lånfångnastes": "lånfången",
    "lånfångnasts": "lånfången",
    "lånfångne": "lånfången",
    "lånfångnes": "lånfången",
    "långa": "lång",
    "långan": "långa",
    "långans": "långa",
    "långas": "långa",
    "långbenta": "långbent",
    "långbentare": "långbent",
    "långbentares": "långbent",
    "långbentas": "långbent",
    "långbentast": "långbent",
    "långbentaste": "långbent",
    "långbentastes": "långbent",
    "långbentasts": "långbent",
    "långbente": "långbent",
    "långbentes": "långbent",
    "långbentheten": "långbenthet",
    "långbenthetens": "långbenthet",
    "långbenthets": "långbenthet",
    "långbents": "långbent",
    "långbollar": "långboll",
    "långbollarna": "långboll",
    "långbollarnas": "långboll",
    "långbollars": "långboll",
    "långbollen": "långboll",
    "långbollens": "långboll",
    "långbolls": "långboll",
    "långborden": "långbord",
    "långbordens": "långbord",
    "långbordet": "långbord",
    "långbordets": "långbord",
    "långbords": "långbord",
    "långbyx": "långbyxa",
    "långbyxan": "långbyxa",
    "långbyxans": "långbyxa",
    "långbyxas": "långbyxa",
    "långbyxe": "långbyxa",
    "långbyxor": "långbyxa",
    "långbyxorna": "långbyxa",
    "långbyxornas": "långbyxa",
    "långbyxors": "långbyxa",
    "långbänkar": "långbänk",
    "långbänkarna": "långbänk",
    "långbänkarnas": "långbänk",
    "långbänkars": "långbänk",
    "långbänken": "långbänk",
    "långbänkens": "långbänk",
    "långbänks": "långbänk",
    "långdansen": "långdans",
    "långdansens": "långdans",
    "långdanser": "långdans",
    "långdanserna": "långdans",
    "långdansernas": "långdans",
    "långdansers": "långdans",
    "långdistansen": "långdistans",
    "långdistansens": "långdistans",
    "långdistanser": "långdistans",
    "långdistanserna": "långdistans",
    "långdistansernas": "långdistans",
    "långdistansers": "långdistans",
    "långdistanslöpningar": "långdistanslöpning",
    "långdistanslöpningarna": "långdistanslöpning",
    "långdistanslöpningarnas": "långdistanslöpning",
    "långdistanslöpningars": "långdistanslöpning",
    "långdistanslöpningen": "långdistanslöpning",
    "långdistanslöpningens": "långdistanslöpning",
    "långdistanslöpnings": "långdistanslöpning",
    "långdistansraketen": "långdistansraket",
    "långdistansraketens": "långdistansraket",
    "långdistansraketer": "långdistansraket",
    "långdistansraketerna": "långdistansraket",
    "långdistansraketernas": "långdistansraket",
    "långdistansraketers": "långdistansraket",
    "långdistansrakets": "långdistansraket",
    "långdragenheten": "långdragenhet",
    "långdragenhetens": "långdragenhet",
    "långdragenhets": "långdragenhet",
    "långdragens": "långdragen",
    "långdraget": "långdragen",
    "långdragets": "långdragen",
    "långdragna": "långdragen",
    "långdragnare": "långdragen",
    "långdragnares": "långdragen",
    "långdragnas": "långdragen",
    "långdragnast": "långdragen",
    "långdragnaste": "långdragen",
    "långdragnastes": "långdragen",
    "långdragnasts": "långdragen",
    "långdragne": "långdragen",
    "långdragnes": "långdragen",
    "långdukar": "långduk",
    "långdukarna": "långduk",
    "långdukarnas": "långduk",
    "långdukars": "långduk",
    "långduken": "långduk",
    "långdukens": "långduk",
    "långduks": "långduk",
    "långe": "lång",
    "långemannen": "långeman",
    "långemannens": "långeman",
    "långemans": "långeman",
    "långemän": "långeman",
    "långemännen": "långeman",
    "långemännens": "långeman",
    "långemäns": "långeman",
    "långes": "lång",
    "långfarar": "långfarare",
    "långfararen": "långfarare",
    "långfararens": "långfarare",
    "långfarares": "långfarare",
    "långfararna": "långfarare",
    "långfararnas": "långfarare",
    "långfilmen": "långfilm",
    "långfilmens": "långfilm",
    "långfilmer": "långfilm",
    "långfilmerna": "långfilm",
    "långfilmernas": "långfilm",
    "långfilmers": "långfilm",
    "långfilms": "långfilm",
    "långfingern": "långfinger",
    "långfingerns": "långfinger",
    "långfingers": "långfinger",
    "långfingrade": "långfingrad",
    "långfingrades": "långfingrad",
    "långfingrads": "långfingrad",
    "långfingrar": "långfinger",
    "långfingrarna": "långfinger",
    "långfingrarnas": "långfinger",
    "långfingrars": "långfinger",
    "långfingrat": "långfingrad",
    "långfingrats": "långfingrad",
    "långfingret": "långfinger",
    "långfingrets": "långfinger",
    "långfranskan": "långfranska",
    "långfranskana": "långfranska",
    "långfranskanas": "långfranska",
    "långfranskans": "långfranska",
    "långfranskas": "långfranska",
    "långfranskat": "långfranska",
    "långfranskats": "långfranska",
    "långfranskor": "långfranska",
    "långfranskorna": "långfranska",
    "långfranskornas": "långfranska",
    "långfranskors": "långfranska",
    "långfredagar": "långfredag",
    "långfredagarna": "långfredag",
    "långfredagarnas": "långfredag",
    "långfredagars": "långfredag",
    "långfredagen": "långfredag",
    "långfredagens": "långfredag",
    "långfredags": "långfredag",
    "långfristiga": "långfristig",
    "långfristigare": "långfristig",
    "långfristigares": "långfristig",
    "långfristigas": "långfristig",
    "långfristigast": "långfristig",
    "långfristigaste": "långfristig",
    "långfristigastes": "långfristig",
    "långfristigasts": "långfristig",
    "långfristige": "långfristig",
    "långfristiges": "långfristig",
    "långfristigheten": "långfristighet",
    "långfristighetens": "långfristighet",
    "långfristighets": "långfristighet",
    "långfristigs": "långfristig",
    "långfristigt": "långfristig",
    "långfristigts": "långfristig",
    "långfärden": "långfärd",
    "långfärdens": "långfärd",
    "långfärder": "långfärd",
    "långfärderna": "långfärd",
    "långfärdernas": "långfärd",
    "långfärders": "långfärd",
    "långfärds": "långfärd",
    "långfärdsbussar": "långfärdsbuss",
    "långfärdsbussarna": "långfärdsbuss",
    "långfärdsbussarnas": "långfärdsbuss",
    "långfärdsbussars": "långfärdsbuss",
    "långfärdsbussen": "långfärdsbuss",
    "långfärdsbussens": "långfärdsbuss",
    "långgardinen": "långgardin",
    "långgardinens": "långgardin",
    "långgardiner": "långgardin",
    "långgardinerna": "långgardin",
    "långgardinernas": "långgardin",
    "långgardiners": "långgardin",
    "långgardins": "långgardin",
    "långgroggar": "långgrogg",
    "långgroggarna": "långgrogg",
    "långgroggarnas": "långgrogg",
    "långgroggars": "långgrogg",
    "långgroggen": "långgrogg",
    "långgroggens": "långgrogg",
    "långgroggs": "långgrogg",
    "långgrunda": "långgrund",
    "långgrundare": "långgrund",
    "långgrundares": "långgrund",
    "långgrundas": "långgrund",
    "långgrundast": "långgrund",
    "långgrundaste": "långgrund",
    "långgrundastes": "långgrund",
    "långgrundasts": "långgrund",
    "långgrunde": "långgrund",
    "långgrundes": "långgrund",
    "långgrundheten": "långgrundhet",
    "långgrundhetens": "långgrundhet",
    "långgrundhets": "långgrundhet",
    "långgrunds": "långgrund",
    "långgrunt": "långgrund",
    "långgrunts": "långgrund",
    "långhelgen": "långhelg",
    "långhelgens": "långhelg",
    "långhelger": "långhelg",
    "långhelgerna": "långhelg",
    "långhelgernas": "långhelg",
    "långhelgers": "långhelg",
    "långhelgs": "långhelg",
    "långhorniga": "långhornig",
    "långhornigare": "långhornig",
    "långhornigares": "långhornig",
    "långhornigas": "långhornig",
    "långhornigast": "långhornig",
    "långhornigaste": "långhornig",
    "långhornigastes": "långhornig",
    "långhornigasts": "långhornig",
    "långhornige": "långhornig",
    "långhorniges": "långhornig",
    "långhornigs": "långhornig",
    "långhornigt": "långhornig",
    "långhornigts": "långhornig",
    "långhusen": "långhus",
    "långhusens": "långhus",
    "långhuset": "långhus",
    "långhusets": "långhus",
    "långhåriga": "långhårig",
    "långhårigare": "långhårig",
    "långhårigares": "långhårig",
    "långhårigas": "långhårig",
    "långhårigast": "långhårig",
    "långhårigaste": "långhårig",
    "långhårigastes": "långhårig",
    "långhårigasts": "långhårig",
    "långhårige": "långhårig",
    "långhåriges": "långhårig",
    "långhårigheten": "långhårighet",
    "långhårighetens": "långhårighet",
    "långhårighets": "långhårighet",
    "långhårigs": "långhårig",
    "långhårigt": "långhårig",
    "långhårigts": "långhårig",
    "långivar": "långivare",
    "långivaren": "långivare",
    "långivarens": "långivare",
    "långivares": "långivare",
    "långivarna": "långivare",
    "långivarnas": "långivare",
    "långkalsong": "långkalsonger",
    "långkalsongerna": "långkalsonger",
    "långkalsongernas": "långkalsonger",
    "långkalsongers": "långkalsonger",
    "långkalsongs": "långkalsonger",
    "långkalsongsdebuten": "långkalsongsdebut",
    "långkalsongsdebutens": "långkalsongsdebut",
    "långkalsongsdebuter": "långkalsongsdebut",
    "långkalsongsdebuterna": "långkalsongsdebut",
    "långkalsongsdebuternas": "långkalsongsdebut",
    "långkalsongsdebuters": "långkalsongsdebut",
    "långkalsongsdebuts": "långkalsongsdebut",
    "långkatekesen": "långkatekes",
    "långkatekesens": "långkatekes",
    "långkoken": "långkok",
    "långkokens": "långkok",
    "långkoket": "långkok",
    "långkokets": "långkok",
    "långkoks": "långkok",
    "långkörar": "långkörare",
    "långköraren": "långkörare",
    "långkörarens": "långkörare",
    "långkörares": "långkörare",
    "långkörarna": "långkörare",
    "långkörarnas": "långkörare",
    "långledats": "långledas",
    "långleddes": "långledas",
    "långledes": "långledas",
    "långlediga": "långledig",
    "långledigare": "långledig",
    "långledigares": "långledig",
    "långledigas": "långledig",
    "långledigast": "långledig",
    "långledigaste": "långledig",
    "långledigastes": "långledig",
    "långledigasts": "långledig",
    "långledige": "långledig",
    "långlediges": "långledig",
    "långledigheten": "långledighet",
    "långledighetens": "långledighet",
    "långledigheter": "långledighet",
    "långledigheterna": "långledighet",
    "långledigheternas": "långledighet",
    "långledigheters": "långledighet",
    "långledighets": "långledighet",
    "långledigs": "långledig",
    "långledigt": "långledig",
    "långledigts": "långledig",
    "långleds": "långledas",
    "långletts": "långledas",
    "långliga": "långlig",
    "långligare": "långlig",
    "långligares": "långlig",
    "långligas": "långlig",
    "långligast": "långlig",
    "långligaste": "långlig",
    "långligastes": "långlig",
    "långligasts": "långlig",
    "långlige": "långlig",
    "långliges": "långlig",
    "långliggar": "långliggare",
    "långliggaren": "långliggare",
    "långliggarens": "långliggare",
    "långliggares": "långliggare",
    "långliggarna": "långliggare",
    "långliggarnas": "långliggare",
    "långligheten": "långlighet",
    "långlighetens": "långlighet",
    "långlighets": "långlighet",
    "långligs": "långlig",
    "långligt": "långlig",
    "långligts": "långlig",
    "långlivade": "långlivad",
    "långlivades": "långlivad",
    "långlivads": "långlivad",
    "långlivat": "långlivad",
    "långlivats": "långlivad",
    "långloppen": "långlopp",
    "långloppens": "långlopp",
    "långloppet": "långlopp",
    "långloppets": "långlopp",
    "långlopps": "långlopp",
    "långlotsningar": "långlotsning",
    "långlotsningarna": "långlotsning",
    "långlotsningarnas": "långlotsning",
    "långlotsningars": "långlotsning",
    "långlotsningen": "långlotsning",
    "långlotsningens": "långlotsning",
    "långlotsnings": "långlotsning",
    "långmarschen": "långmarsch",
    "långmarschens": "långmarsch",
    "långmarscher": "långmarsch",
    "långmarscherna": "långmarsch",
    "långmarschernas": "långmarsch",
    "långmarschers": "långmarsch",
    "långmarschs": "långmarsch",
    "långmjölken": "långmjölk",
    "långmjölkens": "långmjölk",
    "långmjölks": "långmjölk",
    "långmodet": "långmod",
    "långmodets": "långmod",
    "långmodiga": "långmodig",
    "långmodigare": "långmodig",
    "långmodigares": "långmodig",
    "långmodigas": "långmodig",
    "långmodigast": "långmodig",
    "långmodigaste": "långmodig",
    "långmodigastes": "långmodig",
    "långmodigasts": "långmodig",
    "långmodige": "långmodig",
    "långmodiges": "långmodig",
    "långmodigheten": "långmodighet",
    "långmodighetens": "långmodighet",
    "långmodighets": "långmodighet",
    "långmodigs": "långmodig",
    "långmodigt": "långmodig",
    "långmodigts": "långmodig",
    "långmods": "långmod",
    "långnäbbar": "långnäbb",
    "långnäbbarna": "långnäbb",
    "långnäbbarnas": "långnäbb",
    "långnäbbars": "långnäbb",
    "långnäbben": "långnäbb",
    "långnäbbens": "långnäbb",
    "långnäbbs": "långnäbb",
    "långnästa": "långnäst",
    "långnästare": "långnäst",
    "långnästares": "långnäst",
    "långnästas": "långnäst",
    "långnästast": "långnäst",
    "långnästaste": "långnäst",
    "långnästastes": "långnäst",
    "långnästasts": "långnäst",
    "långnäste": "långnäst",
    "långnästes": "långnäst",
    "långnästheten": "långnästhet",
    "långnästhetens": "långnästhet",
    "långnästhets": "långnästhet",
    "långnästs": "långnäst",
    "långor": "långa",
    "långorna": "långa",
    "långornas": "långa",
    "långors": "långa",
    "långpannan": "långpanna",
    "långpannans": "långpanna",
    "långpannas": "långpanna",
    "långpanne": "långpanna",
    "långpannor": "långpanna",
    "långpannorna": "långpanna",
    "långpannornas": "långpanna",
    "långpannors": "långpanna",
    "långperiodiska": "långperiodisk",
    "långperiodiskare": "långperiodisk",
    "långperiodiskares": "långperiodisk",
    "långperiodiskas": "långperiodisk",
    "långperiodiskast": "långperiodisk",
    "långperiodiskaste": "långperiodisk",
    "långperiodiskastes": "långperiodisk",
    "långperiodiskasts": "långperiodisk",
    "långperiodiske": "långperiodisk",
    "långperiodiskes": "långperiodisk",
    "långperiodisks": "långperiodisk",
    "långperiodiskt": "långperiodisk",
    "långperiodiskts": "långperiodisk",
    "långpromenaden": "långpromenad",
    "långpromenadens": "långpromenad",
    "långpromenader": "långpromenad",
    "långpromenaderna": "långpromenad",
    "långpromenadernas": "långpromenad",
    "långpromenaders": "långpromenad",
    "långpromenads": "långpromenad",
    "långrandiga": "långrandig",
    "långrandigare": "långrandig",
    "långrandigares": "långrandig",
    "långrandigas": "långrandig",
    "långrandigast": "långrandig",
    "långrandigaste": "långrandig",
    "långrandigastes": "långrandig",
    "långrandigasts": "långrandig",
    "långrandige": "långrandig",
    "långrandiges": "långrandig",
    "långrandigheten": "långrandighet",
    "långrandighetens": "långrandighet",
    "långrandighets": "långrandighet",
    "långrandigs": "långrandig",
    "långrandigt": "långrandig",
    "långrandigts": "långrandig",
    "långrevar": "långrev",
    "långrevarna": "långrev",
    "långrevarnas": "långrev",
    "långrevars": "långrev",
    "långreven": "långrev",
    "långrevens": "långrev",
    "långrevs": "långrev",
    "långs": "lång",
    "långsalningar": "långsalning",
    "långsalningarna": "långsalning",
    "långsalningarnas": "långsalning",
    "långsalningars": "långsalning",
    "långsalningen": "långsalning",
    "långsalningens": "långsalning",
    "långsalnings": "långsalning",
    "långsamheten": "långsamhet",
    "långsamhetens": "långsamhet",
    "långsamhets": "långsamhet",
    "långsamma": "långsam",
    "långsammare": "långsam",
    "långsammares": "långsam",
    "långsammas": "långsam",
    "långsammast": "långsam",
    "långsammaste": "långsam",
    "långsammastes": "långsam",
    "långsammasts": "långsam",
    "långsamme": "långsam",
    "långsammes": "långsam",
    "långsams": "långsam",
    "långsamt": "långsam",
    "långsamts": "långsam",
    "långschalar": "långschal",
    "långschalarna": "långschal",
    "långschalarnas": "långschal",
    "långschalars": "långschal",
    "långschalen": "långschal",
    "långschalens": "långschal",
    "långschals": "långschal",
    "långsidan": "långsida",
    "långsidans": "långsida",
    "långsidas": "långsida",
    "långside": "långsida",
    "långsides": "långsida",
    "långsidor": "långsida",
    "långsidorna": "långsida",
    "långsidornas": "långsida",
    "långsidors": "långsida",
    "långsiktiga": "långsiktig",
    "långsiktigare": "långsiktig",
    "långsiktigares": "långsiktig",
    "långsiktigas": "långsiktig",
    "långsiktigast": "långsiktig",
    "långsiktigaste": "långsiktig",
    "långsiktigastes": "långsiktig",
    "långsiktigasts": "långsiktig",
    "långsiktige": "långsiktig",
    "långsiktiges": "långsiktig",
    "långsiktigheten": "långsiktighet",
    "långsiktighetens": "långsiktighet",
    "långsiktighets": "långsiktighet",
    "långsiktigs": "långsiktig",
    "långsiktigt": "långsiktig",
    "långsiktigts": "långsiktig",
    "långsinta": "långsint",
    "långsintare": "långsint",
    "långsintares": "långsint",
    "långsintas": "långsint",
    "långsintast": "långsint",
    "långsintaste": "långsint",
    "långsintastes": "långsint",
    "långsintasts": "långsint",
    "långsinte": "långsint",
    "långsintes": "långsint",
    "långsintheten": "långsinthet",
    "långsinthetens": "långsinthet",
    "långsinthets": "långsinthet",
    "långsints": "långsint",
    "långsjalar": "långsjal",
    "långsjalarna": "långsjal",
    "långsjalarnas": "långsjal",
    "långsjalars": "långsjal",
    "långsjalen": "långsjal",
    "långsjalens": "långsjal",
    "långsjals": "långsjal",
    "långskaftade": "långskaftad",
    "långskaftades": "långskaftad",
    "långskaftads": "långskaftad",
    "långskaftat": "långskaftad",
    "långskaftats": "långskaftad",
    "långskalliga": "långskallig",
    "långskalligare": "långskallig",
    "långskalligares": "långskallig",
    "långskalligas": "långskallig",
    "långskalligast": "långskallig",
    "långskalligaste": "långskallig",
    "långskalligastes": "långskallig",
    "långskalligasts": "långskallig",
    "långskallige": "långskallig",
    "långskalliges": "långskallig",
    "långskalligheten": "långskallighet",
    "långskallighetens": "långskallighet",
    "långskallighets": "långskallighet",
    "långskalligs": "långskallig",
    "långskalligt": "långskallig",
    "långskalligts": "långskallig",
    "långskeppen": "långskepp",
    "långskeppens": "långskepp",
    "långskeppet": "långskepp",
    "långskeppets": "långskepp",
    "långskepps": "långskepp",
    "långskotten": "långskott",
    "långskottens": "långskott",
    "långskottet": "långskott",
    "långskottets": "långskott",
    "långskotts": "långskott",
    "långsmala": "långsmal",
    "långsmalare": "långsmal",
    "långsmalares": "långsmal",
    "långsmalas": "långsmal",
    "långsmalast": "långsmal",
    "långsmalaste": "långsmal",
    "långsmalastes": "långsmal",
    "långsmalasts": "långsmal",
    "långsmale": "långsmal",
    "långsmales": "långsmal",
    "långsmals": "långsmal",
    "långsmalt": "långsmal",
    "långsmalts": "långsmal",
    "långspanten": "långspant",
    "långspantens": "långspant",
    "långspantet": "långspant",
    "långspantets": "långspant",
    "långspants": "långspant",
    "långspelen": "långspel",
    "långspelens": "långspel",
    "långspelet": "långspel",
    "långspelets": "långspel",
    "långspels": "långspel",
    "långstrump": "långstrumpa",
    "långstrumpan": "långstrumpa",
    "långstrumpans": "långstrumpa",
    "långstrumpas": "långstrumpa",
    "långstrumpe": "långstrumpa",
    "långstrumpor": "långstrumpa",
    "långstrumporna": "långstrumpa",
    "långstrumpornas": "långstrumpa",
    "långstrumpors": "långstrumpa",
    "långstrumps": "långstrumpa",
    "långsträckta": "långsträckt",
    "långsträcktare": "långsträckt",
    "långsträcktares": "långsträckt",
    "långsträcktas": "långsträckt",
    "långsträcktast": "långsträckt",
    "långsträcktaste": "långsträckt",
    "långsträcktastes": "långsträckt",
    "långsträcktasts": "långsträckt",
    "långsträckte": "långsträckt",
    "långsträcktes": "långsträckt",
    "långsträckts": "långsträckt",
    "långsvansade": "långsvansad",
    "långsvansades": "långsvansad",
    "långsvansads": "långsvansad",
    "långsvansat": "långsvansad",
    "långsvansats": "långsvansad",
    "långsynta": "långsynt",
    "långsyntare": "långsynt",
    "långsyntares": "långsynt",
    "långsyntas": "långsynt",
    "långsyntast": "långsynt",
    "långsyntaste": "långsynt",
    "långsyntastes": "långsynt",
    "långsyntasts": "långsynt",
    "långsynte": "långsynt",
    "långsyntes": "långsynt",
    "långsyntheten": "långsynthet",
    "långsynthetens": "långsynthet",
    "långsyntheter": "långsynthet",
    "långsyntheterna": "långsynthet",
    "långsyntheternas": "långsynthet",
    "långsyntheters": "långsynthet",
    "långsynthets": "långsynthet",
    "långsynts": "långsynt",
    "långsökta": "långsökt",
    "långsöktare": "långsökt",
    "långsöktares": "långsökt",
    "långsöktas": "långsökt",
    "långsöktast": "långsökt",
    "långsöktaste": "långsökt",
    "långsöktastes": "långsökt",
    "långsöktasts": "långsökt",
    "långsökte": "långsökt",
    "långsöktes": "långsökt",
    "långsöktheten": "långsökthet",
    "långsökthetens": "långsökthet",
    "långsökthets": "långsökthet",
    "långsökts": "långsökt",
    "långt": "lång",
    "långtandade": "långtandad",
    "långtandades": "långtandad",
    "långtandads": "långtandad",
    "långtandat": "långtandad",
    "långtandats": "långtandad",
    "långtidsarbetslösa": "långtidsarbetslös",
    "långtidsarbetslösas": "långtidsarbetslös",
    "långtidsarbetslöse": "långtidsarbetslös",
    "långtidsarbetslöses": "långtidsarbetslös",
    "långtidsarbetslöst": "långtidsarbetslös",
    "långtidsarbetslösts": "långtidsarbetslös",
    "långtidsbehandlingar": "långtidsbehandling",
    "långtidsbehandlingarna": "långtidsbehandling",
    "långtidsbehandlingarnas": "långtidsbehandling",
    "långtidsbehandlingars": "långtidsbehandling",
    "långtidsbehandlingen": "långtidsbehandling",
    "långtidsbehandlingens": "långtidsbehandling",
    "långtidsbehandlings": "långtidsbehandling",
    "långtidsförvaringar": "långtidsförvaring",
    "långtidsförvaringarna": "långtidsförvaring",
    "långtidsförvaringarnas": "långtidsförvaring",
    "långtidsförvaringars": "långtidsförvaring",
    "långtidsförvaringen": "långtidsförvaring",
    "långtidsförvaringens": "långtidsförvaring",
    "långtidsförvarings": "långtidsförvaring",
    "långtidsminnes": "långtidsminne",
    "långtidsminnet": "långtidsminne",
    "långtidsminnets": "långtidsminne",
    "långtidsparkerad": "långtidsparkera",
    "långtidsparkerade": "långtidsparkera",
    "långtidsparkerades": "långtidsparkera",
    "långtidsparkerads": "långtidsparkera",
    "långtidsparkerande": "långtidsparkera",
    "långtidsparkeranden": "långtidsparkerande",
    "långtidsparkerandena": "långtidsparkerande",
    "långtidsparkerandenas": "långtidsparkerande",
    "långtidsparkerandens": "långtidsparkerande",
    "långtidsparkerandes": "långtidsparkerande",
    "långtidsparkerandet": "långtidsparkerande",
    "långtidsparkerandets": "långtidsparkerande",
    "långtidsparkerar": "långtidsparkera",
    "långtidsparkeras": "långtidsparkera",
    "långtidsparkerat": "långtidsparkera",
    "långtidsparkerats": "långtidsparkera",
    "långtidsparkerbara": "långtidsparkerbar",
    "långtidsparkerbarare": "långtidsparkerbar",
    "långtidsparkerbarares": "långtidsparkerbar",
    "långtidsparkerbaras": "långtidsparkerbar",
    "långtidsparkerbarast": "långtidsparkerbar",
    "långtidsparkerbaraste": "långtidsparkerbar",
    "långtidsparkerbarastes": "långtidsparkerbar",
    "långtidsparkerbarasts": "långtidsparkerbar",
    "långtidsparkerbare": "långtidsparkerbar",
    "långtidsparkerbares": "långtidsparkerbar",
    "långtidsparkerbarheten": "långtidsparkerbarhet",
    "långtidsparkerbarhetens": "långtidsparkerbarhet",
    "långtidsparkerbarhets": "långtidsparkerbarhet",
    "långtidsparkerbars": "långtidsparkerbar",
    "långtidsparkerbart": "långtidsparkerbar",
    "långtidsparkerbarts": "långtidsparkerbar",
    "långtidsparkeringar": "långtidsparkering",
    "långtidsparkeringarna": "långtidsparkering",
    "långtidsparkeringarnas": "långtidsparkering",
    "långtidsparkeringars": "långtidsparkering",
    "långtidsparkeringen": "långtidsparkering",
    "långtidsparkeringens": "långtidsparkering",
    "långtidsparkerings": "långtidsparkering",
    "långtidsprognosen": "långtidsprognos",
    "långtidsprognosens": "långtidsprognos",
    "långtidsprognoser": "långtidsprognos",
    "långtidsprognoserna": "långtidsprognos",
    "långtidsprognosernas": "långtidsprognos",
    "långtidsprognosers": "långtidsprognos",
    "långtidssjuka": "långtidssjuk",
    "långtidssjukare": "långtidssjuk",
    "långtidssjukares": "långtidssjuk",
    "långtidssjukas": "långtidssjuk",
    "långtidssjukast": "långtidssjuk",
    "långtidssjukaste": "långtidssjuk",
    "långtidssjukastes": "långtidssjuk",
    "långtidssjukasts": "långtidssjuk",
    "långtidssjuke": "långtidssjuk",
    "långtidssjukes": "långtidssjuk",
    "långtidssjukheten": "långtidssjukhet",
    "långtidssjukhetens": "långtidssjukhet",
    "långtidssjukhets": "långtidssjukhet",
    "långtidssjuks": "långtidssjuk",
    "långtidssjukt": "långtidssjuk",
    "långtidssjukts": "långtidssjuk",
    "långtidsskydden": "långtidsskydd",
    "långtidsskyddens": "långtidsskydd",
    "långtidsskyddet": "långtidsskydd",
    "långtidsskyddets": "långtidsskydd",
    "långtidsskydds": "långtidsskydd",
    "långtidsvikariaten": "långtidsvikariat",
    "långtidsvikariatens": "långtidsvikariat",
    "långtidsvikariatet": "långtidsvikariat",
    "långtidsvikariatets": "långtidsvikariat",
    "långtidsvikariats": "långtidsvikariat",
    "långtradar": "långtradare",
    "långtradarchauffören": "långtradarchaufför",
    "långtradarchaufförens": "långtradarchaufför",
    "långtradarchaufförer": "långtradarchaufför",
    "långtradarchaufförerna": "långtradarchaufför",
    "långtradarchaufförernas": "långtradarchaufför",
    "långtradarchaufförers": "långtradarchaufför",
    "långtradarchaufförn": "långtradarchaufför",
    "långtradarchaufförns": "långtradarchaufför",
    "långtradarchaufförs": "långtradarchaufför",
    "långtradaren": "långtradare",
    "långtradarens": "långtradare",
    "långtradares": "långtradare",
    "långtradarmotorer": "långtradarmotor",
    "långtradarmotorerna": "långtradarmotor",
    "långtradarmotorernas": "långtradarmotor",
    "långtradarmotorers": "långtradarmotor",
    "långtradarmotorn": "långtradarmotor",
    "långtradarmotorns": "långtradarmotor",
    "långtradarmotors": "långtradarmotor",
    "långtradarna": "långtradare",
    "långtradarnas": "långtradare",
    "långtradiga": "långtradig",
    "långtradigare": "långtradig",
    "långtradigares": "långtradig",
    "långtradigas": "långtradig",
    "långtradigast": "långtradig",
    "långtradigaste": "långtradig",
    "långtradigastes": "långtradig",
    "långtradigasts": "långtradig",
    "långtradige": "långtradig",
    "långtradiges": "långtradig",
    "långtradigheten": "långtradighet",
    "långtradighetens": "långtradighet",
    "långtradighets": "långtradighet",
    "långtradigs": "långtradig",
    "långtradigt": "långtradig",
    "långtradigts": "långtradig",
    "långtrådiga": "långtrådig",
    "långtrådigare": "långtrådig",
    "långtrådigares": "långtrådig",
    "långtrådigas": "långtrådig",
    "långtrådigast": "långtrådig",
    "långtrådigaste": "långtrådig",
    "långtrådigastes": "långtrådig",
    "långtrådigasts": "långtrådig",
    "långtrådige": "långtrådig",
    "långtrådiges": "långtrådig",
    "långtrådigs": "långtrådig",
    "långtrådigt": "långtrådig",
    "långtrådigts": "långtrådig",
    "långtråkiga": "långtråkig",
    "långtråkigare": "långtråkig",
    "långtråkigares": "långtråkig",
    "långtråkigas": "långtråkig",
    "långtråkigast": "långtråkig",
    "långtråkigaste": "långtråkig",
    "långtråkigastes": "långtråkig",
    "långtråkigasts": "långtråkig",
    "långtråkige": "långtråkig",
    "långtråkiges": "långtråkig",
    "långtråkigheten": "långtråkighet",
    "långtråkighetens": "långtråkighet",
    "långtråkighets": "långtråkighet",
    "långtråkigs": "långtråkig",
    "långtråkigt": "långtråkig",
    "långtråkigts": "långtråkig",
    "långts": "lång",
    "långturen": "långtur",
    "långturens": "långtur",
    "långturer": "långtur",
    "långturerna": "långtur",
    "långturernas": "långtur",
    "långturers": "långtur",
    "långturs": "långtur",
    "långvariga": "långvarig",
    "långvarigare": "långvarig",
    "långvarigares": "långvarig",
    "långvarigas": "långvarig",
    "långvarigast": "långvarig",
    "långvarigaste": "långvarig",
    "långvarigastes": "långvarig",
    "långvarigasts": "långvarig",
    "långvarige": "långvarig",
    "långvariges": "långvarig",
    "långvarigheten": "långvarighet",
    "långvarighetens": "långvarighet",
    "långvarighets": "långvarighet",
    "långvarigs": "långvarig",
    "långvarigt": "långvarig",
    "långvarigts": "långvarig",
    "långveden": "långved",
    "långvedens": "långved",
    "långveds": "långved",
    "långvirkes": "långvirke",
    "långvirket": "långvirke",
    "långvirkets": "långvirke",
    "långväggar": "långvägg",
    "långväggarna": "långvägg",
    "långväggarnas": "långvägg",
    "långväggars": "långvägg",
    "långväggen": "långvägg",
    "långväggens": "långvägg",
    "långväggs": "långvägg",
    "långvågen": "långvåg",
    "långvågens": "långvåg",
    "långvågiga": "långvågig",
    "långvågigare": "långvågig",
    "långvågigares": "långvågig",
    "långvågigas": "långvågig",
    "långvågigast": "långvågig",
    "långvågigaste": "långvågig",
    "långvågigastes": "långvågig",
    "långvågigasts": "långvågig",
    "långvågige": "långvågig",
    "långvågiges": "långvågig",
    "långvågigs": "långvågig",
    "långvågigt": "långvågig",
    "långvågigts": "långvågig",
    "långvågor": "långvåg",
    "långvågorna": "långvåg",
    "långvågornas": "långvåg",
    "långvågors": "långvåg",
    "långvågs": "långvåg",
    "långvården": "långvård",
    "långvårdens": "långvård",
    "långvårds": "långvård",
    "långärmade": "långärmad",
    "långärmades": "långärmad",
    "långärmads": "långärmad",
    "långärmat": "långärmad",
    "långärmats": "långärmad",
    "långörade": "långörad",
    "långörades": "långörad",
    "långörads": "långörad",
    "långörat": "långörad",
    "långörats": "långörad",
    "lånorden": "lånord",
    "lånordens": "lånord",
    "lånordet": "lånord",
    "lånordets": "lånord",
    "lånords": "lånord",
    "låns": "lån",
    "lånspar": "lånspara",
    "lånsparad": "lånspara",
    "lånsparade": "lånspara",
    "lånsparades": "lånspara",
    "lånsparads": "lånspara",
    "lånsparande": "lånspara",
    "lånsparanden": "lånsparande",
    "lånsparandena": "lånsparande",
    "lånsparandenas": "lånsparande",
    "lånsparandens": "lånsparande",
    "lånsparandes": "lånsparande",
    "lånsparandet": "lånsparande",
    "lånsparandets": "lånsparande",
    "lånsparar": "lånspara",
    "lånsparas": "lånspara",
    "lånsparat": "lånspara",
    "lånsparats": "lånspara",
    "lånta": "lånt",
    "låntagar": "låntagare",
    "låntagaren": "låntagare",
    "låntagarens": "låntagare",
    "låntagares": "låntagare",
    "låntagarna": "låntagare",
    "låntagarnas": "låntagare",
    "låntas": "lånt",
    "lånte": "lånt",
    "låntes": "lånt",
    "lånts": "lånt",
    "lårar": "lår",
    "lårarna": "lår",
    "lårarnas": "lår",
    "lårars": "lår",
    "lårbenen": "lårben",
    "lårbenens": "lårben",
    "lårbenet": "lårben",
    "lårbenets": "lårben",
    "lårbens": "lårben",
    "lårbensbrotten": "lårbensbrott",
    "lårbensbrottens": "lårbensbrott",
    "lårbensbrottet": "lårbensbrott",
    "lårbensbrottets": "lårbensbrott",
    "lårbensbrotts": "lårbensbrott",
    "lårbenshalsar": "lårbenshals",
    "lårbenshalsarna": "lårbenshals",
    "lårbenshalsarnas": "lårbenshals",
    "lårbenshalsars": "lårbenshals",
    "lårbenshalsen": "lårbenshals",
    "lårbenshalsens": "lårbenshals",
    "lårdingar": "lårding",
    "lårdingarna": "lårding",
    "lårdingarnas": "lårding",
    "lårdingars": "lårding",
    "lårdingen": "lårding",
    "lårdingens": "lårding",
    "lårdings": "lårding",
    "låren": "lår",
    "lårens": "lår",
    "låret": "lår",
    "lårets": "lår",
    "lårhöga": "lårhög",
    "lårhögas": "lårhög",
    "lårhöge": "lårhög",
    "lårhöges": "lårhög",
    "lårhögs": "lårhög",
    "lårhögt": "lårhög",
    "lårhögts": "lårhög",
    "låringar": "låring",
    "låringarna": "låring",
    "låringarnas": "låring",
    "låringars": "låring",
    "låringen": "låring",
    "låringens": "låring",
    "lårings": "låring",
    "låringsvindar": "låringsvind",
    "låringsvindarna": "låringsvind",
    "låringsvindarnas": "låringsvind",
    "låringsvindars": "låringsvind",
    "låringsvinden": "låringsvind",
    "låringsvindens": "låringsvind",
    "låringsvinds": "låringsvind",
    "lårkak": "lårkaka",
    "lårkakan": "lårkaka",
    "lårkakans": "lårkaka",
    "lårkakas": "lårkaka",
    "lårkake": "lårkaka",
    "lårkakor": "lårkaka",
    "lårkakorna": "lårkaka",
    "lårkakornas": "lårkaka",
    "lårkakors": "lårkaka",
    "lårkaks": "lårkaka",
    "lårmuskeln": "lårmuskel",
    "lårmuskelns": "lårmuskel",
    "lårmuskels": "lårmuskel",
    "lårmuskler": "lårmuskel",
    "lårmusklerna": "lårmuskel",
    "lårmusklernas": "lårmuskel",
    "lårmusklers": "lårmuskel",
    "lårs": "lår",
    "lårstycken": "lårstycke",
    "lårstyckena": "lårstycke",
    "lårstyckenas": "lårstycke",
    "lårstyckens": "lårstycke",
    "lårstyckes": "lårstycke",
    "lårstycket": "lårstycke",
    "lårstyckets": "lårstycke",
    "lårstycks": "lårstycke",
    "lås": "låsa",
    "låsande": "låsa",
    "låsanden": "låsande",
    "låsandena": "låsande",
    "låsandenas": "låsande",
    "låsandens": "låsande",
    "låsandes": "låsande",
    "låsandet": "låsande",
    "låsandets": "låsande",
    "låsanordningar": "låsanordning",
    "låsanordningarna": "låsanordning",
    "låsanordningarnas": "låsanordning",
    "låsanordningars": "låsanordning",
    "låsanordningen": "låsanordning",
    "låsanordningens": "låsanordning",
    "låsanordnings": "låsanordning",
    "låsar": "lås",
    "låsarna": "lås",
    "låsarnas": "lås",
    "låsars": "lås",
    "låsas": "låsa",
    "låsbara": "låsbar",
    "låsbarare": "låsbar",
    "låsbarares": "låsbar",
    "låsbaras": "låsbar",
    "låsbarast": "låsbar",
    "låsbaraste": "låsbar",
    "låsbarastes": "låsbar",
    "låsbarasts": "låsbar",
    "låsbare": "låsbar",
    "låsbares": "låsbar",
    "låsbarheten": "låsbarhet",
    "låsbarhetens": "låsbarhet",
    "låsbarhets": "låsbarhet",
    "låsbars": "låsbar",
    "låsbart": "låsbar",
    "låsbarts": "låsbar",
    "låsbeslagen": "låsbeslag",
    "låsbeslagens": "låsbeslag",
    "låsbeslaget": "låsbeslag",
    "låsbeslagets": "låsbeslag",
    "låsbeslags": "låsbeslag",
    "låsbrick": "låsbricka",
    "låsbrickan": "låsbricka",
    "låsbrickans": "låsbricka",
    "låsbrickas": "låsbricka",
    "låsbricke": "låsbricka",
    "låsbrickor": "låsbricka",
    "låsbrickorna": "låsbricka",
    "låsbrickornas": "låsbricka",
    "låsbrickors": "låsbricka",
    "låsbricks": "låsbricka",
    "låsen": "lås",
    "låsens": "lås",
    "låser": "låsa",
    "låses": "låsa",
    "låset": "lås",
    "låsets": "lås",
    "låsfirman": "låsfirma",
    "låsfirmans": "låsfirma",
    "låsfirmas": "låsfirma",
    "låsfirme": "låsfirma",
    "låsfirmor": "låsfirma",
    "låsfirmorna": "låsfirma",
    "låsfirmornas": "låsfirma",
    "låsfirmors": "låsfirma",
    "låshyls": "låshylsa",
    "låshylsan": "låshylsa",
    "låshylsans": "låshylsa",
    "låshylsas": "låshylsa",
    "låshylse": "låshylsa",
    "låshylsor": "låshylsa",
    "låshylsorna": "låshylsa",
    "låshylsornas": "låshylsa",
    "låshylsors": "låshylsa",
    "låskolvar": "låskolv",
    "låskolvarna": "låskolv",
    "låskolvarnas": "låskolv",
    "låskolvars": "låskolv",
    "låskolven": "låskolv",
    "låskolvens": "låskolv",
    "låskolvs": "låskolv",
    "låsmuttern": "låsmutter",
    "låsmutterns": "låsmutter",
    "låsmutters": "låsmutter",
    "låsmuttrar": "låsmutter",
    "låsmuttrarna": "låsmutter",
    "låsmuttrarnas": "låsmutter",
    "låsmuttrars": "låsmutter",
    "låsningar": "låsning",
    "låsningarna": "låsning",
    "låsningarnas": "låsning",
    "låsningars": "låsning",
    "låsningen": "låsning",
    "låsningens": "låsning",
    "låsnings": "låsning",
    "låsningsfria": "låsningsfri",
    "låsningsfriare": "låsningsfri",
    "låsningsfriares": "låsningsfri",
    "låsningsfrias": "låsningsfri",
    "låsningsfriast": "låsningsfri",
    "låsningsfriaste": "låsningsfri",
    "låsningsfriastes": "låsningsfri",
    "låsningsfriasts": "låsningsfri",
    "låsningsfrie": "låsningsfri",
    "låsningsfries": "låsningsfri",
    "låsningsfris": "låsningsfri",
    "låsningsfritt": "låsningsfri",
    "låsningsfritts": "låsningsfri",
    "låsoljan": "låsolja",
    "låsoljans": "låsolja",
    "låsoljas": "låsolja",
    "låsolje": "låsolja",
    "låsoljor": "låsolja",
    "låsoljorna": "låsolja",
    "låsoljornas": "låsolja",
    "låsoljors": "låsolja",
    "låss": "låssa",
    "låssad": "låssa",
    "låssade": "låssa",
    "låssades": "låssas",
    "låssads": "låssa",
    "låssande": "låssa",
    "låssanden": "låssande",
    "låssandena": "låssande",
    "låssandenas": "låssande",
    "låssandens": "låssande",
    "låssandes": "låssande",
    "låssandet": "låssande",
    "låssandets": "låssande",
    "låssar": "låssa",
    "låssas": "låssa",
    "låssaskak": "låssaskaka",
    "låssaskakan": "låssaskaka",
    "låssaskakans": "låssaskaka",
    "låssaskakas": "låssaskaka",
    "låssaskake": "låssaskaka",
    "låssaskakor": "låssaskaka",
    "låssaskakorna": "låssaskaka",
    "låssaskakornas": "låssaskaka",
    "låssaskakors": "låssaskaka",
    "låssaskaks": "låssaskaka",
    "låssaslekar": "låssaslek",
    "låssaslekarna": "låssaslek",
    "låssaslekarnas": "låssaslek",
    "låssaslekars": "låssaslek",
    "låssasleken": "låssaslek",
    "låssaslekens": "låssaslek",
    "låssasleks": "låssaslek",
    "låssasvärldar": "låssasvärld",
    "låssasvärldarna": "låssasvärld",
    "låssasvärldarnas": "låssasvärld",
    "låssasvärldars": "låssasvärld",
    "låssasvärlden": "låssasvärld",
    "låssasvärldens": "låssasvärld",
    "låssasvärlds": "låssasvärld",
    "låssat": "låssa",
    "låssats": "låssas",
    "låsskruvar": "låsskruv",
    "låsskruvarna": "låsskruv",
    "låsskruvarnas": "låsskruv",
    "låsskruvars": "låsskruv",
    "låsskruven": "låsskruv",
    "låsskruvens": "låsskruv",
    "låsskruvs": "låsskruv",
    "låssmeden": "låssmed",
    "låssmedens": "låssmed",
    "låssmeder": "låssmed",
    "låssmederna": "låssmed",
    "låssmedernas": "låssmed",
    "låssmeders": "låssmed",
    "låssmeds": "låssmed",
    "låssprintar": "låssprint",
    "låssprintarna": "låssprint",
    "låssprintarnas": "låssprint",
    "låssprintars": "låssprint",
    "låssprinten": "låssprint",
    "låssprintens": "låssprint",
    "låssprints": "låssprint",
    "låst": "låsa",
    "låsta": "låsa",
    "låstas": "låsa",
    "låste": "låsa",
    "låstes": "låsa",
    "låsts": "låsa",
    "låsvreden": "låsvred",
    "låsvredens": "låsvred",
    "låsvredet": "låsvred",
    "låsvredets": "låsvred",
    "låsvreds": "låsvred",
    "låt": "låta",
    "låtande": "låta",
    "låtanden": "låtande",
    "låtandena": "låtande",
    "låtandenas": "låtande",
    "låtandens": "låtande",
    "låtandes": "låtande",
    "låtandet": "låtande",
    "låtandets": "låtande",
    "låtar": "låt",
    "låtarna": "låt",
    "låtarnas": "låt",
    "låtars": "låt",
    "låtas": "låta",
    "låte": "låta",
    "låten": "låt",
    "låtens": "låt",
    "låter": "låta",
    "låtes": "låta",
    "låtgåpolitiken": "låtgåpolitik",
    "låtgåpolitikens": "låtgåpolitik",
    "låtgåpolitiks": "låtgåpolitik",
    "låtgåsystemen": "låtgåsystem",
    "låtgåsystemens": "låtgåsystem",
    "låtgåsystemet": "låtgåsystem",
    "låtgåsystemets": "låtgåsystem",
    "låtgåsystems": "låtgåsystem",
    "låtit": "låta",
    "låtits": "låta",
    "låtmässiga": "låtmässig",
    "låtmässigare": "låtmässig",
    "låtmässigares": "låtmässig",
    "låtmässigas": "låtmässig",
    "låtmässigast": "låtmässig",
    "låtmässigaste": "låtmässig",
    "låtmässigastes": "låtmässig",
    "låtmässigasts": "låtmässig",
    "låtmässige": "låtmässig",
    "låtmässiges": "låtmässig",
    "låtmässigs": "låtmässig",
    "låtmässigt": "låtmässig",
    "låtmässigts": "låtmässig",
    "låts": "låtsa",
    "låtsad": "låtsa",
    "låtsade": "låtsa",
    "låtsades": "låtsas",
    "låtsads": "låtsa",
    "låtsande": "låtsa",
    "låtsanden": "låtsande",
    "låtsandena": "låtsande",
    "låtsandenas": "låtsande",
    "låtsandens": "låtsande",
    "låtsandes": "låtsande",
    "låtsandet": "låtsande",
    "låtsandets": "låtsande",
    "låtsar": "låtsa",
    "låtsas": "låtsa",
    "låtsasbrottningar": "låtsasbrottning",
    "låtsasbrottningarna": "låtsasbrottning",
    "låtsasbrottningarnas": "låtsasbrottning",
    "låtsasbrottningars": "låtsasbrottning",
    "låtsasbrottningen": "låtsasbrottning",
    "låtsasbrottningens": "låtsasbrottning",
    "låtsasbrottnings": "låtsasbrottning",
    "låtsascigaretten": "låtsascigarett",
    "låtsascigarettens": "låtsascigarett",
    "låtsascigaretter": "låtsascigarett",
    "låtsascigaretterna": "låtsascigarett",
    "låtsascigaretternas": "låtsascigarett",
    "låtsascigaretters": "låtsascigarett",
    "låtsascigaretts": "låtsascigarett",
    "låtsasdemokratien": "låtsasdemokrati",
    "låtsasdemokratiens": "låtsasdemokrati",
    "låtsasdemokratin": "låtsasdemokrati",
    "låtsasdemokratins": "låtsasdemokrati",
    "låtsasdemokratis": "låtsasdemokrati",
    "låtsasfiguren": "låtsasfigur",
    "låtsasfigurens": "låtsasfigur",
    "låtsasfigurer": "låtsasfigur",
    "låtsasfigurerna": "låtsasfigur",
    "låtsasfigurernas": "låtsasfigur",
    "låtsasfigurers": "låtsasfigur",
    "låtsasfigurs": "låtsasfigur",
    "låtsaskak": "låtsaskaka",
    "låtsaskakan": "låtsaskaka",
    "låtsaskakans": "låtsaskaka",
    "låtsaskakas": "låtsaskaka",
    "låtsaskake": "låtsaskaka",
    "låtsaskakor": "låtsaskaka",
    "låtsaskakorna": "låtsaskaka",
    "låtsaskakornas": "låtsaskaka",
    "låtsaskakors": "låtsaskaka",
    "låtsaskaks": "låtsaskaka",
    "låtsaskamraten": "låtsaskamrat",
    "låtsaskamratens": "låtsaskamrat",
    "låtsaskamrater": "låtsaskamrat",
    "låtsaskamraterna": "låtsaskamrat",
    "låtsaskamraternas": "låtsaskamrat",
    "låtsaskamraters": "låtsaskamrat",
    "låtsaskamrats": "låtsaskamrat",
    "låtsaslandet": "låtsasland",
    "låtsaslandets": "låtsasland",
    "låtsaslands": "låtsasland",
    "låtsaslekar": "låtsaslek",
    "låtsaslekarna": "låtsaslek",
    "låtsaslekarnas": "låtsaslek",
    "låtsaslekars": "låtsaslek",
    "låtsasleken": "låtsaslek",
    "låtsaslekens": "låtsaslek",
    "låtsasleks": "låtsaslek",
    "låtsasländer": "låtsasland",
    "låtsasländerna": "låtsasland",
    "låtsasländernas": "låtsasland",
    "låtsasländers": "låtsasland",
    "låtsasvärldar": "låtsasvärld",
    "låtsasvärldarna": "låtsasvärld",
    "låtsasvärldarnas": "låtsasvärld",
    "låtsasvärldars": "låtsasvärld",
    "låtsasvärlden": "låtsasvärld",
    "låtsasvärldens": "låtsasvärld",
    "låtsasvärlds": "låtsasvärld",
    "låtsat": "låtsa",
    "låtsats": "låtsas",
    "låtstölden": "låtstöld",
    "låtstöldens": "låtstöld",
    "låtstölder": "låtstöld",
    "låtstölderna": "låtstöld",
    "låtstöldernas": "låtstöld",
    "låtstölders": "låtstöld",
    "låtstölds": "låtstöld",
    "læstadianens": "læstadian",
    "læstadianerna": "læstadian",
    "læstadianers": "læstadian",
    "læstadianismens": "læstadianism",
    "læstadianismerna": "læstadianism",
    "læstadianismers": "læstadianism",
    "læstadians": "læstadian",
    "löd": "lyda",
    "lödad": "löda",
    "lödade": "löda",
    "lödades": "löda",
    "lödads": "löda",
    "lödande": "löda",
    "lödanden": "lödande",
    "lödandena": "lödande",
    "lödandenas": "lödande",
    "lödandens": "lödande",
    "lödandes": "lödande",
    "lödandet": "lödande",
    "lödandets": "lödande",
    "lödar": "löda",
    "lödas": "löda",
    "lödat": "löda",
    "lödats": "löda",
    "lödd": "löda",
    "lödda": "löda",
    "löddas": "löda",
    "lödde": "löda",
    "lödder": "löddra",
    "lödders": "lödder",
    "löddes": "löda",
    "löddr": "löddra",
    "löddrade": "löddra",
    "löddrades": "löddra",
    "löddran": "löddra",
    "löddrande": "löddra",
    "löddranden": "löddrande",
    "löddrandena": "löddrande",
    "löddrandenas": "löddrande",
    "löddrandens": "löddrande",
    "löddrandes": "löddrande",
    "löddrandet": "löddrande",
    "löddrandets": "löddrande",
    "löddrans": "löddra",
    "löddrar": "löddra",
    "löddras": "löddra",
    "löddrat": "löddra",
    "löddrats": "löddra",
    "löddre": "löddra",
    "löddret": "lödder",
    "löddrets": "lödder",
    "löddriga": "löddrig",
    "löddrigare": "löddrig",
    "löddrigares": "löddrig",
    "löddrigas": "löddrig",
    "löddrigast": "löddrig",
    "löddrigaste": "löddrig",
    "löddrigastes": "löddrig",
    "löddrigasts": "löddrig",
    "löddrige": "löddrig",
    "löddriges": "löddrig",
    "löddrigheten": "löddrighet",
    "löddrighetens": "löddrighet",
    "löddrighets": "löddrighet",
    "löddrigs": "löddrig",
    "löddrigt": "löddrig",
    "löddrigts": "löddrig",
    "löddror": "löddra",
    "löddrorna": "löddra",
    "löddrornas": "löddra",
    "löddrors": "löddra",
    "löddrs": "löddra",
    "lödds": "löda",
    "löde": "lyda",
    "löder": "löda",
    "lödes": "lyda",
    "lödet": "löd",
    "lödets": "löd",
    "lödfogar": "lödfog",
    "lödfogarna": "lödfog",
    "lödfogarnas": "lödfog",
    "lödfogars": "lödfog",
    "lödfogen": "lödfog",
    "lödfogens": "lödfog",
    "lödfogs": "lödfog",
    "lödiga": "lödig",
    "lödigare": "lödig",
    "lödigares": "lödig",
    "lödigas": "lödig",
    "lödigast": "lödig",
    "lödigaste": "lödig",
    "lödigastes": "lödig",
    "lödigasts": "lödig",
    "lödige": "lödig",
    "lödiges": "lödig",
    "lödigs": "lödig",
    "lödigt": "lödig",
    "lödigts": "lödig",
    "lödkolvar": "lödkolv",
    "lödkolvarna": "lödkolv",
    "lödkolvarnas": "lödkolv",
    "lödkolvars": "lödkolv",
    "lödkolven": "lödkolv",
    "lödkolvens": "lödkolv",
    "lödkolvs": "lödkolv",
    "lödmetallen": "lödmetall",
    "lödmetallens": "lödmetall",
    "lödmetaller": "lödmetall",
    "lödmetallerna": "lödmetall",
    "lödmetallernas": "lödmetall",
    "lödmetallers": "lödmetall",
    "lödmetalls": "lödmetall",
    "lödningar": "lödning",
    "lödningarna": "lödning",
    "lödningarnas": "lödning",
    "lödningars": "lödning",
    "lödningen": "lödning",
    "lödningens": "lödning",
    "lödnings": "lödning",
    "lödpenn": "lödpenna",
    "lödpennan": "lödpenna",
    "lödpennans": "lödpenna",
    "lödpennas": "lödpenna",
    "lödpenne": "lödpenna",
    "lödpennor": "lödpenna",
    "lödpennorna": "lödpenna",
    "lödpennornas": "lödpenna",
    "lödpennors": "lödpenna",
    "lödpenns": "lödpenna",
    "löds": "lyda",
    "lödverktygen": "lödverktyg",
    "lödverktygens": "lödverktyg",
    "lödverktyget": "lödverktyg",
    "lödverktygets": "lödverktyg",
    "lödverktygs": "lödverktyg",
    "löften": "löfte",
    "löftena": "löfte",
    "löftenas": "löfte",
    "löftens": "löfte",
    "löftes": "löfte",
    "löftesbrotten": "löftesbrott",
    "löftesbrottens": "löftesbrott",
    "löftesbrottet": "löftesbrott",
    "löftesbrottets": "löftesbrott",
    "löftesbrotts": "löftesbrott",
    "löftesmannen": "löftesman",
    "löftesmannens": "löftesman",
    "löftesmans": "löftesman",
    "löftesmän": "löftesman",
    "löftesmännen": "löftesman",
    "löftesmännens": "löftesman",
    "löftesmäns": "löftesman",
    "löftesrika": "löftesrik",
    "löftesrikare": "löftesrik",
    "löftesrikares": "löftesrik",
    "löftesrikas": "löftesrik",
    "löftesrikast": "löftesrik",
    "löftesrikaste": "löftesrik",
    "löftesrikastes": "löftesrik",
    "löftesrikasts": "löftesrik",
    "löftesrike": "löftesrik",
    "löftesrikes": "löftesrik",
    "löftesrikheten": "löftesrikhet",
    "löftesrikhetens": "löftesrikhet",
    "löftesrikhets": "löftesrikhet",
    "löftesriks": "löftesrik",
    "löftesrikt": "löftesrik",
    "löftesrikts": "löftesrik",
    "löftesskriften": "löftesskrift",
    "löftesskriftens": "löftesskrift",
    "löftesskrifter": "löftesskrift",
    "löftesskrifterna": "löftesskrift",
    "löftesskrifternas": "löftesskrift",
    "löftesskrifters": "löftesskrift",
    "löftesskrifts": "löftesskrift",
    "löftet": "löfte",
    "löftets": "löfte",
    "lög": "löga",
    "lögad": "löga",
    "lögade": "löga",
    "lögades": "löga",
    "lögads": "löga",
    "lögande": "löga",
    "löganden": "lögande",
    "lögandena": "lögande",
    "lögandenas": "lögande",
    "lögandens": "lögande",
    "lögandes": "lögande",
    "lögandet": "lögande",
    "lögandets": "lögande",
    "lögar": "löga",
    "lögas": "löga",
    "lögat": "löga",
    "lögats": "löga",
    "lögnaktiga": "lögnaktig",
    "lögnaktigare": "lögnaktig",
    "lögnaktigares": "lögnaktig",
    "lögnaktigas": "lögnaktig",
    "lögnaktigast": "lögnaktig",
    "lögnaktigaste": "lögnaktig",
    "lögnaktigastes": "lögnaktig",
    "lögnaktigasts": "lögnaktig",
    "lögnaktige": "lögnaktig",
    "lögnaktiges": "lögnaktig",
    "lögnaktigheten": "lögnaktighet",
    "lögnaktighetens": "lögnaktighet",
    "lögnaktigheter": "lögnaktighet",
    "lögnaktigheterna": "lögnaktighet",
    "lögnaktigheternas": "lögnaktighet",
    "lögnaktigheters": "lögnaktighet",
    "lögnaktighets": "lögnaktighet",
    "lögnaktigs": "lögnaktig",
    "lögnaktigt": "lögnaktig",
    "lögnaktigts": "lögnaktig",
    "lögnar": "lögnare",
    "lögnaren": "lögnare",
    "lögnarens": "lögnare",
    "lögnares": "lögnare",
    "lögnarna": "lögnare",
    "lögnarnas": "lögnare",
    "lögndetektorer": "lögndetektor",
    "lögndetektorerna": "lögndetektor",
    "lögndetektorernas": "lögndetektor",
    "lögndetektorers": "lögndetektor",
    "lögndetektorn": "lögndetektor",
    "lögndetektorns": "lögndetektor",
    "lögndetektors": "lögndetektor",
    "lögnen": "lögn",
    "lögnens": "lögn",
    "lögner": "lögn",
    "lögnerna": "lögn",
    "lögnernas": "lögn",
    "lögners": "lögn",
    "lögnhalsar": "lögnhals",
    "lögnhalsarna": "lögnhals",
    "lögnhalsarnas": "lögnhals",
    "lögnhalsars": "lögnhals",
    "lögnhalsen": "lögnhals",
    "lögnhalsens": "lögnhals",
    "lögnkampanjen": "lögnkampanj",
    "lögnkampanjens": "lögnkampanj",
    "lögnkampanjer": "lögnkampanj",
    "lögnkampanjerna": "lögnkampanj",
    "lögnkampanjernas": "lögnkampanj",
    "lögnkampanjers": "lögnkampanj",
    "lögnkampanjs": "lögnkampanj",
    "lögns": "lögn",
    "löj": "löja",
    "löjan": "löja",
    "löjans": "löja",
    "löjas": "löja",
    "löje": "löja",
    "löjen": "löje",
    "löjena": "löje",
    "löjenas": "löje",
    "löjens": "löje",
    "löjes": "löje",
    "löjet": "löje",
    "löjets": "löje",
    "löjliga": "löjlig",
    "löjligare": "löjlig",
    "löjligares": "löjlig",
    "löjligas": "löjlig",
    "löjligast": "löjlig",
    "löjligaste": "löjlig",
    "löjligastes": "löjlig",
    "löjligasts": "löjlig",
    "löjlige": "löjlig",
    "löjliges": "löjlig",
    "löjligheten": "löjlighet",
    "löjlighetens": "löjlighet",
    "löjligheter": "löjlighet",
    "löjligheterna": "löjlighet",
    "löjligheternas": "löjlighet",
    "löjligheters": "löjlighet",
    "löjlighets": "löjlighet",
    "löjligs": "löjlig",
    "löjligt": "löjlig",
    "löjligts": "löjlig",
    "löjor": "löja",
    "löjorna": "löja",
    "löjornas": "löja",
    "löjors": "löja",
    "löjrommen": "löjrom",
    "löjrommens": "löjrom",
    "löjroms": "löjrom",
    "löjs": "löja",
    "löjtnanten": "löjtnant",
    "löjtnantens": "löjtnant",
    "löjtnanter": "löjtnant",
    "löjtnanterna": "löjtnant",
    "löjtnanternas": "löjtnant",
    "löjtnanters": "löjtnant",
    "löjtnants": "löjtnant",
    "löjtnantshjärt": "löjtnantshjärta",
    "löjtnantshjärtan": "löjtnantshjärta",
    "löjtnantshjärtana": "löjtnantshjärta",
    "löjtnantshjärtanas": "löjtnantshjärta",
    "löjtnantshjärtans": "löjtnantshjärta",
    "löjtnantshjärtas": "löjtnantshjärta",
    "löjtnantshjärtat": "löjtnantshjärta",
    "löjtnantshjärtats": "löjtnantshjärta",
    "löjtnantshjärts": "löjtnantshjärta",
    "lökar": "lök",
    "lökarna": "lök",
    "lökarnas": "lök",
    "lökars": "lök",
    "löken": "lök",
    "lökens": "lök",
    "lökfjällen": "lökfjäll",
    "lökfjällens": "lökfjäll",
    "lökfjället": "lökfjäll",
    "lökfjällets": "lökfjäll",
    "lökfjälls": "lökfjäll",
    "lökformiga": "lökformig",
    "lökformigare": "lökformig",
    "lökformigares": "lökformig",
    "lökformigas": "lökformig",
    "lökformigast": "lökformig",
    "lökformigaste": "lökformig",
    "lökformigastes": "lökformig",
    "lökformigasts": "lökformig",
    "lökformige": "lökformig",
    "lökformiges": "lökformig",
    "lökformigs": "lökformig",
    "lökformigt": "lökformig",
    "lökformigts": "lökformig",
    "lökknoppar": "lökknopp",
    "lökknopparna": "lökknopp",
    "lökknopparnas": "lökknopp",
    "lökknoppars": "lökknopp",
    "lökknoppen": "lökknopp",
    "lökknoppens": "lökknopp",
    "lökknopps": "lökknopp",
    "lökkupolen": "lökkupol",
    "lökkupolens": "lökkupol",
    "lökkupoler": "lökkupol",
    "lökkupolerna": "lökkupol",
    "lökkupolernas": "lökkupol",
    "lökkupolers": "lökkupol",
    "lökkupols": "lökkupol",
    "löks": "lök",
    "löksillar": "löksill",
    "löksillarna": "löksill",
    "löksillarnas": "löksill",
    "löksillars": "löksill",
    "löksillen": "löksill",
    "löksillens": "löksill",
    "löksills": "löksill",
    "lökstammar": "lökstam",
    "lökstammarna": "lökstam",
    "lökstammarnas": "lökstam",
    "lökstammars": "lökstam",
    "lökstammen": "lökstam",
    "lökstammens": "lökstam",
    "lökstams": "lökstam",
    "lökväxten": "lökväxt",
    "lökväxtens": "lökväxt",
    "lökväxter": "lökväxt",
    "lökväxterna": "lökväxt",
    "lökväxternas": "lökväxt",
    "lökväxters": "lökväxt",
    "lökväxts": "lökväxt",
    "lömska": "lömsk",
    "lömskare": "lömsk",
    "lömskares": "lömsk",
    "lömskas": "lömsk",
    "lömskast": "lömsk",
    "lömskaste": "lömsk",
    "lömskastes": "lömsk",
    "lömskasts": "lömsk",
    "lömske": "lömsk",
    "lömskes": "lömsk",
    "lömskheten": "lömskhet",
    "lömskhetens": "lömskhet",
    "lömskhets": "lömskhet",
    "lömsknade": "lömskna",
    "lömsknades": "lömskna",
    "lömsknande": "lömskna",
    "lömsknanden": "lömsknande",
    "lömsknandena": "lömsknande",
    "lömsknandenas": "lömsknande",
    "lömsknandens": "lömsknande",
    "lömsknandes": "lömsknande",
    "lömsknandet": "lömsknande",
    "lömsknandets": "lömsknande",
    "lömsknar": "lömskna",
    "lömsknas": "lömskna",
    "lömsknat": "lömskna",
    "lömsknats": "lömskna",
    "lömsks": "lömsk",
    "lömskt": "lömsk",
    "lömskts": "lömsk",
    "lön": "löna",
    "lönad": "löna",
    "lönade": "löna",
    "lönades": "löna",
    "lönads": "löna",
    "lönande": "löna",
    "lönanden": "lönande",
    "lönandena": "lönande",
    "lönandenas": "lönande",
    "lönandens": "lönande",
    "lönandes": "lönande",
    "lönandet": "lönande",
    "lönandets": "lönande",
    "lönar": "löna",
    "lönas": "löna",
    "lönat": "löna",
    "lönats": "löna",
    "löne": "lön",
    "löneanspråken": "löneanspråk",
    "löneanspråkens": "löneanspråk",
    "löneanspråket": "löneanspråk",
    "löneanspråkets": "löneanspråk",
    "löneanspråks": "löneanspråk",
    "lönearbetar": "lönearbetare",
    "lönearbetaren": "lönearbetare",
    "lönearbetarens": "lönearbetare",
    "lönearbetares": "lönearbetare",
    "lönearbetarna": "lönearbetare",
    "lönearbetarnas": "lönearbetare",
    "löneavdragen": "löneavdrag",
    "löneavdragens": "löneavdrag",
    "löneavdraget": "löneavdrag",
    "löneavdragets": "löneavdrag",
    "löneavdrags": "löneavdrag",
    "löneavtalen": "löneavtal",
    "löneavtalens": "löneavtal",
    "löneavtalet": "löneavtal",
    "löneavtalets": "löneavtal",
    "löneavtals": "löneavtal",
    "lönebeskeden": "lönebesked",
    "lönebeskedens": "lönebesked",
    "lönebeskedet": "lönebesked",
    "lönebeskedets": "lönebesked",
    "lönebeskeds": "lönebesked",
    "lönebidragen": "lönebidrag",
    "lönebidragens": "lönebidrag",
    "lönebidraget": "lönebidrag",
    "lönebidragets": "lönebidrag",
    "lönebidrags": "lönebidrag",
    "lönecheckar": "lönecheck",
    "lönecheckarna": "lönecheck",
    "lönecheckarnas": "lönecheck",
    "lönecheckars": "lönecheck",
    "lönechecken": "lönecheck",
    "lönecheckens": "lönecheck",
    "lönechecker": "lönecheck",
    "lönecheckerna": "lönecheck",
    "lönecheckernas": "lönecheck",
    "lönecheckers": "lönecheck",
    "lönechecks": "lönecheck",
    "lönedumpningar": "lönedumpning",
    "lönedumpningarna": "lönedumpning",
    "lönedumpningarnas": "lönedumpning",
    "lönedumpningars": "lönedumpning",
    "lönedumpningen": "lönedumpning",
    "lönedumpningens": "lönedumpning",
    "lönedumpnings": "lönedumpning",
    "lönefilen": "lönefil",
    "lönefilens": "lönefil",
    "lönefiler": "lönefil",
    "lönefilerna": "lönefil",
    "lönefilernas": "lönefil",
    "lönefilers": "lönefil",
    "lönefils": "lönefil",
    "löneförhandlingar": "löneförhandling",
    "löneförhandlingarna": "löneförhandling",
    "löneförhandlingarnas": "löneförhandling",
    "löneförhandlingars": "löneförhandling",
    "löneförhandlingen": "löneförhandling",
    "löneförhandlingens": "löneförhandling",
    "löneförhandlings": "löneförhandling",
    "löneförhöjningar": "löneförhöjning",
    "löneförhöjningarna": "löneförhöjning",
    "löneförhöjningarnas": "löneförhöjning",
    "löneförhöjningars": "löneförhöjning",
    "löneförhöjningen": "löneförhöjning",
    "löneförhöjningens": "löneförhöjning",
    "löneförhöjnings": "löneförhöjning",
    "löneförmånen": "löneförmån",
    "löneförmånens": "löneförmån",
    "löneförmåner": "löneförmån",
    "löneförmånerna": "löneförmån",
    "löneförmånernas": "löneförmån",
    "löneförmåners": "löneförmån",
    "löneförmåns": "löneförmån",
    "lönegarantien": "lönegaranti",
    "lönegarantiens": "lönegaranti",
    "lönegarantier": "lönegaranti",
    "lönegarantierna": "lönegaranti",
    "lönegarantiernas": "lönegaranti",
    "lönegarantiers": "lönegaranti",
    "lönegarantin": "lönegaranti",
    "lönegarantins": "lönegaranti",
    "lönegarantis": "lönegaranti",
    "löneglidningar": "löneglidning",
    "löneglidningarna": "löneglidning",
    "löneglidningarnas": "löneglidning",
    "löneglidningars": "löneglidning",
    "löneglidningen": "löneglidning",
    "löneglidningens": "löneglidning",
    "löneglidnings": "löneglidning",
    "lönegraden": "lönegrad",
    "lönegradens": "lönegrad",
    "lönegrader": "lönegrad",
    "lönegraderna": "lönegrad",
    "lönegradernas": "lönegrad",
    "lönegraders": "lönegrad",
    "lönegrads": "lönegrad",
    "lönehöjningar": "lönehöjning",
    "lönehöjningarna": "lönehöjning",
    "lönehöjningarnas": "lönehöjning",
    "lönehöjningars": "lönehöjning",
    "lönehöjningen": "lönehöjning",
    "lönehöjningens": "lönehöjning",
    "lönehöjnings": "lönehöjning",
    "löneklassen": "löneklass",
    "löneklassens": "löneklass",
    "löneklasser": "löneklass",
    "löneklasserna": "löneklass",
    "löneklassernas": "löneklass",
    "löneklassers": "löneklass",
    "löneklippen": "löneklipp",
    "löneklippens": "löneklipp",
    "löneklippet": "löneklipp",
    "löneklippets": "löneklipp",
    "löneklipps": "löneklipp",
    "lönekostnaden": "lönekostnad",
    "lönekostnadens": "lönekostnad",
    "lönekostnader": "lönekostnad",
    "lönekostnaderna": "lönekostnad",
    "lönekostnadernas": "lönekostnad",
    "lönekostnaders": "lönekostnad",
    "lönekostnads": "lönekostnad",
    "lönekuverten": "lönekuvert",
    "lönekuvertens": "lönekuvert",
    "lönekuvertet": "lönekuvert",
    "lönekuvertets": "lönekuvert",
    "lönekuverts": "lönekuvert",
    "lönelyften": "lönelyft",
    "lönelyftens": "lönelyft",
    "lönelyftet": "lönelyft",
    "lönelyftets": "lönelyft",
    "lönelyfts": "lönelyft",
    "lönelägen": "löneläge",
    "lönelägena": "löneläge",
    "lönelägenas": "löneläge",
    "lönelägens": "löneläge",
    "löneläges": "löneläge",
    "löneläget": "löneläge",
    "lönelägets": "löneläge",
    "lönemässiga": "lönemässig",
    "lönemässigare": "lönemässig",
    "lönemässigares": "lönemässig",
    "lönemässigas": "lönemässig",
    "lönemässigast": "lönemässig",
    "lönemässigaste": "lönemässig",
    "lönemässigastes": "lönemässig",
    "lönemässigasts": "lönemässig",
    "lönemässige": "lönemässig",
    "lönemässiges": "lönemässig",
    "lönemässigs": "lönemässig",
    "lönemässigt": "lönemässig",
    "lönemässigts": "lönemässig",
    "lönen": "lön",
    "lönenivåer": "lönenivå",
    "lönenivåerna": "lönenivå",
    "lönenivåernas": "lönenivå",
    "lönenivåers": "lönenivå",
    "lönenivån": "lönenivå",
    "lönenivåns": "lönenivå",
    "lönenivås": "lönenivå",
    "lönens": "lön",
    "löneplane": "löneplan",
    "löneplanen": "löneplan",
    "löneplanens": "löneplan",
    "löneplaner": "löneplan",
    "löneplanerna": "löneplan",
    "löneplanernas": "löneplan",
    "löneplaners": "löneplan",
    "löneplans": "löneplan",
    "lönepolitiken": "lönepolitik",
    "lönepolitikens": "lönepolitik",
    "lönepolitiks": "lönepolitik",
    "lönepolitiska": "lönepolitisk",
    "lönepolitiskas": "lönepolitisk",
    "lönepolitiske": "lönepolitisk",
    "lönepolitiskes": "lönepolitisk",
    "lönepolitisks": "lönepolitisk",
    "lönepolitiskt": "lönepolitisk",
    "lönepolitiskts": "lönepolitisk",
    "lönepåslagen": "lönepåslag",
    "lönepåslagens": "lönepåslag",
    "lönepåslaget": "lönepåslag",
    "lönepåslagets": "lönepåslag",
    "lönepåslags": "lönepåslag",
    "löner": "lön",
    "lönerna": "lön",
    "lönernas": "lön",
    "löners": "lön",
    "lönerutinen": "lönerutin",
    "lönerutinens": "lönerutin",
    "lönerutiner": "lönerutin",
    "lönerutinerna": "lönerutin",
    "lönerutinernas": "lönerutin",
    "lönerutiners": "lönerutin",
    "lönerutins": "lönerutin",
    "lönerättvisan": "lönerättvisa",
    "lönerättvisans": "lönerättvisa",
    "lönerättvisas": "lönerättvisa",
    "lönerörelsen": "lönerörelse",
    "lönerörelsens": "lönerörelse",
    "lönerörelser": "lönerörelse",
    "lönerörelserna": "lönerörelse",
    "lönerörelsernas": "lönerörelse",
    "lönerörelsers": "lönerörelse",
    "lönerörelses": "lönerörelse",
    "löneslavar": "löneslav",
    "löneslavarna": "löneslav",
    "löneslavarnas": "löneslav",
    "löneslavars": "löneslav",
    "löneslaven": "löneslav",
    "löneslavens": "löneslav",
    "löneslavs": "löneslav",
    "lönestoppen": "lönestopp",
    "lönestoppens": "lönestopp",
    "lönestoppet": "lönestopp",
    "lönestoppets": "lönestopp",
    "lönestopps": "lönestopp",
    "lönesystemen": "lönesystem",
    "lönesystemens": "lönesystem",
    "lönesystemet": "lönesystem",
    "lönesystemets": "lönesystem",
    "lönesystems": "lönesystem",
    "lönesättningar": "lönesättning",
    "lönesättningarna": "lönesättning",
    "lönesättningarnas": "lönesättning",
    "lönesättningars": "lönesättning",
    "lönesättningen": "lönesättning",
    "lönesättningens": "lönesättning",
    "lönesättnings": "lönesättning",
    "lönetaken": "lönetak",
    "lönetakens": "lönetak",
    "lönetaket": "lönetak",
    "lönetakets": "lönetak",
    "lönetaks": "lönetak",
    "lönetilläggen": "lönetillägg",
    "lönetilläggens": "lönetillägg",
    "lönetillägget": "lönetillägg",
    "lönetilläggets": "lönetillägg",
    "lönetilläggs": "lönetillägg",
    "löneuppgiften": "löneuppgift",
    "löneuppgiftens": "löneuppgift",
    "löneuppgifter": "löneuppgift",
    "löneuppgifterna": "löneuppgift",
    "löneuppgifternas": "löneuppgift",
    "löneuppgifters": "löneuppgift",
    "löneuppgifts": "löneuppgift",
    "löneutvecklingar": "löneutveckling",
    "löneutvecklingarna": "löneutveckling",
    "löneutvecklingarnas": "löneutveckling",
    "löneutvecklingars": "löneutveckling",
    "löneutvecklingen": "löneutveckling",
    "löneutvecklingens": "löneutveckling",
    "löneutvecklings": "löneutveckling",
    "löneökningar": "löneökning",
    "löneökningarna": "löneökning",
    "löneökningarnas": "löneökning",
    "löneökningars": "löneökning",
    "löneökningen": "löneökning",
    "löneökningens": "löneökning",
    "löneöknings": "löneökning",
    "löningar": "löning",
    "löningarna": "löning",
    "löningarnas": "löning",
    "löningars": "löning",
    "löningen": "löning",
    "löningens": "löning",
    "lönings": "löning",
    "lönlösa": "lönlös",
    "lönlösare": "lönlös",
    "lönlösares": "lönlös",
    "lönlösas": "lönlös",
    "lönlösast": "lönlös",
    "lönlösaste": "lönlös",
    "lönlösastes": "lönlös",
    "lönlösasts": "lönlös",
    "lönlöse": "lönlös",
    "lönlöses": "lönlös",
    "lönlösheten": "lönlöshet",
    "lönlöshetens": "lönlöshet",
    "lönlöshets": "lönlöshet",
    "lönlöst": "lönlös",
    "lönlösts": "lönlös",
    "lönnar": "lönn",
    "lönnarna": "lönn",
    "lönnarnas": "lönn",
    "lönnars": "lönn",
    "lönnbränningar": "lönnbränning",
    "lönnbränningarna": "lönnbränning",
    "lönnbränningarnas": "lönnbränning",
    "lönnbränningars": "lönnbränning",
    "lönnbränningen": "lönnbränning",
    "lönnbränningens": "lönnbränning",
    "lönnbrännings": "lönnbränning",
    "lönnen": "lönn",
    "lönnens": "lönn",
    "lönnfacken": "lönnfack",
    "lönnfackens": "lönnfack",
    "lönnfacket": "lönnfack",
    "lönnfackets": "lönnfack",
    "lönnfacks": "lönnfack",
    "lönnfeta": "lönnfet",
    "lönnfetare": "lönnfet",
    "lönnfetares": "lönnfet",
    "lönnfetas": "lönnfet",
    "lönnfetast": "lönnfet",
    "lönnfetaste": "lönnfet",
    "lönnfetastes": "lönnfet",
    "lönnfetasts": "lönnfet",
    "lönnfete": "lönnfet",
    "lönnfetes": "lönnfet",
    "lönnfets": "lönnfet",
    "lönnfett": "lönnfet",
    "lönnfetts": "lönnfet",
    "lönnkrogar": "lönnkrog",
    "lönnkrogarna": "lönnkrog",
    "lönnkrogarnas": "lönnkrog",
    "lönnkrogars": "lönnkrog",
    "lönnkrogen": "lönnkrog",
    "lönnkrogens": "lönnkrog",
    "lönnkrogs": "lönnkrog",
    "lönnliga": "lönnlig",
    "lönnligare": "lönnlig",
    "lönnligares": "lönnlig",
    "lönnligas": "lönnlig",
    "lönnligast": "lönnlig",
    "lönnligaste": "lönnlig",
    "lönnligastes": "lönnlig",
    "lönnligasts": "lönnlig",
    "lönnlige": "lönnlig",
    "lönnliges": "lönnlig",
    "lönnligheten": "lönnlighet",
    "lönnlighetens": "lönnlighet",
    "lönnlighets": "lönnlighet",
    "lönnligs": "lönnlig",
    "lönnligt": "lönnlig",
    "lönnligts": "lönnlig",
    "lönnmorden": "lönnmord",
    "lönnmordens": "lönnmord",
    "lönnmordet": "lönnmord",
    "lönnmordets": "lönnmord",
    "lönnmords": "lönnmord",
    "lönnmörd": "lönnmörda",
    "lönnmördad": "lönnmörda",
    "lönnmördade": "lönnmörda",
    "lönnmördades": "lönnmörda",
    "lönnmördads": "lönnmörda",
    "lönnmördande": "lönnmörda",
    "lönnmördanden": "lönnmördande",
    "lönnmördandena": "lönnmördande",
    "lönnmördandenas": "lönnmördande",
    "lönnmördandens": "lönnmördande",
    "lönnmördandes": "lönnmördande",
    "lönnmördandet": "lönnmördande",
    "lönnmördandets": "lönnmördande",
    "lönnmördar": "lönnmörda",
    "lönnmördas": "lönnmörda",
    "lönnmördat": "lönnmörda",
    "lönnmördats": "lönnmörda",
    "lönnrun": "lönnruna",
    "lönnrunan": "lönnruna",
    "lönnrunans": "lönnruna",
    "lönnrunas": "lönnruna",
    "lönnrune": "lönnruna",
    "lönnrunor": "lönnruna",
    "lönnrunorna": "lönnruna",
    "lönnrunornas": "lönnruna",
    "lönnrunors": "lönnruna",
    "lönnruns": "lönnruna",
    "lönns": "lönn",
    "lönnskriften": "lönnskrift",
    "lönnskriftens": "lönnskrift",
    "lönnskrifts": "lönnskrift",
    "löns": "lön",
    "lönsamheten": "lönsamhet",
    "lönsamhetens": "lönsamhet",
    "lönsamheter": "lönsamhet",
    "lönsamheterna": "lönsamhet",
    "lönsamheternas": "lönsamhet",
    "lönsamheters": "lönsamhet",
    "lönsamhets": "lönsamhet",
    "lönsamma": "lönsam",
    "lönsammare": "lönsam",
    "lönsammares": "lönsam",
    "lönsammas": "lönsam",
    "lönsammast": "lönsam",
    "lönsammaste": "lönsam",
    "lönsammastes": "lönsam",
    "lönsammasts": "lönsam",
    "lönsamme": "lönsam",
    "lönsammes": "lönsam",
    "lönsams": "lönsam",
    "lönsamt": "lönsam",
    "lönsamts": "lönsam",
    "lönskalägen": "lönskaläge",
    "lönskalägena": "lönskaläge",
    "lönskalägenas": "lönskaläge",
    "lönskalägens": "lönskaläge",
    "lönskaläges": "lönskaläge",
    "lönskaläget": "lönskaläge",
    "lönskalägets": "lönskaläge",
    "lönspar": "lönspara",
    "lönsparad": "lönspara",
    "lönsparade": "lönspara",
    "lönsparades": "lönspara",
    "lönsparads": "lönspara",
    "lönsparande": "lönspara",
    "lönsparanden": "lönsparande",
    "lönsparandena": "lönsparande",
    "lönsparandenas": "lönsparande",
    "lönsparandens": "lönsparande",
    "lönsparandes": "lönsparande",
    "lönsparandet": "lönsparande",
    "lönsparandets": "lönsparande",
    "lönsparar": "lönspara",
    "lönsparas": "lönspara",
    "lönsparat": "lönspara",
    "lönsparats": "lönspara",
    "löntagar": "löntagare",
    "löntagaren": "löntagare",
    "löntagarens": "löntagare",
    "löntagares": "löntagare",
    "löntagarfonden": "löntagarfond",
    "löntagarfondens": "löntagarfond",
    "löntagarfonder": "löntagarfond",
    "löntagarfonderna": "löntagarfond",
    "löntagarfondernas": "löntagarfond",
    "löntagarfonders": "löntagarfond",
    "löntagarfonds": "löntagarfond",
    "löntagarna": "löntagare",
    "löntagarnas": "löntagare",
    "löp": "löpa",
    "löpan": "löpa",
    "löpande": "löpa",
    "löpanden": "löpande",
    "löpandena": "löpande",
    "löpandenas": "löpande",
    "löpandens": "löpande",
    "löpandes": "löpande",
    "löpandet": "löpande",
    "löpandets": "löpande",
    "löpans": "löpa",
    "löpar": "löpare",
    "löparbanan": "löparbana",
    "löparbanans": "löparbana",
    "löparbanas": "löparbana",
    "löparbane": "löparbana",
    "löparbanor": "löparbana",
    "löparbanorna": "löparbana",
    "löparbanornas": "löparbana",
    "löparbanors": "löparbana",
    "löparen": "löpare",
    "löparens": "löpare",
    "löpares": "löpare",
    "löparna": "löpare",
    "löparnas": "löpare",
    "löparstenar": "löparsten",
    "löparstenarna": "löparsten",
    "löparstenarnas": "löparsten",
    "löparstenars": "löparsten",
    "löparstenen": "löparsten",
    "löparstenens": "löparsten",
    "löparstens": "löparsten",
    "löpas": "löpa",
    "löpe": "löpa",
    "löpeldar": "löpeld",
    "löpeldarna": "löpeld",
    "löpeldarnas": "löpeld",
    "löpeldars": "löpeld",
    "löpelden": "löpeld",
    "löpeldens": "löpeld",
    "löpelds": "löpeld",
    "löpen": "löp",
    "löpens": "löp",
    "löpeostar": "löpeost",
    "löpeostarna": "löpeost",
    "löpeostarnas": "löpeost",
    "löpeostars": "löpeost",
    "löpeosten": "löpeost",
    "löpeostens": "löpeost",
    "löpeosts": "löpeost",
    "löper": "löpa",
    "löpes": "löpe",
    "löpet": "löpe",
    "löpets": "löpe",
    "löpgravar": "löpgrav",
    "löpgravarna": "löpgrav",
    "löpgravarnas": "löpgrav",
    "löpgravars": "löpgrav",
    "löpgraven": "löpgrav",
    "löpgravens": "löpgrav",
    "löpgravs": "löpgrav",
    "löphjulen": "löphjul",
    "löphjulens": "löphjul",
    "löphjulet": "löphjul",
    "löphjulets": "löphjul",
    "löphjuls": "löphjul",
    "löpknutar": "löpknut",
    "löpknutarna": "löpknut",
    "löpknutarnas": "löpknut",
    "löpknutars": "löpknut",
    "löpknuten": "löpknut",
    "löpknutens": "löpknut",
    "löpknuts": "löpknut",
    "löplin": "löplina",
    "löplinan": "löplina",
    "löplinans": "löplina",
    "löplinas": "löplina",
    "löpline": "löplina",
    "löplinor": "löplina",
    "löplinorna": "löplina",
    "löplinornas": "löplina",
    "löplinors": "löplina",
    "löplins": "löplina",
    "löpmag": "löpmage",
    "löpmagar": "löpmage",
    "löpmagarna": "löpmage",
    "löpmagarnas": "löpmage",
    "löpmagars": "löpmage",
    "löpmagen": "löpmage",
    "löpmagens": "löpmage",
    "löpmages": "löpmage",
    "löpmags": "löpmage",
    "löpmask": "löpmaska",
    "löpmaskan": "löpmaska",
    "löpmaskans": "löpmaska",
    "löpmaskas": "löpmaska",
    "löpmaske": "löpmaska",
    "löpmaskor": "löpmaska",
    "löpmaskorna": "löpmaska",
    "löpmaskornas": "löpmaska",
    "löpmaskors": "löpmaska",
    "löpmetern": "löpmeter",
    "löpmeterna": "löpmeter",
    "löpmeternas": "löpmeter",
    "löpmeterns": "löpmeter",
    "löpmeters": "löpmeter",
    "löpmässiga": "löpmässig",
    "löpmässigare": "löpmässig",
    "löpmässigares": "löpmässig",
    "löpmässigas": "löpmässig",
    "löpmässigast": "löpmässig",
    "löpmässigaste": "löpmässig",
    "löpmässigastes": "löpmässig",
    "löpmässigasts": "löpmässig",
    "löpmässige": "löpmässig",
    "löpmässiges": "löpmässig",
    "löpmässigs": "löpmässig",
    "löpmässigt": "löpmässig",
    "löpmässigts": "löpmässig",
    "löpnade": "löpna",
    "löpnades": "löpna",
    "löpnande": "löpna",
    "löpnanden": "löpnande",
    "löpnandena": "löpnande",
    "löpnandenas": "löpnande",
    "löpnandens": "löpnande",
    "löpnandes": "löpnande",
    "löpnandet": "löpnande",
    "löpnandets": "löpnande",
    "löpnar": "löpna",
    "löpnas": "löpna",
    "löpnat": "löpna",
    "löpnats": "löpna",
    "löpningar": "löpning",
    "löpningarna": "löpning",
    "löpningarnas": "löpning",
    "löpningars": "löpning",
    "löpningen": "löpning",
    "löpningens": "löpning",
    "löpnings": "löpning",
    "löpor": "löpa",
    "löporden": "löpord",
    "löpordens": "löpord",
    "löpordet": "löpord",
    "löpordets": "löpord",
    "löpords": "löpord",
    "löporna": "löpa",
    "löpornas": "löpa",
    "löpors": "löpa",
    "löpostar": "löpost",
    "löpostarna": "löpost",
    "löpostarnas": "löpost",
    "löpostars": "löpost",
    "löposten": "löpost",
    "löpostens": "löpost",
    "löposts": "löpost",
    "löpringar": "löpring",
    "löpringarna": "löpring",
    "löpringarnas": "löpring",
    "löpringars": "löpring",
    "löpringen": "löpring",
    "löpringens": "löpring",
    "löprings": "löpring",
    "löps": "löpa",
    "löpsedeln": "löpsedel",
    "löpsedelns": "löpsedel",
    "löpsedels": "löpsedel",
    "löpsedelsresan": "löpsedelsresa",
    "löpsedelsresans": "löpsedelsresa",
    "löpsedelsresas": "löpsedelsresa",
    "löpsedelsrese": "löpsedelsresa",
    "löpsedelsresor": "löpsedelsresa",
    "löpsedelsresorna": "löpsedelsresa",
    "löpsedelsresornas": "löpsedelsresa",
    "löpsedelsresors": "löpsedelsresa",
    "löpsedlar": "löpsedel",
    "löpsedlarna": "löpsedel",
    "löpsedlarnas": "löpsedel",
    "löpsedlars": "löpsedel",
    "löpska": "löpsk",
    "löpskare": "löpsk",
    "löpskares": "löpsk",
    "löpskas": "löpsk",
    "löpskast": "löpsk",
    "löpskaste": "löpsk",
    "löpskastes": "löpsk",
    "löpskasts": "löpsk",
    "löpske": "löpsk",
    "löpskes": "löpsk",
    "löpskheten": "löpskhet",
    "löpskhetens": "löpskhet",
    "löpskhets": "löpskhet",
    "löpskiften": "löpskift",
    "löpskiftens": "löpskift",
    "löpskiftet": "löpskift",
    "löpskiftets": "löpskift",
    "löpskifts": "löpskift",
    "löpsks": "löpsk",
    "löpskt": "löpsk",
    "löpskts": "löpsk",
    "löpsnar": "löpsnara",
    "löpsnaran": "löpsnara",
    "löpsnarans": "löpsnara",
    "löpsnaras": "löpsnara",
    "löpsnare": "löpsnara",
    "löpsnaror": "löpsnara",
    "löpsnarorna": "löpsnara",
    "löpsnarornas": "löpsnara",
    "löpsnarors": "löpsnara",
    "löpsnars": "löpsnara",
    "löpstegen": "löpsteg",
    "löpstegens": "löpsteg",
    "löpsteget": "löpsteg",
    "löpstegets": "löpsteg",
    "löpstegs": "löpsteg",
    "löpstenar": "löpsten",
    "löpstenarna": "löpsten",
    "löpstenarnas": "löpsten",
    "löpstenars": "löpsten",
    "löpstenen": "löpsten",
    "löpstenens": "löpsten",
    "löpstens": "löpsten",
    "löpt": "löpa",
    "löpta": "löpa",
    "löptas": "löpa",
    "löpte": "löpa",
    "löptekniken": "löpteknik",
    "löpteknikens": "löpteknik",
    "löptekniker": "löpteknik",
    "löpteknikerna": "löpteknik",
    "löpteknikernas": "löpteknik",
    "löpteknikers": "löpteknik",
    "löptekniks": "löpteknik",
    "löptes": "löpa",
    "löptiden": "löptid",
    "löptidens": "löptid",
    "löptider": "löptid",
    "löptiderna": "löptid",
    "löptidernas": "löptid",
    "löptiders": "löptid",
    "löptids": "löptid",
    "löpträningen": "löpträning",
    "löpträningens": "löpträning",
    "löptränings": "löpträning",
    "löpts": "löpa",
    "löpvagnar": "löpvagn",
    "löpvagnarna": "löpvagn",
    "löpvagnarnas": "löpvagn",
    "löpvagnars": "löpvagn",
    "löpvagnen": "löpvagn",
    "löpvagnens": "löpvagn",
    "löpvagns": "löpvagn",
    "löpvikten": "löpvikt",
    "löpviktens": "löpvikt",
    "löpvikter": "löpvikt",
    "löpvikterna": "löpvikt",
    "löpvikternas": "löpvikt",
    "löpvikters": "löpvikt",
    "löpvikts": "löpvikt",
    "lördagar": "lördag",
    "lördagarna": "lördag",
    "lördagarnas": "lördag",
    "lördagars": "lördag",
    "lördageftermiddagar": "lördageftermiddag",
    "lördageftermiddagarna": "lördageftermiddag",
    "lördageftermiddagarnas": "lördageftermiddag",
    "lördageftermiddagars": "lördageftermiddag",
    "lördageftermiddagen": "lördageftermiddag",
    "lördageftermiddagens": "lördageftermiddag",
    "lördageftermiddags": "lördageftermiddag",
    "lördagen": "lördag",
    "lördagens": "lördag",
    "lördagkvällar": "lördagkväll",
    "lördagkvällarna": "lördagkväll",
    "lördagkvällarnas": "lördagkväll",
    "lördagkvällars": "lördagkväll",
    "lördagkvällen": "lördagkväll",
    "lördagkvällens": "lördagkväll",
    "lördagkvälls": "lördagkväll",
    "lördagmorgnar": "lördagmorgon",
    "lördagmorgnarna": "lördagmorgon",
    "lördagmorgnarnas": "lördagmorgon",
    "lördagmorgnars": "lördagmorgon",
    "lördagmorgonen": "lördagmorgon",
    "lördagmorgonens": "lördagmorgon",
    "lördagmorgons": "lördagmorgon",
    "lördagmornar": "lördagmorgon",
    "lördagmornarna": "lördagmorgon",
    "lördagmornarnas": "lördagmorgon",
    "lördagmornars": "lördagmorgon",
    "lördags": "lördag",
    "lördagsbilag": "lördagsbilaga",
    "lördagsbilagan": "lördagsbilaga",
    "lördagsbilagans": "lördagsbilaga",
    "lördagsbilagas": "lördagsbilaga",
    "lördagsbilage": "lördagsbilaga",
    "lördagsbilagor": "lördagsbilaga",
    "lördagsbilagorna": "lördagsbilaga",
    "lördagsbilagornas": "lördagsbilaga",
    "lördagsbilagors": "lördagsbilaga",
    "lördagsbilags": "lördagsbilaga",
    "lördagseftermiddagar": "lördagseftermiddag",
    "lördagseftermiddagarna": "lördagseftermiddag",
    "lördagseftermiddagarnas": "lördagseftermiddag",
    "lördagseftermiddagars": "lördagseftermiddag",
    "lördagseftermiddagen": "lördagseftermiddag",
    "lördagseftermiddagens": "lördagseftermiddag",
    "lördagseftermiddags": "lördagseftermiddag",
    "lördagsgodiset": "lördagsgodis",
    "lördagsgodisets": "lördagsgodis",
    "lördagshipp": "lördagshippa",
    "lördagshippan": "lördagshippa",
    "lördagshippans": "lördagshippa",
    "lördagshippas": "lördagshippa",
    "lördagshippe": "lördagshippa",
    "lördagshippor": "lördagshippa",
    "lördagshipporna": "lördagshippa",
    "lördagshippornas": "lördagshippa",
    "lördagshippors": "lördagshippa",
    "lördagshipps": "lördagshippa",
    "lördagskvällar": "lördagskväll",
    "lördagskvällarna": "lördagskväll",
    "lördagskvällarnas": "lördagskväll",
    "lördagskvällars": "lördagskväll",
    "lördagskvällen": "lördagskväll",
    "lördagskvällens": "lördagskväll",
    "lördagskvälls": "lördagskväll",
    "lördagsmorgnar": "lördagsmorgon",
    "lördagsmorgnarna": "lördagsmorgon",
    "lördagsmorgnarnas": "lördagsmorgon",
    "lördagsmorgnars": "lördagsmorgon",
    "lördagsmorgonen": "lördagsmorgon",
    "lördagsmorgonens": "lördagsmorgon",
    "lördagsmorgons": "lördagsmorgon",
    "lördagsmornar": "lördagsmorgon",
    "lördagsmornarna": "lördagsmorgon",
    "lördagsmornarnas": "lördagsmorgon",
    "lördagsmornars": "lördagsmorgon",
    "lördagsstängda": "lördagsstängd",
    "lördagsstängdare": "lördagsstängd",
    "lördagsstängdares": "lördagsstängd",
    "lördagsstängdas": "lördagsstängd",
    "lördagsstängdast": "lördagsstängd",
    "lördagsstängdaste": "lördagsstängd",
    "lördagsstängdastes": "lördagsstängd",
    "lördagsstängdasts": "lördagsstängd",
    "lördagsstängde": "lördagsstängd",
    "lördagsstängdes": "lördagsstängd",
    "lördagsstängds": "lördagsstängd",
    "lördagsstängt": "lördagsstängd",
    "lördagsstängts": "lördagsstängd",
    "lördagsöppens": "lördagsöppen",
    "lördagsöppet": "lördagsöppen",
    "lördagsöppets": "lördagsöppen",
    "lördagsöppna": "lördagsöppen",
    "lördagsöppnare": "lördagsöppen",
    "lördagsöppnares": "lördagsöppen",
    "lördagsöppnas": "lördagsöppen",
    "lördagsöppnast": "lördagsöppen",
    "lördagsöppnaste": "lördagsöppen",
    "lördagsöppnastes": "lördagsöppen",
    "lördagsöppnasts": "lördagsöppen",
    "lördagsöppne": "lördagsöppen",
    "lördagsöppnes": "lördagsöppen",
    "lös": "lösa",
    "lösa": "lös",
    "lösaktiga": "lösaktig",
    "lösaktigare": "lösaktig",
    "lösaktigares": "lösaktig",
    "lösaktigas": "lösaktig",
    "lösaktigast": "lösaktig",
    "lösaktigaste": "lösaktig",
    "lösaktigastes": "lösaktig",
    "lösaktigasts": "lösaktig",
    "lösaktige": "lösaktig",
    "lösaktiges": "lösaktig",
    "lösaktigheten": "lösaktighet",
    "lösaktighetens": "lösaktighet",
    "lösaktighets": "lösaktighet",
    "lösaktigs": "lösaktig",
    "lösaktigt": "lösaktig",
    "lösaktigts": "lösaktig",
    "lösande": "lösa",
    "lösanden": "lösande",
    "lösandena": "lösande",
    "lösandenas": "lösande",
    "lösandens": "lösande",
    "lösandes": "lösande",
    "lösandet": "lösande",
    "lösandets": "lösande",
    "lösare": "lös",
    "lösares": "lös",
    "lösas": "lösa",
    "lösast": "lös",
    "lösaste": "lös",
    "lösastes": "lös",
    "lösasts": "lös",
    "lösbara": "lösbar",
    "lösbarare": "lösbar",
    "lösbarares": "lösbar",
    "lösbaras": "lösbar",
    "lösbarast": "lösbar",
    "lösbaraste": "lösbar",
    "lösbarastes": "lösbar",
    "lösbarasts": "lösbar",
    "lösbare": "lösbar",
    "lösbares": "lösbar",
    "lösbarheten": "lösbarhet",
    "lösbarhetens": "lösbarhet",
    "lösbarhets": "lösbarhet",
    "lösbars": "lösbar",
    "lösbart": "lösbar",
    "lösbarts": "lösbar",
    "lösbladssystemen": "lösbladssystem",
    "lösbladssystemens": "lösbladssystem",
    "lösbladssystemet": "lösbladssystem",
    "lösbladssystemets": "lösbladssystem",
    "lösbladssystems": "lösbladssystem",
    "lösdriften": "lösdrift",
    "lösdriftens": "lösdrift",
    "lösdrifts": "lösdrift",
    "lösdrivar": "lösdrivare",
    "lösdrivaren": "lösdrivare",
    "lösdrivarens": "lösdrivare",
    "lösdrivares": "lösdrivare",
    "lösdrivarna": "lösdrivare",
    "lösdrivarnas": "lösdrivare",
    "lösdriverien": "lösdriveri",
    "lösdriveriens": "lösdriveri",
    "lösdriverin": "lösdriveri",
    "lösdriverins": "lösdriveri",
    "lösdriveris": "lösdriveri",
    "löse": "lös",
    "lösebeloppen": "lösebelopp",
    "lösebeloppens": "lösebelopp",
    "lösebeloppet": "lösebelopp",
    "lösebeloppets": "lösebelopp",
    "lösebelopps": "lösebelopp",
    "lösegendomar": "lösegendom",
    "lösegendomarna": "lösegendom",
    "lösegendomarnas": "lösegendom",
    "lösegendomars": "lösegendom",
    "lösegendomen": "lösegendom",
    "lösegendomens": "lösegendom",
    "lösegendoms": "lösegendom",
    "lösenbeloppen": "lösenbelopp",
    "lösenbeloppens": "lösenbelopp",
    "lösenbeloppet": "lösenbelopp",
    "lösenbeloppets": "lösenbelopp",
    "lösenbelopps": "lösenbelopp",
    "lösenorden": "lösenord",
    "lösenordens": "lösenord",
    "lösenordet": "lösenord",
    "lösenordets": "lösenord",
    "lösenords": "lösenord",
    "lösenpenningar": "lösenpenning",
    "lösenpenningarna": "lösenpenning",
    "lösenpenningarnas": "lösenpenning",
    "lösenpenningars": "lösenpenning",
    "lösenpenningen": "lösenpenning",
    "lösenpenningens": "lösenpenning",
    "lösenpennings": "lösenpenning",
    "lösens": "lösen",
    "lösenskillingar": "lösenskilling",
    "lösenskillingarna": "lösenskilling",
    "lösenskillingarnas": "lösenskilling",
    "lösenskillingars": "lösenskilling",
    "lösenskillingen": "lösenskilling",
    "lösenskillingens": "lösenskilling",
    "lösenskillings": "lösenskilling",
    "lösensumman": "lösensumma",
    "lösensummans": "lösensumma",
    "lösensummas": "lösensumma",
    "lösensumme": "lösensumma",
    "lösensummor": "lösensumma",
    "lösensummorna": "lösensumma",
    "lösensummornas": "lösensumma",
    "lösensummors": "lösensumma",
    "lösepenningar": "lösepenning",
    "lösepenningarna": "lösepenning",
    "lösepenningarnas": "lösepenning",
    "lösepenningars": "lösepenning",
    "lösepenningen": "lösepenning",
    "lösepenningens": "lösepenning",
    "lösepennings": "lösepenning",
    "löser": "lösa",
    "löses": "lösa",
    "löseskillingar": "löseskilling",
    "löseskillingarna": "löseskilling",
    "löseskillingarnas": "löseskilling",
    "löseskillingars": "löseskilling",
    "löseskillingen": "löseskilling",
    "löseskillingens": "löseskilling",
    "löseskillings": "löseskilling",
    "lösesumman": "lösesumma",
    "lösesummans": "lösesumma",
    "lösesummas": "lösesumma",
    "lösesumme": "lösesumma",
    "lösesummor": "lösesumma",
    "lösesummorna": "lösesumma",
    "lösesummornas": "lösesumma",
    "lösesummors": "lösesumma",
    "lösfynden": "lösfynd",
    "lösfyndens": "lösfynd",
    "lösfyndet": "lösfynd",
    "lösfyndets": "lösfynd",
    "lösfynds": "lösfynd",
    "lösgjord": "lösgöra",
    "lösgjorda": "lösgöra",
    "lösgjordas": "lösgöra",
    "lösgjorde": "lösgöra",
    "lösgjordes": "lösgöra",
    "lösgjords": "lösgöra",
    "lösgjort": "lösgöra",
    "lösgjorts": "lösgöra",
    "lösgodiset": "lösgodis",
    "lösgodisets": "lösgodis",
    "lösgommar": "lösgom",
    "lösgommarna": "lösgom",
    "lösgommarnas": "lösgom",
    "lösgommars": "lösgom",
    "lösgommen": "lösgom",
    "lösgommens": "lösgom",
    "lösgoms": "lösgom",
    "lösgör": "lösgöra",
    "lösgörande": "lösgöra",
    "lösgöranden": "lösgörande",
    "lösgörandena": "lösgörande",
    "lösgörandenas": "lösgörande",
    "lösgörandens": "lösgörande",
    "lösgörandes": "lösgörande",
    "lösgörandet": "lösgörande",
    "lösgörandets": "lösgörande",
    "lösgöras": "lösgöra",
    "lösgöres": "lösgöra",
    "lösgörs": "lösgöra",
    "lösheten": "löshet",
    "löshetens": "löshet",
    "löshets": "löshet",
    "löshästar": "löshäst",
    "löshästarna": "löshäst",
    "löshästarnas": "löshäst",
    "löshästars": "löshäst",
    "löshästen": "löshäst",
    "löshästens": "löshäst",
    "löshästs": "löshäst",
    "löshåren": "löshår",
    "löshårens": "löshår",
    "löshåret": "löshår",
    "löshårets": "löshår",
    "löshårs": "löshår",
    "löskekarlar": "löskekarl",
    "löskekarlarna": "löskekarl",
    "löskekarlarnas": "löskekarl",
    "löskekarlars": "löskekarl",
    "löskekarlen": "löskekarl",
    "löskekarlens": "löskekarl",
    "löskekarls": "löskekarl",
    "löskerkarlar": "löskerkarl",
    "löskerkarlarna": "löskerkarl",
    "löskerkarlarnas": "löskerkarl",
    "löskerkarlars": "löskerkarl",
    "löskerkarlen": "löskerkarl",
    "löskerkarlens": "löskerkarl",
    "löskerkarls": "löskerkarl",
    "löskokta": "löskokt",
    "löskoktare": "löskokt",
    "löskoktares": "löskokt",
    "löskoktas": "löskokt",
    "löskoktast": "löskokt",
    "löskoktaste": "löskokt",
    "löskoktastes": "löskokt",
    "löskoktasts": "löskokt",
    "löskokte": "löskokt",
    "löskoktes": "löskokt",
    "löskokts": "löskokt",
    "lösliga": "löslig",
    "lösligare": "löslig",
    "lösligares": "löslig",
    "lösligas": "löslig",
    "lösligast": "löslig",
    "lösligaste": "löslig",
    "lösligastes": "löslig",
    "lösligasts": "löslig",
    "löslige": "löslig",
    "lösliges": "löslig",
    "lösligheten": "löslighet",
    "löslighetens": "löslighet",
    "lösligheter": "löslighet",
    "lösligheterna": "löslighet",
    "lösligheternas": "löslighet",
    "lösligheters": "löslighet",
    "löslighets": "löslighet",
    "lösligs": "löslig",
    "lösligt": "löslig",
    "lösligts": "löslig",
    "lösmagar": "lösmage",
    "lösmagarna": "lösmage",
    "lösmagarnas": "lösmage",
    "lösmagars": "lösmage",
    "lösmagen": "lösmage",
    "lösmagens": "lösmage",
    "lösmages": "lösmage",
    "lösmynta": "lösmynt",
    "lösmyntare": "lösmynt",
    "lösmyntares": "lösmynt",
    "lösmyntas": "lösmynt",
    "lösmyntast": "lösmynt",
    "lösmyntaste": "lösmynt",
    "lösmyntastes": "lösmynt",
    "lösmyntasts": "lösmynt",
    "lösmynte": "lösmynt",
    "lösmyntes": "lösmynt",
    "lösmyntheten": "lösmynthet",
    "lösmynthetens": "lösmynthet",
    "lösmynthets": "lösmynthet",
    "lösmynts": "lösmynt",
    "lösningar": "lösning",
    "lösningarna": "lösning",
    "lösningarnas": "lösning",
    "lösningars": "lösning",
    "lösningen": "lösning",
    "lösningens": "lösning",
    "lösnings": "lösning",
    "lösningsegenskapen": "lösningsegenskap",
    "lösningsegenskapens": "lösningsegenskap",
    "lösningsegenskaper": "lösningsegenskap",
    "lösningsegenskaperna": "lösningsegenskap",
    "lösningsegenskapernas": "lösningsegenskap",
    "lösningsegenskapers": "lösningsegenskap",
    "lösningsegenskaps": "lösningsegenskap",
    "lösningsmedels": "lösningsmedel",
    "lösningsmedelsbaserade": "lösningsmedelsbaserad",
    "lösningsmedelsbaserades": "lösningsmedelsbaserad",
    "lösningsmedelsbaserads": "lösningsmedelsbaserad",
    "lösningsmedelsbaserat": "lösningsmedelsbaserad",
    "lösningsmedelsbaserats": "lösningsmedelsbaserad",
    "lösningsmedlen": "lösningsmedel",
    "lösningsmedlens": "lösningsmedel",
    "lösningsmedlet": "lösningsmedel",
    "lösningsmedlets": "lösningsmedel",
    "lösningsrätten": "lösningsrätt",
    "lösningsrättens": "lösningsrätt",
    "lösningsrätts": "lösningsrätt",
    "lösnummerna": "lösnummer",
    "lösnummernas": "lösnummer",
    "lösnummers": "lösnummer",
    "lösnumren": "lösnummer",
    "lösnumrens": "lösnummer",
    "lösnumret": "lösnummer",
    "lösnumrets": "lösnummer",
    "lösnäs": "lösnäsa",
    "lösnäsan": "lösnäsa",
    "lösnäsans": "lösnäsa",
    "lösnäsas": "lösnäsa",
    "lösnäse": "lösnäsa",
    "lösnäsor": "lösnäsa",
    "lösnäsorna": "lösnäsa",
    "lösnäsornas": "lösnäsa",
    "lösnäsors": "lösnäsa",
    "lösryckta": "lösryckt",
    "lösrycktare": "lösryckt",
    "lösrycktares": "lösryckt",
    "lösrycktas": "lösryckt",
    "lösrycktast": "lösryckt",
    "lösrycktaste": "lösryckt",
    "lösrycktastes": "lösryckt",
    "lösrycktasts": "lösryckt",
    "lösryckte": "lösryckt",
    "lösrycktes": "lösryckt",
    "lösrycktheten": "lösryckthet",
    "lösryckthetens": "lösryckthet",
    "lösryckthets": "lösryckthet",
    "lösryckts": "lösryckt",
    "lösryggar": "lösrygg",
    "lösryggarna": "lösrygg",
    "lösryggarnas": "lösrygg",
    "lösryggars": "lösrygg",
    "lösryggen": "lösrygg",
    "lösryggens": "lösrygg",
    "lösryggs": "lösrygg",
    "löss": "lus",
    "lössen": "lus",
    "lössens": "lus",
    "lössjordar": "lössjord",
    "lössjordarna": "lössjord",
    "lössjordarnas": "lössjord",
    "lössjordars": "lössjord",
    "lössjorden": "lössjord",
    "lössjordens": "lössjord",
    "lössjords": "lössjord",
    "lösskäggen": "lösskägg",
    "lösskäggens": "lösskägg",
    "lösskägget": "lösskägg",
    "lösskäggets": "lösskägg",
    "lösskäggs": "lösskägg",
    "lössläppta": "lössläppt",
    "lössläpptare": "lössläppt",
    "lössläpptares": "lössläppt",
    "lössläpptas": "lössläppt",
    "lössläpptast": "lössläppt",
    "lössläpptaste": "lössläppt",
    "lössläpptastes": "lössläppt",
    "lössläpptasts": "lössläppt",
    "lössläppte": "lössläppt",
    "lössläpptes": "lössläppt",
    "lössläpptheten": "lössläppthet",
    "lössläppthetens": "lössläppthet",
    "lössläppthets": "lössläppthet",
    "lössläppts": "lössläppt",
    "lössnön": "lössnö",
    "lössnöns": "lössnö",
    "lössnös": "lössnö",
    "löst": "lösa",
    "lösta": "lösa",
    "löstagbara": "löstagbar",
    "löstagbarare": "löstagbar",
    "löstagbarares": "löstagbar",
    "löstagbaras": "löstagbar",
    "löstagbarast": "löstagbar",
    "löstagbaraste": "löstagbar",
    "löstagbarastes": "löstagbar",
    "löstagbarasts": "löstagbar",
    "löstagbare": "löstagbar",
    "löstagbares": "löstagbar",
    "löstagbarheten": "löstagbarhet",
    "löstagbarhetens": "löstagbarhet",
    "löstagbarhets": "löstagbarhet",
    "löstagbars": "löstagbar",
    "löstagbart": "löstagbar",
    "löstagbarts": "löstagbar",
    "löstas": "lösa",
    "löste": "lösa",
    "löstes": "lösa",
    "lösts": "lösa",
    "löständerna": "löständer",
    "löständernas": "löständer",
    "löständers": "löständer",
    "lösögonfransar": "lösögonfrans",
    "lösögonfransarna": "lösögonfrans",
    "lösögonfransarnas": "lösögonfrans",
    "lösögonfransars": "lösögonfrans",
    "lösögonfransen": "lösögonfrans",
    "lösögonfransens": "lösögonfrans",
    "lösöreköpen": "lösöreköp",
    "lösöreköpens": "lösöreköp",
    "lösöreköpet": "lösöreköp",
    "lösöreköpets": "lösöreköp",
    "lösöreköps": "lösöreköp",
    "lösören": "lösöre",
    "lösörena": "lösöre",
    "lösörenas": "lösöre",
    "lösörens": "lösöre",
    "lösöres": "lösöre",
    "lösöret": "lösöre",
    "lösörets": "lösöre",
    "lötar": "löt",
    "lötarna": "löt",
    "lötarnas": "löt",
    "lötars": "löt",
    "löten": "löt",
    "lötens": "löt",
    "löts": "löt",
    "lött": "löda",
    "lötts": "löda",
    "löv": "löva",
    "lövad": "löva",
    "lövade": "löva",
    "lövades": "lövas",
    "lövads": "löva",
    "lövande": "löva",
    "lövanden": "lövande",
    "lövandena": "lövande",
    "lövandenas": "lövande",
    "lövandens": "lövande",
    "lövandes": "lövande",
    "lövandet": "lövande",
    "lövandets": "lövande",
    "lövar": "löva",
    "lövas": "löva",
    "lövat": "löva",
    "lövats": "lövas",
    "lövbiffar": "lövbiff",
    "lövbiffarna": "lövbiff",
    "lövbiffarnas": "lövbiff",
    "lövbiffars": "lövbiff",
    "lövbiffen": "lövbiff",
    "lövbiffens": "lövbiff",
    "lövbiffs": "lövbiff",
    "lövblandskogar": "lövblandskog",
    "lövblandskogarna": "lövblandskog",
    "lövblandskogarnas": "lövblandskog",
    "lövblandskogars": "lövblandskog",
    "lövblandskogen": "lövblandskog",
    "lövblandskogens": "lövblandskog",
    "lövblandskogs": "lövblandskog",
    "lövblåsar": "lövblås",
    "lövblåsarna": "lövblås",
    "lövblåsarnas": "lövblås",
    "lövblåsars": "lövblås",
    "lövblåsen": "lövblås",
    "lövblåsens": "lövblås",
    "löven": "löv",
    "lövens": "löv",
    "lövet": "löv",
    "lövets": "löv",
    "lövfoderna": "lövfoder",
    "lövfodernas": "lövfoder",
    "lövfoders": "lövfoder",
    "lövfodren": "lövfoder",
    "lövfodrens": "lövfoder",
    "lövfodret": "lövfoder",
    "lövfodrets": "lövfoder",
    "lövfällningar": "lövfällning",
    "lövfällningarna": "lövfällning",
    "lövfällningarnas": "lövfällning",
    "lövfällningars": "lövfällning",
    "lövfällningen": "lövfällning",
    "lövfällningens": "lövfällning",
    "lövfällnings": "lövfällning",
    "lövgrod": "lövgroda",
    "lövgrodan": "lövgroda",
    "lövgrodans": "lövgroda",
    "lövgrodas": "lövgroda",
    "lövgrode": "lövgroda",
    "lövgrodor": "lövgroda",
    "lövgrodorna": "lövgroda",
    "lövgrodornas": "lövgroda",
    "lövgrodors": "lövgroda",
    "lövgrods": "lövgroda",
    "lövhyddohögtiden": "lövhyddohögtid",
    "lövhyddohögtidens": "lövhyddohögtid",
    "lövhyddohögtider": "lövhyddohögtid",
    "lövhyddohögtiderna": "lövhyddohögtid",
    "lövhyddohögtidernas": "lövhyddohögtid",
    "lövhyddohögtiders": "lövhyddohögtid",
    "lövhyddohögtids": "lövhyddohögtid",
    "lövhögar": "lövhög",
    "lövhögarna": "lövhög",
    "lövhögarnas": "lövhög",
    "lövhögars": "lövhög",
    "lövhögen": "lövhög",
    "lövhögens": "lövhög",
    "lövhögs": "lövhög",
    "lövjordar": "lövjord",
    "lövjordarna": "lövjord",
    "lövjordarnas": "lövjord",
    "lövjordars": "lövjord",
    "lövjorden": "lövjord",
    "lövjordens": "lövjord",
    "lövjords": "lövjord",
    "lövkass": "lövkasse",
    "lövkassar": "lövkasse",
    "lövkassarna": "lövkasse",
    "lövkassarnas": "lövkasse",
    "lövkassars": "lövkasse",
    "lövkassen": "lövkasse",
    "lövkassens": "lövkasse",
    "lövkasses": "lövkasse",
    "lövklädda": "lövklädd",
    "lövkläddare": "lövklädd",
    "lövkläddares": "lövklädd",
    "lövkläddas": "lövklädd",
    "lövkläddast": "lövklädd",
    "lövkläddaste": "lövklädd",
    "lövkläddastes": "lövklädd",
    "lövkläddasts": "lövklädd",
    "lövklädde": "lövklädd",
    "lövkläddes": "lövklädd",
    "lövklädds": "lövklädd",
    "lövklätt": "lövklädd",
    "lövklätts": "lövklädd",
    "lövkoj": "lövkoja",
    "lövkojan": "lövkoja",
    "lövkojans": "lövkoja",
    "lövkojas": "lövkoja",
    "lövkoje": "lövkoja",
    "lövkojor": "lövkoja",
    "lövkojorna": "lövkoja",
    "lövkojornas": "lövkoja",
    "lövkojors": "lövkoja",
    "lövkojs": "lövkoja",
    "lövmaskar": "lövmask",
    "lövmaskarna": "lövmask",
    "lövmaskarnas": "lövmask",
    "lövmaskars": "lövmask",
    "lövmasken": "lövmask",
    "lövmaskens": "lövmask",
    "lövmasks": "lövmask",
    "lövmoss": "lövmossa",
    "lövmossan": "lövmossa",
    "lövmossans": "lövmossa",
    "lövmossas": "lövmossa",
    "lövmosse": "lövmossa",
    "lövmossor": "lövmossa",
    "lövmossorna": "lövmossa",
    "lövmossornas": "lövmossa",
    "lövmossors": "lövmossa",
    "lövrusk": "lövruska",
    "lövruskan": "lövruska",
    "lövruskans": "lövruska",
    "lövruskas": "lövruska",
    "lövruske": "lövruska",
    "lövruskor": "lövruska",
    "lövruskorna": "lövruska",
    "lövruskornas": "lövruska",
    "lövruskors": "lövruska",
    "lövs": "löv",
    "lövsalar": "lövsal",
    "lövsalarna": "lövsal",
    "lövsalarnas": "lövsal",
    "lövsalars": "lövsal",
    "lövsalen": "lövsal",
    "lövsalens": "lövsal",
    "lövsals": "lövsal",
    "lövskogar": "lövskog",
    "lövskogarna": "lövskog",
    "lövskogarnas": "lövskog",
    "lövskogars": "lövskog",
    "lövskogen": "lövskog",
    "lövskogens": "lövskog",
    "lövskogs": "lövskog",
    "lövslyet": "lövsly",
    "lövslyets": "lövsly",
    "lövslys": "lövsly",
    "lövslyt": "lövsly",
    "lövslyts": "lövsly",
    "lövsmygar": "lövsmyg",
    "lövsmygarna": "lövsmyg",
    "lövsmygarnas": "lövsmyg",
    "lövsmygars": "lövsmyg",
    "lövsmygen": "lövsmyg",
    "lövsmygens": "lövsmyg",
    "lövsmygs": "lövsmyg",
    "lövsprickningar": "lövsprickning",
    "lövsprickningarna": "lövsprickning",
    "lövsprickningarnas": "lövsprickning",
    "lövsprickningars": "lövsprickning",
    "lövsprickningen": "lövsprickning",
    "lövsprickningens": "lövsprickning",
    "lövspricknings": "lövsprickning",
    "lövsugar": "lövsug",
    "lövsugarna": "lövsug",
    "lövsugarnas": "lövsug",
    "lövsugars": "lövsug",
    "lövsugen": "lövsug",
    "lövsugens": "lövsug",
    "lövsugs": "lövsug",
    "lövsågar": "lövsåg",
    "lövsågarna": "lövsåg",
    "lövsågarnas": "lövsåg",
    "lövsågars": "lövsåg",
    "lövsågen": "lövsåg",
    "lövsågens": "lövsåg",
    "lövsågningar": "lövsågning",
    "lövsågningarna": "lövsågning",
    "lövsågningarnas": "lövsågning",
    "lövsågningars": "lövsågning",
    "lövsågningen": "lövsågning",
    "lövsågningens": "lövsågning",
    "lövsågnings": "lövsågning",
    "lövsågs": "lövsåg",
    "lövsångar": "lövsångare",
    "lövsångaren": "lövsångare",
    "lövsångarens": "lövsångare",
    "lövsångares": "lövsångare",
    "lövsångarna": "lövsångare",
    "lövsångarnas": "lövsångare",
    "lövträden": "lövträd",
    "lövträdens": "lövträd",
    "lövträdet": "lövträd",
    "lövträdets": "lövträd",
    "lövträds": "lövträd",
    "lövträet": "lövträ",
    "lövträets": "lövträ",
    "lövträs": "lövträ",
    "lövträt": "lövträ",
    "lövträts": "lövträ",
    "lövtunna": "lövtunn",
    "lövtunnare": "lövtunn",
    "lövtunnares": "lövtunn",
    "lövtunnas": "lövtunn",
    "lövtunnast": "lövtunn",
    "lövtunnaste": "lövtunn",
    "lövtunnastes": "lövtunn",
    "lövtunnasts": "lövtunn",
    "lövtunne": "lövtunn",
    "lövtunnes": "lövtunn",
    "lövtunnheten": "lövtunnhet",
    "lövtunnhetens": "lövtunnhet",
    "lövtunnhets": "lövtunnhet",
    "lövtunns": "lövtunn",
    "lövtunt": "lövtunn",
    "lövtunts": "lövtunn",
    "lövtäkten": "lövtäkt",
    "lövtäktens": "lövtäkt",
    "lövtäkter": "lövtäkt",
    "lövtäkterna": "lövtäkt",
    "lövtäkternas": "lövtäkt",
    "lövtäkters": "lövtäkt",
    "lövtäkts": "lövtäkt",
    "lövuppsamlar": "lövuppsamlare",
    "lövuppsamlaren": "lövuppsamlare",
    "lövuppsamlarens": "lövuppsamlare",
    "lövuppsamlares": "lövuppsamlare",
    "lövuppsamlarna": "lövuppsamlare",
    "lövuppsamlarnas": "lövuppsamlare",
    "lövverken": "lövverk",
    "lövverkens": "lövverk",
    "lövverket": "lövverk",
    "lövverkets": "lövverk",
    "lövverks": "lövverk",
    "lövängar": "löväng",
    "lövängarna": "löväng",
    "lövängarnas": "löväng",
    "lövängars": "löväng",
    "lövängen": "löväng",
    "lövängens": "löväng",
    "lövängs": "löväng",
    "m-en": "m",
    "m-ens": "m",
    "m-et": "m",
    "m-ets": "m",
    "m-s": "m",
    "m:en": "m",
    "m:ens": "m",
    "m:et": "m",
    "m:ets": "m",
    "m:s": "m",
    "mRNA-er": "mRNA",
    "mRNA-erna": "mRNA",
    "mRNA-ernas": "mRNA",
    "mRNA-ers": "mRNA",
    "mRNA-n": "mRNA",
    "mRNA-na": "mRNA",
    "mRNA-nas": "mRNA",
    "mRNA-ns": "mRNA",
    "mRNA-s": "mRNA",
    "mRNA-t": "mRNA",
    "mRNA-ts": "mRNA",
    "mRNA:er": "mRNA",
    "mRNA:erna": "mRNA",
    "mRNA:ernas": "mRNA",
    "mRNA:ers": "mRNA",
    "mRNA:n": "mRNA",
    "mRNA:na": "mRNA",
    "mRNA:nas": "mRNA",
    "mRNA:ns": "mRNA",
    "mRNA:s": "mRNA",
    "mRNA:t": "mRNA",
    "mRNA:ts": "mRNA",
    "mRNAer": "mRNA",
    "mRNAerna": "mRNA",
    "mRNAernas": "mRNA",
    "mRNAers": "mRNA",
    "mRNAn": "mRNA",
    "mRNAna": "mRNA",
    "mRNAnas": "mRNA",
    "mRNAns": "mRNA",
    "mRNAs": "mRNA",
    "mRNAt": "mRNA",
    "mRNAts": "mRNA",
    "macchiaton": "macchiato",
    "macchiatons": "macchiato",
    "macchiatos": "macchiato",
    "macedoniska": "macedonisk",
    "macedoniskare": "macedonisk",
    "macedoniskares": "macedonisk",
    "macedoniskas": "macedonisk",
    "macedoniskast": "macedonisk",
    "macedoniskaste": "macedonisk",
    "macedoniskastes": "macedonisk",
    "macedoniskasts": "macedonisk",
    "macedoniske": "macedonisk",
    "macedoniskes": "macedonisk",
    "macedonisks": "macedonisk",
    "macedoniskt": "macedonisk",
    "macedoniskts": "macedonisk",
    "macedonsk": "macedonska",
    "macedonska": "macedonsk",
    "macedonskan": "macedonska",
    "macedonskans": "macedonska",
    "macedonskare": "macedonsk",
    "macedonskares": "macedonsk",
    "macedonskas": "macedonska",
    "macedonskast": "macedonsk",
    "macedonskaste": "macedonsk",
    "macedonskastes": "macedonsk",
    "macedonskasts": "macedonsk",
    "macedonske": "macedonska",
    "macedonskes": "macedonsk",
    "macedonskor": "macedonska",
    "macedonskorna": "macedonska",
    "macedonskornas": "macedonska",
    "macedonskors": "macedonska",
    "macedonsks": "macedonsk",
    "macedonskt": "macedonsk",
    "macedonskts": "macedonsk",
    "machen": "mach",
    "machens": "mach",
    "macheten": "machete",
    "machetens": "machete",
    "macheter": "machete",
    "macheterna": "machete",
    "macheternas": "machete",
    "macheters": "machete",
    "machetes": "machete",
    "machiavelliska": "machiavellisk",
    "machiavelliskare": "machiavellisk",
    "machiavelliskares": "machiavellisk",
    "machiavelliskas": "machiavellisk",
    "machiavelliskast": "machiavellisk",
    "machiavelliskaste": "machiavellisk",
    "machiavelliskastes": "machiavellisk",
    "machiavelliskasts": "machiavellisk",
    "machiavelliske": "machiavellisk",
    "machiavelliskes": "machiavellisk",
    "machiavellisks": "machiavellisk",
    "machiavelliskt": "machiavellisk",
    "machiavelliskts": "machiavellisk",
    "machiavellismen": "machiavellism",
    "machiavellismens": "machiavellism",
    "machiavellismer": "machiavellism",
    "machiavellismerna": "machiavellism",
    "machiavellismernas": "machiavellism",
    "machiavellismers": "machiavellism",
    "machiavellisms": "machiavellism",
    "machiavellistiska": "machiavellistisk",
    "machiavellistiskare": "machiavellistisk",
    "machiavellistiskares": "machiavellistisk",
    "machiavellistiskas": "machiavellistisk",
    "machiavellistiskast": "machiavellistisk",
    "machiavellistiskaste": "machiavellistisk",
    "machiavellistiskastes": "machiavellistisk",
    "machiavellistiskasts": "machiavellistisk",
    "machiavellistiske": "machiavellistisk",
    "machiavellistiskes": "machiavellistisk",
    "machiavellistisks": "machiavellistisk",
    "machiavellistiskt": "machiavellistisk",
    "machiavellistiskts": "machiavellistisk",
    "machoidealen": "machoideal",
    "machoidealens": "machoideal",
    "machoidealet": "machoideal",
    "machoidealets": "machoideal",
    "machoideals": "machoideal",
    "macholiven": "macholiv",
    "macholivens": "macholiv",
    "macholivet": "macholiv",
    "macholivets": "macholiv",
    "macholivs": "macholiv",
    "machomyten": "machomyt",
    "machomytens": "machomyt",
    "machomyter": "machomyt",
    "machomyterna": "machomyt",
    "machomyternas": "machomyt",
    "machomyters": "machomyt",
    "machomyts": "machomyt",
    "machs": "mach",
    "machtalen": "machtal",
    "machtalens": "machtal",
    "machtalet": "machtal",
    "machtalets": "machtal",
    "machtals": "machtal",
    "machverken": "machverk",
    "machverkens": "machverk",
    "machverket": "machverk",
    "machverkets": "machverk",
    "machverks": "machverk",
    "mack": "macka",
    "mackan": "macka",
    "mackans": "macka",
    "mackapären": "mackapär",
    "mackapärens": "mackapär",
    "mackapärer": "mackapär",
    "mackapärerna": "mackapär",
    "mackapärernas": "mackapär",
    "mackapärers": "mackapär",
    "mackapärs": "mackapär",
    "mackar": "mack",
    "mackarna": "mack",
    "mackarnas": "mack",
    "mackars": "mack",
    "mackas": "macka",
    "mackbesöken": "mackbesök",
    "mackbesökens": "mackbesök",
    "mackbesöket": "mackbesök",
    "mackbesökets": "mackbesök",
    "mackbesöks": "mackbesök",
    "macke": "macka",
    "mackel": "mackla",
    "mackels": "mackel",
    "macken": "mack",
    "mackens": "mack",
    "macklade": "mackla",
    "macklades": "mackla",
    "macklande": "mackla",
    "macklanden": "macklande",
    "macklandena": "macklande",
    "macklandenas": "macklande",
    "macklandens": "macklande",
    "macklandes": "macklande",
    "macklandet": "macklande",
    "macklandets": "macklande",
    "macklar": "mackla",
    "macklas": "mackla",
    "macklat": "mackla",
    "macklats": "mackla",
    "macklet": "mackel",
    "macklets": "mackel",
    "mackor": "macka",
    "mackorna": "macka",
    "mackornas": "macka",
    "mackors": "macka",
    "macks": "macka",
    "madagasken": "madagask",
    "madagaskens": "madagask",
    "madagasker": "madagask",
    "madagaskerna": "madagask",
    "madagaskernas": "madagask",
    "madagaskers": "madagask",
    "madagaskiska": "madagaskisk",
    "madagaskiskan": "madagaskiska",
    "madagaskiskans": "madagaskiska",
    "madagaskiskare": "madagaskisk",
    "madagaskiskares": "madagaskisk",
    "madagaskiskas": "madagaskiska",
    "madagaskiskast": "madagaskisk",
    "madagaskiskaste": "madagaskisk",
    "madagaskiskastes": "madagaskisk",
    "madagaskiskasts": "madagaskisk",
    "madagaskiske": "madagaskiska",
    "madagaskiskes": "madagaskisk",
    "madagaskiskor": "madagaskiska",
    "madagaskiskorna": "madagaskiska",
    "madagaskiskornas": "madagaskiska",
    "madagaskiskors": "madagaskiska",
    "madagaskisks": "madagaskisk",
    "madagaskiskt": "madagaskisk",
    "madagaskiskts": "madagaskisk",
    "madagasks": "madagask",
    "madamen": "madame",
    "madamens": "madame",
    "madamer": "madame",
    "madamerna": "madame",
    "madamernas": "madame",
    "madamers": "madame",
    "madames": "madame",
    "madammen": "madam",
    "madammens": "madam",
    "madammer": "madam",
    "madammerna": "madam",
    "madammernas": "madam",
    "madammers": "madam",
    "madams": "madam",
    "madapolamen": "madapolam",
    "madapolamens": "madapolam",
    "madapolamer": "madapolam",
    "madapolamerna": "madapolam",
    "madapolamernas": "madapolam",
    "madapolamers": "madapolam",
    "madapolamet": "madapolam",
    "madapolamets": "madapolam",
    "madapolams": "madapolam",
    "madeiran": "madeira",
    "madeirans": "madeira",
    "madeiras": "madeira",
    "madeleinekak": "madeleinekaka",
    "madeleinekakan": "madeleinekaka",
    "madeleinekakans": "madeleinekaka",
    "madeleinekakas": "madeleinekaka",
    "madeleinekake": "madeleinekaka",
    "madeleinekakor": "madeleinekaka",
    "madeleinekakorna": "madeleinekaka",
    "madeleinekakornas": "madeleinekaka",
    "madeleinekakors": "madeleinekaka",
    "madeleinekaks": "madeleinekaka",
    "maden": "mad",
    "madens": "mad",
    "mader": "mad",
    "maderna": "mad",
    "madernas": "mad",
    "maders": "mad",
    "madonnan": "madonna",
    "madonnans": "madonna",
    "madonnas": "madonna",
    "madonne": "madonna",
    "madonnor": "madonna",
    "madonnorna": "madonna",
    "madonnornas": "madonna",
    "madonnors": "madonna",
    "madran": "madra",
    "madrans": "madra",
    "madras": "madra",
    "madrassen": "madrass",
    "madrassens": "madrass",
    "madrasser": "madrass",
    "madrasserad": "madrassera",
    "madrasserade": "madrassera",
    "madrasserades": "madrassera",
    "madrasserads": "madrassera",
    "madrasserande": "madrassera",
    "madrasseranden": "madrasserande",
    "madrasserandena": "madrasserande",
    "madrasserandenas": "madrasserande",
    "madrasserandens": "madrasserande",
    "madrasserandes": "madrasserande",
    "madrasserandet": "madrasserande",
    "madrasserandets": "madrasserande",
    "madrasserar": "madrassera",
    "madrasseras": "madrassera",
    "madrasserat": "madrassera",
    "madrasserats": "madrassera",
    "madrasserbara": "madrasserbar",
    "madrasserbarare": "madrasserbar",
    "madrasserbarares": "madrasserbar",
    "madrasserbaras": "madrasserbar",
    "madrasserbarast": "madrasserbar",
    "madrasserbaraste": "madrasserbar",
    "madrasserbarastes": "madrasserbar",
    "madrasserbarasts": "madrasserbar",
    "madrasserbare": "madrasserbar",
    "madrasserbares": "madrasserbar",
    "madrasserbarheten": "madrasserbarhet",
    "madrasserbarhetens": "madrasserbarhet",
    "madrasserbarhets": "madrasserbarhet",
    "madrasserbars": "madrasserbar",
    "madrasserbart": "madrasserbar",
    "madrasserbarts": "madrasserbar",
    "madrasseringar": "madrassering",
    "madrasseringarna": "madrassering",
    "madrasseringarnas": "madrassering",
    "madrasseringars": "madrassering",
    "madrasseringen": "madrassering",
    "madrasseringens": "madrassering",
    "madrasserings": "madrassering",
    "madrasserna": "madrass",
    "madrassernas": "madrass",
    "madrassers": "madrass",
    "madrassfabriken": "madrassfabrik",
    "madrassfabrikens": "madrassfabrik",
    "madrassfabriker": "madrassfabrik",
    "madrassfabrikerna": "madrassfabrik",
    "madrassfabrikernas": "madrassfabrik",
    "madrassfabrikers": "madrassfabrik",
    "madrassfabriks": "madrassfabrik",
    "madrassnålar": "madrassnål",
    "madrassnålarna": "madrassnål",
    "madrassnålarnas": "madrassnål",
    "madrassnålars": "madrassnål",
    "madrassnålen": "madrassnål",
    "madrassnålens": "madrassnål",
    "madrassnåls": "madrassnål",
    "madre": "madra",
    "madrigalen": "madrigal",
    "madrigalens": "madrigal",
    "madrigaler": "madrigal",
    "madrigalerna": "madrigal",
    "madrigalernas": "madrigal",
    "madrigalers": "madrigal",
    "madrigals": "madrigal",
    "madror": "madra",
    "madrorna": "madra",
    "madrornas": "madra",
    "madrors": "madra",
    "mads": "mad",
    "maduskan": "maduska",
    "maduskans": "maduska",
    "maduskas": "maduska",
    "maduske": "maduska",
    "maduskor": "maduska",
    "maduskorna": "maduska",
    "maduskornas": "maduska",
    "maduskors": "maduska",
    "maestron": "maestro",
    "maestrons": "maestro",
    "maestros": "maestro",
    "maffiaavslöjar": "maffiaavslöjare",
    "maffiaavslöjaren": "maffiaavslöjare",
    "maffiaavslöjarens": "maffiaavslöjare",
    "maffiaavslöjares": "maffiaavslöjare",
    "maffiaavslöjarna": "maffiaavslöjare",
    "maffiaavslöjarnas": "maffiaavslöjare",
    "maffiabossar": "maffiaboss",
    "maffiabossarna": "maffiaboss",
    "maffiabossarnas": "maffiaboss",
    "maffiabossars": "maffiaboss",
    "maffiabossen": "maffiaboss",
    "maffiabossens": "maffiaboss",
    "maffiafilmen": "maffiafilm",
    "maffiafilmens": "maffiafilm",
    "maffiafilmer": "maffiafilm",
    "maffiafilmerna": "maffiafilm",
    "maffiafilmernas": "maffiafilm",
    "maffiafilmers": "maffiafilm",
    "maffiafilms": "maffiafilm",
    "maffialigan": "maffialiga",
    "maffialigans": "maffialiga",
    "maffialigas": "maffialiga",
    "maffialige": "maffialiga",
    "maffialigor": "maffialiga",
    "maffialigorna": "maffialiga",
    "maffialigornas": "maffialiga",
    "maffialigors": "maffialiga",
    "maffiamässiga": "maffiamässig",
    "maffiamässigare": "maffiamässig",
    "maffiamässigares": "maffiamässig",
    "maffiamässigas": "maffiamässig",
    "maffiamässigast": "maffiamässig",
    "maffiamässigaste": "maffiamässig",
    "maffiamässigastes": "maffiamässig",
    "maffiamässigasts": "maffiamässig",
    "maffiamässige": "maffiamässig",
    "maffiamässiges": "maffiamässig",
    "maffiamässigs": "maffiamässig",
    "maffiamässigt": "maffiamässig",
    "maffiamässigts": "maffiamässig",
    "maffian": "maffia",
    "maffians": "maffia",
    "maffias": "maffia",
    "maffiga": "maffig",
    "maffigare": "maffig",
    "maffigares": "maffig",
    "maffigas": "maffig",
    "maffigast": "maffig",
    "maffigaste": "maffig",
    "maffigastes": "maffig",
    "maffigasts": "maffig",
    "maffige": "maffig",
    "maffiges": "maffig",
    "maffigheten": "maffighet",
    "maffighetens": "maffighet",
    "maffighets": "maffighet",
    "maffigs": "maffig",
    "maffigt": "maffig",
    "maffigts": "maffig",
    "maffior": "maffia",
    "maffiorna": "maffia",
    "maffiornas": "maffia",
    "maffiors": "maffia",
    "mag": "mage",
    "magar": "mage",
    "magarna": "mage",
    "magarnas": "mage",
    "magars": "mage",
    "magasinen": "magasin",
    "magasinens": "magasin",
    "magasinerad": "magasinera",
    "magasinerade": "magasinera",
    "magasinerades": "magasinera",
    "magasinerads": "magasinera",
    "magasinerande": "magasinera",
    "magasineranden": "magasinerande",
    "magasinerandena": "magasinerande",
    "magasinerandenas": "magasinerande",
    "magasinerandens": "magasinerande",
    "magasinerandes": "magasinerande",
    "magasinerandet": "magasinerande",
    "magasinerandets": "magasinerande",
    "magasinerar": "magasinera",
    "magasineras": "magasinera",
    "magasinerat": "magasinera",
    "magasinerats": "magasinera",
    "magasinerbara": "magasinerbar",
    "magasinerbarare": "magasinerbar",
    "magasinerbarares": "magasinerbar",
    "magasinerbaras": "magasinerbar",
    "magasinerbarast": "magasinerbar",
    "magasinerbaraste": "magasinerbar",
    "magasinerbarastes": "magasinerbar",
    "magasinerbarasts": "magasinerbar",
    "magasinerbare": "magasinerbar",
    "magasinerbares": "magasinerbar",
    "magasinerbarheten": "magasinerbarhet",
    "magasinerbarhetens": "magasinerbarhet",
    "magasinerbarhets": "magasinerbarhet",
    "magasinerbars": "magasinerbar",
    "magasinerbart": "magasinerbar",
    "magasinerbarts": "magasinerbar",
    "magasineringar": "magasinering",
    "magasineringarna": "magasinering",
    "magasineringarnas": "magasinering",
    "magasineringars": "magasinering",
    "magasineringen": "magasinering",
    "magasineringens": "magasinering",
    "magasinerings": "magasinering",
    "magasinet": "magasin",
    "magasinets": "magasin",
    "magasinkärr": "magasinkärra",
    "magasinkärran": "magasinkärra",
    "magasinkärrans": "magasinkärra",
    "magasinkärras": "magasinkärra",
    "magasinkärre": "magasinkärra",
    "magasinkärror": "magasinkärra",
    "magasinkärrorna": "magasinkärra",
    "magasinkärrornas": "magasinkärra",
    "magasinkärrors": "magasinkärra",
    "magasinkärrs": "magasinkärra",
    "magasins": "magasin",
    "magbesvären": "magbesvär",
    "magbesvärens": "magbesvär",
    "magbesväret": "magbesvär",
    "magbesvärets": "magbesvär",
    "magbesvärs": "magbesvär",
    "magborstar": "magborstare",
    "magborstaren": "magborstare",
    "magborstarens": "magborstare",
    "magborstares": "magborstare",
    "magborstarna": "magborstare",
    "magborstarnas": "magborstare",
    "magdansen": "magdans",
    "magdansens": "magdans",
    "magdanser": "magdans",
    "magdanserna": "magdans",
    "magdansernas": "magdans",
    "magdansers": "magdans",
    "magdansösen": "magdansös",
    "magdansösens": "magdansös",
    "magdansöser": "magdansös",
    "magdansöserna": "magdansös",
    "magdansösernas": "magdansös",
    "magdansösers": "magdansös",
    "magen": "mage",
    "magens": "mage",
    "magentafärgade": "magentafärgad",
    "magentafärgades": "magentafärgad",
    "magentafärgads": "magentafärgad",
    "magentafärgat": "magentafärgad",
    "magentafärgats": "magentafärgad",
    "magerlagda": "magerlagd",
    "magerlagdare": "magerlagd",
    "magerlagdares": "magerlagd",
    "magerlagdas": "magerlagd",
    "magerlagdast": "magerlagd",
    "magerlagdaste": "magerlagd",
    "magerlagdastes": "magerlagd",
    "magerlagdasts": "magerlagd",
    "magerlagde": "magerlagd",
    "magerlagdes": "magerlagd",
    "magerlagdheten": "magerlagdhet",
    "magerlagdhetens": "magerlagdhet",
    "magerlagdhets": "magerlagdhet",
    "magerlagds": "magerlagd",
    "magerlagt": "magerlagd",
    "magerlagts": "magerlagd",
    "magern": "mager",
    "magerna": "mager",
    "magernas": "mager",
    "magerns": "mager",
    "magers": "mager",
    "magert": "mager",
    "magerts": "mager",
    "mages": "mage",
    "maggropar": "maggrop",
    "maggroparna": "maggrop",
    "maggroparnas": "maggrop",
    "maggropars": "maggrop",
    "maggropen": "maggrop",
    "maggropens": "maggrop",
    "maggrops": "maggrop",
    "maggördeln": "maggördel",
    "maggördelns": "maggördel",
    "maggördels": "maggördel",
    "maggördlar": "maggördel",
    "maggördlarna": "maggördel",
    "maggördlarnas": "maggördel",
    "maggördlars": "maggördel",
    "magien": "magi",
    "magiens": "magi",
    "magiern": "magier",
    "magierna": "magier",
    "magiernas": "magier",
    "magierns": "magier",
    "magiers": "magier",
    "magikern": "magiker",
    "magikerna": "magiker",
    "magikernas": "magiker",
    "magikerns": "magiker",
    "magikers": "magiker",
    "magin": "magi",
    "maginfluens": "maginfluensa",
    "maginfluensan": "maginfluensa",
    "maginfluensans": "maginfluensa",
    "maginfluensas": "maginfluensa",
    "maginfluense": "maginfluensa",
    "maginfluensor": "maginfluensa",
    "maginfluensorna": "maginfluensa",
    "maginfluensornas": "maginfluensa",
    "maginfluensors": "maginfluensa",
    "maginnehållen": "maginnehåll",
    "maginnehållens": "maginnehåll",
    "maginnehållet": "maginnehåll",
    "maginnehållets": "maginnehåll",
    "maginnehålls": "maginnehåll",
    "magins": "magi",
    "magis": "magi",
    "magiska": "magisk",
    "magiskare": "magisk",
    "magiskares": "magisk",
    "magiskas": "magisk",
    "magiskast": "magisk",
    "magiskaste": "magisk",
    "magiskastes": "magisk",
    "magiskasts": "magisk",
    "magiske": "magisk",
    "magiskes": "magisk",
    "magisks": "magisk",
    "magiskt": "magisk",
    "magiskts": "magisk",
    "magistern": "magister",
    "magisterns": "magister",
    "magisters": "magister",
    "magistrala": "magistral",
    "magistralare": "magistral",
    "magistralares": "magistral",
    "magistralas": "magistral",
    "magistralast": "magistral",
    "magistralaste": "magistral",
    "magistralastes": "magistral",
    "magistralasts": "magistral",
    "magistrale": "magistral",
    "magistrales": "magistral",
    "magistrals": "magistral",
    "magistralt": "magistral",
    "magistralts": "magistral",
    "magistrar": "magister",
    "magistrarna": "magister",
    "magistrarnas": "magister",
    "magistrars": "magister",
    "magistraten": "magistrat",
    "magistratens": "magistrat",
    "magistrater": "magistrat",
    "magistraterna": "magistrat",
    "magistraternas": "magistrat",
    "magistraters": "magistrat",
    "magistrats": "magistrat",
    "magkatarren": "magkatarr",
    "magkatarrens": "magkatarr",
    "magkatarrer": "magkatarr",
    "magkatarrerna": "magkatarr",
    "magkatarrernas": "magkatarr",
    "magkatarrers": "magkatarr",
    "magkatarrs": "magkatarr",
    "magknipet": "magknip",
    "magknipets": "magknip",
    "magknips": "magknip",
    "maglevar": "maglev",
    "maglevarna": "maglev",
    "maglevarnas": "maglev",
    "maglevars": "maglev",
    "magleven": "maglev",
    "maglevens": "maglev",
    "maglevs": "maglev",
    "magm": "magma",
    "magmabergarten": "magmabergart",
    "magmabergartens": "magmabergart",
    "magmabergarter": "magmabergart",
    "magmabergarterna": "magmabergart",
    "magmabergarternas": "magmabergart",
    "magmabergarters": "magmabergart",
    "magmabergarts": "magmabergart",
    "magmaexplosionen": "magmaexplosion",
    "magmaexplosionens": "magmaexplosion",
    "magmaexplosioner": "magmaexplosion",
    "magmaexplosionerna": "magmaexplosion",
    "magmaexplosionernas": "magmaexplosion",
    "magmaexplosioners": "magmaexplosion",
    "magmaexplosions": "magmaexplosion",
    "magmakammar": "magmakammare",
    "magmakammaren": "magmakammare",
    "magmakammarens": "magmakammare",
    "magmakammares": "magmakammare",
    "magmakamrar": "magmakammare",
    "magmakamrarna": "magmakammare",
    "magmakamrarnas": "magmakammare",
    "magmakamrars": "magmakammare",
    "magman": "magma",
    "magmans": "magma",
    "magmas": "magma",
    "magme": "magma",
    "magmedicinen": "magmedicin",
    "magmedicinens": "magmedicin",
    "magmediciner": "magmedicin",
    "magmedicinerna": "magmedicin",
    "magmedicinernas": "magmedicin",
    "magmediciners": "magmedicin",
    "magmedicins": "magmedicin",
    "magmor": "magma",
    "magmorna": "magma",
    "magmornas": "magma",
    "magmors": "magma",
    "magms": "magma",
    "magmunnar": "magmun",
    "magmunnarna": "magmun",
    "magmunnarnas": "magmun",
    "magmunnars": "magmun",
    "magmunnen": "magmun",
    "magmunnens": "magmun",
    "magmuns": "magmun",
    "magmuskeln": "magmuskel",
    "magmuskelns": "magmuskel",
    "magmuskels": "magmuskel",
    "magmuskler": "magmuskel",
    "magmusklerna": "magmuskel",
    "magmusklernas": "magmuskel",
    "magmusklers": "magmuskel",
    "magnaten": "magnat",
    "magnatens": "magnat",
    "magnater": "magnat",
    "magnaterna": "magnat",
    "magnaternas": "magnat",
    "magnaters": "magnat",
    "magnats": "magnat",
    "magnecylen": "magnecyl",
    "magnecylens": "magnecyl",
    "magnecyls": "magnecyl",
    "magnesiet": "magnesium",
    "magnesiets": "magnesium",
    "magnesiten": "magnesit",
    "magnesitens": "magnesit",
    "magnesits": "magnesit",
    "magnesiumet": "magnesium",
    "magnesiumets": "magnesium",
    "magnesiumhusen": "magnesiumhus",
    "magnesiumhusens": "magnesiumhus",
    "magnesiumhuset": "magnesiumhus",
    "magnesiumhusets": "magnesiumhus",
    "magnesiumlegeringar": "magnesiumlegering",
    "magnesiumlegeringarna": "magnesiumlegering",
    "magnesiumlegeringarnas": "magnesiumlegering",
    "magnesiumlegeringars": "magnesiumlegering",
    "magnesiumlegeringen": "magnesiumlegering",
    "magnesiumlegeringens": "magnesiumlegering",
    "magnesiumlegerings": "magnesiumlegering",
    "magnesiums": "magnesium",
    "magnesiumsulfaten": "magnesiumsulfat",
    "magnesiumsulfatens": "magnesiumsulfat",
    "magnesiumsulfater": "magnesiumsulfat",
    "magnesiumsulfaterna": "magnesiumsulfat",
    "magnesiumsulfaternas": "magnesiumsulfat",
    "magnesiumsulfaters": "magnesiumsulfat",
    "magnesiumsulfatet": "magnesiumsulfat",
    "magnesiumsulfatets": "magnesiumsulfat",
    "magnesiumsulfats": "magnesiumsulfat",
    "magnetapparaten": "magnetapparat",
    "magnetapparatens": "magnetapparat",
    "magnetapparater": "magnetapparat",
    "magnetapparaterna": "magnetapparat",
    "magnetapparaternas": "magnetapparat",
    "magnetapparaters": "magnetapparat",
    "magnetapparats": "magnetapparat",
    "magnetbanden": "magnetband",
    "magnetbandens": "magnetband",
    "magnetbandet": "magnetband",
    "magnetbandets": "magnetband",
    "magnetbands": "magnetband",
    "magneten": "magnet",
    "magnetens": "magnet",
    "magneter": "magnet",
    "magneterna": "magnet",
    "magneternas": "magnet",
    "magneters": "magnet",
    "magnetfälten": "magnetfält",
    "magnetfältens": "magnetfält",
    "magnetfältet": "magnetfält",
    "magnetfältets": "magnetfält",
    "magnetfälts": "magnetfält",
    "magnetiserad": "magnetisera",
    "magnetiserade": "magnetisera",
    "magnetiserades": "magnetisera",
    "magnetiserads": "magnetisera",
    "magnetiserande": "magnetisera",
    "magnetiseranden": "magnetiserande",
    "magnetiserandena": "magnetiserande",
    "magnetiserandenas": "magnetiserande",
    "magnetiserandens": "magnetiserande",
    "magnetiserandes": "magnetiserande",
    "magnetiserandet": "magnetiserande",
    "magnetiserandets": "magnetiserande",
    "magnetiserar": "magnetisera",
    "magnetiseras": "magnetisera",
    "magnetiserat": "magnetisera",
    "magnetiserats": "magnetisera",
    "magnetiserbara": "magnetiserbar",
    "magnetiserbarare": "magnetiserbar",
    "magnetiserbarares": "magnetiserbar",
    "magnetiserbaras": "magnetiserbar",
    "magnetiserbarast": "magnetiserbar",
    "magnetiserbaraste": "magnetiserbar",
    "magnetiserbarastes": "magnetiserbar",
    "magnetiserbarasts": "magnetiserbar",
    "magnetiserbare": "magnetiserbar",
    "magnetiserbares": "magnetiserbar",
    "magnetiserbarheten": "magnetiserbarhet",
    "magnetiserbarhetens": "magnetiserbarhet",
    "magnetiserbarhets": "magnetiserbarhet",
    "magnetiserbars": "magnetiserbar",
    "magnetiserbart": "magnetiserbar",
    "magnetiserbarts": "magnetiserbar",
    "magnetiseringar": "magnetisering",
    "magnetiseringarna": "magnetisering",
    "magnetiseringarnas": "magnetisering",
    "magnetiseringars": "magnetisering",
    "magnetiseringen": "magnetisering",
    "magnetiseringens": "magnetisering",
    "magnetiserings": "magnetisering",
    "magnetiska": "magnetisk",
    "magnetiskare": "magnetisk",
    "magnetiskares": "magnetisk",
    "magnetiskas": "magnetisk",
    "magnetiskast": "magnetisk",
    "magnetiskaste": "magnetisk",
    "magnetiskastes": "magnetisk",
    "magnetiskasts": "magnetisk",
    "magnetiske": "magnetisk",
    "magnetiskes": "magnetisk",
    "magnetisks": "magnetisk",
    "magnetiskt": "magnetisk",
    "magnetiskts": "magnetisk",
    "magnetismen": "magnetism",
    "magnetismens": "magnetism",
    "magnetismer": "magnetism",
    "magnetismerna": "magnetism",
    "magnetismernas": "magnetism",
    "magnetismers": "magnetism",
    "magnetisms": "magnetism",
    "magnetisören": "magnetisör",
    "magnetisörens": "magnetisör",
    "magnetisörer": "magnetisör",
    "magnetisörerna": "magnetisör",
    "magnetisörernas": "magnetisör",
    "magnetisörers": "magnetisör",
    "magnetisörs": "magnetisör",
    "magnetiten": "magnetit",
    "magnetitens": "magnetit",
    "magnetits": "magnetit",
    "magnetkompassen": "magnetkompass",
    "magnetkompassens": "magnetkompass",
    "magnetkompasser": "magnetkompass",
    "magnetkompasserna": "magnetkompass",
    "magnetkompassernas": "magnetkompass",
    "magnetkompassers": "magnetkompass",
    "magnetkorten": "magnetkort",
    "magnetkortens": "magnetkort",
    "magnetkortet": "magnetkort",
    "magnetkortets": "magnetkort",
    "magnetkorts": "magnetkort",
    "magnetmin": "magnetmina",
    "magnetminan": "magnetmina",
    "magnetminans": "magnetmina",
    "magnetminas": "magnetmina",
    "magnetmine": "magnetmina",
    "magnetminor": "magnetmina",
    "magnetminorna": "magnetmina",
    "magnetminornas": "magnetmina",
    "magnetminors": "magnetmina",
    "magnetmins": "magnetmina",
    "magnetnålar": "magnetnål",
    "magnetnålarna": "magnetnål",
    "magnetnålarnas": "magnetnål",
    "magnetnålars": "magnetnål",
    "magnetnålen": "magnetnål",
    "magnetnålens": "magnetnål",
    "magnetnåls": "magnetnål",
    "magnetofonen": "magnetofon",
    "magnetofonens": "magnetofon",
    "magnetofoner": "magnetofon",
    "magnetofonerna": "magnetofon",
    "magnetofonernas": "magnetofon",
    "magnetofoners": "magnetofon",
    "magnetofons": "magnetofon",
    "magnetpolen": "magnetpol",
    "magnetpolens": "magnetpol",
    "magnetpoler": "magnetpol",
    "magnetpolerna": "magnetpol",
    "magnetpolernas": "magnetpol",
    "magnetpolers": "magnetpol",
    "magnetpols": "magnetpol",
    "magnetrems": "magnetremsa",
    "magnetremsan": "magnetremsa",
    "magnetremsans": "magnetremsa",
    "magnetremsas": "magnetremsa",
    "magnetremse": "magnetremsa",
    "magnetremsor": "magnetremsa",
    "magnetremsorna": "magnetremsa",
    "magnetremsornas": "magnetremsa",
    "magnetremsors": "magnetremsa",
    "magnetronen": "magnetron",
    "magnetronens": "magnetron",
    "magnetroner": "magnetron",
    "magnetronerna": "magnetron",
    "magnetronernas": "magnetron",
    "magnetroners": "magnetron",
    "magnetrons": "magnetron",
    "magnets": "magnet",
    "magnettändningar": "magnettändning",
    "magnettändningarna": "magnettändning",
    "magnettändningarnas": "magnettändning",
    "magnettändningars": "magnettändning",
    "magnettändningen": "magnettändning",
    "magnettändningens": "magnettändning",
    "magnettändnings": "magnettändning",
    "magnificensen": "magnificens",
    "magnificensens": "magnificens",
    "magnifika": "magnifik",
    "magnifikare": "magnifik",
    "magnifikares": "magnifik",
    "magnifikas": "magnifik",
    "magnifikast": "magnifik",
    "magnifikaste": "magnifik",
    "magnifikastes": "magnifik",
    "magnifikasts": "magnifik",
    "magnifike": "magnifik",
    "magnifikes": "magnifik",
    "magnifiks": "magnifik",
    "magnifikt": "magnifik",
    "magnifikts": "magnifik",
    "magnituden": "magnitud",
    "magnitudens": "magnitud",
    "magnituder": "magnitud",
    "magnituderna": "magnitud",
    "magnitudernas": "magnitud",
    "magnituders": "magnitud",
    "magnituds": "magnitud",
    "magnoli": "magnolia",
    "magnolian": "magnolia",
    "magnolians": "magnolia",
    "magnolias": "magnolia",
    "magnolie": "magnolia",
    "magnolior": "magnolia",
    "magnoliorna": "magnolia",
    "magnoliornas": "magnolia",
    "magnoliors": "magnolia",
    "magnolis": "magnolia",
    "magnumbuteljen": "magnumbutelj",
    "magnumbuteljens": "magnumbutelj",
    "magnumbuteljer": "magnumbutelj",
    "magnumbuteljerna": "magnumbutelj",
    "magnumbuteljernas": "magnumbutelj",
    "magnumbuteljers": "magnumbutelj",
    "magnumbuteljs": "magnumbutelj",
    "magplasken": "magplask",
    "magplaskens": "magplask",
    "magplasket": "magplask",
    "magplaskets": "magplask",
    "magplasks": "magplask",
    "magpump": "magpumpa",
    "magpumpad": "magpumpa",
    "magpumpade": "magpumpa",
    "magpumpades": "magpumpa",
    "magpumpads": "magpumpa",
    "magpumpande": "magpumpa",
    "magpumpanden": "magpumpande",
    "magpumpandena": "magpumpande",
    "magpumpandenas": "magpumpande",
    "magpumpandens": "magpumpande",
    "magpumpandes": "magpumpande",
    "magpumpandet": "magpumpande",
    "magpumpandets": "magpumpande",
    "magpumpar": "magpumpa",
    "magpumpas": "magpumpa",
    "magpumpat": "magpumpa",
    "magpumpats": "magpumpa",
    "magra": "mager",
    "magrade": "magra",
    "magrades": "magra",
    "magrande": "magra",
    "magranden": "magrande",
    "magrandena": "magrande",
    "magrandenas": "magrande",
    "magrandens": "magrande",
    "magrandes": "magrande",
    "magrandet": "magrande",
    "magrandets": "magrande",
    "magrar": "magra",
    "magrare": "mager",
    "magrares": "mager",
    "magras": "magra",
    "magrast": "mager",
    "magraste": "mager",
    "magrastes": "mager",
    "magrasts": "mager",
    "magrat": "magra",
    "magrats": "magra",
    "magre": "mager",
    "magres": "mager",
    "magröntgenen": "magröntgen",
    "magröntgenens": "magröntgen",
    "magröntgens": "magröntgen",
    "mags": "mage",
    "magsaften": "magsaft",
    "magsaftens": "magsaft",
    "magsafter": "magsaft",
    "magsafterna": "magsaft",
    "magsafternas": "magsaft",
    "magsafters": "magsaft",
    "magsafts": "magsaft",
    "magsjuk": "magsjuka",
    "magsjukan": "magsjuka",
    "magsjukans": "magsjuka",
    "magsjukas": "magsjuka",
    "magsjukdomar": "magsjukdom",
    "magsjukdomarna": "magsjukdom",
    "magsjukdomarnas": "magsjukdom",
    "magsjukdomars": "magsjukdom",
    "magsjukdomen": "magsjukdom",
    "magsjukdomens": "magsjukdom",
    "magsjukdoms": "magsjukdom",
    "magsjuke": "magsjuka",
    "magsjukor": "magsjuka",
    "magsjukorna": "magsjuka",
    "magsjukornas": "magsjuka",
    "magsjukors": "magsjuka",
    "magsjuks": "magsjuka",
    "magsmittan": "magsmitta",
    "magsmittans": "magsmitta",
    "magsmittas": "magsmitta",
    "magsmitte": "magsmitta",
    "magsmittor": "magsmitta",
    "magsmittorna": "magsmitta",
    "magsmittornas": "magsmitta",
    "magsmittors": "magsmitta",
    "magstarka": "magstark",
    "magstarkare": "magstark",
    "magstarkares": "magstark",
    "magstarkas": "magstark",
    "magstarkast": "magstark",
    "magstarkaste": "magstark",
    "magstarkastes": "magstark",
    "magstarkasts": "magstark",
    "magstarke": "magstark",
    "magstarkes": "magstark",
    "magstarkheten": "magstarkhet",
    "magstarkhetens": "magstarkhet",
    "magstarkhets": "magstarkhet",
    "magstarks": "magstark",
    "magstarkt": "magstark",
    "magstarkts": "magstark",
    "magsura": "magsur",
    "magsurare": "magsur",
    "magsurares": "magsur",
    "magsuras": "magsur",
    "magsurast": "magsur",
    "magsuraste": "magsur",
    "magsurastes": "magsur",
    "magsurasts": "magsur",
    "magsure": "magsur",
    "magsures": "magsur",
    "magsurheten": "magsurhet",
    "magsurhetens": "magsurhet",
    "magsurhets": "magsurhet",
    "magsurs": "magsur",
    "magsurt": "magsur",
    "magsurts": "magsur",
    "magsyran": "magsyra",
    "magsyrans": "magsyra",
    "magsyras": "magsyra",
    "magsyre": "magsyra",
    "magsyror": "magsyra",
    "magsyrorna": "magsyra",
    "magsyrornas": "magsyra",
    "magsyrors": "magsyra",
    "magsäckar": "magsäck",
    "magsäckarna": "magsäck",
    "magsäckarnas": "magsäck",
    "magsäckars": "magsäck",
    "magsäcken": "magsäck",
    "magsäckens": "magsäck",
    "magsäcks": "magsäck",
    "magsåren": "magsår",
    "magsårens": "magsår",
    "magsåret": "magsår",
    "magsårets": "magsår",
    "magsårs": "magsår",
    "magsårsbakterien": "magsårsbakterie",
    "magsårsbakteriens": "magsårsbakterie",
    "magsårsbakterier": "magsårsbakterie",
    "magsårsbakterierna": "magsårsbakterie",
    "magsårsbakteriernas": "magsårsbakterie",
    "magsårsbakteriers": "magsårsbakterie",
    "magsårsbakteries": "magsårsbakterie",
    "magtrakten": "magtrakt",
    "magtraktens": "magtrakt",
    "magtrakter": "magtrakt",
    "magtrakterna": "magtrakt",
    "magtrakternas": "magtrakt",
    "magtrakters": "magtrakt",
    "magtrakts": "magtrakt",
    "magyaren": "magyar",
    "magyarens": "magyar",
    "magyarer": "magyar",
    "magyarerna": "magyar",
    "magyarernas": "magyar",
    "magyarers": "magyar",
    "magyars": "magyar",
    "magövningar": "magövning",
    "magövningarna": "magövning",
    "magövningarnas": "magövning",
    "magövningars": "magövning",
    "magövningen": "magövning",
    "magövningens": "magövning",
    "magövnings": "magövning",
    "maharadjan": "maharadja",
    "maharadjans": "maharadja",
    "maharadjas": "maharadja",
    "maharadje": "maharadja",
    "maharadjor": "maharadja",
    "maharadjorna": "maharadja",
    "maharadjornas": "maharadja",
    "maharadjors": "maharadja",
    "mahatm": "mahatma",
    "mahatman": "mahatma",
    "mahatmans": "mahatma",
    "mahatmas": "mahatma",
    "mahatme": "mahatma",
    "mahatmor": "mahatma",
    "mahatmorna": "mahatma",
    "mahatmornas": "mahatma",
    "mahatmors": "mahatma",
    "mahatms": "mahatma",
    "mahjongen": "mahjong",
    "mahjongens": "mahjong",
    "mahjongs": "mahjong",
    "mahognyfanerade": "mahognyfanerad",
    "mahognyfanerades": "mahognyfanerad",
    "mahognyfanerads": "mahognyfanerad",
    "mahognyfanerat": "mahognyfanerad",
    "mahognyfanerats": "mahognyfanerad",
    "mahognyfaneren": "mahognyfaner",
    "mahognyfanerens": "mahognyfaner",
    "mahognyfaneret": "mahognyfaner",
    "mahognyfanerets": "mahognyfaner",
    "mahognyfaners": "mahognyfaner",
    "mahognyfanéren": "mahognyfanér",
    "mahognyfanérens": "mahognyfanér",
    "mahognyfanéret": "mahognyfanér",
    "mahognyfanérets": "mahognyfanér",
    "mahognyfanérs": "mahognyfanér",
    "mahognylaminatdörrar": "mahognylaminatdörr",
    "mahognylaminatdörrarna": "mahognylaminatdörr",
    "mahognylaminatdörrarnas": "mahognylaminatdörr",
    "mahognylaminatdörrars": "mahognylaminatdörr",
    "mahognylaminatdörren": "mahognylaminatdörr",
    "mahognylaminatdörrens": "mahognylaminatdörr",
    "mahognylaminatdörrs": "mahognylaminatdörr",
    "mahognylaminaten": "mahognylaminat",
    "mahognylaminatens": "mahognylaminat",
    "mahognylaminatet": "mahognylaminat",
    "mahognylaminatets": "mahognylaminat",
    "mahognylaminats": "mahognylaminat",
    "mahognyn": "mahogny",
    "mahognyns": "mahogny",
    "mahognys": "mahogny",
    "mahognyt": "mahogny",
    "mahognyts": "mahogny",
    "mahoni": "mahonia",
    "mahonian": "mahonia",
    "mahonians": "mahonia",
    "mahonias": "mahonia",
    "mahonie": "mahonia",
    "mahonior": "mahonia",
    "mahoniorna": "mahonia",
    "mahoniornas": "mahonia",
    "mahoniors": "mahonia",
    "mahonis": "mahonia",
    "mailad": "maila",
    "mailade": "maila",
    "mailades": "maila",
    "mailads": "maila",
    "mailande": "maila",
    "mailanden": "mailande",
    "mailandena": "mailande",
    "mailandenas": "mailande",
    "mailandens": "mailande",
    "mailandes": "mailande",
    "mailandet": "mailande",
    "mailandets": "mailande",
    "mailar": "mailare",
    "mailaren": "mailare",
    "mailarens": "mailare",
    "mailares": "mailare",
    "mailarna": "mailare",
    "mailarnas": "mailare",
    "mailas": "maila",
    "mailat": "maila",
    "mailats": "maila",
    "mailen": "mail",
    "mailens": "mail",
    "mailet": "mail",
    "mailets": "mail",
    "mails": "mail",
    "maj": "maja",
    "majad": "maja",
    "majade": "maja",
    "majades": "maja",
    "majads": "maja",
    "majande": "maja",
    "majanden": "majande",
    "majandena": "majande",
    "majandenas": "majande",
    "majandens": "majande",
    "majandes": "majande",
    "majandet": "majande",
    "majandets": "majande",
    "majar": "maja",
    "majas": "maja",
    "majat": "maja",
    "majats": "maja",
    "majbagg": "majbagge",
    "majbaggar": "majbagge",
    "majbaggarna": "majbagge",
    "majbaggarnas": "majbagge",
    "majbaggars": "majbagge",
    "majbaggen": "majbagge",
    "majbaggens": "majbagge",
    "majbagges": "majbagge",
    "majbaggs": "majbagge",
    "majblom": "majblomma",
    "majblomman": "majblomma",
    "majblommans": "majblomma",
    "majblommas": "majblomma",
    "majblomme": "majblomma",
    "majblommor": "majblomma",
    "majblommorna": "majblomma",
    "majblommornas": "majblomma",
    "majblommors": "majblomma",
    "majbloms": "majblomma",
    "majbrudar": "majbrud",
    "majbrudarna": "majbrud",
    "majbrudarnas": "majbrud",
    "majbrudars": "majbrud",
    "majbruden": "majbrud",
    "majbrudens": "majbrud",
    "majbruds": "majbrud",
    "majen": "maj",
    "majens": "maj",
    "majestäten": "majestät",
    "majestätens": "majestät",
    "majestäter": "majestät",
    "majestäterna": "majestät",
    "majestäternas": "majestät",
    "majestäters": "majestät",
    "majestätet": "majestät",
    "majestätets": "majestät",
    "majestätiska": "majestätisk",
    "majestätiskare": "majestätisk",
    "majestätiskares": "majestätisk",
    "majestätiskas": "majestätisk",
    "majestätiskast": "majestätisk",
    "majestätiskaste": "majestätisk",
    "majestätiskastes": "majestätisk",
    "majestätiskasts": "majestätisk",
    "majestätiske": "majestätisk",
    "majestätiskes": "majestätisk",
    "majestätisks": "majestätisk",
    "majestätiskt": "majestätisk",
    "majestätiskts": "majestätisk",
    "majestäts": "majestät",
    "majestätsbrotten": "majestätsbrott",
    "majestätsbrottens": "majestätsbrott",
    "majestätsbrottet": "majestätsbrott",
    "majestätsbrottets": "majestätsbrott",
    "majestätsbrotts": "majestätsbrott",
    "majestätsförbrytelsen": "majestätsförbrytelse",
    "majestätsförbrytelsens": "majestätsförbrytelse",
    "majestätsförbrytelser": "majestätsförbrytelse",
    "majestätsförbrytelserna": "majestätsförbrytelse",
    "majestätsförbrytelsernas": "majestätsförbrytelse",
    "majestätsförbrytelsers": "majestätsförbrytelse",
    "majestätsförbrytelses": "majestätsförbrytelse",
    "majmorgnar": "majmorgon",
    "majmorgnarna": "majmorgon",
    "majmorgnarnas": "majmorgon",
    "majmorgnars": "majmorgon",
    "majmorgonen": "majmorgon",
    "majmorgonens": "majmorgon",
    "majmorgonhimlar": "majmorgonhimmel",
    "majmorgonhimlarna": "majmorgonhimmel",
    "majmorgonhimlarnas": "majmorgonhimmel",
    "majmorgonhimlars": "majmorgonhimmel",
    "majmorgonhimlen": "majmorgonhimmel",
    "majmorgonhimlens": "majmorgonhimmel",
    "majmorgonhimmelen": "majmorgonhimmel",
    "majmorgonhimmelens": "majmorgonhimmel",
    "majmorgonhimmeln": "majmorgonhimmel",
    "majmorgonhimmelns": "majmorgonhimmel",
    "majmorgonhimmels": "majmorgonhimmel",
    "majmorgons": "majmorgon",
    "majmornar": "majmorgon",
    "majmornarna": "majmorgon",
    "majmornarnas": "majmorgon",
    "majmornars": "majmorgon",
    "majolikan": "majolika",
    "majolikans": "majolika",
    "majolikas": "majolika",
    "majonnäsen": "majonnäs",
    "majonnäsens": "majonnäs",
    "majonnäser": "majonnäs",
    "majonnäserna": "majonnäs",
    "majonnäsernas": "majonnäs",
    "majonnäsers": "majonnäs",
    "majonnässåsen": "majonnässås",
    "majonnässåsens": "majonnässås",
    "majonnässåser": "majonnässås",
    "majonnässåserna": "majonnässås",
    "majonnässåsernas": "majonnässås",
    "majonnässåsers": "majonnässås",
    "majoren": "major",
    "majorens": "major",
    "majorer": "major",
    "majorerna": "major",
    "majorernas": "major",
    "majorers": "major",
    "majoriteten": "majoritet",
    "majoritetens": "majoritet",
    "majoriteter": "majoritet",
    "majoriteterna": "majoritet",
    "majoriteternas": "majoritet",
    "majoriteters": "majoritet",
    "majoritets": "majoritet",
    "majoritetsförtrycket": "majoritetsförtryck",
    "majoritetsförtryckets": "majoritetsförtryck",
    "majoritetsförtrycks": "majoritetsförtryck",
    "majoritetsregeringar": "majoritetsregering",
    "majoritetsregeringarna": "majoritetsregering",
    "majoritetsregeringarnas": "majoritetsregering",
    "majoritetsregeringars": "majoritetsregering",
    "majoritetsregeringen": "majoritetsregering",
    "majoritetsregeringens": "majoritetsregering",
    "majoritetsregerings": "majoritetsregering",
    "majoritetssamhällen": "majoritetssamhälle",
    "majoritetssamhällena": "majoritetssamhälle",
    "majoritetssamhällenas": "majoritetssamhälle",
    "majoritetssamhällens": "majoritetssamhälle",
    "majoritetssamhälles": "majoritetssamhälle",
    "majoritetssamhället": "majoritetssamhälle",
    "majoritetssamhällets": "majoritetssamhälle",
    "majoritetssamhälls": "majoritetssamhälle",
    "majoritetsvalen": "majoritetsval",
    "majoritetsvalens": "majoritetsval",
    "majoritetsvalet": "majoritetsval",
    "majoritetsvalets": "majoritetsval",
    "majoritetsvals": "majoritetsval",
    "majorn": "major",
    "majorns": "major",
    "majors": "major",
    "majs": "maj",
    "majsen": "majs",
    "majsenan": "majsena",
    "majsenans": "majsena",
    "majsenas": "majsena",
    "majsens": "majs",
    "majsfling": "majsflinga",
    "majsflingan": "majsflinga",
    "majsflingans": "majsflinga",
    "majsflingas": "majsflinga",
    "majsflinge": "majsflinga",
    "majsflingor": "majsflinga",
    "majsflingorna": "majsflinga",
    "majsflingornas": "majsflinga",
    "majsflingors": "majsflinga",
    "majsflings": "majsflinga",
    "majsgrötar": "majsgröt",
    "majsgrötarna": "majsgröt",
    "majsgrötarnas": "majsgröt",
    "majsgrötars": "majsgröt",
    "majsgröten": "majsgröt",
    "majsgrötens": "majsgröt",
    "majsgröts": "majsgröt",
    "majsjukan": "majsjuka",
    "majsjukans": "majsjuka",
    "majsjukas": "majsjuka",
    "majsjuke": "majsjuka",
    "majsjuks": "majsjuka",
    "majskolvar": "majskolv",
    "majskolvarna": "majskolv",
    "majskolvarnas": "majskolv",
    "majskolvars": "majskolv",
    "majskolven": "majskolv",
    "majskolvens": "majskolv",
    "majskolvs": "majskolv",
    "majskornen": "majskorn",
    "majskornens": "majskorn",
    "majskornet": "majskorn",
    "majskornets": "majskorn",
    "majskorns": "majskorn",
    "majsmjölet": "majsmjöl",
    "majsmjölets": "majsmjöl",
    "majsmjöls": "majsmjöl",
    "majstänger": "majstång",
    "majstängerna": "majstång",
    "majstängernas": "majstång",
    "majstängers": "majstång",
    "majstången": "majstång",
    "majstångens": "majstång",
    "majstångs": "majstång",
    "majsölen": "majsöl",
    "majsölens": "majsöl",
    "majsöler": "majsöl",
    "majsölerna": "majsöl",
    "majsölernas": "majsöl",
    "majsölers": "majsöl",
    "majsölet": "majsöl",
    "majsölets": "majsöl",
    "majsöls": "majsöl",
    "majsölsberusade": "majsölsberusad",
    "majsölsberusades": "majsölsberusad",
    "majsölsberusads": "majsölsberusad",
    "majsölsberusat": "majsölsberusad",
    "majsölsberusats": "majsölsberusad",
    "majuskeln": "majuskel",
    "majuskelns": "majuskel",
    "majuskels": "majuskel",
    "majuskler": "majuskel",
    "majusklerna": "majuskel",
    "majusklernas": "majuskel",
    "majusklers": "majuskel",
    "mak": "maka",
    "makaberheten": "makaberhet",
    "makaberhetens": "makaberhet",
    "makaberhets": "makaberhet",
    "makabers": "makaber",
    "makabert": "makaber",
    "makaberts": "makaber",
    "makabra": "makaber",
    "makabrare": "makaber",
    "makabrares": "makaber",
    "makabras": "makaber",
    "makabrast": "makaber",
    "makabraste": "makaber",
    "makabrastes": "makaber",
    "makabrasts": "makaber",
    "makabre": "makaber",
    "makabres": "makaber",
    "makad": "maka",
    "makadamen": "makadam",
    "makadamens": "makadam",
    "makadammen": "makadam",
    "makadammens": "makadam",
    "makadams": "makadam",
    "makade": "maka",
    "makades": "maka",
    "makads": "maka",
    "makalösa": "makalös",
    "makalösare": "makalös",
    "makalösares": "makalös",
    "makalösas": "makalös",
    "makalösast": "makalös",
    "makalösaste": "makalös",
    "makalösastes": "makalös",
    "makalösasts": "makalös",
    "makalöse": "makalös",
    "makalöses": "makalös",
    "makalösheten": "makalöshet",
    "makalöshetens": "makalöshet",
    "makalösheter": "makalöshet",
    "makalösheterna": "makalöshet",
    "makalösheternas": "makalöshet",
    "makalösheters": "makalöshet",
    "makalöshets": "makalöshet",
    "makalöst": "makalös",
    "makalösts": "makalös",
    "makan": "maka",
    "makande": "maka",
    "makanden": "makande",
    "makandena": "makande",
    "makandenas": "makande",
    "makandens": "makande",
    "makandes": "makande",
    "makandet": "makande",
    "makandets": "makande",
    "makans": "maka",
    "makar": "make",
    "makarna": "make",
    "makarnas": "make",
    "makaron": "makaroner",
    "makaronerna": "makaroner",
    "makaronernas": "makaroner",
    "makaroners": "makaroner",
    "makaronina": "makaroni",
    "makaroninas": "makaroni",
    "makaronis": "makaroni",
    "makarons": "makaroner",
    "makars": "make",
    "makas": "maka",
    "makassaroljan": "makassarolja",
    "makassaroljans": "makassarolja",
    "makassaroljas": "makassarolja",
    "makassarolje": "makassarolja",
    "makassaroljor": "makassarolja",
    "makassaroljorna": "makassarolja",
    "makassaroljornas": "makassarolja",
    "makassaroljors": "makassarolja",
    "makat": "maka",
    "makats": "maka",
    "make": "maka",
    "makedoniern": "makedonier",
    "makedonierna": "makedonier",
    "makedoniernas": "makedonier",
    "makedonierns": "makedonier",
    "makedoniers": "makedonier",
    "makedoniska": "makedonisk",
    "makedoniskan": "makedoniska",
    "makedoniskans": "makedoniska",
    "makedoniskare": "makedonisk",
    "makedoniskares": "makedonisk",
    "makedoniskas": "makedoniska",
    "makedoniskast": "makedonisk",
    "makedoniskaste": "makedonisk",
    "makedoniskastes": "makedonisk",
    "makedoniskasts": "makedonisk",
    "makedoniske": "makedoniska",
    "makedoniskes": "makedonisk",
    "makedoniskor": "makedoniska",
    "makedoniskorna": "makedoniska",
    "makedoniskornas": "makedoniska",
    "makedoniskors": "makedoniska",
    "makedonisks": "makedonisk",
    "makedoniskt": "makedonisk",
    "makedoniskts": "makedonisk",
    "makedonsk": "makedonska",
    "makedonska": "makedonsk",
    "makedonskan": "makedonska",
    "makedonskans": "makedonska",
    "makedonskare": "makedonsk",
    "makedonskares": "makedonsk",
    "makedonskas": "makedonska",
    "makedonskast": "makedonsk",
    "makedonskaste": "makedonsk",
    "makedonskastes": "makedonsk",
    "makedonskasts": "makedonsk",
    "makedonske": "makedonska",
    "makedonskes": "makedonsk",
    "makedonskor": "makedonska",
    "makedonskorna": "makedonska",
    "makedonskornas": "makedonska",
    "makedonskors": "makedonska",
    "makedonsks": "makedonsk",
    "makedonskt": "makedonsk",
    "makedonskts": "makedonsk",
    "maken": "make",
    "makens": "make",
    "makes": "make",
    "makliga": "maklig",
    "makligare": "maklig",
    "makligares": "maklig",
    "makligas": "maklig",
    "makligast": "maklig",
    "makligaste": "maklig",
    "makligastes": "maklig",
    "makligasts": "maklig",
    "maklige": "maklig",
    "makliges": "maklig",
    "makligheten": "maklighet",
    "maklighetens": "maklighet",
    "maklighets": "maklighet",
    "makligs": "maklig",
    "makligt": "maklig",
    "makligts": "maklig",
    "makon": "mako",
    "makons": "mako",
    "makor": "maka",
    "makorna": "maka",
    "makornas": "maka",
    "makors": "maka",
    "makos": "mako",
    "makramén": "makramé",
    "makraméns": "makramé",
    "makramés": "makramé",
    "makrillar": "makrill",
    "makrillarna": "makrill",
    "makrillarnas": "makrill",
    "makrillars": "makrill",
    "makrillen": "makrill",
    "makrillens": "makrill",
    "makrills": "makrill",
    "makroklimaten": "makroklimat",
    "makroklimatens": "makroklimat",
    "makroklimatet": "makroklimat",
    "makroklimatets": "makroklimat",
    "makroklimats": "makroklimat",
    "makronen": "makron",
    "makronens": "makron",
    "makroner": "makron",
    "makronerna": "makron",
    "makronernas": "makron",
    "makroners": "makron",
    "makrons": "makron",
    "makroskopiska": "makroskopisk",
    "makroskopiskare": "makroskopisk",
    "makroskopiskares": "makroskopisk",
    "makroskopiskas": "makroskopisk",
    "makroskopiskast": "makroskopisk",
    "makroskopiskaste": "makroskopisk",
    "makroskopiskastes": "makroskopisk",
    "makroskopiskasts": "makroskopisk",
    "makroskopiske": "makroskopisk",
    "makroskopiskes": "makroskopisk",
    "makroskopisks": "makroskopisk",
    "makroskopiskt": "makroskopisk",
    "makroskopiskts": "makroskopisk",
    "maks": "maka",
    "maktanspråken": "maktanspråk",
    "maktanspråkens": "maktanspråk",
    "maktanspråket": "maktanspråk",
    "maktanspråkets": "maktanspråk",
    "maktanspråks": "maktanspråk",
    "maktbalansen": "maktbalans",
    "maktbalansens": "maktbalans",
    "maktbalanser": "maktbalans",
    "maktbalanserna": "maktbalans",
    "maktbalansernas": "maktbalans",
    "maktbalansers": "maktbalans",
    "maktbasen": "maktbas",
    "maktbasens": "maktbas",
    "maktbaser": "maktbas",
    "maktbaserna": "maktbas",
    "maktbasernas": "maktbas",
    "maktbasers": "maktbas",
    "maktbefogenheten": "maktbefogenhet",
    "maktbefogenhetens": "maktbefogenhet",
    "maktbefogenheter": "maktbefogenhet",
    "maktbefogenheterna": "maktbefogenhet",
    "maktbefogenheternas": "maktbefogenhet",
    "maktbefogenheters": "maktbefogenhet",
    "maktbefogenhets": "maktbefogenhet",
    "maktbegäret": "maktbegär",
    "maktbegärets": "maktbegär",
    "maktbegärs": "maktbegär",
    "maktblocken": "maktblock",
    "maktblockens": "maktblock",
    "maktblocket": "maktblock",
    "maktblockets": "maktblock",
    "maktblocks": "maktblock",
    "maktcentra": "maktcentrum",
    "maktcentrana": "maktcentrum",
    "maktcentranas": "maktcentrum",
    "maktcentras": "maktcentrum",
    "maktcentrer": "maktcentrum",
    "maktcentrerna": "maktcentrum",
    "maktcentrernas": "maktcentrum",
    "maktcentrers": "maktcentrum",
    "maktcentret": "maktcentrum",
    "maktcentrets": "maktcentrum",
    "maktcentrumen": "maktcentrum",
    "maktcentrumens": "maktcentrum",
    "maktcentrumet": "maktcentrum",
    "maktcentrumets": "maktcentrum",
    "maktcentrums": "maktcentrum",
    "makten": "makt",
    "maktens": "makt",
    "makter": "makt",
    "makterna": "makt",
    "makternas": "makt",
    "makters": "makt",
    "maktfaktorer": "maktfaktor",
    "maktfaktorerna": "maktfaktor",
    "maktfaktorernas": "maktfaktor",
    "maktfaktorers": "maktfaktor",
    "maktfaktorn": "maktfaktor",
    "maktfaktorns": "maktfaktor",
    "maktfaktors": "maktfaktor",
    "maktfilosofien": "maktfilosofi",
    "maktfilosofiens": "maktfilosofi",
    "maktfilosofin": "maktfilosofi",
    "maktfilosofins": "maktfilosofi",
    "maktfilosofis": "maktfilosofi",
    "maktfullkomliga": "maktfullkomlig",
    "maktfullkomligare": "maktfullkomlig",
    "maktfullkomligares": "maktfullkomlig",
    "maktfullkomligas": "maktfullkomlig",
    "maktfullkomligast": "maktfullkomlig",
    "maktfullkomligaste": "maktfullkomlig",
    "maktfullkomligastes": "maktfullkomlig",
    "maktfullkomligasts": "maktfullkomlig",
    "maktfullkomlige": "maktfullkomlig",
    "maktfullkomliges": "maktfullkomlig",
    "maktfullkomligheten": "maktfullkomlighet",
    "maktfullkomlighetens": "maktfullkomlighet",
    "maktfullkomlighets": "maktfullkomlighet",
    "maktfullkomligs": "maktfullkomlig",
    "maktfullkomligt": "maktfullkomlig",
    "maktfullkomligts": "maktfullkomlig",
    "maktfördelningar": "maktfördelning",
    "maktfördelningarna": "maktfördelning",
    "maktfördelningarnas": "maktfördelning",
    "maktfördelningars": "maktfördelning",
    "maktfördelningen": "maktfördelning",
    "maktfördelningens": "maktfördelning",
    "maktfördelnings": "maktfördelning",
    "maktförskjutningar": "maktförskjutning",
    "maktförskjutningarna": "maktförskjutning",
    "maktförskjutningarnas": "maktförskjutning",
    "maktförskjutningars": "maktförskjutning",
    "maktförskjutningen": "maktförskjutning",
    "maktförskjutningens": "maktförskjutning",
    "maktförskjutnings": "maktförskjutning",
    "makthavar": "makthavare",
    "makthavaren": "makthavare",
    "makthavarens": "makthavare",
    "makthavares": "makthavare",
    "makthavarna": "makthavare",
    "makthavarnas": "makthavare",
    "makthungern": "makthunger",
    "makthungerns": "makthunger",
    "makthungers": "makthunger",
    "maktkampen": "maktkamp",
    "maktkampens": "maktkamp",
    "maktkamper": "maktkamp",
    "maktkamperna": "maktkamp",
    "maktkampernas": "maktkamp",
    "maktkampers": "maktkamp",
    "maktkamps": "maktkamp",
    "maktkoncentrationen": "maktkoncentration",
    "maktkoncentrationens": "maktkoncentration",
    "maktkoncentrationer": "maktkoncentration",
    "maktkoncentrationerna": "maktkoncentration",
    "maktkoncentrationernas": "maktkoncentration",
    "maktkoncentrationers": "maktkoncentration",
    "maktkoncentrations": "maktkoncentration",
    "maktkretsar": "maktkrets",
    "maktkretsarna": "maktkrets",
    "maktkretsarnas": "maktkrets",
    "maktkretsars": "maktkrets",
    "maktkretsen": "maktkrets",
    "maktkretsens": "maktkrets",
    "maktlystenheten": "maktlystenhet",
    "maktlystenhetens": "maktlystenhet",
    "maktlystenhets": "maktlystenhet",
    "maktlystens": "maktlysten",
    "maktlystet": "maktlysten",
    "maktlystets": "maktlysten",
    "maktlystna": "maktlysten",
    "maktlystnare": "maktlysten",
    "maktlystnares": "maktlysten",
    "maktlystnas": "maktlysten",
    "maktlystnast": "maktlysten",
    "maktlystnaste": "maktlysten",
    "maktlystnastes": "maktlysten",
    "maktlystnasts": "maktlysten",
    "maktlystne": "maktlysten",
    "maktlystnes": "maktlysten",
    "maktlösa": "maktlös",
    "maktlösare": "maktlös",
    "maktlösares": "maktlös",
    "maktlösas": "maktlös",
    "maktlösast": "maktlös",
    "maktlösaste": "maktlös",
    "maktlösastes": "maktlös",
    "maktlösasts": "maktlös",
    "maktlöse": "maktlös",
    "maktlöses": "maktlös",
    "maktlösheten": "maktlöshet",
    "maktlöshetens": "maktlöshet",
    "maktlöshets": "maktlöshet",
    "maktlöst": "maktlös",
    "maktlösts": "maktlös",
    "maktmedels": "maktmedel",
    "maktmedlen": "maktmedel",
    "maktmedlens": "maktmedel",
    "maktmedlet": "maktmedel",
    "maktmedlets": "maktmedel",
    "maktmissbruket": "maktmissbruk",
    "maktmissbrukets": "maktmissbruk",
    "maktmissbruks": "maktmissbruk",
    "maktmänniskan": "maktmänniska",
    "maktmänniskans": "maktmänniska",
    "maktmänniskas": "maktmänniska",
    "maktmännisko": "maktmänniska",
    "maktmänniskor": "maktmänniska",
    "maktmänniskorna": "maktmänniska",
    "maktmänniskornas": "maktmänniska",
    "maktmänniskors": "maktmänniska",
    "maktmässiga": "maktmässig",
    "maktmässigare": "maktmässig",
    "maktmässigares": "maktmässig",
    "maktmässigas": "maktmässig",
    "maktmässigast": "maktmässig",
    "maktmässigaste": "maktmässig",
    "maktmässigastes": "maktmässig",
    "maktmässigasts": "maktmässig",
    "maktmässige": "maktmässig",
    "maktmässiges": "maktmässig",
    "maktmässigs": "maktmässig",
    "maktmässigt": "maktmässig",
    "maktmässigts": "maktmässig",
    "maktpolitiken": "maktpolitik",
    "maktpolitikens": "maktpolitik",
    "maktpolitiks": "maktpolitik",
    "maktpolitiska": "maktpolitisk",
    "maktpolitiskas": "maktpolitisk",
    "maktpolitiske": "maktpolitisk",
    "maktpolitiskes": "maktpolitisk",
    "maktpolitisks": "maktpolitisk",
    "maktpolitiskt": "maktpolitisk",
    "maktpolitiskts": "maktpolitisk",
    "maktpositionen": "maktposition",
    "maktpositionens": "maktposition",
    "maktpositioner": "maktposition",
    "maktpositionerna": "maktposition",
    "maktpositionernas": "maktposition",
    "maktpositioners": "maktposition",
    "maktpositions": "maktposition",
    "makts": "makt",
    "maktskiften": "maktskifte",
    "maktskiftena": "maktskifte",
    "maktskiftenas": "maktskifte",
    "maktskiftens": "maktskifte",
    "maktskiftes": "maktskifte",
    "maktskiftet": "maktskifte",
    "maktskiftets": "maktskifte",
    "maktspelen": "maktspel",
    "maktspelens": "maktspel",
    "maktspelet": "maktspel",
    "maktspelets": "maktspel",
    "maktspels": "maktspel",
    "maktspråket": "maktspråk",
    "maktspråkets": "maktspråk",
    "maktspråks": "maktspråk",
    "maktstinna": "maktstinn",
    "maktstinnare": "maktstinn",
    "maktstinnares": "maktstinn",
    "maktstinnas": "maktstinn",
    "maktstinnast": "maktstinn",
    "maktstinnaste": "maktstinn",
    "maktstinnastes": "maktstinn",
    "maktstinnasts": "maktstinn",
    "maktstinne": "maktstinn",
    "maktstinnes": "maktstinn",
    "maktstinnheten": "maktstinnhet",
    "maktstinnhetens": "maktstinnhet",
    "maktstinnhets": "maktstinnhet",
    "maktstinns": "maktstinn",
    "maktstint": "maktstinn",
    "maktstints": "maktstinn",
    "maktsymbolen": "maktsymbol",
    "maktsymbolens": "maktsymbol",
    "maktsymboler": "maktsymbol",
    "maktsymbolerna": "maktsymbol",
    "maktsymbolernas": "maktsymbol",
    "maktsymbolers": "maktsymbol",
    "maktsymbols": "maktsymbol",
    "maktutövandes": "maktutövande",
    "maktutövandet": "maktutövande",
    "maktutövandets": "maktutövande",
    "maktutövar": "maktutövare",
    "maktutövaren": "maktutövare",
    "maktutövarens": "maktutövare",
    "maktutövares": "maktutövare",
    "maktutövarna": "maktutövare",
    "maktutövarnas": "maktutövare",
    "maktutövningen": "maktutövning",
    "maktutövningens": "maktutövning",
    "maktutövnings": "maktutövning",
    "maktövertaganden": "maktövertagande",
    "maktövertagandena": "maktövertagande",
    "maktövertagandenas": "maktövertagande",
    "maktövertagandens": "maktövertagande",
    "maktövertagandes": "maktövertagande",
    "maktövertagandet": "maktövertagande",
    "maktövertagandets": "maktövertagande",
    "makulaturen": "makulatur",
    "makulaturens": "makulatur",
    "makulaturs": "makulatur",
    "makulerad": "makulera",
    "makulerade": "makulera",
    "makulerades": "makulera",
    "makulerads": "makulera",
    "makulerande": "makulera",
    "makuleranden": "makulerande",
    "makulerandena": "makulerande",
    "makulerandenas": "makulerande",
    "makulerandens": "makulerande",
    "makulerandes": "makulerande",
    "makulerandet": "makulerande",
    "makulerandets": "makulerande",
    "makulerar": "makulera",
    "makuleras": "makulera",
    "makulerat": "makulera",
    "makulerats": "makulera",
    "makulerbara": "makulerbar",
    "makulerbarare": "makulerbar",
    "makulerbarares": "makulerbar",
    "makulerbaras": "makulerbar",
    "makulerbarast": "makulerbar",
    "makulerbaraste": "makulerbar",
    "makulerbarastes": "makulerbar",
    "makulerbarasts": "makulerbar",
    "makulerbare": "makulerbar",
    "makulerbares": "makulerbar",
    "makulerbarheten": "makulerbarhet",
    "makulerbarhetens": "makulerbarhet",
    "makulerbarhets": "makulerbarhet",
    "makulerbars": "makulerbar",
    "makulerbart": "makulerbar",
    "makulerbarts": "makulerbar",
    "makuleringar": "makulering",
    "makuleringarna": "makulering",
    "makuleringarnas": "makulering",
    "makuleringars": "makulering",
    "makuleringen": "makulering",
    "makuleringens": "makulering",
    "makulerings": "makulering",
    "mal": "mala",
    "malagan": "malaga",
    "malagans": "malaga",
    "malagas": "malaga",
    "malajen": "malaj",
    "malajens": "malaj",
    "malajer": "malaj",
    "malajerna": "malaj",
    "malajernas": "malaj",
    "malajers": "malaj",
    "malajisk": "malajiska",
    "malajiska": "malajisk",
    "malajiskan": "malajiska",
    "malajiskans": "malajiska",
    "malajiskare": "malajisk",
    "malajiskares": "malajisk",
    "malajiskas": "malajiska",
    "malajiskast": "malajisk",
    "malajiskaste": "malajisk",
    "malajiskastes": "malajisk",
    "malajiskasts": "malajisk",
    "malajiske": "malajiska",
    "malajiskes": "malajisk",
    "malajiskor": "malajiska",
    "malajiskorna": "malajiska",
    "malajiskornas": "malajiska",
    "malajiskors": "malajiska",
    "malajisks": "malajisk",
    "malajiskt": "malajisk",
    "malajiskts": "malajisk",
    "malajs": "malaj",
    "malakiten": "malakit",
    "malakitens": "malakit",
    "malakiter": "malakit",
    "malakiterna": "malakit",
    "malakiternas": "malakit",
    "malakiters": "malakit",
    "malakitgrönts": "malakitgrönt",
    "malakits": "malakit",
    "malande": "mala",
    "malanden": "malande",
    "malandena": "malande",
    "malandenas": "malande",
    "malandens": "malande",
    "malandes": "malande",
    "malandet": "malande",
    "malandets": "malande",
    "malar": "mal",
    "malariamygg": "malariamygga",
    "malariamyggan": "malariamygga",
    "malariamyggans": "malariamygga",
    "malariamyggas": "malariamygga",
    "malariamygge": "malariamygga",
    "malariamyggor": "malariamygga",
    "malariamyggorna": "malariamygga",
    "malariamyggornas": "malariamygga",
    "malariamyggors": "malariamygga",
    "malariamyggs": "malariamygga",
    "malarian": "malaria",
    "malarians": "malaria",
    "malariaparasiten": "malariaparasit",
    "malariaparasitens": "malariaparasit",
    "malariaparasiter": "malariaparasit",
    "malariaparasiterna": "malariaparasit",
    "malariaparasiternas": "malariaparasit",
    "malariaparasiters": "malariaparasit",
    "malariaparasits": "malariaparasit",
    "malarias": "malaria",
    "malarna": "mal",
    "malarnas": "mal",
    "malars": "mal",
    "malas": "mala",
    "malawiern": "malawier",
    "malawierna": "malawier",
    "malawiernas": "malawier",
    "malawierns": "malawier",
    "malawiers": "malawier",
    "malawiska": "malawisk",
    "malawiskan": "malawiska",
    "malawiskans": "malawiska",
    "malawiskare": "malawisk",
    "malawiskares": "malawisk",
    "malawiskas": "malawiska",
    "malawiskast": "malawisk",
    "malawiskaste": "malawisk",
    "malawiskastes": "malawisk",
    "malawiskasts": "malawisk",
    "malawiske": "malawiska",
    "malawiskes": "malawisk",
    "malawiskor": "malawiska",
    "malawiskorna": "malawiska",
    "malawiskornas": "malawiska",
    "malawiskors": "malawiska",
    "malawisks": "malawisk",
    "malawiskt": "malawisk",
    "malawiskts": "malawisk",
    "malaysiern": "malaysier",
    "malaysierna": "malaysier",
    "malaysiernas": "malaysier",
    "malaysierns": "malaysier",
    "malaysiers": "malaysier",
    "malaysiska": "malaysisk",
    "malaysiskan": "malaysiska",
    "malaysiskans": "malaysiska",
    "malaysiskare": "malaysisk",
    "malaysiskares": "malaysisk",
    "malaysiskas": "malaysiska",
    "malaysiskast": "malaysisk",
    "malaysiskaste": "malaysisk",
    "malaysiskastes": "malaysisk",
    "malaysiskasts": "malaysisk",
    "malaysiske": "malaysiska",
    "malaysiskes": "malaysisk",
    "malaysiskor": "malaysiska",
    "malaysiskorna": "malaysiska",
    "malaysiskornas": "malaysiska",
    "malaysiskors": "malaysiska",
    "malaysisks": "malaysisk",
    "malaysiskt": "malaysisk",
    "malaysiskts": "malaysisk",
    "mald": "mala",
    "malda": "mala",
    "maldas": "mala",
    "malde": "mala",
    "maldes": "mala",
    "maldivern": "maldiver",
    "maldiverna": "maldiver",
    "maldivernas": "maldiver",
    "maldiverns": "maldiver",
    "maldivers": "maldiver",
    "maldiviern": "maldivier",
    "maldivierna": "maldivier",
    "maldiviernas": "maldivier",
    "maldivierns": "maldivier",
    "maldiviers": "maldivier",
    "maldivisk": "maldiviska",
    "maldiviska": "maldivisk",
    "maldiviskan": "maldiviska",
    "maldiviskans": "maldiviska",
    "maldiviskare": "maldivisk",
    "maldiviskares": "maldivisk",
    "maldiviskas": "maldiviska",
    "maldiviskast": "maldivisk",
    "maldiviskaste": "maldivisk",
    "maldiviskastes": "maldivisk",
    "maldiviskasts": "maldivisk",
    "maldiviske": "maldiviska",
    "maldiviskes": "maldivisk",
    "maldiviskor": "maldiviska",
    "maldiviskorna": "maldiviska",
    "maldiviskornas": "maldiviska",
    "maldiviskors": "maldiviska",
    "maldivisks": "maldivisk",
    "maldiviskt": "maldivisk",
    "maldiviskts": "maldivisk",
    "malds": "mala",
    "malen": "mala",
    "malens": "mala",
    "maler": "mala",
    "malet": "mala",
    "malets": "mala",
    "malfoberad": "malfobera",
    "malfoberade": "malfobera",
    "malfoberades": "malfobera",
    "malfoberads": "malfobera",
    "malfoberande": "malfobera",
    "malfoberanden": "malfoberande",
    "malfoberandena": "malfoberande",
    "malfoberandenas": "malfoberande",
    "malfoberandens": "malfoberande",
    "malfoberandes": "malfoberande",
    "malfoberandet": "malfoberande",
    "malfoberandets": "malfoberande",
    "malfoberar": "malfobera",
    "malfoberas": "malfobera",
    "malfoberat": "malfobera",
    "malfoberats": "malfobera",
    "malfoberbara": "malfoberbar",
    "malfoberbarare": "malfoberbar",
    "malfoberbarares": "malfoberbar",
    "malfoberbaras": "malfoberbar",
    "malfoberbarast": "malfoberbar",
    "malfoberbaraste": "malfoberbar",
    "malfoberbarastes": "malfoberbar",
    "malfoberbarasts": "malfoberbar",
    "malfoberbare": "malfoberbar",
    "malfoberbares": "malfoberbar",
    "malfoberbarheten": "malfoberbarhet",
    "malfoberbarhetens": "malfoberbarhet",
    "malfoberbarhets": "malfoberbarhet",
    "malfoberbars": "malfoberbar",
    "malfoberbart": "malfoberbar",
    "malfoberbarts": "malfoberbar",
    "malfoberingar": "malfobering",
    "malfoberingarna": "malfobering",
    "malfoberingarnas": "malfobering",
    "malfoberingars": "malfobering",
    "malfoberingen": "malfobering",
    "malfoberingens": "malfobering",
    "malfoberings": "malfobering",
    "maliciösa": "maliciös",
    "maliciösare": "maliciös",
    "maliciösares": "maliciös",
    "maliciösas": "maliciös",
    "maliciösast": "maliciös",
    "maliciösaste": "maliciös",
    "maliciösastes": "maliciös",
    "maliciösasts": "maliciös",
    "maliciöse": "maliciös",
    "maliciöses": "maliciös",
    "maliciöst": "maliciös",
    "maliciösts": "maliciös",
    "maliern": "malier",
    "malierna": "malier",
    "maliernas": "malier",
    "malierns": "malier",
    "maliers": "malier",
    "maligna": "malign",
    "malignare": "malign",
    "malignares": "malign",
    "malignas": "malign",
    "malignast": "malign",
    "malignaste": "malign",
    "malignastes": "malign",
    "malignasts": "malign",
    "maligne": "malign",
    "malignes": "malign",
    "maligns": "malign",
    "malignt": "malign",
    "malignts": "malign",
    "malisen": "malis",
    "malisens": "malis",
    "maliska": "malisk",
    "maliskan": "maliska",
    "maliskans": "maliska",
    "maliskare": "malisk",
    "maliskares": "malisk",
    "maliskas": "maliska",
    "maliskast": "malisk",
    "maliskaste": "malisk",
    "maliskastes": "malisk",
    "maliskasts": "malisk",
    "maliske": "maliska",
    "maliskes": "malisk",
    "maliskor": "maliska",
    "maliskorna": "maliska",
    "maliskornas": "maliska",
    "maliskors": "maliska",
    "malisks": "malisk",
    "maliskt": "malisk",
    "maliskts": "malisk",
    "malj": "malja",
    "maljan": "malja",
    "maljans": "malja",
    "maljas": "malja",
    "malje": "malja",
    "maljor": "malja",
    "maljorna": "malja",
    "maljornas": "malja",
    "maljors": "malja",
    "maljs": "malja",
    "mallar": "mall",
    "mallarna": "mall",
    "mallarnas": "mall",
    "mallars": "mall",
    "mallen": "mall",
    "mallens": "mall",
    "malliga": "mallig",
    "malligare": "mallig",
    "malligares": "mallig",
    "malligas": "mallig",
    "malligast": "mallig",
    "malligaste": "mallig",
    "malligastes": "mallig",
    "malligasts": "mallig",
    "mallige": "mallig",
    "malliges": "mallig",
    "malligheten": "mallighet",
    "mallighetens": "mallighet",
    "mallighets": "mallighet",
    "malligs": "mallig",
    "malligt": "mallig",
    "malligts": "mallig",
    "malls": "mall",
    "malm": "malma",
    "malmad": "malma",
    "malmade": "malma",
    "malmades": "malma",
    "malmads": "malma",
    "malmande": "malma",
    "malmanden": "malmande",
    "malmandena": "malmande",
    "malmandenas": "malmande",
    "malmandens": "malmande",
    "malmandes": "malmande",
    "malmandet": "malmande",
    "malmandets": "malmande",
    "malmar": "malma",
    "malmarna": "malm",
    "malmarnas": "malm",
    "malmars": "malm",
    "malmas": "malma",
    "malmat": "malma",
    "malmats": "malma",
    "malmedels": "malmedel",
    "malmedlen": "malmedel",
    "malmedlens": "malmedel",
    "malmedlet": "malmedel",
    "malmedlets": "malmedel",
    "malmen": "malm",
    "malmens": "malm",
    "malmer": "malm",
    "malmerna": "malm",
    "malmernas": "malm",
    "malmers": "malm",
    "malmfick": "malmficka",
    "malmfickan": "malmficka",
    "malmfickans": "malmficka",
    "malmfickas": "malmficka",
    "malmficke": "malmficka",
    "malmfickor": "malmficka",
    "malmfickorna": "malmficka",
    "malmfickornas": "malmficka",
    "malmfickors": "malmficka",
    "malmficks": "malmficka",
    "malmfyndiga": "malmfyndig",
    "malmfyndigare": "malmfyndig",
    "malmfyndigares": "malmfyndig",
    "malmfyndigas": "malmfyndig",
    "malmfyndigast": "malmfyndig",
    "malmfyndigaste": "malmfyndig",
    "malmfyndigastes": "malmfyndig",
    "malmfyndigasts": "malmfyndig",
    "malmfyndige": "malmfyndig",
    "malmfyndiges": "malmfyndig",
    "malmfyndigheten": "malmfyndighet",
    "malmfyndighetens": "malmfyndighet",
    "malmfyndigheter": "malmfyndighet",
    "malmfyndigheterna": "malmfyndighet",
    "malmfyndigheternas": "malmfyndighet",
    "malmfyndigheters": "malmfyndighet",
    "malmfyndighets": "malmfyndighet",
    "malmfyndigs": "malmfyndig",
    "malmfyndigt": "malmfyndig",
    "malmfyndigts": "malmfyndig",
    "malmfälten": "malmfält",
    "malmfältens": "malmfält",
    "malmfältet": "malmfält",
    "malmfältets": "malmfält",
    "malmfälts": "malmfält",
    "malmgruv": "malmgruva",
    "malmgruvan": "malmgruva",
    "malmgruvans": "malmgruva",
    "malmgruvas": "malmgruva",
    "malmgruve": "malmgruva",
    "malmgruvor": "malmgruva",
    "malmgruvorna": "malmgruva",
    "malmgruvornas": "malmgruva",
    "malmgruvors": "malmgruva",
    "malmgruvs": "malmgruva",
    "malmhalten": "malmhalt",
    "malmhaltens": "malmhalt",
    "malmhalter": "malmhalt",
    "malmhalterna": "malmhalt",
    "malmhalternas": "malmhalt",
    "malmhalters": "malmhalt",
    "malmhalts": "malmhalt",
    "malmkroppar": "malmkropp",
    "malmkropparna": "malmkropp",
    "malmkropparnas": "malmkropp",
    "malmkroppars": "malmkropp",
    "malmkroppen": "malmkropp",
    "malmkroppens": "malmkropp",
    "malmkropps": "malmkropp",
    "malmkrossar": "malmkross",
    "malmkrossarna": "malmkross",
    "malmkrossarnas": "malmkross",
    "malmkrossars": "malmkross",
    "malmkrossen": "malmkross",
    "malmkrossens": "malmkross",
    "malmkörteln": "malmkörtel",
    "malmkörtelns": "malmkörtel",
    "malmkörtels": "malmkörtel",
    "malmkörtlar": "malmkörtel",
    "malmkörtlarna": "malmkörtel",
    "malmkörtlarnas": "malmkörtel",
    "malmkörtlars": "malmkörtel",
    "malmsligen": "malmslig",
    "malmsligens": "malmslig",
    "malmsligs": "malmslig",
    "malmtransporten": "malmtransport",
    "malmtransportens": "malmtransport",
    "malmtransporter": "malmtransport",
    "malmtransporterna": "malmtransport",
    "malmtransporternas": "malmtransport",
    "malmtransporters": "malmtransport",
    "malmtransports": "malmtransport",
    "malmtäkten": "malmtäkt",
    "malmtäktens": "malmtäkt",
    "malmtäkter": "malmtäkt",
    "malmtäkterna": "malmtäkt",
    "malmtäkternas": "malmtäkt",
    "malmtäkters": "malmtäkt",
    "malmtäkts": "malmtäkt",
    "malmöbon": "malmöbo",
    "malmöbons": "malmöbo",
    "malmöbor": "malmöbo",
    "malmöborna": "malmöbo",
    "malmöbornas": "malmöbo",
    "malmöbors": "malmöbo",
    "malmöbos": "malmöbo",
    "malna": "mala",
    "malnas": "mala",
    "malne": "mala",
    "malnes": "mala",
    "malplacerade": "malplacerad",
    "malplacerades": "malplacerad",
    "malplacerads": "malplacerad",
    "malplacerat": "malplacerad",
    "malplacerats": "malplacerad",
    "malpås": "malpåse",
    "malpåsar": "malpåse",
    "malpåsarna": "malpåse",
    "malpåsarnas": "malpåse",
    "malpåsars": "malpåse",
    "malpåsen": "malpåse",
    "malpåsens": "malpåse",
    "malpåses": "malpåse",
    "mals": "mala",
    "malströmmar": "malström",
    "malströmmarna": "malström",
    "malströmmarnas": "malström",
    "malströmmars": "malström",
    "malströmmen": "malström",
    "malströmmens": "malström",
    "malströms": "malström",
    "malt": "mala",
    "maltdrycken": "maltdryck",
    "maltdryckens": "maltdryck",
    "maltdrycker": "maltdryck",
    "maltdryckerna": "maltdryck",
    "maltdryckernas": "maltdryck",
    "maltdryckers": "maltdryck",
    "maltdrycks": "maltdryck",
    "malten": "malt",
    "maltens": "malt",
    "maltesar": "maltesare",
    "maltesaren": "maltesare",
    "maltesarens": "maltesare",
    "maltesares": "maltesare",
    "maltesarna": "maltesare",
    "maltesarnas": "maltesare",
    "maltesen": "maltes",
    "maltesens": "maltes",
    "malteser": "maltes",
    "malteserhundar": "malteserhund",
    "malteserhundarna": "malteserhund",
    "malteserhundarnas": "malteserhund",
    "malteserhundars": "malteserhund",
    "malteserhunden": "malteserhund",
    "malteserhundens": "malteserhund",
    "malteserhunds": "malteserhund",
    "malteserkorsen": "malteserkors",
    "malteserkorsens": "malteserkors",
    "malteserkorset": "malteserkors",
    "malteserkorsets": "malteserkors",
    "malteserna": "maltes",
    "maltesernas": "maltes",
    "malteserordens": "malteserorden",
    "malteserordnar": "malteserorden",
    "malteserordnarna": "malteserorden",
    "malteserordnarnas": "malteserorden",
    "malteserordnars": "malteserorden",
    "malteserordnen": "malteserorden",
    "malteserordnens": "malteserorden",
    "maltesers": "maltes",
    "maltesisk": "maltesiska",
    "maltesiska": "maltesisk",
    "maltesiskan": "maltesiska",
    "maltesiskans": "maltesiska",
    "maltesiskare": "maltesisk",
    "maltesiskares": "maltesisk",
    "maltesiskas": "maltesiska",
    "maltesiskast": "maltesisk",
    "maltesiskaste": "maltesisk",
    "maltesiskastes": "maltesisk",
    "maltesiskasts": "maltesisk",
    "maltesiske": "maltesiska",
    "maltesiskes": "maltesisk",
    "maltesiskor": "maltesiska",
    "maltesiskorna": "maltesiska",
    "maltesiskornas": "maltesiska",
    "maltesiskors": "maltesiska",
    "maltesisks": "maltesisk",
    "maltesiskt": "maltesisk",
    "maltesiskts": "maltesisk",
    "maltet": "malt",
    "maltets": "malt",
    "maltosen": "maltos",
    "maltosens": "maltos",
    "malträterad": "malträtera",
    "malträterade": "malträtera",
    "malträterades": "malträtera",
    "malträterads": "malträtera",
    "malträterande": "malträtera",
    "malträteranden": "malträterande",
    "malträterandena": "malträterande",
    "malträterandenas": "malträterande",
    "malträterandens": "malträterande",
    "malträterandes": "malträterande",
    "malträterandet": "malträterande",
    "malträterandets": "malträterande",
    "malträterar": "malträtera",
    "malträteras": "malträtera",
    "malträterat": "malträtera",
    "malträterats": "malträtera",
    "malträterbara": "malträterbar",
    "malträterbarare": "malträterbar",
    "malträterbarares": "malträterbar",
    "malträterbaras": "malträterbar",
    "malträterbarast": "malträterbar",
    "malträterbaraste": "malträterbar",
    "malträterbarastes": "malträterbar",
    "malträterbarasts": "malträterbar",
    "malträterbare": "malträterbar",
    "malträterbares": "malträterbar",
    "malträterbarheten": "malträterbarhet",
    "malträterbarhetens": "malträterbarhet",
    "malträterbarhets": "malträterbarhet",
    "malträterbars": "malträterbar",
    "malträterbart": "malträterbar",
    "malträterbarts": "malträterbar",
    "malträteringar": "malträtering",
    "malträteringarna": "malträtering",
    "malträteringarnas": "malträtering",
    "malträteringars": "malträtering",
    "malträteringen": "malträtering",
    "malträteringens": "malträtering",
    "malträterings": "malträtering",
    "malts": "malt",
    "maltsockers": "maltsocker",
    "maltsockret": "maltsocker",
    "maltsockrets": "maltsocker",
    "malv": "malva",
    "malvafärgade": "malvafärgad",
    "malvafärgades": "malvafärgad",
    "malvafärgads": "malvafärgad",
    "malvafärgat": "malvafärgad",
    "malvafärgats": "malvafärgad",
    "malvan": "malva",
    "malvans": "malva",
    "malvas": "malva",
    "malvasiren": "malvasir",
    "malvasirens": "malvasir",
    "malvasirs": "malvasir",
    "malve": "malva",
    "malvor": "malva",
    "malvorna": "malva",
    "malvornas": "malva",
    "malvors": "malva",
    "malvs": "malva",
    "malätenheten": "malätenhet",
    "malätenhetens": "malätenhet",
    "malätenhets": "malätenhet",
    "malätens": "maläten",
    "malätet": "maläten",
    "malätets": "maläten",
    "malätna": "maläten",
    "malätnare": "maläten",
    "malätnares": "maläten",
    "malätnas": "maläten",
    "malätnast": "maläten",
    "malätnaste": "maläten",
    "malätnastes": "maläten",
    "malätnasts": "maläten",
    "malätne": "maläten",
    "malätnes": "maläten",
    "malören": "malör",
    "malörens": "malör",
    "malörer": "malör",
    "malörerna": "malör",
    "malörernas": "malör",
    "malörers": "malör",
    "malörs": "malör",
    "malörten": "malört",
    "malörtens": "malört",
    "malörts": "malört",
    "mamb": "mamba",
    "mamban": "mamba",
    "mambans": "mamba",
    "mambas": "mamba",
    "mambe": "mamba",
    "mambon": "mambo",
    "mambons": "mambo",
    "mambor": "mambo",
    "mamborna": "mambo",
    "mambornas": "mambo",
    "mambors": "mambo",
    "mambos": "mambo",
    "mambs": "mamba",
    "mameluck": "mamelucker",
    "mameluckerna": "mamelucker",
    "mameluckernas": "mamelucker",
    "mameluckers": "mamelucker",
    "mamelucks": "mamelucker",
    "mammaklänningar": "mammaklänning",
    "mammaklänningarna": "mammaklänning",
    "mammaklänningarnas": "mammaklänning",
    "mammaklänningars": "mammaklänning",
    "mammaklänningen": "mammaklänning",
    "mammaklänningens": "mammaklänning",
    "mammaklännings": "mammaklänning",
    "mammalediga": "mammaledig",
    "mammaledigare": "mammaledig",
    "mammaledigares": "mammaledig",
    "mammaledigas": "mammaledig",
    "mammaledigast": "mammaledig",
    "mammaledigaste": "mammaledig",
    "mammaledigastes": "mammaledig",
    "mammaledigasts": "mammaledig",
    "mammaledige": "mammaledig",
    "mammalediges": "mammaledig",
    "mammaledigheten": "mammaledighet",
    "mammaledighetens": "mammaledighet",
    "mammaledighets": "mammaledighet",
    "mammaledigs": "mammaledig",
    "mammaledigt": "mammaledig",
    "mammaledigts": "mammaledig",
    "mammalie": "mammalier",
    "mammalierna": "mammalier",
    "mammaliernas": "mammalier",
    "mammaliers": "mammalier",
    "mamman": "mamma",
    "mammans": "mamma",
    "mammas": "mamma",
    "mamme": "mamma",
    "mammiga": "mammig",
    "mammigare": "mammig",
    "mammigares": "mammig",
    "mammigas": "mammig",
    "mammigast": "mammig",
    "mammigaste": "mammig",
    "mammigastes": "mammig",
    "mammigasts": "mammig",
    "mammige": "mammig",
    "mammiges": "mammig",
    "mammigheten": "mammighet",
    "mammighetens": "mammighet",
    "mammighets": "mammighet",
    "mammigs": "mammig",
    "mammigt": "mammig",
    "mammigts": "mammig",
    "mammografien": "mammografi",
    "mammografiens": "mammografi",
    "mammografier": "mammografi",
    "mammografierna": "mammografi",
    "mammografiernas": "mammografi",
    "mammografiers": "mammografi",
    "mammografin": "mammografi",
    "mammografins": "mammografi",
    "mammografis": "mammografi",
    "mammonsträlar": "mammonsträl",
    "mammonsträlarna": "mammonsträl",
    "mammonsträlarnas": "mammonsträl",
    "mammonsträlars": "mammonsträl",
    "mammonsträlen": "mammonsträl",
    "mammonsträlens": "mammonsträl",
    "mammonsträls": "mammonsträl",
    "mammor": "mamma",
    "mammorna": "mamma",
    "mammornas": "mamma",
    "mammors": "mamma",
    "mammutar": "mammut",
    "mammutarna": "mammut",
    "mammutarnas": "mammut",
    "mammutars": "mammut",
    "mammuten": "mammut",
    "mammutens": "mammut",
    "mammuts": "mammut",
    "mammutträden": "mammutträd",
    "mammutträdens": "mammutträd",
    "mammutträdet": "mammutträd",
    "mammutträdets": "mammutträd",
    "mammutträds": "mammutträd",
    "mamsellen": "mamsell",
    "mamsellens": "mamsell",
    "mamseller": "mamsell",
    "mamsellerna": "mamsell",
    "mamsellernas": "mamsell",
    "mamsellers": "mamsell",
    "mamsells": "mamsell",
    "man": "mana",
    "manad": "mana",
    "manade": "mana",
    "manades": "mana",
    "manads": "mana",
    "managements": "management",
    "managern": "manager",
    "managerna": "manager",
    "managernas": "manager",
    "managerns": "manager",
    "managers": "manager",
    "manan": "mana",
    "manande": "mana",
    "mananden": "manande",
    "manandena": "manande",
    "manandenas": "manande",
    "manandens": "manande",
    "manandes": "manande",
    "manandet": "manande",
    "manandets": "manande",
    "manans": "mana",
    "manar": "mana",
    "manarna": "man",
    "manarnas": "man",
    "manars": "man",
    "manas": "mana",
    "manat": "mana",
    "manats": "mana",
    "manbara": "manbar",
    "manbarare": "manbar",
    "manbarares": "manbar",
    "manbaras": "manbar",
    "manbarast": "manbar",
    "manbaraste": "manbar",
    "manbarastes": "manbar",
    "manbarasts": "manbar",
    "manbare": "manbar",
    "manbares": "manbar",
    "manbarheten": "manbarhet",
    "manbarhetens": "manbarhet",
    "manbarhets": "manbarhet",
    "manbars": "manbar",
    "manbart": "manbar",
    "manbarts": "manbar",
    "manbyggnaden": "manbyggnad",
    "manbyggnadens": "manbyggnad",
    "manbyggnader": "manbyggnad",
    "manbyggnaderna": "manbyggnad",
    "manbyggnadernas": "manbyggnad",
    "manbyggnaders": "manbyggnad",
    "manbyggnads": "manbyggnad",
    "manchesterhängselkjolar": "manchesterhängselkjol",
    "manchesterhängselkjolarna": "manchesterhängselkjol",
    "manchesterhängselkjolarnas": "manchesterhängselkjol",
    "manchesterhängselkjolars": "manchesterhängselkjol",
    "manchesterhängselkjolen": "manchesterhängselkjol",
    "manchesterhängselkjolens": "manchesterhängselkjol",
    "manchesterhängselkjols": "manchesterhängselkjol",
    "manchesterjack": "manchesterjacka",
    "manchesterjackan": "manchesterjacka",
    "manchesterjackans": "manchesterjacka",
    "manchesterjackas": "manchesterjacka",
    "manchesterjacke": "manchesterjacka",
    "manchesterjackor": "manchesterjacka",
    "manchesterjackorna": "manchesterjacka",
    "manchesterjackornas": "manchesterjacka",
    "manchesterjackors": "manchesterjacka",
    "manchesterjacks": "manchesterjacka",
    "manchesterkavajen": "manchesterkavaj",
    "manchesterkavajens": "manchesterkavaj",
    "manchesterkavajer": "manchesterkavaj",
    "manchesterkavajerna": "manchesterkavaj",
    "manchesterkavajernas": "manchesterkavaj",
    "manchesterkavajers": "manchesterkavaj",
    "manchesterkavajs": "manchesterkavaj",
    "manchesterkostymen": "manchesterkostym",
    "manchesterkostymens": "manchesterkostym",
    "manchesterkostymer": "manchesterkostym",
    "manchesterkostymerna": "manchesterkostym",
    "manchesterkostymernas": "manchesterkostym",
    "manchesterkostymers": "manchesterkostym",
    "manchesterkostyms": "manchesterkostym",
    "manchesterliberalismen": "manchesterliberalism",
    "manchesterliberalismens": "manchesterliberalism",
    "manchesterliberalismer": "manchesterliberalism",
    "manchesterliberalismerna": "manchesterliberalism",
    "manchesterliberalismernas": "manchesterliberalism",
    "manchesterliberalismers": "manchesterliberalism",
    "manchesterliberalisms": "manchesterliberalism",
    "manchestern": "manchester",
    "manchesterns": "manchester",
    "manchesters": "manchester",
    "manchuer": "manchu",
    "manchuerna": "manchu",
    "manchuernas": "manchu",
    "manchuers": "manchu",
    "manchuisk": "manchuiska",
    "manchuiska": "manchuisk",
    "manchuiskan": "manchuiska",
    "manchuiskans": "manchuiska",
    "manchuiskare": "manchuisk",
    "manchuiskares": "manchuisk",
    "manchuiskas": "manchuiska",
    "manchuiskast": "manchuisk",
    "manchuiskaste": "manchuisk",
    "manchuiskastes": "manchuisk",
    "manchuiskasts": "manchuisk",
    "manchuiske": "manchuiska",
    "manchuiskes": "manchuisk",
    "manchuiskor": "manchuiska",
    "manchuiskorna": "manchuiska",
    "manchuiskornas": "manchuiska",
    "manchuiskors": "manchuiska",
    "manchuisks": "manchuisk",
    "manchuiskt": "manchuisk",
    "manchuiskts": "manchuisk",
    "manchun": "manchu",
    "manchuns": "manchu",
    "manchus": "manchu",
    "mandarinen": "mandarin",
    "mandarinens": "mandarin",
    "mandariner": "mandarin",
    "mandarinerna": "mandarin",
    "mandarinernas": "mandarin",
    "mandariners": "mandarin",
    "mandarins": "mandarin",
    "mandaten": "mandat",
    "mandatens": "mandat",
    "mandatet": "mandat",
    "mandatets": "mandat",
    "mandatfördelningar": "mandatfördelning",
    "mandatfördelningarna": "mandatfördelning",
    "mandatfördelningarnas": "mandatfördelning",
    "mandatfördelningars": "mandatfördelning",
    "mandatfördelningen": "mandatfördelning",
    "mandatfördelningens": "mandatfördelning",
    "mandatfördelnings": "mandatfördelning",
    "mandatperioden": "mandatperiod",
    "mandatperiodens": "mandatperiod",
    "mandatperioder": "mandatperiod",
    "mandatperioderna": "mandatperiod",
    "mandatperiodernas": "mandatperiod",
    "mandatperioders": "mandatperiod",
    "mandatperiods": "mandatperiod",
    "mandats": "mandat",
    "mandelblom": "mandelblomma",
    "mandelblomman": "mandelblomma",
    "mandelblommans": "mandelblomma",
    "mandelblommas": "mandelblomma",
    "mandelblomme": "mandelblomma",
    "mandelblommor": "mandelblomma",
    "mandelblommorna": "mandelblomma",
    "mandelblommornas": "mandelblomma",
    "mandelblommors": "mandelblomma",
    "mandelbloms": "mandelblomma",
    "mandelformade": "mandelformad",
    "mandelformades": "mandelformad",
    "mandelformads": "mandelformad",
    "mandelformat": "mandelformad",
    "mandelformats": "mandelformad",
    "mandelgröna": "mandelgrön",
    "mandelgrönare": "mandelgrön",
    "mandelgrönares": "mandelgrön",
    "mandelgrönas": "mandelgrön",
    "mandelgrönast": "mandelgrön",
    "mandelgrönaste": "mandelgrön",
    "mandelgrönastes": "mandelgrön",
    "mandelgrönasts": "mandelgrön",
    "mandelgröne": "mandelgrön",
    "mandelgrönes": "mandelgrön",
    "mandelgröns": "mandelgrön",
    "mandelgrönt": "mandelgrön",
    "mandelgrönts": "mandelgrön",
    "mandelkak": "mandelkaka",
    "mandelkakan": "mandelkaka",
    "mandelkakans": "mandelkaka",
    "mandelkakas": "mandelkaka",
    "mandelkake": "mandelkaka",
    "mandelkakor": "mandelkaka",
    "mandelkakorna": "mandelkaka",
    "mandelkakornas": "mandelkaka",
    "mandelkakors": "mandelkaka",
    "mandelkaks": "mandelkaka",
    "mandelmassan": "mandelmassa",
    "mandelmassans": "mandelmassa",
    "mandelmassas": "mandelmassa",
    "mandelmasse": "mandelmassa",
    "mandeln": "mandel",
    "mandelns": "mandel",
    "mandeloljan": "mandelolja",
    "mandeloljans": "mandelolja",
    "mandeloljas": "mandelolja",
    "mandelolje": "mandelolja",
    "mandeloljor": "mandelolja",
    "mandeloljorna": "mandelolja",
    "mandeloljornas": "mandelolja",
    "mandeloljors": "mandelolja",
    "mandelpotatisar": "mandelpotatis",
    "mandelpotatisarna": "mandelpotatis",
    "mandelpotatisarnas": "mandelpotatis",
    "mandelpotatisars": "mandelpotatis",
    "mandelpotatisen": "mandelpotatis",
    "mandelpotatisens": "mandelpotatis",
    "mandels": "mandel",
    "mandelstenen": "mandelsten",
    "mandelstenens": "mandelsten",
    "mandelstens": "mandelsten",
    "mandelögda": "mandelögd",
    "mandelögdare": "mandelögd",
    "mandelögdares": "mandelögd",
    "mandelögdas": "mandelögd",
    "mandelögdast": "mandelögd",
    "mandelögdaste": "mandelögd",
    "mandelögdastes": "mandelögd",
    "mandelögdasts": "mandelögd",
    "mandelögde": "mandelögd",
    "mandelögdes": "mandelögd",
    "mandelögds": "mandelögd",
    "mandelögt": "mandelögd",
    "mandelögts": "mandelögd",
    "mandibeln": "mandibel",
    "mandibelns": "mandibel",
    "mandibels": "mandibel",
    "mandibler": "mandibel",
    "mandiblerna": "mandibel",
    "mandiblernas": "mandibel",
    "mandiblers": "mandibel",
    "mandlar": "mandel",
    "mandlarna": "mandel",
    "mandlarnas": "mandel",
    "mandlars": "mandel",
    "mandolinen": "mandolin",
    "mandolinens": "mandolin",
    "mandoliner": "mandolin",
    "mandolinerna": "mandolin",
    "mandolinernas": "mandolin",
    "mandoliners": "mandolin",
    "mandolins": "mandolin",
    "mandomar": "mandom",
    "mandomarna": "mandom",
    "mandomarnas": "mandom",
    "mandomars": "mandom",
    "mandomen": "mandom",
    "mandomens": "mandom",
    "mandoms": "mandom",
    "mandomsproven": "mandomsprov",
    "mandomsprovens": "mandomsprov",
    "mandomsprovet": "mandomsprov",
    "mandomsprovets": "mandomsprov",
    "mandomsprovs": "mandomsprov",
    "mandorl": "mandorla",
    "mandorlan": "mandorla",
    "mandorlans": "mandorla",
    "mandorlas": "mandorla",
    "mandorle": "mandorla",
    "mandorlor": "mandorla",
    "mandorlorna": "mandorla",
    "mandorlornas": "mandorla",
    "mandorlors": "mandorla",
    "mandorls": "mandorla",
    "mandragor": "mandragora",
    "mandragoran": "mandragora",
    "mandragorans": "mandragora",
    "mandragoras": "mandragora",
    "mandragore": "mandragora",
    "mandragoror": "mandragora",
    "mandragororna": "mandragora",
    "mandragorornas": "mandragora",
    "mandragorors": "mandragora",
    "mandragors": "mandragora",
    "mandrillen": "mandrill",
    "mandrillens": "mandrill",
    "mandriller": "mandrill",
    "mandrillerna": "mandrill",
    "mandrillernas": "mandrill",
    "mandrillers": "mandrill",
    "mandrills": "mandrill",
    "manegen": "manege",
    "manegens": "manege",
    "maneger": "manege",
    "manegerna": "manege",
    "manegernas": "manege",
    "manegers": "manege",
    "maneges": "manege",
    "manen": "man",
    "manens": "man",
    "maneren": "maner",
    "manerens": "maner",
    "maneret": "maner",
    "manerets": "maner",
    "manerna": "maner",
    "manernas": "maner",
    "maners": "maner",
    "maneten": "manet",
    "manetens": "manet",
    "maneter": "manet",
    "maneterna": "manet",
    "maneternas": "manet",
    "maneters": "manet",
    "manets": "manet",
    "manfallen": "manfall",
    "manfallens": "manfall",
    "manfallet": "manfall",
    "manfallets": "manfall",
    "manfalls": "manfall",
    "manfolken": "manfolk",
    "manfolkens": "manfolk",
    "manfolket": "manfolk",
    "manfolkets": "manfolk",
    "manfolks": "manfolk",
    "manganen": "mangan",
    "manganens": "mangan",
    "manganet": "mangan",
    "manganets": "mangan",
    "manganinen": "manganin",
    "manganinens": "manganin",
    "manganiner": "manganin",
    "manganinerna": "manganin",
    "manganinernas": "manganin",
    "manganiners": "manganin",
    "manganins": "manganin",
    "mangans": "mangan",
    "mangel": "mangla",
    "mangeln": "mangel",
    "mangelns": "mangel",
    "mangels": "mangel",
    "manglad": "mangla",
    "manglade": "mangla",
    "manglades": "mangla",
    "manglads": "mangla",
    "manglande": "mangla",
    "manglanden": "manglande",
    "manglandena": "manglande",
    "manglandenas": "manglande",
    "manglandens": "manglande",
    "manglandes": "manglande",
    "manglandet": "manglande",
    "manglandets": "manglande",
    "manglar": "mangla",
    "manglarna": "mangel",
    "manglarnas": "mangel",
    "manglars": "mangel",
    "manglas": "mangla",
    "manglat": "mangla",
    "manglats": "mangla",
    "mangoer": "mango",
    "mangoerna": "mango",
    "mangoernas": "mango",
    "mangoers": "mango",
    "mangolden": "mangold",
    "mangoldens": "mangold",
    "mangolds": "mangold",
    "mangon": "mango",
    "mangons": "mango",
    "mangor": "mango",
    "mangorna": "mango",
    "mangornas": "mango",
    "mangors": "mango",
    "mangos": "mango",
    "mangranna": "mangrann",
    "mangrannare": "mangrann",
    "mangrannares": "mangrann",
    "mangrannas": "mangrann",
    "mangrannast": "mangrann",
    "mangrannaste": "mangrann",
    "mangrannastes": "mangrann",
    "mangrannasts": "mangrann",
    "mangranne": "mangrann",
    "mangrannes": "mangrann",
    "mangranns": "mangrann",
    "mangrant": "mangrann",
    "mangrants": "mangrann",
    "mangroven": "mangrove",
    "mangrovens": "mangrove",
    "mangrover": "mangrove",
    "mangroverna": "mangrove",
    "mangrovernas": "mangrove",
    "mangrovers": "mangrove",
    "mangroves": "mangrove",
    "mangroveträsken": "mangroveträsk",
    "mangroveträskens": "mangroveträsk",
    "mangroveträsket": "mangroveträsk",
    "mangroveträskets": "mangroveträsk",
    "mangroveträsks": "mangroveträsk",
    "mangårdsbyggnaden": "mangårdsbyggnad",
    "mangårdsbyggnadens": "mangårdsbyggnad",
    "mangårdsbyggnader": "mangårdsbyggnad",
    "mangårdsbyggnaderna": "mangårdsbyggnad",
    "mangårdsbyggnadernas": "mangårdsbyggnad",
    "mangårdsbyggnaders": "mangårdsbyggnad",
    "mangårdsbyggnads": "mangårdsbyggnad",
    "manhaftiga": "manhaftig",
    "manhaftigare": "manhaftig",
    "manhaftigares": "manhaftig",
    "manhaftigas": "manhaftig",
    "manhaftigast": "manhaftig",
    "manhaftigaste": "manhaftig",
    "manhaftigastes": "manhaftig",
    "manhaftigasts": "manhaftig",
    "manhaftige": "manhaftig",
    "manhaftiges": "manhaftig",
    "manhaftigheten": "manhaftighet",
    "manhaftighetens": "manhaftighet",
    "manhaftighets": "manhaftighet",
    "manhaftigs": "manhaftig",
    "manhaftigt": "manhaftig",
    "manhaftigts": "manhaftig",
    "manhålen": "manhål",
    "manhålens": "manhål",
    "manhålet": "manhål",
    "manhålets": "manhål",
    "manhåls": "manhål",
    "maniakaliska": "maniakalisk",
    "maniakaliskare": "maniakalisk",
    "maniakaliskares": "maniakalisk",
    "maniakaliskas": "maniakalisk",
    "maniakaliskast": "maniakalisk",
    "maniakaliskaste": "maniakalisk",
    "maniakaliskastes": "maniakalisk",
    "maniakaliskasts": "maniakalisk",
    "maniakaliske": "maniakalisk",
    "maniakaliskes": "maniakalisk",
    "maniakalisks": "maniakalisk",
    "maniakaliskt": "maniakalisk",
    "maniakaliskts": "maniakalisk",
    "manicken": "manick",
    "manickens": "manick",
    "manicker": "manick",
    "manickerna": "manick",
    "manickernas": "manick",
    "manickers": "manick",
    "manicks": "manick",
    "manien": "mani",
    "maniens": "mani",
    "manier": "mani",
    "maniererade": "maniererad",
    "maniererades": "maniererad",
    "maniererads": "maniererad",
    "maniererat": "maniererad",
    "maniererats": "maniererad",
    "manierismen": "manierism",
    "manierismens": "manierism",
    "manierismer": "manierism",
    "manierismerna": "manierism",
    "manierismernas": "manierism",
    "manierismers": "manierism",
    "manierisms": "manierism",
    "manieristiska": "manieristisk",
    "manieristiskas": "manieristisk",
    "manieristiske": "manieristisk",
    "manieristiskes": "manieristisk",
    "manieristisks": "manieristisk",
    "manieristiskt": "manieristisk",
    "manieristiskts": "manieristisk",
    "manierna": "mani",
    "maniernas": "mani",
    "maniers": "mani",
    "manifesta": "manifest",
    "manifestare": "manifest",
    "manifestares": "manifest",
    "manifestas": "manifest",
    "manifestast": "manifest",
    "manifestaste": "manifest",
    "manifestastes": "manifest",
    "manifestasts": "manifest",
    "manifestationen": "manifestation",
    "manifestationens": "manifestation",
    "manifestationer": "manifestation",
    "manifestationerna": "manifestation",
    "manifestationernas": "manifestation",
    "manifestationers": "manifestation",
    "manifestations": "manifestation",
    "manifeste": "manifest",
    "manifesten": "manifest",
    "manifestens": "manifest",
    "manifesterad": "manifestera",
    "manifesterade": "manifestera",
    "manifesterades": "manifestera",
    "manifesterads": "manifestera",
    "manifesterande": "manifestera",
    "manifesteranden": "manifesterande",
    "manifesterandena": "manifesterande",
    "manifesterandenas": "manifesterande",
    "manifesterandens": "manifesterande",
    "manifesterandes": "manifesterande",
    "manifesterandet": "manifesterande",
    "manifesterandets": "manifesterande",
    "manifesterar": "manifestera",
    "manifesteras": "manifestera",
    "manifesterat": "manifestera",
    "manifesterats": "manifestera",
    "manifesterbara": "manifesterbar",
    "manifesterbarare": "manifesterbar",
    "manifesterbarares": "manifesterbar",
    "manifesterbaras": "manifesterbar",
    "manifesterbarast": "manifesterbar",
    "manifesterbaraste": "manifesterbar",
    "manifesterbarastes": "manifesterbar",
    "manifesterbarasts": "manifesterbar",
    "manifesterbare": "manifesterbar",
    "manifesterbares": "manifesterbar",
    "manifesterbarheten": "manifesterbarhet",
    "manifesterbarhetens": "manifesterbarhet",
    "manifesterbarhets": "manifesterbarhet",
    "manifesterbars": "manifesterbar",
    "manifesterbart": "manifesterbar",
    "manifesterbarts": "manifesterbar",
    "manifesteringar": "manifestering",
    "manifesteringarna": "manifestering",
    "manifesteringarnas": "manifestering",
    "manifesteringars": "manifestering",
    "manifesteringen": "manifestering",
    "manifesteringens": "manifestering",
    "manifesterings": "manifestering",
    "manifestes": "manifest",
    "manifestet": "manifest",
    "manifestets": "manifest",
    "manifests": "manifest",
    "manikeismen": "manikeism",
    "manikeismens": "manikeism",
    "manikeismer": "manikeism",
    "manikeismerna": "manikeism",
    "manikeismernas": "manikeism",
    "manikeismers": "manikeism",
    "manikeisms": "manikeism",
    "manikeistiska": "manikeistisk",
    "manikeistiskas": "manikeistisk",
    "manikeistiske": "manikeistisk",
    "manikeistiskes": "manikeistisk",
    "manikeistisks": "manikeistisk",
    "manikeistiskt": "manikeistisk",
    "manikeistiskts": "manikeistisk",
    "manikern": "maniker",
    "manikerna": "maniker",
    "manikernas": "maniker",
    "manikerns": "maniker",
    "manikers": "maniker",
    "manikuren": "manikur",
    "manikurens": "manikur",
    "manikurer": "manikur",
    "manikurerad": "manikurera",
    "manikurerade": "manikurera",
    "manikurerades": "manikurera",
    "manikurerads": "manikurera",
    "manikurerande": "manikurera",
    "manikureranden": "manikurerande",
    "manikurerandena": "manikurerande",
    "manikurerandenas": "manikurerande",
    "manikurerandens": "manikurerande",
    "manikurerandes": "manikurerande",
    "manikurerandet": "manikurerande",
    "manikurerandets": "manikurerande",
    "manikurerar": "manikurera",
    "manikureras": "manikurera",
    "manikurerat": "manikurera",
    "manikurerats": "manikurera",
    "manikurerbara": "manikurerbar",
    "manikurerbarare": "manikurerbar",
    "manikurerbarares": "manikurerbar",
    "manikurerbaras": "manikurerbar",
    "manikurerbarast": "manikurerbar",
    "manikurerbaraste": "manikurerbar",
    "manikurerbarastes": "manikurerbar",
    "manikurerbarasts": "manikurerbar",
    "manikurerbare": "manikurerbar",
    "manikurerbares": "manikurerbar",
    "manikurerbarheten": "manikurerbarhet",
    "manikurerbarhetens": "manikurerbarhet",
    "manikurerbarhets": "manikurerbarhet",
    "manikurerbars": "manikurerbar",
    "manikurerbart": "manikurerbar",
    "manikurerbarts": "manikurerbar",
    "manikureringar": "manikurering",
    "manikureringarna": "manikurering",
    "manikureringarnas": "manikurering",
    "manikureringars": "manikurering",
    "manikureringen": "manikurering",
    "manikureringens": "manikurering",
    "manikurerings": "manikurering",
    "manikurerna": "manikur",
    "manikurernas": "manikur",
    "manikurers": "manikur",
    "manikuristen": "manikurist",
    "manikuristens": "manikurist",
    "manikurister": "manikurist",
    "manikuristerna": "manikurist",
    "manikuristernas": "manikurist",
    "manikuristers": "manikurist",
    "manikurists": "manikurist",
    "manikurs": "manikur",
    "manikyren": "manikyr",
    "manikyrens": "manikyr",
    "manikyrerad": "manikyrera",
    "manikyrerade": "manikyrera",
    "manikyrerades": "manikyrera",
    "manikyrerads": "manikyrera",
    "manikyrerande": "manikyrera",
    "manikyreranden": "manikyrerande",
    "manikyrerandena": "manikyrerande",
    "manikyrerandenas": "manikyrerande",
    "manikyrerandens": "manikyrerande",
    "manikyrerandes": "manikyrerande",
    "manikyrerandet": "manikyrerande",
    "manikyrerandets": "manikyrerande",
    "manikyrerar": "manikyrera",
    "manikyreras": "manikyrera",
    "manikyrerat": "manikyrera",
    "manikyrerats": "manikyrera",
    "manikyrerbara": "manikyrerbar",
    "manikyrerbarare": "manikyrerbar",
    "manikyrerbarares": "manikyrerbar",
    "manikyrerbaras": "manikyrerbar",
    "manikyrerbarast": "manikyrerbar",
    "manikyrerbaraste": "manikyrerbar",
    "manikyrerbarastes": "manikyrerbar",
    "manikyrerbarasts": "manikyrerbar",
    "manikyrerbare": "manikyrerbar",
    "manikyrerbares": "manikyrerbar",
    "manikyrerbarheten": "manikyrerbarhet",
    "manikyrerbarhetens": "manikyrerbarhet",
    "manikyrerbarhets": "manikyrerbarhet",
    "manikyrerbars": "manikyrerbar",
    "manikyrerbart": "manikyrerbar",
    "manikyrerbarts": "manikyrerbar",
    "manikyreringar": "manikyrering",
    "manikyreringarna": "manikyrering",
    "manikyreringarnas": "manikyrering",
    "manikyreringars": "manikyrering",
    "manikyreringen": "manikyrering",
    "manikyreringens": "manikyrering",
    "manikyrerings": "manikyrering",
    "manikyristen": "manikyrist",
    "manikyristens": "manikyrist",
    "manikyrister": "manikyrist",
    "manikyristerna": "manikyrist",
    "manikyristernas": "manikyrist",
    "manikyristers": "manikyrist",
    "manikyrists": "manikyrist",
    "manikyrs": "manikyr",
    "manikéen": "maniké",
    "manikéens": "maniké",
    "manikéer": "maniké",
    "manikéerna": "maniké",
    "manikéernas": "maniké",
    "manikéers": "maniké",
    "manikén": "maniké",
    "manikéns": "maniké",
    "manikés": "maniké",
    "manillan": "manilla",
    "manillans": "manilla",
    "manillas": "manilla",
    "manin": "mani",
    "maningar": "maning",
    "maningarna": "maning",
    "maningarnas": "maning",
    "maningars": "maning",
    "maningen": "maning",
    "maningens": "maning",
    "manings": "maning",
    "manins": "mani",
    "manioken": "maniok",
    "maniokens": "maniok",
    "manioks": "maniok",
    "manipulationen": "manipulation",
    "manipulationens": "manipulation",
    "manipulationer": "manipulation",
    "manipulationerna": "manipulation",
    "manipulationernas": "manipulation",
    "manipulationers": "manipulation",
    "manipulations": "manipulation",
    "manipulerad": "manipulera",
    "manipulerade": "manipulera",
    "manipulerades": "manipulera",
    "manipulerads": "manipulera",
    "manipulerande": "manipulera",
    "manipuleranden": "manipulerande",
    "manipulerandena": "manipulerande",
    "manipulerandenas": "manipulerande",
    "manipulerandens": "manipulerande",
    "manipulerandes": "manipulerande",
    "manipulerandet": "manipulerande",
    "manipulerandets": "manipulerande",
    "manipulerar": "manipulera",
    "manipuleras": "manipulera",
    "manipulerat": "manipulera",
    "manipulerats": "manipulera",
    "manipulerbara": "manipulerbar",
    "manipulerbarare": "manipulerbar",
    "manipulerbarares": "manipulerbar",
    "manipulerbaras": "manipulerbar",
    "manipulerbarast": "manipulerbar",
    "manipulerbaraste": "manipulerbar",
    "manipulerbarastes": "manipulerbar",
    "manipulerbarasts": "manipulerbar",
    "manipulerbare": "manipulerbar",
    "manipulerbares": "manipulerbar",
    "manipulerbarheten": "manipulerbarhet",
    "manipulerbarhetens": "manipulerbarhet",
    "manipulerbarhets": "manipulerbarhet",
    "manipulerbars": "manipulerbar",
    "manipulerbart": "manipulerbar",
    "manipulerbarts": "manipulerbar",
    "manipuleringar": "manipulering",
    "manipuleringarna": "manipulering",
    "manipuleringarnas": "manipulering",
    "manipuleringars": "manipulering",
    "manipuleringen": "manipulering",
    "manipuleringens": "manipulering",
    "manipulerings": "manipulering",
    "manis": "mani",
    "manisk-depressiva": "manisk-depressiv",
    "manisk-depressivare": "manisk-depressiv",
    "manisk-depressivares": "manisk-depressiv",
    "manisk-depressivas": "manisk-depressiv",
    "manisk-depressivast": "manisk-depressiv",
    "manisk-depressivaste": "manisk-depressiv",
    "manisk-depressivastes": "manisk-depressiv",
    "manisk-depressivasts": "manisk-depressiv",
    "manisk-depressive": "manisk-depressiv",
    "manisk-depressives": "manisk-depressiv",
    "manisk-depressivs": "manisk-depressiv",
    "manisk-depressivt": "manisk-depressiv",
    "manisk-depressivts": "manisk-depressiv",
    "maniska": "manisk",
    "maniskare": "manisk",
    "maniskares": "manisk",
    "maniskas": "manisk",
    "maniskast": "manisk",
    "maniskaste": "manisk",
    "maniskastes": "manisk",
    "maniskasts": "manisk",
    "maniske": "manisk",
    "maniskes": "manisk",
    "manisks": "manisk",
    "maniskt": "manisk",
    "maniskts": "manisk",
    "mank": "manke",
    "mankar": "manke",
    "mankarna": "manke",
    "mankarnas": "manke",
    "mankars": "manke",
    "mankemangen": "mankemang",
    "mankemangens": "mankemang",
    "mankemanger": "mankemang",
    "mankemangerna": "mankemang",
    "mankemangernas": "mankemang",
    "mankemangers": "mankemang",
    "mankemanget": "mankemang",
    "mankemangets": "mankemang",
    "mankemangs": "mankemang",
    "manken": "manke",
    "mankens": "manke",
    "mankerade": "mankera",
    "mankerades": "mankera",
    "mankerande": "mankera",
    "mankeranden": "mankerande",
    "mankerandena": "mankerande",
    "mankerandenas": "mankerande",
    "mankerandens": "mankerande",
    "mankerandes": "mankerande",
    "mankerandet": "mankerande",
    "mankerandets": "mankerande",
    "mankerar": "mankera",
    "mankeras": "mankera",
    "mankerat": "mankera",
    "mankerats": "mankera",
    "mankeringar": "mankering",
    "mankeringarna": "mankering",
    "mankeringarnas": "mankering",
    "mankeringars": "mankering",
    "mankeringen": "mankering",
    "mankeringens": "mankering",
    "mankerings": "mankering",
    "mankes": "manke",
    "mankillen": "mankill",
    "mankillens": "mankill",
    "mankiller": "mankill",
    "mankillerna": "mankill",
    "mankillernas": "mankill",
    "mankillers": "mankill",
    "mankills": "mankill",
    "mankon": "manko",
    "mankona": "manko",
    "mankonas": "manko",
    "mankons": "manko",
    "mankos": "manko",
    "mankot": "manko",
    "mankots": "manko",
    "manks": "manke",
    "mankönen": "mankön",
    "mankönens": "mankön",
    "mankönet": "mankön",
    "mankönets": "mankön",
    "manköns": "mankön",
    "manliga": "manlig",
    "manligare": "manlig",
    "manligares": "manlig",
    "manligas": "manlig",
    "manligast": "manlig",
    "manligaste": "manlig",
    "manligastes": "manlig",
    "manligasts": "manlig",
    "manlige": "manlig",
    "manliges": "manlig",
    "manligheten": "manlighet",
    "manlighetens": "manlighet",
    "manlighets": "manlighet",
    "manlighetsproven": "manlighetsprov",
    "manlighetsprovens": "manlighetsprov",
    "manlighetsprovet": "manlighetsprov",
    "manlighetsprovets": "manlighetsprov",
    "manlighetsprovs": "manlighetsprov",
    "manligs": "manlig",
    "manligt": "manlig",
    "manligts": "manlig",
    "manluck": "manlucka",
    "manluckan": "manlucka",
    "manluckans": "manlucka",
    "manluckas": "manlucka",
    "manlucke": "manlucka",
    "manluckor": "manlucka",
    "manluckorna": "manlucka",
    "manluckornas": "manlucka",
    "manluckors": "manlucka",
    "manlucks": "manlucka",
    "mannagrynen": "mannagryn",
    "mannagrynens": "mannagryn",
    "mannagrynet": "mannagryn",
    "mannagrynets": "mannagryn",
    "mannagryns": "mannagryn",
    "mannagrynsgrötar": "mannagrynsgröt",
    "mannagrynsgrötarna": "mannagrynsgröt",
    "mannagrynsgrötarnas": "mannagrynsgröt",
    "mannagrynsgrötars": "mannagrynsgröt",
    "mannagrynsgröten": "mannagrynsgröt",
    "mannagrynsgrötens": "mannagrynsgröt",
    "mannagrynsgröts": "mannagrynsgröt",
    "mannagräset": "mannagräs",
    "mannagräsets": "mannagräs",
    "mannakraften": "mannakraft",
    "mannakraftens": "mannakraft",
    "mannakrafts": "mannakraft",
    "mannalavar": "mannalav",
    "mannalavarna": "mannalav",
    "mannalavarnas": "mannalav",
    "mannalavars": "mannalav",
    "mannalaven": "mannalav",
    "mannalavens": "mannalav",
    "mannalavs": "mannalav",
    "mannamåns": "mannamån",
    "mannan": "manna",
    "mannans": "manna",
    "mannar": "man",
    "mannarna": "man",
    "mannarnas": "man",
    "mannars": "man",
    "mannas": "manna",
    "mannat": "manna",
    "mannats": "manna",
    "mannaåldern": "mannaålder",
    "mannaålderns": "mannaålder",
    "mannaålders": "mannaålder",
    "mannaåldrar": "mannaålder",
    "mannaåldrarna": "mannaålder",
    "mannaåldrarnas": "mannaålder",
    "mannaåldrars": "mannaålder",
    "mannaåren": "mannaår",
    "mannaårens": "mannaår",
    "mannaårs": "mannaår",
    "mannekängen": "mannekäng",
    "mannekängens": "mannekäng",
    "mannekänger": "mannekäng",
    "mannekängerna": "mannekäng",
    "mannekängernas": "mannekäng",
    "mannekängers": "mannekäng",
    "mannekängs": "mannekäng",
    "mannen": "man",
    "mannens": "man",
    "manodepressiva": "manodepressiv",
    "manodepressivare": "manodepressiv",
    "manodepressivares": "manodepressiv",
    "manodepressivas": "manodepressiv",
    "manodepressivast": "manodepressiv",
    "manodepressivaste": "manodepressiv",
    "manodepressivastes": "manodepressiv",
    "manodepressivasts": "manodepressiv",
    "manodepressive": "manodepressiv",
    "manodepressives": "manodepressiv",
    "manodepressivs": "manodepressiv",
    "manodepressivt": "manodepressiv",
    "manodepressivts": "manodepressiv",
    "manometern": "manometer",
    "manometerns": "manometer",
    "manometers": "manometer",
    "manometrar": "manometer",
    "manometrarna": "manometer",
    "manometrarnas": "manometer",
    "manometrars": "manometer",
    "mans": "man",
    "mansarden": "mansard",
    "mansardens": "mansard",
    "mansarder": "mansard",
    "mansarderna": "mansard",
    "mansardernas": "mansard",
    "mansarders": "mansard",
    "mansards": "mansard",
    "mansardtaken": "mansardtak",
    "mansardtakens": "mansardtak",
    "mansardtaket": "mansardtak",
    "mansardtakets": "mansardtak",
    "mansardtaks": "mansardtak",
    "mansboten": "mansbot",
    "mansbotens": "mansbot",
    "mansbots": "mansbot",
    "manschauvinismen": "manschauvinism",
    "manschauvinismens": "manschauvinism",
    "manschauvinismer": "manschauvinism",
    "manschauvinismerna": "manschauvinism",
    "manschauvinismernas": "manschauvinism",
    "manschauvinismers": "manschauvinism",
    "manschauvinisms": "manschauvinism",
    "manschauvinistiska": "manschauvinistisk",
    "manschauvinistiskas": "manschauvinistisk",
    "manschauvinistiske": "manschauvinistisk",
    "manschauvinistiskes": "manschauvinistisk",
    "manschauvinistisks": "manschauvinistisk",
    "manschauvinistiskt": "manschauvinistisk",
    "manschauvinistiskts": "manschauvinistisk",
    "manschetten": "manschett",
    "manschettens": "manschett",
    "manschetter": "manschett",
    "manschetterna": "manschett",
    "manschetternas": "manschett",
    "manschetters": "manschett",
    "manschettknappar": "manschettknapp",
    "manschettknapparna": "manschettknapp",
    "manschettknapparnas": "manschettknapp",
    "manschettknappars": "manschettknapp",
    "manschettknappen": "manschettknapp",
    "manschettknappens": "manschettknapp",
    "manschettknapps": "manschettknapp",
    "manschettproletariatet": "manschettproletariat",
    "manschettproletariatets": "manschettproletariat",
    "manschettproletariats": "manschettproletariat",
    "manschetts": "manschett",
    "manschettyrken": "manschettyrke",
    "manschettyrkena": "manschettyrke",
    "manschettyrkenas": "manschettyrke",
    "manschettyrkens": "manschettyrke",
    "manschettyrkes": "manschettyrke",
    "manschettyrket": "manschettyrke",
    "manschettyrkets": "manschettyrke",
    "mansdominerade": "mansdominerad",
    "mansdominerades": "mansdominerad",
    "mansdominerads": "mansdominerad",
    "mansdominerat": "mansdominerad",
    "mansdominerats": "mansdominerad",
    "mansgravar": "mansgrav",
    "mansgravarna": "mansgrav",
    "mansgravarnas": "mansgrav",
    "mansgravars": "mansgrav",
    "mansgraven": "mansgrav",
    "mansgravens": "mansgrav",
    "mansgravs": "mansgrav",
    "mansgrisar": "mansgris",
    "mansgrisarna": "mansgris",
    "mansgrisarnas": "mansgris",
    "mansgrisars": "mansgris",
    "mansgrisen": "mansgris",
    "mansgrisens": "mansgris",
    "mansidealen": "mansideal",
    "mansidealens": "mansideal",
    "mansidealet": "mansideal",
    "mansidealets": "mansideal",
    "mansideals": "mansideal",
    "mansintressen": "mansintresse",
    "mansintressena": "mansintresse",
    "mansintressenas": "mansintresse",
    "mansintressens": "mansintresse",
    "mansintresses": "mansintresse",
    "mansintresset": "mansintresse",
    "mansintressets": "mansintresse",
    "manskapen": "manskap",
    "manskapens": "manskap",
    "manskapet": "manskap",
    "manskapets": "manskap",
    "manskaps": "manskap",
    "manskören": "manskör",
    "manskörens": "manskör",
    "manskörer": "manskör",
    "manskörerna": "manskör",
    "manskörernas": "manskör",
    "manskörers": "manskör",
    "manskörs": "manskör",
    "manslemmar": "manslem",
    "manslemmarna": "manslem",
    "manslemmarnas": "manslem",
    "manslemmars": "manslem",
    "manslemmen": "manslem",
    "manslemmens": "manslem",
    "manslems": "manslem",
    "manslukerskan": "manslukerska",
    "manslukerskans": "manslukerska",
    "manslukerskas": "manslukerska",
    "manslukerske": "manslukerska",
    "manslukerskor": "manslukerska",
    "manslukerskorna": "manslukerska",
    "manslukerskornas": "manslukerska",
    "manslukerskors": "manslukerska",
    "manslägerna": "mansläger",
    "manslägernas": "mansläger",
    "manslägers": "mansläger",
    "manslägren": "mansläger",
    "manslägrens": "mansläger",
    "manslägret": "mansläger",
    "manslägrets": "mansläger",
    "mansnamnen": "mansnamn",
    "mansnamnens": "mansnamn",
    "mansnamnet": "mansnamn",
    "mansnamnets": "mansnamn",
    "mansnamns": "mansnamn",
    "manspersonen": "mansperson",
    "manspersonens": "mansperson",
    "manspersoner": "mansperson",
    "manspersonerna": "mansperson",
    "manspersonernas": "mansperson",
    "manspersoners": "mansperson",
    "manspersons": "mansperson",
    "manspillans": "manspillan",
    "manssamhällen": "manssamhälle",
    "manssamhällena": "manssamhälle",
    "manssamhällenas": "manssamhälle",
    "manssamhällens": "manssamhälle",
    "manssamhälles": "manssamhälle",
    "manssamhället": "manssamhälle",
    "manssamhällets": "manssamhälle",
    "manssamhälls": "manssamhälle",
    "manssidan": "manssida",
    "manssidans": "manssida",
    "manssidas": "manssida",
    "mansside": "manssida",
    "manssides": "manssida",
    "manssidor": "manssida",
    "manssidorna": "manssida",
    "manssidornas": "manssida",
    "manssidors": "manssida",
    "mansslukerskan": "mansslukerska",
    "mansslukerskans": "mansslukerska",
    "mansslukerskas": "mansslukerska",
    "mansslukerske": "mansslukerska",
    "mansslukerskor": "mansslukerska",
    "mansslukerskorna": "mansslukerska",
    "mansslukerskornas": "mansslukerska",
    "mansslukerskors": "mansslukerska",
    "manstarka": "manstark",
    "manstarkare": "manstark",
    "manstarkares": "manstark",
    "manstarkas": "manstark",
    "manstarkast": "manstark",
    "manstarkaste": "manstark",
    "manstarkastes": "manstark",
    "manstarkasts": "manstark",
    "manstarke": "manstark",
    "manstarkes": "manstark",
    "manstarks": "manstark",
    "manstarkt": "manstark",
    "manstarkts": "manstark",
    "manstukten": "manstukt",
    "manstuktens": "manstukt",
    "manstukts": "manstukt",
    "mansåldern": "mansålder",
    "mansålderns": "mansålder",
    "mansålders": "mansålder",
    "mansåldrar": "mansålder",
    "mansåldrarna": "mansålder",
    "mansåldrarnas": "mansålder",
    "mansåldrars": "mansålder",
    "mantalen": "mantal",
    "mantalens": "mantal",
    "mantalet": "mantal",
    "mantalets": "mantal",
    "mantals": "mantal",
    "mantalslängden": "mantalslängd",
    "mantalslängdens": "mantalslängd",
    "mantalslängder": "mantalslängd",
    "mantalslängderna": "mantalslängd",
    "mantalslängdernas": "mantalslängd",
    "mantalslängders": "mantalslängd",
    "mantalslängds": "mantalslängd",
    "mantalsskrivens": "mantalsskriven",
    "mantalsskrivet": "mantalsskriven",
    "mantalsskrivets": "mantalsskriven",
    "mantalsskrivna": "mantalsskriven",
    "mantalsskrivnare": "mantalsskriven",
    "mantalsskrivnares": "mantalsskriven",
    "mantalsskrivnas": "mantalsskriven",
    "mantalsskrivnast": "mantalsskriven",
    "mantalsskrivnaste": "mantalsskriven",
    "mantalsskrivnastes": "mantalsskriven",
    "mantalsskrivnasts": "mantalsskriven",
    "mantalsskrivne": "mantalsskriven",
    "mantalsskrivnes": "mantalsskriven",
    "mantalsskrivningar": "mantalsskrivning",
    "mantalsskrivningarna": "mantalsskrivning",
    "mantalsskrivningarnas": "mantalsskrivning",
    "mantalsskrivningars": "mantalsskrivning",
    "mantalsskrivningen": "mantalsskrivning",
    "mantalsskrivningens": "mantalsskrivning",
    "mantalsskrivnings": "mantalsskrivning",
    "mantel": "mantla",
    "manteldjuren": "manteldjur",
    "manteldjurens": "manteldjur",
    "manteldjuret": "manteldjur",
    "manteldjurets": "manteldjur",
    "manteldjurs": "manteldjur",
    "manteln": "mantel",
    "mantelns": "mantel",
    "mantelrörelsen": "mantelrörelse",
    "mantelrörelsens": "mantelrörelse",
    "mantelrörelser": "mantelrörelse",
    "mantelrörelserna": "mantelrörelse",
    "mantelrörelsernas": "mantelrörelse",
    "mantelrörelsers": "mantelrörelse",
    "mantelrörelses": "mantelrörelse",
    "mantels": "mantel",
    "mantelskur": "mantelskura",
    "mantelskuran": "mantelskura",
    "mantelskurans": "mantelskura",
    "mantelskuras": "mantelskura",
    "mantelskure": "mantelskura",
    "mantelskuror": "mantelskura",
    "mantelskurorna": "mantelskura",
    "mantelskurornas": "mantelskura",
    "mantelskurors": "mantelskura",
    "mantelskurs": "mantelskura",
    "mantelstyrningar": "mantelstyrning",
    "mantelstyrningarna": "mantelstyrning",
    "mantelstyrningarnas": "mantelstyrning",
    "mantelstyrningars": "mantelstyrning",
    "mantelstyrningen": "mantelstyrning",
    "mantelstyrningens": "mantelstyrning",
    "mantelstyrnings": "mantelstyrning",
    "mantelytan": "mantelyta",
    "mantelytans": "mantelyta",
    "mantelytas": "mantelyta",
    "mantelyte": "mantelyta",
    "mantelytor": "mantelyta",
    "mantelytorna": "mantelyta",
    "mantelytornas": "mantelyta",
    "mantelytors": "mantelyta",
    "mantiljen": "mantilj",
    "mantiljens": "mantilj",
    "mantiljer": "mantilj",
    "mantiljerna": "mantilj",
    "mantiljernas": "mantilj",
    "mantiljers": "mantilj",
    "mantiljs": "mantilj",
    "mantiss": "mantissa",
    "mantissan": "mantissa",
    "mantissans": "mantissa",
    "mantissas": "mantissa",
    "mantisse": "mantissa",
    "mantissor": "mantissa",
    "mantissorna": "mantissa",
    "mantissornas": "mantissa",
    "mantissors": "mantissa",
    "mantlad": "mantla",
    "mantlade": "mantla",
    "mantlades": "mantla",
    "mantlads": "mantla",
    "mantlande": "mantla",
    "mantlanden": "mantlande",
    "mantlandena": "mantlande",
    "mantlandenas": "mantlande",
    "mantlandens": "mantlande",
    "mantlandes": "mantlande",
    "mantlandet": "mantlande",
    "mantlandets": "mantlande",
    "mantlar": "mantla",
    "mantlarna": "mantel",
    "mantlarnas": "mantel",
    "mantlars": "mantel",
    "mantlas": "mantla",
    "mantlat": "mantla",
    "mantlats": "mantla",
    "mantågen": "mantåg",
    "mantågens": "mantåg",
    "mantåget": "mantåg",
    "mantågets": "mantåg",
    "mantågs": "mantåg",
    "manualen": "manual",
    "manualens": "manual",
    "manualer": "manual",
    "manualerna": "manual",
    "manualernas": "manual",
    "manualers": "manual",
    "manuals": "manual",
    "manuella": "manuell",
    "manuellare": "manuell",
    "manuellares": "manuell",
    "manuellas": "manuell",
    "manuellast": "manuell",
    "manuellaste": "manuell",
    "manuellastes": "manuell",
    "manuellasts": "manuell",
    "manuelle": "manuell",
    "manuelles": "manuell",
    "manuells": "manuell",
    "manuellt": "manuell",
    "manuellts": "manuell",
    "manufakturen": "manufaktur",
    "manufakturens": "manufaktur",
    "manufakturer": "manufaktur",
    "manufakturerna": "manufaktur",
    "manufakturernas": "manufaktur",
    "manufakturers": "manufaktur",
    "manufakturs": "manufaktur",
    "manusen": "manus",
    "manusens": "manus",
    "manuset": "manus",
    "manusets": "manus",
    "manusförfattar": "manusförfattare",
    "manusförfattaren": "manusförfattare",
    "manusförfattarens": "manusförfattare",
    "manusförfattares": "manusförfattare",
    "manusförfattarna": "manusförfattare",
    "manusförfattarnas": "manusförfattare",
    "manusgenomgångar": "manusgenomgång",
    "manusgenomgångarna": "manusgenomgång",
    "manusgenomgångarnas": "manusgenomgång",
    "manusgenomgångars": "manusgenomgång",
    "manusgenomgången": "manusgenomgång",
    "manusgenomgångens": "manusgenomgång",
    "manusgenomgångs": "manusgenomgång",
    "manuskripten": "manuskript",
    "manuskriptens": "manuskript",
    "manuskriptet": "manuskript",
    "manuskriptets": "manuskript",
    "manuskripts": "manuskript",
    "manåren": "manår",
    "manårens": "manår",
    "manåret": "manår",
    "manårets": "manår",
    "manårs": "manår",
    "manéren": "manér",
    "manérens": "manér",
    "manéret": "manér",
    "manérets": "manér",
    "manérs": "manér",
    "manöverdugliga": "manöverduglig",
    "manöverdugligare": "manöverduglig",
    "manöverdugligares": "manöverduglig",
    "manöverdugligas": "manöverduglig",
    "manöverdugligast": "manöverduglig",
    "manöverdugligaste": "manöverduglig",
    "manöverdugligastes": "manöverduglig",
    "manöverdugligasts": "manöverduglig",
    "manöverduglige": "manöverduglig",
    "manöverdugliges": "manöverduglig",
    "manöverdugligheten": "manöverduglighet",
    "manöverduglighetens": "manöverduglighet",
    "manöverduglighets": "manöverduglighet",
    "manöverdugligs": "manöverduglig",
    "manöverdugligt": "manöverduglig",
    "manöverdugligts": "manöverduglig",
    "manöverkraften": "manöverkraft",
    "manöverkraftens": "manöverkraft",
    "manöverkrafter": "manöverkraft",
    "manöverkrafterna": "manöverkraft",
    "manöverkrafternas": "manöverkraft",
    "manöverkrafters": "manöverkraft",
    "manöverkrafts": "manöverkraft",
    "manövern": "manöver",
    "manöverns": "manöver",
    "manövers": "manöver",
    "manöverutrymmen": "manöverutrymme",
    "manöverutrymmena": "manöverutrymme",
    "manöverutrymmenas": "manöverutrymme",
    "manöverutrymmens": "manöverutrymme",
    "manöverutrymmes": "manöverutrymme",
    "manöverutrymmet": "manöverutrymme",
    "manöverutrymmets": "manöverutrymme",
    "manövrar": "manöver",
    "manövrarna": "manöver",
    "manövrarnas": "manöver",
    "manövrars": "manöver",
    "manövrer": "manöver",
    "manövrerad": "manövrera",
    "manövrerade": "manövrera",
    "manövrerades": "manövrera",
    "manövrerads": "manövrera",
    "manövrerande": "manövrera",
    "manövreranden": "manövrerande",
    "manövrerandena": "manövrerande",
    "manövrerandenas": "manövrerande",
    "manövrerandens": "manövrerande",
    "manövrerandes": "manövrerande",
    "manövrerandet": "manövrerande",
    "manövrerandets": "manövrerande",
    "manövrerar": "manövrera",
    "manövreras": "manövrera",
    "manövrerat": "manövrera",
    "manövrerats": "manövrera",
    "manövrerbara": "manövrerbar",
    "manövrerbarare": "manövrerbar",
    "manövrerbarares": "manövrerbar",
    "manövrerbaras": "manövrerbar",
    "manövrerbarast": "manövrerbar",
    "manövrerbaraste": "manövrerbar",
    "manövrerbarastes": "manövrerbar",
    "manövrerbarasts": "manövrerbar",
    "manövrerbare": "manövrerbar",
    "manövrerbares": "manövrerbar",
    "manövrerbarheten": "manövrerbarhet",
    "manövrerbarhetens": "manövrerbarhet",
    "manövrerbarhets": "manövrerbarhet",
    "manövrerbars": "manövrerbar",
    "manövrerbart": "manövrerbar",
    "manövrerbarts": "manövrerbar",
    "manövreringar": "manövrering",
    "manövreringarna": "manövrering",
    "manövreringarnas": "manövrering",
    "manövreringars": "manövrering",
    "manövreringen": "manövrering",
    "manövreringens": "manövrering",
    "manövrerings": "manövrering",
    "manövrerna": "manöver",
    "manövrernas": "manöver",
    "manövrers": "manöver",
    "maoismen": "maoism",
    "maoismens": "maoism",
    "maoismer": "maoism",
    "maoismerna": "maoism",
    "maoismernas": "maoism",
    "maoismers": "maoism",
    "maoisms": "maoism",
    "maoistiska": "maoistisk",
    "maoistiskas": "maoistisk",
    "maoistiske": "maoistisk",
    "maoistiskes": "maoistisk",
    "maoistisks": "maoistisk",
    "maoistiskt": "maoistisk",
    "maoistiskts": "maoistisk",
    "maorier": "maori",
    "maoriern": "maorier",
    "maorierna": "maorier",
    "maoriernas": "maorier",
    "maorierns": "maorier",
    "maoriers": "maorier",
    "maorin": "maori",
    "maorins": "maori",
    "maoris": "maori",
    "maoriska": "maorisk",
    "maoriskare": "maorisk",
    "maoriskares": "maorisk",
    "maoriskas": "maorisk",
    "maoriskast": "maorisk",
    "maoriskaste": "maorisk",
    "maoriskastes": "maorisk",
    "maoriskasts": "maorisk",
    "maoriske": "maorisk",
    "maoriskes": "maorisk",
    "maorisks": "maorisk",
    "maoriskt": "maorisk",
    "maoriskts": "maorisk",
    "mappar": "mapp",
    "mapparna": "mapp",
    "mapparnas": "mapp",
    "mappars": "mapp",
    "mappen": "mapp",
    "mappens": "mapp",
    "mapps": "mapp",
    "mar": "mara",
    "marabuer": "marabu",
    "marabuerna": "marabu",
    "marabuernas": "marabu",
    "marabuers": "marabu",
    "marabun": "marabu",
    "marabuns": "marabu",
    "marabus": "marabu",
    "maran": "mara",
    "maranatas": "maranata",
    "marans": "mara",
    "maras": "mara",
    "maraskinon": "maraskino",
    "maraskinons": "maraskino",
    "maraskinos": "maraskino",
    "marasmen": "marasm",
    "marasmens": "marasm",
    "marasms": "marasm",
    "maratonen": "maraton",
    "maratonens": "maraton",
    "maratonet": "maraton",
    "maratonets": "maraton",
    "maratonförhandlingar": "maratonförhandling",
    "maratonförhandlingarna": "maratonförhandling",
    "maratonförhandlingarnas": "maratonförhandling",
    "maratonförhandlingars": "maratonförhandling",
    "maratonförhandlingen": "maratonförhandling",
    "maratonförhandlingens": "maratonförhandling",
    "maratonförhandlings": "maratonförhandling",
    "maratonloppen": "maratonlopp",
    "maratonloppens": "maratonlopp",
    "maratonloppet": "maratonlopp",
    "maratonloppets": "maratonlopp",
    "maratonlopps": "maratonlopp",
    "maratons": "maraton",
    "mardrömmar": "mardröm",
    "mardrömmarna": "mardröm",
    "mardrömmarnas": "mardröm",
    "mardrömmars": "mardröm",
    "mardrömmen": "mardröm",
    "mardrömmens": "mardröm",
    "mardröms": "mardröm",
    "mardrömscenarier": "mardrömscenario",
    "mardrömscenarierna": "mardrömscenario",
    "mardrömscenariernas": "mardrömscenario",
    "mardrömscenariers": "mardrömscenario",
    "mardrömscenarion": "mardrömscenario",
    "mardrömscenariona": "mardrömscenario",
    "mardrömscenarionas": "mardrömscenario",
    "mardrömscenarions": "mardrömscenario",
    "mardrömscenarios": "mardrömscenario",
    "mardrömscenariot": "mardrömscenario",
    "mardrömscenariots": "mardrömscenario",
    "mardrömsjulfesten": "mardrömsjulfest",
    "mardrömsjulfestens": "mardrömsjulfest",
    "mardrömsjulfester": "mardrömsjulfest",
    "mardrömsjulfesterna": "mardrömsjulfest",
    "mardrömsjulfesternas": "mardrömsjulfest",
    "mardrömsjulfesters": "mardrömsjulfest",
    "mardrömsjulfests": "mardrömsjulfest",
    "mardrömslika": "mardrömslik",
    "mardrömslikare": "mardrömslik",
    "mardrömslikares": "mardrömslik",
    "mardrömslikas": "mardrömslik",
    "mardrömslikast": "mardrömslik",
    "mardrömslikaste": "mardrömslik",
    "mardrömslikastes": "mardrömslik",
    "mardrömslikasts": "mardrömslik",
    "mardrömslike": "mardrömslik",
    "mardrömslikes": "mardrömslik",
    "mardrömslikheten": "mardrömslikhet",
    "mardrömslikhetens": "mardrömslikhet",
    "mardrömslikhets": "mardrömslikhet",
    "mardrömsliks": "mardrömslik",
    "mardrömslikt": "mardrömslik",
    "mardrömslikts": "mardrömslik",
    "mardrömsstarten": "mardrömsstart",
    "mardrömsstartens": "mardrömsstart",
    "mardrömsstarter": "mardrömsstart",
    "mardrömsstarterna": "mardrömsstart",
    "mardrömsstarternas": "mardrömsstart",
    "mardrömsstarters": "mardrömsstart",
    "mardrömsstarts": "mardrömsstart",
    "mardrömssynen": "mardrömssyn",
    "mardrömssynens": "mardrömssyn",
    "mardrömssyner": "mardrömssyn",
    "mardrömssynerna": "mardrömssyn",
    "mardrömssynernas": "mardrömssyn",
    "mardrömssyners": "mardrömssyn",
    "mardrömssyns": "mardrömssyn",
    "mare": "mara",
    "marelden": "mareld",
    "mareldens": "mareld",
    "marelds": "mareld",
    "margarinen": "margarin",
    "margarinens": "margarin",
    "margariner": "margarin",
    "margarinerna": "margarin",
    "margarinernas": "margarin",
    "margariners": "margarin",
    "margarinet": "margarin",
    "margarinets": "margarin",
    "margarins": "margarin",
    "margen": "marg",
    "margens": "marg",
    "marger": "marg",
    "margerna": "marg",
    "margernas": "marg",
    "margers": "marg",
    "margfaldiga": "margfaldig",
    "margfaldigare": "margfaldig",
    "margfaldigares": "margfaldig",
    "margfaldigas": "margfaldig",
    "margfaldigast": "margfaldig",
    "margfaldigaste": "margfaldig",
    "margfaldigastes": "margfaldig",
    "margfaldigasts": "margfaldig",
    "margfaldige": "margfaldig",
    "margfaldiges": "margfaldig",
    "margfaldigs": "margfaldig",
    "margfaldigt": "margfaldig",
    "margfaldigts": "margfaldig",
    "marginalanteckningar": "marginalanteckning",
    "marginalanteckningarna": "marginalanteckning",
    "marginalanteckningarnas": "marginalanteckning",
    "marginalanteckningars": "marginalanteckning",
    "marginalanteckningen": "marginalanteckning",
    "marginalanteckningens": "marginalanteckning",
    "marginalantecknings": "marginalanteckning",
    "marginalbeskattningar": "marginalbeskattning",
    "marginalbeskattningarna": "marginalbeskattning",
    "marginalbeskattningarnas": "marginalbeskattning",
    "marginalbeskattningars": "marginalbeskattning",
    "marginalbeskattningen": "marginalbeskattning",
    "marginalbeskattningens": "marginalbeskattning",
    "marginalbeskattnings": "marginalbeskattning",
    "marginaleffekten": "marginaleffekt",
    "marginaleffektens": "marginaleffekt",
    "marginaleffekter": "marginaleffekt",
    "marginaleffekterna": "marginaleffekt",
    "marginaleffekternas": "marginaleffekt",
    "marginaleffekters": "marginaleffekt",
    "marginaleffekts": "marginaleffekt",
    "marginalen": "marginal",
    "marginalens": "marginal",
    "marginaler": "marginal",
    "marginalerna": "marginal",
    "marginalernas": "marginal",
    "marginalers": "marginal",
    "marginalinkomsten": "marginalinkomst",
    "marginalinkomstens": "marginalinkomst",
    "marginalinkomster": "marginalinkomst",
    "marginalinkomsterna": "marginalinkomst",
    "marginalinkomsternas": "marginalinkomst",
    "marginalinkomsters": "marginalinkomst",
    "marginalinkomsts": "marginalinkomst",
    "marginalintäkten": "marginalintäkt",
    "marginalintäktens": "marginalintäkt",
    "marginalintäkter": "marginalintäkt",
    "marginalintäkterna": "marginalintäkt",
    "marginalintäkternas": "marginalintäkt",
    "marginalintäkters": "marginalintäkt",
    "marginalintäkts": "marginalintäkt",
    "marginaliserad": "marginalisera",
    "marginaliserade": "marginaliserad",
    "marginaliserades": "marginaliserad",
    "marginaliserads": "marginaliserad",
    "marginaliseraingar": "marginaliseraing",
    "marginaliseraingarna": "marginaliseraing",
    "marginaliseraingarnas": "marginaliseraing",
    "marginaliseraingars": "marginaliseraing",
    "marginaliseraingen": "marginaliseraing",
    "marginaliseraingens": "marginaliseraing",
    "marginaliseraings": "marginaliseraing",
    "marginaliserande": "marginalisera",
    "marginaliseranden": "marginaliserande",
    "marginaliserandena": "marginaliserande",
    "marginaliserandenas": "marginaliserande",
    "marginaliserandens": "marginaliserande",
    "marginaliserandes": "marginaliserande",
    "marginaliserandet": "marginaliserande",
    "marginaliserandets": "marginaliserande",
    "marginaliserar": "marginalisera",
    "marginaliseras": "marginalisera",
    "marginaliserat": "marginaliserad",
    "marginaliserats": "marginaliserad",
    "marginaliserbara": "marginaliserbar",
    "marginaliserbarare": "marginaliserbar",
    "marginaliserbarares": "marginaliserbar",
    "marginaliserbaras": "marginaliserbar",
    "marginaliserbarast": "marginaliserbar",
    "marginaliserbaraste": "marginaliserbar",
    "marginaliserbarastes": "marginaliserbar",
    "marginaliserbarasts": "marginaliserbar",
    "marginaliserbare": "marginaliserbar",
    "marginaliserbares": "marginaliserbar",
    "marginaliserbarheten": "marginaliserbarhet",
    "marginaliserbarhetens": "marginaliserbarhet",
    "marginaliserbarhets": "marginaliserbarhet",
    "marginaliserbars": "marginaliserbar",
    "marginaliserbart": "marginaliserbar",
    "marginaliserbarts": "marginaliserbar",
    "marginalkostnaden": "marginalkostnad",
    "marginalkostnadens": "marginalkostnad",
    "marginalkostnader": "marginalkostnad",
    "marginalkostnaderna": "marginalkostnad",
    "marginalkostnadernas": "marginalkostnad",
    "marginalkostnaders": "marginalkostnad",
    "marginalkostnads": "marginalkostnad",
    "marginals": "marginal",
    "marginalskatten": "marginalskatt",
    "marginalskattens": "marginalskatt",
    "marginalskatter": "marginalskatt",
    "marginalskatterna": "marginalskatt",
    "marginalskatternas": "marginalskatt",
    "marginalskatters": "marginalskatt",
    "marginalskatts": "marginalskatt",
    "marginalväljar": "marginalväljare",
    "marginalväljaren": "marginalväljare",
    "marginalväljarens": "marginalväljare",
    "marginalväljares": "marginalväljare",
    "marginalväljarna": "marginalväljare",
    "marginalväljarnas": "marginalväljare",
    "marginella": "marginell",
    "marginellare": "marginell",
    "marginellares": "marginell",
    "marginellas": "marginell",
    "marginellast": "marginell",
    "marginellaste": "marginell",
    "marginellastes": "marginell",
    "marginellasts": "marginell",
    "marginelle": "marginell",
    "marginelles": "marginell",
    "marginells": "marginell",
    "marginellt": "marginell",
    "marginellts": "marginell",
    "margräset": "margräs",
    "margräsets": "margräs",
    "margs": "marg",
    "mariga": "marig",
    "marigare": "marig",
    "marigares": "marig",
    "marigas": "marig",
    "marigast": "marig",
    "marigaste": "marig",
    "marigastes": "marig",
    "marigasts": "marig",
    "marige": "marig",
    "mariges": "marig",
    "marigs": "marig",
    "marigt": "marig",
    "marigts": "marig",
    "marihuanan": "marihuana",
    "marihuanans": "marihuana",
    "marihuanas": "marihuana",
    "marijuanan": "marijuana",
    "marijuanans": "marijuana",
    "marijuanas": "marijuana",
    "marimb": "marimba",
    "marimban": "marimba",
    "marimbans": "marimba",
    "marimbas": "marimba",
    "marimbe": "marimba",
    "marimbor": "marimba",
    "marimborna": "marimba",
    "marimbornas": "marimba",
    "marimbors": "marimba",
    "marimbs": "marimba",
    "marin": "marina",
    "marina": "marin",
    "marinaden": "marinad",
    "marinadens": "marinad",
    "marinader": "marinad",
    "marinaderna": "marinad",
    "marinadernas": "marinad",
    "marinaders": "marinad",
    "marinads": "marinad",
    "marinan": "marina",
    "marinans": "marina",
    "marinare": "marin",
    "marinares": "marin",
    "marinarkeologen": "marinarkeolog",
    "marinarkeologens": "marinarkeolog",
    "marinarkeologer": "marinarkeolog",
    "marinarkeologerna": "marinarkeolog",
    "marinarkeologernas": "marinarkeolog",
    "marinarkeologers": "marinarkeolog",
    "marinarkeologien": "marinarkeologi",
    "marinarkeologiens": "marinarkeologi",
    "marinarkeologin": "marinarkeologi",
    "marinarkeologins": "marinarkeologi",
    "marinarkeologis": "marinarkeologi",
    "marinarkeologs": "marinarkeolog",
    "marinas": "marina",
    "marinast": "marin",
    "marinaste": "marin",
    "marinastes": "marin",
    "marinasts": "marin",
    "marinattachéer": "marinattaché",
    "marinattachéerna": "marinattaché",
    "marinattachéernas": "marinattaché",
    "marinattachéers": "marinattaché",
    "marinattachén": "marinattaché",
    "marinattachéns": "marinattaché",
    "marinattachés": "marinattaché",
    "marinbiologen": "marinbiolog",
    "marinbiologens": "marinbiolog",
    "marinbiologer": "marinbiolog",
    "marinbiologerna": "marinbiolog",
    "marinbiologernas": "marinbiolog",
    "marinbiologers": "marinbiolog",
    "marinbiologien": "marinbiologi",
    "marinbiologiens": "marinbiologi",
    "marinbiologin": "marinbiologi",
    "marinbiologins": "marinbiologi",
    "marinbiologis": "marinbiologi",
    "marinbiologiska": "marinbiologisk",
    "marinbiologiskare": "marinbiologisk",
    "marinbiologiskares": "marinbiologisk",
    "marinbiologiskas": "marinbiologisk",
    "marinbiologiskast": "marinbiologisk",
    "marinbiologiskaste": "marinbiologisk",
    "marinbiologiskastes": "marinbiologisk",
    "marinbiologiskasts": "marinbiologisk",
    "marinbiologiske": "marinbiologisk",
    "marinbiologiskes": "marinbiologisk",
    "marinbiologisks": "marinbiologisk",
    "marinbiologiskt": "marinbiologisk",
    "marinbiologiskts": "marinbiologisk",
    "marinbiologs": "marinbiolog",
    "marinblåa": "marinblå",
    "marinblåare": "marinblå",
    "marinblåares": "marinblå",
    "marinblåas": "marinblå",
    "marinblåast": "marinblå",
    "marinblåaste": "marinblå",
    "marinblåastes": "marinblå",
    "marinblåasts": "marinblå",
    "marinblåe": "marinblå",
    "marinblåes": "marinblå",
    "marinblås": "marinblå",
    "marinblått": "marinblå",
    "marinblåtts": "marinblå",
    "marindirektören": "marindirektör",
    "marindirektörens": "marindirektör",
    "marindirektörer": "marindirektör",
    "marindirektörerna": "marindirektör",
    "marindirektörernas": "marindirektör",
    "marindirektörers": "marindirektör",
    "marindirektörn": "marindirektör",
    "marindirektörns": "marindirektör",
    "marindirektörs": "marindirektör",
    "marine": "marina",
    "marinen": "marin",
    "marinens": "marin",
    "mariner": "marin",
    "marinerad": "marinera",
    "marinerade": "marinera",
    "marinerades": "marinera",
    "marinerads": "marinera",
    "marinerande": "marinera",
    "marineranden": "marinerande",
    "marinerandena": "marinerande",
    "marinerandenas": "marinerande",
    "marinerandens": "marinerande",
    "marinerandes": "marinerande",
    "marinerandet": "marinerande",
    "marinerandets": "marinerande",
    "marinerar": "marinera",
    "marineras": "marinera",
    "marinerat": "marinera",
    "marinerats": "marinera",
    "marinerbara": "marinerbar",
    "marinerbarare": "marinerbar",
    "marinerbarares": "marinerbar",
    "marinerbaras": "marinerbar",
    "marinerbarast": "marinerbar",
    "marinerbaraste": "marinerbar",
    "marinerbarastes": "marinerbar",
    "marinerbarasts": "marinerbar",
    "marinerbare": "marinerbar",
    "marinerbares": "marinerbar",
    "marinerbarheten": "marinerbarhet",
    "marinerbarhetens": "marinerbarhet",
    "marinerbarhets": "marinerbarhet",
    "marinerbars": "marinerbar",
    "marinerbart": "marinerbar",
    "marinerbarts": "marinerbar",
    "marineringar": "marinering",
    "marineringarna": "marinering",
    "marineringarnas": "marinering",
    "marineringars": "marinering",
    "marineringen": "marinering",
    "marineringens": "marinering",
    "marinerings": "marinering",
    "marinerna": "marin",
    "marinernas": "marin",
    "mariners": "marin",
    "marines": "marin",
    "marinkåren": "marinkår",
    "marinkårens": "marinkår",
    "marinkårer": "marinkår",
    "marinkårerna": "marinkår",
    "marinkårernas": "marinkår",
    "marinkårers": "marinkår",
    "marinkårs": "marinkår",
    "marinledningar": "marinledning",
    "marinledningarna": "marinledning",
    "marinledningarnas": "marinledning",
    "marinledningars": "marinledning",
    "marinledningen": "marinledning",
    "marinledningens": "marinledning",
    "marinlednings": "marinledning",
    "marinor": "marina",
    "marinorna": "marina",
    "marinornas": "marina",
    "marinors": "marina",
    "marins": "marina",
    "marinsoldaten": "marinsoldat",
    "marinsoldatens": "marinsoldat",
    "marinsoldater": "marinsoldat",
    "marinsoldaterna": "marinsoldat",
    "marinsoldaternas": "marinsoldat",
    "marinsoldaters": "marinsoldat",
    "marinsoldats": "marinsoldat",
    "marinstyrkan": "marinstyrka",
    "marinstyrkans": "marinstyrka",
    "marinstyrkas": "marinstyrka",
    "marinstyrke": "marinstyrka",
    "marinstyrkor": "marinstyrka",
    "marinstyrkorna": "marinstyrka",
    "marinstyrkornas": "marinstyrka",
    "marinstyrkors": "marinstyrka",
    "marint": "marin",
    "marints": "marin",
    "marionetten": "marionett",
    "marionettens": "marionett",
    "marionetter": "marionett",
    "marionetterna": "marionett",
    "marionetternas": "marionett",
    "marionetters": "marionett",
    "marionetts": "marionett",
    "maritima": "maritim",
    "maritimare": "maritim",
    "maritimares": "maritim",
    "maritimas": "maritim",
    "maritimast": "maritim",
    "maritimaste": "maritim",
    "maritimastes": "maritim",
    "maritimasts": "maritim",
    "maritime": "maritim",
    "maritimes": "maritim",
    "maritims": "maritim",
    "maritimt": "maritim",
    "maritimts": "maritim",
    "markanta": "markant",
    "markantare": "markant",
    "markantares": "markant",
    "markantas": "markant",
    "markantast": "markant",
    "markantaste": "markant",
    "markantastes": "markant",
    "markantasts": "markant",
    "markante": "markant",
    "markantes": "markant",
    "markants": "markant",
    "markatt": "markatta",
    "markattan": "markatta",
    "markattans": "markatta",
    "markattas": "markatta",
    "markatte": "markatta",
    "markattor": "markatta",
    "markattorna": "markatta",
    "markattornas": "markatta",
    "markattors": "markatta",
    "markatts": "markatta",
    "markeffektfarkosten": "markeffektfarkost",
    "markeffektfarkostens": "markeffektfarkost",
    "markeffektfarkoster": "markeffektfarkost",
    "markeffektfarkosterna": "markeffektfarkost",
    "markeffektfarkosternas": "markeffektfarkost",
    "markeffektfarkosters": "markeffektfarkost",
    "markeffektfarkosts": "markeffektfarkost",
    "markegångar": "markegång",
    "markegångarna": "markegång",
    "markegångarnas": "markegång",
    "markegångars": "markegång",
    "markegången": "markegång",
    "markegångens": "markegång",
    "markegångs": "markegång",
    "marken": "mark",
    "markens": "mark",
    "marker": "markera",
    "markerad": "markera",
    "markerade": "markerad",
    "markerades": "markerad",
    "markerads": "markerad",
    "markerande": "markera",
    "markeranden": "markerande",
    "markerandena": "markerande",
    "markerandenas": "markerande",
    "markerandens": "markerande",
    "markerandes": "markerande",
    "markerandet": "markerande",
    "markerandets": "markerande",
    "markerar": "markera",
    "markeras": "markera",
    "markerat": "markerad",
    "markerats": "markerad",
    "markerbara": "markerbar",
    "markerbarare": "markerbar",
    "markerbarares": "markerbar",
    "markerbaras": "markerbar",
    "markerbarast": "markerbar",
    "markerbaraste": "markerbar",
    "markerbarastes": "markerbar",
    "markerbarasts": "markerbar",
    "markerbare": "markerbar",
    "markerbares": "markerbar",
    "markerbarheten": "markerbarhet",
    "markerbarhetens": "markerbarhet",
    "markerbarhets": "markerbarhet",
    "markerbars": "markerbar",
    "markerbart": "markerbar",
    "markerbarts": "markerbar",
    "markeringar": "markering",
    "markeringarna": "markering",
    "markeringarnas": "markering",
    "markeringars": "markering",
    "markeringen": "markering",
    "markeringens": "markering",
    "markerings": "markering",
    "markerna": "mark",
    "markernas": "mark",
    "markers": "mark",
    "marketentar": "marketentare",
    "marketentaren": "marketentare",
    "marketentarens": "marketentare",
    "marketentares": "marketentare",
    "marketentarna": "marketentare",
    "marketentarnas": "marketentare",
    "marketenterier": "marketenteri",
    "marketenterierna": "marketenteri",
    "marketenteriernas": "marketenteri",
    "marketenteriers": "marketenteri",
    "marketenteriet": "marketenteri",
    "marketenteriets": "marketenteri",
    "marketenteris": "marketenteri",
    "marketenterit": "marketenteri",
    "marketenterits": "marketenteri",
    "marketerier": "marketeri",
    "marketerierna": "marketeri",
    "marketeriernas": "marketeri",
    "marketeriers": "marketeri",
    "marketeriet": "marketeri",
    "marketeriets": "marketeri",
    "marketeris": "marketeri",
    "marketerit": "marketeri",
    "marketerits": "marketeri",
    "marketingen": "marketing",
    "marketingens": "marketing",
    "marketings": "marketing",
    "markgrev": "markgreve",
    "markgrevar": "markgreve",
    "markgrevarna": "markgreve",
    "markgrevarnas": "markgreve",
    "markgrevars": "markgreve",
    "markgreven": "markgreve",
    "markgrevens": "markgreve",
    "markgreves": "markgreve",
    "markgrevs": "markgreve",
    "markisen": "markis",
    "markisens": "markis",
    "markiser": "markis",
    "markiserna": "markis",
    "markisernas": "markis",
    "markisers": "markis",
    "markkonflikten": "markkonflikt",
    "markkonfliktens": "markkonflikt",
    "markkonflikter": "markkonflikt",
    "markkonflikterna": "markkonflikt",
    "markkonflikternas": "markkonflikt",
    "markkonflikters": "markkonflikt",
    "markkonflikts": "markkonflikt",
    "markläran": "marklära",
    "marklärans": "marklära",
    "markläras": "marklära",
    "markläre": "marklära",
    "markläro": "marklära",
    "markläror": "marklära",
    "marklärorna": "marklära",
    "marklärornas": "marklära",
    "marklärors": "marklära",
    "marknaden": "marknad",
    "marknadens": "marknad",
    "marknader": "marknad",
    "marknaderna": "marknad",
    "marknadernas": "marknad",
    "marknaders": "marknad",
    "marknads": "marknad",
    "marknadsandelar": "marknadsandel",
    "marknadsandelarna": "marknadsandel",
    "marknadsandelarnas": "marknadsandel",
    "marknadsandelars": "marknadsandel",
    "marknadsandelen": "marknadsandel",
    "marknadsandelens": "marknadsandel",
    "marknadsandels": "marknadsandel",
    "marknadsanpassad": "marknadsanpassa",
    "marknadsanpassade": "marknadsanpassa",
    "marknadsanpassades": "marknadsanpassa",
    "marknadsanpassads": "marknadsanpassa",
    "marknadsanpassande": "marknadsanpassa",
    "marknadsanpassanden": "marknadsanpassande",
    "marknadsanpassandena": "marknadsanpassande",
    "marknadsanpassandenas": "marknadsanpassande",
    "marknadsanpassandens": "marknadsanpassande",
    "marknadsanpassandes": "marknadsanpassande",
    "marknadsanpassandet": "marknadsanpassande",
    "marknadsanpassandets": "marknadsanpassande",
    "marknadsanpassar": "marknadsanpassa",
    "marknadsanpassas": "marknadsanpassa",
    "marknadsanpassat": "marknadsanpassa",
    "marknadsanpassats": "marknadsanpassa",
    "marknadsekonomien": "marknadsekonomi",
    "marknadsekonomiens": "marknadsekonomi",
    "marknadsekonomier": "marknadsekonomi",
    "marknadsekonomierna": "marknadsekonomi",
    "marknadsekonomiernas": "marknadsekonomi",
    "marknadsekonomiers": "marknadsekonomi",
    "marknadsekonomin": "marknadsekonomi",
    "marknadsekonomins": "marknadsekonomi",
    "marknadsekonomis": "marknadsekonomi",
    "marknadsekonomiska": "marknadsekonomisk",
    "marknadsekonomiskare": "marknadsekonomisk",
    "marknadsekonomiskares": "marknadsekonomisk",
    "marknadsekonomiskas": "marknadsekonomisk",
    "marknadsekonomiskast": "marknadsekonomisk",
    "marknadsekonomiskaste": "marknadsekonomisk",
    "marknadsekonomiskastes": "marknadsekonomisk",
    "marknadsekonomiskasts": "marknadsekonomisk",
    "marknadsekonomiske": "marknadsekonomisk",
    "marknadsekonomiskes": "marknadsekonomisk",
    "marknadsekonomisks": "marknadsekonomisk",
    "marknadsekonomiskt": "marknadsekonomisk",
    "marknadsekonomiskts": "marknadsekonomisk",
    "marknadsför": "marknadsföra",
    "marknadsförande": "marknadsföra",
    "marknadsföranden": "marknadsförande",
    "marknadsförandena": "marknadsförande",
    "marknadsförandenas": "marknadsförande",
    "marknadsförandens": "marknadsförande",
    "marknadsförandes": "marknadsförande",
    "marknadsförandet": "marknadsförande",
    "marknadsförandets": "marknadsförande",
    "marknadsföras": "marknadsföra",
    "marknadsförd": "marknadsföra",
    "marknadsförda": "marknadsföra",
    "marknadsfördas": "marknadsföra",
    "marknadsförde": "marknadsföra",
    "marknadsfördes": "marknadsföra",
    "marknadsförds": "marknadsföra",
    "marknadsföres": "marknadsföra",
    "marknadsföringar": "marknadsföring",
    "marknadsföringarna": "marknadsföring",
    "marknadsföringarnas": "marknadsföring",
    "marknadsföringars": "marknadsföring",
    "marknadsföringen": "marknadsföring",
    "marknadsföringens": "marknadsföring",
    "marknadsförings": "marknadsföring",
    "marknadsföringskuppen": "marknadsföringskupp",
    "marknadsföringskuppens": "marknadsföringskupp",
    "marknadsföringskupper": "marknadsföringskupp",
    "marknadsföringskupperna": "marknadsföringskupp",
    "marknadsföringskuppernas": "marknadsföringskupp",
    "marknadsföringskuppers": "marknadsföringskupp",
    "marknadsföringskupps": "marknadsföringskupp",
    "marknadsföringsmässiga": "marknadsföringsmässig",
    "marknadsföringsmässigare": "marknadsföringsmässig",
    "marknadsföringsmässigares": "marknadsföringsmässig",
    "marknadsföringsmässigas": "marknadsföringsmässig",
    "marknadsföringsmässigast": "marknadsföringsmässig",
    "marknadsföringsmässigaste": "marknadsföringsmässig",
    "marknadsföringsmässigastes": "marknadsföringsmässig",
    "marknadsföringsmässigasts": "marknadsföringsmässig",
    "marknadsföringsmässige": "marknadsföringsmässig",
    "marknadsföringsmässiges": "marknadsföringsmässig",
    "marknadsföringsmässigs": "marknadsföringsmässig",
    "marknadsföringsmässigt": "marknadsföringsmässig",
    "marknadsföringsmässigts": "marknadsföringsmässig",
    "marknadsförs": "marknadsföra",
    "marknadsfört": "marknadsföra",
    "marknadsförts": "marknadsföra",
    "marknadsgyckels": "marknadsgyckel",
    "marknadsgycklar": "marknadsgycklare",
    "marknadsgycklaren": "marknadsgycklare",
    "marknadsgycklarens": "marknadsgycklare",
    "marknadsgycklares": "marknadsgycklare",
    "marknadsgycklarna": "marknadsgycklare",
    "marknadsgycklarnas": "marknadsgycklare",
    "marknadsgycklet": "marknadsgyckel",
    "marknadsgycklets": "marknadsgyckel",
    "marknadshyr": "marknadshyra",
    "marknadshyran": "marknadshyra",
    "marknadshyrans": "marknadshyra",
    "marknadshyras": "marknadshyra",
    "marknadshyre": "marknadshyra",
    "marknadshyror": "marknadshyra",
    "marknadshyrorna": "marknadshyra",
    "marknadshyrornas": "marknadshyra",
    "marknadshyrors": "marknadshyra",
    "marknadshyrs": "marknadshyra",
    "marknadskrafterna": "marknadskrafter",
    "marknadskrafternas": "marknadskrafter",
    "marknadskrafters": "marknadskrafter",
    "marknadskrafts": "marknadskrafter",
    "marknadslägen": "marknadsläge",
    "marknadslägena": "marknadsläge",
    "marknadslägenas": "marknadsläge",
    "marknadslägens": "marknadsläge",
    "marknadsläges": "marknadsläge",
    "marknadsläget": "marknadsläge",
    "marknadslägets": "marknadsläge",
    "marknadsmässiga": "marknadsmässig",
    "marknadsmässigare": "marknadsmässig",
    "marknadsmässigares": "marknadsmässig",
    "marknadsmässigas": "marknadsmässig",
    "marknadsmässigast": "marknadsmässig",
    "marknadsmässigaste": "marknadsmässig",
    "marknadsmässigastes": "marknadsmässig",
    "marknadsmässigasts": "marknadsmässig",
    "marknadsmässige": "marknadsmässig",
    "marknadsmässiges": "marknadsmässig",
    "marknadsmässigheten": "marknadsmässighet",
    "marknadsmässighetens": "marknadsmässighet",
    "marknadsmässigheter": "marknadsmässighet",
    "marknadsmässigheterna": "marknadsmässighet",
    "marknadsmässigheternas": "marknadsmässighet",
    "marknadsmässigheters": "marknadsmässighet",
    "marknadsmässighets": "marknadsmässighet",
    "marknadsmässigs": "marknadsmässig",
    "marknadsmässigt": "marknadsmässig",
    "marknadsmässigts": "marknadsmässig",
    "marknadsplatsen": "marknadsplats",
    "marknadsplatsens": "marknadsplats",
    "marknadsplatser": "marknadsplats",
    "marknadsplatserna": "marknadsplats",
    "marknadsplatsernas": "marknadsplats",
    "marknadsplatsers": "marknadsplats",
    "marknadsprisen": "marknadspris",
    "marknadsprisens": "marknadspris",
    "marknadspriser": "marknadspris",
    "marknadspriserna": "marknadspris",
    "marknadsprisernas": "marknadspris",
    "marknadsprisers": "marknadspris",
    "marknadspriset": "marknadspris",
    "marknadsprisets": "marknadspris",
    "marknadsreformen": "marknadsreform",
    "marknadsreformens": "marknadsreform",
    "marknadsreformer": "marknadsreform",
    "marknadsreformerna": "marknadsreform",
    "marknadsreformernas": "marknadsreform",
    "marknadsreformers": "marknadsreform",
    "marknadsreforms": "marknadsreform",
    "marknadsräntan": "marknadsränta",
    "marknadsräntans": "marknadsränta",
    "marknadsräntas": "marknadsränta",
    "marknadsränte": "marknadsränta",
    "marknadsräntor": "marknadsränta",
    "marknadsräntorna": "marknadsränta",
    "marknadsräntornas": "marknadsränta",
    "marknadsräntors": "marknadsränta",
    "marknadsstånden": "marknadsstånd",
    "marknadsståndens": "marknadsstånd",
    "marknadsståndet": "marknadsstånd",
    "marknadsståndets": "marknadsstånd",
    "marknadsstånds": "marknadsstånd",
    "marknadsundersökningar": "marknadsundersökning",
    "marknadsundersökningarna": "marknadsundersökning",
    "marknadsundersökningarnas": "marknadsundersökning",
    "marknadsundersökningars": "marknadsundersökning",
    "marknadsundersökningen": "marknadsundersökning",
    "marknadsundersökningens": "marknadsundersökning",
    "marknadsundersöknings": "marknadsundersökning",
    "marknadsvärden": "marknadsvärde",
    "marknadsvärdena": "marknadsvärde",
    "marknadsvärdenas": "marknadsvärde",
    "marknadsvärdens": "marknadsvärde",
    "marknadsvärderad": "marknadsvärdera",
    "marknadsvärderade": "marknadsvärdera",
    "marknadsvärderades": "marknadsvärdera",
    "marknadsvärderads": "marknadsvärdera",
    "marknadsvärderande": "marknadsvärdera",
    "marknadsvärderanden": "marknadsvärderande",
    "marknadsvärderandena": "marknadsvärderande",
    "marknadsvärderandenas": "marknadsvärderande",
    "marknadsvärderandens": "marknadsvärderande",
    "marknadsvärderandes": "marknadsvärderande",
    "marknadsvärderandet": "marknadsvärderande",
    "marknadsvärderandets": "marknadsvärderande",
    "marknadsvärderar": "marknadsvärdera",
    "marknadsvärderas": "marknadsvärdera",
    "marknadsvärderat": "marknadsvärdera",
    "marknadsvärderats": "marknadsvärdera",
    "marknadsvärderbara": "marknadsvärderbar",
    "marknadsvärderbarare": "marknadsvärderbar",
    "marknadsvärderbarares": "marknadsvärderbar",
    "marknadsvärderbaras": "marknadsvärderbar",
    "marknadsvärderbarast": "marknadsvärderbar",
    "marknadsvärderbaraste": "marknadsvärderbar",
    "marknadsvärderbarastes": "marknadsvärderbar",
    "marknadsvärderbarasts": "marknadsvärderbar",
    "marknadsvärderbare": "marknadsvärderbar",
    "marknadsvärderbares": "marknadsvärderbar",
    "marknadsvärderbarheten": "marknadsvärderbarhet",
    "marknadsvärderbarhetens": "marknadsvärderbarhet",
    "marknadsvärderbarhets": "marknadsvärderbarhet",
    "marknadsvärderbars": "marknadsvärderbar",
    "marknadsvärderbart": "marknadsvärderbar",
    "marknadsvärderbarts": "marknadsvärderbar",
    "marknadsvärderingar": "marknadsvärdering",
    "marknadsvärderingarna": "marknadsvärdering",
    "marknadsvärderingarnas": "marknadsvärdering",
    "marknadsvärderingars": "marknadsvärdering",
    "marknadsvärderingen": "marknadsvärdering",
    "marknadsvärderingens": "marknadsvärdering",
    "marknadsvärderings": "marknadsvärdering",
    "marknadsvärdes": "marknadsvärde",
    "marknadsvärdet": "marknadsvärde",
    "marknadsvärdets": "marknadsvärde",
    "marknivåer": "marknivå",
    "marknivåerna": "marknivå",
    "marknivåernas": "marknivå",
    "marknivåers": "marknivå",
    "marknivån": "marknivå",
    "marknivåns": "marknivå",
    "marknivås": "marknivå",
    "markomannern": "markomanner",
    "markomannerna": "markomanner",
    "markomannernas": "markomanner",
    "markomannerns": "markomanner",
    "markomanners": "markomanner",
    "markområden": "markområde",
    "markområdena": "markområde",
    "markområdenas": "markområde",
    "markområdens": "markområde",
    "markområdes": "markområde",
    "markområdet": "markområde",
    "markområdets": "markområde",
    "markorganismen": "markorganism",
    "markorganismens": "markorganism",
    "markorganismer": "markorganism",
    "markorganismerna": "markorganism",
    "markorganismernas": "markorganism",
    "markorganismers": "markorganism",
    "markorganisms": "markorganism",
    "marks": "mark",
    "markservicen": "markservice",
    "markservicens": "markservice",
    "markservices": "markservice",
    "marktjänsten": "marktjänst",
    "marktjänstens": "marktjänst",
    "marktjänster": "marktjänst",
    "marktjänsterna": "marktjänst",
    "marktjänsternas": "marktjänst",
    "marktjänsters": "marktjänst",
    "marktjänsts": "marktjänst",
    "marktäckar": "marktäckare",
    "marktäckaren": "marktäckare",
    "marktäckarens": "marktäckare",
    "marktäckares": "marktäckare",
    "marktäckarna": "marktäckare",
    "marktäckarnas": "marktäckare",
    "markvägar": "markväg",
    "markvägarna": "markväg",
    "markvägarnas": "markväg",
    "markvägars": "markväg",
    "markvägen": "markväg",
    "markvägens": "markväg",
    "markvägs": "markväg",
    "markytan": "markyta",
    "markytans": "markyta",
    "markytas": "markyta",
    "markyte": "markyta",
    "markytor": "markyta",
    "markytorna": "markyta",
    "markytornas": "markyta",
    "markytors": "markyta",
    "markägar": "markägare",
    "markägaren": "markägare",
    "markägarens": "markägare",
    "markägares": "markägare",
    "markägarna": "markägare",
    "markägarnas": "markägare",
    "markören": "markör",
    "markörens": "markör",
    "markörer": "markör",
    "markörerna": "markör",
    "markörernas": "markör",
    "markörers": "markör",
    "markörs": "markör",
    "marlek": "marleka",
    "marlekan": "marleka",
    "marlekans": "marleka",
    "marlekas": "marleka",
    "marleke": "marleka",
    "marlekor": "marleka",
    "marlekorna": "marleka",
    "marlekornas": "marleka",
    "marlekors": "marleka",
    "marleks": "marleka",
    "marmeladen": "marmelad",
    "marmeladens": "marmelad",
    "marmelader": "marmelad",
    "marmeladerna": "marmelad",
    "marmeladernas": "marmelad",
    "marmeladers": "marmelad",
    "marmelads": "marmelad",
    "marmorerad": "marmorera",
    "marmorerade": "marmorera",
    "marmorerades": "marmorera",
    "marmorerads": "marmorera",
    "marmorerande": "marmorera",
    "marmoreranden": "marmorerande",
    "marmorerandena": "marmorerande",
    "marmorerandenas": "marmorerande",
    "marmorerandens": "marmorerande",
    "marmorerandes": "marmorerande",
    "marmorerandet": "marmorerande",
    "marmorerandets": "marmorerande",
    "marmorerar": "marmorera",
    "marmoreras": "marmorera",
    "marmorerat": "marmorera",
    "marmorerats": "marmorera",
    "marmorerbara": "marmorerbar",
    "marmorerbarare": "marmorerbar",
    "marmorerbarares": "marmorerbar",
    "marmorerbaras": "marmorerbar",
    "marmorerbarast": "marmorerbar",
    "marmorerbaraste": "marmorerbar",
    "marmorerbarastes": "marmorerbar",
    "marmorerbarasts": "marmorerbar",
    "marmorerbare": "marmorerbar",
    "marmorerbares": "marmorerbar",
    "marmorerbarheten": "marmorerbarhet",
    "marmorerbarhetens": "marmorerbarhet",
    "marmorerbarhets": "marmorerbarhet",
    "marmorerbars": "marmorerbar",
    "marmorerbart": "marmorerbar",
    "marmorerbarts": "marmorerbar",
    "marmoreringar": "marmorering",
    "marmoreringarna": "marmorering",
    "marmoreringarnas": "marmorering",
    "marmoreringars": "marmorering",
    "marmoreringen": "marmorering",
    "marmoreringens": "marmorering",
    "marmorerings": "marmorering",
    "marmorhällar": "marmorhäll",
    "marmorhällarna": "marmorhäll",
    "marmorhällarnas": "marmorhäll",
    "marmorhällars": "marmorhäll",
    "marmorhällen": "marmorhäll",
    "marmorhällens": "marmorhäll",
    "marmorhälls": "marmorhäll",
    "marmorn": "marmor",
    "marmorns": "marmor",
    "marmors": "marmor",
    "marmortrapp": "marmortrappa",
    "marmortrappan": "marmortrappa",
    "marmortrappans": "marmortrappa",
    "marmortrappas": "marmortrappa",
    "marmortrappe": "marmortrappa",
    "marmortrappor": "marmortrappa",
    "marmortrapporna": "marmortrappa",
    "marmortrappornas": "marmortrappa",
    "marmortrappors": "marmortrappa",
    "marmortrapps": "marmortrappa",
    "marockanen": "marockan",
    "marockanens": "marockan",
    "marockaner": "marockan",
    "marockanerna": "marockan",
    "marockanernas": "marockan",
    "marockaners": "marockan",
    "marockans": "marockan",
    "marockanska": "marockansk",
    "marockanskan": "marockanska",
    "marockanskans": "marockanska",
    "marockanskare": "marockansk",
    "marockanskares": "marockansk",
    "marockanskas": "marockanska",
    "marockanskast": "marockansk",
    "marockanskaste": "marockansk",
    "marockanskastes": "marockansk",
    "marockanskasts": "marockansk",
    "marockanske": "marockanska",
    "marockanskes": "marockansk",
    "marockanskor": "marockanska",
    "marockanskorna": "marockanska",
    "marockanskornas": "marockanska",
    "marockanskors": "marockanska",
    "marockansks": "marockansk",
    "marockanskt": "marockansk",
    "marockanskts": "marockansk",
    "maroderade": "marodera",
    "maroderades": "marodera",
    "maroderande": "marodera",
    "maroderanden": "maroderande",
    "maroderandena": "maroderande",
    "maroderandenas": "maroderande",
    "maroderandens": "maroderande",
    "maroderandes": "maroderande",
    "maroderandet": "maroderande",
    "maroderandets": "maroderande",
    "maroderar": "marodera",
    "maroderas": "marodera",
    "maroderat": "marodera",
    "maroderats": "marodera",
    "maroderingar": "marodering",
    "maroderingarna": "marodering",
    "maroderingarnas": "marodering",
    "maroderingars": "marodering",
    "maroderingen": "marodering",
    "maroderingens": "marodering",
    "maroderings": "marodering",
    "marodören": "marodör",
    "marodörens": "marodör",
    "marodörer": "marodör",
    "marodörerna": "marodör",
    "marodörernas": "marodör",
    "marodörers": "marodör",
    "marodörs": "marodör",
    "marokängen": "marokäng",
    "marokängens": "marokäng",
    "marokängs": "marokäng",
    "maror": "mara",
    "marorna": "mara",
    "marornas": "mara",
    "marors": "mara",
    "mars": "mara",
    "marsalan": "marsala",
    "marsalans": "marsala",
    "marsalas": "marsala",
    "marschallen": "marschall",
    "marschallens": "marschall",
    "marschaller": "marschall",
    "marschallerna": "marschall",
    "marschallernas": "marschall",
    "marschallers": "marschall",
    "marschalls": "marschall",
    "marschen": "marsch",
    "marschens": "marsch",
    "marscher": "marsch",
    "marscherade": "marschera",
    "marscherades": "marschera",
    "marscherande": "marschera",
    "marscheranden": "marscherande",
    "marscherandena": "marscherande",
    "marscherandenas": "marscherande",
    "marscherandens": "marscherande",
    "marscherandes": "marscherande",
    "marscherandet": "marscherande",
    "marscherandets": "marscherande",
    "marscherar": "marschera",
    "marscheras": "marschera",
    "marscherat": "marschera",
    "marscherats": "marschera",
    "marscherbara": "marscherbar",
    "marscherbarare": "marscherbar",
    "marscherbarares": "marscherbar",
    "marscherbaras": "marscherbar",
    "marscherbarast": "marscherbar",
    "marscherbaraste": "marscherbar",
    "marscherbarastes": "marscherbar",
    "marscherbarasts": "marscherbar",
    "marscherbare": "marscherbar",
    "marscherbares": "marscherbar",
    "marscherbarheten": "marscherbarhet",
    "marscherbarhetens": "marscherbarhet",
    "marscherbarhets": "marscherbarhet",
    "marscherbars": "marscherbar",
    "marscherbart": "marscherbar",
    "marscherbarts": "marscherbar",
    "marscheringar": "marschering",
    "marscheringarna": "marschering",
    "marscheringarnas": "marschering",
    "marscheringars": "marschering",
    "marscheringen": "marschering",
    "marscheringens": "marschering",
    "marscherings": "marschering",
    "marscherna": "marsch",
    "marschernas": "marsch",
    "marschers": "marsch",
    "marschfarten": "marschfart",
    "marschfartens": "marschfart",
    "marschfarter": "marschfart",
    "marschfarterna": "marschfart",
    "marschfarternas": "marschfart",
    "marschfarters": "marschfart",
    "marschfarts": "marschfart",
    "marschlägen": "marschläge",
    "marschlägena": "marschläge",
    "marschlägenas": "marschläge",
    "marschlägens": "marschläge",
    "marschläges": "marschläge",
    "marschläget": "marschläge",
    "marschlägets": "marschläge",
    "marschmusiken": "marschmusik",
    "marschmusikens": "marschmusik",
    "marschmusiks": "marschmusik",
    "marschordern": "marschorder",
    "marschorderna": "marschorder",
    "marschordernas": "marschorder",
    "marschorderns": "marschorder",
    "marschorders": "marschorder",
    "marschordrar": "marschorder",
    "marschordrarna": "marschorder",
    "marschordrarnas": "marschorder",
    "marschordrars": "marschorder",
    "marschriktningar": "marschriktning",
    "marschriktningarna": "marschriktning",
    "marschriktningarnas": "marschriktning",
    "marschriktningars": "marschriktning",
    "marschriktningen": "marschriktning",
    "marschriktningens": "marschriktning",
    "marschriktnings": "marschriktning",
    "marschs": "marsch",
    "marschtakten": "marschtakt",
    "marschtaktens": "marschtakt",
    "marschtakts": "marschtakt",
    "marseljäsen": "marseljäs",
    "marseljäsens": "marseljäs",
    "marshmallowen": "marshmallow",
    "marshmallowens": "marshmallow",
    "marshmallower": "marshmallow",
    "marshmallowerna": "marshmallow",
    "marshmallowernas": "marshmallow",
    "marshmallowers": "marshmallow",
    "marshmallows": "marshmallow",
    "marsianen": "marsian",
    "marsianens": "marsian",
    "marsianer": "marsian",
    "marsianerna": "marsian",
    "marsianernas": "marsian",
    "marsianers": "marsian",
    "marsians": "marsian",
    "marsipanen": "marsipan",
    "marsipanens": "marsipan",
    "marsipans": "marsipan",
    "marsipantårt": "marsipantårta",
    "marsipantårtan": "marsipantårta",
    "marsipantårtans": "marsipantårta",
    "marsipantårtas": "marsipantårta",
    "marsipantårte": "marsipantårta",
    "marsipantårtor": "marsipantårta",
    "marsipantårtorna": "marsipantårta",
    "marsipantårtornas": "marsipantårta",
    "marsipantårtors": "marsipantårta",
    "marsipantårts": "marsipantårta",
    "marskalkar": "marskalk",
    "marskalkarna": "marskalk",
    "marskalkarnas": "marskalk",
    "marskalkars": "marskalk",
    "marskalken": "marskalk",
    "marskalkens": "marskalk",
    "marskalks": "marskalk",
    "marskalkstavar": "marskalkstav",
    "marskalkstavarna": "marskalkstav",
    "marskalkstavarnas": "marskalkstav",
    "marskalkstavars": "marskalkstav",
    "marskalkstaven": "marskalkstav",
    "marskalkstavens": "marskalkstav",
    "marskalkstavs": "marskalkstav",
    "marskatten": "marskatt",
    "marskattens": "marskatt",
    "marskatter": "marskatt",
    "marskatterna": "marskatt",
    "marskatternas": "marskatt",
    "marskatters": "marskatt",
    "marskatts": "marskatt",
    "marsken": "marsk",
    "marskens": "marsk",
    "marsker": "marsk",
    "marskerna": "marsk",
    "marskernas": "marsk",
    "marskers": "marsk",
    "marsklandet": "marskland",
    "marsklandets": "marskland",
    "marsklands": "marskland",
    "marsks": "marsk",
    "marsvinen": "marsvin",
    "marsvinens": "marsvin",
    "marsvinet": "marsvin",
    "marsvinets": "marsvin",
    "marsvins": "marsvin",
    "mart": "marter",
    "martallar": "martall",
    "martallarna": "martall",
    "martallarnas": "martall",
    "martallars": "martall",
    "martallen": "martall",
    "martallens": "martall",
    "martalls": "martall",
    "martasbekymmerna": "martasbekymmer",
    "martasbekymmernas": "martasbekymmer",
    "martasbekymmers": "martasbekymmer",
    "martasbekymren": "martasbekymmer",
    "martasbekymrens": "martasbekymmer",
    "martasbekymret": "martasbekymmer",
    "martasbekymrets": "martasbekymmer",
    "marterad": "martera",
    "marterade": "martera",
    "marterades": "martera",
    "marterads": "martera",
    "marterande": "martera",
    "marteranden": "marterande",
    "marterandena": "marterande",
    "marterandenas": "marterande",
    "marterandens": "marterande",
    "marterandes": "marterande",
    "marterandet": "marterande",
    "marterandets": "marterande",
    "marterar": "martera",
    "marteras": "martera",
    "marterat": "martera",
    "marterats": "martera",
    "marterbara": "marterbar",
    "marterbarare": "marterbar",
    "marterbarares": "marterbar",
    "marterbaras": "marterbar",
    "marterbarast": "marterbar",
    "marterbaraste": "marterbar",
    "marterbarastes": "marterbar",
    "marterbarasts": "marterbar",
    "marterbare": "marterbar",
    "marterbares": "marterbar",
    "marterbarheten": "marterbarhet",
    "marterbarhetens": "marterbarhet",
    "marterbarhets": "marterbarhet",
    "marterbars": "marterbar",
    "marterbart": "marterbar",
    "marterbarts": "marterbar",
    "marteringar": "martering",
    "marteringarna": "martering",
    "marteringarnas": "martering",
    "marteringars": "martering",
    "marteringen": "martering",
    "marteringens": "martering",
    "marterings": "martering",
    "marterna": "marter",
    "marternas": "marter",
    "marters": "marter",
    "martialiska": "martialisk",
    "martialiskare": "martialisk",
    "martialiskares": "martialisk",
    "martialiskas": "martialisk",
    "martialiskast": "martialisk",
    "martialiskaste": "martialisk",
    "martialiskastes": "martialisk",
    "martialiskasts": "martialisk",
    "martialiske": "martialisk",
    "martialiskes": "martialisk",
    "martialisks": "martialisk",
    "martialiskt": "martialisk",
    "martialiskts": "martialisk",
    "martinin": "martini",
    "martinina": "martini",
    "martininas": "martini",
    "martinins": "martini",
    "martinis": "martini",
    "martinisarna": "martini",
    "martinisarnas": "martini",
    "martinisen": "martini",
    "martinisens": "martini",
    "martinprocessens": "martinprocessen",
    "martornen": "martorn",
    "martornens": "martorn",
    "martornet": "martorn",
    "martornets": "martorn",
    "martorns": "martorn",
    "marts": "marter",
    "martyren": "martyr",
    "martyrens": "martyr",
    "martyrer": "martyr",
    "martyrerna": "martyr",
    "martyrernas": "martyr",
    "martyrers": "martyr",
    "martyrglori": "martyrgloria",
    "martyrglorian": "martyrgloria",
    "martyrglorians": "martyrgloria",
    "martyrglorias": "martyrgloria",
    "martyrglorie": "martyrgloria",
    "martyrglorior": "martyrgloria",
    "martyrgloriorna": "martyrgloria",
    "martyrgloriornas": "martyrgloria",
    "martyrgloriors": "martyrgloria",
    "martyrgloris": "martyrgloria",
    "martyrie": "martyrium",
    "martyrier": "martyrium",
    "martyrierna": "martyrium",
    "martyriernas": "martyrium",
    "martyriers": "martyrium",
    "martyriet": "martyrium",
    "martyriets": "martyrium",
    "martyriums": "martyrium",
    "martyrs": "martyr",
    "marulkar": "marulk",
    "marulkarna": "marulk",
    "marulkarnas": "marulk",
    "marulkars": "marulk",
    "marulken": "marulk",
    "marulkens": "marulk",
    "marulks": "marulk",
    "marvattens": "marvatten",
    "marvattnet": "marvatten",
    "marvattnets": "marvatten",
    "marviolen": "marviol",
    "marviolens": "marviol",
    "marvioler": "marviol",
    "marviolerna": "marviol",
    "marviolernas": "marviol",
    "marviolers": "marviol",
    "marviols": "marviol",
    "marxismen": "marxism",
    "marxismens": "marxism",
    "marxismer": "marxism",
    "marxismerna": "marxism",
    "marxismernas": "marxism",
    "marxismers": "marxism",
    "marxisms": "marxism",
    "marxisten": "marxist",
    "marxistens": "marxist",
    "marxister": "marxist",
    "marxisterna": "marxist",
    "marxisternas": "marxist",
    "marxisters": "marxist",
    "marxistiska": "marxistisk",
    "marxistiskare": "marxistisk",
    "marxistiskares": "marxistisk",
    "marxistiskas": "marxistisk",
    "marxistiskast": "marxistisk",
    "marxistiskaste": "marxistisk",
    "marxistiskastes": "marxistisk",
    "marxistiskasts": "marxistisk",
    "marxistiske": "marxistisk",
    "marxistiskes": "marxistisk",
    "marxistisks": "marxistisk",
    "marxistiskt": "marxistisk",
    "marxistiskts": "marxistisk",
    "marxists": "marxist",
    "marängen": "maräng",
    "marängens": "maräng",
    "maränger": "maräng",
    "marängerna": "maräng",
    "marängernas": "maräng",
    "marängers": "maräng",
    "marängs": "maräng",
    "marängsvissen": "marängsviss",
    "marängsvissens": "marängsviss",
    "marängsvisser": "marängsviss",
    "marängsvisserna": "marängsviss",
    "marängsvissernas": "marängsviss",
    "marängsvissers": "marängsviss",
    "mas": "masa",
    "masad": "masa",
    "masade": "masa",
    "masades": "masa",
    "masads": "masa",
    "masande": "masa",
    "masanden": "masande",
    "masandena": "masande",
    "masandenas": "masande",
    "masandens": "masande",
    "masandes": "masande",
    "masandet": "masande",
    "masandets": "masande",
    "masar": "masa",
    "masarna": "mas",
    "masarnas": "mas",
    "masars": "mas",
    "masas": "masa",
    "masat": "masa",
    "masats": "masa",
    "mascaran": "mascara",
    "mascarans": "mascara",
    "mascaras": "mascara",
    "masen": "mas",
    "masens": "mas",
    "masern": "maser",
    "maserns": "maser",
    "masers": "maser",
    "masiga": "masig",
    "masigare": "masig",
    "masigares": "masig",
    "masigas": "masig",
    "masigast": "masig",
    "masigaste": "masig",
    "masigastes": "masig",
    "masigasts": "masig",
    "masige": "masig",
    "masiges": "masig",
    "masigs": "masig",
    "masigt": "masig",
    "masigts": "masig",
    "mask": "maska",
    "maskad": "maska",
    "maskade": "maska",
    "maskades": "maska",
    "maskads": "maska",
    "maskan": "maska",
    "maskande": "maska",
    "maskanden": "maskande",
    "maskandena": "maskande",
    "maskandenas": "maskande",
    "maskandens": "maskande",
    "maskandes": "maskande",
    "maskandet": "maskande",
    "maskandets": "maskande",
    "maskans": "maska",
    "maskar": "maska",
    "maskarna": "mask",
    "maskarnas": "mask",
    "maskars": "mask",
    "maskas": "maska",
    "maskat": "maska",
    "maskats": "maska",
    "maske": "maska",
    "masken": "mask",
    "maskens": "mask",
    "masker": "mask",
    "maskerad": "maskera",
    "maskeraddräkten": "maskeraddräkt",
    "maskeraddräktens": "maskeraddräkt",
    "maskeraddräkter": "maskeraddräkt",
    "maskeraddräkterna": "maskeraddräkt",
    "maskeraddräkternas": "maskeraddräkt",
    "maskeraddräkters": "maskeraddräkt",
    "maskeraddräkts": "maskeraddräkt",
    "maskerade": "maskera",
    "maskeraden": "maskerad",
    "maskeradens": "maskerad",
    "maskerader": "maskerad",
    "maskeraderna": "maskerad",
    "maskeradernas": "maskerad",
    "maskeraders": "maskerad",
    "maskerades": "maskera",
    "maskerads": "maskerad",
    "maskerande": "maskera",
    "maskeranden": "maskerande",
    "maskerandena": "maskerande",
    "maskerandenas": "maskerande",
    "maskerandens": "maskerande",
    "maskerandes": "maskerande",
    "maskerandet": "maskerande",
    "maskerandets": "maskerande",
    "maskerar": "maskera",
    "maskeras": "maskera",
    "maskerat": "maskera",
    "maskerats": "maskera",
    "maskerbara": "maskerbar",
    "maskerbarare": "maskerbar",
    "maskerbarares": "maskerbar",
    "maskerbaras": "maskerbar",
    "maskerbarast": "maskerbar",
    "maskerbaraste": "maskerbar",
    "maskerbarastes": "maskerbar",
    "maskerbarasts": "maskerbar",
    "maskerbare": "maskerbar",
    "maskerbares": "maskerbar",
    "maskerbarheten": "maskerbarhet",
    "maskerbarhetens": "maskerbarhet",
    "maskerbarhets": "maskerbarhet",
    "maskerbars": "maskerbar",
    "maskerbart": "maskerbar",
    "maskerbarts": "maskerbar",
    "maskeringar": "maskering",
    "maskeringarna": "maskering",
    "maskeringarnas": "maskering",
    "maskeringars": "maskering",
    "maskeringen": "maskering",
    "maskeringens": "maskering",
    "maskerings": "maskering",
    "maskeringstejpen": "maskeringstejp",
    "maskeringstejpens": "maskeringstejp",
    "maskeringstejps": "maskeringstejp",
    "maskerna": "mask",
    "maskernas": "mask",
    "maskers": "mask",
    "maskformiga": "maskformig",
    "maskformigare": "maskformig",
    "maskformigares": "maskformig",
    "maskformigas": "maskformig",
    "maskformigast": "maskformig",
    "maskformigaste": "maskformig",
    "maskformigastes": "maskformig",
    "maskformigasts": "maskformig",
    "maskformige": "maskformig",
    "maskformiges": "maskformig",
    "maskformigs": "maskformig",
    "maskformigt": "maskformig",
    "maskformigts": "maskformig",
    "maskfratet": "maskfrat",
    "maskfratets": "maskfrat",
    "maskfrats": "maskfrat",
    "maskhålen": "maskhål",
    "maskhålens": "maskhål",
    "maskhålet": "maskhål",
    "maskhålets": "maskhål",
    "maskhåls": "maskhål",
    "maskindelar": "maskindel",
    "maskindelarna": "maskindel",
    "maskindelarnas": "maskindel",
    "maskindelars": "maskindel",
    "maskindelen": "maskindel",
    "maskindelens": "maskindel",
    "maskindels": "maskindel",
    "maskinelementen": "maskinelement",
    "maskinelementens": "maskinelement",
    "maskinelementet": "maskinelement",
    "maskinelementets": "maskinelement",
    "maskinelements": "maskinelement",
    "maskinella": "maskinell",
    "maskinellare": "maskinell",
    "maskinellares": "maskinell",
    "maskinellas": "maskinell",
    "maskinellast": "maskinell",
    "maskinellaste": "maskinell",
    "maskinellastes": "maskinell",
    "maskinellasts": "maskinell",
    "maskinelle": "maskinell",
    "maskinelles": "maskinell",
    "maskinells": "maskinell",
    "maskinellt": "maskinell",
    "maskinellts": "maskinell",
    "maskinen": "maskin",
    "maskinens": "maskin",
    "maskiner": "maskin",
    "maskinerier": "maskineri",
    "maskinerierna": "maskineri",
    "maskineriernas": "maskineri",
    "maskineriers": "maskineri",
    "maskineriet": "maskineri",
    "maskineriets": "maskineri",
    "maskineris": "maskineri",
    "maskinerit": "maskineri",
    "maskinerits": "maskineri",
    "maskinerna": "maskin",
    "maskinernas": "maskin",
    "maskiners": "maskin",
    "maskingevären": "maskingevär",
    "maskingevärens": "maskingevär",
    "maskingeväret": "maskingevär",
    "maskingevärets": "maskingevär",
    "maskingevärs": "maskingevär",
    "maskinhallar": "maskinhall",
    "maskinhallarna": "maskinhall",
    "maskinhallarnas": "maskinhall",
    "maskinhallars": "maskinhall",
    "maskinhallen": "maskinhall",
    "maskinhallens": "maskinhall",
    "maskinhalls": "maskinhall",
    "maskinhaverier": "maskinhaveri",
    "maskinhaverierna": "maskinhaveri",
    "maskinhaveriernas": "maskinhaveri",
    "maskinhaveriers": "maskinhaveri",
    "maskinhaveriet": "maskinhaveri",
    "maskinhaveriets": "maskinhaveri",
    "maskinhaveris": "maskinhaveri",
    "maskinhaverit": "maskinhaveri",
    "maskinhaverits": "maskinhaveri",
    "maskinisten": "maskinist",
    "maskinistens": "maskinist",
    "maskinister": "maskinist",
    "maskinisterna": "maskinist",
    "maskinisternas": "maskinist",
    "maskinisters": "maskinist",
    "maskinists": "maskinist",
    "maskinläsbara": "maskinläsbar",
    "maskinläsbarare": "maskinläsbar",
    "maskinläsbarares": "maskinläsbar",
    "maskinläsbaras": "maskinläsbar",
    "maskinläsbarast": "maskinläsbar",
    "maskinläsbaraste": "maskinläsbar",
    "maskinläsbarastes": "maskinläsbar",
    "maskinläsbarasts": "maskinläsbar",
    "maskinläsbare": "maskinläsbar",
    "maskinläsbares": "maskinläsbar",
    "maskinläsbarheten": "maskinläsbarhet",
    "maskinläsbarhetens": "maskinläsbarhet",
    "maskinläsbarhets": "maskinläsbarhet",
    "maskinläsbars": "maskinläsbar",
    "maskinläsbart": "maskinläsbar",
    "maskinläsbarts": "maskinläsbar",
    "maskinmässiga": "maskinmässig",
    "maskinmässigare": "maskinmässig",
    "maskinmässigares": "maskinmässig",
    "maskinmässigas": "maskinmässig",
    "maskinmässigast": "maskinmässig",
    "maskinmässigaste": "maskinmässig",
    "maskinmässigastes": "maskinmässig",
    "maskinmässigasts": "maskinmässig",
    "maskinmässige": "maskinmässig",
    "maskinmässiges": "maskinmässig",
    "maskinmässigheten": "maskinmässighet",
    "maskinmässighetens": "maskinmässighet",
    "maskinmässighets": "maskinmässighet",
    "maskinmässigs": "maskinmässig",
    "maskinmässigt": "maskinmässig",
    "maskinmässigts": "maskinmässig",
    "maskinparken": "maskinpark",
    "maskinparkens": "maskinpark",
    "maskinparker": "maskinpark",
    "maskinparkerna": "maskinpark",
    "maskinparkernas": "maskinpark",
    "maskinparkers": "maskinpark",
    "maskinparks": "maskinpark",
    "maskinpistolen": "maskinpistol",
    "maskinpistolens": "maskinpistol",
    "maskinpistoler": "maskinpistol",
    "maskinpistolerna": "maskinpistol",
    "maskinpistolernas": "maskinpistol",
    "maskinpistolers": "maskinpistol",
    "maskinpistols": "maskinpistol",
    "maskinpressar": "maskinpress",
    "maskinpressarna": "maskinpress",
    "maskinpressarnas": "maskinpress",
    "maskinpressars": "maskinpress",
    "maskinpressen": "maskinpress",
    "maskinpressens": "maskinpress",
    "maskinrummen": "maskinrum",
    "maskinrummens": "maskinrum",
    "maskinrummet": "maskinrum",
    "maskinrummets": "maskinrum",
    "maskinrums": "maskinrum",
    "maskins": "maskin",
    "maskinskrivens": "maskinskriven",
    "maskinskrivet": "maskinskriven",
    "maskinskrivets": "maskinskriven",
    "maskinskrivna": "maskinskriven",
    "maskinskrivnare": "maskinskriven",
    "maskinskrivnares": "maskinskriven",
    "maskinskrivnas": "maskinskriven",
    "maskinskrivnast": "maskinskriven",
    "maskinskrivnaste": "maskinskriven",
    "maskinskrivnastes": "maskinskriven",
    "maskinskrivnasts": "maskinskriven",
    "maskinskrivne": "maskinskriven",
    "maskinskrivnes": "maskinskriven",
    "maskinskrivningar": "maskinskrivning",
    "maskinskrivningarna": "maskinskrivning",
    "maskinskrivningarnas": "maskinskrivning",
    "maskinskrivningars": "maskinskrivning",
    "maskinskrivningen": "maskinskrivning",
    "maskinskrivningens": "maskinskrivning",
    "maskinskrivnings": "maskinskrivning",
    "maskinspråken": "maskinspråk",
    "maskinspråkens": "maskinspråk",
    "maskinspråket": "maskinspråk",
    "maskinspråkets": "maskinspråk",
    "maskinspråks": "maskinspråk",
    "maskintelegrafen": "maskintelegraf",
    "maskintelegrafens": "maskintelegraf",
    "maskintelegrafer": "maskintelegraf",
    "maskintelegraferna": "maskintelegraf",
    "maskintelegrafernas": "maskintelegraf",
    "maskintelegrafers": "maskintelegraf",
    "maskintelegrafs": "maskintelegraf",
    "maskintiden": "maskintid",
    "maskintidens": "maskintid",
    "maskintider": "maskintid",
    "maskintiderna": "maskintid",
    "maskintidernas": "maskintid",
    "maskintiders": "maskintid",
    "maskintids": "maskintid",
    "maskintvättar": "maskintvätt",
    "maskintvättarna": "maskintvätt",
    "maskintvättarnas": "maskintvätt",
    "maskintvättars": "maskintvätt",
    "maskintvätten": "maskintvätt",
    "maskintvättens": "maskintvätt",
    "maskintvätts": "maskintvätt",
    "maskinvar": "maskinvara",
    "maskinvaran": "maskinvara",
    "maskinvarans": "maskinvara",
    "maskinvaras": "maskinvara",
    "maskinvare": "maskinvara",
    "maskinvaror": "maskinvara",
    "maskinvarorna": "maskinvara",
    "maskinvarornas": "maskinvara",
    "maskinvarors": "maskinvara",
    "maskinvars": "maskinvara",
    "maskinverkstaden": "maskinverkstad",
    "maskinverkstadens": "maskinverkstad",
    "maskinverkstads": "maskinverkstad",
    "maskinverkstan": "maskinverkstad",
    "maskinverkstans": "maskinverkstad",
    "maskinverkstäder": "maskinverkstad",
    "maskinverkstäderna": "maskinverkstad",
    "maskinverkstädernas": "maskinverkstad",
    "maskinverkstäders": "maskinverkstad",
    "maskinöversättningar": "maskinöversättning",
    "maskinöversättningarna": "maskinöversättning",
    "maskinöversättningarnas": "maskinöversättning",
    "maskinöversättningars": "maskinöversättning",
    "maskinöversättningen": "maskinöversättning",
    "maskinöversättningens": "maskinöversättning",
    "maskinöversättnings": "maskinöversättning",
    "maskmedels": "maskmedel",
    "maskmedlen": "maskmedel",
    "maskmedlens": "maskmedel",
    "maskmedlet": "maskmedel",
    "maskmedlets": "maskmedel",
    "maskningar": "maskning",
    "maskningarna": "maskning",
    "maskningarnas": "maskning",
    "maskningars": "maskning",
    "maskningen": "maskning",
    "maskningens": "maskning",
    "masknings": "maskning",
    "maskopien": "maskopi",
    "maskopiens": "maskopi",
    "maskopier": "maskopi",
    "maskopierna": "maskopi",
    "maskopiernas": "maskopi",
    "maskopiers": "maskopi",
    "maskopin": "maskopi",
    "maskopins": "maskopi",
    "maskopis": "maskopi",
    "maskor": "maska",
    "maskorna": "maska",
    "maskornas": "maska",
    "maskors": "maska",
    "maskotar": "maskot",
    "maskotarna": "maskot",
    "maskotarnas": "maskot",
    "maskotars": "maskot",
    "maskoten": "maskot",
    "maskotens": "maskot",
    "maskoter": "maskot",
    "maskoterna": "maskot",
    "maskoternas": "maskot",
    "maskoters": "maskot",
    "maskots": "maskot",
    "maskrosbarnen": "maskrosbarn",
    "maskrosbarnens": "maskrosbarn",
    "maskrosbarnet": "maskrosbarn",
    "maskrosbarnets": "maskrosbarn",
    "maskrosbarns": "maskrosbarn",
    "maskrosen": "maskros",
    "maskrosens": "maskros",
    "maskrosor": "maskros",
    "maskrosorna": "maskros",
    "maskrosornas": "maskros",
    "maskrosors": "maskros",
    "masks": "mask",
    "maskspelen": "maskspel",
    "maskspelens": "maskspel",
    "maskspelet": "maskspel",
    "maskspelets": "maskspel",
    "maskspels": "maskspel",
    "maskstungens": "maskstungen",
    "maskstunget": "maskstungen",
    "maskstungets": "maskstungen",
    "maskstungna": "maskstungen",
    "maskstungnare": "maskstungen",
    "maskstungnares": "maskstungen",
    "maskstungnas": "maskstungen",
    "maskstungnast": "maskstungen",
    "maskstungnaste": "maskstungen",
    "maskstungnastes": "maskstungen",
    "maskstungnasts": "maskstungen",
    "maskstungne": "maskstungen",
    "maskstungnes": "maskstungen",
    "masktätheten": "masktäthet",
    "masktäthetens": "masktäthet",
    "masktätheter": "masktäthet",
    "masktätheterna": "masktäthet",
    "masktätheternas": "masktäthet",
    "masktätheters": "masktäthet",
    "masktäthets": "masktäthet",
    "maskulin": "maskulinum",
    "maskulina": "maskulin",
    "maskulinare": "maskulin",
    "maskulinares": "maskulin",
    "maskulinas": "maskulin",
    "maskulinast": "maskulin",
    "maskulinaste": "maskulin",
    "maskulinastes": "maskulin",
    "maskulinasts": "maskulin",
    "maskuline": "maskulin",
    "maskulinen": "maskulinum",
    "maskulinens": "maskulinum",
    "maskuliner": "maskulinum",
    "maskulinerna": "maskulinum",
    "maskulinernas": "maskulinum",
    "maskuliners": "maskulinum",
    "maskulines": "maskulin",
    "maskulinet": "maskulinum",
    "maskulinets": "maskulinum",
    "maskuliniserad": "maskulinisera",
    "maskuliniserade": "maskulinisera",
    "maskuliniserades": "maskulinisera",
    "maskuliniserads": "maskulinisera",
    "maskuliniserande": "maskulinisera",
    "maskuliniseranden": "maskuliniserande",
    "maskuliniserandena": "maskuliniserande",
    "maskuliniserandenas": "maskuliniserande",
    "maskuliniserandens": "maskuliniserande",
    "maskuliniserandes": "maskuliniserande",
    "maskuliniserandet": "maskuliniserande",
    "maskuliniserandets": "maskuliniserande",
    "maskuliniserar": "maskulinisera",
    "maskuliniseras": "maskulinisera",
    "maskuliniserat": "maskulinisera",
    "maskuliniserats": "maskulinisera",
    "maskuliniserbara": "maskuliniserbar",
    "maskuliniserbarare": "maskuliniserbar",
    "maskuliniserbarares": "maskuliniserbar",
    "maskuliniserbaras": "maskuliniserbar",
    "maskuliniserbarast": "maskuliniserbar",
    "maskuliniserbaraste": "maskuliniserbar",
    "maskuliniserbarastes": "maskuliniserbar",
    "maskuliniserbarasts": "maskuliniserbar",
    "maskuliniserbare": "maskuliniserbar",
    "maskuliniserbares": "maskuliniserbar",
    "maskuliniserbarheten": "maskuliniserbarhet",
    "maskuliniserbarhetens": "maskuliniserbarhet",
    "maskuliniserbarhets": "maskuliniserbarhet",
    "maskuliniserbars": "maskuliniserbar",
    "maskuliniserbart": "maskuliniserbar",
    "maskuliniserbarts": "maskuliniserbar",
    "maskuliniseringar": "maskulinisering",
    "maskuliniseringarna": "maskulinisering",
    "maskuliniseringarnas": "maskulinisering",
    "maskuliniseringars": "maskulinisering",
    "maskuliniseringen": "maskulinisering",
    "maskuliniseringens": "maskulinisering",
    "maskuliniserings": "maskulinisering",
    "maskulins": "maskulinum",
    "maskulint": "maskulin",
    "maskulints": "maskulin",
    "maskulinumet": "maskulinum",
    "maskulinumets": "maskulinum",
    "maskulinums": "maskulinum",
    "maskätens": "maskäten",
    "maskätet": "maskäten",
    "maskätets": "maskäten",
    "maskätna": "maskäten",
    "maskätnare": "maskäten",
    "maskätnares": "maskäten",
    "maskätnas": "maskäten",
    "maskätnast": "maskäten",
    "maskätnaste": "maskäten",
    "maskätnastes": "maskäten",
    "maskätnasts": "maskäten",
    "maskätne": "maskäten",
    "maskätnes": "maskäten",
    "maskören": "maskör",
    "maskörens": "maskör",
    "maskörer": "maskör",
    "maskörerna": "maskör",
    "maskörernas": "maskör",
    "maskörers": "maskör",
    "maskörs": "maskör",
    "masochismen": "masochism",
    "masochismens": "masochism",
    "masochismer": "masochism",
    "masochismerna": "masochism",
    "masochismernas": "masochism",
    "masochismers": "masochism",
    "masochisms": "masochism",
    "masochisten": "masochist",
    "masochistens": "masochist",
    "masochister": "masochist",
    "masochisterna": "masochist",
    "masochisternas": "masochist",
    "masochisters": "masochist",
    "masochistiska": "masochistisk",
    "masochistiskas": "masochistisk",
    "masochistiske": "masochistisk",
    "masochistiskes": "masochistisk",
    "masochistisks": "masochistisk",
    "masochistiskt": "masochistisk",
    "masochistiskts": "masochistisk",
    "masochists": "masochist",
    "masoniten": "masonit",
    "masonitens": "masonit",
    "masonits": "masonit",
    "masrar": "maser",
    "masrarna": "maser",
    "masrarnas": "maser",
    "masrars": "maser",
    "mass": "massa",
    "massabruken": "massabruk",
    "massabrukens": "massabruk",
    "massabruket": "massabruk",
    "massabrukets": "massabruk",
    "massabruks": "massabruk",
    "massafabriken": "massafabrik",
    "massafabrikens": "massafabrik",
    "massafabriker": "massafabrik",
    "massafabrikerna": "massafabrik",
    "massafabrikernas": "massafabrik",
    "massafabrikers": "massafabrik",
    "massafabriks": "massafabrik",
    "massageapparaten": "massageapparat",
    "massageapparatens": "massageapparat",
    "massageapparater": "massageapparat",
    "massageapparaterna": "massageapparat",
    "massageapparaternas": "massageapparat",
    "massageapparaters": "massageapparat",
    "massageapparats": "massageapparat",
    "massagefåtöljen": "massagefåtölj",
    "massagefåtöljens": "massagefåtölj",
    "massagefåtöljer": "massagefåtölj",
    "massagefåtöljerna": "massagefåtölj",
    "massagefåtöljernas": "massagefåtölj",
    "massagefåtöljers": "massagefåtölj",
    "massagefåtöljs": "massagefåtölj",
    "massageinstituten": "massageinstitut",
    "massageinstitutens": "massageinstitut",
    "massageinstitutet": "massageinstitut",
    "massageinstitutets": "massageinstitut",
    "massageinstituts": "massageinstitut",
    "massagen": "massage",
    "massagens": "massage",
    "massages": "massage",
    "massagestolar": "massagestol",
    "massagestolarna": "massagestol",
    "massagestolarnas": "massagestol",
    "massagestolars": "massagestol",
    "massagestolen": "massagestol",
    "massagestolens": "massagestol",
    "massagestols": "massagestol",
    "massakerklanen": "massakerklan",
    "massakerklanens": "massakerklan",
    "massakerklaner": "massakerklan",
    "massakerklanerna": "massakerklan",
    "massakerklanernas": "massakerklan",
    "massakerklaners": "massakerklan",
    "massakerklans": "massakerklan",
    "massakern": "massaker",
    "massakerns": "massaker",
    "massakers": "massaker",
    "massakerskyttar": "massakerskytt",
    "massakerskyttarna": "massakerskytt",
    "massakerskyttarnas": "massakerskytt",
    "massakerskyttars": "massakerskytt",
    "massakerskytten": "massakerskytt",
    "massakerskyttens": "massakerskytt",
    "massakerskytts": "massakerskytt",
    "massakrer": "massaker",
    "massakrerad": "massakrera",
    "massakrerade": "massakrera",
    "massakrerades": "massakrera",
    "massakrerads": "massakrera",
    "massakrerande": "massakrera",
    "massakreranden": "massakrerande",
    "massakrerandena": "massakrerande",
    "massakrerandenas": "massakrerande",
    "massakrerandens": "massakrerande",
    "massakrerandes": "massakrerande",
    "massakrerandet": "massakrerande",
    "massakrerandets": "massakrerande",
    "massakrerar": "massakrera",
    "massakreras": "massakrera",
    "massakrerat": "massakrera",
    "massakrerats": "massakrera",
    "massakrerbara": "massakrerbar",
    "massakrerbarare": "massakrerbar",
    "massakrerbarares": "massakrerbar",
    "massakrerbaras": "massakrerbar",
    "massakrerbarast": "massakrerbar",
    "massakrerbaraste": "massakrerbar",
    "massakrerbarastes": "massakrerbar",
    "massakrerbarasts": "massakrerbar",
    "massakrerbare": "massakrerbar",
    "massakrerbares": "massakrerbar",
    "massakrerbarheten": "massakrerbarhet",
    "massakrerbarhetens": "massakrerbarhet",
    "massakrerbarhets": "massakrerbarhet",
    "massakrerbars": "massakrerbar",
    "massakrerbart": "massakrerbar",
    "massakrerbarts": "massakrerbar",
    "massakreringar": "massakrering",
    "massakreringarna": "massakrering",
    "massakreringarnas": "massakrering",
    "massakreringars": "massakrering",
    "massakreringen": "massakrering",
    "massakreringens": "massakrering",
    "massakrerings": "massakrering",
    "massakrerna": "massaker",
    "massakrernas": "massaker",
    "massakrers": "massaker",
    "massan": "massa",
    "massans": "massa",
    "massarbetslösheten": "massarbetslöshet",
    "massarbetslöshetens": "massarbetslöshet",
    "massarbetslöshets": "massarbetslöshet",
    "massas": "massa",
    "massaveden": "massaved",
    "massavedens": "massaved",
    "massaveds": "massaved",
    "massavrättningar": "massavrättning",
    "massavrättningarna": "massavrättning",
    "massavrättningarnas": "massavrättning",
    "massavrättningars": "massavrättning",
    "massavrättningen": "massavrättning",
    "massavrättningens": "massavrättning",
    "massavrättnings": "massavrättning",
    "massbjäss": "massbjässe",
    "massbjässar": "massbjässe",
    "massbjässarna": "massbjässe",
    "massbjässarnas": "massbjässe",
    "massbjässars": "massbjässe",
    "massbjässen": "massbjässe",
    "massbjässens": "massbjässe",
    "massbjässes": "massbjässe",
    "masscentra": "masscentrum",
    "masscentrana": "masscentrum",
    "masscentranas": "masscentrum",
    "masscentras": "masscentrum",
    "masscentrer": "masscentrum",
    "masscentrerna": "masscentrum",
    "masscentrernas": "masscentrum",
    "masscentrers": "masscentrum",
    "masscentret": "masscentrum",
    "masscentrets": "masscentrum",
    "masscentrumen": "masscentrum",
    "masscentrumens": "masscentrum",
    "masscentrumet": "masscentrum",
    "masscentrumets": "masscentrum",
    "masscentrums": "masscentrum",
    "massdödar": "massdöd",
    "massdödarna": "massdöd",
    "massdödarnas": "massdöd",
    "massdödars": "massdöd",
    "massdöden": "massdöd",
    "massdödens": "massdöd",
    "massdöds": "massdöd",
    "masse": "massa",
    "masserad": "massera",
    "masserade": "massera",
    "masserades": "massera",
    "masserads": "massera",
    "masserande": "massera",
    "masseranden": "masserande",
    "masserandena": "masserande",
    "masserandenas": "masserande",
    "masserandens": "masserande",
    "masserandes": "masserande",
    "masserandet": "masserande",
    "masserandets": "masserande",
    "masserar": "massera",
    "masseras": "massera",
    "masserat": "massera",
    "masserats": "massera",
    "masserbara": "masserbar",
    "masserbarare": "masserbar",
    "masserbarares": "masserbar",
    "masserbaras": "masserbar",
    "masserbarast": "masserbar",
    "masserbaraste": "masserbar",
    "masserbarastes": "masserbar",
    "masserbarasts": "masserbar",
    "masserbare": "masserbar",
    "masserbares": "masserbar",
    "masserbarheten": "masserbarhet",
    "masserbarhetens": "masserbarhet",
    "masserbarhets": "masserbarhet",
    "masserbars": "masserbar",
    "masserbart": "masserbar",
    "masserbarts": "masserbar",
    "masseringar": "massering",
    "masseringarna": "massering",
    "masseringarnas": "massering",
    "masseringars": "massering",
    "masseringen": "massering",
    "masseringens": "massering",
    "masserings": "massering",
    "massfångsten": "massfångst",
    "massfångstens": "massfångst",
    "massfångster": "massfångst",
    "massfångsterna": "massfångst",
    "massfångsternas": "massfångst",
    "massfångsters": "massfångst",
    "massfångsts": "massfångst",
    "massgravar": "massgrav",
    "massgravarna": "massgrav",
    "massgravarnas": "massgrav",
    "massgravars": "massgrav",
    "massgraven": "massgrav",
    "massgravens": "massgrav",
    "massgravs": "massgrav",
    "masshäktningar": "masshäktning",
    "masshäktningarna": "masshäktning",
    "masshäktningarnas": "masshäktning",
    "masshäktningars": "masshäktning",
    "masshäktningen": "masshäktning",
    "masshäktningens": "masshäktning",
    "masshäktnings": "masshäktning",
    "massiva": "massiv",
    "massivare": "massiv",
    "massivares": "massiv",
    "massivas": "massiv",
    "massivast": "massiv",
    "massivaste": "massiv",
    "massivastes": "massiv",
    "massivasts": "massiv",
    "massive": "massiv",
    "massiven": "massiv",
    "massivens": "massiv",
    "massives": "massiv",
    "massivet": "massiv",
    "massivets": "massiv",
    "massiviteten": "massivitet",
    "massivitetens": "massivitet",
    "massiviteter": "massivitet",
    "massiviteterna": "massivitet",
    "massiviteternas": "massivitet",
    "massiviteters": "massivitet",
    "massivitets": "massivitet",
    "massivs": "massiv",
    "massivt": "massiv",
    "massivts": "massiv",
    "massjätt": "massjätte",
    "massjättar": "massjätte",
    "massjättarna": "massjätte",
    "massjättarnas": "massjätte",
    "massjättars": "massjätte",
    "massjätten": "massjätte",
    "massjättens": "massjätte",
    "massjättes": "massjätte",
    "massjätts": "massjätte",
    "masskommunikationen": "masskommunikation",
    "masskommunikationens": "masskommunikation",
    "masskommunikationer": "masskommunikation",
    "masskommunikationerna": "masskommunikation",
    "masskommunikationernas": "masskommunikation",
    "masskommunikationers": "masskommunikation",
    "masskommunikations": "masskommunikation",
    "masskonsten": "masskonst",
    "masskonstens": "masskonst",
    "masskonster": "masskonst",
    "masskonsterna": "masskonst",
    "masskonsternas": "masskonst",
    "masskonsters": "masskonst",
    "masskonsts": "masskonst",
    "masskorsbanden": "masskorsband",
    "masskorsbandens": "masskorsband",
    "masskorsbandet": "masskorsband",
    "masskorsbandets": "masskorsband",
    "masskorsbands": "masskorsband",
    "masslösa": "masslös",
    "masslösare": "masslös",
    "masslösares": "masslös",
    "masslösas": "masslös",
    "masslösast": "masslös",
    "masslösaste": "masslös",
    "masslösastes": "masslös",
    "masslösasts": "masslös",
    "masslöse": "masslös",
    "masslöses": "masslös",
    "masslösheten": "masslöshet",
    "masslöshetens": "masslöshet",
    "masslöshets": "masslöshet",
    "masslöst": "masslös",
    "masslösts": "masslös",
    "massmedia": "massmedium",
    "massmediala": "massmedial",
    "massmedialare": "massmedial",
    "massmedialares": "massmedial",
    "massmedialas": "massmedial",
    "massmedialast": "massmedial",
    "massmedialaste": "massmedial",
    "massmedialastes": "massmedial",
    "massmedialasts": "massmedial",
    "massmediale": "massmedial",
    "massmediales": "massmedial",
    "massmedials": "massmedial",
    "massmedialt": "massmedial",
    "massmedialts": "massmedial",
    "massmediana": "massmedium",
    "massmedianas": "massmedium",
    "massmedias": "massmedium",
    "massmedie": "massmedium",
    "massmedier": "massmedium",
    "massmedierna": "massmedium",
    "massmediernas": "massmedium",
    "massmediers": "massmedium",
    "massmediet": "massmedium",
    "massmediets": "massmedium",
    "massmediums": "massmedium",
    "massmorden": "massmord",
    "massmordens": "massmord",
    "massmordet": "massmord",
    "massmordets": "massmord",
    "massmords": "massmord",
    "massmördar": "massmördare",
    "massmördaren": "massmördare",
    "massmördarens": "massmördare",
    "massmördares": "massmördare",
    "massmördarna": "massmördare",
    "massmördarnas": "massmördare",
    "massmöten": "massmöte",
    "massmötena": "massmöte",
    "massmötenas": "massmöte",
    "massmötens": "massmöte",
    "massmötes": "massmöte",
    "massmötet": "massmöte",
    "massmötets": "massmöte",
    "massor": "massa",
    "massorna": "massa",
    "massornas": "massa",
    "massors": "massa",
    "masspektra": "masspektrum",
    "masspektrana": "masspektrum",
    "masspektranas": "masspektrum",
    "masspektras": "masspektrum",
    "masspektrena": "masspektrum",
    "masspektrenas": "masspektrum",
    "masspektrer": "masspektrum",
    "masspektrers": "masspektrum",
    "masspektret": "masspektrum",
    "masspektrets": "masspektrum",
    "masspektrumen": "masspektrum",
    "masspektrumens": "masspektrum",
    "masspektrumet": "masspektrum",
    "masspektrumets": "masspektrum",
    "masspektrums": "masspektrum",
    "massprotesten": "massprotest",
    "massprotestens": "massprotest",
    "massprotester": "massprotest",
    "massprotesterna": "massprotest",
    "massprotesternas": "massprotest",
    "massprotesters": "massprotest",
    "massprotests": "massprotest",
    "masspsykologien": "masspsykologi",
    "masspsykologiens": "masspsykologi",
    "masspsykologin": "masspsykologi",
    "masspsykologins": "masspsykologi",
    "masspsykologis": "masspsykologi",
    "masspsykosen": "masspsykos",
    "masspsykosens": "masspsykos",
    "masspsykoser": "masspsykos",
    "masspsykoserna": "masspsykos",
    "masspsykosernas": "masspsykos",
    "masspsykosers": "masspsykos",
    "masstalen": "masstal",
    "masstalens": "masstal",
    "masstalet": "masstal",
    "masstalets": "masstal",
    "masstals": "masstal",
    "massvaccineringar": "massvaccinering",
    "massvaccineringarna": "massvaccinering",
    "massvaccineringarnas": "massvaccinering",
    "massvaccineringars": "massvaccinering",
    "massvaccineringen": "massvaccinering",
    "massvaccineringens": "massvaccinering",
    "massvaccinerings": "massvaccinering",
    "massvåldtäkten": "massvåldtäkt",
    "massvåldtäktens": "massvåldtäkt",
    "massvåldtäkter": "massvåldtäkt",
    "massvåldtäkterna": "massvåldtäkt",
    "massvåldtäkternas": "massvåldtäkt",
    "massvåldtäkters": "massvåldtäkt",
    "massvåldtäkts": "massvåldtäkt",
    "massören": "massör",
    "massörens": "massör",
    "massörer": "massör",
    "massörerna": "massör",
    "massörernas": "massör",
    "massörers": "massör",
    "massörs": "massör",
    "mastade": "mastad",
    "mastades": "mastad",
    "mastads": "mastad",
    "mastat": "mastad",
    "mastats": "mastad",
    "masten": "mast",
    "mastens": "mast",
    "master": "mast",
    "mastern": "master",
    "masterna": "mast",
    "masternas": "mast",
    "masterns": "master",
    "masters": "master",
    "mastfiskar": "mastfisk",
    "mastfiskarna": "mastfisk",
    "mastfiskarnas": "mastfisk",
    "mastfiskars": "mastfisk",
    "mastfisken": "mastfisk",
    "mastfiskens": "mastfisk",
    "mastfisks": "mastfisk",
    "masthålen": "masthål",
    "masthålens": "masthål",
    "masthålet": "masthål",
    "masthålets": "masthål",
    "masthåls": "masthål",
    "mastiga": "mastig",
    "mastigare": "mastig",
    "mastigares": "mastig",
    "mastigas": "mastig",
    "mastigast": "mastig",
    "mastigaste": "mastig",
    "mastigastes": "mastig",
    "mastigasts": "mastig",
    "mastige": "mastig",
    "mastiges": "mastig",
    "mastigheten": "mastighet",
    "mastighetens": "mastighet",
    "mastighets": "mastighet",
    "mastigs": "mastig",
    "mastigt": "mastig",
    "mastigts": "mastig",
    "mastixen": "mastix",
    "mastixens": "mastix",
    "mastkorgar": "mastkorg",
    "mastkorgarna": "mastkorg",
    "mastkorgarnas": "mastkorg",
    "mastkorgars": "mastkorg",
    "mastkorgen": "mastkorg",
    "mastkorgens": "mastkorg",
    "mastkorgs": "mastkorg",
    "mastkrag": "mastkrage",
    "mastkragar": "mastkrage",
    "mastkragarna": "mastkrage",
    "mastkragarnas": "mastkrage",
    "mastkragars": "mastkrage",
    "mastkragen": "mastkrage",
    "mastkragens": "mastkrage",
    "mastkrages": "mastkrage",
    "mastkrags": "mastkrage",
    "mastodonten": "mastodont",
    "mastodontens": "mastodont",
    "mastodonter": "mastodont",
    "mastodonterna": "mastodont",
    "mastodonternas": "mastodont",
    "mastodonters": "mastodont",
    "mastodontiska": "mastodontisk",
    "mastodontiskare": "mastodontisk",
    "mastodontiskares": "mastodontisk",
    "mastodontiskas": "mastodontisk",
    "mastodontiskast": "mastodontisk",
    "mastodontiskaste": "mastodontisk",
    "mastodontiskastes": "mastodontisk",
    "mastodontiskasts": "mastodontisk",
    "mastodontiske": "mastodontisk",
    "mastodontiskes": "mastodontisk",
    "mastodontisks": "mastodontisk",
    "mastodontiskt": "mastodontisk",
    "mastodontiskts": "mastodontisk",
    "mastodontprojekten": "mastodontprojekt",
    "mastodontprojektens": "mastodontprojekt",
    "mastodontprojektet": "mastodontprojekt",
    "mastodontprojektets": "mastodontprojekt",
    "mastodontprojekts": "mastodontprojekt",
    "mastodonts": "mastodont",
    "mastrar": "master",
    "mastrarna": "master",
    "mastrarnas": "master",
    "mastrars": "master",
    "masts": "mast",
    "masturbationen": "masturbation",
    "masturbationens": "masturbation",
    "masturbationer": "masturbation",
    "masturbationerna": "masturbation",
    "masturbationernas": "masturbation",
    "masturbationers": "masturbation",
    "masturbations": "masturbation",
    "masturberade": "masturbera",
    "masturberades": "masturbera",
    "masturberande": "masturbera",
    "masturberanden": "masturberande",
    "masturberandena": "masturberande",
    "masturberandenas": "masturberande",
    "masturberandens": "masturberande",
    "masturberandes": "masturberande",
    "masturberandet": "masturberande",
    "masturberandets": "masturberande",
    "masturberar": "masturbera",
    "masturberas": "masturbera",
    "masturberat": "masturbera",
    "masturberats": "masturbera",
    "masturberingar": "masturbering",
    "masturberingarna": "masturbering",
    "masturberingarnas": "masturbering",
    "masturberingars": "masturbering",
    "masturberingen": "masturbering",
    "masturberingens": "masturbering",
    "masturberings": "masturbering",
    "masugnar": "masugn",
    "masugnarna": "masugn",
    "masugnarnas": "masugn",
    "masugnars": "masugn",
    "masugnen": "masugn",
    "masugnens": "masugn",
    "masugns": "masugn",
    "masurbjörkar": "masurbjörk",
    "masurbjörkarna": "masurbjörk",
    "masurbjörkarnas": "masurbjörk",
    "masurbjörkars": "masurbjörk",
    "masurbjörken": "masurbjörk",
    "masurbjörkens": "masurbjörk",
    "masurbjörks": "masurbjörk",
    "masurk": "masurka",
    "masurkan": "masurka",
    "masurkans": "masurka",
    "masurkas": "masurka",
    "masurke": "masurka",
    "masurkor": "masurka",
    "masurkorna": "masurka",
    "masurkornas": "masurka",
    "masurkors": "masurka",
    "masurks": "masurka",
    "masurn": "masur",
    "masurns": "masur",
    "masurs": "masur",
    "masverken": "masverk",
    "masverkens": "masverk",
    "masverket": "masverk",
    "masverkets": "masverk",
    "masverks": "masverk",
    "matad": "mata",
    "matade": "mata",
    "matades": "mata",
    "matadoren": "matador",
    "matadorens": "matador",
    "matadorer": "matador",
    "matadorerna": "matador",
    "matadorernas": "matador",
    "matadorers": "matador",
    "matadors": "matador",
    "matads": "mata",
    "matande": "mata",
    "matanden": "matande",
    "matandena": "matande",
    "matandenas": "matande",
    "matandens": "matande",
    "matandes": "matande",
    "matandet": "matande",
    "matandets": "matande",
    "matar": "matare",
    "matarbussar": "matarbuss",
    "matarbussarna": "matarbuss",
    "matarbussarnas": "matarbuss",
    "matarbussars": "matarbuss",
    "matarbussen": "matarbuss",
    "matarbussens": "matarbuss",
    "mataren": "matare",
    "matarens": "matare",
    "matares": "matare",
    "matarledningar": "matarledning",
    "matarledningarna": "matarledning",
    "matarledningarnas": "matarledning",
    "matarledningars": "matarledning",
    "matarledningen": "matarledning",
    "matarledningens": "matarledning",
    "matarlednings": "matarledning",
    "matarna": "matare",
    "matarnas": "matare",
    "matarvattens": "matarvatten",
    "matarvattnet": "matarvatten",
    "matarvattnets": "matarvatten",
    "matas": "mata",
    "matat": "mata",
    "matats": "mata",
    "matbesticken": "matbestick",
    "matbestickens": "matbestick",
    "matbesticket": "matbestick",
    "matbestickets": "matbestick",
    "matbesticks": "matbestick",
    "matbitar": "matbit",
    "matbitarna": "matbit",
    "matbitarnas": "matbit",
    "matbitars": "matbit",
    "matbiten": "matbit",
    "matbitens": "matbit",
    "matbits": "matbit",
    "matborden": "matbord",
    "matbordens": "matbord",
    "matbordet": "matbord",
    "matbordets": "matbord",
    "matbords": "matbord",
    "matbröden": "matbröd",
    "matbrödens": "matbröd",
    "matbrödet": "matbröd",
    "matbrödets": "matbröd",
    "matbröds": "matbröd",
    "match": "matcha",
    "matchad": "matcha",
    "matchade": "matcha",
    "matchades": "matcha",
    "matchads": "matcha",
    "matchande": "matcha",
    "matchanden": "matchande",
    "matchandena": "matchande",
    "matchandenas": "matchande",
    "matchandens": "matchande",
    "matchandes": "matchande",
    "matchandet": "matchande",
    "matchandets": "matchande",
    "matchar": "matcha",
    "matchas": "matcha",
    "matchat": "matcha",
    "matchats": "matcha",
    "matchbollar": "matchboll",
    "matchbollarna": "matchboll",
    "matchbollarnas": "matchboll",
    "matchbollars": "matchboll",
    "matchbollen": "matchboll",
    "matchbollens": "matchboll",
    "matchbolls": "matchboll",
    "matchen": "match",
    "matchens": "match",
    "matcher": "match",
    "matcherna": "match",
    "matchernas": "match",
    "matchers": "match",
    "matchhjältar": "matchhjälte",
    "matchhjältarna": "matchhjälte",
    "matchhjältarnas": "matchhjälte",
    "matchhjältars": "matchhjälte",
    "matchhjälten": "matchhjälte",
    "matchhjältens": "matchhjälte",
    "matchhjältes": "matchhjälte",
    "matchs": "match",
    "matelasserad": "matelassera",
    "matelasserade": "matelassera",
    "matelasserades": "matelassera",
    "matelasserads": "matelassera",
    "matelasserande": "matelassera",
    "matelasseranden": "matelasserande",
    "matelasserandena": "matelasserande",
    "matelasserandenas": "matelasserande",
    "matelasserandens": "matelasserande",
    "matelasserandes": "matelasserande",
    "matelasserandet": "matelasserande",
    "matelasserandets": "matelasserande",
    "matelasserar": "matelassera",
    "matelasseras": "matelassera",
    "matelasserat": "matelassera",
    "matelasserats": "matelassera",
    "matelasserbara": "matelasserbar",
    "matelasserbarare": "matelasserbar",
    "matelasserbarares": "matelasserbar",
    "matelasserbaras": "matelasserbar",
    "matelasserbarast": "matelasserbar",
    "matelasserbaraste": "matelasserbar",
    "matelasserbarastes": "matelasserbar",
    "matelasserbarasts": "matelasserbar",
    "matelasserbare": "matelasserbar",
    "matelasserbares": "matelasserbar",
    "matelasserbarheten": "matelasserbarhet",
    "matelasserbarhetens": "matelasserbarhet",
    "matelasserbarhets": "matelasserbarhet",
    "matelasserbars": "matelasserbar",
    "matelasserbart": "matelasserbar",
    "matelasserbarts": "matelasserbar",
    "matelasseringar": "matelassering",
    "matelasseringarna": "matelassering",
    "matelasseringarnas": "matelassering",
    "matelasseringars": "matelassering",
    "matelasseringen": "matelassering",
    "matelasseringens": "matelassering",
    "matelasserings": "matelassering",
    "matelassén": "matelassé",
    "matelasséns": "matelassé",
    "matelassés": "matelassé",
    "matematiken": "matematik",
    "matematikens": "matematik",
    "matematikern": "matematiker",
    "matematikerna": "matematiker",
    "matematikernas": "matematiker",
    "matematikerns": "matematiker",
    "matematikers": "matematiker",
    "matematiklärar": "matematiklärare",
    "matematikläraren": "matematiklärare",
    "matematiklärarens": "matematiklärare",
    "matematiklärares": "matematiklärare",
    "matematiklärarna": "matematiklärare",
    "matematiklärarnas": "matematiklärare",
    "matematiks": "matematik",
    "matematisk-naturvetenskapliga": "matematisk-naturvetenskaplig",
    "matematisk-naturvetenskapligare": "matematisk-naturvetenskaplig",
    "matematisk-naturvetenskapligares": "matematisk-naturvetenskaplig",
    "matematisk-naturvetenskapligas": "matematisk-naturvetenskaplig",
    "matematisk-naturvetenskapligast": "matematisk-naturvetenskaplig",
    "matematisk-naturvetenskapligaste": "matematisk-naturvetenskaplig",
    "matematisk-naturvetenskapligastes": "matematisk-naturvetenskaplig",
    "matematisk-naturvetenskapligasts": "matematisk-naturvetenskaplig",
    "matematisk-naturvetenskaplige": "matematisk-naturvetenskaplig",
    "matematisk-naturvetenskapliges": "matematisk-naturvetenskaplig",
    "matematisk-naturvetenskapligs": "matematisk-naturvetenskaplig",
    "matematisk-naturvetenskapligt": "matematisk-naturvetenskaplig",
    "matematisk-naturvetenskapligts": "matematisk-naturvetenskaplig",
    "matematiska": "matematisk",
    "matematiskare": "matematisk",
    "matematiskares": "matematisk",
    "matematiskas": "matematisk",
    "matematiskast": "matematisk",
    "matematiskaste": "matematisk",
    "matematiskastes": "matematisk",
    "matematiskasts": "matematisk",
    "matematiske": "matematisk",
    "matematiskes": "matematisk",
    "matematisks": "matematisk",
    "matematiskt": "matematisk",
    "matematiskts": "matematisk",
    "maten": "mat",
    "matens": "mat",
    "materialen": "material",
    "materialens": "material",
    "materialet": "material",
    "materialets": "material",
    "materialisationen": "materialisation",
    "materialisationens": "materialisation",
    "materialisationer": "materialisation",
    "materialisationerna": "materialisation",
    "materialisationernas": "materialisation",
    "materialisationers": "materialisation",
    "materialisations": "materialisation",
    "materialiserad": "materialisera",
    "materialiserade": "materialisera",
    "materialiserades": "materialisera",
    "materialiserads": "materialisera",
    "materialiserande": "materialisera",
    "materialiseranden": "materialiserande",
    "materialiserandena": "materialiserande",
    "materialiserandenas": "materialiserande",
    "materialiserandens": "materialiserande",
    "materialiserandes": "materialiserande",
    "materialiserandet": "materialiserande",
    "materialiserandets": "materialiserande",
    "materialiserar": "materialisera",
    "materialiseras": "materialisera",
    "materialiserat": "materialisera",
    "materialiserats": "materialisera",
    "materialiserbara": "materialiserbar",
    "materialiserbarare": "materialiserbar",
    "materialiserbarares": "materialiserbar",
    "materialiserbaras": "materialiserbar",
    "materialiserbarast": "materialiserbar",
    "materialiserbaraste": "materialiserbar",
    "materialiserbarastes": "materialiserbar",
    "materialiserbarasts": "materialiserbar",
    "materialiserbare": "materialiserbar",
    "materialiserbares": "materialiserbar",
    "materialiserbarheten": "materialiserbarhet",
    "materialiserbarhetens": "materialiserbarhet",
    "materialiserbarhets": "materialiserbarhet",
    "materialiserbars": "materialiserbar",
    "materialiserbart": "materialiserbar",
    "materialiserbarts": "materialiserbar",
    "materialiseringar": "materialisering",
    "materialiseringarna": "materialisering",
    "materialiseringarnas": "materialisering",
    "materialiseringars": "materialisering",
    "materialiseringen": "materialisering",
    "materialiseringens": "materialisering",
    "materialiserings": "materialisering",
    "materialismen": "materialism",
    "materialismens": "materialism",
    "materialismer": "materialism",
    "materialismerna": "materialism",
    "materialismernas": "materialism",
    "materialismers": "materialism",
    "materialisms": "materialism",
    "materialisten": "materialist",
    "materialistens": "materialist",
    "materialister": "materialist",
    "materialisterna": "materialist",
    "materialisternas": "materialist",
    "materialisters": "materialist",
    "materialistiska": "materialistisk",
    "materialistiskare": "materialistisk",
    "materialistiskares": "materialistisk",
    "materialistiskas": "materialistisk",
    "materialistiskast": "materialistisk",
    "materialistiskaste": "materialistisk",
    "materialistiskastes": "materialistisk",
    "materialistiskasts": "materialistisk",
    "materialistiske": "materialistisk",
    "materialistiskes": "materialistisk",
    "materialistisks": "materialistisk",
    "materialistiskt": "materialistisk",
    "materialistiskts": "materialistisk",
    "materialists": "materialist",
    "materialkonstanten": "materialkonstant",
    "materialkonstantens": "materialkonstant",
    "materialkonstanter": "materialkonstant",
    "materialkonstanterna": "materialkonstant",
    "materialkonstanternas": "materialkonstant",
    "materialkonstanters": "materialkonstant",
    "materialkonstants": "materialkonstant",
    "materialmässiga": "materialmässig",
    "materialmässigare": "materialmässig",
    "materialmässigares": "materialmässig",
    "materialmässigas": "materialmässig",
    "materialmässigast": "materialmässig",
    "materialmässigaste": "materialmässig",
    "materialmässigastes": "materialmässig",
    "materialmässigasts": "materialmässig",
    "materialmässige": "materialmässig",
    "materialmässiges": "materialmässig",
    "materialmässigs": "materialmässig",
    "materialmässigt": "materialmässig",
    "materialmässigts": "materialmässig",
    "materialproblemen": "materialproblem",
    "materialproblemens": "materialproblem",
    "materialproblemet": "materialproblem",
    "materialproblemets": "materialproblem",
    "materialproblems": "materialproblem",
    "materials": "material",
    "materialsamlingar": "materialsamling",
    "materialsamlingarna": "materialsamling",
    "materialsamlingarnas": "materialsamling",
    "materialsamlingars": "materialsamling",
    "materialsamlingen": "materialsamling",
    "materialsamlingens": "materialsamling",
    "materialsamlings": "materialsamling",
    "materialspelar": "materialspelare",
    "materialspelaren": "materialspelare",
    "materialspelarens": "materialspelare",
    "materialspelares": "materialspelare",
    "materialspelarna": "materialspelare",
    "materialspelarnas": "materialspelare",
    "materian": "materia",
    "materians": "materia",
    "materias": "materia",
    "materieer": "materieera",
    "materieeran": "materieera",
    "materieerans": "materieera",
    "materieeras": "materieera",
    "materieere": "materieera",
    "materieeror": "materieera",
    "materieerorna": "materieera",
    "materieerornas": "materieera",
    "materieerors": "materieera",
    "materieers": "materieera",
    "materieforskningar": "materieforskning",
    "materieforskningarna": "materieforskning",
    "materieforskningarnas": "materieforskning",
    "materieforskningars": "materieforskning",
    "materieforskningen": "materieforskning",
    "materieforskningens": "materieforskning",
    "materieforsknings": "materieforskning",
    "materiegasen": "materiegas",
    "materiegasens": "materiegas",
    "materiegaser": "materiegas",
    "materiegaserna": "materiegas",
    "materiegasernas": "materiegas",
    "materiegasers": "materiegas",
    "materielen": "materiel",
    "materielens": "materiel",
    "materiella": "materiell",
    "materiellare": "materiell",
    "materiellares": "materiell",
    "materiellas": "materiell",
    "materiellast": "materiell",
    "materiellaste": "materiell",
    "materiellastes": "materiell",
    "materiellasts": "materiell",
    "materielle": "materiell",
    "materielles": "materiell",
    "materiells": "materiell",
    "materiellt": "materiell",
    "materiellts": "materiell",
    "materiels": "materiel",
    "materiemolnen": "materiemoln",
    "materiemolnens": "materiemoln",
    "materiemolnet": "materiemoln",
    "materiemolnets": "materiemoln",
    "materiemolns": "materiemoln",
    "materien": "materie",
    "materiens": "materie",
    "materier": "materie",
    "materierna": "materie",
    "materiernas": "materie",
    "materiers": "materie",
    "materies": "materie",
    "materieströmmar": "materieström",
    "materieströmmarna": "materieström",
    "materieströmmarnas": "materieström",
    "materieströmmars": "materieström",
    "materieströmmen": "materieström",
    "materieströmmens": "materieström",
    "materieströms": "materieström",
    "materietransporten": "materietransport",
    "materietransportens": "materietransport",
    "materietransporter": "materietransport",
    "materietransporterna": "materietransport",
    "materietransporternas": "materietransport",
    "materietransporters": "materietransport",
    "materietransports": "materietransport",
    "materieutbyten": "materieutbyte",
    "materieutbytena": "materieutbyte",
    "materieutbytenas": "materieutbyte",
    "materieutbytens": "materieutbyte",
    "materieutbytes": "materieutbyte",
    "materieutbytet": "materieutbyte",
    "materieutbytets": "materieutbyte",
    "mates": "mate",
    "matet": "mate",
    "matets": "mate",
    "matfetter": "matfett",
    "matfetterna": "matfett",
    "matfetternas": "matfett",
    "matfetters": "matfett",
    "matfettet": "matfett",
    "matfettets": "matfett",
    "matfetts": "matfett",
    "matfriska": "matfrisk",
    "matfriskare": "matfrisk",
    "matfriskares": "matfrisk",
    "matfriskas": "matfrisk",
    "matfriskast": "matfrisk",
    "matfriskaste": "matfrisk",
    "matfriskastes": "matfrisk",
    "matfriskasts": "matfrisk",
    "matfriske": "matfrisk",
    "matfriskes": "matfrisk",
    "matfrisks": "matfrisk",
    "matfriskt": "matfrisk",
    "matfriskts": "matfrisk",
    "matfrukten": "matfrukt",
    "matfruktens": "matfrukt",
    "matfrukter": "matfrukt",
    "matfrukterna": "matfrukt",
    "matfrukternas": "matfrukt",
    "matfrukters": "matfrukt",
    "matfrukts": "matfrukt",
    "matförgiftningar": "matförgiftning",
    "matförgiftningarna": "matförgiftning",
    "matförgiftningarnas": "matförgiftning",
    "matförgiftningars": "matförgiftning",
    "matförgiftningen": "matförgiftning",
    "matförgiftningens": "matförgiftning",
    "matförgiftnings": "matförgiftning",
    "matförråden": "matförråd",
    "matförrådens": "matförråd",
    "matförrådet": "matförråd",
    "matförrådets": "matförråd",
    "matförråds": "matförråd",
    "matgästen": "matgäst",
    "matgästens": "matgäst",
    "matgäster": "matgäst",
    "matgästerna": "matgäst",
    "matgästernas": "matgäst",
    "matgästers": "matgäst",
    "matgästs": "matgäst",
    "mathållningar": "mathållning",
    "mathållningarna": "mathållning",
    "mathållningarnas": "mathållning",
    "mathållningars": "mathållning",
    "mathållningen": "mathållning",
    "mathållningens": "mathållning",
    "mathållnings": "mathållning",
    "matiga": "matig",
    "matigare": "matig",
    "matigares": "matig",
    "matigas": "matig",
    "matigast": "matig",
    "matigaste": "matig",
    "matigastes": "matig",
    "matigasts": "matig",
    "matige": "matig",
    "matiges": "matig",
    "matigs": "matig",
    "matigt": "matig",
    "matigts": "matig",
    "matinéer": "matiné",
    "matinéerna": "matiné",
    "matinéernas": "matiné",
    "matinéers": "matiné",
    "matinén": "matiné",
    "matinéns": "matiné",
    "matinés": "matiné",
    "matjessillar": "matjessill",
    "matjessillarna": "matjessill",
    "matjessillarnas": "matjessill",
    "matjessillars": "matjessill",
    "matjessillen": "matjessill",
    "matjessillens": "matjessill",
    "matjessills": "matjessill",
    "matjordar": "matjord",
    "matjordarna": "matjord",
    "matjordarnas": "matjord",
    "matjordars": "matjord",
    "matjorden": "matjord",
    "matjordens": "matjord",
    "matjords": "matjord",
    "matkass": "matkasse",
    "matkassar": "matkasse",
    "matkassarna": "matkasse",
    "matkassarnas": "matkasse",
    "matkassars": "matkasse",
    "matkassen": "matkasse",
    "matkassens": "matkasse",
    "matkasses": "matkasse",
    "matkonserven": "matkonserv",
    "matkonservens": "matkonserv",
    "matkonserver": "matkonserv",
    "matkonserverna": "matkonserv",
    "matkonservernas": "matkonserv",
    "matkonservers": "matkonserv",
    "matkonservs": "matkonserv",
    "matkorgar": "matkorg",
    "matkorgarna": "matkorg",
    "matkorgarnas": "matkorg",
    "matkorgars": "matkorg",
    "matkorgen": "matkorg",
    "matkorgens": "matkorg",
    "matkorgs": "matkorg",
    "matkupongen": "matkupong",
    "matkupongens": "matkupong",
    "matkuponger": "matkupong",
    "matkupongerna": "matkupong",
    "matkupongernas": "matkupong",
    "matkupongers": "matkupong",
    "matkupongs": "matkupong",
    "matlagen": "matlag",
    "matlagens": "matlag",
    "matlaget": "matlag",
    "matlagets": "matlag",
    "matlagningar": "matlagning",
    "matlagningarna": "matlagning",
    "matlagningarnas": "matlagning",
    "matlagningars": "matlagning",
    "matlagningen": "matlagning",
    "matlagningens": "matlagning",
    "matlagnings": "matlagning",
    "matlagningskonsten": "matlagningskonst",
    "matlagningskonstens": "matlagningskonst",
    "matlagningskonster": "matlagningskonst",
    "matlagningskonsterna": "matlagningskonst",
    "matlagningskonsternas": "matlagningskonst",
    "matlagningskonsters": "matlagningskonst",
    "matlagningskonsts": "matlagningskonst",
    "matlagningsskickligheten": "matlagningsskicklighet",
    "matlagningsskicklighetens": "matlagningsskicklighet",
    "matlagningsskickligheter": "matlagningsskicklighet",
    "matlagningsskickligheterna": "matlagningsskicklighet",
    "matlagningsskickligheternas": "matlagningsskicklighet",
    "matlagningsskickligheters": "matlagningsskicklighet",
    "matlagningsskicklighets": "matlagningsskicklighet",
    "matlags": "matlag",
    "matlandet": "matland",
    "matlandets": "matland",
    "matlands": "matland",
    "matlarmen": "matlarm",
    "matlarmens": "matlarm",
    "matlarmet": "matlarm",
    "matlarmets": "matlarm",
    "matlarms": "matlarm",
    "matlusten": "matlust",
    "matlustens": "matlust",
    "matlusts": "matlust",
    "matländer": "matland",
    "matländerna": "matland",
    "matländernas": "matland",
    "matländers": "matland",
    "matlåd": "matlåda",
    "matlådan": "matlåda",
    "matlådans": "matlåda",
    "matlådas": "matlåda",
    "matlåde": "matlåda",
    "matlådor": "matlåda",
    "matlådorna": "matlåda",
    "matlådornas": "matlåda",
    "matlådors": "matlåda",
    "matlåds": "matlåda",
    "matmamman": "matmamma",
    "matmammans": "matmamma",
    "matmammas": "matmamma",
    "matmamme": "matmamma",
    "matmammor": "matmamma",
    "matmammorna": "matmamma",
    "matmammornas": "matmamma",
    "matmammors": "matmamma",
    "matmors": "matmor",
    "matmässiga": "matmässig",
    "matmässigare": "matmässig",
    "matmässigares": "matmässig",
    "matmässigas": "matmässig",
    "matmässigast": "matmässig",
    "matmässigaste": "matmässig",
    "matmässigastes": "matmässig",
    "matmässigasts": "matmässig",
    "matmässige": "matmässig",
    "matmässiges": "matmässig",
    "matmässigs": "matmässig",
    "matmässigt": "matmässig",
    "matmässigts": "matmässig",
    "matningar": "matning",
    "matningarna": "matning",
    "matningarnas": "matning",
    "matningars": "matning",
    "matningen": "matning",
    "matningens": "matning",
    "matnings": "matning",
    "matnyttiga": "matnyttig",
    "matnyttigare": "matnyttig",
    "matnyttigares": "matnyttig",
    "matnyttigas": "matnyttig",
    "matnyttigast": "matnyttig",
    "matnyttigaste": "matnyttig",
    "matnyttigastes": "matnyttig",
    "matnyttigasts": "matnyttig",
    "matnyttige": "matnyttig",
    "matnyttiges": "matnyttig",
    "matnyttigheten": "matnyttighet",
    "matnyttighetens": "matnyttighet",
    "matnyttigheter": "matnyttighet",
    "matnyttigheterna": "matnyttighet",
    "matnyttigheternas": "matnyttighet",
    "matnyttigheters": "matnyttighet",
    "matnyttighets": "matnyttighet",
    "matnyttigs": "matnyttig",
    "matnyttigt": "matnyttig",
    "matnyttigts": "matnyttig",
    "matoljan": "matolja",
    "matoljans": "matolja",
    "matoljas": "matolja",
    "matolje": "matolja",
    "matoljor": "matolja",
    "matoljorna": "matolja",
    "matoljornas": "matolja",
    "matoljors": "matolja",
    "matoset": "matos",
    "matosets": "matos",
    "matpatrullen": "matpatrull",
    "matpatrullens": "matpatrull",
    "matpatruller": "matpatrull",
    "matpatrullerna": "matpatrull",
    "matpatrullernas": "matpatrull",
    "matpatrullers": "matpatrull",
    "matpatrulls": "matpatrull",
    "matpotatisar": "matpotatis",
    "matpotatisarna": "matpotatis",
    "matpotatisarnas": "matpotatis",
    "matpotatisars": "matpotatis",
    "matpotatisen": "matpotatis",
    "matpotatisens": "matpotatis",
    "matransonen": "matranson",
    "matransonens": "matranson",
    "matransoner": "matranson",
    "matransonerna": "matranson",
    "matransonernas": "matranson",
    "matransoners": "matranson",
    "matransons": "matranson",
    "matrasten": "matrast",
    "matrastens": "matrast",
    "matraster": "matrast",
    "matrasterna": "matrast",
    "matrasternas": "matrast",
    "matrasters": "matrast",
    "matrasts": "matrast",
    "matrecepten": "matrecept",
    "matreceptens": "matrecept",
    "matreceptet": "matrecept",
    "matreceptets": "matrecept",
    "matrecepts": "matrecept",
    "matresten": "matrest",
    "matrestens": "matrest",
    "matrester": "matrest",
    "matresterna": "matrest",
    "matresternas": "matrest",
    "matresters": "matrest",
    "matrests": "matrest",
    "matriarkala": "matriarkal",
    "matriarkalare": "matriarkal",
    "matriarkalares": "matriarkal",
    "matriarkalas": "matriarkal",
    "matriarkalast": "matriarkal",
    "matriarkalaste": "matriarkal",
    "matriarkalastes": "matriarkal",
    "matriarkalasts": "matriarkal",
    "matriarkale": "matriarkal",
    "matriarkales": "matriarkal",
    "matriarkaliska": "matriarkalisk",
    "matriarkaliskare": "matriarkalisk",
    "matriarkaliskares": "matriarkalisk",
    "matriarkaliskas": "matriarkalisk",
    "matriarkaliskast": "matriarkalisk",
    "matriarkaliskaste": "matriarkalisk",
    "matriarkaliskastes": "matriarkalisk",
    "matriarkaliskasts": "matriarkalisk",
    "matriarkaliske": "matriarkalisk",
    "matriarkaliskes": "matriarkalisk",
    "matriarkalisks": "matriarkalisk",
    "matriarkaliskt": "matriarkalisk",
    "matriarkaliskts": "matriarkalisk",
    "matriarkals": "matriarkal",
    "matriarkalt": "matriarkal",
    "matriarkalts": "matriarkal",
    "matriarkatet": "matriarkat",
    "matriarkatets": "matriarkat",
    "matriarkats": "matriarkat",
    "matrikeln": "matrikel",
    "matrikelns": "matrikel",
    "matrikels": "matrikel",
    "matriklar": "matrikel",
    "matriklarna": "matrikel",
    "matriklarnas": "matrikel",
    "matriklars": "matrikel",
    "matrisen": "matris",
    "matrisens": "matris",
    "matriser": "matris",
    "matriserna": "matris",
    "matrisernas": "matris",
    "matrisers": "matris",
    "matron": "matrona",
    "matronan": "matrona",
    "matronans": "matrona",
    "matronas": "matrona",
    "matrone": "matrona",
    "matronor": "matrona",
    "matronorna": "matrona",
    "matronornas": "matrona",
    "matronors": "matrona",
    "matrons": "matrona",
    "matrosen": "matros",
    "matrosens": "matros",
    "matroser": "matros",
    "matroserna": "matros",
    "matrosernas": "matros",
    "matrosers": "matros",
    "matroskostymen": "matroskostym",
    "matroskostymens": "matroskostym",
    "matroskostymer": "matroskostym",
    "matroskostymerna": "matroskostym",
    "matroskostymernas": "matroskostym",
    "matroskostymers": "matroskostym",
    "matroskostyms": "matroskostym",
    "maträtten": "maträtt",
    "maträttens": "maträtt",
    "maträtter": "maträtt",
    "maträtterna": "maträtt",
    "maträtternas": "maträtt",
    "maträtters": "maträtt",
    "maträtts": "maträtt",
    "mats": "mat",
    "matsalar": "matsal",
    "matsalarna": "matsal",
    "matsalarnas": "matsal",
    "matsalars": "matsal",
    "matsalen": "matsal",
    "matsalens": "matsal",
    "matsalongen": "matsalong",
    "matsalongens": "matsalong",
    "matsalonger": "matsalong",
    "matsalongerna": "matsalong",
    "matsalongernas": "matsalong",
    "matsalongers": "matsalong",
    "matsalongs": "matsalong",
    "matsals": "matsal",
    "matsedeln": "matsedel",
    "matsedelns": "matsedel",
    "matsedels": "matsedel",
    "matsedlar": "matsedel",
    "matsedlarna": "matsedel",
    "matsedlarnas": "matsedel",
    "matsedlars": "matsedel",
    "matserveringar": "matservering",
    "matserveringarna": "matservering",
    "matserveringarnas": "matservering",
    "matserveringars": "matservering",
    "matserveringen": "matservering",
    "matserveringens": "matservering",
    "matserverings": "matservering",
    "matservisen": "matservis",
    "matservisens": "matservis",
    "matserviser": "matservis",
    "matserviserna": "matservis",
    "matservisernas": "matservis",
    "matservisers": "matservis",
    "matsilvers": "matsilver",
    "matsilvret": "matsilver",
    "matsilvrets": "matsilver",
    "matskedar": "matsked",
    "matskedarna": "matsked",
    "matskedarnas": "matsked",
    "matskedars": "matsked",
    "matskeden": "matsked",
    "matskedens": "matsked",
    "matskeds": "matsked",
    "matsmältningar": "matsmältning",
    "matsmältningarna": "matsmältning",
    "matsmältningarnas": "matsmältning",
    "matsmältningars": "matsmältning",
    "matsmältningen": "matsmältning",
    "matsmältningens": "matsmältning",
    "matsmältnings": "matsmältning",
    "matsmältningskanalen": "matsmältningskanal",
    "matsmältningskanalens": "matsmältningskanal",
    "matsmältningskanaler": "matsmältningskanal",
    "matsmältningskanalerna": "matsmältningskanal",
    "matsmältningskanalernas": "matsmältningskanal",
    "matsmältningskanalers": "matsmältningskanal",
    "matsmältningskanals": "matsmältningskanal",
    "matsmältningsorganen": "matsmältningsorgan",
    "matsmältningsorganens": "matsmältningsorgan",
    "matsmältningsorganet": "matsmältningsorgan",
    "matsmältningsorganets": "matsmältningsorgan",
    "matsmältningsorgans": "matsmältningsorgan",
    "matsmältningsvätskan": "matsmältningsvätska",
    "matsmältningsvätskans": "matsmältningsvätska",
    "matsmältningsvätskas": "matsmältningsvätska",
    "matsmältningsvätske": "matsmältningsvätska",
    "matsmältningsvätskor": "matsmältningsvätska",
    "matsmältningsvätskorna": "matsmältningsvätska",
    "matsmältningsvätskornas": "matsmältningsvätska",
    "matsmältningsvätskors": "matsmältningsvätska",
    "matsmöret": "matsmör",
    "matsmörets": "matsmör",
    "matsmörs": "matsmör",
    "matstrup": "matstrupe",
    "matstrupar": "matstrupe",
    "matstruparna": "matstrupe",
    "matstruparnas": "matstrupe",
    "matstrupars": "matstrupe",
    "matstrupen": "matstrupe",
    "matstrupens": "matstrupe",
    "matstrupes": "matstrupe",
    "matstrups": "matstrupe",
    "matställen": "matställe",
    "matställena": "matställe",
    "matställenas": "matställe",
    "matställens": "matställe",
    "matställes": "matställe",
    "matstället": "matställe",
    "matställets": "matställe",
    "matsvampar": "matsvamp",
    "matsvamparna": "matsvamp",
    "matsvamparnas": "matsvamp",
    "matsvampars": "matsvamp",
    "matsvampen": "matsvamp",
    "matsvampens": "matsvamp",
    "matsvamps": "matsvamp",
    "matsäckar": "matsäck",
    "matsäckarna": "matsäck",
    "matsäckarnas": "matsäck",
    "matsäckars": "matsäck",
    "matsäcken": "matsäck",
    "matsäckens": "matsäck",
    "matsäcks": "matsäck",
    "matsäckssmörgåsar": "matsäckssmörgås",
    "matsäckssmörgåsarna": "matsäckssmörgås",
    "matsäckssmörgåsarnas": "matsäckssmörgås",
    "matsäckssmörgåsars": "matsäckssmörgås",
    "matsäckssmörgåsen": "matsäckssmörgås",
    "matsäckssmörgåsens": "matsäckssmörgås",
    "matsäcksväsk": "matsäcksväska",
    "matsäcksväskan": "matsäcksväska",
    "matsäcksväskans": "matsäcksväska",
    "matsäcksväskas": "matsäcksväska",
    "matsäcksväske": "matsäcksväska",
    "matsäcksväskor": "matsäcksväska",
    "matsäcksväskorna": "matsäcksväska",
    "matsäcksväskornas": "matsäcksväska",
    "matsäcksväskors": "matsäcksväska",
    "matt": "matte",
    "matta": "matt",
    "mattad": "matta",
    "mattade": "matta",
    "mattades": "mattas",
    "mattads": "matta",
    "mattallrikar": "mattallrik",
    "mattallrikarna": "mattallrik",
    "mattallrikarnas": "mattallrik",
    "mattallrikars": "mattallrik",
    "mattallriken": "mattallrik",
    "mattallrikens": "mattallrik",
    "mattallriks": "mattallrik",
    "mattan": "matta",
    "mattande": "matta",
    "mattanden": "mattande",
    "mattandena": "mattande",
    "mattandenas": "mattande",
    "mattandens": "mattande",
    "mattandes": "mattande",
    "mattandet": "mattande",
    "mattandets": "mattande",
    "mattans": "matta",
    "mattar": "matte",
    "mattare": "matt",
    "mattares": "matt",
    "mattarna": "matte",
    "mattarnas": "matte",
    "mattars": "matte",
    "mattas": "matta",
    "mattast": "matt",
    "mattaste": "matt",
    "mattastes": "matt",
    "mattasts": "matt",
    "mattat": "matta",
    "mattats": "mattas",
    "mattdomar": "mattdomare",
    "mattdomaren": "mattdomare",
    "mattdomarens": "mattdomare",
    "mattdomares": "mattdomare",
    "mattdomarna": "mattdomare",
    "mattdomarnas": "mattdomare",
    "matte": "matta",
    "mattejpen": "mattejp",
    "mattejpens": "mattejp",
    "mattejps": "mattejp",
    "matten": "matte",
    "mattens": "matte",
    "matteproven": "matteprov",
    "matteprovens": "matteprov",
    "matteprovet": "matteprov",
    "matteprovets": "matteprov",
    "matteprovs": "matteprov",
    "matterad": "mattera",
    "matterade": "mattera",
    "matterades": "mattera",
    "matterads": "mattera",
    "matterande": "mattera",
    "matteranden": "matterande",
    "matterandena": "matterande",
    "matterandenas": "matterande",
    "matterandens": "matterande",
    "matterandes": "matterande",
    "matterandet": "matterande",
    "matterandets": "matterande",
    "matterar": "mattera",
    "matteras": "mattera",
    "matterat": "mattera",
    "matterats": "mattera",
    "matterbara": "matterbar",
    "matterbarare": "matterbar",
    "matterbarares": "matterbar",
    "matterbaras": "matterbar",
    "matterbarast": "matterbar",
    "matterbaraste": "matterbar",
    "matterbarastes": "matterbar",
    "matterbarasts": "matterbar",
    "matterbare": "matterbar",
    "matterbares": "matterbar",
    "matterbarheten": "matterbarhet",
    "matterbarhetens": "matterbarhet",
    "matterbarhets": "matterbarhet",
    "matterbars": "matterbar",
    "matterbart": "matterbar",
    "matterbarts": "matterbar",
    "matteringar": "mattering",
    "matteringarna": "mattering",
    "matteringarnas": "mattering",
    "matteringars": "mattering",
    "matteringen": "mattering",
    "matteringens": "mattering",
    "matterings": "mattering",
    "mattes": "matte",
    "mattesnillen": "mattesnille",
    "mattesnillena": "mattesnille",
    "mattesnillenas": "mattesnille",
    "mattesnillens": "mattesnille",
    "mattesnilles": "mattesnille",
    "mattesnillet": "mattesnille",
    "mattesnillets": "mattesnille",
    "mattet": "matte",
    "mattets": "matte",
    "mattheten": "matthet",
    "matthetens": "matthet",
    "mattheter": "matthet",
    "mattheterna": "matthet",
    "mattheternas": "matthet",
    "mattheters": "matthet",
    "matthets": "matthet",
    "mattigheten": "mattighet",
    "mattighetens": "mattighet",
    "mattigheter": "mattighet",
    "mattigheterna": "mattighet",
    "mattigheternas": "mattighet",
    "mattigheters": "mattighet",
    "mattighets": "mattighet",
    "mattor": "matta",
    "mattorna": "matta",
    "mattornas": "matta",
    "mattors": "matta",
    "mattpiskar": "mattpiskare",
    "mattpiskaren": "mattpiskare",
    "mattpiskarens": "mattpiskare",
    "mattpiskares": "mattpiskare",
    "mattpiskarna": "mattpiskare",
    "mattpiskarnas": "mattpiskare",
    "mattpiskningar": "mattpiskning",
    "mattpiskningarna": "mattpiskning",
    "mattpiskningarnas": "mattpiskning",
    "mattpiskningars": "mattpiskning",
    "mattpiskningen": "mattpiskning",
    "mattpiskningens": "mattpiskning",
    "mattpisknings": "mattpiskning",
    "mattramen": "mattram",
    "mattramens": "mattram",
    "mattrams": "mattram",
    "matts": "matte",
    "mattskivan": "mattskiva",
    "mattskivans": "mattskiva",
    "mattskivas": "mattskiva",
    "mattskive": "mattskiva",
    "mattskivor": "mattskiva",
    "mattskivorna": "mattskiva",
    "mattskivornas": "mattskiva",
    "mattskivors": "mattskiva",
    "mattslipade": "mattslipad",
    "mattslipades": "mattslipad",
    "mattslipads": "mattslipad",
    "mattslipat": "mattslipad",
    "mattslipats": "mattslipad",
    "mattsopar": "mattsopare",
    "mattsoparen": "mattsopare",
    "mattsoparens": "mattsopare",
    "mattsopares": "mattsopare",
    "mattsoparna": "mattsopare",
    "mattsoparnas": "mattsopare",
    "mattsvarta": "mattsvart",
    "mattsvartas": "mattsvart",
    "mattsvarte": "mattsvart",
    "mattsvartes": "mattsvart",
    "mattsvarts": "mattsvart",
    "mattvävar": "mattvävare",
    "mattvävaren": "mattvävare",
    "mattvävarens": "mattvävare",
    "mattvävares": "mattvävare",
    "mattvävarna": "mattvävare",
    "mattvävarnas": "mattvävare",
    "matutinen": "matutin",
    "matutinens": "matutin",
    "matutiner": "matutin",
    "matutinerna": "matutin",
    "matutinernas": "matutin",
    "matutiners": "matutin",
    "matutins": "matutin",
    "matvanan": "matvana",
    "matvanans": "matvana",
    "matvanas": "matvana",
    "matvane": "matvana",
    "matvanor": "matvana",
    "matvanorna": "matvana",
    "matvanornas": "matvana",
    "matvanors": "matvana",
    "matvar": "matvara",
    "matvaran": "matvara",
    "matvarans": "matvara",
    "matvaras": "matvara",
    "matvaror": "matvara",
    "matvarorna": "matvara",
    "matvarornas": "matvara",
    "matvarors": "matvara",
    "matvaru": "matvara",
    "matvaruaffären": "matvaruaffär",
    "matvaruaffärens": "matvaruaffär",
    "matvaruaffärer": "matvaruaffär",
    "matvaruaffärerna": "matvaruaffär",
    "matvaruaffärernas": "matvaruaffär",
    "matvaruaffärers": "matvaruaffär",
    "matvaruaffärs": "matvaruaffär",
    "matvaruhallar": "matvaruhall",
    "matvaruhallarna": "matvaruhall",
    "matvaruhallarnas": "matvaruhall",
    "matvaruhallars": "matvaruhall",
    "matvaruhallen": "matvaruhall",
    "matvaruhallens": "matvaruhall",
    "matvaruhalls": "matvaruhall",
    "matvraken": "matvrak",
    "matvrakens": "matvrak",
    "matvraket": "matvrak",
    "matvrakets": "matvrak",
    "matvraks": "matvrak",
    "matvrån": "matvrå",
    "matvråns": "matvrå",
    "matvrår": "matvrå",
    "matvrårna": "matvrå",
    "matvrårnas": "matvrå",
    "matvrårs": "matvrå",
    "matvrås": "matvrå",
    "matvägrade": "matvägra",
    "matvägrades": "matvägra",
    "matvägrande": "matvägra",
    "matvägranden": "matvägrande",
    "matvägrandena": "matvägrande",
    "matvägrandenas": "matvägrande",
    "matvägrandens": "matvägrande",
    "matvägrandes": "matvägrande",
    "matvägrandet": "matvägrande",
    "matvägrandets": "matvägrande",
    "matvägrar": "matvägra",
    "matvägras": "matvägra",
    "matvägrat": "matvägra",
    "matvägrats": "matvägra",
    "matäpplen": "matäpple",
    "matäpplena": "matäpple",
    "matäpplenas": "matäpple",
    "matäpplens": "matäpple",
    "matäpples": "matäpple",
    "matäpplet": "matäpple",
    "matäpplets": "matäpple",
    "matäppls": "matäpple",
    "matés": "maté",
    "matét": "maté",
    "matéts": "maté",
    "mauretaniern": "mauretanier",
    "mauretanierna": "mauretanier",
    "mauretaniernas": "mauretanier",
    "mauretanierns": "mauretanier",
    "mauretaniers": "mauretanier",
    "mauretanska": "mauretansk",
    "mauretanskan": "mauretanska",
    "mauretanskans": "mauretanska",
    "mauretanskare": "mauretansk",
    "mauretanskares": "mauretansk",
    "mauretanskas": "mauretanska",
    "mauretanskast": "mauretansk",
    "mauretanskaste": "mauretansk",
    "mauretanskastes": "mauretansk",
    "mauretanskasts": "mauretansk",
    "mauretanske": "mauretanska",
    "mauretanskes": "mauretansk",
    "mauretanskor": "mauretanska",
    "mauretanskorna": "mauretanska",
    "mauretanskornas": "mauretanska",
    "mauretanskors": "mauretanska",
    "mauretansks": "mauretansk",
    "mauretanskt": "mauretansk",
    "mauretanskts": "mauretansk",
    "mauritiern": "mauritier",
    "mauritierna": "mauritier",
    "mauritiernas": "mauritier",
    "mauritierns": "mauritier",
    "mauritiers": "mauritier",
    "mauritiska": "mauritisk",
    "mauritiskan": "mauritiska",
    "mauritiskans": "mauritiska",
    "mauritiskare": "mauritisk",
    "mauritiskares": "mauritisk",
    "mauritiskas": "mauritiska",
    "mauritiskast": "mauritisk",
    "mauritiskaste": "mauritisk",
    "mauritiskastes": "mauritisk",
    "mauritiskasts": "mauritisk",
    "mauritiske": "mauritiska",
    "mauritiskes": "mauritisk",
    "mauritiskor": "mauritiska",
    "mauritiskorna": "mauritiska",
    "mauritiskornas": "mauritiska",
    "mauritiskors": "mauritiska",
    "mauritisks": "mauritisk",
    "mauritiskt": "mauritisk",
    "mauritiskts": "mauritisk",
    "mausergevären": "mausergevär",
    "mausergevärens": "mausergevär",
    "mausergeväret": "mausergevär",
    "mausergevärets": "mausergevär",
    "mausergevärs": "mausergevär",
    "mausern": "mauser",
    "mauserna": "mauser",
    "mausernas": "mauser",
    "mauserns": "mauser",
    "mauserpistolen": "mauserpistol",
    "mauserpistolens": "mauserpistol",
    "mauserpistoler": "mauserpistol",
    "mauserpistolerna": "mauserpistol",
    "mauserpistolernas": "mauserpistol",
    "mauserpistolers": "mauserpistol",
    "mauserpistols": "mauserpistol",
    "mausers": "mauser",
    "mausoleer": "mausoleum",
    "mausoleerna": "mausoleum",
    "mausoleernas": "mausoleum",
    "mausoleers": "mausoleum",
    "mausoleet": "mausoleum",
    "mausoleets": "mausoleum",
    "mausolei": "mausoleum",
    "mausoleums": "mausoleum",
    "maxad": "maxa",
    "maxade": "maxa",
    "maxades": "maxa",
    "maxads": "maxa",
    "maxande": "maxa",
    "maxanden": "maxande",
    "maxandena": "maxande",
    "maxandenas": "maxande",
    "maxandens": "maxande",
    "maxandes": "maxande",
    "maxandet": "maxande",
    "maxandets": "maxande",
    "maxar": "maxa",
    "maxas": "maxa",
    "maxat": "maxa",
    "maxats": "maxa",
    "maxet": "max",
    "maxets": "max",
    "maxfarten": "maxfart",
    "maxfartens": "maxfart",
    "maxfarter": "maxfart",
    "maxfarterna": "maxfart",
    "maxfarternas": "maxfart",
    "maxfarters": "maxfart",
    "maxfarts": "maxfart",
    "maxhastigheten": "maxhastighet",
    "maxhastighetens": "maxhastighet",
    "maxhastigheter": "maxhastighet",
    "maxhastigheterna": "maxhastighet",
    "maxhastigheternas": "maxhastighet",
    "maxhastigheters": "maxhastighet",
    "maxhastighets": "maxhastighet",
    "maxikjolar": "maxikjol",
    "maxikjolarna": "maxikjol",
    "maxikjolarnas": "maxikjol",
    "maxikjolars": "maxikjol",
    "maxikjolen": "maxikjol",
    "maxikjolens": "maxikjol",
    "maxikjols": "maxikjol",
    "maxillen": "maxill",
    "maxillens": "maxill",
    "maxiller": "maxill",
    "maxillerna": "maxill",
    "maxillernas": "maxill",
    "maxillers": "maxill",
    "maxills": "maxill",
    "maxilönen": "maxilön",
    "maxilönens": "maxilön",
    "maxilöner": "maxilön",
    "maxilönerna": "maxilön",
    "maxilönernas": "maxilön",
    "maxilöners": "maxilön",
    "maxilöns": "maxilön",
    "maxima": "maximum",
    "maximala": "maximal",
    "maximalare": "maximal",
    "maximalares": "maximal",
    "maximalas": "maximal",
    "maximalast": "maximal",
    "maximalaste": "maximal",
    "maximalastes": "maximal",
    "maximalasts": "maximal",
    "maximale": "maximal",
    "maximales": "maximal",
    "maximals": "maximal",
    "maximalt": "maximal",
    "maximalts": "maximal",
    "maximana": "maximum",
    "maximanas": "maximum",
    "maximas": "maximum",
    "maximen": "maxim",
    "maximens": "maxim",
    "maximer": "maxim",
    "maximerad": "maximera",
    "maximerade": "maximera",
    "maximerades": "maximera",
    "maximerads": "maximera",
    "maximerande": "maximera",
    "maximeranden": "maximerande",
    "maximerandena": "maximerande",
    "maximerandenas": "maximerande",
    "maximerandens": "maximerande",
    "maximerandes": "maximerande",
    "maximerandet": "maximerande",
    "maximerandets": "maximerande",
    "maximerar": "maximera",
    "maximeras": "maximera",
    "maximerat": "maximera",
    "maximerats": "maximera",
    "maximerbara": "maximerbar",
    "maximerbarare": "maximerbar",
    "maximerbarares": "maximerbar",
    "maximerbaras": "maximerbar",
    "maximerbarast": "maximerbar",
    "maximerbaraste": "maximerbar",
    "maximerbarastes": "maximerbar",
    "maximerbarasts": "maximerbar",
    "maximerbare": "maximerbar",
    "maximerbares": "maximerbar",
    "maximerbarheten": "maximerbarhet",
    "maximerbarhetens": "maximerbarhet",
    "maximerbarhets": "maximerbarhet",
    "maximerbars": "maximerbar",
    "maximerbart": "maximerbar",
    "maximerbarts": "maximerbar",
    "maximeringar": "maximering",
    "maximeringarna": "maximering",
    "maximeringarnas": "maximering",
    "maximeringars": "maximering",
    "maximeringen": "maximering",
    "maximeringens": "maximering",
    "maximerings": "maximering",
    "maximerna": "maxim",
    "maximernas": "maxim",
    "maximers": "maxim",
    "maximet": "maximum",
    "maximets": "maximum",
    "maximipunkten": "maximipunkt",
    "maximipunktens": "maximipunkt",
    "maximipunkter": "maximipunkt",
    "maximipunkterna": "maximipunkt",
    "maximipunkternas": "maximipunkt",
    "maximipunkters": "maximipunkt",
    "maximipunkts": "maximipunkt",
    "maximitemperaturen": "maximitemperatur",
    "maximitemperaturens": "maximitemperatur",
    "maximitemperaturer": "maximitemperatur",
    "maximitemperaturerna": "maximitemperatur",
    "maximitemperaturernas": "maximitemperatur",
    "maximitemperaturers": "maximitemperatur",
    "maximitemperaturs": "maximitemperatur",
    "maximitermometern": "maximitermometer",
    "maximitermometerns": "maximitermometer",
    "maximitermometers": "maximitermometer",
    "maximitermometrar": "maximitermometer",
    "maximitermometrarna": "maximitermometer",
    "maximitermometrarnas": "maximitermometer",
    "maximitermometrars": "maximitermometer",
    "maxims": "maxim",
    "maximumen": "maximum",
    "maximumens": "maximum",
    "maximumet": "maximum",
    "maximumets": "maximum",
    "maximums": "maximum",
    "maxirollern": "maxiroller",
    "maxirollerns": "maxiroller",
    "maxirollers": "maxiroller",
    "maxirollersarna": "maxiroller",
    "maxirollersarnas": "maxiroller",
    "maxirollersen": "maxiroller",
    "maxirollersens": "maxiroller",
    "maxirollrar": "maxiroller",
    "maxirollrarna": "maxiroller",
    "maxirollrarnas": "maxiroller",
    "maxirollrars": "maxiroller",
    "maxlasten": "maxlast",
    "maxlastens": "maxlast",
    "maxlaster": "maxlast",
    "maxlasterna": "maxlast",
    "maxlasternas": "maxlast",
    "maxlasters": "maxlast",
    "maxlasts": "maxlast",
    "mayafolken": "mayafolk",
    "mayafolkens": "mayafolk",
    "mayafolket": "mayafolk",
    "mayafolkets": "mayafolk",
    "mayafolks": "mayafolk",
    "mazarinen": "mazarin",
    "mazarinens": "mazarin",
    "mazariner": "mazarin",
    "mazarinerna": "mazarin",
    "mazarinernas": "mazarin",
    "mazariners": "mazarin",
    "mazarins": "mazarin",
    "mazurk": "mazurka",
    "mazurkan": "mazurka",
    "mazurkans": "mazurka",
    "mazurkas": "mazurka",
    "mazurke": "mazurka",
    "mazurkor": "mazurka",
    "mazurkorna": "mazurka",
    "mazurkornas": "mazurka",
    "mazurkors": "mazurka",
    "mazurks": "mazurka",
    "mc-byx": "mc-byxa",
    "mc-byxan": "mc-byxa",
    "mc-byxans": "mc-byxa",
    "mc-byxas": "mc-byxa",
    "mc-byxe": "mc-byxa",
    "mc-byxor": "mc-byxa",
    "mc-byxorna": "mc-byxa",
    "mc-byxornas": "mc-byxa",
    "mc-byxors": "mc-byxa",
    "mc-lyftar": "mc-lyft",
    "mc-lyftarna": "mc-lyft",
    "mc-lyftarnas": "mc-lyft",
    "mc-lyftars": "mc-lyft",
    "mc-lyften": "mc-lyft",
    "mc-lyftens": "mc-lyft",
    "mc-lyfts": "mc-lyft",
    "mc-åkningen": "mc-åkning",
    "mc-åkningens": "mc-åkning",
    "mc-åknings": "mc-åkning",
    "mc:s": "mc",
    "meandern": "meander",
    "meanderns": "meander",
    "meanders": "meander",
    "meandrar": "meander",
    "meandrarna": "meander",
    "meandrarnas": "meander",
    "meandrars": "meander",
    "meccanon": "meccano",
    "meccanona": "meccano",
    "meccanonas": "meccano",
    "meccanons": "meccano",
    "meccanos": "meccano",
    "meccanot": "meccano",
    "meccanots": "meccano",
    "mecenaten": "mecenat",
    "mecenatens": "mecenat",
    "mecenater": "mecenat",
    "mecenaterna": "mecenat",
    "mecenaternas": "mecenat",
    "mecenaters": "mecenat",
    "mecenats": "mecenat",
    "meck": "mecka",
    "meckade": "mecka",
    "meckades": "mecka",
    "meckan": "mecka",
    "meckana": "mecka",
    "meckanas": "mecka",
    "meckande": "mecka",
    "meckanden": "meckande",
    "meckandena": "meckande",
    "meckandenas": "meckande",
    "meckandens": "meckande",
    "meckandes": "meckande",
    "meckandet": "meckande",
    "meckandets": "meckande",
    "meckans": "mecka",
    "meckar": "mecka",
    "meckas": "mecka",
    "meckat": "mecka",
    "meckats": "mecka",
    "meckel": "meckla",
    "mecklade": "meckla",
    "mecklades": "meckla",
    "mecklande": "meckla",
    "mecklanden": "mecklande",
    "mecklandena": "mecklande",
    "mecklandenas": "mecklande",
    "mecklandens": "mecklande",
    "mecklandes": "mecklande",
    "mecklandet": "mecklande",
    "mecklandets": "mecklande",
    "mecklar": "meckla",
    "mecklas": "meckla",
    "mecklat": "meckla",
    "mecklats": "meckla",
    "med": "mede",
    "medaljceremonien": "medaljceremoni",
    "medaljceremoniens": "medaljceremoni",
    "medaljceremonier": "medaljceremoni",
    "medaljceremonierna": "medaljceremoni",
    "medaljceremoniernas": "medaljceremoni",
    "medaljceremoniers": "medaljceremoni",
    "medaljceremonin": "medaljceremoni",
    "medaljceremonins": "medaljceremoni",
    "medaljceremonis": "medaljceremoni",
    "medaljen": "medalj",
    "medaljens": "medalj",
    "medaljer": "medalj",
    "medaljerad": "medaljera",
    "medaljerade": "medaljera",
    "medaljerades": "medaljera",
    "medaljerads": "medaljera",
    "medaljerande": "medaljera",
    "medaljeranden": "medaljerande",
    "medaljerandena": "medaljerande",
    "medaljerandenas": "medaljerande",
    "medaljerandens": "medaljerande",
    "medaljerandes": "medaljerande",
    "medaljerandet": "medaljerande",
    "medaljerandets": "medaljerande",
    "medaljerar": "medaljera",
    "medaljeras": "medaljera",
    "medaljerat": "medaljera",
    "medaljerats": "medaljera",
    "medaljerbara": "medaljerbar",
    "medaljerbarare": "medaljerbar",
    "medaljerbarares": "medaljerbar",
    "medaljerbaras": "medaljerbar",
    "medaljerbarast": "medaljerbar",
    "medaljerbaraste": "medaljerbar",
    "medaljerbarastes": "medaljerbar",
    "medaljerbarasts": "medaljerbar",
    "medaljerbare": "medaljerbar",
    "medaljerbares": "medaljerbar",
    "medaljerbarheten": "medaljerbarhet",
    "medaljerbarhetens": "medaljerbarhet",
    "medaljerbarhets": "medaljerbarhet",
    "medaljerbars": "medaljerbar",
    "medaljerbart": "medaljerbar",
    "medaljerbarts": "medaljerbar",
    "medaljeringar": "medaljering",
    "medaljeringarna": "medaljering",
    "medaljeringarnas": "medaljering",
    "medaljeringars": "medaljering",
    "medaljeringen": "medaljering",
    "medaljeringens": "medaljering",
    "medaljerings": "medaljering",
    "medaljerna": "medalj",
    "medaljernas": "medalj",
    "medaljers": "medalj",
    "medaljmässiga": "medaljmässig",
    "medaljmässigare": "medaljmässig",
    "medaljmässigares": "medaljmässig",
    "medaljmässigas": "medaljmässig",
    "medaljmässigast": "medaljmässig",
    "medaljmässigaste": "medaljmässig",
    "medaljmässigastes": "medaljmässig",
    "medaljmässigasts": "medaljmässig",
    "medaljmässige": "medaljmässig",
    "medaljmässiges": "medaljmässig",
    "medaljmässigs": "medaljmässig",
    "medaljmässigt": "medaljmässig",
    "medaljmässigts": "medaljmässig",
    "medaljongen": "medaljong",
    "medaljongens": "medaljong",
    "medaljonger": "medaljong",
    "medaljongerna": "medaljong",
    "medaljongernas": "medaljong",
    "medaljongers": "medaljong",
    "medaljongs": "medaljong",
    "medaljongtrycken": "medaljongtryck",
    "medaljongtryckens": "medaljongtryck",
    "medaljongtrycket": "medaljongtryck",
    "medaljongtryckets": "medaljongtryck",
    "medaljongtrycks": "medaljongtryck",
    "medaljs": "medalj",
    "medaljutdelningar": "medaljutdelning",
    "medaljutdelningarna": "medaljutdelning",
    "medaljutdelningarnas": "medaljutdelning",
    "medaljutdelningars": "medaljutdelning",
    "medaljutdelningen": "medaljutdelning",
    "medaljutdelningens": "medaljutdelning",
    "medaljutdelnings": "medaljutdelning",
    "medaljören": "medaljör",
    "medaljörens": "medaljör",
    "medaljörer": "medaljör",
    "medaljörerna": "medaljör",
    "medaljörernas": "medaljör",
    "medaljörers": "medaljör",
    "medaljörs": "medaljör",
    "medansvaret": "medansvar",
    "medansvarets": "medansvar",
    "medansvariga": "medansvarig",
    "medansvarigare": "medansvarig",
    "medansvarigares": "medansvarig",
    "medansvarigas": "medansvarig",
    "medansvarigast": "medansvarig",
    "medansvarigaste": "medansvarig",
    "medansvarigastes": "medansvarig",
    "medansvarigasts": "medansvarig",
    "medansvarige": "medansvarig",
    "medansvariges": "medansvarig",
    "medansvarigheten": "medansvarighet",
    "medansvarighetens": "medansvarighet",
    "medansvarighets": "medansvarighet",
    "medansvarigs": "medansvarig",
    "medansvarigt": "medansvarig",
    "medansvarigts": "medansvarig",
    "medansvars": "medansvar",
    "medar": "mede",
    "medarbetade": "medarbeta",
    "medarbetades": "medarbeta",
    "medarbetande": "medarbeta",
    "medarbetanden": "medarbetande",
    "medarbetandena": "medarbetande",
    "medarbetandenas": "medarbetande",
    "medarbetandens": "medarbetande",
    "medarbetandes": "medarbetande",
    "medarbetandet": "medarbetande",
    "medarbetandets": "medarbetande",
    "medarbetar": "medarbetare",
    "medarbetaren": "medarbetare",
    "medarbetarens": "medarbetare",
    "medarbetares": "medarbetare",
    "medarbetarna": "medarbetare",
    "medarbetarnas": "medarbetare",
    "medarbetas": "medarbeta",
    "medarbetat": "medarbeta",
    "medarbetats": "medarbeta",
    "medarna": "mede",
    "medarnas": "mede",
    "medars": "mede",
    "medbedömar": "medbedömare",
    "medbedömaren": "medbedömare",
    "medbedömarens": "medbedömare",
    "medbedömares": "medbedömare",
    "medbedömarna": "medbedömare",
    "medbedömarnas": "medbedömare",
    "medbestämmandelagar": "medbestämmandelag",
    "medbestämmandelagarna": "medbestämmandelag",
    "medbestämmandelagarnas": "medbestämmandelag",
    "medbestämmandelagars": "medbestämmandelag",
    "medbestämmandelagen": "medbestämmandelag",
    "medbestämmandelagens": "medbestämmandelag",
    "medbestämmandelags": "medbestämmandelag",
    "medbestämmandes": "medbestämmande",
    "medbestämmandet": "medbestämmande",
    "medbestämmandets": "medbestämmande",
    "medborgar": "medborgare",
    "medborgarandan": "medborgaranda",
    "medborgarandans": "medborgaranda",
    "medborgarandas": "medborgaranda",
    "medborgaren": "medborgare",
    "medborgarens": "medborgare",
    "medborgares": "medborgare",
    "medborgargarden": "medborgargarde",
    "medborgargardena": "medborgargarde",
    "medborgargardenas": "medborgargarde",
    "medborgargardens": "medborgargarde",
    "medborgargardes": "medborgargarde",
    "medborgargardet": "medborgargarde",
    "medborgargardets": "medborgargarde",
    "medborgarhusen": "medborgarhus",
    "medborgarhusens": "medborgarhus",
    "medborgarhuset": "medborgarhus",
    "medborgarhusets": "medborgarhus",
    "medborgarinflytanden": "medborgarinflytande",
    "medborgarinflytandena": "medborgarinflytande",
    "medborgarinflytandenas": "medborgarinflytande",
    "medborgarinflytandens": "medborgarinflytande",
    "medborgarinflytandes": "medborgarinflytande",
    "medborgarinflytandet": "medborgarinflytande",
    "medborgarinflytandets": "medborgarinflytande",
    "medborgarinitierade": "medborgarinitierad",
    "medborgarinitierades": "medborgarinitierad",
    "medborgarinitierads": "medborgarinitierad",
    "medborgarinitierat": "medborgarinitierad",
    "medborgarinitierats": "medborgarinitierad",
    "medborgarna": "medborgare",
    "medborgarnas": "medborgare",
    "medborgarrätten": "medborgarrätt",
    "medborgarrättens": "medborgarrätt",
    "medborgarrätts": "medborgarrätt",
    "medborgarsinnes": "medborgarsinne",
    "medborgarsinnet": "medborgarsinne",
    "medborgarsinnets": "medborgarsinne",
    "medborgarskapen": "medborgarskap",
    "medborgarskapens": "medborgarskap",
    "medborgarskapet": "medborgarskap",
    "medborgarskapets": "medborgarskap",
    "medborgarskaps": "medborgarskap",
    "medborgarvittnen": "medborgarvittne",
    "medborgarvittnena": "medborgarvittne",
    "medborgarvittnenas": "medborgarvittne",
    "medborgarvittnens": "medborgarvittne",
    "medborgarvittnes": "medborgarvittne",
    "medborgarvittnet": "medborgarvittne",
    "medborgarvittnets": "medborgarvittne",
    "medborgenären": "medborgenär",
    "medborgenärens": "medborgenär",
    "medborgenärer": "medborgenär",
    "medborgenärerna": "medborgenär",
    "medborgenärernas": "medborgenär",
    "medborgenärers": "medborgenär",
    "medborgenärs": "medborgenär",
    "medborgerliga": "medborgerlig",
    "medborgerligare": "medborgerlig",
    "medborgerligares": "medborgerlig",
    "medborgerligas": "medborgerlig",
    "medborgerligast": "medborgerlig",
    "medborgerligaste": "medborgerlig",
    "medborgerligastes": "medborgerlig",
    "medborgerligasts": "medborgerlig",
    "medborgerlige": "medborgerlig",
    "medborgerliges": "medborgerlig",
    "medborgerligheten": "medborgerlighet",
    "medborgerlighetens": "medborgerlighet",
    "medborgerlighets": "medborgerlighet",
    "medborgerligs": "medborgerlig",
    "medborgerligt": "medborgerlig",
    "medborgerligts": "medborgerlig",
    "medbragt": "medbringa",
    "medbragte": "medbringa",
    "medbragtes": "medbringa",
    "medbragts": "medbringa",
    "medbring": "medbringa",
    "medbringad": "medbringa",
    "medbringade": "medbringa",
    "medbringades": "medbringa",
    "medbringads": "medbringa",
    "medbringande": "medbringa",
    "medbringanden": "medbringande",
    "medbringandena": "medbringande",
    "medbringandenas": "medbringande",
    "medbringandens": "medbringande",
    "medbringandes": "medbringande",
    "medbringandet": "medbringande",
    "medbringandets": "medbringande",
    "medbringar": "medbringare",
    "medbringaren": "medbringare",
    "medbringarens": "medbringare",
    "medbringares": "medbringare",
    "medbringarna": "medbringare",
    "medbringarnas": "medbringare",
    "medbringas": "medbringa",
    "medbringat": "medbringa",
    "medbringats": "medbringa",
    "medbrodern": "medbroder",
    "medbroderns": "medbroder",
    "medbroders": "medbroder",
    "medbrottsliga": "medbrottslig",
    "medbrottsligare": "medbrottslig",
    "medbrottsligares": "medbrottslig",
    "medbrottsligas": "medbrottslig",
    "medbrottsligast": "medbrottslig",
    "medbrottsligaste": "medbrottslig",
    "medbrottsligastes": "medbrottslig",
    "medbrottsligasts": "medbrottslig",
    "medbrottslige": "medbrottslig",
    "medbrottsliges": "medbrottslig",
    "medbrottsligheten": "medbrottslighet",
    "medbrottslighetens": "medbrottslighet",
    "medbrottslighets": "medbrottslighet",
    "medbrottsligs": "medbrottslig",
    "medbrottsligt": "medbrottslig",
    "medbrottsligts": "medbrottslig",
    "medbrottslingar": "medbrottsling",
    "medbrottslingarna": "medbrottsling",
    "medbrottslingarnas": "medbrottsling",
    "medbrottslingars": "medbrottsling",
    "medbrottslingen": "medbrottsling",
    "medbrottslingens": "medbrottsling",
    "medbrottslings": "medbrottsling",
    "medbröder": "medbroder",
    "medbröderna": "medbroder",
    "medbrödernas": "medbroder",
    "medbröders": "medbroder",
    "meddelade": "meddela",
    "meddelades": "meddela",
    "meddelaktiga": "meddelaktig",
    "meddelaktigare": "meddelaktig",
    "meddelaktigares": "meddelaktig",
    "meddelaktigas": "meddelaktig",
    "meddelaktigast": "meddelaktig",
    "meddelaktigaste": "meddelaktig",
    "meddelaktigastes": "meddelaktig",
    "meddelaktigasts": "meddelaktig",
    "meddelaktige": "meddelaktig",
    "meddelaktiges": "meddelaktig",
    "meddelaktigheten": "meddelaktighet",
    "meddelaktighetens": "meddelaktighet",
    "meddelaktighets": "meddelaktighet",
    "meddelaktigs": "meddelaktig",
    "meddelaktigt": "meddelaktig",
    "meddelaktigts": "meddelaktig",
    "meddelande": "meddela",
    "meddelanden": "meddelande",
    "meddelandena": "meddelande",
    "meddelandenas": "meddelande",
    "meddelandens": "meddelande",
    "meddelandes": "meddelande",
    "meddelandet": "meddelande",
    "meddelandets": "meddelande",
    "meddelar": "meddelare",
    "meddelaren": "meddelare",
    "meddelarens": "meddelare",
    "meddelares": "meddelare",
    "meddelarna": "meddelare",
    "meddelarnas": "meddelare",
    "meddelas": "meddela",
    "meddelat": "meddela",
    "meddelats": "meddela",
    "meddelelsemedels": "meddelelsemedel",
    "meddelelsemedlen": "meddelelsemedel",
    "meddelelsemedlens": "meddelelsemedel",
    "meddelelsemedlet": "meddelelsemedel",
    "meddelelsemedlets": "meddelelsemedel",
    "meddelelsen": "meddelelse",
    "meddelelsens": "meddelelse",
    "meddelelses": "meddelelse",
    "meddelsamheten": "meddelsamhet",
    "meddelsamhetens": "meddelsamhet",
    "meddelsamhets": "meddelsamhet",
    "meddelsamma": "meddelsam",
    "meddelsammare": "meddelsam",
    "meddelsammares": "meddelsam",
    "meddelsammas": "meddelsam",
    "meddelsammast": "meddelsam",
    "meddelsammaste": "meddelsam",
    "meddelsammastes": "meddelsam",
    "meddelsammasts": "meddelsam",
    "meddelsamme": "meddelsam",
    "meddelsammes": "meddelsam",
    "meddelsams": "meddelsam",
    "meddelsamt": "meddelsam",
    "meddelsamts": "meddelsam",
    "medelbara": "medelbar",
    "medelbarare": "medelbar",
    "medelbarares": "medelbar",
    "medelbaras": "medelbar",
    "medelbarast": "medelbar",
    "medelbaraste": "medelbar",
    "medelbarastes": "medelbar",
    "medelbarasts": "medelbar",
    "medelbare": "medelbar",
    "medelbares": "medelbar",
    "medelbarheten": "medelbarhet",
    "medelbarhetens": "medelbarhet",
    "medelbarhets": "medelbarhet",
    "medelbars": "medelbar",
    "medelbart": "medelbar",
    "medelbarts": "medelbar",
    "medeldistansen": "medeldistans",
    "medeldistansens": "medeldistans",
    "medeldistanser": "medeldistans",
    "medeldistanserna": "medeldistans",
    "medeldistansernas": "medeldistans",
    "medeldistansers": "medeldistans",
    "medeldistansraketen": "medeldistansraket",
    "medeldistansraketens": "medeldistansraket",
    "medeldistansraketer": "medeldistansraket",
    "medeldistansraketerna": "medeldistansraket",
    "medeldistansraketernas": "medeldistansraket",
    "medeldistansraketers": "medeldistansraket",
    "medeldistansrakets": "medeldistansraket",
    "medeldistansrobotar": "medeldistansrobot",
    "medeldistansrobotarna": "medeldistansrobot",
    "medeldistansrobotarnas": "medeldistansrobot",
    "medeldistansrobotars": "medeldistansrobot",
    "medeldistansroboten": "medeldistansrobot",
    "medeldistansrobotens": "medeldistansrobot",
    "medeldistansrobots": "medeldistansrobot",
    "medelfelen": "medelfel",
    "medelfelens": "medelfel",
    "medelfelet": "medelfel",
    "medelfelets": "medelfel",
    "medelfels": "medelfel",
    "medelgrova": "medelgrov",
    "medelgrovas": "medelgrov",
    "medelgrove": "medelgrov",
    "medelgroves": "medelgrov",
    "medelgrovs": "medelgrov",
    "medelgrovt": "medelgrov",
    "medelgrovts": "medelgrov",
    "medelhöga": "medelhög",
    "medelhögas": "medelhög",
    "medelhöge": "medelhög",
    "medelhöges": "medelhög",
    "medelhögs": "medelhög",
    "medelhögt": "medelhög",
    "medelhögts": "medelhög",
    "medelindiska": "medelindisk",
    "medelindiskare": "medelindisk",
    "medelindiskares": "medelindisk",
    "medelindiskas": "medelindisk",
    "medelindiskast": "medelindisk",
    "medelindiskaste": "medelindisk",
    "medelindiskastes": "medelindisk",
    "medelindiskasts": "medelindisk",
    "medelindiske": "medelindisk",
    "medelindiskes": "medelindisk",
    "medelindisks": "medelindisk",
    "medelindiskt": "medelindisk",
    "medelindiskts": "medelindisk",
    "medelinkomsten": "medelinkomst",
    "medelinkomstens": "medelinkomst",
    "medelinkomster": "medelinkomst",
    "medelinkomsterna": "medelinkomst",
    "medelinkomsternas": "medelinkomst",
    "medelinkomsters": "medelinkomst",
    "medelinkomsts": "medelinkomst",
    "medelinkomsttagar": "medelinkomsttagare",
    "medelinkomsttagaren": "medelinkomsttagare",
    "medelinkomsttagarens": "medelinkomsttagare",
    "medelinkomsttagares": "medelinkomsttagare",
    "medelinkomsttagarna": "medelinkomsttagare",
    "medelinkomsttagarnas": "medelinkomsttagare",
    "medelklassen": "medelklass",
    "medelklassens": "medelklass",
    "medelklasser": "medelklass",
    "medelklasserna": "medelklass",
    "medelklassernas": "medelklass",
    "medelklassers": "medelklass",
    "medelklassfördomar": "medelklassfördom",
    "medelklassfördomarna": "medelklassfördom",
    "medelklassfördomarnas": "medelklassfördom",
    "medelklassfördomars": "medelklassfördom",
    "medelklassfördomen": "medelklassfördom",
    "medelklassfördomens": "medelklassfördom",
    "medelklassfördoms": "medelklassfördom",
    "medelklassgetton": "medelklassgetto",
    "medelklassgettona": "medelklassgetto",
    "medelklassgettonas": "medelklassgetto",
    "medelklassgettons": "medelklassgetto",
    "medelklassgettos": "medelklassgetto",
    "medelklassgettot": "medelklassgetto",
    "medelklassgettots": "medelklassgetto",
    "medelklassghetton": "medelklassghetto",
    "medelklassghettona": "medelklassghetto",
    "medelklassghettonas": "medelklassghetto",
    "medelklassghettons": "medelklassghetto",
    "medelklassghettos": "medelklassghetto",
    "medelklassghettot": "medelklassghetto",
    "medelklassghettots": "medelklassghetto",
    "medellivslängden": "medellivslängd",
    "medellivslängdens": "medellivslängd",
    "medellivslängder": "medellivslängd",
    "medellivslängderna": "medellivslängd",
    "medellivslängdernas": "medellivslängd",
    "medellivslängders": "medellivslängd",
    "medellivslängds": "medellivslängd",
    "medellängden": "medellängd",
    "medellängdens": "medellängd",
    "medellängder": "medellängd",
    "medellängderna": "medellängd",
    "medellängdernas": "medellängd",
    "medellängders": "medellängd",
    "medellängds": "medellängd",
    "medellösa": "medellös",
    "medellösare": "medellös",
    "medellösares": "medellös",
    "medellösas": "medellös",
    "medellösast": "medellös",
    "medellösaste": "medellös",
    "medellösastes": "medellös",
    "medellösasts": "medellös",
    "medellöse": "medellös",
    "medellöses": "medellös",
    "medellösheten": "medellöshet",
    "medellöshetens": "medellöshet",
    "medellöshets": "medellöshet",
    "medellöst": "medellös",
    "medellösts": "medellös",
    "medelmåttan": "medelmåtta",
    "medelmåttans": "medelmåtta",
    "medelmåttas": "medelmåtta",
    "medelmåtte": "medelmåtta",
    "medelmåttiga": "medelmåttig",
    "medelmåttigare": "medelmåttig",
    "medelmåttigares": "medelmåttig",
    "medelmåttigas": "medelmåttig",
    "medelmåttigast": "medelmåttig",
    "medelmåttigaste": "medelmåttig",
    "medelmåttigastes": "medelmåttig",
    "medelmåttigasts": "medelmåttig",
    "medelmåttige": "medelmåttig",
    "medelmåttiges": "medelmåttig",
    "medelmåttigheten": "medelmåttighet",
    "medelmåttighetens": "medelmåttighet",
    "medelmåttighets": "medelmåttighet",
    "medelmåttigs": "medelmåttig",
    "medelmåttigt": "medelmåttig",
    "medelmåttigts": "medelmåttig",
    "medelmåttor": "medelmåtta",
    "medelmåttorna": "medelmåtta",
    "medelmåttornas": "medelmåtta",
    "medelmåttors": "medelmåtta",
    "medelpadar": "medelpadare",
    "medelpadaren": "medelpadare",
    "medelpadarens": "medelpadare",
    "medelpadares": "medelpadare",
    "medelpadarna": "medelpadare",
    "medelpadarnas": "medelpadare",
    "medelpadsk": "medelpadska",
    "medelpadska": "medelpadsk",
    "medelpadskan": "medelpadska",
    "medelpadskans": "medelpadska",
    "medelpadskare": "medelpadsk",
    "medelpadskares": "medelpadsk",
    "medelpadskas": "medelpadska",
    "medelpadskast": "medelpadsk",
    "medelpadskaste": "medelpadsk",
    "medelpadskastes": "medelpadsk",
    "medelpadskasts": "medelpadsk",
    "medelpadske": "medelpadska",
    "medelpadskes": "medelpadsk",
    "medelpadskor": "medelpadska",
    "medelpadskorna": "medelpadska",
    "medelpadskornas": "medelpadska",
    "medelpadskors": "medelpadska",
    "medelpadsks": "medelpadsk",
    "medelpadskt": "medelpadsk",
    "medelpadskts": "medelpadsk",
    "medelproportionalen": "medelproportional",
    "medelproportionalens": "medelproportional",
    "medelproportionaler": "medelproportional",
    "medelproportionalerna": "medelproportional",
    "medelproportionalernas": "medelproportional",
    "medelproportionalers": "medelproportional",
    "medelproportionals": "medelproportional",
    "medelpunkten": "medelpunkt",
    "medelpunktens": "medelpunkt",
    "medelpunkter": "medelpunkt",
    "medelpunkterna": "medelpunkt",
    "medelpunkternas": "medelpunkt",
    "medelpunkters": "medelpunkt",
    "medelpunkts": "medelpunkt",
    "medels": "medel",
    "medelsanvisningar": "medelsanvisning",
    "medelsanvisningarna": "medelsanvisning",
    "medelsanvisningarnas": "medelsanvisning",
    "medelsanvisningars": "medelsanvisning",
    "medelsanvisningen": "medelsanvisning",
    "medelsanvisningens": "medelsanvisning",
    "medelsanvisnings": "medelsanvisning",
    "medelsolen": "medelsol",
    "medelsolens": "medelsol",
    "medelsols": "medelsol",
    "medelsoltiden": "medelsoltid",
    "medelsoltidens": "medelsoltid",
    "medelsoltider": "medelsoltid",
    "medelsoltiderna": "medelsoltid",
    "medelsoltidernas": "medelsoltid",
    "medelsoltiders": "medelsoltid",
    "medelsoltids": "medelsoltid",
    "medelstora": "medelstor",
    "medelstoras": "medelstor",
    "medelstore": "medelstor",
    "medelstores": "medelstor",
    "medelstors": "medelstor",
    "medelstort": "medelstor",
    "medelstorts": "medelstor",
    "medelsvenssonen": "medelsvensson",
    "medelsvenssonens": "medelsvensson",
    "medelsvenssons": "medelsvensson",
    "medelsvenssöner": "medelsvensson",
    "medelsvenssönerna": "medelsvensson",
    "medelsvenssönernas": "medelsvensson",
    "medelsvenssöners": "medelsvensson",
    "medeltalen": "medeltal",
    "medeltalens": "medeltal",
    "medeltalet": "medeltal",
    "medeltalets": "medeltal",
    "medeltals": "medeltal",
    "medeltemperaturen": "medeltemperatur",
    "medeltemperaturens": "medeltemperatur",
    "medeltemperaturer": "medeltemperatur",
    "medeltemperaturerna": "medeltemperatur",
    "medeltemperaturernas": "medeltemperatur",
    "medeltemperaturers": "medeltemperatur",
    "medeltemperaturs": "medeltemperatur",
    "medeltiden": "medeltid",
    "medeltidens": "medeltid",
    "medeltider": "medeltid",
    "medeltiderna": "medeltid",
    "medeltidernas": "medeltid",
    "medeltiders": "medeltid",
    "medeltids": "medeltid",
    "medeltidslatinet": "medeltidslatin",
    "medeltidslatinets": "medeltidslatin",
    "medeltidslatins": "medeltidslatin",
    "medeltidsmänniskan": "medeltidsmänniska",
    "medeltidsmänniskans": "medeltidsmänniska",
    "medeltidsmänniskas": "medeltidsmänniska",
    "medeltidsmännisko": "medeltidsmänniska",
    "medeltidsmänniskor": "medeltidsmänniska",
    "medeltidsmänniskorna": "medeltidsmänniska",
    "medeltidsmänniskornas": "medeltidsmänniska",
    "medeltidsmänniskors": "medeltidsmänniska",
    "medeltidsmässiga": "medeltidsmässig",
    "medeltidsmässigare": "medeltidsmässig",
    "medeltidsmässigares": "medeltidsmässig",
    "medeltidsmässigas": "medeltidsmässig",
    "medeltidsmässigast": "medeltidsmässig",
    "medeltidsmässigaste": "medeltidsmässig",
    "medeltidsmässigastes": "medeltidsmässig",
    "medeltidsmässigasts": "medeltidsmässig",
    "medeltidsmässige": "medeltidsmässig",
    "medeltidsmässiges": "medeltidsmässig",
    "medeltidsmässigs": "medeltidsmässig",
    "medeltidsmässigt": "medeltidsmässig",
    "medeltidsmässigts": "medeltidsmässig",
    "medeltidsmålningar": "medeltidsmålning",
    "medeltidsmålningarna": "medeltidsmålning",
    "medeltidsmålningarnas": "medeltidsmålning",
    "medeltidsmålningars": "medeltidsmålning",
    "medeltidsmålningen": "medeltidsmålning",
    "medeltidsmålningens": "medeltidsmålning",
    "medeltidsmålnings": "medeltidsmålning",
    "medeltidstänkar": "medeltidstänkare",
    "medeltidstänkaren": "medeltidstänkare",
    "medeltidstänkarens": "medeltidstänkare",
    "medeltidstänkares": "medeltidstänkare",
    "medeltidstänkarna": "medeltidstänkare",
    "medeltidstänkarnas": "medeltidstänkare",
    "medelvattenstånden": "medelvattenstånd",
    "medelvattenståndens": "medelvattenstånd",
    "medelvattenståndet": "medelvattenstånd",
    "medelvattenståndets": "medelvattenstånd",
    "medelvattenstånds": "medelvattenstånd",
    "medelvägar": "medelväg",
    "medelvägarna": "medelväg",
    "medelvägarnas": "medelväg",
    "medelvägars": "medelväg",
    "medelvägen": "medelväg",
    "medelvägens": "medelväg",
    "medelvägs": "medelväg",
    "medelvärden": "medelvärde",
    "medelvärdena": "medelvärde",
    "medelvärdenas": "medelvärde",
    "medelvärdens": "medelvärde",
    "medelvärdes": "medelvärde",
    "medelvärdet": "medelvärde",
    "medelvärdets": "medelvärde",
    "medelåldern": "medelålder",
    "medelålderns": "medelålder",
    "medelålders": "medelålder",
    "medelålderskrisen": "medelålderskris",
    "medelålderskrisens": "medelålderskris",
    "medelålderskriser": "medelålderskris",
    "medelålderskriserna": "medelålderskris",
    "medelålderskrisernas": "medelålderskris",
    "medelålderskrisers": "medelålderskris",
    "medelåldrar": "medelålder",
    "medelåldrarna": "medelålder",
    "medelåldrarnas": "medelålder",
    "medelåldrars": "medelålder",
    "meden": "mede",
    "medens": "mede",
    "medes": "mede",
    "medfarenheten": "medfarenhet",
    "medfarenhetens": "medfarenhet",
    "medfarenhets": "medfarenhet",
    "medfarens": "medfaren",
    "medfaret": "medfaren",
    "medfarets": "medfaren",
    "medfarna": "medfaren",
    "medfarnare": "medfaren",
    "medfarnares": "medfaren",
    "medfarnas": "medfaren",
    "medfarnast": "medfaren",
    "medfarnaste": "medfaren",
    "medfarnastes": "medfaren",
    "medfarnasts": "medfaren",
    "medfarne": "medfaren",
    "medfarnes": "medfaren",
    "medfinansiären": "medfinansiär",
    "medfinansiärens": "medfinansiär",
    "medfinansiärer": "medfinansiär",
    "medfinansiärerna": "medfinansiär",
    "medfinansiärernas": "medfinansiär",
    "medfinansiärers": "medfinansiär",
    "medfinansiärs": "medfinansiär",
    "medfångar": "medfånge",
    "medfångarna": "medfånge",
    "medfångarnas": "medfånge",
    "medfångars": "medfånge",
    "medfången": "medfånge",
    "medfångens": "medfånge",
    "medfånges": "medfånge",
    "medfödda": "medfödd",
    "medföddare": "medfödd",
    "medföddares": "medfödd",
    "medföddas": "medfödd",
    "medföddast": "medfödd",
    "medföddaste": "medfödd",
    "medföddastes": "medfödd",
    "medföddasts": "medfödd",
    "medfödde": "medfödd",
    "medföddes": "medfödd",
    "medföddheten": "medföddhet",
    "medföddhetens": "medföddhet",
    "medföddhets": "medföddhet",
    "medfödds": "medfödd",
    "medfölj": "medfölja",
    "medföljande": "medfölja",
    "medföljanden": "medföljande",
    "medföljandena": "medföljande",
    "medföljandenas": "medföljande",
    "medföljandens": "medföljande",
    "medföljandes": "medföljande",
    "medföljandet": "medföljande",
    "medföljandets": "medföljande",
    "medföljde": "medfölja",
    "medföljer": "medfölja",
    "medföljt": "medfölja",
    "medför": "medföra",
    "medförande": "medföra",
    "medföranden": "medförande",
    "medförandena": "medförande",
    "medförandenas": "medförande",
    "medförandens": "medförande",
    "medförandes": "medförande",
    "medförandet": "medförande",
    "medförandets": "medförande",
    "medföras": "medföra",
    "medförd": "medföra",
    "medförda": "medföra",
    "medfördas": "medföra",
    "medförde": "medföra",
    "medfördes": "medföra",
    "medförds": "medföra",
    "medföres": "medföra",
    "medförs": "medföra",
    "medfört": "medföra",
    "medförts": "medföra",
    "medfött": "medfödd",
    "medfötts": "medfödd",
    "medgav": "medge",
    "medgavs": "medge",
    "medgeende": "medge",
    "medgeendes": "medge",
    "medger": "medge",
    "medges": "medge",
    "medgett": "medge",
    "medgetts": "medge",
    "medgiv": "medge",
    "medgiva": "medge",
    "medgivande": "medge",
    "medgivanden": "medgivande",
    "medgivandena": "medgivande",
    "medgivandenas": "medgivande",
    "medgivandens": "medgivande",
    "medgivandes": "medgivande",
    "medgivandet": "medgivande",
    "medgivandets": "medgivande",
    "medgivas": "medge",
    "medgive": "medge",
    "medgiven": "medge",
    "medgivens": "medge",
    "medgiver": "medge",
    "medgives": "medge",
    "medgivet": "medge",
    "medgivets": "medge",
    "medgivit": "medge",
    "medgivits": "medge",
    "medgivna": "medge",
    "medgivnas": "medge",
    "medgivne": "medge",
    "medgivnes": "medge",
    "medgivs": "medge",
    "medgångar": "medgång",
    "medgångarna": "medgång",
    "medgångarnas": "medgång",
    "medgångars": "medgång",
    "medgången": "medgång",
    "medgångens": "medgång",
    "medgångs": "medgång",
    "medgåve": "medge",
    "medgåves": "medge",
    "medgörliga": "medgörlig",
    "medgörligare": "medgörlig",
    "medgörligares": "medgörlig",
    "medgörligas": "medgörlig",
    "medgörligast": "medgörlig",
    "medgörligaste": "medgörlig",
    "medgörligastes": "medgörlig",
    "medgörligasts": "medgörlig",
    "medgörlige": "medgörlig",
    "medgörliges": "medgörlig",
    "medgörligheten": "medgörlighet",
    "medgörlighetens": "medgörlighet",
    "medgörlighets": "medgörlighet",
    "medgörligs": "medgörlig",
    "medgörligt": "medgörlig",
    "medgörligts": "medgörlig",
    "medhavda": "medhavd",
    "medhavdare": "medhavd",
    "medhavdares": "medhavd",
    "medhavdas": "medhavd",
    "medhavdast": "medhavd",
    "medhavdaste": "medhavd",
    "medhavdastes": "medhavd",
    "medhavdasts": "medhavd",
    "medhavde": "medhavd",
    "medhavdes": "medhavd",
    "medhavds": "medhavd",
    "medhavt": "medhavd",
    "medhavts": "medhavd",
    "medhjälpar": "medhjälpare",
    "medhjälparen": "medhjälpare",
    "medhjälparens": "medhjälpare",
    "medhjälpares": "medhjälpare",
    "medhjälparna": "medhjälpare",
    "medhjälparnas": "medhjälpare",
    "medhjälpen": "medhjälp",
    "medhjälpens": "medhjälp",
    "medhjälps": "medhjälp",
    "medhållet": "medhåll",
    "medhållets": "medhåll",
    "medhålls": "medhåll",
    "media": "medium",
    "mediabilden": "mediabild",
    "mediabildens": "mediabild",
    "mediabilder": "mediabild",
    "mediabilderna": "mediabild",
    "mediabildernas": "mediabild",
    "mediabilders": "mediabild",
    "mediabilds": "mediabild",
    "mediadreven": "mediadrev",
    "mediadrevens": "mediadrev",
    "mediadrevet": "mediadrev",
    "mediadrevets": "mediadrev",
    "mediadrevs": "mediadrev",
    "mediala": "medial",
    "medialare": "medial",
    "medialares": "medial",
    "medialas": "medial",
    "medialast": "medial",
    "medialaste": "medial",
    "medialastes": "medial",
    "medialasts": "medial",
    "mediale": "medial",
    "mediales": "medial",
    "medials": "medial",
    "medialt": "medial",
    "medialts": "medial",
    "mediamakten": "mediamakt",
    "mediamaktens": "mediamakt",
    "mediamakts": "mediamakt",
    "mediamässiga": "mediamässig",
    "mediamässigare": "mediamässig",
    "mediamässigares": "mediamässig",
    "mediamässigas": "mediamässig",
    "mediamässigast": "mediamässig",
    "mediamässigaste": "mediamässig",
    "mediamässigastes": "mediamässig",
    "mediamässigasts": "mediamässig",
    "mediamässige": "mediamässig",
    "mediamässiges": "mediamässig",
    "mediamässigs": "mediamässig",
    "mediamässigt": "mediamässig",
    "mediamässigts": "mediamässig",
    "mediana": "medium",
    "medianas": "medium",
    "medianen": "median",
    "medianens": "median",
    "medianer": "median",
    "medianerna": "median",
    "medianernas": "median",
    "medianers": "median",
    "medians": "median",
    "medianväljar": "medianväljare",
    "medianväljaren": "medianväljare",
    "medianväljarens": "medianväljare",
    "medianväljares": "medianväljare",
    "medianväljarna": "medianväljare",
    "medianväljarnas": "medianväljare",
    "mediapolitiken": "mediapolitik",
    "mediapolitikens": "mediapolitik",
    "mediapolitiks": "mediapolitik",
    "mediapolitiska": "mediapolitisk",
    "mediapolitiskas": "mediapolitisk",
    "mediapolitiske": "mediapolitisk",
    "mediapolitiskes": "mediapolitisk",
    "mediapolitisks": "mediapolitisk",
    "mediapolitiskt": "mediapolitisk",
    "mediapolitiskts": "mediapolitisk",
    "medias": "medium",
    "mediateken": "mediatek",
    "mediatekens": "mediatek",
    "mediateket": "mediatek",
    "mediatekets": "mediatek",
    "mediateks": "mediatek",
    "medici": "medikus",
    "medicina": "medikus",
    "medicinalstyrelsen": "medicinalstyrelse",
    "medicinalstyrelsens": "medicinalstyrelse",
    "medicinalstyrelser": "medicinalstyrelse",
    "medicinalstyrelserna": "medicinalstyrelse",
    "medicinalstyrelsernas": "medicinalstyrelse",
    "medicinalstyrelsers": "medicinalstyrelse",
    "medicinalstyrelses": "medicinalstyrelse",
    "medicinalvikten": "medicinalvikt",
    "medicinalviktens": "medicinalvikt",
    "medicinalvikts": "medicinalvikt",
    "medicinalväxten": "medicinalväxt",
    "medicinalväxtens": "medicinalväxt",
    "medicinalväxter": "medicinalväxt",
    "medicinalväxterna": "medicinalväxt",
    "medicinalväxternas": "medicinalväxt",
    "medicinalväxters": "medicinalväxt",
    "medicinalväxts": "medicinalväxt",
    "medicinar": "medicinare",
    "medicinaren": "medicinare",
    "medicinarens": "medicinare",
    "medicinares": "medicinare",
    "medicinarna": "medicinare",
    "medicinarnas": "medicinare",
    "medicinas": "medikus",
    "medicinbluffar": "medicinbluff",
    "medicinbluffarna": "medicinbluff",
    "medicinbluffarnas": "medicinbluff",
    "medicinbluffars": "medicinbluff",
    "medicinbluffen": "medicinbluff",
    "medicinbluffens": "medicinbluff",
    "medicinbluffs": "medicinbluff",
    "medicinbollar": "medicinboll",
    "medicinbollarna": "medicinboll",
    "medicinbollarnas": "medicinboll",
    "medicinbollars": "medicinboll",
    "medicinbollen": "medicinboll",
    "medicinbollens": "medicinboll",
    "medicinbolls": "medicinboll",
    "medicinen": "medicin",
    "medicinens": "medicin",
    "mediciner": "medicin",
    "medicinerad": "medicinera",
    "medicinerade": "medicinera",
    "medicinerades": "medicinera",
    "medicinerads": "medicinera",
    "medicinerande": "medicinera",
    "medicineranden": "medicinerande",
    "medicinerandena": "medicinerande",
    "medicinerandenas": "medicinerande",
    "medicinerandens": "medicinerande",
    "medicinerandes": "medicinerande",
    "medicinerandet": "medicinerande",
    "medicinerandets": "medicinerande",
    "medicinerar": "medicinera",
    "medicineras": "medicinera",
    "medicinerat": "medicinera",
    "medicinerats": "medicinera",
    "medicinerbara": "medicinerbar",
    "medicinerbarare": "medicinerbar",
    "medicinerbarares": "medicinerbar",
    "medicinerbaras": "medicinerbar",
    "medicinerbarast": "medicinerbar",
    "medicinerbaraste": "medicinerbar",
    "medicinerbarastes": "medicinerbar",
    "medicinerbarasts": "medicinerbar",
    "medicinerbare": "medicinerbar",
    "medicinerbares": "medicinerbar",
    "medicinerbarheten": "medicinerbarhet",
    "medicinerbarhetens": "medicinerbarhet",
    "medicinerbarhets": "medicinerbarhet",
    "medicinerbars": "medicinerbar",
    "medicinerbart": "medicinerbar",
    "medicinerbarts": "medicinerbar",
    "medicineringar": "medicinering",
    "medicineringarna": "medicinering",
    "medicineringarnas": "medicinering",
    "medicineringars": "medicinering",
    "medicineringen": "medicinering",
    "medicineringens": "medicinering",
    "medicinerings": "medicinering",
    "medicinerna": "medicin",
    "medicinernas": "medicin",
    "mediciners": "medicin",
    "medicinglasen": "medicinglas",
    "medicinglasens": "medicinglas",
    "medicinglaset": "medicinglas",
    "medicinglasets": "medicinglas",
    "medicinmannen": "medicinman",
    "medicinmannens": "medicinman",
    "medicinmans": "medicinman",
    "medicinmän": "medicinman",
    "medicinmännen": "medicinman",
    "medicinmännens": "medicinman",
    "medicinmäns": "medicinman",
    "medicins": "medicin",
    "medicinska": "medicinsk",
    "medicinskare": "medicinsk",
    "medicinskares": "medicinsk",
    "medicinskas": "medicinsk",
    "medicinskast": "medicinsk",
    "medicinskaste": "medicinsk",
    "medicinskastes": "medicinsk",
    "medicinskasts": "medicinsk",
    "medicinske": "medicinsk",
    "medicinskes": "medicinsk",
    "medicinsks": "medicinsk",
    "medicinskt": "medicinsk",
    "medicinskts": "medicinsk",
    "medicis": "medikus",
    "medie": "medium",
    "mediebevakningar": "mediebevakning",
    "mediebevakningarna": "mediebevakning",
    "mediebevakningarnas": "mediebevakning",
    "mediebevakningars": "mediebevakning",
    "mediebevakningen": "mediebevakning",
    "mediebevakningens": "mediebevakning",
    "mediebevaknings": "mediebevakning",
    "mediebilden": "mediebild",
    "mediebildens": "mediebild",
    "mediebilder": "mediebild",
    "mediebilderna": "mediebild",
    "mediebildernas": "mediebild",
    "mediebilders": "mediebild",
    "mediebilds": "mediebild",
    "mediecirkusar": "mediecirkus",
    "mediecirkusarna": "mediecirkus",
    "mediecirkusarnas": "mediecirkus",
    "mediecirkusars": "mediecirkus",
    "mediecirkusen": "mediecirkus",
    "mediecirkusens": "mediecirkus",
    "mediedammar": "mediedamm",
    "mediedammarna": "mediedamm",
    "mediedammarnas": "mediedamm",
    "mediedammars": "mediedamm",
    "mediedammen": "mediedamm",
    "mediedammens": "mediedamm",
    "mediedamms": "mediedamm",
    "mediedreven": "mediedrev",
    "mediedrevens": "mediedrev",
    "mediedrevet": "mediedrev",
    "mediedrevets": "mediedrev",
    "mediedrevs": "mediedrev",
    "medieföretagen": "medieföretag",
    "medieföretagens": "medieföretag",
    "medieföretaget": "medieföretag",
    "medieföretagets": "medieföretag",
    "medieföretags": "medieföretag",
    "mediekanalen": "mediekanal",
    "mediekanalens": "mediekanal",
    "mediekanaler": "mediekanal",
    "mediekanalerna": "mediekanal",
    "mediekanalernas": "mediekanal",
    "mediekanalers": "mediekanal",
    "mediekanals": "mediekanal",
    "mediekritiska": "mediekritisk",
    "mediekritiskare": "mediekritisk",
    "mediekritiskares": "mediekritisk",
    "mediekritiskas": "mediekritisk",
    "mediekritiskast": "mediekritisk",
    "mediekritiskaste": "mediekritisk",
    "mediekritiskastes": "mediekritisk",
    "mediekritiskasts": "mediekritisk",
    "mediekritiske": "mediekritisk",
    "mediekritiskes": "mediekritisk",
    "mediekritisks": "mediekritisk",
    "mediekritiskt": "mediekritisk",
    "mediekritiskts": "mediekritisk",
    "medielogiken": "medielogik",
    "medielogikens": "medielogik",
    "medielogiks": "medielogik",
    "mediemakten": "mediemakt",
    "mediemaktens": "mediemakt",
    "mediemakts": "mediemakt",
    "mediemässiga": "mediemässig",
    "mediemässigare": "mediemässig",
    "mediemässigares": "mediemässig",
    "mediemässigas": "mediemässig",
    "mediemässigast": "mediemässig",
    "mediemässigaste": "mediemässig",
    "mediemässigastes": "mediemässig",
    "mediemässigasts": "mediemässig",
    "mediemässige": "mediemässig",
    "mediemässiges": "mediemässig",
    "mediemässigs": "mediemässig",
    "mediemässigt": "mediemässig",
    "mediemässigts": "mediemässig",
    "mediena": "medium",
    "medienas": "medium",
    "mediepolitiken": "mediepolitik",
    "mediepolitikens": "mediepolitik",
    "mediepolitiks": "mediepolitik",
    "mediepolitiska": "mediepolitisk",
    "mediepolitiskas": "mediepolitisk",
    "mediepolitiske": "mediepolitisk",
    "mediepolitiskes": "mediepolitisk",
    "mediepolitisks": "mediepolitisk",
    "mediepolitiskt": "mediepolitisk",
    "mediepolitiskts": "mediepolitisk",
    "medier": "medium",
    "medierapporteringen": "medierapportering",
    "medierapporteringens": "medierapportering",
    "medierapporterings": "medierapportering",
    "medierna": "medium",
    "mediernas": "medium",
    "mediers": "medium",
    "mediet": "medium",
    "medietrenden": "medietrend",
    "medietrendens": "medietrend",
    "medietrender": "medietrend",
    "medietrenderna": "medietrend",
    "medietrendernas": "medietrend",
    "medietrenders": "medietrend",
    "medietrends": "medietrend",
    "mediets": "medium",
    "medieutbuden": "medieutbud",
    "medieutbudens": "medieutbud",
    "medieutbudet": "medieutbud",
    "medieutbudets": "medieutbud",
    "medieutbuds": "medieutbud",
    "medievalen": "medieval",
    "medievalens": "medieval",
    "medievaler": "medieval",
    "medievalerna": "medieval",
    "medievalernas": "medieval",
    "medievalers": "medieval",
    "medievals": "medieval",
    "medikamenten": "medikament",
    "medikamentens": "medikament",
    "medikamenter": "medikament",
    "medikamenterna": "medikament",
    "medikamenternas": "medikament",
    "medikamenters": "medikament",
    "medikamentet": "medikament",
    "medikamentets": "medikament",
    "medikaments": "medikament",
    "medikusen": "medikus",
    "medikusens": "medikus",
    "medinflytandes": "medinflytande",
    "medinflytandet": "medinflytande",
    "medinflytandets": "medinflytande",
    "mediokerheten": "mediokerhet",
    "mediokerhetens": "mediokerhet",
    "mediokerhets": "mediokerhet",
    "mediokers": "medioker",
    "mediokert": "medioker",
    "mediokerts": "medioker",
    "mediokra": "medioker",
    "mediokrare": "medioker",
    "mediokrares": "medioker",
    "mediokras": "medioker",
    "mediokrast": "medioker",
    "mediokraste": "medioker",
    "mediokrastes": "medioker",
    "mediokrasts": "medioker",
    "mediokre": "medioker",
    "mediokres": "medioker",
    "medioteken": "mediotek",
    "mediotekens": "mediotek",
    "medioteket": "mediotek",
    "mediotekets": "mediotek",
    "medioteks": "mediotek",
    "medisterkorvar": "medisterkorv",
    "medisterkorvarna": "medisterkorv",
    "medisterkorvarnas": "medisterkorv",
    "medisterkorvars": "medisterkorv",
    "medisterkorven": "medisterkorv",
    "medisterkorvens": "medisterkorv",
    "medisterkorvs": "medisterkorv",
    "meditationen": "meditation",
    "meditationens": "meditation",
    "meditationer": "meditation",
    "meditationerna": "meditation",
    "meditationernas": "meditation",
    "meditationers": "meditation",
    "meditations": "meditation",
    "meditativa": "meditativ",
    "meditativare": "meditativ",
    "meditativares": "meditativ",
    "meditativas": "meditativ",
    "meditativast": "meditativ",
    "meditativaste": "meditativ",
    "meditativastes": "meditativ",
    "meditativasts": "meditativ",
    "meditative": "meditativ",
    "meditatives": "meditativ",
    "meditativs": "meditativ",
    "meditativt": "meditativ",
    "meditativts": "meditativ",
    "mediterade": "meditera",
    "mediterades": "meditera",
    "mediterande": "meditera",
    "mediteranden": "mediterande",
    "mediterandena": "mediterande",
    "mediterandenas": "mediterande",
    "mediterandens": "mediterande",
    "mediterandes": "mediterande",
    "mediterandet": "mediterande",
    "mediterandets": "mediterande",
    "mediterar": "meditera",
    "mediteras": "meditera",
    "mediterat": "meditera",
    "mediterats": "meditera",
    "mediteringar": "meditering",
    "mediteringarna": "meditering",
    "mediteringarnas": "meditering",
    "mediteringars": "meditering",
    "mediteringen": "meditering",
    "mediteringens": "meditering",
    "mediterings": "meditering",
    "mediterrana": "mediterran",
    "mediterranare": "mediterran",
    "mediterranares": "mediterran",
    "mediterranas": "mediterran",
    "mediterranast": "mediterran",
    "mediterranaste": "mediterran",
    "mediterranastes": "mediterran",
    "mediterranasts": "mediterran",
    "mediterrane": "mediterran",
    "mediterranes": "mediterran",
    "mediterrans": "mediterran",
    "mediterrant": "mediterran",
    "mediterrants": "mediterran",
    "mediumen": "medium",
    "mediumens": "medium",
    "mediumet": "medium",
    "mediumets": "medium",
    "mediums": "medium",
    "mediuppgiften": "mediuppgift",
    "mediuppgiftens": "mediuppgift",
    "mediuppgifter": "mediuppgift",
    "mediuppgifterna": "mediuppgift",
    "mediuppgifternas": "mediuppgift",
    "mediuppgifters": "mediuppgift",
    "mediuppgifts": "mediuppgift",
    "medkänslan": "medkänsla",
    "medkänslans": "medkänsla",
    "medkänslas": "medkänsla",
    "medkänsle": "medkänsla",
    "medkänslo": "medkänsla",
    "medlade": "medla",
    "medlades": "medla",
    "medlande": "medla",
    "medlanden": "medlande",
    "medlandena": "medlande",
    "medlandenas": "medlande",
    "medlandens": "medlande",
    "medlandes": "medlande",
    "medlandet": "medlande",
    "medlandets": "medlande",
    "medlar": "medlare",
    "medlaren": "medlare",
    "medlarens": "medlare",
    "medlares": "medlare",
    "medlarna": "medlare",
    "medlarnas": "medlare",
    "medlas": "medla",
    "medlat": "medla",
    "medlats": "medla",
    "medlemmar": "medlem",
    "medlemmarna": "medlem",
    "medlemmarnas": "medlem",
    "medlemmars": "medlem",
    "medlemmen": "medlem",
    "medlemmens": "medlem",
    "medlems": "medlem",
    "medlemsantalen": "medlemsantal",
    "medlemsantalens": "medlemsantal",
    "medlemsantalet": "medlemsantal",
    "medlemsantalets": "medlemsantal",
    "medlemsantals": "medlemsantal",
    "medlemsantalsmässiga": "medlemsantalsmässig",
    "medlemsantalsmässigare": "medlemsantalsmässig",
    "medlemsantalsmässigares": "medlemsantalsmässig",
    "medlemsantalsmässigas": "medlemsantalsmässig",
    "medlemsantalsmässigast": "medlemsantalsmässig",
    "medlemsantalsmässigaste": "medlemsantalsmässig",
    "medlemsantalsmässigastes": "medlemsantalsmässig",
    "medlemsantalsmässigasts": "medlemsantalsmässig",
    "medlemsantalsmässige": "medlemsantalsmässig",
    "medlemsantalsmässiges": "medlemsantalsmässig",
    "medlemsantalsmässigs": "medlemsantalsmässig",
    "medlemsantalsmässigt": "medlemsantalsmässig",
    "medlemsantalsmässigts": "medlemsantalsmässig",
    "medlemsavgiften": "medlemsavgift",
    "medlemsavgiftens": "medlemsavgift",
    "medlemsavgifter": "medlemsavgift",
    "medlemsavgifterna": "medlemsavgift",
    "medlemsavgifternas": "medlemsavgift",
    "medlemsavgifters": "medlemsavgift",
    "medlemsavgifts": "medlemsavgift",
    "medlemsföretagen": "medlemsföretag",
    "medlemsföretagens": "medlemsföretag",
    "medlemsföretaget": "medlemsföretag",
    "medlemsföretagets": "medlemsföretag",
    "medlemsföretags": "medlemsföretag",
    "medlemskapen": "medlemskap",
    "medlemskapens": "medlemskap",
    "medlemskapet": "medlemskap",
    "medlemskapets": "medlemskap",
    "medlemskaps": "medlemskap",
    "medlemskorten": "medlemskort",
    "medlemskortens": "medlemskort",
    "medlemskortet": "medlemskort",
    "medlemskortets": "medlemskort",
    "medlemskorts": "medlemskort",
    "medlemslandet": "medlemsland",
    "medlemslandets": "medlemsland",
    "medlemslands": "medlemsland",
    "medlemsländer": "medlemsland",
    "medlemsländerna": "medlemsland",
    "medlemsländernas": "medlemsland",
    "medlemsländers": "medlemsland",
    "medlemsmässiga": "medlemsmässig",
    "medlemsmässigare": "medlemsmässig",
    "medlemsmässigares": "medlemsmässig",
    "medlemsmässigas": "medlemsmässig",
    "medlemsmässigast": "medlemsmässig",
    "medlemsmässigaste": "medlemsmässig",
    "medlemsmässigastes": "medlemsmässig",
    "medlemsmässigasts": "medlemsmässig",
    "medlemsmässige": "medlemsmässig",
    "medlemsmässiges": "medlemsmässig",
    "medlemsmässigs": "medlemsmässig",
    "medlemsmässigt": "medlemsmässig",
    "medlemsmässigts": "medlemsmässig",
    "medlemsmöten": "medlemsmöte",
    "medlemsmötena": "medlemsmöte",
    "medlemsmötenas": "medlemsmöte",
    "medlemsmötens": "medlemsmöte",
    "medlemsmötes": "medlemsmöte",
    "medlemsmötet": "medlemsmöte",
    "medlemsmötets": "medlemsmöte",
    "medlemsskapen": "medlemsskap",
    "medlemsskapens": "medlemsskap",
    "medlemsskapet": "medlemsskap",
    "medlemsskapets": "medlemsskap",
    "medlemsskaps": "medlemsskap",
    "medlemsstaten": "medlemsstat",
    "medlemsstatens": "medlemsstat",
    "medlemsstater": "medlemsstat",
    "medlemsstaterna": "medlemsstat",
    "medlemsstaternas": "medlemsstat",
    "medlemsstaters": "medlemsstat",
    "medlemsstats": "medlemsstat",
    "medlen": "medel",
    "medlens": "medel",
    "medlet": "medel",
    "medlets": "medel",
    "medleyn": "medley",
    "medleyns": "medley",
    "medleys": "medley",
    "medlidandes": "medlidande",
    "medlidandet": "medlidande",
    "medlidandets": "medlidande",
    "medlidsamheten": "medlidsamhet",
    "medlidsamhetens": "medlidsamhet",
    "medlidsamhets": "medlidsamhet",
    "medlidsamma": "medlidsam",
    "medlidsammare": "medlidsam",
    "medlidsammares": "medlidsam",
    "medlidsammas": "medlidsam",
    "medlidsammast": "medlidsam",
    "medlidsammaste": "medlidsam",
    "medlidsammastes": "medlidsam",
    "medlidsammasts": "medlidsam",
    "medlidsamme": "medlidsam",
    "medlidsammes": "medlidsam",
    "medlidsams": "medlidsam",
    "medlidsamt": "medlidsam",
    "medlidsamts": "medlidsam",
    "medlingar": "medling",
    "medlingarna": "medling",
    "medlingarnas": "medling",
    "medlingars": "medling",
    "medlingen": "medling",
    "medlingens": "medling",
    "medlings": "medling",
    "medlingsförslagen": "medlingsförslag",
    "medlingsförslagens": "medlingsförslag",
    "medlingsförslaget": "medlingsförslag",
    "medlingsförslagets": "medlingsförslag",
    "medlingsförslags": "medlingsförslag",
    "medlingskommissionen": "medlingskommission",
    "medlingskommissionens": "medlingskommission",
    "medlingskommissioner": "medlingskommission",
    "medlingskommissionerna": "medlingskommission",
    "medlingskommissionernas": "medlingskommission",
    "medlingskommissioners": "medlingskommission",
    "medlingskommissions": "medlingskommission",
    "medljuden": "medljud",
    "medljudens": "medljud",
    "medljudet": "medljud",
    "medljudets": "medljud",
    "medljuds": "medljud",
    "medluten": "medlut",
    "medlutens": "medlut",
    "medlutet": "medlut",
    "medlutets": "medlut",
    "medluts": "medlut",
    "medlöftesmannen": "medlöftesman",
    "medlöftesmannens": "medlöftesman",
    "medlöftesmans": "medlöftesman",
    "medlöftesmän": "medlöftesman",
    "medlöftesmännen": "medlöftesman",
    "medlöftesmännens": "medlöftesman",
    "medlöftesmäns": "medlöftesman",
    "medlöpar": "medlöpare",
    "medlöparen": "medlöpare",
    "medlöparens": "medlöpare",
    "medlöpares": "medlöpare",
    "medlöparna": "medlöpare",
    "medlöparnas": "medlöpare",
    "medmänniskan": "medmänniska",
    "medmänniskans": "medmänniska",
    "medmänniskas": "medmänniska",
    "medmännisko": "medmänniska",
    "medmänniskor": "medmänniska",
    "medmänniskorna": "medmänniska",
    "medmänniskornas": "medmänniska",
    "medmänniskors": "medmänniska",
    "medmänskliga": "medmänsklig",
    "medmänskligare": "medmänsklig",
    "medmänskligares": "medmänsklig",
    "medmänskligas": "medmänsklig",
    "medmänskligast": "medmänsklig",
    "medmänskligaste": "medmänsklig",
    "medmänskligastes": "medmänsklig",
    "medmänskligasts": "medmänsklig",
    "medmänsklige": "medmänsklig",
    "medmänskliges": "medmänsklig",
    "medmänskligheten": "medmänsklighet",
    "medmänsklighetens": "medmänsklighet",
    "medmänsklighets": "medmänsklighet",
    "medmänskligs": "medmänsklig",
    "medmänskligt": "medmänsklig",
    "medmänskligts": "medmänsklig",
    "medresenären": "medresenär",
    "medresenärens": "medresenär",
    "medresenärer": "medresenär",
    "medresenärerna": "medresenär",
    "medresenärernas": "medresenär",
    "medresenärers": "medresenär",
    "medresenärs": "medresenär",
    "meds": "mede",
    "medskyldiga": "medskyldig",
    "medskyldigare": "medskyldig",
    "medskyldigares": "medskyldig",
    "medskyldigas": "medskyldig",
    "medskyldigast": "medskyldig",
    "medskyldigaste": "medskyldig",
    "medskyldigastes": "medskyldig",
    "medskyldigasts": "medskyldig",
    "medskyldige": "medskyldig",
    "medskyldiges": "medskyldig",
    "medskyldigheten": "medskyldighet",
    "medskyldighetens": "medskyldighet",
    "medskyldighets": "medskyldighet",
    "medskyldigs": "medskyldig",
    "medskyldigt": "medskyldig",
    "medskyldigts": "medskyldig",
    "medspelar": "medspelare",
    "medspelaren": "medspelare",
    "medspelarens": "medspelare",
    "medspelares": "medspelare",
    "medspelarna": "medspelare",
    "medspelarnas": "medspelare",
    "medströmmar": "medström",
    "medströmmarna": "medström",
    "medströmmarnas": "medström",
    "medströmmars": "medström",
    "medströmmen": "medström",
    "medströmmens": "medström",
    "medströms": "medström",
    "medsökanden": "medsökande",
    "medsökandena": "medsökande",
    "medsökandenas": "medsökande",
    "medsökandens": "medsökande",
    "medsökandes": "medsökande",
    "medtag": "medta",
    "medtaga": "medta",
    "medtagande": "medta",
    "medtaganden": "medtagande",
    "medtagandena": "medtagande",
    "medtagandenas": "medtagande",
    "medtagandens": "medtagande",
    "medtagandes": "medtagande",
    "medtagandet": "medtagande",
    "medtagandets": "medtagande",
    "medtagas": "medta",
    "medtage": "medta",
    "medtagen": "medta",
    "medtagenheten": "medtagenhet",
    "medtagenhetens": "medtagenhet",
    "medtagenhets": "medtagenhet",
    "medtagens": "medtagen",
    "medtager": "medta",
    "medtages": "medta",
    "medtaget": "medtagen",
    "medtagets": "medtagen",
    "medtagit": "medta",
    "medtagits": "medta",
    "medtagna": "medtagen",
    "medtagnare": "medtagen",
    "medtagnares": "medtagen",
    "medtagnas": "medtagen",
    "medtagnast": "medtagen",
    "medtagnaste": "medtagen",
    "medtagnastes": "medtagen",
    "medtagnasts": "medtagen",
    "medtagne": "medtagen",
    "medtagnes": "medtagen",
    "medtags": "medta",
    "medtar": "medta",
    "medtas": "medta",
    "medtog": "medta",
    "medtoge": "medta",
    "medtoges": "medta",
    "medtogs": "medta",
    "medtrafikanten": "medtrafikant",
    "medtrafikantens": "medtrafikant",
    "medtrafikanter": "medtrafikant",
    "medtrafikanterna": "medtrafikant",
    "medtrafikanternas": "medtrafikant",
    "medtrafikanters": "medtrafikant",
    "medtrafikants": "medtrafikant",
    "medtävlar": "medtävlare",
    "medtävlaren": "medtävlare",
    "medtävlarens": "medtävlare",
    "medtävlares": "medtävlare",
    "medtävlarna": "medtävlare",
    "medtävlarnas": "medtävlare",
    "medus": "medusa",
    "medusan": "medusa",
    "medusans": "medusa",
    "medusas": "medusa",
    "meduse": "medusa",
    "medusor": "medusa",
    "medusorna": "medusa",
    "medusornas": "medusa",
    "medusors": "medusa",
    "medverkade": "medverka",
    "medverkades": "medverka",
    "medverkande": "medverka",
    "medverkanden": "medverkande",
    "medverkandena": "medverkande",
    "medverkandenas": "medverkande",
    "medverkandens": "medverkande",
    "medverkandes": "medverkande",
    "medverkandet": "medverkande",
    "medverkandets": "medverkande",
    "medverkans": "medverkan",
    "medverkar": "medverka",
    "medverkas": "medverka",
    "medverkat": "medverka",
    "medverkats": "medverka",
    "medvetandenivåer": "medvetandenivå",
    "medvetandenivåerna": "medvetandenivå",
    "medvetandenivåernas": "medvetandenivå",
    "medvetandenivåers": "medvetandenivå",
    "medvetandenivån": "medvetandenivå",
    "medvetandenivåns": "medvetandenivå",
    "medvetandenivås": "medvetandenivå",
    "medvetandes": "medvetande",
    "medvetandet": "medvetande",
    "medvetandets": "medvetande",
    "medvetenheten": "medvetenhet",
    "medvetenhetens": "medvetenhet",
    "medvetenheter": "medvetenhet",
    "medvetenheterna": "medvetenhet",
    "medvetenheternas": "medvetenhet",
    "medvetenheters": "medvetenhet",
    "medvetenhets": "medvetenhet",
    "medvetens": "medveten",
    "medvetet": "medveten",
    "medvetets": "medveten",
    "medvetna": "medveten",
    "medvetnare": "medveten",
    "medvetnares": "medveten",
    "medvetnas": "medveten",
    "medvetnast": "medveten",
    "medvetnaste": "medveten",
    "medvetnastes": "medveten",
    "medvetnasts": "medveten",
    "medvetne": "medveten",
    "medvetnes": "medveten",
    "medvetslösa": "medvetslös",
    "medvetslösare": "medvetslös",
    "medvetslösares": "medvetslös",
    "medvetslösas": "medvetslös",
    "medvetslösast": "medvetslös",
    "medvetslösaste": "medvetslös",
    "medvetslösastes": "medvetslös",
    "medvetslösasts": "medvetslös",
    "medvetslöse": "medvetslös",
    "medvetslöses": "medvetslös",
    "medvetslösheten": "medvetslöshet",
    "medvetslöshetens": "medvetslöshet",
    "medvetslöshets": "medvetslöshet",
    "medvetslöst": "medvetslös",
    "medvetslösts": "medvetslös",
    "medvindar": "medvind",
    "medvindarna": "medvind",
    "medvindarnas": "medvind",
    "medvindars": "medvind",
    "medvinden": "medvind",
    "medvindens": "medvind",
    "medvinds": "medvind",
    "medvurstar": "medvurst",
    "medvurstarna": "medvurst",
    "medvurstarnas": "medvurst",
    "medvurstars": "medvurst",
    "medvursten": "medvurst",
    "medvurstens": "medvurst",
    "medvursts": "medvurst",
    "medåtalade": "medåtalad",
    "medåtalades": "medåtalad",
    "medåtalads": "medåtalad",
    "medåtalat": "medåtalad",
    "medåtalats": "medåtalad",
    "medömkans": "medömkan",
    "mef": "mefa",
    "mefan": "mefa",
    "mefans": "mefa",
    "mefas": "mefa",
    "mefe": "mefa",
    "mefistofeliska": "mefistofelisk",
    "mefistofeliskare": "mefistofelisk",
    "mefistofeliskares": "mefistofelisk",
    "mefistofeliskas": "mefistofelisk",
    "mefistofeliskast": "mefistofelisk",
    "mefistofeliskaste": "mefistofelisk",
    "mefistofeliskastes": "mefistofelisk",
    "mefistofeliskasts": "mefistofelisk",
    "mefistofeliske": "mefistofelisk",
    "mefistofeliskes": "mefistofelisk",
    "mefistofelisks": "mefistofelisk",
    "mefistofeliskt": "mefistofelisk",
    "mefistofeliskts": "mefistofelisk",
    "mefitiska": "mefitisk",
    "mefitiskare": "mefitisk",
    "mefitiskares": "mefitisk",
    "mefitiskas": "mefitisk",
    "mefitiskast": "mefitisk",
    "mefitiskaste": "mefitisk",
    "mefitiskastes": "mefitisk",
    "mefitiskasts": "mefitisk",
    "mefitiske": "mefitisk",
    "mefitiskes": "mefitisk",
    "mefitisks": "mefitisk",
    "mefitiskt": "mefitisk",
    "mefitiskts": "mefitisk",
    "mefor": "mefa",
    "meforna": "mefa",
    "mefornas": "mefa",
    "mefors": "mefa",
    "mefs": "mefa",
    "megabyten": "megabyte",
    "megabytena": "megabyte",
    "megabytenas": "megabyte",
    "megabytens": "megabyte",
    "megabytes": "megabyte",
    "megafonen": "megafon",
    "megafonens": "megafon",
    "megafoner": "megafon",
    "megafonerna": "megafon",
    "megafonernas": "megafon",
    "megafoners": "megafon",
    "megafons": "megafon",
    "megajoulen": "megajoule",
    "megajoulena": "megajoule",
    "megajoulenas": "megajoule",
    "megajoulens": "megajoule",
    "megajoules": "megajoule",
    "megakollisionen": "megakollision",
    "megakollisionens": "megakollision",
    "megakollisioner": "megakollision",
    "megakollisionerna": "megakollision",
    "megakollisionernas": "megakollision",
    "megakollisioners": "megakollision",
    "megakollisions": "megakollision",
    "megaliten": "megalit",
    "megalitens": "megalit",
    "megaliter": "megalit",
    "megaliterna": "megalit",
    "megaliternas": "megalit",
    "megaliters": "megalit",
    "megalits": "megalit",
    "megalomanien": "megalomani",
    "megalomaniens": "megalomani",
    "megalomanin": "megalomani",
    "megalomanins": "megalomani",
    "megalomanis": "megalomani",
    "meganewtonen": "meganewton",
    "meganewtonens": "meganewton",
    "meganewtons": "meganewton",
    "megaskrällar": "megaskräll",
    "megaskrällarna": "megaskräll",
    "megaskrällarnas": "megaskräll",
    "megaskrällars": "megaskräll",
    "megaskrällen": "megaskräll",
    "megaskrällens": "megaskräll",
    "megaskrälls": "megaskräll",
    "megatonnen": "megaton",
    "megatonnens": "megaton",
    "megatonnet": "megaton",
    "megatonnets": "megaton",
    "megatons": "megaton",
    "megawatten": "megawatt",
    "megawattens": "megawatt",
    "megawatts": "megawatt",
    "megär": "megära",
    "megäran": "megära",
    "megärans": "megära",
    "megäras": "megära",
    "megäre": "megära",
    "megäror": "megära",
    "megärorna": "megära",
    "megärornas": "megära",
    "megärors": "megära",
    "megärs": "megära",
    "mej": "meja",
    "mejad": "meja",
    "mejade": "meja",
    "mejades": "meja",
    "mejads": "meja",
    "mejande": "meja",
    "mejanden": "mejande",
    "mejandena": "mejande",
    "mejandenas": "mejande",
    "mejandens": "mejande",
    "mejandes": "mejande",
    "mejandet": "mejande",
    "mejandets": "mejande",
    "mejar": "meja",
    "mejas": "meja",
    "mejat": "meja",
    "mejats": "meja",
    "mejerier": "mejeri",
    "mejerierna": "mejeri",
    "mejeriernas": "mejeri",
    "mejeriers": "mejeri",
    "mejeriet": "mejeri",
    "mejeriets": "mejeri",
    "mejerifabriken": "mejerifabrik",
    "mejerifabrikens": "mejerifabrik",
    "mejerifabriker": "mejerifabrik",
    "mejerifabrikerna": "mejerifabrik",
    "mejerifabrikernas": "mejerifabrik",
    "mejerifabrikers": "mejerifabrik",
    "mejerifabriks": "mejerifabrik",
    "mejeriföreningar": "mejeriförening",
    "mejeriföreningarna": "mejeriförening",
    "mejeriföreningarnas": "mejeriförening",
    "mejeriföreningars": "mejeriförening",
    "mejeriföreningen": "mejeriförening",
    "mejeriföreningens": "mejeriförening",
    "mejeriförenings": "mejeriförening",
    "mejeris": "mejeri",
    "mejeristen": "mejerist",
    "mejeristens": "mejerist",
    "mejerister": "mejerist",
    "mejeristerna": "mejerist",
    "mejeristernas": "mejerist",
    "mejeristers": "mejerist",
    "mejerists": "mejerist",
    "mejerit": "mejeri",
    "mejerits": "mejeri",
    "mejlad": "mejla",
    "mejlade": "mejla",
    "mejlades": "mejla",
    "mejlads": "mejla",
    "mejlande": "mejla",
    "mejlanden": "mejlande",
    "mejlandena": "mejlande",
    "mejlandenas": "mejlande",
    "mejlandens": "mejlande",
    "mejlandes": "mejlande",
    "mejlandet": "mejlande",
    "mejlandets": "mejlande",
    "mejlar": "mejlare",
    "mejlaren": "mejlare",
    "mejlarens": "mejlare",
    "mejlares": "mejlare",
    "mejlarna": "mejlare",
    "mejlarnas": "mejlare",
    "mejlas": "mejla",
    "mejlat": "mejla",
    "mejlats": "mejla",
    "mejlbombad": "mejlbomba",
    "mejlbombade": "mejlbomba",
    "mejlbombades": "mejlbomba",
    "mejlbombads": "mejlbomba",
    "mejlbombande": "mejlbomba",
    "mejlbombanden": "mejlbombande",
    "mejlbombandena": "mejlbombande",
    "mejlbombandenas": "mejlbombande",
    "mejlbombandens": "mejlbombande",
    "mejlbombandes": "mejlbombande",
    "mejlbombandet": "mejlbombande",
    "mejlbombandets": "mejlbombande",
    "mejlbombar": "mejlbomba",
    "mejlbombas": "mejlbomba",
    "mejlbombat": "mejlbomba",
    "mejlbombats": "mejlbomba",
    "mejlen": "mejl",
    "mejlens": "mejl",
    "mejlet": "mejl",
    "mejlets": "mejl",
    "mejlhoten": "mejlhot",
    "mejlhotens": "mejlhot",
    "mejlhotet": "mejlhot",
    "mejlhotets": "mejlhot",
    "mejlhots": "mejlhot",
    "mejlintervjuer": "mejlintervju",
    "mejlintervjuerna": "mejlintervju",
    "mejlintervjuernas": "mejlintervju",
    "mejlintervjuers": "mejlintervju",
    "mejlintervjun": "mejlintervju",
    "mejlintervjuns": "mejlintervju",
    "mejlintervjus": "mejlintervju",
    "mejlintrången": "mejlintrång",
    "mejlintrångens": "mejlintrång",
    "mejlintrånget": "mejlintrång",
    "mejlintrångets": "mejlintrång",
    "mejlintrångs": "mejlintrång",
    "mejls": "mejl",
    "mejramen": "mejram",
    "mejramens": "mejram",
    "mejrams": "mejram",
    "mejseln": "mejsel",
    "mejselns": "mejsel",
    "mejsels": "mejsel",
    "mejslad": "mejsla",
    "mejslade": "mejsla",
    "mejslades": "mejsla",
    "mejslads": "mejsla",
    "mejslande": "mejsla",
    "mejslanden": "mejslande",
    "mejslandena": "mejslande",
    "mejslandenas": "mejslande",
    "mejslandens": "mejslande",
    "mejslandes": "mejslande",
    "mejslandet": "mejslande",
    "mejslandets": "mejslande",
    "mejslar": "mejsla",
    "mejslarna": "mejsel",
    "mejslarnas": "mejsel",
    "mejslars": "mejsel",
    "mejslas": "mejsla",
    "mejslat": "mejsla",
    "mejslats": "mejsla",
    "mek": "meka",
    "mekade": "meka",
    "mekades": "meka",
    "mekande": "meka",
    "mekanden": "mekande",
    "mekandena": "mekande",
    "mekandenas": "mekande",
    "mekandens": "mekande",
    "mekandes": "mekande",
    "mekandet": "mekande",
    "mekandets": "mekande",
    "mekanici": "mekanikus",
    "mekanicina": "mekanikus",
    "mekanicinas": "mekanikus",
    "mekanicis": "mekanikus",
    "mekaniken": "mekanik",
    "mekanikens": "mekanik",
    "mekanikern": "mekaniker",
    "mekanikerna": "mekaniker",
    "mekanikernas": "mekaniker",
    "mekanikerns": "mekaniker",
    "mekanikers": "mekaniker",
    "mekaniks": "mekanik",
    "mekanikusen": "mekanikus",
    "mekanikusens": "mekanikus",
    "mekaniserad": "mekanisera",
    "mekaniserade": "mekanisera",
    "mekaniserades": "mekanisera",
    "mekaniserads": "mekanisera",
    "mekaniserande": "mekanisera",
    "mekaniseranden": "mekaniserande",
    "mekaniserandena": "mekaniserande",
    "mekaniserandenas": "mekaniserande",
    "mekaniserandens": "mekaniserande",
    "mekaniserandes": "mekaniserande",
    "mekaniserandet": "mekaniserande",
    "mekaniserandets": "mekaniserande",
    "mekaniserar": "mekanisera",
    "mekaniseras": "mekanisera",
    "mekaniserat": "mekanisera",
    "mekaniserats": "mekanisera",
    "mekaniserbara": "mekaniserbar",
    "mekaniserbarare": "mekaniserbar",
    "mekaniserbarares": "mekaniserbar",
    "mekaniserbaras": "mekaniserbar",
    "mekaniserbarast": "mekaniserbar",
    "mekaniserbaraste": "mekaniserbar",
    "mekaniserbarastes": "mekaniserbar",
    "mekaniserbarasts": "mekaniserbar",
    "mekaniserbare": "mekaniserbar",
    "mekaniserbares": "mekaniserbar",
    "mekaniserbarheten": "mekaniserbarhet",
    "mekaniserbarhetens": "mekaniserbarhet",
    "mekaniserbarhets": "mekaniserbarhet",
    "mekaniserbars": "mekaniserbar",
    "mekaniserbart": "mekaniserbar",
    "mekaniserbarts": "mekaniserbar",
    "mekaniseringar": "mekanisering",
    "mekaniseringarna": "mekanisering",
    "mekaniseringarnas": "mekanisering",
    "mekaniseringars": "mekanisering",
    "mekaniseringen": "mekanisering",
    "mekaniseringens": "mekanisering",
    "mekaniserings": "mekanisering",
    "mekaniska": "mekanisk",
    "mekaniskare": "mekanisk",
    "mekaniskares": "mekanisk",
    "mekaniskas": "mekanisk",
    "mekaniskast": "mekanisk",
    "mekaniskaste": "mekanisk",
    "mekaniskastes": "mekanisk",
    "mekaniskasts": "mekanisk",
    "mekaniske": "mekanisk",
    "mekaniskes": "mekanisk",
    "mekanisks": "mekanisk",
    "mekaniskt": "mekanisk",
    "mekaniskts": "mekanisk",
    "mekanismen": "mekanism",
    "mekanismens": "mekanism",
    "mekanismer": "mekanism",
    "mekanismerna": "mekanism",
    "mekanismernas": "mekanism",
    "mekanismers": "mekanism",
    "mekanisms": "mekanism",
    "mekanistiska": "mekanistisk",
    "mekanistiskare": "mekanistisk",
    "mekanistiskares": "mekanistisk",
    "mekanistiskas": "mekanistisk",
    "mekanistiskast": "mekanistisk",
    "mekanistiskaste": "mekanistisk",
    "mekanistiskastes": "mekanistisk",
    "mekanistiskasts": "mekanistisk",
    "mekanistiske": "mekanistisk",
    "mekanistiskes": "mekanistisk",
    "mekanistisks": "mekanistisk",
    "mekanistiskt": "mekanistisk",
    "mekanistiskts": "mekanistisk",
    "mekar": "meka",
    "mekas": "meka",
    "mekat": "meka",
    "mekats": "meka",
    "mekvänliga": "mekvänlig",
    "mekvänligare": "mekvänlig",
    "mekvänligares": "mekvänlig",
    "mekvänligas": "mekvänlig",
    "mekvänligast": "mekvänlig",
    "mekvänligaste": "mekvänlig",
    "mekvänligastes": "mekvänlig",
    "mekvänligasts": "mekvänlig",
    "mekvänlige": "mekvänlig",
    "mekvänliges": "mekvänlig",
    "mekvänligheten": "mekvänlighet",
    "mekvänlighetens": "mekvänlighet",
    "mekvänlighets": "mekvänlighet",
    "mekvänligs": "mekvänlig",
    "mekvänligt": "mekvänlig",
    "mekvänligts": "mekvänlig",
    "melanesiern": "melanesier",
    "melanesierna": "melanesier",
    "melanesiernas": "melanesier",
    "melanesierns": "melanesier",
    "melanesiers": "melanesier",
    "melanesiska": "melanesisk",
    "melanesiskan": "melanesiska",
    "melanesiskans": "melanesiska",
    "melanesiskare": "melanesisk",
    "melanesiskares": "melanesisk",
    "melanesiskas": "melanesiska",
    "melanesiskast": "melanesisk",
    "melanesiskaste": "melanesisk",
    "melanesiskastes": "melanesisk",
    "melanesiskasts": "melanesisk",
    "melanesiske": "melanesiska",
    "melanesiskes": "melanesisk",
    "melanesiskor": "melanesiska",
    "melanesiskorna": "melanesiska",
    "melanesiskornas": "melanesiska",
    "melanesiskors": "melanesiska",
    "melanesisks": "melanesisk",
    "melanesiskt": "melanesisk",
    "melanesiskts": "melanesisk",
    "melankolien": "melankoli",
    "melankoliens": "melankoli",
    "melankolikern": "melankoliker",
    "melankolikerna": "melankoliker",
    "melankolikernas": "melankoliker",
    "melankolikerns": "melankoliker",
    "melankolikers": "melankoliker",
    "melankolin": "melankoli",
    "melankolins": "melankoli",
    "melankolis": "melankoli",
    "melankoliska": "melankolisk",
    "melankoliskare": "melankolisk",
    "melankoliskares": "melankolisk",
    "melankoliskas": "melankolisk",
    "melankoliskast": "melankolisk",
    "melankoliskaste": "melankolisk",
    "melankoliskastes": "melankolisk",
    "melankoliskasts": "melankolisk",
    "melankoliske": "melankolisk",
    "melankoliskes": "melankolisk",
    "melankolisks": "melankolisk",
    "melankoliskt": "melankolisk",
    "melankoliskts": "melankolisk",
    "melanomen": "melanom",
    "melanomens": "melanom",
    "melanomet": "melanom",
    "melanomets": "melanom",
    "melanoms": "melanom",
    "melassen": "melass",
    "melassens": "melass",
    "melatoninen": "melatonin",
    "melatoninens": "melatonin",
    "melatoniner": "melatonin",
    "melatoninerna": "melatonin",
    "melatoninernas": "melatonin",
    "melatoniners": "melatonin",
    "melatoninnivåer": "melatoninnivå",
    "melatoninnivåerna": "melatoninnivå",
    "melatoninnivåernas": "melatoninnivå",
    "melatoninnivåers": "melatoninnivå",
    "melatoninnivån": "melatoninnivå",
    "melatoninnivåns": "melatoninnivå",
    "melatoninnivås": "melatoninnivå",
    "melatonins": "melatonin",
    "melerade": "melerad",
    "melerades": "melerad",
    "melerads": "melerad",
    "melerat": "melerad",
    "melerats": "melerad",
    "meliniten": "melinit",
    "melinitens": "melinit",
    "melinits": "melinit",
    "meliorationen": "melioration",
    "meliorationens": "melioration",
    "meliorationer": "melioration",
    "meliorationerna": "melioration",
    "meliorationernas": "melioration",
    "meliorationers": "melioration",
    "meliorations": "melioration",
    "mellanakten": "mellanakt",
    "mellanaktens": "mellanakt",
    "mellanakter": "mellanakt",
    "mellanakterna": "mellanakt",
    "mellanakternas": "mellanakt",
    "mellanakters": "mellanakt",
    "mellanakts": "mellanakt",
    "mellanboken": "mellanbok",
    "mellanbokens": "mellanbok",
    "mellanboks": "mellanbok",
    "mellanböcker": "mellanbok",
    "mellanböckerna": "mellanbok",
    "mellanböckernas": "mellanbok",
    "mellanböckers": "mellanbok",
    "mellandagar": "mellandag",
    "mellandagarna": "mellandag",
    "mellandagarnas": "mellandag",
    "mellandagars": "mellandag",
    "mellandagen": "mellandag",
    "mellandagens": "mellandag",
    "mellandags": "mellandag",
    "mellandäcken": "mellandäck",
    "mellandäckens": "mellandäck",
    "mellandäcket": "mellandäck",
    "mellandäckets": "mellandäck",
    "mellandäcks": "mellandäck",
    "mellanfolkliga": "mellanfolklig",
    "mellanfolkligare": "mellanfolklig",
    "mellanfolkligares": "mellanfolklig",
    "mellanfolkligas": "mellanfolklig",
    "mellanfolkligast": "mellanfolklig",
    "mellanfolkligaste": "mellanfolklig",
    "mellanfolkligastes": "mellanfolklig",
    "mellanfolkligasts": "mellanfolklig",
    "mellanfolklige": "mellanfolklig",
    "mellanfolkliges": "mellanfolklig",
    "mellanfolkligs": "mellanfolklig",
    "mellanfolkligt": "mellanfolklig",
    "mellanfolkligts": "mellanfolklig",
    "mellanformen": "mellanform",
    "mellanformens": "mellanform",
    "mellanformer": "mellanform",
    "mellanformerna": "mellanform",
    "mellanformernas": "mellanform",
    "mellanformers": "mellanform",
    "mellanforms": "mellanform",
    "mellanguldet": "mellanguld",
    "mellanguldets": "mellanguld",
    "mellangulds": "mellanguld",
    "mellangärden": "mellangärde",
    "mellangärdena": "mellangärde",
    "mellangärdenas": "mellangärde",
    "mellangärdens": "mellangärde",
    "mellangärdes": "mellangärde",
    "mellangärdet": "mellangärde",
    "mellangärdets": "mellangärde",
    "mellanhanden": "mellanhand",
    "mellanhandens": "mellanhand",
    "mellanhands": "mellanhand",
    "mellanhavanden": "mellanhavande",
    "mellanhavandena": "mellanhavande",
    "mellanhavandenas": "mellanhavande",
    "mellanhavandens": "mellanhavande",
    "mellanhavandes": "mellanhavande",
    "mellanhavandet": "mellanhavande",
    "mellanhavandets": "mellanhavande",
    "mellanheaten": "mellanheat",
    "mellanheatens": "mellanheat",
    "mellanheatet": "mellanheat",
    "mellanheatets": "mellanheat",
    "mellanheats": "mellanheat",
    "mellanhjärn": "mellanhjärna",
    "mellanhjärnan": "mellanhjärna",
    "mellanhjärnans": "mellanhjärna",
    "mellanhjärnas": "mellanhjärna",
    "mellanhjärne": "mellanhjärna",
    "mellanhjärnor": "mellanhjärna",
    "mellanhjärnorna": "mellanhjärna",
    "mellanhjärnornas": "mellanhjärna",
    "mellanhjärnors": "mellanhjärna",
    "mellanhjärns": "mellanhjärna",
    "mellanhoppen": "mellanhopp",
    "mellanhoppens": "mellanhopp",
    "mellanhoppet": "mellanhopp",
    "mellanhoppets": "mellanhopp",
    "mellanhopps": "mellanhopp",
    "mellanhänder": "mellanhand",
    "mellanhänderna": "mellanhand",
    "mellanhändernas": "mellanhand",
    "mellanhänders": "mellanhand",
    "mellankalven": "mellankalv",
    "mellankalvens": "mellankalv",
    "mellankalvs": "mellankalv",
    "mellankommunala": "mellankommunal",
    "mellankommunalare": "mellankommunal",
    "mellankommunalares": "mellankommunal",
    "mellankommunalas": "mellankommunal",
    "mellankommunalast": "mellankommunal",
    "mellankommunalaste": "mellankommunal",
    "mellankommunalastes": "mellankommunal",
    "mellankommunalasts": "mellankommunal",
    "mellankommunale": "mellankommunal",
    "mellankommunales": "mellankommunal",
    "mellankommunals": "mellankommunal",
    "mellankommunalt": "mellankommunal",
    "mellankommunalts": "mellankommunal",
    "mellankomsten": "mellankomst",
    "mellankomstens": "mellankomst",
    "mellankomsts": "mellankomst",
    "mellankrigstiden": "mellankrigstid",
    "mellankrigstidens": "mellankrigstid",
    "mellankrigstider": "mellankrigstid",
    "mellankrigstiderna": "mellankrigstid",
    "mellankrigstidernas": "mellankrigstid",
    "mellankrigstiders": "mellankrigstid",
    "mellankrigstids": "mellankrigstid",
    "mellankroppar": "mellankropp",
    "mellankropparna": "mellankropp",
    "mellankropparnas": "mellankropp",
    "mellankroppars": "mellankropp",
    "mellankroppen": "mellankropp",
    "mellankroppens": "mellankropp",
    "mellankropps": "mellankropp",
    "mellankulturen": "mellankultur",
    "mellankulturens": "mellankultur",
    "mellankulturer": "mellankultur",
    "mellankulturerna": "mellankultur",
    "mellankulturernas": "mellankultur",
    "mellankulturers": "mellankultur",
    "mellankulturs": "mellankultur",
    "mellanlandad": "mellanlanda",
    "mellanlandade": "mellanlanda",
    "mellanlandades": "mellanlanda",
    "mellanlandads": "mellanlanda",
    "mellanlandande": "mellanlanda",
    "mellanlandanden": "mellanlandande",
    "mellanlandandena": "mellanlandande",
    "mellanlandandenas": "mellanlandande",
    "mellanlandandens": "mellanlandande",
    "mellanlandandes": "mellanlandande",
    "mellanlandandet": "mellanlandande",
    "mellanlandandets": "mellanlandande",
    "mellanlandar": "mellanlanda",
    "mellanlandas": "mellanlanda",
    "mellanlandat": "mellanlanda",
    "mellanlandats": "mellanlanda",
    "mellanlandningar": "mellanlandning",
    "mellanlandningarna": "mellanlandning",
    "mellanlandningarnas": "mellanlandning",
    "mellanlandningars": "mellanlandning",
    "mellanlandningen": "mellanlandning",
    "mellanlandningens": "mellanlandning",
    "mellanlandnings": "mellanlandning",
    "mellanlägen": "mellanläge",
    "mellanlägena": "mellanläge",
    "mellanlägenas": "mellanläge",
    "mellanlägens": "mellanläge",
    "mellanläges": "mellanläge",
    "mellanläget": "mellanläge",
    "mellanlägets": "mellanläge",
    "mellanmålen": "mellanmål",
    "mellanmålens": "mellanmål",
    "mellanmålet": "mellanmål",
    "mellanmålets": "mellanmål",
    "mellanmåls": "mellanmål",
    "mellanmålstipsen": "mellanmålstips",
    "mellanmålstipsens": "mellanmålstips",
    "mellanmålstipset": "mellanmålstips",
    "mellanmålstipsets": "mellanmålstips",
    "mellanreven": "mellanrev",
    "mellanrevens": "mellanrev",
    "mellanrevet": "mellanrev",
    "mellanrevets": "mellanrev",
    "mellanrevs": "mellanrev",
    "mellanriksbanan": "mellanriksbana",
    "mellanriksbanans": "mellanriksbana",
    "mellanriksbanas": "mellanriksbana",
    "mellanriksbane": "mellanriksbana",
    "mellanriksbanor": "mellanriksbana",
    "mellanriksbanorna": "mellanriksbana",
    "mellanriksbanornas": "mellanriksbana",
    "mellanriksbanors": "mellanriksbana",
    "mellanriksvägar": "mellanriksväg",
    "mellanriksvägarna": "mellanriksväg",
    "mellanriksvägarnas": "mellanriksväg",
    "mellanriksvägars": "mellanriksväg",
    "mellanriksvägen": "mellanriksväg",
    "mellanriksvägens": "mellanriksväg",
    "mellanriksvägs": "mellanriksväg",
    "mellanrummen": "mellanrum",
    "mellanrummens": "mellanrum",
    "mellanrummet": "mellanrum",
    "mellanrummets": "mellanrum",
    "mellanrums": "mellanrum",
    "mellanrumsföreningar": "mellanrumsförening",
    "mellanrumsföreningarna": "mellanrumsförening",
    "mellanrumsföreningarnas": "mellanrumsförening",
    "mellanrumsföreningars": "mellanrumsförening",
    "mellanrumsföreningen": "mellanrumsförening",
    "mellanrumsföreningens": "mellanrumsförening",
    "mellanrumsförenings": "mellanrumsförening",
    "mellanrätten": "mellanrätt",
    "mellanrättens": "mellanrätt",
    "mellanrätter": "mellanrätt",
    "mellanrätterna": "mellanrätt",
    "mellanrätternas": "mellanrätt",
    "mellanrätters": "mellanrätt",
    "mellanrätts": "mellanrätt",
    "mellanskikten": "mellanskikt",
    "mellanskiktens": "mellanskikt",
    "mellanskiktet": "mellanskikt",
    "mellanskiktets": "mellanskikt",
    "mellanskikts": "mellanskikt",
    "mellanskillnaden": "mellanskillnad",
    "mellanskillnadens": "mellanskillnad",
    "mellanskillnader": "mellanskillnad",
    "mellanskillnaderna": "mellanskillnad",
    "mellanskillnadernas": "mellanskillnad",
    "mellanskillnaders": "mellanskillnad",
    "mellanskillnads": "mellanskillnad",
    "mellanslagen": "mellanslag",
    "mellanslagens": "mellanslag",
    "mellanslaget": "mellanslag",
    "mellanslagets": "mellanslag",
    "mellanslags": "mellanslag",
    "mellanspelen": "mellanspel",
    "mellanspelens": "mellanspel",
    "mellanspelet": "mellanspel",
    "mellanspelets": "mellanspel",
    "mellanspels": "mellanspel",
    "mellanspettar": "mellanspett",
    "mellanspettarna": "mellanspett",
    "mellanspettarnas": "mellanspett",
    "mellanspettars": "mellanspett",
    "mellanspetten": "mellanspett",
    "mellanspettens": "mellanspett",
    "mellanspetts": "mellanspett",
    "mellanstadie": "mellanstadium",
    "mellanstadier": "mellanstadium",
    "mellanstadierna": "mellanstadium",
    "mellanstadiernas": "mellanstadium",
    "mellanstadiers": "mellanstadium",
    "mellanstadiet": "mellanstadium",
    "mellanstadiets": "mellanstadium",
    "mellanstadiums": "mellanstadium",
    "mellanstatliga": "mellanstatlig",
    "mellanstatligare": "mellanstatlig",
    "mellanstatligares": "mellanstatlig",
    "mellanstatligas": "mellanstatlig",
    "mellanstatligast": "mellanstatlig",
    "mellanstatligaste": "mellanstatlig",
    "mellanstatligastes": "mellanstatlig",
    "mellanstatligasts": "mellanstatlig",
    "mellanstatlige": "mellanstatlig",
    "mellanstatliges": "mellanstatlig",
    "mellanstatligs": "mellanstatlig",
    "mellanstatligt": "mellanstatlig",
    "mellanstatligts": "mellanstatlig",
    "mellansticken": "mellanstick",
    "mellanstickens": "mellanstick",
    "mellansticket": "mellanstick",
    "mellanstickets": "mellanstick",
    "mellansticks": "mellanstick",
    "mellanstora": "mellanstor",
    "mellanstoras": "mellanstor",
    "mellanstore": "mellanstor",
    "mellanstores": "mellanstor",
    "mellanstors": "mellanstor",
    "mellanstort": "mellanstor",
    "mellanstorts": "mellanstor",
    "mellanströmbrytar": "mellanströmbrytare",
    "mellanströmbrytaren": "mellanströmbrytare",
    "mellanströmbrytarens": "mellanströmbrytare",
    "mellanströmbrytares": "mellanströmbrytare",
    "mellanströmbrytarna": "mellanströmbrytare",
    "mellanströmbrytarnas": "mellanströmbrytare",
    "mellansubstansen": "mellansubstans",
    "mellansubstansens": "mellansubstans",
    "mellansubstanser": "mellansubstans",
    "mellansubstanserna": "mellansubstans",
    "mellansubstansernas": "mellansubstans",
    "mellansubstansers": "mellansubstans",
    "mellansvenska": "mellansvensk",
    "mellansvenskare": "mellansvensk",
    "mellansvenskares": "mellansvensk",
    "mellansvenskas": "mellansvensk",
    "mellansvenskast": "mellansvensk",
    "mellansvenskaste": "mellansvensk",
    "mellansvenskastes": "mellansvensk",
    "mellansvenskasts": "mellansvensk",
    "mellansvenske": "mellansvensk",
    "mellansvenskes": "mellansvensk",
    "mellansvensks": "mellansvensk",
    "mellansvenskt": "mellansvensk",
    "mellansvenskts": "mellansvensk",
    "mellantiden": "mellantid",
    "mellantidens": "mellantid",
    "mellantider": "mellantid",
    "mellantiderna": "mellantid",
    "mellantidernas": "mellantid",
    "mellantiders": "mellantid",
    "mellantids": "mellantid",
    "mellantingen": "mellanting",
    "mellantingens": "mellanting",
    "mellantinget": "mellanting",
    "mellantingets": "mellanting",
    "mellantings": "mellanting",
    "mellanverken": "mellanverk",
    "mellanverkens": "mellanverk",
    "mellanverket": "mellanverk",
    "mellanverkets": "mellanverk",
    "mellanverks": "mellanverk",
    "mellanvikten": "mellanvikt",
    "mellanviktens": "mellanvikt",
    "mellanvikts": "mellanvikt",
    "mellanvägar": "mellanväg",
    "mellanvägarna": "mellanväg",
    "mellanvägarnas": "mellanväg",
    "mellanvägars": "mellanväg",
    "mellanvägen": "mellanväg",
    "mellanvägens": "mellanväg",
    "mellanväggar": "mellanvägg",
    "mellanväggarna": "mellanvägg",
    "mellanväggarnas": "mellanvägg",
    "mellanväggars": "mellanvägg",
    "mellanväggen": "mellanvägg",
    "mellanväggens": "mellanvägg",
    "mellanväggs": "mellanvägg",
    "mellanvägs": "mellanväg",
    "mellanvärdar": "mellanvärd",
    "mellanvärdarna": "mellanvärd",
    "mellanvärdarnas": "mellanvärd",
    "mellanvärdars": "mellanvärd",
    "mellanvärden": "mellanvärd",
    "mellanvärdens": "mellanvärd",
    "mellanvärds": "mellanvärd",
    "mellanvågen": "mellanvåg",
    "mellanvågens": "mellanvåg",
    "mellanvågor": "mellanvåg",
    "mellanvågorna": "mellanvåg",
    "mellanvågornas": "mellanvåg",
    "mellanvågors": "mellanvåg",
    "mellanvågs": "mellanvåg",
    "mellanvåningar": "mellanvåning",
    "mellanvåningarna": "mellanvåning",
    "mellanvåningarnas": "mellanvåning",
    "mellanvåningars": "mellanvåning",
    "mellanvåningen": "mellanvåning",
    "mellanvåningens": "mellanvåning",
    "mellanvånings": "mellanvåning",
    "mellanölen": "mellanöl",
    "mellanölens": "mellanöl",
    "mellanölet": "mellanöl",
    "mellanölets": "mellanöl",
    "mellanöls": "mellanöl",
    "mellanöras": "mellanöra",
    "mellanörat": "mellanöra",
    "mellanörats": "mellanöra",
    "mellanöron": "mellanöra",
    "mellanöronen": "mellanöra",
    "mellanöronens": "mellanöra",
    "mellanörons": "mellanöra",
    "mellerstas": "mellersta",
    "melodien": "melodi",
    "melodiens": "melodi",
    "melodier": "melodi",
    "melodierna": "melodi",
    "melodiernas": "melodi",
    "melodiers": "melodi",
    "melodiken": "melodik",
    "melodikens": "melodik",
    "melodiks": "melodik",
    "melodin": "melodi",
    "melodins": "melodi",
    "melodiradion": "melodiradio",
    "melodiradions": "melodiradio",
    "melodiradios": "melodiradio",
    "melodis": "melodi",
    "melodiska": "melodisk",
    "melodiskare": "melodisk",
    "melodiskares": "melodisk",
    "melodiskas": "melodisk",
    "melodiskast": "melodisk",
    "melodiskaste": "melodisk",
    "melodiskastes": "melodisk",
    "melodiskasts": "melodisk",
    "melodiske": "melodisk",
    "melodiskes": "melodisk",
    "melodisks": "melodisk",
    "melodiskt": "melodisk",
    "melodiskts": "melodisk",
    "melodistämman": "melodistämma",
    "melodistämmans": "melodistämma",
    "melodistämmas": "melodistämma",
    "melodistämme": "melodistämma",
    "melodistämmo": "melodistämma",
    "melodistämmor": "melodistämma",
    "melodistämmorna": "melodistämma",
    "melodistämmornas": "melodistämma",
    "melodistämmors": "melodistämma",
    "melodiösa": "melodiös",
    "melodiösare": "melodiös",
    "melodiösares": "melodiös",
    "melodiösas": "melodiös",
    "melodiösast": "melodiös",
    "melodiösaste": "melodiös",
    "melodiösastes": "melodiös",
    "melodiösasts": "melodiös",
    "melodiöse": "melodiös",
    "melodiöses": "melodiös",
    "melodiöst": "melodiös",
    "melodiösts": "melodiös",
    "melodramatiska": "melodramatisk",
    "melodramatiskare": "melodramatisk",
    "melodramatiskares": "melodramatisk",
    "melodramatiskas": "melodramatisk",
    "melodramatiskast": "melodramatisk",
    "melodramatiskaste": "melodramatisk",
    "melodramatiskastes": "melodramatisk",
    "melodramatiskasts": "melodramatisk",
    "melodramatiske": "melodramatisk",
    "melodramatiskes": "melodramatisk",
    "melodramatisks": "melodramatisk",
    "melodramatiskt": "melodramatisk",
    "melodramatiskts": "melodramatisk",
    "melodramen": "melodram",
    "melodramens": "melodram",
    "melodramer": "melodram",
    "melodramerna": "melodram",
    "melodramernas": "melodram",
    "melodramers": "melodram",
    "melodrams": "melodram",
    "melon": "meloner",
    "melonen": "melon",
    "melonens": "melon",
    "meloner": "melon",
    "melonerna": "meloner",
    "melonernas": "meloner",
    "meloners": "meloner",
    "melons": "meloner",
    "melonäpplen": "melonäpple",
    "melonäpplena": "melonäpple",
    "melonäpplenas": "melonäpple",
    "melonäpplens": "melonäpple",
    "melonäpples": "melonäpple",
    "melonäpplet": "melonäpple",
    "melonäpplets": "melonäpple",
    "melonäppls": "melonäpple",
    "membra": "membrum",
    "membrana": "membrum",
    "membranas": "membrum",
    "membranen": "membran",
    "membranens": "membran",
    "membraner": "membran",
    "membranerna": "membran",
    "membranernas": "membran",
    "membraners": "membran",
    "membranet": "membran",
    "membranets": "membran",
    "membrans": "membran",
    "membranskadan": "membranskada",
    "membranskadans": "membranskada",
    "membranskadas": "membranskada",
    "membranskade": "membranskada",
    "membranskador": "membranskada",
    "membranskadorna": "membranskada",
    "membranskadornas": "membranskada",
    "membranskadors": "membranskada",
    "membras": "membrum",
    "membrena": "membrum",
    "membrenas": "membrum",
    "membrer": "membrum",
    "membrers": "membrum",
    "membret": "membrum",
    "membrets": "membrum",
    "membrumen": "membrum",
    "membrumens": "membrum",
    "membrumet": "membrum",
    "membrumets": "membrum",
    "membrums": "membrum",
    "mementon": "memento",
    "mementona": "memento",
    "mementonas": "memento",
    "mementons": "memento",
    "mementos": "memento",
    "mementot": "memento",
    "mementots": "memento",
    "memoar": "memoarer",
    "memoarboken": "memoarbok",
    "memoarbokens": "memoarbok",
    "memoarboks": "memoarbok",
    "memoarböcker": "memoarbok",
    "memoarböckerna": "memoarbok",
    "memoarböckernas": "memoarbok",
    "memoarböckers": "memoarbok",
    "memoarerna": "memoarer",
    "memoarernas": "memoarer",
    "memoarers": "memoarer",
    "memoars": "memoarer",
    "memoranda": "memorandum",
    "memorandana": "memorandum",
    "memorandanas": "memorandum",
    "memorandas": "memorandum",
    "memorandumet": "memorandum",
    "memorandumets": "memorandum",
    "memorandums": "memorandum",
    "memorerad": "memorera",
    "memorerade": "memorera",
    "memorerades": "memorera",
    "memorerads": "memorera",
    "memorerande": "memorera",
    "memoreranden": "memorerande",
    "memorerandena": "memorerande",
    "memorerandenas": "memorerande",
    "memorerandens": "memorerande",
    "memorerandes": "memorerande",
    "memorerandet": "memorerande",
    "memorerandets": "memorerande",
    "memorerar": "memorera",
    "memoreras": "memorera",
    "memorerat": "memorera",
    "memorerats": "memorera",
    "memorerbara": "memorerbar",
    "memorerbarare": "memorerbar",
    "memorerbarares": "memorerbar",
    "memorerbaras": "memorerbar",
    "memorerbarast": "memorerbar",
    "memorerbaraste": "memorerbar",
    "memorerbarastes": "memorerbar",
    "memorerbarasts": "memorerbar",
    "memorerbare": "memorerbar",
    "memorerbares": "memorerbar",
    "memorerbarheten": "memorerbarhet",
    "memorerbarhetens": "memorerbarhet",
    "memorerbarhets": "memorerbarhet",
    "memorerbars": "memorerbar",
    "memorerbart": "memorerbar",
    "memorerbarts": "memorerbar",
    "memoreringar": "memorering",
    "memoreringarna": "memorering",
    "memoreringarnas": "memorering",
    "memoreringars": "memorering",
    "memoreringen": "memorering",
    "memoreringens": "memorering",
    "memorerings": "memorering",
    "memorialen": "memorial",
    "memorialens": "memorial",
    "memorialer": "memorial",
    "memorialerna": "memorial",
    "memorialernas": "memorial",
    "memorialers": "memorial",
    "memorialet": "memorial",
    "memorialets": "memorial",
    "memorials": "memorial",
    "men": "mena",
    "menad": "mena",
    "menade": "mena",
    "menades": "mena",
    "menads": "mena",
    "menagerier": "menageri",
    "menagerierna": "menageri",
    "menageriernas": "menageri",
    "menageriers": "menageri",
    "menageriet": "menageri",
    "menageriets": "menageri",
    "menageris": "menageri",
    "menagerit": "menageri",
    "menagerits": "menageri",
    "menande": "mena",
    "menanden": "menande",
    "menandena": "menande",
    "menandenas": "menande",
    "menandens": "menande",
    "menandes": "menande",
    "menandet": "menande",
    "menandets": "menande",
    "menar": "mena",
    "menas": "mena",
    "menat": "mena",
    "menats": "mena",
    "mend": "mena",
    "menda": "mena",
    "mendas": "mena",
    "mende": "mena",
    "mendeleviet": "mendelevium",
    "mendeleviets": "mendelevium",
    "mendeleviumet": "mendelevium",
    "mendeleviumets": "mendelevium",
    "mendeleviums": "mendelevium",
    "mendelismen": "mendelism",
    "mendelismens": "mendelism",
    "mendelismer": "mendelism",
    "mendelismerna": "mendelism",
    "mendelismernas": "mendelism",
    "mendelismers": "mendelism",
    "mendelisms": "mendelism",
    "mendelistiska": "mendelistisk",
    "mendelistiskare": "mendelistisk",
    "mendelistiskares": "mendelistisk",
    "mendelistiskas": "mendelistisk",
    "mendelistiskast": "mendelistisk",
    "mendelistiskaste": "mendelistisk",
    "mendelistiskastes": "mendelistisk",
    "mendelistiskasts": "mendelistisk",
    "mendelistiske": "mendelistisk",
    "mendelistiskes": "mendelistisk",
    "mendelistisks": "mendelistisk",
    "mendelistiskt": "mendelistisk",
    "mendelistiskts": "mendelistisk",
    "mendelska": "mendelsk",
    "mendelskare": "mendelsk",
    "mendelskares": "mendelsk",
    "mendelskas": "mendelsk",
    "mendelskast": "mendelsk",
    "mendelskaste": "mendelsk",
    "mendelskastes": "mendelsk",
    "mendelskasts": "mendelsk",
    "mendelske": "mendelsk",
    "mendelskes": "mendelsk",
    "mendelsks": "mendelsk",
    "mendelskt": "mendelsk",
    "mendelskts": "mendelsk",
    "mendes": "mena",
    "mends": "mena",
    "menedar": "menedare",
    "menedaren": "menedare",
    "menedarens": "menedare",
    "menedares": "menedare",
    "menedarna": "menedare",
    "menedarnas": "menedare",
    "meneden": "mened",
    "menedens": "mened",
    "meneder": "mened",
    "menederna": "mened",
    "menedernas": "mened",
    "meneders": "mened",
    "meneds": "mened",
    "menen": "men",
    "menens": "men",
    "menet": "men",
    "menets": "men",
    "menfören": "menföre",
    "menförena": "menföre",
    "menförenas": "menföre",
    "menförens": "menföre",
    "menföres": "menföre",
    "menföret": "menföre",
    "menförets": "menföre",
    "meniga": "menig",
    "menigare": "menig",
    "menigares": "menig",
    "menigas": "menig",
    "menigast": "menig",
    "menigaste": "menig",
    "menigastes": "menig",
    "menigasts": "menig",
    "menige": "menig",
    "meniges": "menig",
    "menigheten": "menighet",
    "menighetens": "menighet",
    "menigheter": "menighet",
    "menigheterna": "menighet",
    "menigheternas": "menighet",
    "menigheters": "menighet",
    "menighets": "menighet",
    "menigs": "menig",
    "menigt": "menig",
    "menigts": "menig",
    "meningar": "mening",
    "meningarna": "mening",
    "meningarnas": "mening",
    "meningars": "mening",
    "meningen": "mening",
    "meningens": "mening",
    "meningiten": "meningit",
    "meningitens": "meningit",
    "meningits": "meningit",
    "menings": "mening",
    "meningsbrytningar": "meningsbrytning",
    "meningsbrytningarna": "meningsbrytning",
    "meningsbrytningarnas": "meningsbrytning",
    "meningsbrytningars": "meningsbrytning",
    "meningsbrytningen": "meningsbrytning",
    "meningsbrytningens": "meningsbrytning",
    "meningsbrytnings": "meningsbrytning",
    "meningsbyggnaden": "meningsbyggnad",
    "meningsbyggnadens": "meningsbyggnad",
    "meningsbyggnader": "meningsbyggnad",
    "meningsbyggnaderna": "meningsbyggnad",
    "meningsbyggnadernas": "meningsbyggnad",
    "meningsbyggnaders": "meningsbyggnad",
    "meningsbyggnads": "meningsbyggnad",
    "meningsbyten": "meningsbyte",
    "meningsbytena": "meningsbyte",
    "meningsbytenas": "meningsbyte",
    "meningsbytens": "meningsbyte",
    "meningsbytes": "meningsbyte",
    "meningsbytet": "meningsbyte",
    "meningsbytets": "meningsbyte",
    "meningsfränden": "meningsfrände",
    "meningsfrändens": "meningsfrände",
    "meningsfränder": "meningsfrände",
    "meningsfränderna": "meningsfrände",
    "meningsfrändernas": "meningsfrände",
    "meningsfränders": "meningsfrände",
    "meningsfrändes": "meningsfrände",
    "meningsfulla": "meningsfull",
    "meningsfullare": "meningsfull",
    "meningsfullares": "meningsfull",
    "meningsfullas": "meningsfull",
    "meningsfullast": "meningsfull",
    "meningsfullaste": "meningsfull",
    "meningsfullastes": "meningsfull",
    "meningsfullasts": "meningsfull",
    "meningsfulle": "meningsfull",
    "meningsfulles": "meningsfull",
    "meningsfullheten": "meningsfullhet",
    "meningsfullhetens": "meningsfullhet",
    "meningsfullhets": "meningsfullhet",
    "meningsfulls": "meningsfull",
    "meningsfullt": "meningsfull",
    "meningsfullts": "meningsfull",
    "meningsfyllda": "meningsfylld",
    "meningsfylldare": "meningsfylld",
    "meningsfylldares": "meningsfylld",
    "meningsfylldas": "meningsfylld",
    "meningsfylldast": "meningsfylld",
    "meningsfylldaste": "meningsfylld",
    "meningsfylldastes": "meningsfylld",
    "meningsfylldasts": "meningsfylld",
    "meningsfyllde": "meningsfylld",
    "meningsfylldes": "meningsfylld",
    "meningsfylldheten": "meningsfylldhet",
    "meningsfylldhetens": "meningsfylldhet",
    "meningsfylldhets": "meningsfylldhet",
    "meningsfyllds": "meningsfylld",
    "meningsfyllt": "meningsfylld",
    "meningsfyllts": "meningsfylld",
    "meningslösa": "meningslös",
    "meningslösare": "meningslös",
    "meningslösares": "meningslös",
    "meningslösas": "meningslös",
    "meningslösast": "meningslös",
    "meningslösaste": "meningslös",
    "meningslösastes": "meningslös",
    "meningslösasts": "meningslös",
    "meningslöse": "meningslös",
    "meningslöses": "meningslös",
    "meningslösheten": "meningslöshet",
    "meningslöshetens": "meningslöshet",
    "meningslösheter": "meningslöshet",
    "meningslösheterna": "meningslöshet",
    "meningslösheternas": "meningslöshet",
    "meningslösheters": "meningslöshet",
    "meningslöshets": "meningslöshet",
    "meningslöst": "meningslös",
    "meningslösts": "meningslös",
    "meningsmotståndar": "meningsmotståndare",
    "meningsmotståndaren": "meningsmotståndare",
    "meningsmotståndarens": "meningsmotståndare",
    "meningsmotståndares": "meningsmotståndare",
    "meningsmotståndarna": "meningsmotståndare",
    "meningsmotståndarnas": "meningsmotståndare",
    "meningsriktningar": "meningsriktning",
    "meningsriktningarna": "meningsriktning",
    "meningsriktningarnas": "meningsriktning",
    "meningsriktningars": "meningsriktning",
    "meningsriktningen": "meningsriktning",
    "meningsriktningens": "meningsriktning",
    "meningsriktnings": "meningsriktning",
    "meningsskiljaktigheten": "meningsskiljaktighet",
    "meningsskiljaktighetens": "meningsskiljaktighet",
    "meningsskiljaktigheter": "meningsskiljaktighet",
    "meningsskiljaktigheterna": "meningsskiljaktighet",
    "meningsskiljaktigheternas": "meningsskiljaktighet",
    "meningsskiljaktigheters": "meningsskiljaktighet",
    "meningsskiljaktighets": "meningsskiljaktighet",
    "meningsutbyten": "meningsutbyte",
    "meningsutbytena": "meningsutbyte",
    "meningsutbytenas": "meningsutbyte",
    "meningsutbytens": "meningsutbyte",
    "meningsutbytes": "meningsutbyte",
    "meningsutbytet": "meningsutbyte",
    "meningsutbytets": "meningsutbyte",
    "meningsyttringar": "meningsyttring",
    "meningsyttringarna": "meningsyttring",
    "meningsyttringarnas": "meningsyttring",
    "meningsyttringars": "meningsyttring",
    "meningsyttringen": "meningsyttring",
    "meningsyttringens": "meningsyttring",
    "meningsyttrings": "meningsyttring",
    "menisken": "menisk",
    "meniskens": "menisk",
    "menisker": "menisk",
    "meniskerna": "menisk",
    "meniskernas": "menisk",
    "meniskers": "menisk",
    "menisks": "menisk",
    "menliga": "menlig",
    "menligare": "menlig",
    "menligares": "menlig",
    "menligas": "menlig",
    "menligast": "menlig",
    "menligaste": "menlig",
    "menligastes": "menlig",
    "menligasts": "menlig",
    "menlige": "menlig",
    "menliges": "menlig",
    "menligheten": "menlighet",
    "menlighetens": "menlighet",
    "menlighets": "menlighet",
    "menligs": "menlig",
    "menligt": "menlig",
    "menligts": "menlig",
    "menlösa": "menlös",
    "menlösare": "menlös",
    "menlösares": "menlös",
    "menlösas": "menlös",
    "menlösast": "menlös",
    "menlösaste": "menlös",
    "menlösastes": "menlös",
    "menlösasts": "menlös",
    "menlöse": "menlös",
    "menlöses": "menlös",
    "menlösheten": "menlöshet",
    "menlöshetens": "menlöshet",
    "menlösheter": "menlöshet",
    "menlösheterna": "menlöshet",
    "menlösheternas": "menlöshet",
    "menlösheters": "menlöshet",
    "menlöshets": "menlöshet",
    "menlöst": "menlös",
    "menlösts": "menlös",
    "menopausen": "menopaus",
    "menopausens": "menopaus",
    "menopauser": "menopaus",
    "menopauserna": "menopaus",
    "menopausernas": "menopaus",
    "menopausers": "menopaus",
    "mens": "men",
    "mensen": "mens",
    "mensens": "mens",
    "menstruationen": "menstruation",
    "menstruationens": "menstruation",
    "menstruationer": "menstruation",
    "menstruationerna": "menstruation",
    "menstruationernas": "menstruation",
    "menstruationers": "menstruation",
    "menstruations": "menstruation",
    "menstruationscykeln": "menstruationscykel",
    "menstruationscykelns": "menstruationscykel",
    "menstruationscykels": "menstruationscykel",
    "menstruationscyklar": "menstruationscykel",
    "menstruationscyklarna": "menstruationscykel",
    "menstruationscyklarnas": "menstruationscykel",
    "menstruationscyklars": "menstruationscykel",
    "menstruationscykler": "menstruationscykel",
    "menstruationscyklerna": "menstruationscykel",
    "menstruationscyklernas": "menstruationscykel",
    "menstruationscyklers": "menstruationscykel",
    "menstruerade": "menstruera",
    "menstruerades": "menstruera",
    "menstruerande": "menstruera",
    "menstrueranden": "menstruerande",
    "menstruerandena": "menstruerande",
    "menstruerandenas": "menstruerande",
    "menstruerandens": "menstruerande",
    "menstruerandes": "menstruerande",
    "menstruerandet": "menstruerande",
    "menstruerandets": "menstruerande",
    "menstruerar": "menstruera",
    "menstrueras": "menstruera",
    "menstruerat": "menstruera",
    "menstruerats": "menstruera",
    "menstrueringar": "menstruering",
    "menstrueringarna": "menstruering",
    "menstrueringarnas": "menstruering",
    "menstrueringars": "menstruering",
    "menstrueringen": "menstruering",
    "menstrueringens": "menstruering",
    "menstruerings": "menstruering",
    "mensuren": "mensur",
    "mensurens": "mensur",
    "mensurer": "mensur",
    "mensurerna": "mensur",
    "mensurernas": "mensur",
    "mensurers": "mensur",
    "mensurs": "mensur",
    "mensvärken": "mensvärk",
    "mensvärkens": "mensvärk",
    "mensvärks": "mensvärk",
    "ment": "mena",
    "mentala": "mental",
    "mentalare": "mental",
    "mentalares": "mental",
    "mentalas": "mental",
    "mentalast": "mental",
    "mentalaste": "mental",
    "mentalastes": "mental",
    "mentalasts": "mental",
    "mentale": "mental",
    "mentales": "mental",
    "mentalhygienen": "mentalhygien",
    "mentalhygienens": "mentalhygien",
    "mentalhygiens": "mentalhygien",
    "mentalismen": "mentalism",
    "mentalismens": "mentalism",
    "mentalismer": "mentalism",
    "mentalismerna": "mentalism",
    "mentalismernas": "mentalism",
    "mentalismers": "mentalism",
    "mentalisms": "mentalism",
    "mentalistiska": "mentalistisk",
    "mentalistiskas": "mentalistisk",
    "mentalistiske": "mentalistisk",
    "mentalistiskes": "mentalistisk",
    "mentalistisks": "mentalistisk",
    "mentalistiskt": "mentalistisk",
    "mentalistiskts": "mentalistisk",
    "mentaliteten": "mentalitet",
    "mentalitetens": "mentalitet",
    "mentaliteter": "mentalitet",
    "mentaliteterna": "mentalitet",
    "mentaliteternas": "mentalitet",
    "mentaliteters": "mentalitet",
    "mentalitets": "mentalitet",
    "mentalkliniken": "mentalklinik",
    "mentalklinikens": "mentalklinik",
    "mentalkliniker": "mentalklinik",
    "mentalklinikerna": "mentalklinik",
    "mentalklinikernas": "mentalklinik",
    "mentalklinikers": "mentalklinik",
    "mentalkliniks": "mentalklinik",
    "mentals": "mental",
    "mentalsjuka": "mentalsjuk",
    "mentalsjukare": "mentalsjuk",
    "mentalsjukares": "mentalsjuk",
    "mentalsjukas": "mentalsjuk",
    "mentalsjukast": "mentalsjuk",
    "mentalsjukaste": "mentalsjuk",
    "mentalsjukastes": "mentalsjuk",
    "mentalsjukasts": "mentalsjuk",
    "mentalsjukdomar": "mentalsjukdom",
    "mentalsjukdomarna": "mentalsjukdom",
    "mentalsjukdomarnas": "mentalsjukdom",
    "mentalsjukdomars": "mentalsjukdom",
    "mentalsjukdomen": "mentalsjukdom",
    "mentalsjukdomens": "mentalsjukdom",
    "mentalsjukdoms": "mentalsjukdom",
    "mentalsjuke": "mentalsjuk",
    "mentalsjukes": "mentalsjuk",
    "mentalsjukheten": "mentalsjukhet",
    "mentalsjukhetens": "mentalsjukhet",
    "mentalsjukhets": "mentalsjukhet",
    "mentalsjukhusen": "mentalsjukhus",
    "mentalsjukhusens": "mentalsjukhus",
    "mentalsjukhuset": "mentalsjukhus",
    "mentalsjukhusets": "mentalsjukhus",
    "mentalsjuks": "mentalsjuk",
    "mentalsjukt": "mentalsjuk",
    "mentalsjukts": "mentalsjuk",
    "mentalt": "mental",
    "mentalts": "mental",
    "mentalvårdar": "mentalvård",
    "mentalvårdarna": "mentalvård",
    "mentalvårdarnas": "mentalvård",
    "mentalvårdars": "mentalvård",
    "mentalvården": "mentalvård",
    "mentalvårdens": "mentalvård",
    "mentalvårds": "mentalvård",
    "mentalvårdsinrättningar": "mentalvårdsinrättning",
    "mentalvårdsinrättningarna": "mentalvårdsinrättning",
    "mentalvårdsinrättningarnas": "mentalvårdsinrättning",
    "mentalvårdsinrättningars": "mentalvårdsinrättning",
    "mentalvårdsinrättningen": "mentalvårdsinrättning",
    "mentalvårdsinrättningens": "mentalvårdsinrättning",
    "mentalvårdsinrättnings": "mentalvårdsinrättning",
    "mente": "mena",
    "mentes": "mena",
    "mentolen": "mentol",
    "mentolens": "mentol",
    "mentols": "mentol",
    "mentometern": "mentometer",
    "mentometerns": "mentometer",
    "mentometers": "mentometer",
    "mentometrar": "mentometer",
    "mentometrarna": "mentometer",
    "mentometrarnas": "mentometer",
    "mentometrars": "mentometer",
    "mentorer": "mentor",
    "mentorerna": "mentor",
    "mentorernas": "mentor",
    "mentorers": "mentor",
    "mentorn": "mentor",
    "mentorns": "mentor",
    "mentors": "mentor",
    "ments": "mena",
    "menuetten": "menuett",
    "menuettens": "menuett",
    "menuetter": "menuett",
    "menuetterna": "menuett",
    "menuetternas": "menuett",
    "menuetters": "menuett",
    "menuetts": "menuett",
    "menyer": "meny",
    "menyerna": "meny",
    "menyernas": "meny",
    "menyers": "meny",
    "menyförslagen": "menyförslag",
    "menyförslagens": "menyförslag",
    "menyförslaget": "menyförslag",
    "menyförslagets": "menyförslag",
    "menyförslags": "menyförslag",
    "menyn": "meny",
    "menyns": "meny",
    "menys": "meny",
    "mer": "mycket",
    "mera": "mycket",
    "merarbeten": "merarbete",
    "merarbetena": "merarbete",
    "merarbetenas": "merarbete",
    "merarbetens": "merarbete",
    "merarbetes": "merarbete",
    "merarbetet": "merarbete",
    "merarbetets": "merarbete",
    "merarbets": "merarbete",
    "meras": "mycken",
    "merbemälda": "merbemäld",
    "merbemäldare": "merbemäld",
    "merbemäldares": "merbemäld",
    "merbemäldas": "merbemäld",
    "merbemäldast": "merbemäld",
    "merbemäldaste": "merbemäld",
    "merbemäldastes": "merbemäld",
    "merbemäldasts": "merbemäld",
    "merbemälde": "merbemäld",
    "merbemäldes": "merbemäld",
    "merbemälds": "merbemäld",
    "merbemält": "merbemäld",
    "merbemälts": "merbemäld",
    "mercans": "merca",
    "mercedesarna": "mercedes",
    "mercedesars": "mercedes",
    "mercedesen": "mercedes",
    "merceriserad": "mercerisera",
    "merceriserade": "mercerisera",
    "merceriserades": "mercerisera",
    "merceriserads": "mercerisera",
    "merceriserande": "mercerisera",
    "merceriseranden": "merceriserande",
    "merceriserandena": "merceriserande",
    "merceriserandenas": "merceriserande",
    "merceriserandens": "merceriserande",
    "merceriserandes": "merceriserande",
    "merceriserandet": "merceriserande",
    "merceriserandets": "merceriserande",
    "merceriserar": "mercerisera",
    "merceriseras": "mercerisera",
    "merceriserat": "mercerisera",
    "merceriserats": "mercerisera",
    "merceriserbara": "merceriserbar",
    "merceriserbarare": "merceriserbar",
    "merceriserbarares": "merceriserbar",
    "merceriserbaras": "merceriserbar",
    "merceriserbarast": "merceriserbar",
    "merceriserbaraste": "merceriserbar",
    "merceriserbarastes": "merceriserbar",
    "merceriserbarasts": "merceriserbar",
    "merceriserbare": "merceriserbar",
    "merceriserbares": "merceriserbar",
    "merceriserbarheten": "merceriserbarhet",
    "merceriserbarhetens": "merceriserbarhet",
    "merceriserbarhets": "merceriserbarhet",
    "merceriserbars": "merceriserbar",
    "merceriserbart": "merceriserbar",
    "merceriserbarts": "merceriserbar",
    "merceriseringar": "mercerisering",
    "merceriseringarna": "mercerisering",
    "merceriseringarnas": "mercerisering",
    "merceriseringars": "mercerisering",
    "merceriseringen": "mercerisering",
    "merceriseringens": "mercerisering",
    "merceriserings": "mercerisering",
    "mercor": "merca",
    "mercornas": "merca",
    "mercors": "merca",
    "meridiancirkeln": "meridiancirkel",
    "meridiancirkelns": "meridiancirkel",
    "meridiancirkels": "meridiancirkel",
    "meridiancirklar": "meridiancirkel",
    "meridiancirklarna": "meridiancirkel",
    "meridiancirklarnas": "meridiancirkel",
    "meridiancirklars": "meridiancirkel",
    "meridianen": "meridian",
    "meridianens": "meridian",
    "meridianer": "meridian",
    "meridianerna": "meridian",
    "meridianernas": "meridian",
    "meridianers": "meridian",
    "meridianhöjden": "meridianhöjd",
    "meridianhöjdens": "meridianhöjd",
    "meridianhöjder": "meridianhöjd",
    "meridianhöjderna": "meridianhöjd",
    "meridianhöjdernas": "meridianhöjd",
    "meridianhöjders": "meridianhöjd",
    "meridianhöjds": "meridianhöjd",
    "meridians": "meridian",
    "merinofåren": "merinofår",
    "merinofårens": "merinofår",
    "merinofåret": "merinofår",
    "merinofårets": "merinofår",
    "merinofårs": "merinofår",
    "meriten": "merit",
    "meritens": "merit",
    "meriter": "merit",
    "meriterad": "meritera",
    "meriterade": "meriterad",
    "meriterades": "meriterad",
    "meriterads": "meriterad",
    "meriterande": "meritera",
    "meriteranden": "meriterande",
    "meriterandena": "meriterande",
    "meriterandenas": "meriterande",
    "meriterandens": "meriterande",
    "meriterandes": "meriterande",
    "meriterandet": "meriterande",
    "meriterandets": "meriterande",
    "meriterar": "meritera",
    "meriteras": "meritera",
    "meriterat": "meriterad",
    "meriterats": "meriterad",
    "meriterbara": "meriterbar",
    "meriterbarare": "meriterbar",
    "meriterbarares": "meriterbar",
    "meriterbaras": "meriterbar",
    "meriterbarast": "meriterbar",
    "meriterbaraste": "meriterbar",
    "meriterbarastes": "meriterbar",
    "meriterbarasts": "meriterbar",
    "meriterbare": "meriterbar",
    "meriterbares": "meriterbar",
    "meriterbarheten": "meriterbarhet",
    "meriterbarhetens": "meriterbarhet",
    "meriterbarhets": "meriterbarhet",
    "meriterbars": "meriterbar",
    "meriterbart": "meriterbar",
    "meriterbarts": "meriterbar",
    "meriteringar": "meritering",
    "meriteringarna": "meritering",
    "meriteringarnas": "meritering",
    "meriteringars": "meritering",
    "meriteringen": "meritering",
    "meriteringens": "meritering",
    "meriterings": "meritering",
    "meriterna": "merit",
    "meriternas": "merit",
    "meriters": "merit",
    "meritlistan": "meritlista",
    "meritlistans": "meritlista",
    "meritlistas": "meritlista",
    "meritliste": "meritlista",
    "meritlistor": "meritlista",
    "meritlistorna": "meritlista",
    "meritlistornas": "meritlista",
    "meritlistors": "meritlista",
    "meritmässiga": "meritmässig",
    "meritmässigare": "meritmässig",
    "meritmässigares": "meritmässig",
    "meritmässigas": "meritmässig",
    "meritmässigast": "meritmässig",
    "meritmässigaste": "meritmässig",
    "meritmässigastes": "meritmässig",
    "meritmässigasts": "meritmässig",
    "meritmässige": "meritmässig",
    "meritmässiges": "meritmässig",
    "meritmässigs": "meritmässig",
    "meritmässigt": "meritmässig",
    "meritmässigts": "meritmässig",
    "meritokratien": "meritokrati",
    "meritokratiens": "meritokrati",
    "meritokratin": "meritokrati",
    "meritokratins": "meritokrati",
    "meritokratis": "meritokrati",
    "merits": "merit",
    "merkantila": "merkantil",
    "merkantilare": "merkantil",
    "merkantilares": "merkantil",
    "merkantilas": "merkantil",
    "merkantilast": "merkantil",
    "merkantilaste": "merkantil",
    "merkantilastes": "merkantil",
    "merkantilasts": "merkantil",
    "merkantile": "merkantil",
    "merkantiles": "merkantil",
    "merkantilismen": "merkantilism",
    "merkantilismens": "merkantilism",
    "merkantilismer": "merkantilism",
    "merkantilismerna": "merkantilism",
    "merkantilismernas": "merkantilism",
    "merkantilismers": "merkantilism",
    "merkantilisms": "merkantilism",
    "merkantilisten": "merkantilist",
    "merkantilistens": "merkantilist",
    "merkantilister": "merkantilist",
    "merkantilisterna": "merkantilist",
    "merkantilisternas": "merkantilist",
    "merkantilisters": "merkantilist",
    "merkantilistiska": "merkantilistisk",
    "merkantilistiskas": "merkantilistisk",
    "merkantilistiske": "merkantilistisk",
    "merkantilistiskes": "merkantilistisk",
    "merkantilistisks": "merkantilistisk",
    "merkantilistiskt": "merkantilistisk",
    "merkantilistiskts": "merkantilistisk",
    "merkantilists": "merkantilist",
    "merkantils": "merkantil",
    "merkantilsystemen": "merkantilsystem",
    "merkantilsystemens": "merkantilsystem",
    "merkantilsystemet": "merkantilsystem",
    "merkantilsystemets": "merkantilsystem",
    "merkantilsystems": "merkantilsystem",
    "merkantilt": "merkantil",
    "merkantilts": "merkantil",
    "merkaptanen": "merkaptan",
    "merkaptanens": "merkaptan",
    "merkaptaner": "merkaptan",
    "merkaptanerna": "merkaptan",
    "merkaptanernas": "merkaptan",
    "merkaptaners": "merkaptan",
    "merkaptans": "merkaptan",
    "merkostnaden": "merkostnad",
    "merkostnadens": "merkostnad",
    "merkostnader": "merkostnad",
    "merkostnaderna": "merkostnad",
    "merkostnadernas": "merkostnad",
    "merkostnaders": "merkostnad",
    "merkostnads": "merkostnad",
    "meronymen": "meronym",
    "meronymens": "meronym",
    "meronymer": "meronym",
    "meronymerna": "meronym",
    "meronymernas": "meronym",
    "meronymers": "meronym",
    "meronymien": "meronymi",
    "meronymiens": "meronymi",
    "meronymier": "meronymi",
    "meronymierna": "meronymi",
    "meronymiernas": "meronymi",
    "meronymiers": "meronymi",
    "meronymin": "meronymi",
    "meronymins": "meronymi",
    "meronymis": "meronymi",
    "meronyms": "meronym",
    "merparten": "merpart",
    "merpartens": "merpart",
    "merparts": "merpart",
    "mers": "mycken",
    "mersans": "mersa",
    "mersmaken": "mersmak",
    "mersmakens": "mersmak",
    "mersmaks": "mersmak",
    "mersornas": "mersa",
    "mersors": "mersa",
    "mervärden": "mervärde",
    "mervärdena": "mervärde",
    "mervärdenas": "mervärde",
    "mervärdens": "mervärde",
    "mervärdes": "mervärde",
    "mervärdesskatten": "mervärdesskatt",
    "mervärdesskattens": "mervärdesskatt",
    "mervärdesskatter": "mervärdesskatt",
    "mervärdesskatterna": "mervärdesskatt",
    "mervärdesskatternas": "mervärdesskatt",
    "mervärdesskatters": "mervärdesskatt",
    "mervärdesskatts": "mervärdesskatt",
    "mervärdet": "mervärde",
    "mervärdets": "mervärde",
    "mesaktiga": "mesaktig",
    "mesaktigare": "mesaktig",
    "mesaktigares": "mesaktig",
    "mesaktigas": "mesaktig",
    "mesaktigast": "mesaktig",
    "mesaktigaste": "mesaktig",
    "mesaktigastes": "mesaktig",
    "mesaktigasts": "mesaktig",
    "mesaktige": "mesaktig",
    "mesaktiges": "mesaktig",
    "mesaktigheten": "mesaktighet",
    "mesaktighetens": "mesaktighet",
    "mesaktighets": "mesaktighet",
    "mesaktigs": "mesaktig",
    "mesaktigt": "mesaktig",
    "mesaktigts": "mesaktig",
    "mesalliansen": "mesallians",
    "mesalliansens": "mesallians",
    "mesallianser": "mesallians",
    "mesallianserna": "mesallians",
    "mesalliansernas": "mesallians",
    "mesalliansers": "mesallians",
    "mesanen": "mesan",
    "mesanens": "mesan",
    "mesaner": "mesan",
    "mesanerna": "mesan",
    "mesanernas": "mesan",
    "mesaners": "mesan",
    "mesanmasten": "mesanmast",
    "mesanmastens": "mesanmast",
    "mesanmaster": "mesanmast",
    "mesanmasterna": "mesanmast",
    "mesanmasternas": "mesanmast",
    "mesanmasters": "mesanmast",
    "mesanmasts": "mesanmast",
    "mesans": "mesan",
    "mesar": "mes",
    "mesarna": "mes",
    "mesarnas": "mes",
    "mesars": "mes",
    "mesen": "mes",
    "mesens": "mes",
    "mesfågeln": "mesfågel",
    "mesfågelns": "mesfågel",
    "mesfågels": "mesfågel",
    "mesfåglar": "mesfågel",
    "mesfåglarna": "mesfågel",
    "mesfåglarnas": "mesfågel",
    "mesfåglars": "mesfågel",
    "mesiga": "mesig",
    "mesigare": "mesig",
    "mesigares": "mesig",
    "mesigas": "mesig",
    "mesigast": "mesig",
    "mesigaste": "mesig",
    "mesigastes": "mesig",
    "mesigasts": "mesig",
    "mesige": "mesig",
    "mesiges": "mesig",
    "mesigs": "mesig",
    "mesigt": "mesig",
    "mesigts": "mesig",
    "meskalinen": "meskalin",
    "meskalinens": "meskalin",
    "meskaliner": "meskalin",
    "meskalinerna": "meskalin",
    "meskalinernas": "meskalin",
    "meskaliners": "meskalin",
    "meskalinet": "meskalin",
    "meskalinets": "meskalin",
    "meskalins": "meskalin",
    "mesonen": "meson",
    "mesonens": "meson",
    "mesoner": "meson",
    "mesonerna": "meson",
    "mesonernas": "meson",
    "mesoners": "meson",
    "mesons": "meson",
    "mesopotamen": "mesopotam",
    "mesopotamens": "mesopotam",
    "mesopotamer": "mesopotam",
    "mesopotamerna": "mesopotam",
    "mesopotamernas": "mesopotam",
    "mesopotamers": "mesopotam",
    "mesopotamisk": "mesopotamiska",
    "mesopotamiska": "mesopotamisk",
    "mesopotamiskan": "mesopotamiska",
    "mesopotamiskans": "mesopotamiska",
    "mesopotamiskare": "mesopotamisk",
    "mesopotamiskares": "mesopotamisk",
    "mesopotamiskas": "mesopotamiska",
    "mesopotamiskast": "mesopotamisk",
    "mesopotamiskaste": "mesopotamisk",
    "mesopotamiskastes": "mesopotamisk",
    "mesopotamiskasts": "mesopotamisk",
    "mesopotamiske": "mesopotamisk",
    "mesopotamiskes": "mesopotamisk",
    "mesopotamisks": "mesopotamisk",
    "mesopotamiskt": "mesopotamisk",
    "mesopotamiskts": "mesopotamisk",
    "mesopotams": "mesopotam",
    "mesostar": "mesost",
    "mesostarna": "mesost",
    "mesostarnas": "mesost",
    "mesostars": "mesost",
    "mesosten": "mesost",
    "mesostens": "mesost",
    "mesosts": "mesost",
    "mesozoikums": "mesozoikum",
    "mesozoiska": "mesozoisk",
    "mesozoiskare": "mesozoisk",
    "mesozoiskares": "mesozoisk",
    "mesozoiskas": "mesozoisk",
    "mesozoiskast": "mesozoisk",
    "mesozoiskaste": "mesozoisk",
    "mesozoiskastes": "mesozoisk",
    "mesozoiskasts": "mesozoisk",
    "mesozoiske": "mesozoisk",
    "mesozoiskes": "mesozoisk",
    "mesozoisks": "mesozoisk",
    "mesozoiskt": "mesozoisk",
    "mesozoiskts": "mesozoisk",
    "mess": "messa",
    "messad": "messa",
    "messade": "messa",
    "messades": "messa",
    "messads": "messa",
    "messande": "messa",
    "messanden": "messande",
    "messandena": "messande",
    "messandenas": "messande",
    "messandens": "messande",
    "messandes": "messande",
    "messandet": "messande",
    "messandets": "messande",
    "messar": "messa",
    "messas": "messa",
    "messat": "messa",
    "messats": "messa",
    "messianska": "messiansk",
    "messianskare": "messiansk",
    "messianskares": "messiansk",
    "messianskas": "messiansk",
    "messianskast": "messiansk",
    "messianskaste": "messiansk",
    "messianskastes": "messiansk",
    "messianskasts": "messiansk",
    "messianske": "messiansk",
    "messianskes": "messiansk",
    "messiansks": "messiansk",
    "messianskt": "messiansk",
    "messianskts": "messiansk",
    "messiasriken": "messiasrike",
    "messiasrikena": "messiasrike",
    "messiasrikenas": "messiasrike",
    "messiasrikens": "messiasrike",
    "messiasrikes": "messiasrike",
    "messiasriket": "messiasrike",
    "messiasrikets": "messiasrike",
    "messmöret": "messmör",
    "messmörets": "messmör",
    "messmörs": "messmör",
    "mest": "mycket",
    "mesta": "mycken",
    "mestas": "mycken",
    "meste": "mycken",
    "mestes": "mycken",
    "mestgynnadnationen": "mestgynnadnation",
    "mestgynnadnationens": "mestgynnadnation",
    "mestgynnadnationer": "mestgynnadnation",
    "mestgynnadnationerna": "mestgynnadnation",
    "mestgynnadnationernas": "mestgynnadnation",
    "mestgynnadnationers": "mestgynnadnation",
    "mestgynnadnations": "mestgynnadnation",
    "mestisen": "mestis",
    "mestisens": "mestis",
    "mestiser": "mestis",
    "mestiserna": "mestis",
    "mestisernas": "mestis",
    "mestisers": "mestis",
    "mests": "mycken",
    "met": "meta",
    "metabolismen": "metabolism",
    "metabolismens": "metabolism",
    "metabolismer": "metabolism",
    "metabolismerna": "metabolism",
    "metabolismernas": "metabolism",
    "metabolismers": "metabolism",
    "metabolisms": "metabolism",
    "metacenterhöjden": "metacenterhöjd",
    "metacenterhöjdens": "metacenterhöjd",
    "metacenterhöjder": "metacenterhöjd",
    "metacenterhöjderna": "metacenterhöjd",
    "metacenterhöjdernas": "metacenterhöjd",
    "metacenterhöjders": "metacenterhöjd",
    "metacenterhöjds": "metacenterhöjd",
    "metacentra": "metacentrum",
    "metacentrana": "metacentrum",
    "metacentranas": "metacentrum",
    "metacentras": "metacentrum",
    "metacentrumen": "metacentrum",
    "metacentrumens": "metacentrum",
    "metacentrumet": "metacentrum",
    "metacentrumets": "metacentrum",
    "metacentrums": "metacentrum",
    "metade": "meta",
    "metades": "meta",
    "metadonet": "metadon",
    "metadonets": "metadon",
    "metadons": "metadon",
    "metafibern": "metafiber",
    "metafiberns": "metafiber",
    "metafibers": "metafiber",
    "metafibrer": "metafiber",
    "metafibrerna": "metafiber",
    "metafibrernas": "metafiber",
    "metafibrers": "metafiber",
    "metaforen": "metafor",
    "metaforens": "metafor",
    "metaforer": "metafor",
    "metaforerna": "metafor",
    "metaforernas": "metafor",
    "metaforers": "metafor",
    "metaforiken": "metaforik",
    "metaforikens": "metaforik",
    "metaforiks": "metaforik",
    "metaforiska": "metaforisk",
    "metaforiskare": "metaforisk",
    "metaforiskares": "metaforisk",
    "metaforiskas": "metaforisk",
    "metaforiskast": "metaforisk",
    "metaforiskaste": "metaforisk",
    "metaforiskastes": "metaforisk",
    "metaforiskasts": "metaforisk",
    "metaforiske": "metaforisk",
    "metaforiskes": "metaforisk",
    "metaforisks": "metaforisk",
    "metaforiskt": "metaforisk",
    "metaforiskts": "metaforisk",
    "metafors": "metafor",
    "metafysiken": "metafysik",
    "metafysikens": "metafysik",
    "metafysikern": "metafysiker",
    "metafysikerna": "metafysiker",
    "metafysikernas": "metafysiker",
    "metafysikerns": "metafysiker",
    "metafysikers": "metafysiker",
    "metafysiks": "metafysik",
    "metafysiska": "metafysisk",
    "metafysiskare": "metafysisk",
    "metafysiskares": "metafysisk",
    "metafysiskas": "metafysisk",
    "metafysiskast": "metafysisk",
    "metafysiskaste": "metafysisk",
    "metafysiskastes": "metafysisk",
    "metafysiskasts": "metafysisk",
    "metafysiske": "metafysisk",
    "metafysiskes": "metafysisk",
    "metafysisks": "metafysisk",
    "metafysiskt": "metafysisk",
    "metafysiskts": "metafysisk",
    "metaköken": "metakök",
    "metakökens": "metakök",
    "metaköket": "metakök",
    "metakökets": "metakök",
    "metaköks": "metakök",
    "metallarbetar": "metallarbetare",
    "metallarbetaren": "metallarbetare",
    "metallarbetarens": "metallarbetare",
    "metallarbetares": "metallarbetare",
    "metallarbetarna": "metallarbetare",
    "metallarbetarnas": "metallarbetare",
    "metallatomen": "metallatom",
    "metallatomens": "metallatom",
    "metallatomer": "metallatom",
    "metallatomerna": "metallatom",
    "metallatomernas": "metallatom",
    "metallatomers": "metallatom",
    "metallatoms": "metallatom",
    "metallbaden": "metallbad",
    "metallbadens": "metallbad",
    "metallbadet": "metallbad",
    "metallbadets": "metallbad",
    "metallbads": "metallbad",
    "metallbitar": "metallbit",
    "metallbitarna": "metallbit",
    "metallbitarnas": "metallbit",
    "metallbitars": "metallbit",
    "metallbiten": "metallbit",
    "metallbitens": "metallbit",
    "metallbits": "metallbit",
    "metallbrick": "metallbricka",
    "metallbrickan": "metallbricka",
    "metallbrickans": "metallbricka",
    "metallbrickas": "metallbricka",
    "metallbricke": "metallbricka",
    "metallbrickor": "metallbricka",
    "metallbrickorna": "metallbricka",
    "metallbrickornas": "metallbricka",
    "metallbrickors": "metallbricka",
    "metallbricks": "metallbricka",
    "metalldelar": "metalldel",
    "metalldelarna": "metalldel",
    "metalldelarnas": "metalldel",
    "metalldelars": "metalldel",
    "metalldelen": "metalldel",
    "metalldelens": "metalldel",
    "metalldels": "metalldel",
    "metalldetektorer": "metalldetektor",
    "metalldetektorerna": "metalldetektor",
    "metalldetektorernas": "metalldetektor",
    "metalldetektorers": "metalldetektor",
    "metalldetektorn": "metalldetektor",
    "metalldetektorns": "metalldetektor",
    "metalldetektors": "metalldetektor",
    "metallen": "metall",
    "metallens": "metall",
    "metaller": "metall",
    "metallerna": "metall",
    "metallernas": "metall",
    "metallers": "metall",
    "metallfoten": "metallfot",
    "metallfotens": "metallfot",
    "metallfots": "metallfot",
    "metallföremålen": "metallföremål",
    "metallföremålens": "metallföremål",
    "metallföremålet": "metallföremål",
    "metallföremålets": "metallföremål",
    "metallföremåls": "metallföremål",
    "metallförgiftningar": "metallförgiftning",
    "metallförgiftningarna": "metallförgiftning",
    "metallförgiftningarnas": "metallförgiftning",
    "metallförgiftningars": "metallförgiftning",
    "metallförgiftningen": "metallförgiftning",
    "metallförgiftningens": "metallförgiftning",
    "metallförgiftnings": "metallförgiftning",
    "metallfötter": "metallfot",
    "metallfötterna": "metallfot",
    "metallfötternas": "metallfot",
    "metallfötters": "metallfot",
    "metallgjutningar": "metallgjutning",
    "metallgjutningarna": "metallgjutning",
    "metallgjutningarnas": "metallgjutning",
    "metallgjutningars": "metallgjutning",
    "metallgjutningen": "metallgjutning",
    "metallgjutningens": "metallgjutning",
    "metallgjutnings": "metallgjutning",
    "metallgolven": "metallgolv",
    "metallgolvens": "metallgolv",
    "metallgolvet": "metallgolv",
    "metallgolvets": "metallgolv",
    "metallgolvs": "metallgolv",
    "metallhandeln": "metallhandel",
    "metallhandelns": "metallhandel",
    "metallhandels": "metallhandel",
    "metallhandlar": "metallhandel",
    "metallhandlarna": "metallhandel",
    "metallhandlarnas": "metallhandel",
    "metallhandlars": "metallhandel",
    "metallicfärgen": "metallicfärg",
    "metallicfärgens": "metallicfärg",
    "metallicfärger": "metallicfärg",
    "metallicfärgerna": "metallicfärg",
    "metallicfärgernas": "metallicfärg",
    "metallicfärgers": "metallicfärg",
    "metallicfärgs": "metallicfärg",
    "metallindustrien": "metallindustri",
    "metallindustriens": "metallindustri",
    "metallindustrier": "metallindustri",
    "metallindustrierna": "metallindustri",
    "metallindustriernas": "metallindustri",
    "metallindustriers": "metallindustri",
    "metallindustrin": "metallindustri",
    "metallindustrins": "metallindustri",
    "metallindustris": "metallindustri",
    "metalliserad": "metallisera",
    "metalliserade": "metallisera",
    "metalliserades": "metallisera",
    "metalliserads": "metallisera",
    "metalliserande": "metallisera",
    "metalliseranden": "metalliserande",
    "metalliserandena": "metalliserande",
    "metalliserandenas": "metalliserande",
    "metalliserandens": "metalliserande",
    "metalliserandes": "metalliserande",
    "metalliserandet": "metalliserande",
    "metalliserandets": "metalliserande",
    "metalliserar": "metallisera",
    "metalliseras": "metallisera",
    "metalliserat": "metallisera",
    "metalliserats": "metallisera",
    "metalliserbara": "metalliserbar",
    "metalliserbarare": "metalliserbar",
    "metalliserbarares": "metalliserbar",
    "metalliserbaras": "metalliserbar",
    "metalliserbarast": "metalliserbar",
    "metalliserbaraste": "metalliserbar",
    "metalliserbarastes": "metalliserbar",
    "metalliserbarasts": "metalliserbar",
    "metalliserbare": "metalliserbar",
    "metalliserbares": "metalliserbar",
    "metalliserbarheten": "metalliserbarhet",
    "metalliserbarhetens": "metalliserbarhet",
    "metalliserbarhets": "metalliserbarhet",
    "metalliserbars": "metalliserbar",
    "metalliserbart": "metalliserbar",
    "metalliserbarts": "metalliserbar",
    "metalliseringar": "metallisering",
    "metalliseringarna": "metallisering",
    "metalliseringarnas": "metallisering",
    "metalliseringars": "metallisering",
    "metalliseringen": "metallisering",
    "metalliseringens": "metallisering",
    "metalliserings": "metallisering",
    "metalliska": "metallisk",
    "metalliskare": "metallisk",
    "metalliskares": "metallisk",
    "metalliskas": "metallisk",
    "metalliskast": "metallisk",
    "metalliskaste": "metallisk",
    "metalliskastes": "metallisk",
    "metalliskasts": "metallisk",
    "metalliske": "metallisk",
    "metalliskes": "metallisk",
    "metallisks": "metallisk",
    "metalliskt": "metallisk",
    "metalliskts": "metallisk",
    "metallkapmaskinen": "metallkapmaskin",
    "metallkapmaskinens": "metallkapmaskin",
    "metallkapmaskiner": "metallkapmaskin",
    "metallkapmaskinerna": "metallkapmaskin",
    "metallkapmaskinernas": "metallkapmaskin",
    "metallkapmaskiners": "metallkapmaskin",
    "metallkapmaskins": "metallkapmaskin",
    "metallkorgar": "metallkorg",
    "metallkorgarna": "metallkorg",
    "metallkorgarnas": "metallkorg",
    "metallkorgars": "metallkorg",
    "metallkorgen": "metallkorg",
    "metallkorgens": "metallkorg",
    "metallkorgs": "metallkorg",
    "metallkul": "metallkula",
    "metallkulan": "metallkula",
    "metallkulans": "metallkula",
    "metallkulas": "metallkula",
    "metallkule": "metallkula",
    "metallkulor": "metallkula",
    "metallkulorna": "metallkula",
    "metallkulornas": "metallkula",
    "metallkulors": "metallkula",
    "metallkuls": "metallkula",
    "metallmuggar": "metallmugg",
    "metallmuggarna": "metallmugg",
    "metallmuggarnas": "metallmugg",
    "metallmuggars": "metallmugg",
    "metallmuggen": "metallmugg",
    "metallmuggens": "metallmugg",
    "metallmuggs": "metallmugg",
    "metallografien": "metallografi",
    "metallografiens": "metallografi",
    "metallografin": "metallografi",
    "metallografins": "metallografi",
    "metallografis": "metallografi",
    "metallografiska": "metallografisk",
    "metallografiskare": "metallografisk",
    "metallografiskares": "metallografisk",
    "metallografiskas": "metallografisk",
    "metallografiskast": "metallografisk",
    "metallografiskaste": "metallografisk",
    "metallografiskastes": "metallografisk",
    "metallografiskasts": "metallografisk",
    "metallografiske": "metallografisk",
    "metallografiskes": "metallografisk",
    "metallografisks": "metallografisk",
    "metallografiskt": "metallografisk",
    "metallografiskts": "metallografisk",
    "metalloiden": "metalloid",
    "metalloidens": "metalloid",
    "metalloider": "metalloid",
    "metalloiderna": "metalloid",
    "metalloidernas": "metalloid",
    "metalloiders": "metalloid",
    "metalloids": "metalloid",
    "metalloxiden": "metalloxid",
    "metalloxidens": "metalloxid",
    "metalloxider": "metalloxid",
    "metalloxiderna": "metalloxid",
    "metalloxidernas": "metalloxid",
    "metalloxiders": "metalloxid",
    "metalloxids": "metalloxid",
    "metallpulverna": "metallpulver",
    "metallpulvernas": "metallpulver",
    "metallpulvers": "metallpulver",
    "metallpulvren": "metallpulver",
    "metallpulvrens": "metallpulver",
    "metallpulvret": "metallpulver",
    "metallpulvrets": "metallpulver",
    "metallringar": "metallring",
    "metallringarna": "metallring",
    "metallringarnas": "metallring",
    "metallringars": "metallring",
    "metallringen": "metallring",
    "metallringens": "metallring",
    "metallrings": "metallring",
    "metalls": "metall",
    "metallslöjden": "metallslöjd",
    "metallslöjdens": "metallslöjd",
    "metallslöjds": "metallslöjd",
    "metallspekulanten": "metallspekulant",
    "metallspekulantens": "metallspekulant",
    "metallspekulanter": "metallspekulant",
    "metallspekulanterna": "metallspekulant",
    "metallspekulanternas": "metallspekulant",
    "metallspekulanters": "metallspekulant",
    "metallspekulants": "metallspekulant",
    "metallspiralen": "metallspiral",
    "metallspiralens": "metallspiral",
    "metallspiraler": "metallspiral",
    "metallspiralerna": "metallspiral",
    "metallspiralernas": "metallspiral",
    "metallspiralers": "metallspiral",
    "metallspirals": "metallspiral",
    "metallspånen": "metallspån",
    "metallspånens": "metallspån",
    "metallspånet": "metallspån",
    "metallspånets": "metallspån",
    "metallspåns": "metallspån",
    "metallsvarvar": "metallsvarv",
    "metallsvarvarna": "metallsvarv",
    "metallsvarvarnas": "metallsvarv",
    "metallsvarvars": "metallsvarv",
    "metallsvarven": "metallsvarv",
    "metallsvarvens": "metallsvarv",
    "metallsvarvs": "metallsvarv",
    "metallsågar": "metallsåg",
    "metallsågarna": "metallsåg",
    "metallsågarnas": "metallsåg",
    "metallsågars": "metallsåg",
    "metallsågen": "metallsåg",
    "metallsågens": "metallsåg",
    "metallsågs": "metallsåg",
    "metalltrådar": "metalltråd",
    "metalltrådarna": "metalltråd",
    "metalltrådarnas": "metalltråd",
    "metalltrådars": "metalltråd",
    "metalltråden": "metalltråd",
    "metalltrådens": "metalltråd",
    "metalltråds": "metalltråd",
    "metallurgen": "metallurg",
    "metallurgens": "metallurg",
    "metallurger": "metallurg",
    "metallurgerna": "metallurg",
    "metallurgernas": "metallurg",
    "metallurgers": "metallurg",
    "metallurgien": "metallurgi",
    "metallurgiens": "metallurgi",
    "metallurgin": "metallurgi",
    "metallurgins": "metallurgi",
    "metallurgis": "metallurgi",
    "metallurgiska": "metallurgisk",
    "metallurgiskare": "metallurgisk",
    "metallurgiskares": "metallurgisk",
    "metallurgiskas": "metallurgisk",
    "metallurgiskast": "metallurgisk",
    "metallurgiskaste": "metallurgisk",
    "metallurgiskastes": "metallurgisk",
    "metallurgiskasts": "metallurgisk",
    "metallurgiske": "metallurgisk",
    "metallurgiskes": "metallurgisk",
    "metallurgisks": "metallurgisk",
    "metallurgiskt": "metallurgisk",
    "metallurgiskts": "metallurgisk",
    "metallurgs": "metallurg",
    "metallvikten": "metallvikt",
    "metallviktens": "metallvikt",
    "metallvikter": "metallvikt",
    "metallvikterna": "metallvikt",
    "metallvikternas": "metallvikt",
    "metallvikters": "metallvikt",
    "metallvikts": "metallvikt",
    "metallvärden": "metallvärde",
    "metallvärdena": "metallvärde",
    "metallvärdenas": "metallvärde",
    "metallvärdens": "metallvärde",
    "metallvärdes": "metallvärde",
    "metallvärdet": "metallvärde",
    "metallvärdets": "metallvärde",
    "metamorfa": "metamorf",
    "metamorfare": "metamorf",
    "metamorfares": "metamorf",
    "metamorfas": "metamorf",
    "metamorfast": "metamorf",
    "metamorfaste": "metamorf",
    "metamorfastes": "metamorf",
    "metamorfasts": "metamorf",
    "metamorfe": "metamorf",
    "metamorfes": "metamorf",
    "metamorfosen": "metamorfos",
    "metamorfosens": "metamorfos",
    "metamorfoser": "metamorfos",
    "metamorfoserna": "metamorfos",
    "metamorfosernas": "metamorfos",
    "metamorfosers": "metamorfos",
    "metamorfs": "metamorf",
    "metamorft": "metamorf",
    "metamorfts": "metamorf",
    "metande": "meta",
    "metanden": "metande",
    "metandena": "metande",
    "metandenas": "metande",
    "metandens": "metande",
    "metandes": "metande",
    "metandet": "metande",
    "metandets": "metande",
    "metanen": "metan",
    "metanens": "metan",
    "metaner": "metan",
    "metanerna": "metan",
    "metanernas": "metan",
    "metaners": "metan",
    "metanet": "metan",
    "metanets": "metan",
    "metangasen": "metangas",
    "metangasens": "metangas",
    "metanhydraten": "metanhydrat",
    "metanhydratens": "metanhydrat",
    "metanhydrats": "metanhydrat",
    "metanisen": "metanis",
    "metanisens": "metanis",
    "metanklatraten": "metanklatrat",
    "metanklatratens": "metanklatrat",
    "metanklatrats": "metanklatrat",
    "metanolen": "metanol",
    "metanolens": "metanol",
    "metanols": "metanol",
    "metans": "metan",
    "metar": "metare",
    "metaren": "metare",
    "metarens": "metare",
    "metares": "metare",
    "metarna": "metare",
    "metarnas": "metare",
    "metas": "meta",
    "metaspråken": "metaspråk",
    "metaspråkens": "metaspråk",
    "metaspråket": "metaspråk",
    "metaspråkets": "metaspråk",
    "metaspråks": "metaspråk",
    "metastasen": "metastas",
    "metastasens": "metastas",
    "metastaser": "metastas",
    "metastaserna": "metastas",
    "metastasernas": "metastas",
    "metastasers": "metastas",
    "metastatiska": "metastatisk",
    "metastatiskare": "metastatisk",
    "metastatiskares": "metastatisk",
    "metastatiskas": "metastatisk",
    "metastatiskast": "metastatisk",
    "metastatiskaste": "metastatisk",
    "metastatiskastes": "metastatisk",
    "metastatiskasts": "metastatisk",
    "metastatiske": "metastatisk",
    "metastatiskes": "metastatisk",
    "metastatisks": "metastatisk",
    "metastatiskt": "metastatisk",
    "metastatiskts": "metastatisk",
    "metat": "meta",
    "metatabletten": "metatablett",
    "metatablettens": "metatablett",
    "metatabletter": "metatablett",
    "metatabletterna": "metatablett",
    "metatabletternas": "metatablett",
    "metatabletters": "metatablett",
    "metatabletts": "metatablett",
    "metatesen": "metates",
    "metatesens": "metates",
    "metateser": "metates",
    "metateserna": "metates",
    "metatesernas": "metates",
    "metatesers": "metates",
    "metats": "meta",
    "metazoer": "metazo",
    "metazoerna": "metazo",
    "metazoernas": "metazo",
    "metazoers": "metazo",
    "metazon": "metazo",
    "metazons": "metazo",
    "metazos": "metazo",
    "meten": "mete",
    "metena": "mete",
    "metenas": "mete",
    "metens": "mete",
    "meteorartade": "meteorartad",
    "meteorartades": "meteorartad",
    "meteorartads": "meteorartad",
    "meteorartat": "meteorartad",
    "meteorartats": "meteorartad",
    "meteoren": "meteor",
    "meteorens": "meteor",
    "meteorer": "meteor",
    "meteorerna": "meteor",
    "meteorernas": "meteor",
    "meteorers": "meteor",
    "meteoriten": "meteorit",
    "meteoritens": "meteorit",
    "meteoriter": "meteorit",
    "meteoriterna": "meteorit",
    "meteoriternas": "meteorit",
    "meteoriters": "meteorit",
    "meteoritnedslagen": "meteoritnedslag",
    "meteoritnedslagens": "meteoritnedslag",
    "meteoritnedslaget": "meteoritnedslag",
    "meteoritnedslagets": "meteoritnedslag",
    "meteoritnedslags": "meteoritnedslag",
    "meteorits": "meteorit",
    "meteorjärnen": "meteorjärn",
    "meteorjärnens": "meteorjärn",
    "meteorjärnet": "meteorjärn",
    "meteorjärnets": "meteorjärn",
    "meteorjärns": "meteorjärn",
    "meteorkratern": "meteorkrater",
    "meteorkraterns": "meteorkrater",
    "meteorkraters": "meteorkrater",
    "meteorkratrar": "meteorkrater",
    "meteorkratrarna": "meteorkrater",
    "meteorkratrarnas": "meteorkrater",
    "meteorkratrars": "meteorkrater",
    "meteorologen": "meteorolog",
    "meteorologens": "meteorolog",
    "meteorologer": "meteorolog",
    "meteorologerna": "meteorolog",
    "meteorologernas": "meteorolog",
    "meteorologers": "meteorolog",
    "meteorologien": "meteorologi",
    "meteorologiens": "meteorologi",
    "meteorologin": "meteorologi",
    "meteorologins": "meteorologi",
    "meteorologis": "meteorologi",
    "meteorologiska": "meteorologisk",
    "meteorologiskare": "meteorologisk",
    "meteorologiskares": "meteorologisk",
    "meteorologiskas": "meteorologisk",
    "meteorologiskast": "meteorologisk",
    "meteorologiskaste": "meteorologisk",
    "meteorologiskastes": "meteorologisk",
    "meteorologiskasts": "meteorologisk",
    "meteorologiske": "meteorologisk",
    "meteorologiskes": "meteorologisk",
    "meteorologisks": "meteorologisk",
    "meteorologiskt": "meteorologisk",
    "meteorologiskts": "meteorologisk",
    "meteorologs": "meteorolog",
    "meteors": "meteor",
    "meteorstenar": "meteorsten",
    "meteorstenarna": "meteorsten",
    "meteorstenarnas": "meteorsten",
    "meteorstenars": "meteorsten",
    "meteorstenen": "meteorsten",
    "meteorstenens": "meteorsten",
    "meteorstens": "meteorsten",
    "meteorstoftet": "meteorstoft",
    "meteorstoftets": "meteorstoft",
    "meteorstofts": "meteorstoft",
    "meterlikar": "meterlikare",
    "meterlikaren": "meterlikare",
    "meterlikarens": "meterlikare",
    "meterlikares": "meterlikare",
    "meterlikarna": "meterlikare",
    "meterlikarnas": "meterlikare",
    "meterlånga": "meterlång",
    "meterlångas": "meterlång",
    "meterlånge": "meterlång",
    "meterlånges": "meterlång",
    "meterlångs": "meterlång",
    "meterlångt": "meterlång",
    "meterlångts": "meterlång",
    "metermåtten": "metermått",
    "metermåttens": "metermått",
    "metermåttet": "metermått",
    "metermåttets": "metermått",
    "metermåtts": "metermått",
    "metern": "meter",
    "meterna": "meter",
    "meternas": "meter",
    "meterns": "meter",
    "meterprototypen": "meterprototyp",
    "meterprototypens": "meterprototyp",
    "meterprototyper": "meterprototyp",
    "meterprototyperna": "meterprototyp",
    "meterprototypernas": "meterprototyp",
    "meterprototypers": "meterprototyp",
    "meterprototyps": "meterprototyp",
    "meters": "meter",
    "meterstavar": "meterstav",
    "meterstavarna": "meterstav",
    "meterstavarnas": "meterstav",
    "meterstavars": "meterstav",
    "meterstaven": "meterstav",
    "meterstavens": "meterstav",
    "meterstavs": "meterstav",
    "metersystemen": "metersystem",
    "metersystemens": "metersystem",
    "metersystemet": "metersystem",
    "metersystemets": "metersystem",
    "metersystems": "metersystem",
    "metertjocka": "metertjock",
    "metertjockare": "metertjock",
    "metertjockares": "metertjock",
    "metertjockas": "metertjock",
    "metertjockast": "metertjock",
    "metertjockaste": "metertjock",
    "metertjockastes": "metertjock",
    "metertjockasts": "metertjock",
    "metertjocke": "metertjock",
    "metertjockes": "metertjock",
    "metertjocks": "metertjock",
    "metertjockt": "metertjock",
    "metertjockts": "metertjock",
    "metervar": "metervara",
    "metervaran": "metervara",
    "metervarans": "metervara",
    "metervaras": "metervara",
    "metervare": "metervara",
    "metervaror": "metervara",
    "metervarorna": "metervara",
    "metervarornas": "metervara",
    "metervarors": "metervara",
    "metervars": "metervara",
    "metes": "mete",
    "metet": "mete",
    "metets": "mete",
    "metkrokar": "metkrok",
    "metkrokarna": "metkrok",
    "metkrokarnas": "metkrok",
    "metkrokars": "metkrok",
    "metkroken": "metkrok",
    "metkrokens": "metkrok",
    "metkroks": "metkrok",
    "metmaskar": "metmask",
    "metmaskarna": "metmask",
    "metmaskarnas": "metmask",
    "metmaskars": "metmask",
    "metmasken": "metmask",
    "metmaskens": "metmask",
    "metmasks": "metmask",
    "metoden": "metod",
    "metodens": "metod",
    "metoder": "metod",
    "metoderna": "metod",
    "metodernas": "metod",
    "metoders": "metod",
    "metodiken": "metodik",
    "metodikens": "metodik",
    "metodikern": "metodiker",
    "metodikerna": "metodiker",
    "metodikernas": "metodiker",
    "metodikerns": "metodiker",
    "metodikers": "metodiker",
    "metodiklektorer": "metodiklektor",
    "metodiklektorerna": "metodiklektor",
    "metodiklektorernas": "metodiklektor",
    "metodiklektorers": "metodiklektor",
    "metodiklektorn": "metodiklektor",
    "metodiklektorns": "metodiklektor",
    "metodiklektors": "metodiklektor",
    "metodiks": "metodik",
    "metodiska": "metodisk",
    "metodiskare": "metodisk",
    "metodiskares": "metodisk",
    "metodiskas": "metodisk",
    "metodiskast": "metodisk",
    "metodiskaste": "metodisk",
    "metodiskastes": "metodisk",
    "metodiskasts": "metodisk",
    "metodiske": "metodisk",
    "metodiskes": "metodisk",
    "metodisks": "metodisk",
    "metodiskt": "metodisk",
    "metodiskts": "metodisk",
    "metodismen": "metodism",
    "metodismens": "metodism",
    "metodismer": "metodism",
    "metodismerna": "metodism",
    "metodismernas": "metodism",
    "metodismers": "metodism",
    "metodisms": "metodism",
    "metodisten": "metodist",
    "metodistens": "metodist",
    "metodister": "metodist",
    "metodisterna": "metodist",
    "metodisternas": "metodist",
    "metodisters": "metodist",
    "metodistiska": "metodistisk",
    "metodistiskas": "metodistisk",
    "metodistiske": "metodistisk",
    "metodistiskes": "metodistisk",
    "metodistisks": "metodistisk",
    "metodistiskt": "metodistisk",
    "metodistiskts": "metodistisk",
    "metodists": "metodist",
    "metodkraven": "metodkrav",
    "metodkravens": "metodkrav",
    "metodkravet": "metodkrav",
    "metodkravets": "metodkrav",
    "metodkravs": "metodkrav",
    "metodläran": "metodlära",
    "metodlärans": "metodlära",
    "metodläras": "metodlära",
    "metodläre": "metodlära",
    "metodläro": "metodlära",
    "metodläror": "metodlära",
    "metodlärorna": "metodlära",
    "metodlärornas": "metodlära",
    "metodlärors": "metodlära",
    "metodmässiga": "metodmässig",
    "metodmässigare": "metodmässig",
    "metodmässigares": "metodmässig",
    "metodmässigas": "metodmässig",
    "metodmässigast": "metodmässig",
    "metodmässigaste": "metodmässig",
    "metodmässigastes": "metodmässig",
    "metodmässigasts": "metodmässig",
    "metodmässige": "metodmässig",
    "metodmässiges": "metodmässig",
    "metodmässigs": "metodmässig",
    "metodmässigt": "metodmässig",
    "metodmässigts": "metodmässig",
    "metodologien": "metodologi",
    "metodologiens": "metodologi",
    "metodologier": "metodologi",
    "metodologierna": "metodologi",
    "metodologiernas": "metodologi",
    "metodologiers": "metodologi",
    "metodologin": "metodologi",
    "metodologins": "metodologi",
    "metodologis": "metodologi",
    "metodologiska": "metodologisk",
    "metodologiskare": "metodologisk",
    "metodologiskares": "metodologisk",
    "metodologiskas": "metodologisk",
    "metodologiskast": "metodologisk",
    "metodologiskaste": "metodologisk",
    "metodologiskastes": "metodologisk",
    "metodologiskasts": "metodologisk",
    "metodologiske": "metodologisk",
    "metodologiskes": "metodologisk",
    "metodologisks": "metodologisk",
    "metodologiskt": "metodologisk",
    "metodologiskts": "metodologisk",
    "metods": "metod",
    "metodsynpunkten": "metodsynpunkt",
    "metodsynpunktens": "metodsynpunkt",
    "metodsynpunkter": "metodsynpunkt",
    "metodsynpunkterna": "metodsynpunkt",
    "metodsynpunkternas": "metodsynpunkt",
    "metodsynpunkters": "metodsynpunkt",
    "metodsynpunkts": "metodsynpunkt",
    "metodvetenskapen": "metodvetenskap",
    "metodvetenskapens": "metodvetenskap",
    "metodvetenskaper": "metodvetenskap",
    "metodvetenskaperna": "metodvetenskap",
    "metodvetenskapernas": "metodvetenskap",
    "metodvetenskapers": "metodvetenskap",
    "metodvetenskaps": "metodvetenskap",
    "metonymien": "metonymi",
    "metonymiens": "metonymi",
    "metonymier": "metonymi",
    "metonymierna": "metonymi",
    "metonymiernas": "metonymi",
    "metonymiers": "metonymi",
    "metonymin": "metonymi",
    "metonymins": "metonymi",
    "metonymis": "metonymi",
    "metrar": "meter",
    "metrarna": "meter",
    "metrarnas": "meter",
    "metrars": "meter",
    "metrevar": "metrev",
    "metrevarna": "metrev",
    "metrevarnas": "metrev",
    "metrevars": "metrev",
    "metreven": "metrev",
    "metrevens": "metrev",
    "metrevs": "metrev",
    "metriken": "metrik",
    "metrikens": "metrik",
    "metriks": "metrik",
    "metriska": "metrisk",
    "metriskare": "metrisk",
    "metriskares": "metrisk",
    "metriskas": "metrisk",
    "metriskast": "metrisk",
    "metriskaste": "metrisk",
    "metriskastes": "metrisk",
    "metriskasts": "metrisk",
    "metriske": "metrisk",
    "metriskes": "metrisk",
    "metrisks": "metrisk",
    "metriskt": "metrisk",
    "metriskts": "metrisk",
    "metrologien": "metrologi",
    "metrologiens": "metrologi",
    "metrologin": "metrologi",
    "metrologins": "metrologi",
    "metrologis": "metrologi",
    "metrologiska": "metrologisk",
    "metrologiskare": "metrologisk",
    "metrologiskares": "metrologisk",
    "metrologiskas": "metrologisk",
    "metrologiskast": "metrologisk",
    "metrologiskaste": "metrologisk",
    "metrologiskastes": "metrologisk",
    "metrologiskasts": "metrologisk",
    "metrologiske": "metrologisk",
    "metrologiskes": "metrologisk",
    "metrologisks": "metrologisk",
    "metrologiskt": "metrologisk",
    "metrologiskts": "metrologisk",
    "metron": "metro",
    "metronomen": "metronom",
    "metronomens": "metronom",
    "metronomer": "metronom",
    "metronomerna": "metronom",
    "metronomernas": "metronom",
    "metronomers": "metronom",
    "metronoms": "metronom",
    "metrons": "metro",
    "metropolen": "metropol",
    "metropolens": "metropol",
    "metropoler": "metropol",
    "metropolerna": "metropol",
    "metropolernas": "metropol",
    "metropolers": "metropol",
    "metropoliten": "metropolit",
    "metropolitens": "metropolit",
    "metropoliter": "metropolit",
    "metropoliterna": "metropolit",
    "metropoliternas": "metropolit",
    "metropoliters": "metropolit",
    "metropolits": "metropolit",
    "metropols": "metropol",
    "metror": "metro",
    "metrorna": "metro",
    "metrornas": "metro",
    "metrors": "metro",
    "metros": "metro",
    "mets": "m",
    "metspöet": "metspö",
    "metspöets": "metspö",
    "metspön": "metspö",
    "metspöna": "metspö",
    "metspönas": "metspö",
    "metspöns": "metspö",
    "metspös": "metspö",
    "metspöt": "metspö",
    "metspöts": "metspö",
    "metvurstar": "metvurst",
    "metvurstarna": "metvurst",
    "metvurstarnas": "metvurst",
    "metvurstars": "metvurst",
    "metvursten": "metvurst",
    "metvurstens": "metvurst",
    "metvursts": "metvurst",
    "metylalkoholen": "metylalkohol",
    "metylalkoholens": "metylalkohol",
    "metylalkohols": "metylalkohol",
    "metylen": "metyl",
    "metylenblåtts": "metylenblått",
    "metylenen": "metylen",
    "metylenens": "metylen",
    "metylenet": "metylen",
    "metylenets": "metylen",
    "metylens": "metylen",
    "metyls": "metyl",
    "mexikanen": "mexikan",
    "mexikanens": "mexikan",
    "mexikaner": "mexikan",
    "mexikanerna": "mexikan",
    "mexikanernas": "mexikan",
    "mexikaners": "mexikan",
    "mexikans": "mexikan",
    "mexikanska": "mexikansk",
    "mexikanskan": "mexikanska",
    "mexikanskans": "mexikanska",
    "mexikanskare": "mexikansk",
    "mexikanskares": "mexikansk",
    "mexikanskas": "mexikanska",
    "mexikanskast": "mexikansk",
    "mexikanskaste": "mexikansk",
    "mexikanskastes": "mexikansk",
    "mexikanskasts": "mexikansk",
    "mexikanske": "mexikanska",
    "mexikanskes": "mexikansk",
    "mexikanskor": "mexikanska",
    "mexikanskorna": "mexikanska",
    "mexikanskornas": "mexikanska",
    "mexikanskors": "mexikanska",
    "mexikansks": "mexikansk",
    "mexikanskt": "mexikansk",
    "mexikanskts": "mexikansk",
    "mexitegels": "mexitegel",
    "mexitegelvillan": "mexitegelvilla",
    "mexitegelvillans": "mexitegelvilla",
    "mexitegelvillas": "mexitegelvilla",
    "mexitegelville": "mexitegelvilla",
    "mexitegelvillor": "mexitegelvilla",
    "mexitegelvillorna": "mexitegelvilla",
    "mexitegelvillornas": "mexitegelvilla",
    "mexitegelvillors": "mexitegelvilla",
    "mexiteglen": "mexitegel",
    "mexiteglens": "mexitegel",
    "mexiteglet": "mexitegel",
    "mexiteglets": "mexitegel",
    "mezzaninen": "mezzanin",
    "mezzaninens": "mezzanin",
    "mezzaniner": "mezzanin",
    "mezzaninerna": "mezzanin",
    "mezzaninernas": "mezzanin",
    "mezzaniners": "mezzanin",
    "mezzanins": "mezzanin",
    "mezzoforten": "mezzoforte",
    "mezzofortena": "mezzoforte",
    "mezzofortenas": "mezzoforte",
    "mezzofortens": "mezzoforte",
    "mezzofortes": "mezzoforte",
    "mezzofortet": "mezzoforte",
    "mezzofortets": "mezzoforte",
    "mezzosopranen": "mezzosopran",
    "mezzosopranens": "mezzosopran",
    "mezzosopraner": "mezzosopran",
    "mezzosopranerna": "mezzosopran",
    "mezzosopranernas": "mezzosopran",
    "mezzosopraners": "mezzosopran",
    "mezzosoprans": "mezzosopran",
    "miasmerna": "miasmer",
    "miasmernas": "miasmer",
    "miasmers": "miasmer",
    "mickar": "mick",
    "mickarna": "mick",
    "mickarnas": "mick",
    "mickars": "mick",
    "mickeln": "mickel",
    "mickelns": "mickel",
    "mickels": "mickel",
    "mickelsmäss": "mickelsmässa",
    "mickelsmässan": "mickelsmässa",
    "mickelsmässans": "mickelsmässa",
    "mickelsmässas": "mickelsmässa",
    "mickelsmässe": "mickelsmässa",
    "mickelsmässor": "mickelsmässa",
    "mickelsmässorna": "mickelsmässa",
    "mickelsmässornas": "mickelsmässa",
    "mickelsmässors": "mickelsmässa",
    "micken": "mick",
    "mickens": "mick",
    "micklar": "mickel",
    "micklarna": "mickel",
    "micklarnas": "mickel",
    "micklars": "mickel",
    "micks": "mick",
    "micrad": "micra",
    "micrade": "micra",
    "micrades": "micra",
    "micrads": "micra",
    "micrande": "micra",
    "micranden": "micrande",
    "micrandena": "micrande",
    "micrandenas": "micrande",
    "micrandens": "micrande",
    "micrandes": "micrande",
    "micrandet": "micrande",
    "micrandets": "micrande",
    "micrar": "micra",
    "micras": "micra",
    "micrat": "micra",
    "micrats": "micra",
    "microhattar": "microhatt",
    "microhattarna": "microhatt",
    "microhattarnas": "microhatt",
    "microhattars": "microhatt",
    "microhatten": "microhatt",
    "microhattens": "microhatt",
    "microhatts": "microhatt",
    "microlocken": "microlock",
    "microlockens": "microlock",
    "microlocket": "microlock",
    "microlockets": "microlock",
    "microlocks": "microlock",
    "micron": "micro",
    "microns": "micro",
    "micror": "micro",
    "microrna": "micro",
    "micrornas": "micro",
    "micrors": "micro",
    "micros": "micro",
    "microvågsugnar": "microvågsugn",
    "microvågsugnarna": "microvågsugn",
    "microvågsugnarnas": "microvågsugn",
    "microvågsugnars": "microvågsugn",
    "microvågsugnen": "microvågsugn",
    "microvågsugnens": "microvågsugn",
    "microvågsugns": "microvågsugn",
    "middagar": "middag",
    "middagarna": "middag",
    "middagarnas": "middag",
    "middagars": "middag",
    "middagen": "middag",
    "middagens": "middag",
    "middags": "middag",
    "middagsbjudningar": "middagsbjudning",
    "middagsbjudningarna": "middagsbjudning",
    "middagsbjudningarnas": "middagsbjudning",
    "middagsbjudningars": "middagsbjudning",
    "middagsbjudningen": "middagsbjudning",
    "middagsbjudningens": "middagsbjudning",
    "middagsbjudnings": "middagsbjudning",
    "middagsgästen": "middagsgäst",
    "middagsgästens": "middagsgäst",
    "middagsgäster": "middagsgäst",
    "middagsgästerna": "middagsgäst",
    "middagsgästernas": "middagsgäst",
    "middagsgästers": "middagsgäst",
    "middagsgästs": "middagsgäst",
    "middagshöjden": "middagshöjd",
    "middagshöjdens": "middagshöjd",
    "middagshöjder": "middagshöjd",
    "middagshöjderna": "middagshöjd",
    "middagshöjdernas": "middagshöjd",
    "middagshöjders": "middagshöjd",
    "middagshöjds": "middagshöjd",
    "middagsklänningar": "middagsklänning",
    "middagsklänningarna": "middagsklänning",
    "middagsklänningarnas": "middagsklänning",
    "middagsklänningars": "middagsklänning",
    "middagsklänningen": "middagsklänning",
    "middagsklänningens": "middagsklänning",
    "middagsklännings": "middagsklänning",
    "middagslurar": "middagslur",
    "middagslurarna": "middagslur",
    "middagslurarnas": "middagslur",
    "middagslurars": "middagslur",
    "middagsluren": "middagslur",
    "middagslurens": "middagslur",
    "middagslurs": "middagslur",
    "middagsmaten": "middagsmat",
    "middagsmatens": "middagsmat",
    "middagsmats": "middagsmat",
    "middagsmålen": "middagsmål",
    "middagsmålens": "middagsmål",
    "middagsmålet": "middagsmål",
    "middagsmålets": "middagsmål",
    "middagsmåls": "middagsmål",
    "middagsrasten": "middagsrast",
    "middagsrastens": "middagsrast",
    "middagsraster": "middagsrast",
    "middagsrasterna": "middagsrast",
    "middagsrasternas": "middagsrast",
    "middagsrasters": "middagsrast",
    "middagsrasts": "middagsrast",
    "middagssällskapen": "middagssällskap",
    "middagssällskapens": "middagssällskap",
    "middagssällskapet": "middagssällskap",
    "middagssällskapets": "middagssällskap",
    "middagssällskaps": "middagssällskap",
    "middagstiden": "middagstid",
    "middagstidens": "middagstid",
    "middagstider": "middagstid",
    "middagstiderna": "middagstid",
    "middagstidernas": "middagstid",
    "middagstiders": "middagstid",
    "middagstids": "middagstid",
    "middagstim": "middagstimme",
    "middagstimman": "middagstimma",
    "middagstimmans": "middagstimma",
    "middagstimmar": "middagstimme",
    "middagstimmarna": "middagstimme",
    "middagstimmarnas": "middagstimme",
    "middagstimmars": "middagstimme",
    "middagstimmas": "middagstimma",
    "middagstimmen": "middagstimme",
    "middagstimmens": "middagstimme",
    "middagstimmes": "middagstimme",
    "middagstims": "middagstimme",
    "middagsvettet": "middagsvett",
    "middagsvettets": "middagsvett",
    "middagsvetts": "middagsvett",
    "middagsätar": "middagsätare",
    "middagsätaren": "middagsätare",
    "middagsätarens": "middagsätare",
    "middagsätares": "middagsätare",
    "middagsätarna": "middagsätare",
    "middagsätarnas": "middagsätare",
    "midfastosöndagar": "midfastosöndag",
    "midfastosöndagarna": "midfastosöndag",
    "midfastosöndagarnas": "midfastosöndag",
    "midfastosöndagars": "midfastosöndag",
    "midfastosöndagen": "midfastosöndag",
    "midfastosöndagens": "midfastosöndag",
    "midfastosöndags": "midfastosöndag",
    "midgetbilar": "midgetbil",
    "midgetbilarna": "midgetbil",
    "midgetbilarnas": "midgetbil",
    "midgetbilars": "midgetbil",
    "midgetbilen": "midgetbil",
    "midgetbilens": "midgetbil",
    "midgetbils": "midgetbil",
    "midjan": "midja",
    "midjans": "midja",
    "midjas": "midja",
    "midje": "midja",
    "midjebanden": "midjeband",
    "midjebandens": "midjeband",
    "midjebandet": "midjeband",
    "midjebandets": "midjeband",
    "midjebands": "midjeband",
    "midjemåtten": "midjemått",
    "midjemåttens": "midjemått",
    "midjemåttet": "midjemått",
    "midjemåttets": "midjemått",
    "midjemåtts": "midjemått",
    "midjetrakten": "midjetrakt",
    "midjetraktens": "midjetrakt",
    "midjetrakter": "midjetrakt",
    "midjetrakterna": "midjetrakt",
    "midjetrakternas": "midjetrakt",
    "midjetrakters": "midjetrakt",
    "midjetrakts": "midjetrakt",
    "midjor": "midja",
    "midjorna": "midja",
    "midjornas": "midja",
    "midjors": "midja",
    "midnatten": "midnatt",
    "midnattens": "midnatt",
    "midnatts": "midnatt",
    "midnattsblåa": "midnattsblå",
    "midnattsblåare": "midnattsblå",
    "midnattsblåares": "midnattsblå",
    "midnattsblåas": "midnattsblå",
    "midnattsblåast": "midnattsblå",
    "midnattsblåaste": "midnattsblå",
    "midnattsblåastes": "midnattsblå",
    "midnattsblåasts": "midnattsblå",
    "midnattsblåe": "midnattsblå",
    "midnattsblåes": "midnattsblå",
    "midnattsblås": "midnattsblå",
    "midnattsblått": "midnattsblå",
    "midnattsblåtts": "midnattsblå",
    "midnattssolar": "midnattssol",
    "midnattssolarna": "midnattssol",
    "midnattssolarnas": "midnattssol",
    "midnattssolars": "midnattssol",
    "midnattssolen": "midnattssol",
    "midnattssolens": "midnattssol",
    "midnattssols": "midnattssol",
    "midskeppssektionen": "midskeppssektion",
    "midskeppssektionens": "midskeppssektion",
    "midskeppssektioner": "midskeppssektion",
    "midskeppssektionerna": "midskeppssektion",
    "midskeppssektionernas": "midskeppssektion",
    "midskeppssektioners": "midskeppssektion",
    "midskeppssektions": "midskeppssektion",
    "midsommaraftnar": "midsommarafton",
    "midsommaraftnarna": "midsommarafton",
    "midsommaraftnarnas": "midsommarafton",
    "midsommaraftnars": "midsommarafton",
    "midsommaraftonen": "midsommarafton",
    "midsommaraftonens": "midsommarafton",
    "midsommaraftons": "midsommarafton",
    "midsommarblomsterna": "midsommarblomster",
    "midsommarblomsternas": "midsommarblomster",
    "midsommarblomsters": "midsommarblomster",
    "midsommarblomstren": "midsommarblomster",
    "midsommarblomstrens": "midsommarblomster",
    "midsommarblomstret": "midsommarblomster",
    "midsommarblomstrets": "midsommarblomster",
    "midsommardagar": "midsommardag",
    "midsommardagarna": "midsommardag",
    "midsommardagarnas": "midsommardag",
    "midsommardagars": "midsommardag",
    "midsommardagen": "midsommardag",
    "midsommardagens": "midsommardag",
    "midsommardags": "midsommardag",
    "midsommaren": "midsommar",
    "midsommarens": "midsommar",
    "midsommarn": "midsommar",
    "midsommarnatn": "midsommarnatt",
    "midsommarnatns": "midsommarnatt",
    "midsommarnatten": "midsommarnatt",
    "midsommarnattens": "midsommarnatt",
    "midsommarnatts": "midsommarnatt",
    "midsommarns": "midsommar",
    "midsommarnätter": "midsommarnatt",
    "midsommarnätterna": "midsommarnatt",
    "midsommarnätternas": "midsommarnatt",
    "midsommarnätters": "midsommarnatt",
    "midsommars": "midsommar",
    "midsommarstänger": "midsommarstång",
    "midsommarstängerna": "midsommarstång",
    "midsommarstängernas": "midsommarstång",
    "midsommarstängers": "midsommarstång",
    "midsommarstången": "midsommarstång",
    "midsommarstångens": "midsommarstång",
    "midsommarstångs": "midsommarstång",
    "midsommartiden": "midsommartid",
    "midsommartidens": "midsommartid",
    "midsommartider": "midsommartid",
    "midsommartiderna": "midsommartid",
    "midsommartidernas": "midsommartid",
    "midsommartiders": "midsommartid",
    "midsommartids": "midsommartid",
    "midsomrar": "midsommar",
    "midsomrarna": "midsommar",
    "midsomrarnas": "midsommar",
    "midsomrars": "midsommar",
    "midvinterbloten": "midvinterblot",
    "midvinterblotens": "midvinterblot",
    "midvinterblotet": "midvinterblot",
    "midvinterblotets": "midvinterblot",
    "midvinterblots": "midvinterblot",
    "midvintern": "midvinter",
    "midvinterns": "midvinter",
    "midvinters": "midvinter",
    "midvintrar": "midvinter",
    "midvintrarna": "midvinter",
    "midvintrarnas": "midvinter",
    "midvintrars": "midvinter",
    "miffon": "miffo",
    "miffona": "miffo",
    "miffonas": "miffo",
    "miffons": "miffo",
    "miffos": "miffo",
    "miffot": "miffo",
    "miffots": "miffo",
    "mig": "jag",
    "migrantbåtar": "migrantbåt",
    "migrantbåtarna": "migrantbåt",
    "migrantbåtarnas": "migrantbåt",
    "migrantbåtars": "migrantbåt",
    "migrantbåten": "migrantbåt",
    "migrantbåtens": "migrantbåt",
    "migrantbåts": "migrantbåt",
    "migranten": "migrant",
    "migrantens": "migrant",
    "migranter": "migrant",
    "migranterna": "migrant",
    "migranternas": "migrant",
    "migranters": "migrant",
    "migrants": "migrant",
    "migrationen": "migration",
    "migrationens": "migration",
    "migrationer": "migration",
    "migrationerna": "migration",
    "migrationernas": "migration",
    "migrationers": "migration",
    "migrations": "migration",
    "migrationskommissionären": "migrationskommissionär",
    "migrationskommissionärens": "migrationskommissionär",
    "migrationskommissionärer": "migrationskommissionär",
    "migrationskommissionärerna": "migrationskommissionär",
    "migrationskommissionärernas": "migrationskommissionär",
    "migrationskommissionärers": "migrationskommissionär",
    "migrationskommissionärs": "migrationskommissionär",
    "migrationsministern": "migrationsminister",
    "migrationsministerns": "migrationsminister",
    "migrationsministers": "migrationsminister",
    "migrationsministrar": "migrationsminister",
    "migrationsministrarna": "migrationsminister",
    "migrationsministrarnas": "migrationsminister",
    "migrationsministrars": "migrationsminister",
    "migränattacken": "migränattack",
    "migränattackens": "migränattack",
    "migränattacker": "migränattack",
    "migränattackerna": "migränattack",
    "migränattackernas": "migränattack",
    "migränattackers": "migränattack",
    "migränattacks": "migränattack",
    "migränen": "migrän",
    "migränens": "migrän",
    "migräns": "migrän",
    "mikon": "miko",
    "mikona": "miko",
    "mikonas": "miko",
    "mikons": "miko",
    "mikos": "miko",
    "mikot": "miko",
    "mikots": "miko",
    "mikrad": "mikra",
    "mikrade": "mikra",
    "mikrades": "mikra",
    "mikrads": "mikra",
    "mikrande": "mikra",
    "mikranden": "mikrande",
    "mikrandena": "mikrande",
    "mikrandenas": "mikrande",
    "mikrandens": "mikrande",
    "mikrandes": "mikrande",
    "mikrandet": "mikrande",
    "mikrandets": "mikrande",
    "mikrar": "mikra",
    "mikras": "mikra",
    "mikrat": "mikra",
    "mikrats": "mikra",
    "mikroben": "mikrob",
    "mikrobens": "mikrob",
    "mikrober": "mikrob",
    "mikroberna": "mikrob",
    "mikrobernas": "mikrob",
    "mikrobers": "mikrob",
    "mikrobiologien": "mikrobiologi",
    "mikrobiologiens": "mikrobiologi",
    "mikrobiologin": "mikrobiologi",
    "mikrobiologins": "mikrobiologi",
    "mikrobiologis": "mikrobiologi",
    "mikrobiologiska": "mikrobiologisk",
    "mikrobiologiskare": "mikrobiologisk",
    "mikrobiologiskares": "mikrobiologisk",
    "mikrobiologiskas": "mikrobiologisk",
    "mikrobiologiskast": "mikrobiologisk",
    "mikrobiologiskaste": "mikrobiologisk",
    "mikrobiologiskastes": "mikrobiologisk",
    "mikrobiologiskasts": "mikrobiologisk",
    "mikrobiologiske": "mikrobiologisk",
    "mikrobiologiskes": "mikrobiologisk",
    "mikrobiologisks": "mikrobiologisk",
    "mikrobiologiskt": "mikrobiologisk",
    "mikrobiologiskts": "mikrobiologisk",
    "mikrobryggerier": "mikrobryggeri",
    "mikrobryggerierna": "mikrobryggeri",
    "mikrobryggeriernas": "mikrobryggeri",
    "mikrobryggeriers": "mikrobryggeri",
    "mikrobryggeriet": "mikrobryggeri",
    "mikrobryggeriets": "mikrobryggeri",
    "mikrobryggeris": "mikrobryggeri",
    "mikrobryggerit": "mikrobryggeri",
    "mikrobryggerits": "mikrobryggeri",
    "mikrobs": "mikrob",
    "mikrodatorer": "mikrodator",
    "mikrodatorerna": "mikrodator",
    "mikrodatorernas": "mikrodator",
    "mikrodatorers": "mikrodator",
    "mikrodatorn": "mikrodator",
    "mikrodatorns": "mikrodator",
    "mikrodators": "mikrodator",
    "mikroelektroniken": "mikroelektronik",
    "mikroelektronikens": "mikroelektronik",
    "mikroelektroniks": "mikroelektronik",
    "mikrofiberdukar": "mikrofiberduk",
    "mikrofiberdukarna": "mikrofiberduk",
    "mikrofiberdukarnas": "mikrofiberduk",
    "mikrofiberdukars": "mikrofiberduk",
    "mikrofiberduken": "mikrofiberduk",
    "mikrofiberdukens": "mikrofiberduk",
    "mikrofiberduks": "mikrofiberduk",
    "mikrofibern": "mikrofiber",
    "mikrofiberns": "mikrofiber",
    "mikrofibers": "mikrofiber",
    "mikrofibrer": "mikrofiber",
    "mikrofibrerna": "mikrofiber",
    "mikrofibrernas": "mikrofiber",
    "mikrofibrers": "mikrofiber",
    "mikrofichen": "mikrofiche",
    "mikrofichens": "mikrofiche",
    "mikroficher": "mikrofiche",
    "mikroficherna": "mikrofiche",
    "mikrofichernas": "mikrofiche",
    "mikrofichers": "mikrofiche",
    "mikrofiches": "mikrofiche",
    "mikrofichet": "mikrofiche",
    "mikrofichets": "mikrofiche",
    "mikrofilm": "mikrofilma",
    "mikrofilmad": "mikrofilma",
    "mikrofilmade": "mikrofilma",
    "mikrofilmades": "mikrofilma",
    "mikrofilmads": "mikrofilma",
    "mikrofilmande": "mikrofilma",
    "mikrofilmanden": "mikrofilmande",
    "mikrofilmandena": "mikrofilmande",
    "mikrofilmandenas": "mikrofilmande",
    "mikrofilmandens": "mikrofilmande",
    "mikrofilmandes": "mikrofilmande",
    "mikrofilmandet": "mikrofilmande",
    "mikrofilmandets": "mikrofilmande",
    "mikrofilmar": "mikrofilma",
    "mikrofilmas": "mikrofilma",
    "mikrofilmat": "mikrofilma",
    "mikrofilmats": "mikrofilma",
    "mikrofilmen": "mikrofilm",
    "mikrofilmens": "mikrofilm",
    "mikrofilmer": "mikrofilm",
    "mikrofilmerna": "mikrofilm",
    "mikrofilmernas": "mikrofilm",
    "mikrofilmers": "mikrofilm",
    "mikrofilms": "mikrofilm",
    "mikrofonbommar": "mikrofonbom",
    "mikrofonbommarna": "mikrofonbom",
    "mikrofonbommarnas": "mikrofonbom",
    "mikrofonbommars": "mikrofonbom",
    "mikrofonbommen": "mikrofonbom",
    "mikrofonbommens": "mikrofonbom",
    "mikrofonboms": "mikrofonbom",
    "mikrofonen": "mikrofon",
    "mikrofonens": "mikrofon",
    "mikrofoner": "mikrofon",
    "mikrofonerna": "mikrofon",
    "mikrofonernas": "mikrofon",
    "mikrofoners": "mikrofon",
    "mikrofons": "mikrofon",
    "mikrofontekniken": "mikrofonteknik",
    "mikrofonteknikens": "mikrofonteknik",
    "mikrofontekniker": "mikrofonteknik",
    "mikrofonteknikerna": "mikrofonteknik",
    "mikrofonteknikernas": "mikrofonteknik",
    "mikrofonteknikers": "mikrofonteknik",
    "mikrofontekniks": "mikrofonteknik",
    "mikrofotograferad": "mikrofotografera",
    "mikrofotograferade": "mikrofotografera",
    "mikrofotograferades": "mikrofotografera",
    "mikrofotograferads": "mikrofotografera",
    "mikrofotograferande": "mikrofotografera",
    "mikrofotograferanden": "mikrofotograferande",
    "mikrofotograferandena": "mikrofotograferande",
    "mikrofotograferandenas": "mikrofotograferande",
    "mikrofotograferandens": "mikrofotograferande",
    "mikrofotograferandes": "mikrofotograferande",
    "mikrofotograferandet": "mikrofotograferande",
    "mikrofotograferandets": "mikrofotograferande",
    "mikrofotograferar": "mikrofotografera",
    "mikrofotograferas": "mikrofotografera",
    "mikrofotograferat": "mikrofotografera",
    "mikrofotograferats": "mikrofotografera",
    "mikrofotograferbara": "mikrofotograferbar",
    "mikrofotograferbarare": "mikrofotograferbar",
    "mikrofotograferbarares": "mikrofotograferbar",
    "mikrofotograferbaras": "mikrofotograferbar",
    "mikrofotograferbarast": "mikrofotograferbar",
    "mikrofotograferbaraste": "mikrofotograferbar",
    "mikrofotograferbarastes": "mikrofotograferbar",
    "mikrofotograferbarasts": "mikrofotograferbar",
    "mikrofotograferbare": "mikrofotograferbar",
    "mikrofotograferbares": "mikrofotograferbar",
    "mikrofotograferbarheten": "mikrofotograferbarhet",
    "mikrofotograferbarhetens": "mikrofotograferbarhet",
    "mikrofotograferbarhets": "mikrofotograferbarhet",
    "mikrofotograferbars": "mikrofotograferbar",
    "mikrofotograferbart": "mikrofotograferbar",
    "mikrofotograferbarts": "mikrofotograferbar",
    "mikrofotograferingar": "mikrofotografering",
    "mikrofotograferingarna": "mikrofotografering",
    "mikrofotograferingarnas": "mikrofotografering",
    "mikrofotograferingars": "mikrofotografering",
    "mikrofotograferingen": "mikrofotografering",
    "mikrofotograferingens": "mikrofotografering",
    "mikrofotograferings": "mikrofotografering",
    "mikrofoton": "mikrofoto",
    "mikrofotona": "mikrofoto",
    "mikrofotonas": "mikrofoto",
    "mikrofotons": "mikrofoto",
    "mikrofotos": "mikrofoto",
    "mikrofotot": "mikrofoto",
    "mikrofotots": "mikrofoto",
    "mikrogrammen": "mikrogram",
    "mikrogrammens": "mikrogram",
    "mikrogrammet": "mikrogram",
    "mikrogrammets": "mikrogram",
    "mikrograms": "mikrogram",
    "mikrohattar": "mikrohatt",
    "mikrohattarna": "mikrohatt",
    "mikrohattarnas": "mikrohatt",
    "mikrohattars": "mikrohatt",
    "mikrohatten": "mikrohatt",
    "mikrohattens": "mikrohatt",
    "mikrohatts": "mikrohatt",
    "mikroklimaten": "mikroklimat",
    "mikroklimatens": "mikroklimat",
    "mikroklimatet": "mikroklimat",
    "mikroklimatets": "mikroklimat",
    "mikroklimats": "mikroklimat",
    "mikrokorten": "mikrokort",
    "mikrokortens": "mikrokort",
    "mikrokortet": "mikrokort",
    "mikrokortets": "mikrokort",
    "mikrokorts": "mikrokort",
    "mikrokosmosen": "mikrokosmos",
    "mikrokosmosens": "mikrokosmos",
    "mikrokosmoset": "mikrokosmos",
    "mikrokosmosets": "mikrokosmos",
    "mikrolocken": "mikrolock",
    "mikrolockens": "mikrolock",
    "mikrolocket": "mikrolock",
    "mikrolockets": "mikrolock",
    "mikrolocks": "mikrolock",
    "mikrometern": "mikrometer",
    "mikrometerna": "mikrometer",
    "mikrometernas": "mikrometer",
    "mikrometerns": "mikrometer",
    "mikrometers": "mikrometer",
    "mikrometersikten": "mikrometersikte",
    "mikrometersiktena": "mikrometersikte",
    "mikrometersiktenas": "mikrometersikte",
    "mikrometersiktens": "mikrometersikte",
    "mikrometersiktes": "mikrometersikte",
    "mikrometersiktet": "mikrometersikte",
    "mikrometersiktets": "mikrometersikte",
    "mikrometrar": "mikrometer",
    "mikrometrarna": "mikrometer",
    "mikrometrarnas": "mikrometer",
    "mikrometrars": "mikrometer",
    "mikron": "mikro",
    "mikronen": "mikron",
    "mikronens": "mikron",
    "mikroner": "mikron",
    "mikronerna": "mikron",
    "mikronernas": "mikron",
    "mikroners": "mikron",
    "mikronesiern": "mikronesier",
    "mikronesierna": "mikronesier",
    "mikronesiernas": "mikronesier",
    "mikronesierns": "mikronesier",
    "mikronesiers": "mikronesier",
    "mikronesiska": "mikronesisk",
    "mikronesiskan": "mikronesiska",
    "mikronesiskans": "mikronesiska",
    "mikronesiskare": "mikronesisk",
    "mikronesiskares": "mikronesisk",
    "mikronesiskas": "mikronesiska",
    "mikronesiskast": "mikronesisk",
    "mikronesiskaste": "mikronesisk",
    "mikronesiskastes": "mikronesisk",
    "mikronesiskasts": "mikronesisk",
    "mikronesiske": "mikronesiska",
    "mikronesiskes": "mikronesisk",
    "mikronesiskor": "mikronesiska",
    "mikronesiskorna": "mikronesiska",
    "mikronesiskornas": "mikronesiska",
    "mikronesiskors": "mikronesiska",
    "mikronesisks": "mikronesisk",
    "mikronesiskt": "mikronesisk",
    "mikronesiskts": "mikronesisk",
    "mikroneurografien": "mikroneurografi",
    "mikroneurografiens": "mikroneurografi",
    "mikroneurografin": "mikroneurografi",
    "mikroneurografins": "mikroneurografi",
    "mikroneurografis": "mikroneurografi",
    "mikrons": "mikron",
    "mikroorganismen": "mikroorganism",
    "mikroorganismens": "mikroorganism",
    "mikroorganismer": "mikroorganism",
    "mikroorganismerna": "mikroorganism",
    "mikroorganismernas": "mikroorganism",
    "mikroorganismers": "mikroorganism",
    "mikroorganisms": "mikroorganism",
    "mikror": "mikro",
    "mikrorna": "mikro",
    "mikrornas": "mikro",
    "mikrors": "mikro",
    "mikros": "mikro",
    "mikrosekunden": "mikrosekund",
    "mikrosekundens": "mikrosekund",
    "mikrosekunder": "mikrosekund",
    "mikrosekunderna": "mikrosekund",
    "mikrosekundernas": "mikrosekund",
    "mikrosekunders": "mikrosekund",
    "mikrosekunds": "mikrosekund",
    "mikroskopen": "mikroskop",
    "mikroskopens": "mikroskop",
    "mikroskoperad": "mikroskopera",
    "mikroskoperade": "mikroskopera",
    "mikroskoperades": "mikroskopera",
    "mikroskoperads": "mikroskopera",
    "mikroskoperande": "mikroskopera",
    "mikroskoperanden": "mikroskoperande",
    "mikroskoperandena": "mikroskoperande",
    "mikroskoperandenas": "mikroskoperande",
    "mikroskoperandens": "mikroskoperande",
    "mikroskoperandes": "mikroskoperande",
    "mikroskoperandet": "mikroskoperande",
    "mikroskoperandets": "mikroskoperande",
    "mikroskoperar": "mikroskopera",
    "mikroskoperas": "mikroskopera",
    "mikroskoperat": "mikroskopera",
    "mikroskoperats": "mikroskopera",
    "mikroskoperbara": "mikroskoperbar",
    "mikroskoperbarare": "mikroskoperbar",
    "mikroskoperbarares": "mikroskoperbar",
    "mikroskoperbaras": "mikroskoperbar",
    "mikroskoperbarast": "mikroskoperbar",
    "mikroskoperbaraste": "mikroskoperbar",
    "mikroskoperbarastes": "mikroskoperbar",
    "mikroskoperbarasts": "mikroskoperbar",
    "mikroskoperbare": "mikroskoperbar",
    "mikroskoperbares": "mikroskoperbar",
    "mikroskoperbarheten": "mikroskoperbarhet",
    "mikroskoperbarhetens": "mikroskoperbarhet",
    "mikroskoperbarhets": "mikroskoperbarhet",
    "mikroskoperbars": "mikroskoperbar",
    "mikroskoperbart": "mikroskoperbar",
    "mikroskoperbarts": "mikroskoperbar",
    "mikroskoperingar": "mikroskopering",
    "mikroskoperingarna": "mikroskopering",
    "mikroskoperingarnas": "mikroskopering",
    "mikroskoperingars": "mikroskopering",
    "mikroskoperingen": "mikroskopering",
    "mikroskoperingens": "mikroskopering",
    "mikroskoperings": "mikroskopering",
    "mikroskopet": "mikroskop",
    "mikroskopets": "mikroskop",
    "mikroskopien": "mikroskopi",
    "mikroskopiens": "mikroskopi",
    "mikroskopin": "mikroskopi",
    "mikroskopins": "mikroskopi",
    "mikroskopis": "mikroskopi",
    "mikroskopiska": "mikroskopisk",
    "mikroskopiskare": "mikroskopisk",
    "mikroskopiskares": "mikroskopisk",
    "mikroskopiskas": "mikroskopisk",
    "mikroskopiskast": "mikroskopisk",
    "mikroskopiskaste": "mikroskopisk",
    "mikroskopiskastes": "mikroskopisk",
    "mikroskopiskasts": "mikroskopisk",
    "mikroskopiske": "mikroskopisk",
    "mikroskopiskes": "mikroskopisk",
    "mikroskopisks": "mikroskopisk",
    "mikroskopiskt": "mikroskopisk",
    "mikroskopiskts": "mikroskopisk",
    "mikroskops": "mikroskop",
    "mikrosömnen": "mikrosömn",
    "mikrosömnens": "mikrosömn",
    "mikrosömns": "mikrosömn",
    "mikrotelefonen": "mikrotelefon",
    "mikrotelefonens": "mikrotelefon",
    "mikrotelefoner": "mikrotelefon",
    "mikrotelefonerna": "mikrotelefon",
    "mikrotelefonernas": "mikrotelefon",
    "mikrotelefoners": "mikrotelefon",
    "mikrotelefons": "mikrotelefon",
    "mikrotomen": "mikrotom",
    "mikrotomens": "mikrotom",
    "mikrotomer": "mikrotom",
    "mikrotomerna": "mikrotom",
    "mikrotomernas": "mikrotom",
    "mikrotomers": "mikrotom",
    "mikrotoms": "mikrotom",
    "mikrovågen": "mikrovåg",
    "mikrovågens": "mikrovåg",
    "mikrovågor": "mikrovåg",
    "mikrovågorna": "mikrovåg",
    "mikrovågornas": "mikrovåg",
    "mikrovågors": "mikrovåg",
    "mikrovågs": "mikrovåg",
    "mikrovågsugnar": "mikrovågsugn",
    "mikrovågsugnarna": "mikrovågsugn",
    "mikrovågsugnarnas": "mikrovågsugn",
    "mikrovågsugnars": "mikrovågsugn",
    "mikrovågsugnen": "mikrovågsugn",
    "mikrovågsugnens": "mikrovågsugn",
    "mikrovågsugns": "mikrovågsugn",
    "mikroölen": "mikroöl",
    "mikroölens": "mikroöl",
    "mikroöler": "mikroöl",
    "mikroölerna": "mikroöl",
    "mikroölernas": "mikroöl",
    "mikroölers": "mikroöl",
    "mikroölet": "mikroöl",
    "mikroölets": "mikroöl",
    "mikroöls": "mikroöl",
    "mil": "mila",
    "milan": "mila",
    "milans": "mila",
    "milas": "mila",
    "milda": "mild",
    "mildare": "mild",
    "mildares": "mild",
    "mildas": "mild",
    "mildast": "mild",
    "mildaste": "mild",
    "mildastes": "mild",
    "mildasts": "mild",
    "milde": "mild",
    "mildes": "mild",
    "mildheten": "mildhet",
    "mildhetens": "mildhet",
    "mildheter": "mildhet",
    "mildheterna": "mildhet",
    "mildheternas": "mildhet",
    "mildheters": "mildhet",
    "mildhets": "mildhet",
    "mildrad": "mildra",
    "mildrade": "mildra",
    "mildrades": "mildra",
    "mildrads": "mildra",
    "mildrande": "mildra",
    "mildranden": "mildrande",
    "mildrandena": "mildrande",
    "mildrandenas": "mildrande",
    "mildrandens": "mildrande",
    "mildrandes": "mildrande",
    "mildrandet": "mildrande",
    "mildrandets": "mildrande",
    "mildrar": "mildra",
    "mildras": "mildra",
    "mildrat": "mildra",
    "mildrats": "mildra",
    "milds": "mild",
    "mildsinta": "mildsint",
    "mildsintare": "mildsint",
    "mildsintares": "mildsint",
    "mildsintas": "mildsint",
    "mildsintast": "mildsint",
    "mildsintaste": "mildsint",
    "mildsintastes": "mildsint",
    "mildsintasts": "mildsint",
    "mildsinte": "mildsint",
    "mildsintes": "mildsint",
    "mildsintheten": "mildsinthet",
    "mildsinthetens": "mildsinthet",
    "mildsinthets": "mildsinthet",
    "mildsints": "mildsint",
    "mildväderna": "mildväder",
    "mildvädernas": "mildväder",
    "mildväders": "mildväder",
    "mildvädren": "mildväder",
    "mildvädrens": "mildväder",
    "mildvädret": "mildväder",
    "mildvädrets": "mildväder",
    "mildögda": "mildögd",
    "mildögdare": "mildögd",
    "mildögdares": "mildögd",
    "mildögdas": "mildögd",
    "mildögdast": "mildögd",
    "mildögdaste": "mildögd",
    "mildögdastes": "mildögd",
    "mildögdasts": "mildögd",
    "mildögde": "mildögd",
    "mildögdes": "mildögd",
    "mildögdheten": "mildögdhet",
    "mildögdhetens": "mildögdhet",
    "mildögdhets": "mildögdhet",
    "mildögds": "mildögd",
    "mildögt": "mildögd",
    "mildögts": "mildögd",
    "mile": "mila",
    "milen": "mil",
    "milens": "mil",
    "miliartuberkulosen": "miliartuberkulos",
    "miliartuberkulosens": "miliartuberkulos",
    "milisen": "milis",
    "milisens": "milis",
    "miliser": "milis",
    "miliserna": "milis",
    "milisernas": "milis",
    "milisers": "milis",
    "militanta": "militant",
    "militantare": "militant",
    "militantares": "militant",
    "militantas": "militant",
    "militantast": "militant",
    "militantaste": "militant",
    "militantastes": "militant",
    "militantasts": "militant",
    "militante": "militant",
    "militantes": "militant",
    "militants": "militant",
    "militariserad": "militarisera",
    "militariserade": "militarisera",
    "militariserades": "militarisera",
    "militariserads": "militarisera",
    "militariserande": "militarisera",
    "militariseranden": "militariserande",
    "militariserandena": "militariserande",
    "militariserandenas": "militariserande",
    "militariserandens": "militariserande",
    "militariserandes": "militariserande",
    "militariserandet": "militariserande",
    "militariserandets": "militariserande",
    "militariserar": "militarisera",
    "militariseras": "militarisera",
    "militariserat": "militarisera",
    "militariserats": "militarisera",
    "militariserbara": "militariserbar",
    "militariserbarare": "militariserbar",
    "militariserbarares": "militariserbar",
    "militariserbaras": "militariserbar",
    "militariserbarast": "militariserbar",
    "militariserbaraste": "militariserbar",
    "militariserbarastes": "militariserbar",
    "militariserbarasts": "militariserbar",
    "militariserbare": "militariserbar",
    "militariserbares": "militariserbar",
    "militariserbarheten": "militariserbarhet",
    "militariserbarhetens": "militariserbarhet",
    "militariserbarhets": "militariserbarhet",
    "militariserbars": "militariserbar",
    "militariserbart": "militariserbar",
    "militariserbarts": "militariserbar",
    "militariseringar": "militarisering",
    "militariseringarna": "militarisering",
    "militariseringarnas": "militarisering",
    "militariseringars": "militarisering",
    "militariseringen": "militarisering",
    "militariseringens": "militarisering",
    "militariserings": "militarisering",
    "militarismen": "militarism",
    "militarismens": "militarism",
    "militarismer": "militarism",
    "militarismerna": "militarism",
    "militarismernas": "militarism",
    "militarismers": "militarism",
    "militarisms": "militarism",
    "militaristen": "militarist",
    "militaristens": "militarist",
    "militarister": "militarist",
    "militaristerna": "militarist",
    "militaristernas": "militarist",
    "militaristers": "militarist",
    "militaristiska": "militaristisk",
    "militaristiskare": "militaristisk",
    "militaristiskares": "militaristisk",
    "militaristiskas": "militaristisk",
    "militaristiskast": "militaristisk",
    "militaristiskaste": "militaristisk",
    "militaristiskastes": "militaristisk",
    "militaristiskasts": "militaristisk",
    "militaristiske": "militaristisk",
    "militaristiskes": "militaristisk",
    "militaristisks": "militaristisk",
    "militaristiskt": "militaristisk",
    "militaristiskts": "militaristisk",
    "militarists": "militarist",
    "militieombudsmannen": "militieombudsman",
    "militieombudsmannens": "militieombudsman",
    "militieombudsmans": "militieombudsman",
    "militieombudsmän": "militieombudsman",
    "militieombudsmännen": "militieombudsman",
    "militieombudsmännens": "militieombudsman",
    "militieombudsmäns": "militieombudsman",
    "militära": "militär",
    "militäralliansen": "militärallians",
    "militäralliansens": "militärallians",
    "militärallianser": "militärallians",
    "militärallianserna": "militärallians",
    "militäralliansernas": "militärallians",
    "militäralliansers": "militärallians",
    "militärare": "militär",
    "militärares": "militär",
    "militäras": "militär",
    "militärast": "militär",
    "militäraste": "militär",
    "militärastes": "militär",
    "militärasts": "militär",
    "militärattachéer": "militärattaché",
    "militärattachéerna": "militärattaché",
    "militärattachéernas": "militärattaché",
    "militärattachéers": "militärattaché",
    "militärattachén": "militärattaché",
    "militärattachéns": "militärattaché",
    "militärattachés": "militärattaché",
    "militärbasen": "militärbas",
    "militärbasens": "militärbas",
    "militärbaser": "militärbas",
    "militärbaserna": "militärbas",
    "militärbasernas": "militärbas",
    "militärbasers": "militärbas",
    "militärbefälhavar": "militärbefälhavare",
    "militärbefälhavaren": "militärbefälhavare",
    "militärbefälhavarens": "militärbefälhavare",
    "militärbefälhavares": "militärbefälhavare",
    "militärbefälhavarna": "militärbefälhavare",
    "militärbefälhavarnas": "militärbefälhavare",
    "militärbudgetar": "militärbudget",
    "militärbudgetarna": "militärbudget",
    "militärbudgetarnas": "militärbudget",
    "militärbudgetars": "militärbudget",
    "militärbudgeten": "militärbudget",
    "militärbudgetens": "militärbudget",
    "militärbudgeter": "militärbudget",
    "militärbudgeterna": "militärbudget",
    "militärbudgeternas": "militärbudget",
    "militärbudgeters": "militärbudget",
    "militärbudgets": "militärbudget",
    "militärdiktaturen": "militärdiktatur",
    "militärdiktaturens": "militärdiktatur",
    "militärdiktaturer": "militärdiktatur",
    "militärdiktaturerna": "militärdiktatur",
    "militärdiktaturernas": "militärdiktatur",
    "militärdiktaturers": "militärdiktatur",
    "militärdiktaturs": "militärdiktatur",
    "militärdomstolar": "militärdomstol",
    "militärdomstolarna": "militärdomstol",
    "militärdomstolarnas": "militärdomstol",
    "militärdomstolars": "militärdomstol",
    "militärdomstolen": "militärdomstol",
    "militärdomstolens": "militärdomstol",
    "militärdomstols": "militärdomstol",
    "militäre": "militär",
    "militären": "militär",
    "militärens": "militär",
    "militärer": "militär",
    "militärerna": "militär",
    "militärernas": "militär",
    "militärers": "militär",
    "militäres": "militär",
    "militärfordonen": "militärfordon",
    "militärfordonens": "militärfordon",
    "militärfordonet": "militärfordon",
    "militärfordonets": "militärfordon",
    "militärfordons": "militärfordon",
    "militärförläggningar": "militärförläggning",
    "militärförläggningarna": "militärförläggning",
    "militärförläggningarnas": "militärförläggning",
    "militärförläggningars": "militärförläggning",
    "militärförläggningen": "militärförläggning",
    "militärförläggningens": "militärförläggning",
    "militärförläggnings": "militärförläggning",
    "militärförvaltningar": "militärförvaltning",
    "militärförvaltningarna": "militärförvaltning",
    "militärförvaltningarnas": "militärförvaltning",
    "militärförvaltningars": "militärförvaltning",
    "militärförvaltningen": "militärförvaltning",
    "militärförvaltningens": "militärförvaltning",
    "militärförvaltnings": "militärförvaltning",
    "militäriska": "militärisk",
    "militäriskare": "militärisk",
    "militäriskares": "militärisk",
    "militäriskas": "militärisk",
    "militäriskast": "militärisk",
    "militäriskaste": "militärisk",
    "militäriskastes": "militärisk",
    "militäriskasts": "militärisk",
    "militäriske": "militärisk",
    "militäriskes": "militärisk",
    "militärisks": "militärisk",
    "militäriskt": "militärisk",
    "militäriskts": "militärisk",
    "militärjunt": "militärjunta",
    "militärjuntan": "militärjunta",
    "militärjuntans": "militärjunta",
    "militärjuntas": "militärjunta",
    "militärjunte": "militärjunta",
    "militärjuntor": "militärjunta",
    "militärjuntorna": "militärjunta",
    "militärjuntornas": "militärjunta",
    "militärjuntors": "militärjunta",
    "militärjunts": "militärjunta",
    "militärkolonnen": "militärkolonn",
    "militärkolonnens": "militärkolonn",
    "militärkolonner": "militärkolonn",
    "militärkolonnerna": "militärkolonn",
    "militärkolonnernas": "militärkolonn",
    "militärkolonners": "militärkolonn",
    "militärkolonns": "militärkolonn",
    "militärkuppen": "militärkupp",
    "militärkuppens": "militärkupp",
    "militärkupper": "militärkupp",
    "militärkupperna": "militärkupp",
    "militärkuppernas": "militärkupp",
    "militärkuppers": "militärkupp",
    "militärkupps": "militärkupp",
    "militärläkar": "militärläkare",
    "militärläkaren": "militärläkare",
    "militärläkarens": "militärläkare",
    "militärläkares": "militärläkare",
    "militärläkarna": "militärläkare",
    "militärläkarnas": "militärläkare",
    "militärmakten": "militärmakt",
    "militärmaktens": "militärmakt",
    "militärmakter": "militärmakt",
    "militärmakterna": "militärmakt",
    "militärmakternas": "militärmakt",
    "militärmakters": "militärmakt",
    "militärmakts": "militärmakt",
    "militärmanövern": "militärmanöver",
    "militärmanöverns": "militärmanöver",
    "militärmanövers": "militärmanöver",
    "militärmanövrar": "militärmanöver",
    "militärmanövrarna": "militärmanöver",
    "militärmanövrarnas": "militärmanöver",
    "militärmanövrars": "militärmanöver",
    "militärmanövrer": "militärmanöver",
    "militärmanövrerna": "militärmanöver",
    "militärmanövrernas": "militärmanöver",
    "militärmanövrers": "militärmanöver",
    "militärmarschen": "militärmarsch",
    "militärmarschens": "militärmarsch",
    "militärmarscher": "militärmarsch",
    "militärmarscherna": "militärmarsch",
    "militärmarschernas": "militärmarsch",
    "militärmarschers": "militärmarsch",
    "militärmarschs": "militärmarsch",
    "militärmusiken": "militärmusik",
    "militärmusikens": "militärmusik",
    "militärmusiks": "militärmusik",
    "militärområden": "militärområde",
    "militärområdena": "militärområde",
    "militärområdenas": "militärområde",
    "militärområdens": "militärområde",
    "militärområdes": "militärområde",
    "militärområdet": "militärområde",
    "militärområdets": "militärområde",
    "militärorkestern": "militärorkester",
    "militärorkesterns": "militärorkester",
    "militärorkesters": "militärorkester",
    "militärorkestrar": "militärorkester",
    "militärorkestrarna": "militärorkester",
    "militärorkestrarnas": "militärorkester",
    "militärorkestrars": "militärorkester",
    "militärpolisen": "militärpolis",
    "militärpolisens": "militärpolis",
    "militärpoliser": "militärpolis",
    "militärpoliserna": "militärpolis",
    "militärpolisernas": "militärpolis",
    "militärpolisers": "militärpolis",
    "militärposteringar": "militärpostering",
    "militärposteringarna": "militärpostering",
    "militärposteringarnas": "militärpostering",
    "militärposteringars": "militärpostering",
    "militärposteringen": "militärpostering",
    "militärposteringens": "militärpostering",
    "militärposterings": "militärpostering",
    "militärpromenaden": "militärpromenad",
    "militärpromenadens": "militärpromenad",
    "militärpromenader": "militärpromenad",
    "militärpromenaderna": "militärpromenad",
    "militärpromenadernas": "militärpromenad",
    "militärpromenaders": "militärpromenad",
    "militärpromenads": "militärpromenad",
    "militärs": "militär",
    "militärt": "militär",
    "militärtjänsten": "militärtjänst",
    "militärtjänstens": "militärtjänst",
    "militärtjänstgöringar": "militärtjänstgöring",
    "militärtjänstgöringarna": "militärtjänstgöring",
    "militärtjänstgöringarnas": "militärtjänstgöring",
    "militärtjänstgöringars": "militärtjänstgöring",
    "militärtjänstgöringen": "militärtjänstgöring",
    "militärtjänstgöringens": "militärtjänstgöring",
    "militärtjänstgörings": "militärtjänstgöring",
    "militärtjänsts": "militärtjänst",
    "militärts": "militär",
    "militäruniformen": "militäruniform",
    "militäruniformens": "militäruniform",
    "militäruniformer": "militäruniform",
    "militäruniformerna": "militäruniform",
    "militäruniformernas": "militäruniform",
    "militäruniformers": "militäruniform",
    "militäruniforms": "militäruniform",
    "militärövningar": "militärövning",
    "militärövningarna": "militärövning",
    "militärövningarnas": "militärövning",
    "militärövningars": "militärövning",
    "militärövningen": "militärövning",
    "militärövningens": "militärövning",
    "militärövnings": "militärövning",
    "miljardaffären": "miljardaffär",
    "miljardaffärens": "miljardaffär",
    "miljardaffärer": "miljardaffär",
    "miljardaffärerna": "miljardaffär",
    "miljardaffärernas": "miljardaffär",
    "miljardaffärers": "miljardaffär",
    "miljardaffärs": "miljardaffär",
    "miljarddelar": "miljarddel",
    "miljarddelarna": "miljarddel",
    "miljarddelarnas": "miljarddel",
    "miljarddelars": "miljarddel",
    "miljarddelen": "miljarddel",
    "miljarddelens": "miljarddel",
    "miljarddels": "miljarddel",
    "miljarden": "miljard",
    "miljardens": "miljard",
    "miljarder": "miljard",
    "miljarderna": "miljard",
    "miljardernas": "miljard",
    "miljarders": "miljard",
    "miljards": "miljard",
    "miljardsatsningar": "miljardsatsning",
    "miljardsatsningarna": "miljardsatsning",
    "miljardsatsningarnas": "miljardsatsning",
    "miljardsatsningars": "miljardsatsning",
    "miljardsatsningen": "miljardsatsning",
    "miljardsatsningens": "miljardsatsning",
    "miljardsatsnings": "miljardsatsning",
    "miljardären": "miljardär",
    "miljardärens": "miljardär",
    "miljardärer": "miljardär",
    "miljardärerna": "miljardär",
    "miljardärernas": "miljardär",
    "miljardärers": "miljardär",
    "miljardärs": "miljardär",
    "miljondelar": "miljondel",
    "miljondelarna": "miljondel",
    "miljondelarnas": "miljondel",
    "miljondelars": "miljondel",
    "miljondelen": "miljondel",
    "miljondelens": "miljondel",
    "miljondels": "miljondel",
    "miljonen": "miljon",
    "miljonens": "miljon",
    "miljoner": "miljon",
    "miljonerna": "miljon",
    "miljonernas": "miljon",
    "miljoners": "miljon",
    "miljoninvesteringar": "miljoninvestering",
    "miljoninvesteringarna": "miljoninvestering",
    "miljoninvesteringarnas": "miljoninvestering",
    "miljoninvesteringars": "miljoninvestering",
    "miljoninvesteringen": "miljoninvestering",
    "miljoninvesteringens": "miljoninvestering",
    "miljoninvesterings": "miljoninvestering",
    "miljonklassen": "miljonklass",
    "miljonklassens": "miljonklass",
    "miljonklasser": "miljonklass",
    "miljonklasserna": "miljonklass",
    "miljonklassernas": "miljonklass",
    "miljonklassers": "miljonklass",
    "miljonklippen": "miljonklipp",
    "miljonklippens": "miljonklipp",
    "miljonklippet": "miljonklipp",
    "miljonklippets": "miljonklipp",
    "miljonklipps": "miljonklipp",
    "miljonlöne": "miljonlön",
    "miljonlönen": "miljonlön",
    "miljonlönens": "miljonlön",
    "miljonlöner": "miljonlön",
    "miljonlönerna": "miljonlön",
    "miljonlönernas": "miljonlön",
    "miljonlöners": "miljonlön",
    "miljonlöns": "miljonlön",
    "miljonpubliken": "miljonpublik",
    "miljonpublikens": "miljonpublik",
    "miljonpubliker": "miljonpublik",
    "miljonpublikerna": "miljonpublik",
    "miljonpublikernas": "miljonpublik",
    "miljonpublikers": "miljonpublik",
    "miljonpubliks": "miljonpublik",
    "miljons": "miljon",
    "miljonskadestånden": "miljonskadestånd",
    "miljonskadeståndens": "miljonskadestånd",
    "miljonskadeståndet": "miljonskadestånd",
    "miljonskadeståndets": "miljonskadestånd",
    "miljonskadestånds": "miljonskadestånd",
    "miljonstaden": "miljonstad",
    "miljonstadens": "miljonstad",
    "miljonstads": "miljonstad",
    "miljonstäder": "miljonstad",
    "miljonstäderna": "miljonstad",
    "miljonstädernas": "miljonstad",
    "miljonstäders": "miljonstad",
    "miljonstöden": "miljonstöd",
    "miljonstödens": "miljonstöd",
    "miljonstödet": "miljonstöd",
    "miljonstödets": "miljonstöd",
    "miljonstöds": "miljonstöd",
    "miljonte": "miljon",
    "miljontes": "miljon",
    "miljonären": "miljonär",
    "miljonärens": "miljonär",
    "miljonärer": "miljonär",
    "miljonärerna": "miljonär",
    "miljonärernas": "miljonär",
    "miljonärers": "miljonär",
    "miljonärs": "miljonär",
    "miljöaktivisten": "miljöaktivist",
    "miljöaktivistens": "miljöaktivist",
    "miljöaktivister": "miljöaktivist",
    "miljöaktivisterna": "miljöaktivist",
    "miljöaktivisternas": "miljöaktivist",
    "miljöaktivisters": "miljöaktivist",
    "miljöaktivists": "miljöaktivist",
    "miljöarbeten": "miljöarbete",
    "miljöarbetena": "miljöarbete",
    "miljöarbetenas": "miljöarbete",
    "miljöarbetens": "miljöarbete",
    "miljöarbetes": "miljöarbete",
    "miljöarbetet": "miljöarbete",
    "miljöarbetets": "miljöarbete",
    "miljöarbets": "miljöarbete",
    "miljöavtalen": "miljöavtal",
    "miljöavtalens": "miljöavtal",
    "miljöavtalet": "miljöavtal",
    "miljöavtalets": "miljöavtal",
    "miljöavtals": "miljöavtal",
    "miljöbilar": "miljöbil",
    "miljöbilarna": "miljöbil",
    "miljöbilarnas": "miljöbil",
    "miljöbilars": "miljöbil",
    "miljöbilen": "miljöbil",
    "miljöbilens": "miljöbil",
    "miljöbils": "miljöbil",
    "miljöbilssatsningar": "miljöbilssatsning",
    "miljöbilssatsningarna": "miljöbilssatsning",
    "miljöbilssatsningarnas": "miljöbilssatsning",
    "miljöbilssatsningars": "miljöbilssatsning",
    "miljöbilssatsningen": "miljöbilssatsning",
    "miljöbilssatsningens": "miljöbilssatsning",
    "miljöbilssatsnings": "miljöbilssatsning",
    "miljöbovar": "miljöbov",
    "miljöbovarna": "miljöbov",
    "miljöbovarnas": "miljöbov",
    "miljöbovars": "miljöbov",
    "miljöboven": "miljöbov",
    "miljöbovens": "miljöbov",
    "miljöbovs": "miljöbov",
    "miljöbrotten": "miljöbrott",
    "miljöbrottens": "miljöbrott",
    "miljöbrottet": "miljöbrott",
    "miljöbrottets": "miljöbrott",
    "miljöbrotts": "miljöbrott",
    "miljöbusar": "miljöbuse",
    "miljöbusarna": "miljöbuse",
    "miljöbusarnas": "miljöbuse",
    "miljöbusars": "miljöbuse",
    "miljöbusen": "miljöbuse",
    "miljöbusens": "miljöbuse",
    "miljöbuses": "miljöbuse",
    "miljöcertifierad": "miljöcertifiera",
    "miljöcertifierade": "miljöcertifiera",
    "miljöcertifierades": "miljöcertifiera",
    "miljöcertifierads": "miljöcertifiera",
    "miljöcertifierande": "miljöcertifiera",
    "miljöcertifieranden": "miljöcertifierande",
    "miljöcertifierandena": "miljöcertifierande",
    "miljöcertifierandenas": "miljöcertifierande",
    "miljöcertifierandens": "miljöcertifierande",
    "miljöcertifierandes": "miljöcertifierande",
    "miljöcertifierandet": "miljöcertifierande",
    "miljöcertifierandets": "miljöcertifierande",
    "miljöcertifierar": "miljöcertifiera",
    "miljöcertifieras": "miljöcertifiera",
    "miljöcertifierat": "miljöcertifiera",
    "miljöcertifierats": "miljöcertifiera",
    "miljöcertifieringar": "miljöcertifiering",
    "miljöcertifieringarna": "miljöcertifiering",
    "miljöcertifieringarnas": "miljöcertifiering",
    "miljöcertifieringars": "miljöcertifiering",
    "miljöcertifieringen": "miljöcertifiering",
    "miljöcertifieringens": "miljöcertifiering",
    "miljöcertifierings": "miljöcertifiering",
    "miljöer": "miljö",
    "miljöerna": "miljö",
    "miljöernas": "miljö",
    "miljöers": "miljö",
    "miljöfarliga": "miljöfarlig",
    "miljöfarligare": "miljöfarlig",
    "miljöfarligares": "miljöfarlig",
    "miljöfarligas": "miljöfarlig",
    "miljöfarligast": "miljöfarlig",
    "miljöfarligaste": "miljöfarlig",
    "miljöfarligastes": "miljöfarlig",
    "miljöfarligasts": "miljöfarlig",
    "miljöfarlige": "miljöfarlig",
    "miljöfarliges": "miljöfarlig",
    "miljöfarligheten": "miljöfarlighet",
    "miljöfarlighetens": "miljöfarlighet",
    "miljöfarlighets": "miljöfarlighet",
    "miljöfarligs": "miljöfarlig",
    "miljöfarligt": "miljöfarlig",
    "miljöfarligts": "miljöfarlig",
    "miljöfrågan": "miljöfråga",
    "miljöfrågans": "miljöfråga",
    "miljöfrågas": "miljöfråga",
    "miljöfråge": "miljöfråga",
    "miljöfrågor": "miljöfråga",
    "miljöfrågorna": "miljöfråga",
    "miljöfrågornas": "miljöfråga",
    "miljöfrågors": "miljöfråga",
    "miljöföroreningar": "miljöförorening",
    "miljöföroreningarna": "miljöförorening",
    "miljöföroreningarnas": "miljöförorening",
    "miljöföroreningars": "miljöförorening",
    "miljöföroreningen": "miljöförorening",
    "miljöföroreningens": "miljöförorening",
    "miljöförorenings": "miljöförorening",
    "miljöförstörar": "miljöförstörare",
    "miljöförstöraren": "miljöförstörare",
    "miljöförstörarens": "miljöförstörare",
    "miljöförstörares": "miljöförstörare",
    "miljöförstörarna": "miljöförstörare",
    "miljöförstörarnas": "miljöförstörare",
    "miljöförstöringar": "miljöförstöring",
    "miljöförstöringarna": "miljöförstöring",
    "miljöförstöringarnas": "miljöförstöring",
    "miljöförstöringars": "miljöförstöring",
    "miljöförstöringen": "miljöförstöring",
    "miljöförstöringens": "miljöförstöring",
    "miljöförstörings": "miljöförstöring",
    "miljöförsämringar": "miljöförsämring",
    "miljöförsämringarna": "miljöförsämring",
    "miljöförsämringarnas": "miljöförsämring",
    "miljöförsämringars": "miljöförsämring",
    "miljöförsämringen": "miljöförsämring",
    "miljöförsämringens": "miljöförsämring",
    "miljöförsämrings": "miljöförsämring",
    "miljögifter": "miljögift",
    "miljögifterna": "miljögift",
    "miljögifternas": "miljögift",
    "miljögifters": "miljögift",
    "miljögiftet": "miljögift",
    "miljögiftets": "miljögift",
    "miljögifts": "miljögift",
    "miljögiftshalten": "miljögiftshalt",
    "miljögiftshaltens": "miljögiftshalt",
    "miljögiftshalter": "miljögiftshalt",
    "miljögiftshalterna": "miljögiftshalt",
    "miljögiftshalternas": "miljögiftshalt",
    "miljögiftshalters": "miljögiftshalt",
    "miljögiftshalts": "miljögiftshalt",
    "miljöhjältar": "miljöhjälte",
    "miljöhjältarna": "miljöhjälte",
    "miljöhjältarnas": "miljöhjälte",
    "miljöhjältars": "miljöhjälte",
    "miljöhjälten": "miljöhjälte",
    "miljöhjältens": "miljöhjälte",
    "miljöhjältes": "miljöhjälte",
    "miljöhycklar": "miljöhycklare",
    "miljöhycklaren": "miljöhycklare",
    "miljöhycklarens": "miljöhycklare",
    "miljöhycklares": "miljöhycklare",
    "miljöhycklarna": "miljöhycklare",
    "miljöhycklarnas": "miljöhycklare",
    "miljöhänsynen": "miljöhänsyn",
    "miljöhänsynens": "miljöhänsyn",
    "miljöhänsynet": "miljöhänsyn",
    "miljöhänsynets": "miljöhänsyn",
    "miljöhänsyns": "miljöhänsyn",
    "miljökatastrofen": "miljökatastrof",
    "miljökatastrofens": "miljökatastrof",
    "miljökatastrofer": "miljökatastrof",
    "miljökatastroferna": "miljökatastrof",
    "miljökatastrofernas": "miljökatastrof",
    "miljökatastrofers": "miljökatastrof",
    "miljökatastrofs": "miljökatastrof",
    "miljöliberala": "miljöliberal",
    "miljöliberalare": "miljöliberal",
    "miljöliberalares": "miljöliberal",
    "miljöliberalas": "miljöliberal",
    "miljöliberalast": "miljöliberal",
    "miljöliberalaste": "miljöliberal",
    "miljöliberalastes": "miljöliberal",
    "miljöliberalasts": "miljöliberal",
    "miljöliberale": "miljöliberal",
    "miljöliberales": "miljöliberal",
    "miljöliberals": "miljöliberal",
    "miljöliberalt": "miljöliberal",
    "miljöliberalts": "miljöliberal",
    "miljömedvetenheten": "miljömedvetenhet",
    "miljömedvetenhetens": "miljömedvetenhet",
    "miljömedvetenhets": "miljömedvetenhet",
    "miljömedvetens": "miljömedveten",
    "miljömedvetet": "miljömedveten",
    "miljömedvetets": "miljömedveten",
    "miljömedvetna": "miljömedveten",
    "miljömedvetnare": "miljömedveten",
    "miljömedvetnares": "miljömedveten",
    "miljömedvetnas": "miljömedveten",
    "miljömedvetnast": "miljömedveten",
    "miljömedvetnaste": "miljömedveten",
    "miljömedvetnastes": "miljömedveten",
    "miljömedvetnasts": "miljömedveten",
    "miljömedvetne": "miljömedveten",
    "miljömedvetnes": "miljömedveten",
    "miljöministern": "miljöminister",
    "miljöministerns": "miljöminister",
    "miljöministers": "miljöminister",
    "miljöministrar": "miljöminister",
    "miljöministrarna": "miljöminister",
    "miljöministrarnas": "miljöminister",
    "miljöministrars": "miljöminister",
    "miljömärk": "miljömärka",
    "miljömärkande": "miljömärka",
    "miljömärkanden": "miljömärkande",
    "miljömärkandena": "miljömärkande",
    "miljömärkandenas": "miljömärkande",
    "miljömärkandens": "miljömärkande",
    "miljömärkandes": "miljömärkande",
    "miljömärkandet": "miljömärkande",
    "miljömärkandets": "miljömärkande",
    "miljömärkas": "miljömärka",
    "miljömärker": "miljömärka",
    "miljömärkes": "miljömärka",
    "miljömärkningar": "miljömärkning",
    "miljömärkningarna": "miljömärkning",
    "miljömärkningarnas": "miljömärkning",
    "miljömärkningars": "miljömärkning",
    "miljömärkningen": "miljömärkning",
    "miljömärkningens": "miljömärkning",
    "miljömärknings": "miljömärkning",
    "miljömärks": "miljömärka",
    "miljömärkt": "miljömärka",
    "miljömärkta": "miljömärka",
    "miljömärktas": "miljömärka",
    "miljömärkte": "miljömärka",
    "miljömärktes": "miljömärka",
    "miljömärkts": "miljömärka",
    "miljömässiga": "miljömässig",
    "miljömässigare": "miljömässig",
    "miljömässigares": "miljömässig",
    "miljömässigas": "miljömässig",
    "miljömässigast": "miljömässig",
    "miljömässigaste": "miljömässig",
    "miljömässigastes": "miljömässig",
    "miljömässigasts": "miljömässig",
    "miljömässige": "miljömässig",
    "miljömässiges": "miljömässig",
    "miljömässigheten": "miljömässighet",
    "miljömässighetens": "miljömässighet",
    "miljömässighets": "miljömässighet",
    "miljömässigs": "miljömässig",
    "miljömässigt": "miljömässig",
    "miljömässigts": "miljömässig",
    "miljön": "miljö",
    "miljöns": "miljö",
    "miljöombyten": "miljöombyte",
    "miljöombytena": "miljöombyte",
    "miljöombytenas": "miljöombyte",
    "miljöombytens": "miljöombyte",
    "miljöombytes": "miljöombyte",
    "miljöombytet": "miljöombyte",
    "miljöombytets": "miljöombyte",
    "miljöpolitiken": "miljöpolitik",
    "miljöpolitikens": "miljöpolitik",
    "miljöpolitiks": "miljöpolitik",
    "miljöpolitiska": "miljöpolitisk",
    "miljöpolitiskas": "miljöpolitisk",
    "miljöpolitiske": "miljöpolitisk",
    "miljöpolitiskes": "miljöpolitisk",
    "miljöpolitisks": "miljöpolitisk",
    "miljöpolitiskt": "miljöpolitisk",
    "miljöpolitiskts": "miljöpolitisk",
    "miljöproblemen": "miljöproblem",
    "miljöproblemens": "miljöproblem",
    "miljöproblemet": "miljöproblem",
    "miljöproblemets": "miljöproblem",
    "miljöproblems": "miljöproblem",
    "miljös": "miljö",
    "miljöskadade": "miljöskadad",
    "miljöskadades": "miljöskadad",
    "miljöskadads": "miljöskadad",
    "miljöskadan": "miljöskada",
    "miljöskadans": "miljöskada",
    "miljöskadas": "miljöskada",
    "miljöskadat": "miljöskadad",
    "miljöskadats": "miljöskadad",
    "miljöskade": "miljöskada",
    "miljöskador": "miljöskada",
    "miljöskadorna": "miljöskada",
    "miljöskadornas": "miljöskada",
    "miljöskadors": "miljöskada",
    "miljöskildringar": "miljöskildring",
    "miljöskildringarna": "miljöskildring",
    "miljöskildringarnas": "miljöskildring",
    "miljöskildringars": "miljöskildring",
    "miljöskildringen": "miljöskildring",
    "miljöskildringens": "miljöskildring",
    "miljöskildrings": "miljöskildring",
    "miljöskurkar": "miljöskurk",
    "miljöskurkarna": "miljöskurk",
    "miljöskurkarnas": "miljöskurk",
    "miljöskurkars": "miljöskurk",
    "miljöskurken": "miljöskurk",
    "miljöskurkens": "miljöskurk",
    "miljöskurks": "miljöskurk",
    "miljöskydden": "miljöskydd",
    "miljöskyddens": "miljöskydd",
    "miljöskydds": "miljöskydd",
    "miljötidskriften": "miljötidskrift",
    "miljötidskriftens": "miljötidskrift",
    "miljötidskrifter": "miljötidskrift",
    "miljötidskrifterna": "miljötidskrift",
    "miljötidskrifternas": "miljötidskrift",
    "miljötidskrifters": "miljötidskrift",
    "miljötidskrifts": "miljötidskrift",
    "miljötänkanden": "miljötänkande",
    "miljötänkandena": "miljötänkande",
    "miljötänkandenas": "miljötänkande",
    "miljötänkandens": "miljötänkande",
    "miljötänkandes": "miljötänkande",
    "miljötänkandet": "miljötänkande",
    "miljötänkandets": "miljötänkande",
    "miljöutskotten": "miljöutskott",
    "miljöutskottens": "miljöutskott",
    "miljöutskottet": "miljöutskott",
    "miljöutskottets": "miljöutskott",
    "miljöutskotts": "miljöutskott",
    "miljövinsten": "miljövinst",
    "miljövinstens": "miljövinst",
    "miljövinster": "miljövinst",
    "miljövinsterna": "miljövinst",
    "miljövinsternas": "miljövinst",
    "miljövinsters": "miljövinst",
    "miljövinsts": "miljövinst",
    "miljövänliga": "miljövänlig",
    "miljövänligare": "miljövänlig",
    "miljövänligares": "miljövänlig",
    "miljövänligas": "miljövänlig",
    "miljövänligast": "miljövänlig",
    "miljövänligaste": "miljövänlig",
    "miljövänligastes": "miljövänlig",
    "miljövänligasts": "miljövänlig",
    "miljövänlige": "miljövänlig",
    "miljövänliges": "miljövänlig",
    "miljövänligheten": "miljövänlighet",
    "miljövänlighetens": "miljövänlighet",
    "miljövänlighets": "miljövänlighet",
    "miljövänligs": "miljövänlig",
    "miljövänligt": "miljövänlig",
    "miljövänligts": "miljövänlig",
    "miljövärnet": "miljövärn",
    "miljövärnets": "miljövärn",
    "miljövärns": "miljövärn",
    "miljövården": "miljövård",
    "miljövårdens": "miljövård",
    "miljövårds": "miljövård",
    "milkshaken": "milkshake",
    "milkshakens": "milkshake",
    "milkshakes": "milkshake",
    "milliarden": "milliard",
    "milliardens": "milliard",
    "milliarder": "milliard",
    "milliarderna": "milliard",
    "milliardernas": "milliard",
    "milliarders": "milliard",
    "milliards": "milliard",
    "millibaren": "millibar",
    "millibarens": "millibar",
    "millibars": "millibar",
    "milligrammen": "milligram",
    "milligrammens": "milligram",
    "milligrammet": "milligram",
    "milligrammets": "milligram",
    "milligrams": "milligram",
    "millilitern": "milliliter",
    "milliliterna": "milliliter",
    "milliliternas": "milliliter",
    "milliliterns": "milliliter",
    "milliliters": "milliliter",
    "millimetern": "millimeter",
    "millimeterna": "millimeter",
    "millimeternas": "millimeter",
    "millimeterns": "millimeter",
    "millimeterpapperen": "millimeterpapper",
    "millimeterpapperens": "millimeterpapper",
    "millimeterpapperet": "millimeterpapper",
    "millimeterpapperets": "millimeterpapper",
    "millimeterpapperna": "millimeterpapper",
    "millimeterpappernas": "millimeterpapper",
    "millimeterpappers": "millimeterpapper",
    "millimeterpappren": "millimeterpapper",
    "millimeterpapprens": "millimeterpapper",
    "millimeterpappret": "millimeterpapper",
    "millimeterpapprets": "millimeterpapper",
    "millimeterrättvisan": "millimeterrättvisa",
    "millimeterrättvisans": "millimeterrättvisa",
    "millimeterrättvisas": "millimeterrättvisa",
    "millimeters": "millimeter",
    "millimetertjocka": "millimetertjock",
    "millimetertjockare": "millimetertjock",
    "millimetertjockares": "millimetertjock",
    "millimetertjockas": "millimetertjock",
    "millimetertjockast": "millimetertjock",
    "millimetertjockaste": "millimetertjock",
    "millimetertjockastes": "millimetertjock",
    "millimetertjockasts": "millimetertjock",
    "millimetertjocke": "millimetertjock",
    "millimetertjockes": "millimetertjock",
    "millimetertjocks": "millimetertjock",
    "millimetertjockt": "millimetertjock",
    "millimetertjockts": "millimetertjock",
    "millimetrar": "millimeter",
    "millimetrarna": "millimeter",
    "millimetrarnas": "millimeter",
    "millimetrars": "millimeter",
    "millionen": "million",
    "millionens": "million",
    "millioner": "million",
    "millionerna": "million",
    "millionernas": "million",
    "millioners": "million",
    "millions": "million",
    "millionte": "million",
    "milliontes": "million",
    "millisieverten": "millisievert",
    "millisievertens": "millisievert",
    "millisieverts": "millisievert",
    "milliwatten": "milliwatt",
    "milliwattens": "milliwatt",
    "milliwatts": "milliwatt",
    "milon": "milo",
    "milona": "milo",
    "milonas": "milo",
    "milons": "milo",
    "milor": "mila",
    "milorna": "mila",
    "milornas": "mila",
    "milors": "mila",
    "milos": "milo",
    "milot": "milo",
    "milots": "milo",
    "mils": "mila",
    "milstenar": "milsten",
    "milstenarna": "milsten",
    "milstenarnas": "milsten",
    "milstenars": "milsten",
    "milstenen": "milsten",
    "milstenens": "milsten",
    "milstens": "milsten",
    "milstolp": "milstolpe",
    "milstolpar": "milstolpe",
    "milstolparna": "milstolpe",
    "milstolparnas": "milstolpe",
    "milstolpars": "milstolpe",
    "milstolpen": "milstolpe",
    "milstolpens": "milstolpe",
    "milstolpes": "milstolpe",
    "milstolps": "milstolpe",
    "milsvida": "milsvid",
    "milsvidare": "milsvid",
    "milsvidares": "milsvid",
    "milsvidas": "milsvid",
    "milsvidast": "milsvid",
    "milsvidaste": "milsvid",
    "milsvidastes": "milsvid",
    "milsvidasts": "milsvid",
    "milsvide": "milsvid",
    "milsvides": "milsvid",
    "milsvids": "milsvid",
    "milsvitt": "milsvid",
    "milsvitts": "milsvid",
    "milt": "mild",
    "milts": "mild",
    "mim": "mima",
    "mimad": "mima",
    "mimade": "mima",
    "mimades": "mima",
    "mimads": "mima",
    "mimande": "mima",
    "mimanden": "mimande",
    "mimandena": "mimande",
    "mimandenas": "mimande",
    "mimandens": "mimande",
    "mimandes": "mimande",
    "mimandet": "mimande",
    "mimandets": "mimande",
    "mimar": "mima",
    "mimas": "mima",
    "mimat": "mima",
    "mimats": "mima",
    "mimen": "mim",
    "mimens": "mim",
    "mimer": "mim",
    "mimerna": "mim",
    "mimernas": "mim",
    "mimers": "mim",
    "mimicryn": "mimicry",
    "mimicryns": "mimicry",
    "mimicrys": "mimicry",
    "mimiken": "mimik",
    "mimikens": "mimik",
    "mimikern": "mimiker",
    "mimikerna": "mimiker",
    "mimikernas": "mimiker",
    "mimikerns": "mimiker",
    "mimikers": "mimiker",
    "mimikryn": "mimikry",
    "mimikryns": "mimikry",
    "mimikrys": "mimikry",
    "mimiks": "mimik",
    "mimiska": "mimisk",
    "mimiskare": "mimisk",
    "mimiskares": "mimisk",
    "mimiskas": "mimisk",
    "mimiskast": "mimisk",
    "mimiskaste": "mimisk",
    "mimiskastes": "mimisk",
    "mimiskasts": "mimisk",
    "mimiske": "mimisk",
    "mimiskes": "mimisk",
    "mimisks": "mimisk",
    "mimiskt": "mimisk",
    "mimiskts": "mimisk",
    "mimos": "mimosa",
    "mimosan": "mimosa",
    "mimosans": "mimosa",
    "mimosas": "mimosa",
    "mimosasalladen": "mimosasallad",
    "mimosasalladens": "mimosasallad",
    "mimosasallader": "mimosasallad",
    "mimosasalladerna": "mimosasallad",
    "mimosasalladernas": "mimosasallad",
    "mimosasalladers": "mimosasallad",
    "mimosasallads": "mimosasallad",
    "mimose": "mimosa",
    "mimosor": "mimosa",
    "mimosorna": "mimosa",
    "mimosornas": "mimosa",
    "mimosors": "mimosa",
    "mims": "mim",
    "min": "mina",
    "mina": "jag",
    "minan": "mina",
    "minans": "mina",
    "minaretbyggen": "minaretbygge",
    "minaretbyggena": "minaretbygge",
    "minaretbyggenas": "minaretbygge",
    "minaretbyggens": "minaretbygge",
    "minaretbygges": "minaretbygge",
    "minaretbygget": "minaretbygge",
    "minaretbyggets": "minaretbygge",
    "minareten": "minaret",
    "minaretens": "minaret",
    "minareter": "minaret",
    "minareterna": "minaret",
    "minareternas": "minaret",
    "minareters": "minaret",
    "minaretförbuden": "minaretförbud",
    "minaretförbudens": "minaretförbud",
    "minaretförbudet": "minaretförbud",
    "minaretförbudets": "minaretförbud",
    "minaretförbuds": "minaretförbud",
    "minarets": "minaret",
    "minas": "mina",
    "minbomben": "minbomb",
    "minbombens": "minbomb",
    "minbomber": "minbomb",
    "minbomberna": "minbomb",
    "minbombernas": "minbomb",
    "minbombers": "minbomb",
    "minbombs": "minbomb",
    "mind": "minna",
    "minda": "minna",
    "mindas": "minna",
    "minde": "minna",
    "mindervärdeskomplexen": "mindervärdeskomplex",
    "mindervärdeskomplexens": "mindervärdeskomplex",
    "mindervärdeskomplexet": "mindervärdeskomplex",
    "mindervärdeskomplexets": "mindervärdeskomplex",
    "mindervärdeskänsl": "mindervärdeskänsla",
    "mindervärdeskänslan": "mindervärdeskänsla",
    "mindervärdeskänslans": "mindervärdeskänsla",
    "mindervärdeskänslas": "mindervärdeskänsla",
    "mindervärdeskänsle": "mindervärdeskänsla",
    "mindervärdeskänslo": "mindervärdeskänsla",
    "mindervärdeskänslor": "mindervärdeskänsla",
    "mindervärdeskänslorna": "mindervärdeskänsla",
    "mindervärdeskänslornas": "mindervärdeskänsla",
    "mindervärdeskänslors": "mindervärdeskänsla",
    "mindervärdiga": "mindervärdig",
    "mindervärdigare": "mindervärdig",
    "mindervärdigares": "mindervärdig",
    "mindervärdigas": "mindervärdig",
    "mindervärdigast": "mindervärdig",
    "mindervärdigaste": "mindervärdig",
    "mindervärdigastes": "mindervärdig",
    "mindervärdigasts": "mindervärdig",
    "mindervärdige": "mindervärdig",
    "mindervärdiges": "mindervärdig",
    "mindervärdigheten": "mindervärdighet",
    "mindervärdighetens": "mindervärdighet",
    "mindervärdighets": "mindervärdighet",
    "mindervärdigs": "mindervärdig",
    "mindervärdigt": "mindervärdig",
    "mindervärdigts": "mindervärdig",
    "minderåriga": "minderårig",
    "minderårigare": "minderårig",
    "minderårigares": "minderårig",
    "minderårigas": "minderårig",
    "minderårigast": "minderårig",
    "minderårigaste": "minderårig",
    "minderårigastes": "minderårig",
    "minderårigasts": "minderårig",
    "minderårige": "minderårig",
    "minderåriges": "minderårig",
    "minderårigheten": "minderårighet",
    "minderårighetens": "minderårighet",
    "minderårighets": "minderårighet",
    "minderårigs": "minderårig",
    "minderårigt": "minderårig",
    "minderårigts": "minderårig",
    "mindes": "minnas",
    "mindre": "liten",
    "mindres": "liten",
    "mindretalen": "mindretal",
    "mindretalens": "mindretal",
    "mindretalet": "mindretal",
    "mindretalets": "mindretal",
    "mindretals": "mindretal",
    "minds": "minna",
    "mine": "mina",
    "minen": "min",
    "minens": "min",
    "miner": "min",
    "minerad": "minera",
    "minerade": "minera",
    "minerades": "minera",
    "minerads": "minera",
    "mineraler": "mineral",
    "mineralerna": "mineral",
    "mineralernas": "mineral",
    "mineralers": "mineral",
    "mineralet": "mineral",
    "mineralets": "mineral",
    "mineralfärgen": "mineralfärg",
    "mineralfärgens": "mineralfärg",
    "mineralfärger": "mineralfärg",
    "mineralfärgerna": "mineralfärg",
    "mineralfärgernas": "mineralfärg",
    "mineralfärgers": "mineralfärg",
    "mineralfärgs": "mineralfärg",
    "mineralgångar": "mineralgång",
    "mineralgångarna": "mineralgång",
    "mineralgångarnas": "mineralgång",
    "mineralgångars": "mineralgång",
    "mineralgången": "mineralgång",
    "mineralgångens": "mineralgång",
    "mineralgångs": "mineralgång",
    "mineralhalten": "mineralhalt",
    "mineralhaltens": "mineralhalt",
    "mineralhalter": "mineralhalt",
    "mineralhalterna": "mineralhalt",
    "mineralhalternas": "mineralhalt",
    "mineralhalters": "mineralhalt",
    "mineralhaltiga": "mineralhaltig",
    "mineralhaltigare": "mineralhaltig",
    "mineralhaltigares": "mineralhaltig",
    "mineralhaltigas": "mineralhaltig",
    "mineralhaltigast": "mineralhaltig",
    "mineralhaltigaste": "mineralhaltig",
    "mineralhaltigastes": "mineralhaltig",
    "mineralhaltigasts": "mineralhaltig",
    "mineralhaltige": "mineralhaltig",
    "mineralhaltiges": "mineralhaltig",
    "mineralhaltigs": "mineralhaltig",
    "mineralhaltigt": "mineralhaltig",
    "mineralhaltigts": "mineralhaltig",
    "mineralhalts": "mineralhalt",
    "mineralier": "mineral",
    "mineralierna": "mineral",
    "mineraliernas": "mineral",
    "mineraliers": "mineral",
    "mineraliserad": "mineralisera",
    "mineraliserade": "mineralisera",
    "mineraliserades": "mineralisera",
    "mineraliserads": "mineralisera",
    "mineraliserande": "mineralisera",
    "mineraliseranden": "mineraliserande",
    "mineraliserandena": "mineraliserande",
    "mineraliserandenas": "mineraliserande",
    "mineraliserandens": "mineraliserande",
    "mineraliserandes": "mineraliserande",
    "mineraliserandet": "mineraliserande",
    "mineraliserandets": "mineraliserande",
    "mineraliserar": "mineralisera",
    "mineraliseras": "mineralisera",
    "mineraliserat": "mineralisera",
    "mineraliserats": "mineralisera",
    "mineraliserbara": "mineraliserbar",
    "mineraliserbarare": "mineraliserbar",
    "mineraliserbarares": "mineraliserbar",
    "mineraliserbaras": "mineraliserbar",
    "mineraliserbarast": "mineraliserbar",
    "mineraliserbaraste": "mineraliserbar",
    "mineraliserbarastes": "mineraliserbar",
    "mineraliserbarasts": "mineraliserbar",
    "mineraliserbare": "mineraliserbar",
    "mineraliserbares": "mineraliserbar",
    "mineraliserbarheten": "mineraliserbarhet",
    "mineraliserbarhetens": "mineraliserbarhet",
    "mineraliserbarhets": "mineraliserbarhet",
    "mineraliserbars": "mineraliserbar",
    "mineraliserbart": "mineraliserbar",
    "mineraliserbarts": "mineraliserbar",
    "mineraliseringar": "mineralisering",
    "mineraliseringarna": "mineralisering",
    "mineraliseringarnas": "mineralisering",
    "mineraliseringars": "mineralisering",
    "mineraliseringen": "mineralisering",
    "mineraliseringens": "mineralisering",
    "mineraliserings": "mineralisering",
    "mineralmuseer": "mineralmuseum",
    "mineralmuseerna": "mineralmuseum",
    "mineralmuseernas": "mineralmuseum",
    "mineralmuseers": "mineralmuseum",
    "mineralmuseet": "mineralmuseum",
    "mineralmuseets": "mineralmuseum",
    "mineralmusei": "mineralmuseum",
    "mineralmuseums": "mineralmuseum",
    "mineralogen": "mineralog",
    "mineralogens": "mineralog",
    "mineraloger": "mineralog",
    "mineralogerna": "mineralog",
    "mineralogernas": "mineralog",
    "mineralogers": "mineralog",
    "mineralogien": "mineralogi",
    "mineralogiens": "mineralogi",
    "mineralogin": "mineralogi",
    "mineralogins": "mineralogi",
    "mineralogis": "mineralogi",
    "mineralogiska": "mineralogisk",
    "mineralogiskare": "mineralogisk",
    "mineralogiskares": "mineralogisk",
    "mineralogiskas": "mineralogisk",
    "mineralogiskast": "mineralogisk",
    "mineralogiskaste": "mineralogisk",
    "mineralogiskastes": "mineralogisk",
    "mineralogiskasts": "mineralogisk",
    "mineralogiske": "mineralogisk",
    "mineralogiskes": "mineralogisk",
    "mineralogisks": "mineralogisk",
    "mineralogiskt": "mineralogisk",
    "mineralogiskts": "mineralogisk",
    "mineralogs": "mineralog",
    "mineraloljan": "mineralolja",
    "mineraloljans": "mineralolja",
    "mineraloljas": "mineralolja",
    "mineralolje": "mineralolja",
    "mineraloljor": "mineralolja",
    "mineraloljorna": "mineralolja",
    "mineraloljornas": "mineralolja",
    "mineraloljors": "mineralolja",
    "mineralproven": "mineralprov",
    "mineralprovens": "mineralprov",
    "mineralprover": "mineralprov",
    "mineralproverna": "mineralprov",
    "mineralprovernas": "mineralprov",
    "mineralprovers": "mineralprov",
    "mineralprovet": "mineralprov",
    "mineralprovets": "mineralprov",
    "mineralprovs": "mineralprov",
    "mineralrikes": "mineralrike",
    "mineralriket": "mineralrike",
    "mineralrikets": "mineralrike",
    "minerals": "mineral",
    "mineralsalter": "mineralsalt",
    "mineralsalterna": "mineralsalt",
    "mineralsalternas": "mineralsalt",
    "mineralsalters": "mineralsalt",
    "mineralsaltet": "mineralsalt",
    "mineralsaltets": "mineralsalt",
    "mineralsalts": "mineralsalt",
    "mineraltillgångarna": "mineraltillgångar",
    "mineraltillgångarnas": "mineraltillgångar",
    "mineraltillgångars": "mineraltillgångar",
    "mineraltillgångs": "mineraltillgångar",
    "mineraltillsatsen": "mineraltillsats",
    "mineraltillsatsens": "mineraltillsats",
    "mineraltillsatser": "mineraltillsats",
    "mineraltillsatserna": "mineraltillsats",
    "mineraltillsatsernas": "mineraltillsats",
    "mineraltillsatsers": "mineraltillsats",
    "mineralullen": "mineralull",
    "mineralullens": "mineralull",
    "mineralulls": "mineralull",
    "mineralutvinningar": "mineralutvinning",
    "mineralutvinningarna": "mineralutvinning",
    "mineralutvinningarnas": "mineralutvinning",
    "mineralutvinningars": "mineralutvinning",
    "mineralutvinningen": "mineralutvinning",
    "mineralutvinningens": "mineralutvinning",
    "mineralutvinnings": "mineralutvinning",
    "mineralvattenflask": "mineralvattenflaska",
    "mineralvattenflaskan": "mineralvattenflaska",
    "mineralvattenflaskans": "mineralvattenflaska",
    "mineralvattenflaskas": "mineralvattenflaska",
    "mineralvattenflaske": "mineralvattenflaska",
    "mineralvattenflaskor": "mineralvattenflaska",
    "mineralvattenflaskorna": "mineralvattenflaska",
    "mineralvattenflaskornas": "mineralvattenflaska",
    "mineralvattenflaskors": "mineralvattenflaska",
    "mineralvattens": "mineralvatten",
    "mineralvattnen": "mineralvatten",
    "mineralvattnens": "mineralvatten",
    "mineralvattnet": "mineralvatten",
    "mineralvattnets": "mineralvatten",
    "mineralämnen": "mineralämne",
    "mineralämnena": "mineralämne",
    "mineralämnenas": "mineralämne",
    "mineralämnens": "mineralämne",
    "mineralämnes": "mineralämne",
    "mineralämnet": "mineralämne",
    "mineralämnets": "mineralämne",
    "mineralöverdragen": "mineralöverdrag",
    "mineralöverdragens": "mineralöverdrag",
    "mineralöverdraget": "mineralöverdrag",
    "mineralöverdragets": "mineralöverdrag",
    "mineralöverdrags": "mineralöverdrag",
    "minerande": "minera",
    "mineranden": "minerande",
    "minerandena": "minerande",
    "minerandenas": "minerande",
    "minerandens": "minerande",
    "minerandes": "minerande",
    "minerandet": "minerande",
    "minerandets": "minerande",
    "minerar": "minera",
    "mineras": "minera",
    "minerat": "minera",
    "minerats": "minera",
    "minerbara": "minerbar",
    "minerbarare": "minerbar",
    "minerbarares": "minerbar",
    "minerbaras": "minerbar",
    "minerbarast": "minerbar",
    "minerbaraste": "minerbar",
    "minerbarastes": "minerbar",
    "minerbarasts": "minerbar",
    "minerbare": "minerbar",
    "minerbares": "minerbar",
    "minerbarheten": "minerbarhet",
    "minerbarhetens": "minerbarhet",
    "minerbarhets": "minerbarhet",
    "minerbars": "minerbar",
    "minerbart": "minerbar",
    "minerbarts": "minerbar",
    "mineringar": "minering",
    "mineringarna": "minering",
    "mineringarnas": "minering",
    "mineringars": "minering",
    "mineringen": "minering",
    "mineringens": "minering",
    "minerings": "minering",
    "minerna": "min",
    "minernas": "min",
    "miners": "min",
    "minestronen": "minestrone",
    "minestronens": "minestrone",
    "minestrones": "minestrone",
    "minestronesoppan": "minestronesoppa",
    "minestronesoppans": "minestronesoppa",
    "minestronesoppas": "minestronesoppa",
    "minestronesoppe": "minestronesoppa",
    "minestronesoppor": "minestronesoppa",
    "minestronesopporna": "minestronesoppa",
    "minestronesoppornas": "minestronesoppa",
    "minestronesoppors": "minestronesoppa",
    "minetten": "minett",
    "minettens": "minett",
    "minetts": "minett",
    "minexplosionen": "minexplosion",
    "minexplosionens": "minexplosion",
    "minexplosioner": "minexplosion",
    "minexplosionerna": "minexplosion",
    "minexplosionernas": "minexplosion",
    "minexplosioners": "minexplosion",
    "minexplosions": "minexplosion",
    "minfälten": "minfält",
    "minfältens": "minfält",
    "minfältet": "minfält",
    "minfältets": "minfält",
    "minfälts": "minfält",
    "mingels": "mingel",
    "mingl": "mingla",
    "minglade": "mingla",
    "minglades": "mingla",
    "minglande": "mingla",
    "minglanden": "minglande",
    "minglandena": "minglande",
    "minglandenas": "minglande",
    "minglandens": "minglande",
    "minglandes": "minglande",
    "minglandet": "minglande",
    "minglandets": "minglande",
    "minglar": "mingla",
    "minglas": "mingla",
    "minglat": "mingla",
    "minglats": "mingla",
    "minglen": "mingel",
    "minglens": "mingel",
    "minglet": "mingel",
    "minglets": "mingel",
    "mingångar": "mingång",
    "mingångarna": "mingång",
    "mingångarnas": "mingång",
    "mingångars": "mingång",
    "mingången": "mingång",
    "mingångens": "mingång",
    "mingångs": "mingång",
    "miniatyren": "miniatyr",
    "miniatyrens": "miniatyr",
    "miniatyrer": "miniatyr",
    "miniatyrerna": "miniatyr",
    "miniatyrernas": "miniatyr",
    "miniatyrers": "miniatyr",
    "miniatyrflask": "miniatyrflaska",
    "miniatyrflaskan": "miniatyrflaska",
    "miniatyrflaskans": "miniatyrflaska",
    "miniatyrflaskas": "miniatyrflaska",
    "miniatyrflaske": "miniatyrflaska",
    "miniatyrflaskor": "miniatyrflaska",
    "miniatyrflaskorna": "miniatyrflaska",
    "miniatyrflaskornas": "miniatyrflaska",
    "miniatyrflaskors": "miniatyrflaska",
    "miniatyriserad": "miniatyrisera",
    "miniatyriserade": "miniatyrisera",
    "miniatyriserades": "miniatyrisera",
    "miniatyriserads": "miniatyrisera",
    "miniatyriserande": "miniatyrisera",
    "miniatyriseranden": "miniatyriserande",
    "miniatyriserandena": "miniatyriserande",
    "miniatyriserandenas": "miniatyriserande",
    "miniatyriserandens": "miniatyriserande",
    "miniatyriserandes": "miniatyriserande",
    "miniatyriserandet": "miniatyriserande",
    "miniatyriserandets": "miniatyriserande",
    "miniatyriserar": "miniatyrisera",
    "miniatyriseras": "miniatyrisera",
    "miniatyriserat": "miniatyrisera",
    "miniatyriserats": "miniatyrisera",
    "miniatyriserbara": "miniatyriserbar",
    "miniatyriserbarare": "miniatyriserbar",
    "miniatyriserbarares": "miniatyriserbar",
    "miniatyriserbaras": "miniatyriserbar",
    "miniatyriserbarast": "miniatyriserbar",
    "miniatyriserbaraste": "miniatyriserbar",
    "miniatyriserbarastes": "miniatyriserbar",
    "miniatyriserbarasts": "miniatyriserbar",
    "miniatyriserbare": "miniatyriserbar",
    "miniatyriserbares": "miniatyriserbar",
    "miniatyriserbarheten": "miniatyriserbarhet",
    "miniatyriserbarhetens": "miniatyriserbarhet",
    "miniatyriserbarhets": "miniatyriserbarhet",
    "miniatyriserbars": "miniatyriserbar",
    "miniatyriserbart": "miniatyriserbar",
    "miniatyriserbarts": "miniatyriserbar",
    "miniatyriseringar": "miniatyrisering",
    "miniatyriseringarna": "miniatyrisering",
    "miniatyriseringarnas": "miniatyrisering",
    "miniatyriseringars": "miniatyrisering",
    "miniatyriseringen": "miniatyrisering",
    "miniatyriseringens": "miniatyrisering",
    "miniatyriserings": "miniatyrisering",
    "miniatyrmässiga": "miniatyrmässig",
    "miniatyrmässigare": "miniatyrmässig",
    "miniatyrmässigares": "miniatyrmässig",
    "miniatyrmässigas": "miniatyrmässig",
    "miniatyrmässigast": "miniatyrmässig",
    "miniatyrmässigaste": "miniatyrmässig",
    "miniatyrmässigastes": "miniatyrmässig",
    "miniatyrmässigasts": "miniatyrmässig",
    "miniatyrmässige": "miniatyrmässig",
    "miniatyrmässiges": "miniatyrmässig",
    "miniatyrmässigs": "miniatyrmässig",
    "miniatyrmässigt": "miniatyrmässig",
    "miniatyrmässigts": "miniatyrmässig",
    "miniatyrs": "miniatyr",
    "minibilar": "minibil",
    "minibilarna": "minibil",
    "minibilarnas": "minibil",
    "minibilars": "minibil",
    "minibilen": "minibil",
    "minibilens": "minibil",
    "minibils": "minibil",
    "minidatorer": "minidator",
    "minidatorerna": "minidator",
    "minidatorernas": "minidator",
    "minidatorers": "minidator",
    "minidatorn": "minidator",
    "minidatorns": "minidator",
    "minidators": "minidator",
    "miniersättningar": "miniersättning",
    "miniersättningarna": "miniersättning",
    "miniersättningarnas": "miniersättning",
    "miniersättningars": "miniersättning",
    "miniersättningen": "miniersättning",
    "miniersättningens": "miniersättning",
    "miniersättnings": "miniersättning",
    "miniflask": "miniflaska",
    "miniflaskan": "miniflaska",
    "miniflaskans": "miniflaska",
    "miniflaskas": "miniflaska",
    "miniflaske": "miniflaska",
    "miniflaskor": "miniflaska",
    "miniflaskorna": "miniflaska",
    "miniflaskornas": "miniflaska",
    "miniflaskors": "miniflaska",
    "minigolfen": "minigolf",
    "minigolfens": "minigolf",
    "minigolfs": "minigolf",
    "minigranar": "minigran",
    "minigranarna": "minigran",
    "minigranarnas": "minigran",
    "minigranars": "minigran",
    "minigranen": "minigran",
    "minigranens": "minigran",
    "minigrans": "minigran",
    "minikjolar": "minikjol",
    "minikjolarna": "minikjol",
    "minikjolarnas": "minikjol",
    "minikjolars": "minikjol",
    "minikjolen": "minikjol",
    "minikjolens": "minikjol",
    "minikjols": "minikjol",
    "minima": "minimum",
    "minimala": "minimal",
    "minimalare": "minimal",
    "minimalares": "minimal",
    "minimalas": "minimal",
    "minimalast": "minimal",
    "minimalaste": "minimal",
    "minimalastes": "minimal",
    "minimalasts": "minimal",
    "minimale": "minimal",
    "minimales": "minimal",
    "minimals": "minimal",
    "minimalt": "minimal",
    "minimalts": "minimal",
    "minimana": "minimum",
    "minimanas": "minimum",
    "minimas": "minimum",
    "minimerad": "minimera",
    "minimerade": "minimera",
    "minimerades": "minimera",
    "minimerads": "minimera",
    "minimerande": "minimera",
    "minimeranden": "minimerande",
    "minimerandena": "minimerande",
    "minimerandenas": "minimerande",
    "minimerandens": "minimerande",
    "minimerandes": "minimerande",
    "minimerandet": "minimerande",
    "minimerandets": "minimerande",
    "minimerar": "minimera",
    "minimeras": "minimera",
    "minimerat": "minimera",
    "minimerats": "minimera",
    "minimerbara": "minimerbar",
    "minimerbarare": "minimerbar",
    "minimerbarares": "minimerbar",
    "minimerbaras": "minimerbar",
    "minimerbarast": "minimerbar",
    "minimerbaraste": "minimerbar",
    "minimerbarastes": "minimerbar",
    "minimerbarasts": "minimerbar",
    "minimerbare": "minimerbar",
    "minimerbares": "minimerbar",
    "minimerbarheten": "minimerbarhet",
    "minimerbarhetens": "minimerbarhet",
    "minimerbarhets": "minimerbarhet",
    "minimerbars": "minimerbar",
    "minimerbart": "minimerbar",
    "minimerbarts": "minimerbar",
    "minimeringar": "minimering",
    "minimeringarna": "minimering",
    "minimeringarnas": "minimering",
    "minimeringars": "minimering",
    "minimeringen": "minimering",
    "minimeringens": "minimering",
    "minimerings": "minimering",
    "minimet": "minimum",
    "minimets": "minimum",
    "minimikapitalen": "minimikapital",
    "minimikapitalens": "minimikapital",
    "minimikapitalet": "minimikapital",
    "minimikapitalets": "minimikapital",
    "minimikapitals": "minimikapital",
    "minimilönen": "minimilön",
    "minimilönens": "minimilön",
    "minimilöner": "minimilön",
    "minimilönerna": "minimilön",
    "minimilönernas": "minimilön",
    "minimilöners": "minimilön",
    "minimilöns": "minimilön",
    "minimiprisen": "minimipris",
    "minimiprisens": "minimipris",
    "minimipriser": "minimipris",
    "minimipriserna": "minimipris",
    "minimiprisernas": "minimipris",
    "minimiprisers": "minimipris",
    "minimipriset": "minimipris",
    "minimiprisets": "minimipris",
    "minimipunkten": "minimipunkt",
    "minimipunktens": "minimipunkt",
    "minimipunkter": "minimipunkt",
    "minimipunkterna": "minimipunkt",
    "minimipunkternas": "minimipunkt",
    "minimipunkters": "minimipunkt",
    "minimipunkts": "minimipunkt",
    "minimisiffer": "minimisiffra",
    "minimisiffran": "minimisiffra",
    "minimisiffrans": "minimisiffra",
    "minimisiffras": "minimisiffra",
    "minimisiffre": "minimisiffra",
    "minimisiffror": "minimisiffra",
    "minimisiffrorna": "minimisiffra",
    "minimisiffrornas": "minimisiffra",
    "minimisiffrors": "minimisiffra",
    "minimitemperaturen": "minimitemperatur",
    "minimitemperaturens": "minimitemperatur",
    "minimitemperaturer": "minimitemperatur",
    "minimitemperaturerna": "minimitemperatur",
    "minimitemperaturernas": "minimitemperatur",
    "minimitemperaturers": "minimitemperatur",
    "minimitemperaturs": "minimitemperatur",
    "minimitermometern": "minimitermometer",
    "minimitermometerns": "minimitermometer",
    "minimitermometers": "minimitermometer",
    "minimitermometrar": "minimitermometer",
    "minimitermometrarna": "minimitermometer",
    "minimitermometrarnas": "minimitermometer",
    "minimitermometrars": "minimitermometer",
    "minimumen": "minimum",
    "minimumens": "minimum",
    "minimumet": "minimum",
    "minimumets": "minimum",
    "minimums": "minimum",
    "minioren": "minior",
    "miniorens": "minior",
    "miniorer": "minior",
    "miniorerna": "minior",
    "miniorernas": "minior",
    "miniorers": "minior",
    "miniors": "minior",
    "minirollern": "miniroller",
    "minirollerns": "miniroller",
    "minirollers": "miniroller",
    "minirollersarna": "miniroller",
    "minirollersarnas": "miniroller",
    "minirollersen": "miniroller",
    "minirollersens": "miniroller",
    "minirollrar": "miniroller",
    "minirollrarna": "miniroller",
    "minirollrarnas": "miniroller",
    "minirollrars": "miniroller",
    "miniräknar": "miniräknare",
    "miniräknaren": "miniräknare",
    "miniräknarens": "miniräknare",
    "miniräknares": "miniräknare",
    "miniräknarna": "miniräknare",
    "miniräknarnas": "miniräknare",
    "ministeransvarigheten": "ministeransvarighet",
    "ministeransvarighetens": "ministeransvarighet",
    "ministeransvarigheter": "ministeransvarighet",
    "ministeransvarigheterna": "ministeransvarighet",
    "ministeransvarigheternas": "ministeransvarighet",
    "ministeransvarigheters": "ministeransvarighet",
    "ministeransvarighets": "ministeransvarighet",
    "ministerbänkar": "ministerbänk",
    "ministerbänkarna": "ministerbänk",
    "ministerbänkarnas": "ministerbänk",
    "ministerbänkars": "ministerbänk",
    "ministerbänken": "ministerbänk",
    "ministerbänkens": "ministerbänk",
    "ministerbänks": "ministerbänk",
    "ministerialboken": "ministerialbok",
    "ministerialbokens": "ministerialbok",
    "ministerialboks": "ministerialbok",
    "ministerialböcker": "ministerialbok",
    "ministerialböckerna": "ministerialbok",
    "ministerialböckernas": "ministerialbok",
    "ministerialböckers": "ministerialbok",
    "ministerie": "ministerium",
    "ministeriella": "ministeriell",
    "ministeriellare": "ministeriell",
    "ministeriellares": "ministeriell",
    "ministeriellas": "ministeriell",
    "ministeriellast": "ministeriell",
    "ministeriellaste": "ministeriell",
    "ministeriellastes": "ministeriell",
    "ministeriellasts": "ministeriell",
    "ministerielle": "ministeriell",
    "ministerielles": "ministeriell",
    "ministeriells": "ministeriell",
    "ministeriellt": "ministeriell",
    "ministeriellts": "ministeriell",
    "ministerier": "ministerium",
    "ministerierna": "ministerium",
    "ministeriernas": "ministerium",
    "ministeriers": "ministerium",
    "ministeriet": "ministerium",
    "ministeriets": "ministerium",
    "ministeriums": "ministerium",
    "ministern": "minister",
    "ministerns": "minister",
    "ministerportföljen": "ministerportfölj",
    "ministerportföljens": "ministerportfölj",
    "ministerportföljer": "ministerportfölj",
    "ministerportföljerna": "ministerportfölj",
    "ministerportföljernas": "ministerportfölj",
    "ministerportföljers": "ministerportfölj",
    "ministerportföljs": "ministerportfölj",
    "ministerposten": "ministerpost",
    "ministerpostens": "ministerpost",
    "ministerposter": "ministerpost",
    "ministerposterna": "ministerpost",
    "ministerposternas": "ministerpost",
    "ministerposters": "ministerpost",
    "ministerposts": "ministerpost",
    "ministerpresidenten": "ministerpresident",
    "ministerpresidentens": "ministerpresident",
    "ministerpresidenter": "ministerpresident",
    "ministerpresidenterna": "ministerpresident",
    "ministerpresidenternas": "ministerpresident",
    "ministerpresidenters": "ministerpresident",
    "ministerpresidents": "ministerpresident",
    "ministerråden": "ministerråd",
    "ministerrådens": "ministerråd",
    "ministerrådet": "ministerråd",
    "ministerrådets": "ministerråd",
    "ministerråds": "ministerråd",
    "ministers": "minister",
    "ministerstyrelsen": "ministerstyrelse",
    "ministerstyrelsens": "ministerstyrelse",
    "ministerstyrelser": "ministerstyrelse",
    "ministerstyrelserna": "ministerstyrelse",
    "ministerstyrelsernas": "ministerstyrelse",
    "ministerstyrelsers": "ministerstyrelse",
    "ministerstyrelses": "ministerstyrelse",
    "ministerstyren": "ministerstyre",
    "ministerstyrena": "ministerstyre",
    "ministerstyrenas": "ministerstyre",
    "ministerstyrens": "ministerstyre",
    "ministerstyres": "ministerstyre",
    "ministerstyret": "ministerstyre",
    "ministerstyrets": "ministerstyre",
    "ministertaburetten": "ministertaburett",
    "ministertaburettens": "ministertaburett",
    "ministertaburetter": "ministertaburett",
    "ministertaburetterna": "ministertaburett",
    "ministertaburetternas": "ministertaburett",
    "ministertaburetters": "ministertaburett",
    "ministertaburetts": "ministertaburett",
    "ministerämbeten": "ministerämbete",
    "ministerämbetena": "ministerämbete",
    "ministerämbetenas": "ministerämbete",
    "ministerämbetens": "ministerämbete",
    "ministerämbetes": "ministerämbete",
    "ministerämbetet": "ministerämbete",
    "ministerämbetets": "ministerämbete",
    "ministrar": "minister",
    "ministrarna": "minister",
    "ministrarnas": "minister",
    "ministrars": "minister",
    "ministären": "ministär",
    "ministärens": "ministär",
    "ministärer": "ministär",
    "ministärerna": "ministär",
    "ministärernas": "ministär",
    "ministärers": "ministär",
    "ministärs": "ministär",
    "minkar": "mink",
    "minkarna": "mink",
    "minkarnas": "mink",
    "minkars": "mink",
    "minken": "mink",
    "minkens": "mink",
    "minks": "mink",
    "minn": "minna",
    "minnande": "minna",
    "minnanden": "minnande",
    "minnandena": "minnande",
    "minnandenas": "minnande",
    "minnandens": "minnande",
    "minnandes": "minnande",
    "minnandet": "minnande",
    "minnandets": "minnande",
    "minnas": "minna",
    "minnen": "minne",
    "minnena": "minne",
    "minnenas": "minne",
    "minnens": "minne",
    "minner": "minna",
    "minnes": "minne",
    "minnesanteckningar": "minnesanteckning",
    "minnesanteckningarna": "minnesanteckning",
    "minnesanteckningarnas": "minnesanteckning",
    "minnesanteckningars": "minnesanteckning",
    "minnesanteckningen": "minnesanteckning",
    "minnesanteckningens": "minnesanteckning",
    "minnesantecknings": "minnesanteckning",
    "minnesbet": "minnesbeta",
    "minnesbetan": "minnesbeta",
    "minnesbetans": "minnesbeta",
    "minnesbetas": "minnesbeta",
    "minnesbete": "minnesbeta",
    "minnesbetor": "minnesbeta",
    "minnesbetorna": "minnesbeta",
    "minnesbetornas": "minnesbeta",
    "minnesbetors": "minnesbeta",
    "minnesbets": "minnesbeta",
    "minnesbilden": "minnesbild",
    "minnesbildens": "minnesbild",
    "minnesbilder": "minnesbild",
    "minnesbilderna": "minnesbild",
    "minnesbildernas": "minnesbild",
    "minnesbilders": "minnesbild",
    "minnesbilds": "minnesbild",
    "minnesbussar": "minnesbuss",
    "minnesbussarna": "minnesbuss",
    "minnesbussarnas": "minnesbuss",
    "minnesbussars": "minnesbuss",
    "minnesbussen": "minnesbuss",
    "minnesbussens": "minnesbuss",
    "minnesenheten": "minnesenhet",
    "minnesenhetens": "minnesenhet",
    "minnesenheter": "minnesenhet",
    "minnesenheterna": "minnesenhet",
    "minnesenheternas": "minnesenhet",
    "minnesenheters": "minnesenhet",
    "minnesenhets": "minnesenhet",
    "minnesfonden": "minnesfond",
    "minnesfondens": "minnesfond",
    "minnesfonder": "minnesfond",
    "minnesfonderna": "minnesfond",
    "minnesfondernas": "minnesfond",
    "minnesfonders": "minnesfond",
    "minnesfonds": "minnesfond",
    "minnesfragmenten": "minnesfragment",
    "minnesfragmentens": "minnesfragment",
    "minnesfragmentet": "minnesfragment",
    "minnesfragmentets": "minnesfragment",
    "minnesfragments": "minnesfragment",
    "minnesfunktionen": "minnesfunktion",
    "minnesfunktionens": "minnesfunktion",
    "minnesfunktioner": "minnesfunktion",
    "minnesfunktionerna": "minnesfunktion",
    "minnesfunktionernas": "minnesfunktion",
    "minnesfunktioners": "minnesfunktion",
    "minnesfunktions": "minnesfunktion",
    "minnesförlusten": "minnesförlust",
    "minnesförlustens": "minnesförlust",
    "minnesförluster": "minnesförlust",
    "minnesförlusterna": "minnesförlust",
    "minnesförlusternas": "minnesförlust",
    "minnesförlusters": "minnesförlust",
    "minnesförlusts": "minnesförlust",
    "minnesgoda": "minnesgod",
    "minnesgodare": "minnesgod",
    "minnesgodares": "minnesgod",
    "minnesgodas": "minnesgod",
    "minnesgodast": "minnesgod",
    "minnesgodaste": "minnesgod",
    "minnesgodastes": "minnesgod",
    "minnesgodasts": "minnesgod",
    "minnesgode": "minnesgod",
    "minnesgodes": "minnesgod",
    "minnesgodheten": "minnesgodhet",
    "minnesgodhetens": "minnesgodhet",
    "minnesgodhets": "minnesgodhet",
    "minnesgods": "minnesgod",
    "minnesgott": "minnesgod",
    "minnesgotts": "minnesgod",
    "minnesgudstjänsten": "minnesgudstjänst",
    "minnesgudstjänstens": "minnesgudstjänst",
    "minnesgudstjänster": "minnesgudstjänst",
    "minnesgudstjänsterna": "minnesgudstjänst",
    "minnesgudstjänsternas": "minnesgudstjänst",
    "minnesgudstjänsters": "minnesgudstjänst",
    "minnesgudstjänsts": "minnesgudstjänst",
    "minnesgärden": "minnesgärd",
    "minnesgärdens": "minnesgärd",
    "minnesgärder": "minnesgärd",
    "minnesgärderna": "minnesgärd",
    "minnesgärdernas": "minnesgärd",
    "minnesgärders": "minnesgärd",
    "minnesgärds": "minnesgärd",
    "minneskonstnären": "minneskonstnär",
    "minneskonstnärens": "minneskonstnär",
    "minneskonstnärer": "minneskonstnär",
    "minneskonstnärerna": "minneskonstnär",
    "minneskonstnärernas": "minneskonstnär",
    "minneskonstnärers": "minneskonstnär",
    "minneskonstnärs": "minneskonstnär",
    "minneskunskapen": "minneskunskap",
    "minneskunskapens": "minneskunskap",
    "minneskunskaper": "minneskunskap",
    "minneskunskaperna": "minneskunskap",
    "minneskunskapernas": "minneskunskap",
    "minneskunskapers": "minneskunskap",
    "minneskunskaps": "minneskunskap",
    "minneslundar": "minneslund",
    "minneslundarna": "minneslund",
    "minneslundarnas": "minneslund",
    "minneslundars": "minneslund",
    "minneslunden": "minneslund",
    "minneslundens": "minneslund",
    "minneslunds": "minneslund",
    "minnesmärken": "minnesmärke",
    "minnesmärkena": "minnesmärke",
    "minnesmärkenas": "minnesmärke",
    "minnesmärkens": "minnesmärke",
    "minnesmärkes": "minnesmärke",
    "minnesmärket": "minnesmärke",
    "minnesmärkets": "minnesmärke",
    "minnesregeln": "minnesregel",
    "minnesregelns": "minnesregel",
    "minnesregels": "minnesregel",
    "minnesregler": "minnesregel",
    "minnesreglerna": "minnesregel",
    "minnesreglernas": "minnesregel",
    "minnesreglers": "minnesregel",
    "minnesrika": "minnesrik",
    "minnesrikare": "minnesrik",
    "minnesrikares": "minnesrik",
    "minnesrikas": "minnesrik",
    "minnesrikast": "minnesrik",
    "minnesrikaste": "minnesrik",
    "minnesrikastes": "minnesrik",
    "minnesrikasts": "minnesrik",
    "minnesrike": "minnesrik",
    "minnesrikes": "minnesrik",
    "minnesrikheten": "minnesrikhet",
    "minnesrikhetens": "minnesrikhet",
    "minnesrikhets": "minnesrikhet",
    "minnesriks": "minnesrik",
    "minnesrikt": "minnesrik",
    "minnesrikts": "minnesrik",
    "minnesrun": "minnesruna",
    "minnesrunan": "minnesruna",
    "minnesrunans": "minnesruna",
    "minnesrunas": "minnesruna",
    "minnesrune": "minnesruna",
    "minnesrunor": "minnesruna",
    "minnesrunorna": "minnesruna",
    "minnesrunornas": "minnesruna",
    "minnesrunors": "minnesruna",
    "minnesruns": "minnesruna",
    "minnesrymden": "minnesrymd",
    "minnesrymdens": "minnesrymd",
    "minnesrymder": "minnesrymd",
    "minnesrymderna": "minnesrymd",
    "minnesrymdernas": "minnesrymd",
    "minnesrymders": "minnesrymd",
    "minnesrymds": "minnesrymd",
    "minnessiffer": "minnessiffra",
    "minnessiffran": "minnessiffra",
    "minnessiffrans": "minnessiffra",
    "minnessiffras": "minnessiffra",
    "minnessiffre": "minnessiffra",
    "minnessiffror": "minnessiffra",
    "minnessiffrorna": "minnessiffra",
    "minnessiffrornas": "minnessiffra",
    "minnessiffrors": "minnessiffra",
    "minnesskriften": "minnesskrift",
    "minnesskriftens": "minnesskrift",
    "minnesskrifter": "minnesskrift",
    "minnesskrifterna": "minnesskrift",
    "minnesskrifternas": "minnesskrift",
    "minnesskrifters": "minnesskrift",
    "minnesskrifts": "minnesskrift",
    "minnesspåren": "minnesspår",
    "minnesspårens": "minnesspår",
    "minnesspåret": "minnesspår",
    "minnesspårets": "minnesspår",
    "minnesspårs": "minnesspår",
    "minnesstenar": "minnessten",
    "minnesstenarna": "minnessten",
    "minnesstenarnas": "minnessten",
    "minnesstenars": "minnessten",
    "minnesstenen": "minnessten",
    "minnesstenens": "minnessten",
    "minnesstens": "minnessten",
    "minnesstödet": "minnesstöd",
    "minnesstödets": "minnesstöd",
    "minnesstöds": "minnesstöd",
    "minnestalen": "minnestal",
    "minnestalens": "minnestal",
    "minnestalet": "minnestal",
    "minnestalets": "minnestal",
    "minnestals": "minnestal",
    "minnesteckningar": "minnesteckning",
    "minnesteckningarna": "minnesteckning",
    "minnesteckningarnas": "minnesteckning",
    "minnesteckningars": "minnesteckning",
    "minnesteckningen": "minnesteckning",
    "minnesteckningens": "minnesteckning",
    "minnestecknings": "minnesteckning",
    "minnesvill": "minnesvilla",
    "minnesvillan": "minnesvilla",
    "minnesvillans": "minnesvilla",
    "minnesvillas": "minnesvilla",
    "minnesville": "minnesvilla",
    "minnesvillor": "minnesvilla",
    "minnesvillorna": "minnesvilla",
    "minnesvillornas": "minnesvilla",
    "minnesvillors": "minnesvilla",
    "minnesvills": "minnesvilla",
    "minnesvärda": "minnesvärd",
    "minnesvärdare": "minnesvärd",
    "minnesvärdares": "minnesvärd",
    "minnesvärdas": "minnesvärd",
    "minnesvärdast": "minnesvärd",
    "minnesvärdaste": "minnesvärd",
    "minnesvärdastes": "minnesvärd",
    "minnesvärdasts": "minnesvärd",
    "minnesvärde": "minnesvärd",
    "minnesvärdes": "minnesvärd",
    "minnesvärdheten": "minnesvärdhet",
    "minnesvärdhetens": "minnesvärdhet",
    "minnesvärdhets": "minnesvärdhet",
    "minnesvärds": "minnesvärd",
    "minnesvärt": "minnesvärd",
    "minnesvärts": "minnesvärd",
    "minnesvårdar": "minnesvård",
    "minnesvårdarna": "minnesvård",
    "minnesvårdarnas": "minnesvård",
    "minnesvårdars": "minnesvård",
    "minnesvården": "minnesvård",
    "minnesvårdens": "minnesvård",
    "minnesvårds": "minnesvård",
    "minnesången": "minnesång",
    "minnesångens": "minnesång",
    "minnesånger": "minnesång",
    "minnesångerna": "minnesång",
    "minnesångernas": "minnesång",
    "minnesångers": "minnesång",
    "minnesångs": "minnesång",
    "minnet": "minne",
    "minnets": "minne",
    "minniga": "minnig",
    "minnigare": "minnig",
    "minnigares": "minnig",
    "minnigas": "minnig",
    "minnigast": "minnig",
    "minnigaste": "minnig",
    "minnigastes": "minnig",
    "minnigasts": "minnig",
    "minnige": "minnig",
    "minniges": "minnig",
    "minnigs": "minnig",
    "minnigt": "minnig",
    "minnigts": "minnig",
    "minns": "minnas",
    "minoiska": "minoisk",
    "minoiskare": "minoisk",
    "minoiskares": "minoisk",
    "minoiskas": "minoisk",
    "minoiskast": "minoisk",
    "minoiskaste": "minoisk",
    "minoiskastes": "minoisk",
    "minoiskasts": "minoisk",
    "minoiske": "minoisk",
    "minoiskes": "minoisk",
    "minoisks": "minoisk",
    "minoiskt": "minoisk",
    "minoiskts": "minoisk",
    "minor": "mina",
    "minoriteten": "minoritet",
    "minoritetens": "minoritet",
    "minoriteter": "minoritet",
    "minoriteterna": "minoritet",
    "minoriteternas": "minoritet",
    "minoriteters": "minoritet",
    "minoritets": "minoritet",
    "minoritetsfolken": "minoritetsfolk",
    "minoritetsfolkens": "minoritetsfolk",
    "minoritetsfolket": "minoritetsfolk",
    "minoritetsfolkets": "minoritetsfolk",
    "minoritetsfolks": "minoritetsfolk",
    "minoritetsförtrycket": "minoritetsförtryck",
    "minoritetsförtryckets": "minoritetsförtryck",
    "minoritetsförtrycks": "minoritetsförtryck",
    "minoritetsregeringar": "minoritetsregering",
    "minoritetsregeringarna": "minoritetsregering",
    "minoritetsregeringarnas": "minoritetsregering",
    "minoritetsregeringars": "minoritetsregering",
    "minoritetsregeringen": "minoritetsregering",
    "minoritetsregeringens": "minoritetsregering",
    "minoritetsregerings": "minoritetsregering",
    "minoritetsskydden": "minoritetsskydd",
    "minoritetsskyddens": "minoritetsskydd",
    "minoritetsskyddet": "minoritetsskydd",
    "minoritetsskyddets": "minoritetsskydd",
    "minoritetsskydds": "minoritetsskydd",
    "minoritetsställningar": "minoritetsställning",
    "minoritetsställningarna": "minoritetsställning",
    "minoritetsställningarnas": "minoritetsställning",
    "minoritetsställningars": "minoritetsställning",
    "minoritetsställningen": "minoritetsställning",
    "minoritetsställningens": "minoritetsställning",
    "minoritetsställnings": "minoritetsställning",
    "minoritetsvälden": "minoritetsvälde",
    "minoritetsväldena": "minoritetsvälde",
    "minoritetsväldenas": "minoritetsvälde",
    "minoritetsväldens": "minoritetsvälde",
    "minoritetsväldes": "minoritetsvälde",
    "minoritetsväldet": "minoritetsvälde",
    "minoritetsväldets": "minoritetsvälde",
    "minorna": "mina",
    "minornas": "mina",
    "minors": "mina",
    "minröjningar": "minröjning",
    "minröjningarna": "minröjning",
    "minröjningarnas": "minröjning",
    "minröjningars": "minröjning",
    "minröjningen": "minröjning",
    "minröjningens": "minröjning",
    "minröjnings": "minröjning",
    "mins": "mina",
    "minsk": "minska",
    "minska": "minsk",
    "minskad": "minska",
    "minskade": "minska",
    "minskades": "minska",
    "minskads": "minska",
    "minskande": "minska",
    "minskanden": "minskande",
    "minskandena": "minskande",
    "minskandenas": "minskande",
    "minskandens": "minskande",
    "minskandes": "minskande",
    "minskandet": "minskande",
    "minskandets": "minskande",
    "minskar": "minska",
    "minskare": "minsk",
    "minskares": "minsk",
    "minskas": "minska",
    "minskast": "minsk",
    "minskaste": "minsk",
    "minskastes": "minsk",
    "minskasts": "minsk",
    "minskat": "minska",
    "minskats": "minska",
    "minske": "minsk",
    "minskes": "minsk",
    "minskheten": "minskhet",
    "minskhetens": "minskhet",
    "minskhets": "minskhet",
    "minskningar": "minskning",
    "minskningarna": "minskning",
    "minskningarnas": "minskning",
    "minskningars": "minskning",
    "minskningen": "minskning",
    "minskningens": "minskning",
    "minsknings": "minskning",
    "minsks": "minsk",
    "minskt": "minsk",
    "minskts": "minsk",
    "minspelet": "minspel",
    "minspelets": "minspel",
    "minspels": "minspel",
    "minspärrar": "minspärr",
    "minspärrarna": "minspärr",
    "minspärrarnas": "minspärr",
    "minspärrars": "minspärr",
    "minspärren": "minspärr",
    "minspärrens": "minspärr",
    "minspärrs": "minspärr",
    "minst": "liten",
    "minsta": "liten",
    "minstas": "liten",
    "minste": "liten",
    "minstes": "liten",
    "minstingar": "minsting",
    "minstingarna": "minsting",
    "minstingarnas": "minsting",
    "minstingars": "minsting",
    "minstingen": "minsting",
    "minstingens": "minsting",
    "minstings": "minsting",
    "minsts": "liten",
    "minsvepar": "minsvepare",
    "minsveparen": "minsvepare",
    "minsveparens": "minsvepare",
    "minsvepares": "minsvepare",
    "minsveparna": "minsvepare",
    "minsveparnas": "minsvepare",
    "minsvepen": "minsvep",
    "minsvepens": "minsvep",
    "minsvepet": "minsvep",
    "minsvepets": "minsvep",
    "minsvepningar": "minsvepning",
    "minsvepningarna": "minsvepning",
    "minsvepningarnas": "minsvepning",
    "minsvepningars": "minsvepning",
    "minsvepningen": "minsvepning",
    "minsvepningens": "minsvepning",
    "minsvepnings": "minsvepning",
    "minsveps": "minsvep",
    "minsökar": "minsökare",
    "minsökaren": "minsökare",
    "minsökarens": "minsökare",
    "minsökares": "minsökare",
    "minsökarna": "minsökare",
    "minsökarnas": "minsökare",
    "mint": "minna",
    "mintblåa": "mintblå",
    "mintblåare": "mintblå",
    "mintblåares": "mintblå",
    "mintblåas": "mintblå",
    "mintblåast": "mintblå",
    "mintblåaste": "mintblå",
    "mintblåastes": "mintblå",
    "mintblåasts": "mintblå",
    "mintblåe": "mintblå",
    "mintblåes": "mintblå",
    "mintblås": "mintblå",
    "mintblått": "mintblå",
    "mintblåtts": "mintblå",
    "minten": "mint",
    "mintens": "mint",
    "mintlikören": "mintlikör",
    "mintlikörens": "mintlikör",
    "mintlikörer": "mintlikör",
    "mintlikörerna": "mintlikör",
    "mintlikörernas": "mintlikör",
    "mintlikörers": "mintlikör",
    "mintlikörs": "mintlikör",
    "mints": "mint",
    "minuenden": "minuend",
    "minuendens": "minuend",
    "minuender": "minuend",
    "minuenderna": "minuend",
    "minuendernas": "minuend",
    "minuenders": "minuend",
    "minuends": "minuend",
    "minusgraden": "minusgrad",
    "minusgradens": "minusgrad",
    "minusgrader": "minusgrad",
    "minusgraderna": "minusgrad",
    "minusgradernas": "minusgrad",
    "minusgraders": "minusgrad",
    "minusgrads": "minusgrad",
    "minuskeln": "minuskel",
    "minuskelns": "minuskel",
    "minuskels": "minuskel",
    "minuskler": "minuskel",
    "minusklerna": "minuskel",
    "minusklernas": "minuskel",
    "minusklers": "minuskel",
    "minuspolen": "minuspol",
    "minuspolens": "minuspol",
    "minuspoler": "minuspol",
    "minuspolerna": "minuspol",
    "minuspolernas": "minuspol",
    "minuspolers": "minuspol",
    "minuspols": "minuspol",
    "minussidan": "minussida",
    "minussidans": "minussida",
    "minussidas": "minussida",
    "minusside": "minussida",
    "minussides": "minussida",
    "minussidor": "minussida",
    "minussidorna": "minussida",
    "minussidornas": "minussida",
    "minussidors": "minussida",
    "minusteckens": "minustecken",
    "minustecknen": "minustecken",
    "minustecknens": "minustecken",
    "minustecknet": "minustecken",
    "minustecknets": "minustecken",
    "minuten": "minut",
    "minutens": "minut",
    "minuter": "minut",
    "minuterna": "minut",
    "minuternas": "minut",
    "minuters": "minut",
    "minutiösa": "minutiös",
    "minutiösare": "minutiös",
    "minutiösares": "minutiös",
    "minutiösas": "minutiös",
    "minutiösast": "minutiös",
    "minutiösaste": "minutiös",
    "minutiösastes": "minutiös",
    "minutiösasts": "minutiös",
    "minutiöse": "minutiös",
    "minutiöses": "minutiös",
    "minutiöst": "minutiös",
    "minutiösts": "minutiös",
    "minutrar": "minut",
    "minutrarna": "minut",
    "minutrarnas": "minut",
    "minutrars": "minut",
    "minuts": "minut",
    "minutvisar": "minutvisare",
    "minutvisaren": "minutvisare",
    "minutvisarens": "minutvisare",
    "minutvisares": "minutvisare",
    "minutvisarna": "minutvisare",
    "minutvisarnas": "minutvisare",
    "minören": "minör",
    "minörens": "minör",
    "minörer": "minör",
    "minörerna": "minör",
    "minörernas": "minör",
    "minörers": "minör",
    "minörs": "minör",
    "mirabellen": "mirabell",
    "mirabellens": "mirabell",
    "mirabeller": "mirabell",
    "mirabellerna": "mirabell",
    "mirabellernas": "mirabell",
    "mirabellers": "mirabell",
    "mirabells": "mirabell",
    "mirakelflick": "mirakelflicka",
    "mirakelflickan": "mirakelflicka",
    "mirakelflickans": "mirakelflicka",
    "mirakelflickas": "mirakelflicka",
    "mirakelflicke": "mirakelflicka",
    "mirakelflickor": "mirakelflicka",
    "mirakelflickorna": "mirakelflicka",
    "mirakelflickornas": "mirakelflicka",
    "mirakelflickors": "mirakelflicka",
    "mirakelflicks": "mirakelflicka",
    "mirakelmedicinen": "mirakelmedicin",
    "mirakelmedicinens": "mirakelmedicin",
    "mirakelmediciner": "mirakelmedicin",
    "mirakelmedicinerna": "mirakelmedicin",
    "mirakelmedicinernas": "mirakelmedicin",
    "mirakelmediciners": "mirakelmedicin",
    "mirakelmedicins": "mirakelmedicin",
    "mirakelräddade": "mirakelräddad",
    "mirakelräddades": "mirakelräddad",
    "mirakelräddads": "mirakelräddad",
    "mirakelräddat": "mirakelräddad",
    "mirakelräddats": "mirakelräddad",
    "mirakels": "mirakel",
    "mirakelspelen": "mirakelspel",
    "mirakelspelens": "mirakelspel",
    "mirakelspelet": "mirakelspel",
    "mirakelspelets": "mirakelspel",
    "mirakelspels": "mirakelspel",
    "miraklen": "mirakel",
    "miraklens": "mirakel",
    "mirakler": "mirakel",
    "miraklerna": "mirakel",
    "miraklernas": "mirakel",
    "miraklers": "mirakel",
    "miraklet": "mirakel",
    "miraklets": "mirakel",
    "mirakulösa": "mirakulös",
    "mirakulösare": "mirakulös",
    "mirakulösares": "mirakulös",
    "mirakulösas": "mirakulös",
    "mirakulösast": "mirakulös",
    "mirakulösaste": "mirakulös",
    "mirakulösastes": "mirakulös",
    "mirakulösasts": "mirakulös",
    "mirakulöse": "mirakulös",
    "mirakulöses": "mirakulös",
    "mirakulöst": "mirakulös",
    "mirakulösts": "mirakulös",
    "misantropen": "misantrop",
    "misantropens": "misantrop",
    "misantroper": "misantrop",
    "misantroperna": "misantrop",
    "misantropernas": "misantrop",
    "misantropers": "misantrop",
    "misantropien": "misantropi",
    "misantropiens": "misantropi",
    "misantropin": "misantropi",
    "misantropins": "misantropi",
    "misantropis": "misantropi",
    "misantropiska": "misantropisk",
    "misantropiskare": "misantropisk",
    "misantropiskares": "misantropisk",
    "misantropiskas": "misantropisk",
    "misantropiskast": "misantropisk",
    "misantropiskaste": "misantropisk",
    "misantropiskastes": "misantropisk",
    "misantropiskasts": "misantropisk",
    "misantropiske": "misantropisk",
    "misantropiskes": "misantropisk",
    "misantropisks": "misantropisk",
    "misantropiskt": "misantropisk",
    "misantropiskts": "misantropisk",
    "misantrops": "misantrop",
    "mischmaschet": "mischmasch",
    "mischmaschets": "mischmasch",
    "mischmaschs": "mischmasch",
    "miserabels": "miserabel",
    "miserabelt": "miserabel",
    "miserabelts": "miserabel",
    "miserabla": "miserabel",
    "miserablare": "miserabel",
    "miserablares": "miserabel",
    "miserablas": "miserabel",
    "miserablast": "miserabel",
    "miserablaste": "miserabel",
    "miserablastes": "miserabel",
    "miserablasts": "miserabel",
    "miserable": "miserabel",
    "miserables": "miserabel",
    "mispeln": "mispel",
    "mispelns": "mispel",
    "mispels": "mispel",
    "misplar": "mispel",
    "misplarna": "mispel",
    "misplarnas": "mispel",
    "misplars": "mispel",
    "miss": "misse",
    "missad": "missa",
    "missade": "missa",
    "missades": "missa",
    "missads": "missa",
    "missakt": "missakta",
    "missaktad": "missakta",
    "missaktade": "missakta",
    "missaktades": "missakta",
    "missaktads": "missakta",
    "missaktande": "missakta",
    "missaktanden": "missaktande",
    "missaktandena": "missaktande",
    "missaktandenas": "missaktande",
    "missaktandens": "missaktande",
    "missaktandes": "missaktande",
    "missaktandet": "missaktande",
    "missaktandets": "missaktande",
    "missaktar": "missakta",
    "missaktas": "missakta",
    "missaktat": "missakta",
    "missaktats": "missakta",
    "missalen": "missale",
    "missalena": "missale",
    "missalenas": "missale",
    "missalens": "missale",
    "missales": "missale",
    "missalet": "missale",
    "missalets": "missale",
    "missals": "missale",
    "missande": "missa",
    "missanden": "missande",
    "missandena": "missande",
    "missandenas": "missande",
    "missandens": "missande",
    "missandes": "missande",
    "missandet": "missande",
    "missandets": "missande",
    "missanpassade": "missanpassad",
    "missanpassades": "missanpassad",
    "missanpassads": "missanpassad",
    "missanpassat": "missanpassad",
    "missanpassats": "missanpassad",
    "missanpassningar": "missanpassning",
    "missanpassningarna": "missanpassning",
    "missanpassningarnas": "missanpassning",
    "missanpassningars": "missanpassning",
    "missanpassningen": "missanpassning",
    "missanpassningens": "missanpassning",
    "missanpassnings": "missanpassning",
    "missar": "misse",
    "missarna": "misse",
    "missarnas": "misse",
    "missars": "misse",
    "missas": "missa",
    "missat": "missa",
    "missats": "missa",
    "missbedöm": "missbedöma",
    "missbedömande": "missbedöma",
    "missbedömanden": "missbedömande",
    "missbedömandena": "missbedömande",
    "missbedömandenas": "missbedömande",
    "missbedömandens": "missbedömande",
    "missbedömandes": "missbedömande",
    "missbedömandet": "missbedömande",
    "missbedömandets": "missbedömande",
    "missbedömas": "missbedöma",
    "missbedömd": "missbedöma",
    "missbedömda": "missbedöma",
    "missbedömdas": "missbedöma",
    "missbedömde": "missbedöma",
    "missbedömdes": "missbedöma",
    "missbedömds": "missbedöma",
    "missbedömer": "missbedöma",
    "missbedöms": "missbedöma",
    "missbedömt": "missbedöma",
    "missbedömts": "missbedöma",
    "missbelåtenheten": "missbelåtenhet",
    "missbelåtenhetens": "missbelåtenhet",
    "missbelåtenhets": "missbelåtenhet",
    "missbelåtens": "missbelåten",
    "missbelåtet": "missbelåten",
    "missbelåtets": "missbelåten",
    "missbelåtna": "missbelåten",
    "missbelåtnare": "missbelåten",
    "missbelåtnares": "missbelåten",
    "missbelåtnas": "missbelåten",
    "missbelåtnast": "missbelåten",
    "missbelåtnaste": "missbelåten",
    "missbelåtnastes": "missbelåten",
    "missbelåtnasts": "missbelåten",
    "missbelåtne": "missbelåten",
    "missbelåtnes": "missbelåten",
    "missbildade": "missbildad",
    "missbildades": "missbildad",
    "missbildads": "missbildad",
    "missbildat": "missbildad",
    "missbildats": "missbildad",
    "missbildningar": "missbildning",
    "missbildningarna": "missbildning",
    "missbildningarnas": "missbildning",
    "missbildningars": "missbildning",
    "missbildningen": "missbildning",
    "missbildningens": "missbildning",
    "missbildnings": "missbildning",
    "missbruk": "missbruka",
    "missbrukad": "missbruka",
    "missbrukade": "missbruka",
    "missbrukades": "missbruka",
    "missbrukads": "missbruka",
    "missbrukande": "missbruka",
    "missbrukanden": "missbrukande",
    "missbrukandena": "missbrukande",
    "missbrukandenas": "missbrukande",
    "missbrukandens": "missbrukande",
    "missbrukandes": "missbrukande",
    "missbrukandet": "missbrukande",
    "missbrukandets": "missbrukande",
    "missbrukar": "missbrukare",
    "missbrukaren": "missbrukare",
    "missbrukarens": "missbrukare",
    "missbrukares": "missbrukare",
    "missbrukarhyn": "missbrukarhy",
    "missbrukarhyns": "missbrukarhy",
    "missbrukarhys": "missbrukarhy",
    "missbrukarna": "missbrukare",
    "missbrukarnas": "missbrukare",
    "missbrukas": "missbruka",
    "missbrukat": "missbruka",
    "missbrukats": "missbruka",
    "missbruken": "missbruk",
    "missbrukens": "missbruk",
    "missbruket": "missbruk",
    "missbrukets": "missbruk",
    "missbruks": "missbruk",
    "missbruksfrågan": "missbruksfråga",
    "missbruksfrågans": "missbruksfråga",
    "missbruksfrågas": "missbruksfråga",
    "missbruksfråge": "missbruksfråga",
    "missbruksfrågor": "missbruksfråga",
    "missbruksfrågorna": "missbruksfråga",
    "missbruksfrågornas": "missbruksfråga",
    "missbruksfrågors": "missbruksfråga",
    "missbruksproblematiken": "missbruksproblematik",
    "missbruksproblematikens": "missbruksproblematik",
    "missbruksproblematiker": "missbruksproblematik",
    "missbruksproblematikerna": "missbruksproblematik",
    "missbruksproblematikernas": "missbruksproblematik",
    "missbruksproblematikers": "missbruksproblematik",
    "missbruksproblematiks": "missbruksproblematik",
    "missdådar": "missdådare",
    "missdådaren": "missdådare",
    "missdådarens": "missdådare",
    "missdådares": "missdådare",
    "missdådarna": "missdådare",
    "missdådarnas": "missdådare",
    "missdåden": "missdåd",
    "missdådens": "missdåd",
    "missdådet": "missdåd",
    "missdådets": "missdåd",
    "missdåds": "missdåd",
    "missen": "misse",
    "missens": "misse",
    "misser": "miss",
    "misserna": "miss",
    "missernas": "miss",
    "missers": "miss",
    "misses": "misse",
    "missfallen": "missfall",
    "missfallens": "missfall",
    "missfallet": "missfall",
    "missfallets": "missfall",
    "missfalls": "missfall",
    "missfirm": "missfirma",
    "missfirmad": "missfirma",
    "missfirmade": "missfirma",
    "missfirmades": "missfirma",
    "missfirmads": "missfirma",
    "missfirmande": "missfirma",
    "missfirmanden": "missfirmande",
    "missfirmandena": "missfirmande",
    "missfirmandenas": "missfirmande",
    "missfirmandens": "missfirmande",
    "missfirmandes": "missfirmande",
    "missfirmandet": "missfirmande",
    "missfirmandets": "missfirmande",
    "missfirmar": "missfirma",
    "missfirmas": "missfirma",
    "missfirmat": "missfirma",
    "missfirmats": "missfirma",
    "missfirmelsen": "missfirmelse",
    "missfirmelsens": "missfirmelse",
    "missfirmelser": "missfirmelse",
    "missfirmelserna": "missfirmelse",
    "missfirmelsernas": "missfirmelse",
    "missfirmelsers": "missfirmelse",
    "missfirmelses": "missfirmelse",
    "missfosterna": "missfoster",
    "missfosternas": "missfoster",
    "missfosters": "missfoster",
    "missfostren": "missfoster",
    "missfostrens": "missfoster",
    "missfostret": "missfoster",
    "missfostrets": "missfoster",
    "missfärg": "missfärga",
    "missfärgad": "missfärga",
    "missfärgade": "missfärga",
    "missfärgades": "missfärga",
    "missfärgads": "missfärga",
    "missfärgande": "missfärga",
    "missfärganden": "missfärgande",
    "missfärgandena": "missfärgande",
    "missfärgandenas": "missfärgande",
    "missfärgandens": "missfärgande",
    "missfärgandes": "missfärgande",
    "missfärgandet": "missfärgande",
    "missfärgandets": "missfärgande",
    "missfärgar": "missfärga",
    "missfärgas": "missfärga",
    "missfärgat": "missfärga",
    "missfärgats": "missfärga",
    "missfärgningar": "missfärgning",
    "missfärgningarna": "missfärgning",
    "missfärgningarnas": "missfärgning",
    "missfärgningars": "missfärgning",
    "missfärgningen": "missfärgning",
    "missfärgningens": "missfärgning",
    "missfärgnings": "missfärgning",
    "missförhållanden": "missförhållande",
    "missförhållandena": "missförhållande",
    "missförhållandenas": "missförhållande",
    "missförhållandens": "missförhållande",
    "missförhållandes": "missförhållande",
    "missförhållandet": "missförhållande",
    "missförhållandets": "missförhållande",
    "missförstod": "missförstå",
    "missförstode": "missförstå",
    "missförstodes": "missförstå",
    "missförstods": "missförstå",
    "missförstådd": "missförstå",
    "missförstådda": "missförstå",
    "missförståddas": "missförstå",
    "missförstådde": "missförstå",
    "missförståddes": "missförstå",
    "missförstådds": "missförstå",
    "missförstående": "missförstå",
    "missförståenden": "missförstående",
    "missförståendena": "missförstående",
    "missförståendenas": "missförstående",
    "missförståendens": "missförstående",
    "missförståendes": "missförstående",
    "missförståendet": "missförstående",
    "missförståendets": "missförstående",
    "missförstånden": "missförstånd",
    "missförståndens": "missförstånd",
    "missförståndet": "missförstånd",
    "missförståndets": "missförstånd",
    "missförstånds": "missförstånd",
    "missförstår": "missförstå",
    "missförstås": "missförstå",
    "missförstått": "missförstå",
    "missförståtts": "missförstå",
    "missgreppen": "missgrepp",
    "missgreppens": "missgrepp",
    "missgreppet": "missgrepp",
    "missgreppets": "missgrepp",
    "missgrepps": "missgrepp",
    "missgynn": "missgynna",
    "missgynnad": "missgynna",
    "missgynnade": "missgynna",
    "missgynnades": "missgynna",
    "missgynnads": "missgynna",
    "missgynnande": "missgynna",
    "missgynnanden": "missgynnande",
    "missgynnandena": "missgynnande",
    "missgynnandenas": "missgynnande",
    "missgynnandens": "missgynnande",
    "missgynnandes": "missgynnande",
    "missgynnandet": "missgynnande",
    "missgynnandets": "missgynnande",
    "missgynnar": "missgynna",
    "missgynnas": "missgynna",
    "missgynnat": "missgynna",
    "missgynnats": "missgynna",
    "missgärningar": "missgärning",
    "missgärningarna": "missgärning",
    "missgärningarnas": "missgärning",
    "missgärningars": "missgärning",
    "missgärningen": "missgärning",
    "missgärningens": "missgärning",
    "missgärnings": "missgärning",
    "missgärningsbalkar": "missgärningsbalk",
    "missgärningsbalkarna": "missgärningsbalk",
    "missgärningsbalkarnas": "missgärningsbalk",
    "missgärningsbalkars": "missgärningsbalk",
    "missgärningsbalken": "missgärningsbalk",
    "missgärningsbalkens": "missgärningsbalk",
    "missgärningsbalks": "missgärningsbalk",
    "missgärningsmannen": "missgärningsman",
    "missgärningsmannens": "missgärningsman",
    "missgärningsmans": "missgärningsman",
    "missgärningsmän": "missgärningsman",
    "missgärningsmännen": "missgärningsman",
    "missgärningsmännens": "missgärningsman",
    "missgärningsmäns": "missgärningsman",
    "misshagade": "misshaga",
    "misshagades": "misshaga",
    "misshagande": "misshaga",
    "misshaganden": "misshagande",
    "misshagandena": "misshagande",
    "misshagandenas": "misshagande",
    "misshagandens": "misshagande",
    "misshagandes": "misshagande",
    "misshagandet": "misshagande",
    "misshagandets": "misshagande",
    "misshagar": "misshaga",
    "misshagas": "misshaga",
    "misshagat": "misshaga",
    "misshagats": "misshaga",
    "misshaget": "misshag",
    "misshagets": "misshag",
    "misshagliga": "misshaglig",
    "misshagligare": "misshaglig",
    "misshagligares": "misshaglig",
    "misshagligas": "misshaglig",
    "misshagligast": "misshaglig",
    "misshagligaste": "misshaglig",
    "misshagligastes": "misshaglig",
    "misshagligasts": "misshaglig",
    "misshaglige": "misshaglig",
    "misshagliges": "misshaglig",
    "misshagligheten": "misshaglighet",
    "misshaglighetens": "misshaglighet",
    "misshaglighets": "misshaglighet",
    "misshagligs": "misshaglig",
    "misshagligt": "misshaglig",
    "misshagligts": "misshaglig",
    "misshags": "misshag",
    "misshandeln": "misshandel",
    "misshandelns": "misshandel",
    "misshandels": "misshandel",
    "misshandelsfallen": "misshandelsfall",
    "misshandelsfallens": "misshandelsfall",
    "misshandelsfallet": "misshandelsfall",
    "misshandelsfallets": "misshandelsfall",
    "misshandelsfalls": "misshandelsfall",
    "misshandelsscenen": "misshandelsscen",
    "misshandelsscenens": "misshandelsscen",
    "misshandelsscener": "misshandelsscen",
    "misshandelsscenerna": "misshandelsscen",
    "misshandelsscenernas": "misshandelsscen",
    "misshandelssceners": "misshandelsscen",
    "misshandelsscens": "misshandelsscen",
    "misshandlad": "misshandla",
    "misshandlade": "misshandla",
    "misshandlades": "misshandla",
    "misshandlads": "misshandla",
    "misshandlande": "misshandla",
    "misshandlanden": "misshandlande",
    "misshandlandena": "misshandlande",
    "misshandlandenas": "misshandlande",
    "misshandlandens": "misshandlande",
    "misshandlandes": "misshandlande",
    "misshandlandet": "misshandlande",
    "misshandlandets": "misshandlande",
    "misshandlar": "misshandla",
    "misshandlas": "misshandla",
    "misshandlat": "misshandla",
    "misshandlats": "misshandla",
    "misshumöret": "misshumör",
    "misshumörets": "misshumör",
    "misshumörs": "misshumör",
    "misshushållade": "misshushålla",
    "misshushållades": "misshushålla",
    "misshushållande": "misshushålla",
    "misshushållanden": "misshushållande",
    "misshushållandena": "misshushållande",
    "misshushållandenas": "misshushållande",
    "misshushållandens": "misshushållande",
    "misshushållandes": "misshushållande",
    "misshushållandet": "misshushållande",
    "misshushållandets": "misshushållande",
    "misshushållar": "misshushålla",
    "misshushållas": "misshushålla",
    "misshushållat": "misshushålla",
    "misshushållats": "misshushålla",
    "misshälligheten": "misshällighet",
    "misshällighetens": "misshällighet",
    "misshälligheter": "misshällighet",
    "misshälligheterna": "misshällighet",
    "misshälligheternas": "misshällighet",
    "misshälligheters": "misshällighet",
    "misshällighets": "misshällighet",
    "missilen": "missil",
    "missilens": "missil",
    "missiler": "missil",
    "missilerna": "missil",
    "missilernas": "missil",
    "missilers": "missil",
    "missils": "missil",
    "missionen": "mission",
    "missionens": "mission",
    "missioner": "mission",
    "missionerade": "missionera",
    "missionerades": "missionera",
    "missionerande": "missionera",
    "missioneranden": "missionerande",
    "missionerandena": "missionerande",
    "missionerandenas": "missionerande",
    "missionerandens": "missionerande",
    "missionerandes": "missionerande",
    "missionerandet": "missionerande",
    "missionerandets": "missionerande",
    "missionerar": "missionera",
    "missioneras": "missionera",
    "missionerat": "missionera",
    "missionerats": "missionera",
    "missioneringar": "missionering",
    "missioneringarna": "missionering",
    "missioneringarnas": "missionering",
    "missioneringars": "missionering",
    "missioneringen": "missionering",
    "missioneringens": "missionering",
    "missionerings": "missionering",
    "missionerna": "mission",
    "missionernas": "mission",
    "missioners": "mission",
    "missions": "mission",
    "missionsbokhandeln": "missionsbokhandel",
    "missionsbokhandelns": "missionsbokhandel",
    "missionsbokhandels": "missionsbokhandel",
    "missionsbokhandlar": "missionsbokhandel",
    "missionsbokhandlarna": "missionsbokhandel",
    "missionsbokhandlarnas": "missionsbokhandel",
    "missionsbokhandlars": "missionsbokhandel",
    "missionsdagen": "missionsdag",
    "missionsdagens": "missionsdag",
    "missionsdags": "missionsdag",
    "missionsfälten": "missionsfält",
    "missionsfältens": "missionsfält",
    "missionsfältet": "missionsfält",
    "missionsfältets": "missionsfält",
    "missionsfälts": "missionsfält",
    "missionsförbunden": "missionsförbund",
    "missionsförbundens": "missionsförbund",
    "missionsförbundet": "missionsförbund",
    "missionsförbundets": "missionsförbund",
    "missionsförbunds": "missionsförbund",
    "missionshotellen": "missionshotell",
    "missionshotellens": "missionshotell",
    "missionshotellet": "missionshotell",
    "missionshotellets": "missionshotell",
    "missionshotells": "missionshotell",
    "missionshusen": "missionshus",
    "missionshusens": "missionshus",
    "missionshuset": "missionshus",
    "missionshusets": "missionshus",
    "missionskyrk": "missionskyrka",
    "missionskyrkan": "missionskyrka",
    "missionskyrkans": "missionskyrka",
    "missionskyrkas": "missionskyrka",
    "missionskyrke": "missionskyrka",
    "missionskyrko": "missionskyrka",
    "missionskyrkor": "missionskyrka",
    "missionskyrkorna": "missionskyrka",
    "missionskyrkornas": "missionskyrka",
    "missionskyrkors": "missionskyrka",
    "missionskyrks": "missionskyrka",
    "missionsstationen": "missionsstation",
    "missionsstationens": "missionsstation",
    "missionsstationer": "missionsstation",
    "missionsstationerna": "missionsstation",
    "missionsstationernas": "missionsstation",
    "missionsstationers": "missionsstation",
    "missionsstations": "missionsstation",
    "missionären": "missionär",
    "missionärens": "missionär",
    "missionärer": "missionär",
    "missionärerna": "missionär",
    "missionärernas": "missionär",
    "missionärers": "missionär",
    "missionärs": "missionär",
    "missiven": "missiv",
    "missivens": "missiv",
    "missiverad": "missivera",
    "missiverade": "missivera",
    "missiverades": "missivera",
    "missiverads": "missivera",
    "missiverande": "missivera",
    "missiveranden": "missiverande",
    "missiverandena": "missiverande",
    "missiverandenas": "missiverande",
    "missiverandens": "missiverande",
    "missiverandes": "missiverande",
    "missiverandet": "missiverande",
    "missiverandets": "missiverande",
    "missiverar": "missivera",
    "missiveras": "missivera",
    "missiverat": "missivera",
    "missiverats": "missivera",
    "missiverbara": "missiverbar",
    "missiverbarare": "missiverbar",
    "missiverbarares": "missiverbar",
    "missiverbaras": "missiverbar",
    "missiverbarast": "missiverbar",
    "missiverbaraste": "missiverbar",
    "missiverbarastes": "missiverbar",
    "missiverbarasts": "missiverbar",
    "missiverbare": "missiverbar",
    "missiverbares": "missiverbar",
    "missiverbarheten": "missiverbarhet",
    "missiverbarhetens": "missiverbarhet",
    "missiverbarhets": "missiverbarhet",
    "missiverbars": "missiverbar",
    "missiverbart": "missiverbar",
    "missiverbarts": "missiverbar",
    "missiveringar": "missivering",
    "missiveringarna": "missivering",
    "missiveringarnas": "missivering",
    "missiveringars": "missivering",
    "missiveringen": "missivering",
    "missiveringens": "missivering",
    "missiverings": "missivering",
    "missivet": "missiv",
    "missivets": "missiv",
    "missivs": "missiv",
    "misskläd": "missklä",
    "misskläda": "missklä",
    "missklädande": "missklä",
    "missklädanden": "missklädande",
    "missklädandena": "missklädande",
    "missklädandenas": "missklädande",
    "missklädandens": "missklädande",
    "missklädandes": "missklädande",
    "missklädandet": "missklädande",
    "missklädandets": "missklädande",
    "missklädas": "missklä",
    "missklädd": "missklä",
    "missklädda": "missklä",
    "misskläddas": "missklä",
    "missklädde": "missklä",
    "misskläddes": "missklä",
    "missklädds": "missklä",
    "misskläder": "missklä",
    "misskläds": "missklä",
    "missklädsamheten": "missklädsamhet",
    "missklädsamhetens": "missklädsamhet",
    "missklädsamhets": "missklädsamhet",
    "missklädsamma": "missklädsam",
    "missklädsammare": "missklädsam",
    "missklädsammares": "missklädsam",
    "missklädsammas": "missklädsam",
    "missklädsammast": "missklädsam",
    "missklädsammaste": "missklädsam",
    "missklädsammastes": "missklädsam",
    "missklädsammasts": "missklädsam",
    "missklädsamme": "missklädsam",
    "missklädsammes": "missklädsam",
    "missklädsams": "missklädsam",
    "missklädsamt": "missklädsam",
    "missklädsamts": "missklädsam",
    "misskläende": "missklä",
    "misskläendes": "missklä",
    "missklär": "missklä",
    "misskläs": "missklä",
    "missklätt": "missklä",
    "missklätts": "missklä",
    "misskrediterad": "misskreditera",
    "misskrediterade": "misskreditera",
    "misskrediterades": "misskreditera",
    "misskrediterads": "misskreditera",
    "misskrediterande": "misskreditera",
    "misskrediteranden": "misskrediterande",
    "misskrediterandena": "misskrediterande",
    "misskrediterandenas": "misskrediterande",
    "misskrediterandens": "misskrediterande",
    "misskrediterandes": "misskrediterande",
    "misskrediterandet": "misskrediterande",
    "misskrediterandets": "misskrediterande",
    "misskrediterar": "misskreditera",
    "misskrediteras": "misskreditera",
    "misskrediterat": "misskreditera",
    "misskrediterats": "misskreditera",
    "misskrediterbara": "misskrediterbar",
    "misskrediterbarare": "misskrediterbar",
    "misskrediterbarares": "misskrediterbar",
    "misskrediterbaras": "misskrediterbar",
    "misskrediterbarast": "misskrediterbar",
    "misskrediterbaraste": "misskrediterbar",
    "misskrediterbarastes": "misskrediterbar",
    "misskrediterbarasts": "misskrediterbar",
    "misskrediterbare": "misskrediterbar",
    "misskrediterbares": "misskrediterbar",
    "misskrediterbarheten": "misskrediterbarhet",
    "misskrediterbarhetens": "misskrediterbarhet",
    "misskrediterbarhets": "misskrediterbarhet",
    "misskrediterbars": "misskrediterbar",
    "misskrediterbart": "misskrediterbar",
    "misskrediterbarts": "misskrediterbar",
    "misskrediteringar": "misskreditering",
    "misskrediteringarna": "misskreditering",
    "misskrediteringarnas": "misskreditering",
    "misskrediteringars": "misskreditering",
    "misskrediteringen": "misskreditering",
    "misskrediteringens": "misskreditering",
    "misskrediterings": "misskreditering",
    "misskredits": "misskredit",
    "misskunden": "misskund",
    "misskundens": "misskund",
    "misskunds": "misskund",
    "misskundsamheten": "misskundsamhet",
    "misskundsamhetens": "misskundsamhet",
    "misskundsamhets": "misskundsamhet",
    "misskundsamma": "misskundsam",
    "misskundsammare": "misskundsam",
    "misskundsammares": "misskundsam",
    "misskundsammas": "misskundsam",
    "misskundsammast": "misskundsam",
    "misskundsammaste": "misskundsam",
    "misskundsammastes": "misskundsam",
    "misskundsammasts": "misskundsam",
    "misskundsamme": "misskundsam",
    "misskundsammes": "misskundsam",
    "misskundsams": "misskundsam",
    "misskundsamt": "misskundsam",
    "misskundsamts": "misskundsam",
    "misskänd": "misskänna",
    "misskända": "misskänna",
    "misskändare": "misskänd",
    "misskändares": "misskänd",
    "misskändas": "misskänna",
    "misskändast": "misskänd",
    "misskändaste": "misskänd",
    "misskändastes": "misskänd",
    "misskändasts": "misskänd",
    "misskände": "misskänna",
    "misskändes": "misskänna",
    "misskänds": "misskänna",
    "misskänn": "misskänna",
    "misskännande": "misskänna",
    "misskännanden": "misskännande",
    "misskännandena": "misskännande",
    "misskännandenas": "misskännande",
    "misskännandens": "misskännande",
    "misskännandes": "misskännande",
    "misskännandet": "misskännande",
    "misskännandets": "misskännande",
    "misskännas": "misskänna",
    "misskänner": "misskänna",
    "misskännes": "misskänna",
    "misskänns": "misskänna",
    "misskänt": "misskänna",
    "misskänts": "misskänna",
    "missköt": "missköta",
    "misskötande": "missköta",
    "misskötanden": "misskötande",
    "misskötandena": "misskötande",
    "misskötandenas": "misskötande",
    "misskötandens": "misskötande",
    "misskötandes": "misskötande",
    "misskötandet": "misskötande",
    "misskötandets": "misskötande",
    "misskötas": "missköta",
    "missköter": "missköta",
    "misskötes": "missköta",
    "missköts": "missköta",
    "misskötsamheten": "misskötsamhet",
    "misskötsamhetens": "misskötsamhet",
    "misskötsamhets": "misskötsamhet",
    "misskötsamma": "misskötsam",
    "misskötsammare": "misskötsam",
    "misskötsammares": "misskötsam",
    "misskötsammas": "misskötsam",
    "misskötsammast": "misskötsam",
    "misskötsammaste": "misskötsam",
    "misskötsammastes": "misskötsam",
    "misskötsammasts": "misskötsam",
    "misskötsamme": "misskötsam",
    "misskötsammes": "misskötsam",
    "misskötsams": "misskötsam",
    "misskötsamt": "misskötsam",
    "misskötsamts": "misskötsam",
    "misskötseln": "misskötsel",
    "misskötselns": "misskötsel",
    "misskötsels": "misskötsel",
    "misskött": "missköta",
    "misskötta": "missköta",
    "missköttas": "missköta",
    "misskötte": "missköta",
    "missköttes": "missköta",
    "misskötts": "missköta",
    "missled": "missleda",
    "missledande": "missleda",
    "missledanden": "missledande",
    "missledandena": "missledande",
    "missledandenas": "missledande",
    "missledandens": "missledande",
    "missledandes": "missledande",
    "missledandet": "missledande",
    "missledandets": "missledande",
    "missledas": "missleda",
    "missledd": "missleda",
    "missledda": "missleda",
    "missleddas": "missleda",
    "missledde": "missleda",
    "missleddes": "missleda",
    "missledds": "missleda",
    "missleder": "missleda",
    "missledes": "missleda",
    "missleds": "missleda",
    "misslett": "missleda",
    "missletts": "missleda",
    "missljuden": "missljud",
    "missljudens": "missljud",
    "missljudet": "missljud",
    "missljudets": "missljud",
    "missljuds": "missljud",
    "misslyckade": "misslyckad",
    "misslyckades": "misslyckas",
    "misslyckads": "misslyckad",
    "misslyckanden": "misslyckande",
    "misslyckandena": "misslyckande",
    "misslyckandenas": "misslyckande",
    "misslyckandens": "misslyckande",
    "misslyckandes": "misslyckande",
    "misslyckandet": "misslyckande",
    "misslyckandets": "misslyckande",
    "misslyckat": "misslyckad",
    "misslyckats": "misslyckas",
    "misslynta": "misslynt",
    "misslyntare": "misslynt",
    "misslyntares": "misslynt",
    "misslyntas": "misslynt",
    "misslyntast": "misslynt",
    "misslyntaste": "misslynt",
    "misslyntastes": "misslynt",
    "misslyntasts": "misslynt",
    "misslynte": "misslynt",
    "misslyntes": "misslynt",
    "misslyntheten": "misslynthet",
    "misslynthetens": "misslynthet",
    "misslynthets": "misslynthet",
    "misslynts": "misslynt",
    "missmodet": "missmod",
    "missmodets": "missmod",
    "missmodiga": "missmodig",
    "missmodigare": "missmodig",
    "missmodigares": "missmodig",
    "missmodigas": "missmodig",
    "missmodigast": "missmodig",
    "missmodigaste": "missmodig",
    "missmodigastes": "missmodig",
    "missmodigasts": "missmodig",
    "missmodige": "missmodig",
    "missmodiges": "missmodig",
    "missmodigheten": "missmodighet",
    "missmodighetens": "missmodighet",
    "missmodighets": "missmodighet",
    "missmodigs": "missmodig",
    "missmodigt": "missmodig",
    "missmodigts": "missmodig",
    "missmods": "missmod",
    "missnen": "missne",
    "missnens": "missne",
    "missnes": "missne",
    "missnet": "missne",
    "missnets": "missne",
    "missnöjda": "missnöjd",
    "missnöjdare": "missnöjd",
    "missnöjdares": "missnöjd",
    "missnöjdas": "missnöjd",
    "missnöjdast": "missnöjd",
    "missnöjdaste": "missnöjd",
    "missnöjdastes": "missnöjd",
    "missnöjdasts": "missnöjd",
    "missnöjde": "missnöjd",
    "missnöjdes": "missnöjd",
    "missnöjdheten": "missnöjdhet",
    "missnöjdhetens": "missnöjdhet",
    "missnöjdhets": "missnöjdhet",
    "missnöjds": "missnöjd",
    "missnöjen": "missnöje",
    "missnöjena": "missnöje",
    "missnöjenas": "missnöje",
    "missnöjens": "missnöje",
    "missnöjes": "missnöje",
    "missnöjesaktionen": "missnöjesaktion",
    "missnöjesaktionens": "missnöjesaktion",
    "missnöjesaktioner": "missnöjesaktion",
    "missnöjesaktionerna": "missnöjesaktion",
    "missnöjesaktionernas": "missnöjesaktion",
    "missnöjesaktioners": "missnöjesaktion",
    "missnöjesaktions": "missnöjesaktion",
    "missnöjesanmälans": "missnöjesanmälan",
    "missnöjesanmälningar": "missnöjesanmälan",
    "missnöjesanmälningarna": "missnöjesanmälan",
    "missnöjesanmälningarnas": "missnöjesanmälan",
    "missnöjesanmälningars": "missnöjesanmälan",
    "missnöjespartier": "missnöjesparti",
    "missnöjespartierna": "missnöjesparti",
    "missnöjespartiernas": "missnöjesparti",
    "missnöjespartiers": "missnöjesparti",
    "missnöjespartiet": "missnöjesparti",
    "missnöjespartiets": "missnöjesparti",
    "missnöjespartis": "missnöjesparti",
    "missnöjespartit": "missnöjesparti",
    "missnöjespartits": "missnöjesparti",
    "missnöjesväljar": "missnöjesväljare",
    "missnöjesväljaren": "missnöjesväljare",
    "missnöjesväljarens": "missnöjesväljare",
    "missnöjesväljares": "missnöjesväljare",
    "missnöjesväljarna": "missnöjesväljare",
    "missnöjesväljarnas": "missnöjesväljare",
    "missnöjet": "missnöje",
    "missnöjets": "missnöje",
    "missnöjt": "missnöjd",
    "missnöjts": "missnöjd",
    "misspryd": "misspryda",
    "missprydande": "misspryda",
    "missprydanden": "missprydande",
    "missprydandena": "missprydande",
    "missprydandenas": "missprydande",
    "missprydandens": "missprydande",
    "missprydandes": "missprydande",
    "missprydandet": "missprydande",
    "missprydandets": "missprydande",
    "missprydas": "misspryda",
    "missprydd": "misspryda",
    "missprydda": "misspryda",
    "misspryddas": "misspryda",
    "missprydde": "misspryda",
    "misspryddes": "misspryda",
    "missprydds": "misspryda",
    "misspryder": "misspryda",
    "missprydes": "misspryda",
    "misspryds": "misspryda",
    "missprytt": "misspryda",
    "missprytts": "misspryda",
    "missriktade": "missriktad",
    "missriktades": "missriktad",
    "missriktads": "missriktad",
    "missriktat": "missriktad",
    "missriktats": "missriktad",
    "missromanen": "missroman",
    "missromanens": "missroman",
    "missromaner": "missroman",
    "missromanerna": "missroman",
    "missromanernas": "missroman",
    "missromaners": "missroman",
    "missromans": "missroman",
    "missräkningar": "missräkning",
    "missräkningarna": "missräkning",
    "missräkningarnas": "missräkning",
    "missräkningars": "missräkning",
    "missräkningen": "missräkning",
    "missräkningens": "missräkning",
    "missräknings": "missräkning",
    "misstag": "missta",
    "misstaga": "missta",
    "misstagande": "missta",
    "misstaganden": "misstagande",
    "misstagandena": "misstagande",
    "misstagandenas": "misstagande",
    "misstagandens": "misstagande",
    "misstagandes": "misstagande",
    "misstagandet": "misstagande",
    "misstagandets": "misstagande",
    "misstagas": "missta",
    "misstage": "missta",
    "misstagen": "misstag",
    "misstagens": "misstag",
    "misstager": "missta",
    "misstages": "missta",
    "misstaget": "misstag",
    "misstagets": "misstag",
    "misstagit": "missta",
    "misstagits": "missta",
    "misstagna": "missta",
    "misstagnas": "missta",
    "misstagne": "missta",
    "misstagnes": "missta",
    "misstags": "misstag",
    "misstankar": "misstanke",
    "misstankarna": "misstanke",
    "misstankarnas": "misstanke",
    "misstankars": "misstanke",
    "misstankegraden": "misstankegrad",
    "misstankegradens": "misstankegrad",
    "misstankegrader": "misstankegrad",
    "misstankegraderna": "misstankegrad",
    "misstankegradernas": "misstankegrad",
    "misstankegraders": "misstankegrad",
    "misstankegrads": "misstankegrad",
    "misstanken": "misstanke",
    "misstankens": "misstanke",
    "misstankes": "misstanke",
    "misstar": "missta",
    "misstas": "missta",
    "misstog": "missta",
    "misstoge": "missta",
    "misstoges": "missta",
    "misstogs": "missta",
    "misstolk": "misstolka",
    "misstolkad": "misstolka",
    "misstolkade": "misstolka",
    "misstolkades": "misstolka",
    "misstolkads": "misstolka",
    "misstolkande": "misstolka",
    "misstolkanden": "misstolkande",
    "misstolkandena": "misstolkande",
    "misstolkandenas": "misstolkande",
    "misstolkandens": "misstolkande",
    "misstolkandes": "misstolkande",
    "misstolkandet": "misstolkande",
    "misstolkandets": "misstolkande",
    "misstolkar": "misstolka",
    "misstolkas": "misstolka",
    "misstolkat": "misstolka",
    "misstolkats": "misstolka",
    "misstrodd": "misstro",
    "misstrodda": "misstro",
    "misstroddas": "misstro",
    "misstrodde": "misstro",
    "misstroddes": "misstro",
    "misstrodds": "misstro",
    "misstroende": "misstro",
    "misstroendeförklaringar": "misstroendeförklaring",
    "misstroendeförklaringarna": "misstroendeförklaring",
    "misstroendeförklaringarnas": "misstroendeförklaring",
    "misstroendeförklaringars": "misstroendeförklaring",
    "misstroendeförklaringen": "misstroendeförklaring",
    "misstroendeförklaringens": "misstroendeförklaring",
    "misstroendeförklarings": "misstroendeförklaring",
    "misstroenden": "misstroende",
    "misstroendena": "misstroende",
    "misstroendenas": "misstroende",
    "misstroendens": "misstroende",
    "misstroendes": "misstroende",
    "misstroendet": "misstroende",
    "misstroendets": "misstroende",
    "misstroendevota": "misstroendevotum",
    "misstroendevotas": "misstroendevotum",
    "misstroendevotumen": "misstroendevotum",
    "misstroendevotumens": "misstroendevotum",
    "misstroendevotumet": "misstroendevotum",
    "misstroendevotumets": "misstroendevotum",
    "misstroendevotums": "misstroendevotum",
    "misstrogenheten": "misstrogenhet",
    "misstrogenhetens": "misstrogenhet",
    "misstrogenhets": "misstrogenhet",
    "misstrogens": "misstrogen",
    "misstroget": "misstrogen",
    "misstrogets": "misstrogen",
    "misstrogna": "misstrogen",
    "misstrognare": "misstrogen",
    "misstrognares": "misstrogen",
    "misstrognas": "misstrogen",
    "misstrognast": "misstrogen",
    "misstrognaste": "misstrogen",
    "misstrognastes": "misstrogen",
    "misstrognasts": "misstrogen",
    "misstrogne": "misstrogen",
    "misstrognes": "misstrogen",
    "misstron": "misstro",
    "misstrons": "misstro",
    "misstror": "misstro",
    "misstros": "misstro",
    "misstrott": "misstro",
    "misstrotts": "misstro",
    "misströstade": "misströsta",
    "misströstades": "misströsta",
    "misströstande": "misströsta",
    "misströstanden": "misströstande",
    "misströstandena": "misströstande",
    "misströstandenas": "misströstande",
    "misströstandens": "misströstande",
    "misströstandes": "misströstande",
    "misströstandet": "misströstande",
    "misströstandets": "misströstande",
    "misströstans": "misströstan",
    "misströstar": "misströsta",
    "misströstas": "misströsta",
    "misströstat": "misströsta",
    "misströstats": "misströsta",
    "misstyck": "misstycka",
    "misstyckande": "misstycka",
    "misstyckanden": "misstyckande",
    "misstyckandena": "misstyckande",
    "misstyckandenas": "misstyckande",
    "misstyckandens": "misstyckande",
    "misstyckandes": "misstyckande",
    "misstyckandet": "misstyckande",
    "misstyckandets": "misstyckande",
    "misstyckas": "misstycka",
    "misstycker": "misstycka",
    "misstyckes": "misstycke",
    "misstycket": "misstycke",
    "misstyckets": "misstycke",
    "misstycks": "misstycka",
    "misstyckt": "misstycka",
    "misstyckte": "misstycka",
    "misstycktes": "misstycka",
    "misstyckts": "misstycka",
    "misstyd": "misstyda",
    "misstydande": "misstyda",
    "misstydanden": "misstydande",
    "misstydandena": "misstydande",
    "misstydandenas": "misstydande",
    "misstydandens": "misstydande",
    "misstydandes": "misstydande",
    "misstydandet": "misstydande",
    "misstydandets": "misstydande",
    "misstydas": "misstyda",
    "misstydd": "misstyda",
    "misstydda": "misstyda",
    "misstyddas": "misstyda",
    "misstydde": "misstyda",
    "misstyddes": "misstyda",
    "misstydds": "misstyda",
    "misstyder": "misstyda",
    "misstydes": "misstyda",
    "misstyds": "misstyda",
    "misstytt": "misstyda",
    "misstytts": "misstyda",
    "misstämningar": "misstämning",
    "misstämningarna": "misstämning",
    "misstämningarnas": "misstämning",
    "misstämningars": "misstämning",
    "misstämningen": "misstämning",
    "misstämningens": "misstämning",
    "misstämnings": "misstämning",
    "misstänk": "misstänka",
    "misstänkande": "misstänka",
    "misstänkanden": "misstänkande",
    "misstänkandena": "misstänkande",
    "misstänkandenas": "misstänkande",
    "misstänkandens": "misstänkande",
    "misstänkandes": "misstänkande",
    "misstänkandet": "misstänkande",
    "misstänkandets": "misstänkande",
    "misstänkas": "misstänka",
    "misstänker": "misstänka",
    "misstänkes": "misstänka",
    "misstänkliggjord": "misstänkliggöra",
    "misstänkliggjorda": "misstänkliggöra",
    "misstänkliggjordas": "misstänkliggöra",
    "misstänkliggjorde": "misstänkliggöra",
    "misstänkliggjordes": "misstänkliggöra",
    "misstänkliggjords": "misstänkliggöra",
    "misstänkliggjort": "misstänkliggöra",
    "misstänkliggjorts": "misstänkliggöra",
    "misstänkliggör": "misstänkliggöra",
    "misstänkliggörande": "misstänkliggöra",
    "misstänkliggöranden": "misstänkliggörande",
    "misstänkliggörandena": "misstänkliggörande",
    "misstänkliggörandenas": "misstänkliggörande",
    "misstänkliggörandens": "misstänkliggörande",
    "misstänkliggörandes": "misstänkliggörande",
    "misstänkliggörandet": "misstänkliggörande",
    "misstänkliggörandets": "misstänkliggörande",
    "misstänkliggöras": "misstänkliggöra",
    "misstänkliggöres": "misstänkliggöra",
    "misstänkliggörs": "misstänkliggöra",
    "misstänks": "misstänka",
    "misstänksamheten": "misstänksamhet",
    "misstänksamhetens": "misstänksamhet",
    "misstänksamheter": "misstänksamhet",
    "misstänksamheterna": "misstänksamhet",
    "misstänksamheternas": "misstänksamhet",
    "misstänksamheters": "misstänksamhet",
    "misstänksamhets": "misstänksamhet",
    "misstänksamma": "misstänksam",
    "misstänksammare": "misstänksam",
    "misstänksammares": "misstänksam",
    "misstänksammas": "misstänksam",
    "misstänksammast": "misstänksam",
    "misstänksammaste": "misstänksam",
    "misstänksammastes": "misstänksam",
    "misstänksammasts": "misstänksam",
    "misstänksamme": "misstänksam",
    "misstänksammes": "misstänksam",
    "misstänksams": "misstänksam",
    "misstänksamt": "misstänksam",
    "misstänksamts": "misstänksam",
    "misstänkt": "misstänka",
    "misstänkta": "misstänkt",
    "misstänktare": "misstänkt",
    "misstänktares": "misstänkt",
    "misstänktas": "misstänkt",
    "misstänktast": "misstänkt",
    "misstänktaste": "misstänkt",
    "misstänktastes": "misstänkt",
    "misstänktasts": "misstänkt",
    "misstänkte": "misstänkt",
    "misstänktes": "misstänkt",
    "misstänkts": "misstänkt",
    "missunnad": "missunna",
    "missunnade": "missunna",
    "missunnades": "missunna",
    "missunnads": "missunna",
    "missunnande": "missunna",
    "missunnanden": "missunnande",
    "missunnandena": "missunnande",
    "missunnandenas": "missunnande",
    "missunnandens": "missunnande",
    "missunnandes": "missunnande",
    "missunnandet": "missunnande",
    "missunnandets": "missunnande",
    "missunnar": "missunna",
    "missunnas": "missunna",
    "missunnat": "missunna",
    "missunnats": "missunna",
    "missunnsamheten": "missunnsamhet",
    "missunnsamhetens": "missunnsamhet",
    "missunnsamhets": "missunnsamhet",
    "missunnsamma": "missunnsam",
    "missunnsammare": "missunnsam",
    "missunnsammares": "missunnsam",
    "missunnsammas": "missunnsam",
    "missunnsammast": "missunnsam",
    "missunnsammaste": "missunnsam",
    "missunnsammastes": "missunnsam",
    "missunnsammasts": "missunnsam",
    "missunnsamme": "missunnsam",
    "missunnsammes": "missunnsam",
    "missunnsams": "missunnsam",
    "missunnsamt": "missunnsam",
    "missunnsamts": "missunnsam",
    "missuppfatt": "missuppfatta",
    "missuppfattad": "missuppfatta",
    "missuppfattade": "missuppfatta",
    "missuppfattades": "missuppfatta",
    "missuppfattads": "missuppfatta",
    "missuppfattande": "missuppfatta",
    "missuppfattanden": "missuppfattande",
    "missuppfattandena": "missuppfattande",
    "missuppfattandenas": "missuppfattande",
    "missuppfattandens": "missuppfattande",
    "missuppfattandes": "missuppfattande",
    "missuppfattandet": "missuppfattande",
    "missuppfattandets": "missuppfattande",
    "missuppfattar": "missuppfatta",
    "missuppfattas": "missuppfatta",
    "missuppfattat": "missuppfatta",
    "missuppfattats": "missuppfatta",
    "missuppfattningar": "missuppfattning",
    "missuppfattningarna": "missuppfattning",
    "missuppfattningarnas": "missuppfattning",
    "missuppfattningars": "missuppfattning",
    "missuppfattningen": "missuppfattning",
    "missuppfattningens": "missuppfattning",
    "missuppfattnings": "missuppfattning",
    "missvisade": "missvisa",
    "missvisades": "missvisa",
    "missvisande": "missvisa",
    "missvisanden": "missvisande",
    "missvisandena": "missvisande",
    "missvisandenas": "missvisande",
    "missvisandens": "missvisande",
    "missvisandes": "missvisande",
    "missvisandet": "missvisande",
    "missvisandets": "missvisande",
    "missvisar": "missvisa",
    "missvisas": "missvisa",
    "missvisat": "missvisa",
    "missvisats": "missvisa",
    "missvisningar": "missvisning",
    "missvisningarna": "missvisning",
    "missvisningarnas": "missvisning",
    "missvisningars": "missvisning",
    "missvisningen": "missvisning",
    "missvisningens": "missvisning",
    "missvisnings": "missvisning",
    "missväxten": "missväxt",
    "missväxtens": "missväxt",
    "missväxts": "missväxt",
    "missämjan": "missämja",
    "missämjans": "missämja",
    "missämjas": "missämja",
    "missöden": "missöde",
    "missödena": "missöde",
    "missödenas": "missöde",
    "missödens": "missöde",
    "missödes": "missöde",
    "missödet": "missöde",
    "missödets": "missöde",
    "mist": "mista",
    "mistad": "mista",
    "mistade": "mista",
    "mistades": "mista",
    "mistads": "mista",
    "mistande": "mista",
    "mistanden": "mistande",
    "mistandena": "mistande",
    "mistandenas": "mistande",
    "mistandens": "mistande",
    "mistandes": "mistande",
    "mistandet": "mistande",
    "mistandets": "mistande",
    "mistas": "mista",
    "mistat": "mista",
    "mistats": "mista",
    "miste": "mista",
    "misteln": "mistel",
    "mistelns": "mistel",
    "mistels": "mistel",
    "misten": "mist",
    "mistens": "mist",
    "mister": "mista",
    "misters": "mister",
    "mistes": "mista",
    "mistiga": "mistig",
    "mistigare": "mistig",
    "mistigares": "mistig",
    "mistigas": "mistig",
    "mistigast": "mistig",
    "mistigaste": "mistig",
    "mistigastes": "mistig",
    "mistigasts": "mistig",
    "mistige": "mistig",
    "mistiges": "mistig",
    "mistigheten": "mistighet",
    "mistighetens": "mistighet",
    "mistighets": "mistighet",
    "mistigs": "mistig",
    "mistigt": "mistig",
    "mistigts": "mistig",
    "mistlar": "mistel",
    "mistlarna": "mistel",
    "mistlarnas": "mistel",
    "mistlars": "mistel",
    "mistlurar": "mistlur",
    "mistlurarna": "mistlur",
    "mistlurarnas": "mistlur",
    "mistlurars": "mistlur",
    "mistluren": "mistlur",
    "mistlurens": "mistlur",
    "mistlurs": "mistlur",
    "mistralen": "mistral",
    "mistralens": "mistral",
    "mistrals": "mistral",
    "mists": "mista",
    "misären": "misär",
    "misärens": "misär",
    "misärer": "misär",
    "misärerna": "misär",
    "misärernas": "misär",
    "misärers": "misär",
    "misärs": "misär",
    "mitell": "mitella",
    "mitellan": "mitella",
    "mitellans": "mitella",
    "mitellas": "mitella",
    "mitelle": "mitella",
    "mitellor": "mitella",
    "mitellorna": "mitella",
    "mitellornas": "mitella",
    "mitellors": "mitella",
    "mitells": "mitella",
    "mitokondrie-DNA-er": "mitokondrie-DNA",
    "mitokondrie-DNA-erna": "mitokondrie-DNA",
    "mitokondrie-DNA-ernas": "mitokondrie-DNA",
    "mitokondrie-DNA-ers": "mitokondrie-DNA",
    "mitokondrie-DNA-n": "mitokondrie-DNA",
    "mitokondrie-DNA-na": "mitokondrie-DNA",
    "mitokondrie-DNA-nas": "mitokondrie-DNA",
    "mitokondrie-DNA-ns": "mitokondrie-DNA",
    "mitokondrie-DNA-s": "mitokondrie-DNA",
    "mitokondrie-DNA-t": "mitokondrie-DNA",
    "mitokondrie-DNA-ts": "mitokondrie-DNA",
    "mitokondrie-DNA:er": "mitokondrie-DNA",
    "mitokondrie-DNA:erna": "mitokondrie-DNA",
    "mitokondrie-DNA:ernas": "mitokondrie-DNA",
    "mitokondrie-DNA:ers": "mitokondrie-DNA",
    "mitokondrie-DNA:n": "mitokondrie-DNA",
    "mitokondrie-DNA:na": "mitokondrie-DNA",
    "mitokondrie-DNA:nas": "mitokondrie-DNA",
    "mitokondrie-DNA:ns": "mitokondrie-DNA",
    "mitokondrie-DNA:s": "mitokondrie-DNA",
    "mitokondrie-DNA:t": "mitokondrie-DNA",
    "mitokondrie-DNA:ts": "mitokondrie-DNA",
    "mitokondrie-DNAer": "mitokondrie-DNA",
    "mitokondrie-DNAerna": "mitokondrie-DNA",
    "mitokondrie-DNAernas": "mitokondrie-DNA",
    "mitokondrie-DNAers": "mitokondrie-DNA",
    "mitokondrie-DNAn": "mitokondrie-DNA",
    "mitokondrie-DNAna": "mitokondrie-DNA",
    "mitokondrie-DNAnas": "mitokondrie-DNA",
    "mitokondrie-DNAns": "mitokondrie-DNA",
    "mitokondrie-DNAs": "mitokondrie-DNA",
    "mitokondrie-DNAt": "mitokondrie-DNA",
    "mitokondrie-DNAts": "mitokondrie-DNA",
    "mitokondrien": "mitokondrie",
    "mitokondriens": "mitokondrie",
    "mitokondrier": "mitokondrie",
    "mitokondrierna": "mitokondrie",
    "mitokondriernas": "mitokondrie",
    "mitokondriers": "mitokondrie",
    "mitokondries": "mitokondrie",
    "mitr": "mitra",
    "mitran": "mitra",
    "mitrans": "mitra",
    "mitras": "mitra",
    "mitre": "mitra",
    "mitror": "mitra",
    "mitrorna": "mitra",
    "mitrornas": "mitra",
    "mitrors": "mitra",
    "mitrs": "mitra",
    "mitt": "jag",
    "mittben": "mittbena",
    "mittbenan": "mittbena",
    "mittbenans": "mittbena",
    "mittbenas": "mittbena",
    "mittbene": "mittbena",
    "mittbenor": "mittbena",
    "mittbenorna": "mittbena",
    "mittbenornas": "mittbena",
    "mittbenors": "mittbena",
    "mittbens": "mittbena",
    "mittelgångar": "mittelgång",
    "mittelgångarna": "mittelgång",
    "mittelgångarnas": "mittelgång",
    "mittelgångars": "mittelgång",
    "mittelgången": "mittelgång",
    "mittelgångens": "mittelgång",
    "mittelgångs": "mittelgång",
    "mitteln": "mittel",
    "mittelns": "mittel",
    "mittels": "mittel",
    "mitten": "mitt",
    "mittenlagerna": "mittenlager",
    "mittenlagernas": "mittenlager",
    "mittenlagers": "mittenlager",
    "mittenlagren": "mittenlager",
    "mittenlagrens": "mittenlager",
    "mittenlagret": "mittenlager",
    "mittenlagrets": "mittenlager",
    "mittenpartier": "mittenparti",
    "mittenpartierna": "mittenparti",
    "mittenpartiernas": "mittenparti",
    "mittenpartiers": "mittenparti",
    "mittenpartiet": "mittenparti",
    "mittenpartiets": "mittenparti",
    "mittenpartis": "mittenparti",
    "mittenpartit": "mittenparti",
    "mittenpartits": "mittenparti",
    "mittens": "mitt",
    "mitterstas": "mittersta",
    "mittfälten": "mittfält",
    "mittfältens": "mittfält",
    "mittfältet": "mittfält",
    "mittfältets": "mittfält",
    "mittfälts": "mittfält",
    "mittlinjen": "mittlinje",
    "mittlinjens": "mittlinje",
    "mittlinjer": "mittlinje",
    "mittlinjerna": "mittlinje",
    "mittlinjernas": "mittlinje",
    "mittlinjers": "mittlinje",
    "mittlinjes": "mittlinje",
    "mittpartier": "mittparti",
    "mittpartierna": "mittparti",
    "mittpartiernas": "mittparti",
    "mittpartiers": "mittparti",
    "mittpartiet": "mittparti",
    "mittpartiets": "mittparti",
    "mittpartis": "mittparti",
    "mittpartit": "mittparti",
    "mittpartits": "mittparti",
    "mittpunkten": "mittpunkt",
    "mittpunktens": "mittpunkt",
    "mittpunkter": "mittpunkt",
    "mittpunkterna": "mittpunkt",
    "mittpunkternas": "mittpunkt",
    "mittpunkters": "mittpunkt",
    "mittpunkts": "mittpunkt",
    "mittpunktsnormalen": "mittpunktsnormal",
    "mittpunktsnormalens": "mittpunktsnormal",
    "mittpunktsnormaler": "mittpunktsnormal",
    "mittpunktsnormalerna": "mittpunktsnormal",
    "mittpunktsnormalernas": "mittpunktsnormal",
    "mittpunktsnormalers": "mittpunktsnormal",
    "mittpunktsnormals": "mittpunktsnormal",
    "mitträcken": "mitträcke",
    "mitträckena": "mitträcke",
    "mitträckenas": "mitträcke",
    "mitträckens": "mitträcke",
    "mitträckes": "mitträcke",
    "mitträcket": "mitträcke",
    "mitträckets": "mitträcke",
    "mitts": "mitt",
    "mittskeppen": "mittskepp",
    "mittskeppens": "mittskepp",
    "mittskeppet": "mittskepp",
    "mittskeppets": "mittskepp",
    "mittskepps": "mittskepp",
    "mix": "mixa",
    "mixad": "mixa",
    "mixade": "mixa",
    "mixades": "mixa",
    "mixads": "mixa",
    "mixande": "mixa",
    "mixanden": "mixande",
    "mixandena": "mixande",
    "mixandenas": "mixande",
    "mixandens": "mixande",
    "mixandes": "mixande",
    "mixandet": "mixande",
    "mixandets": "mixande",
    "mixar": "mixa",
    "mixarna": "mix",
    "mixarnas": "mix",
    "mixars": "mix",
    "mixas": "mixa",
    "mixat": "mixa",
    "mixats": "mixa",
    "mixeden": "mixed",
    "mixedens": "mixed",
    "mixeds": "mixed",
    "mixen": "mix",
    "mixens": "mix",
    "mixer": "mix",
    "mixern": "mixer",
    "mixerna": "mixer",
    "mixernas": "mixer",
    "mixerns": "mixer",
    "mixers": "mixer",
    "mixersarna": "mixer",
    "mixersarnas": "mixer",
    "mixrar": "mixer",
    "mixrarna": "mixer",
    "mixrarnas": "mixer",
    "mixrars": "mixer",
    "mixtrade": "mixtra",
    "mixtrades": "mixtra",
    "mixtrande": "mixtra",
    "mixtranden": "mixtrande",
    "mixtrandena": "mixtrande",
    "mixtrandenas": "mixtrande",
    "mixtrandens": "mixtrande",
    "mixtrandes": "mixtrande",
    "mixtrandet": "mixtrande",
    "mixtrandets": "mixtrande",
    "mixtrar": "mixtra",
    "mixtras": "mixtra",
    "mixtrat": "mixtra",
    "mixtrats": "mixtra",
    "mixturen": "mixtur",
    "mixturens": "mixtur",
    "mixturer": "mixtur",
    "mixturerna": "mixtur",
    "mixturernas": "mixtur",
    "mixturers": "mixtur",
    "mixturs": "mixtur",
    "mjauade": "mjaua",
    "mjauades": "mjaua",
    "mjauande": "mjaua",
    "mjauanden": "mjauande",
    "mjauandena": "mjauande",
    "mjauandenas": "mjauande",
    "mjauandens": "mjauande",
    "mjauandes": "mjauande",
    "mjauandet": "mjauande",
    "mjauandets": "mjauande",
    "mjauar": "mjaua",
    "mjauas": "mjaua",
    "mjauat": "mjaua",
    "mjauats": "mjaua",
    "mjauet": "mjau",
    "mjauets": "mjau",
    "mjaun": "mjau",
    "mjauna": "mjau",
    "mjaunas": "mjau",
    "mjauns": "mjau",
    "mjaus": "mjau",
    "mjaut": "mjau",
    "mjauts": "mjau",
    "mjuk": "mjuka",
    "mjuka": "mjuk",
    "mjukad": "mjuka",
    "mjukade": "mjuka",
    "mjukades": "mjuka",
    "mjukads": "mjuka",
    "mjukande": "mjuka",
    "mjukanden": "mjukande",
    "mjukandena": "mjukande",
    "mjukandenas": "mjukande",
    "mjukandens": "mjukande",
    "mjukandes": "mjukande",
    "mjukandet": "mjukande",
    "mjukandets": "mjukande",
    "mjukar": "mjuka",
    "mjukare": "mjuk",
    "mjukares": "mjuk",
    "mjukas": "mjuka",
    "mjukast": "mjuk",
    "mjukaste": "mjuk",
    "mjukastes": "mjuk",
    "mjukasts": "mjuk",
    "mjukat": "mjuka",
    "mjukats": "mjuka",
    "mjukbagg": "mjukbagge",
    "mjukbaggar": "mjukbagge",
    "mjukbaggarna": "mjukbagge",
    "mjukbaggarnas": "mjukbagge",
    "mjukbaggars": "mjukbagge",
    "mjukbaggen": "mjukbagge",
    "mjukbaggens": "mjukbagge",
    "mjukbagges": "mjukbagge",
    "mjukbaggs": "mjukbagge",
    "mjukdatan": "mjukdata",
    "mjukdatana": "mjukdata",
    "mjukdatanas": "mjukdata",
    "mjukdatans": "mjukdata",
    "mjukdatas": "mjukdata",
    "mjukdatat": "mjukdata",
    "mjukdatats": "mjukdata",
    "mjukdelar": "mjukdel",
    "mjukdelarna": "mjukdel",
    "mjukdelarnas": "mjukdel",
    "mjukdelars": "mjukdel",
    "mjukdelen": "mjukdel",
    "mjukdelens": "mjukdel",
    "mjukdels": "mjukdel",
    "mjukdelsbehandlingar": "mjukdelsbehandling",
    "mjukdelsbehandlingarna": "mjukdelsbehandling",
    "mjukdelsbehandlingarnas": "mjukdelsbehandling",
    "mjukdelsbehandlingars": "mjukdelsbehandling",
    "mjukdelsbehandlingen": "mjukdelsbehandling",
    "mjukdelsbehandlingens": "mjukdelsbehandling",
    "mjukdelsbehandlings": "mjukdelsbehandling",
    "mjuke": "mjuk",
    "mjukes": "mjuk",
    "mjukgjord": "mjukgöra",
    "mjukgjorda": "mjukgöra",
    "mjukgjordas": "mjukgöra",
    "mjukgjorde": "mjukgöra",
    "mjukgjordes": "mjukgöra",
    "mjukgjords": "mjukgöra",
    "mjukgjort": "mjukgöra",
    "mjukgjorts": "mjukgöra",
    "mjukgör": "mjukgöra",
    "mjukgörande": "mjukgöra",
    "mjukgöranden": "mjukgörande",
    "mjukgörandena": "mjukgörande",
    "mjukgörandenas": "mjukgörande",
    "mjukgörandens": "mjukgörande",
    "mjukgörandes": "mjukgörande",
    "mjukgörandet": "mjukgörande",
    "mjukgörandets": "mjukgörande",
    "mjukgöras": "mjukgöra",
    "mjukgöres": "mjukgöra",
    "mjukgörs": "mjukgöra",
    "mjukheten": "mjukhet",
    "mjukhetens": "mjukhet",
    "mjukheter": "mjukhet",
    "mjukheterna": "mjukhet",
    "mjukheternas": "mjukhet",
    "mjukheters": "mjukhet",
    "mjukhets": "mjukhet",
    "mjukisar": "mjukis",
    "mjukisarna": "mjukis",
    "mjukisarnas": "mjukis",
    "mjukisars": "mjukis",
    "mjukisen": "mjukis",
    "mjukisens": "mjukis",
    "mjuklandad": "mjuklanda",
    "mjuklandade": "mjuklanda",
    "mjuklandades": "mjuklanda",
    "mjuklandads": "mjuklanda",
    "mjuklandande": "mjuklanda",
    "mjuklandanden": "mjuklandande",
    "mjuklandandena": "mjuklandande",
    "mjuklandandenas": "mjuklandande",
    "mjuklandandens": "mjuklandande",
    "mjuklandandes": "mjuklandande",
    "mjuklandandet": "mjuklandande",
    "mjuklandandets": "mjuklandande",
    "mjuklandar": "mjuklanda",
    "mjuklandas": "mjuklanda",
    "mjuklandat": "mjuklanda",
    "mjuklandats": "mjuklanda",
    "mjuklodet": "mjuklod",
    "mjuklodets": "mjuklod",
    "mjuklods": "mjuklod",
    "mjuknade": "mjukna",
    "mjuknades": "mjukna",
    "mjuknande": "mjukna",
    "mjuknanden": "mjuknande",
    "mjuknandena": "mjuknande",
    "mjuknandenas": "mjuknande",
    "mjuknandens": "mjuknande",
    "mjuknandes": "mjuknande",
    "mjuknandet": "mjuknande",
    "mjuknandets": "mjuknande",
    "mjuknar": "mjukna",
    "mjuknas": "mjukna",
    "mjuknat": "mjukna",
    "mjuknats": "mjukna",
    "mjukningsmedels": "mjukningsmedel",
    "mjukningsmedlen": "mjukningsmedel",
    "mjukningsmedlens": "mjukningsmedel",
    "mjukningsmedlet": "mjukningsmedel",
    "mjukningsmedlets": "mjukningsmedel",
    "mjukostar": "mjukost",
    "mjukostarna": "mjukost",
    "mjukostarnas": "mjukost",
    "mjukostars": "mjukost",
    "mjukosten": "mjukost",
    "mjukostens": "mjukost",
    "mjukosts": "mjukost",
    "mjukporren": "mjukporr",
    "mjukporrens": "mjukporr",
    "mjukporrs": "mjukporr",
    "mjukryggade": "mjukryggad",
    "mjukryggades": "mjukryggad",
    "mjukryggads": "mjukryggad",
    "mjukryggat": "mjukryggad",
    "mjukryggats": "mjukryggad",
    "mjuks": "mjuk",
    "mjukskall": "mjukskalle",
    "mjukskallar": "mjukskalle",
    "mjukskallarna": "mjukskalle",
    "mjukskallarnas": "mjukskalle",
    "mjukskallars": "mjukskalle",
    "mjukskallen": "mjukskalle",
    "mjukskallens": "mjukskalle",
    "mjukskalles": "mjukskalle",
    "mjukskalls": "mjukskalle",
    "mjukt": "mjuk",
    "mjukts": "mjuk",
    "mjukvalutan": "mjukvaluta",
    "mjukvalutans": "mjukvaluta",
    "mjukvalutas": "mjukvaluta",
    "mjukvalute": "mjukvaluta",
    "mjukvalutor": "mjukvaluta",
    "mjukvalutorna": "mjukvaluta",
    "mjukvalutornas": "mjukvaluta",
    "mjukvalutors": "mjukvaluta",
    "mjukvar": "mjukvara",
    "mjukvaran": "mjukvara",
    "mjukvarans": "mjukvara",
    "mjukvaras": "mjukvara",
    "mjukvaror": "mjukvara",
    "mjukvarorna": "mjukvara",
    "mjukvarornas": "mjukvara",
    "mjukvarors": "mjukvara",
    "mjukvaru": "mjukvara",
    "mjukvattens": "mjukvatten",
    "mjukvattnet": "mjukvatten",
    "mjukvattnets": "mjukvatten",
    "mjukvävnaden": "mjukvävnad",
    "mjukvävnadens": "mjukvävnad",
    "mjukvävnader": "mjukvävnad",
    "mjukvävnaderna": "mjukvävnad",
    "mjukvävnadernas": "mjukvävnad",
    "mjukvävnaders": "mjukvävnad",
    "mjukvävnads": "mjukvävnad",
    "mjäkiga": "mjäkig",
    "mjäkigare": "mjäkig",
    "mjäkigares": "mjäkig",
    "mjäkigas": "mjäkig",
    "mjäkigast": "mjäkig",
    "mjäkigaste": "mjäkig",
    "mjäkigastes": "mjäkig",
    "mjäkigasts": "mjäkig",
    "mjäkige": "mjäkig",
    "mjäkiges": "mjäkig",
    "mjäkigs": "mjäkig",
    "mjäkigt": "mjäkig",
    "mjäkigts": "mjäkig",
    "mjälan": "mjäla",
    "mjälans": "mjäla",
    "mjälas": "mjäla",
    "mjälla": "mjäll",
    "mjällare": "mjäll",
    "mjällares": "mjäll",
    "mjällas": "mjäll",
    "mjällast": "mjäll",
    "mjällaste": "mjäll",
    "mjällastes": "mjäll",
    "mjällasts": "mjäll",
    "mjälle": "mjäll",
    "mjällen": "mjäll",
    "mjällens": "mjäll",
    "mjälles": "mjäll",
    "mjället": "mjäll",
    "mjällets": "mjäll",
    "mjällheten": "mjällhet",
    "mjällhetens": "mjällhet",
    "mjällhets": "mjällhet",
    "mjälliga": "mjällig",
    "mjälligare": "mjällig",
    "mjälligares": "mjällig",
    "mjälligas": "mjällig",
    "mjälligast": "mjällig",
    "mjälligaste": "mjällig",
    "mjälligastes": "mjällig",
    "mjälligasts": "mjällig",
    "mjällige": "mjällig",
    "mjälliges": "mjällig",
    "mjälligheten": "mjällighet",
    "mjällighetens": "mjällighet",
    "mjällighets": "mjällighet",
    "mjälligs": "mjällig",
    "mjälligt": "mjällig",
    "mjälligts": "mjällig",
    "mjälls": "mjäll",
    "mjällschampon": "mjällschampo",
    "mjällschampona": "mjällschampo",
    "mjällschamponas": "mjällschampo",
    "mjällschampons": "mjällschampo",
    "mjällschampos": "mjällschampo",
    "mjällschampot": "mjällschampo",
    "mjällschampots": "mjällschampo",
    "mjällt": "mjäll",
    "mjällts": "mjäll",
    "mjält": "mjälte",
    "mjältar": "mjälte",
    "mjältarna": "mjälte",
    "mjältarnas": "mjälte",
    "mjältars": "mjälte",
    "mjältbranden": "mjältbrand",
    "mjältbrandens": "mjältbrand",
    "mjältbrands": "mjältbrand",
    "mjälten": "mjälte",
    "mjältens": "mjälte",
    "mjältes": "mjälte",
    "mjälthuggen": "mjälthugg",
    "mjälthuggens": "mjälthugg",
    "mjälthugget": "mjälthugg",
    "mjälthuggets": "mjälthugg",
    "mjälthuggs": "mjälthugg",
    "mjälts": "mjälte",
    "mjältsjuka": "mjältsjuk",
    "mjältsjukan": "mjältsjuka",
    "mjältsjukans": "mjältsjuka",
    "mjältsjukare": "mjältsjuk",
    "mjältsjukares": "mjältsjuk",
    "mjältsjukas": "mjältsjuka",
    "mjältsjukast": "mjältsjuk",
    "mjältsjukaste": "mjältsjuk",
    "mjältsjukastes": "mjältsjuk",
    "mjältsjukasts": "mjältsjuk",
    "mjältsjuke": "mjältsjuka",
    "mjältsjukes": "mjältsjuk",
    "mjältsjukheten": "mjältsjukhet",
    "mjältsjukhetens": "mjältsjukhet",
    "mjältsjukhets": "mjältsjukhet",
    "mjältsjuks": "mjältsjuka",
    "mjältsjukt": "mjältsjuk",
    "mjältsjukts": "mjältsjuk",
    "mjärd": "mjärde",
    "mjärdar": "mjärde",
    "mjärdarna": "mjärde",
    "mjärdarnas": "mjärde",
    "mjärdars": "mjärde",
    "mjärden": "mjärde",
    "mjärdens": "mjärde",
    "mjärdes": "mjärde",
    "mjärds": "mjärde",
    "mjödet": "mjöd",
    "mjödets": "mjöd",
    "mjöds": "mjöd",
    "mjöl": "mjöla",
    "mjölad": "mjöla",
    "mjölade": "mjöla",
    "mjölades": "mjöla",
    "mjölads": "mjöla",
    "mjölande": "mjöla",
    "mjölanden": "mjölande",
    "mjölandena": "mjölande",
    "mjölandenas": "mjölande",
    "mjölandens": "mjölande",
    "mjölandes": "mjölande",
    "mjölandet": "mjölande",
    "mjölandets": "mjölande",
    "mjölar": "mjöla",
    "mjölas": "mjöla",
    "mjölat": "mjöla",
    "mjölats": "mjöla",
    "mjölbagg": "mjölbagge",
    "mjölbaggar": "mjölbagge",
    "mjölbaggarna": "mjölbagge",
    "mjölbaggarnas": "mjölbagge",
    "mjölbaggars": "mjölbagge",
    "mjölbaggen": "mjölbagge",
    "mjölbaggens": "mjölbagge",
    "mjölbagges": "mjölbagge",
    "mjölbaggs": "mjölbagge",
    "mjöldaggen": "mjöldagg",
    "mjöldaggens": "mjöldagg",
    "mjöldaggs": "mjöldagg",
    "mjöldammet": "mjöldamm",
    "mjöldammets": "mjöldamm",
    "mjöldamms": "mjöldamm",
    "mjöldryg": "mjöldryga",
    "mjöldrygan": "mjöldryga",
    "mjöldrygans": "mjöldryga",
    "mjöldrygas": "mjöldryga",
    "mjöldryge": "mjöldryga",
    "mjöldrygor": "mjöldryga",
    "mjöldrygorna": "mjöldryga",
    "mjöldrygornas": "mjöldryga",
    "mjöldrygors": "mjöldryga",
    "mjöldrygs": "mjöldryga",
    "mjöler": "mjöl",
    "mjölerna": "mjöl",
    "mjölernas": "mjöl",
    "mjölers": "mjöl",
    "mjölet": "mjöl",
    "mjölets": "mjöl",
    "mjöliga": "mjölig",
    "mjöligare": "mjölig",
    "mjöligares": "mjölig",
    "mjöligas": "mjölig",
    "mjöligast": "mjölig",
    "mjöligaste": "mjölig",
    "mjöligastes": "mjölig",
    "mjöligasts": "mjölig",
    "mjölige": "mjölig",
    "mjöliges": "mjölig",
    "mjöligheten": "mjölighet",
    "mjölighetens": "mjölighet",
    "mjölighets": "mjölighet",
    "mjöligs": "mjölig",
    "mjöligt": "mjölig",
    "mjöligts": "mjölig",
    "mjölk": "mjölke",
    "mjölkad": "mjölka",
    "mjölkade": "mjölka",
    "mjölkades": "mjölka",
    "mjölkads": "mjölka",
    "mjölkallergien": "mjölkallergi",
    "mjölkallergiens": "mjölkallergi",
    "mjölkallergier": "mjölkallergi",
    "mjölkallergierna": "mjölkallergi",
    "mjölkallergiernas": "mjölkallergi",
    "mjölkallergiers": "mjölkallergi",
    "mjölkallergin": "mjölkallergi",
    "mjölkallergins": "mjölkallergi",
    "mjölkallergis": "mjölkallergi",
    "mjölkande": "mjölka",
    "mjölkanden": "mjölkande",
    "mjölkandena": "mjölkande",
    "mjölkandenas": "mjölkande",
    "mjölkandens": "mjölkande",
    "mjölkandes": "mjölkande",
    "mjölkandet": "mjölkande",
    "mjölkandets": "mjölkande",
    "mjölkar": "mjölke",
    "mjölkarna": "mjölke",
    "mjölkarnas": "mjölke",
    "mjölkars": "mjölke",
    "mjölkas": "mjölka",
    "mjölkat": "mjölka",
    "mjölkats": "mjölka",
    "mjölkbaren": "mjölkbar",
    "mjölkbarens": "mjölkbar",
    "mjölkbarer": "mjölkbar",
    "mjölkbarerna": "mjölkbar",
    "mjölkbarernas": "mjölkbar",
    "mjölkbarers": "mjölkbar",
    "mjölkbars": "mjölkbar",
    "mjölkbond": "mjölkbonde",
    "mjölkbonden": "mjölkbonde",
    "mjölkbondens": "mjölkbonde",
    "mjölkbondes": "mjölkbonde",
    "mjölkbonds": "mjölkbonde",
    "mjölkboskapen": "mjölkboskap",
    "mjölkboskapens": "mjölkboskap",
    "mjölkboskaps": "mjölkboskap",
    "mjölkbuden": "mjölkbud",
    "mjölkbudens": "mjölkbud",
    "mjölkbudet": "mjölkbud",
    "mjölkbudets": "mjölkbud",
    "mjölkbuds": "mjölkbud",
    "mjölkbönder": "mjölkbonde",
    "mjölkbönderna": "mjölkbonde",
    "mjölkböndernas": "mjölkbonde",
    "mjölkbönders": "mjölkbonde",
    "mjölkcellen": "mjölkcell",
    "mjölkcellens": "mjölkcell",
    "mjölkceller": "mjölkcell",
    "mjölkcellerna": "mjölkcell",
    "mjölkcellernas": "mjölkcell",
    "mjölkcellers": "mjölkcell",
    "mjölkcells": "mjölkcell",
    "mjölkcentralen": "mjölkcentral",
    "mjölkcentralens": "mjölkcentral",
    "mjölkcentraler": "mjölkcentral",
    "mjölkcentralerna": "mjölkcentral",
    "mjölkcentralernas": "mjölkcentral",
    "mjölkcentralers": "mjölkcentral",
    "mjölkcentrals": "mjölkcentral",
    "mjölkchokladen": "mjölkchoklad",
    "mjölkchokladens": "mjölkchoklad",
    "mjölkchoklads": "mjölkchoklad",
    "mjölken": "mjölke",
    "mjölkens": "mjölke",
    "mjölkes": "mjölke",
    "mjölkfebern": "mjölkfeber",
    "mjölkfeberns": "mjölkfeber",
    "mjölkfebers": "mjölkfeber",
    "mjölkfettet": "mjölkfett",
    "mjölkfettets": "mjölkfett",
    "mjölkfetts": "mjölkfett",
    "mjölkflytningar": "mjölkflytning",
    "mjölkflytningarna": "mjölkflytning",
    "mjölkflytningarnas": "mjölkflytning",
    "mjölkflytningars": "mjölkflytning",
    "mjölkflytningen": "mjölkflytning",
    "mjölkflytningens": "mjölkflytning",
    "mjölkflytnings": "mjölkflytning",
    "mjölkflöden": "mjölkflöde",
    "mjölkflödena": "mjölkflöde",
    "mjölkflödenas": "mjölkflöde",
    "mjölkflödens": "mjölkflöde",
    "mjölkflödes": "mjölkflöde",
    "mjölkflödet": "mjölkflöde",
    "mjölkflödets": "mjölkflöde",
    "mjölkförpackningar": "mjölkförpackning",
    "mjölkförpackningarna": "mjölkförpackning",
    "mjölkförpackningarnas": "mjölkförpackning",
    "mjölkförpackningars": "mjölkförpackning",
    "mjölkförpackningen": "mjölkförpackning",
    "mjölkförpackningens": "mjölkförpackning",
    "mjölkförpacknings": "mjölkförpackning",
    "mjölkglaset": "mjölkglas",
    "mjölkglasets": "mjölkglas",
    "mjölkgrymten": "mjölkgrymt",
    "mjölkgrymtens": "mjölkgrymt",
    "mjölkgrymtet": "mjölkgrymt",
    "mjölkgrymtets": "mjölkgrymt",
    "mjölkgrymtningar": "mjölkgrymtning",
    "mjölkgrymtningarna": "mjölkgrymtning",
    "mjölkgrymtningarnas": "mjölkgrymtning",
    "mjölkgrymtningars": "mjölkgrymtning",
    "mjölkgrymtningen": "mjölkgrymtning",
    "mjölkgrymtningens": "mjölkgrymtning",
    "mjölkgrymtnings": "mjölkgrymtning",
    "mjölkgrymts": "mjölkgrymt",
    "mjölkgångar": "mjölkgång",
    "mjölkgångarna": "mjölkgång",
    "mjölkgångarnas": "mjölkgång",
    "mjölkgångars": "mjölkgång",
    "mjölkgången": "mjölkgång",
    "mjölkgångens": "mjölkgång",
    "mjölkgångs": "mjölkgång",
    "mjölkhinkar": "mjölkhink",
    "mjölkhinkarna": "mjölkhink",
    "mjölkhinkarnas": "mjölkhink",
    "mjölkhinkars": "mjölkhink",
    "mjölkhinken": "mjölkhink",
    "mjölkhinkens": "mjölkhink",
    "mjölkhinks": "mjölkhink",
    "mjölkiga": "mjölkig",
    "mjölkigare": "mjölkig",
    "mjölkigares": "mjölkig",
    "mjölkigas": "mjölkig",
    "mjölkigast": "mjölkig",
    "mjölkigaste": "mjölkig",
    "mjölkigastes": "mjölkig",
    "mjölkigasts": "mjölkig",
    "mjölkige": "mjölkig",
    "mjölkiges": "mjölkig",
    "mjölkigheten": "mjölkighet",
    "mjölkighetens": "mjölkighet",
    "mjölkighets": "mjölkighet",
    "mjölkigs": "mjölkig",
    "mjölkigt": "mjölkig",
    "mjölkigts": "mjölkig",
    "mjölkkanalen": "mjölkkanal",
    "mjölkkanalens": "mjölkkanal",
    "mjölkkanaler": "mjölkkanal",
    "mjölkkanalerna": "mjölkkanal",
    "mjölkkanalernas": "mjölkkanal",
    "mjölkkanalers": "mjölkkanal",
    "mjölkkanals": "mjölkkanal",
    "mjölkkon": "mjölkko",
    "mjölkkons": "mjölkko",
    "mjölkkor": "mjölkko",
    "mjölkkorna": "mjölkko",
    "mjölkkornas": "mjölkko",
    "mjölkkors": "mjölkko",
    "mjölkkos": "mjölkko",
    "mjölkkoss": "mjölkkossa",
    "mjölkkossan": "mjölkkossa",
    "mjölkkossans": "mjölkkossa",
    "mjölkkossas": "mjölkkossa",
    "mjölkkosse": "mjölkkossa",
    "mjölkkossor": "mjölkkossa",
    "mjölkkossorna": "mjölkkossa",
    "mjölkkossornas": "mjölkkossa",
    "mjölkkossors": "mjölkkossa",
    "mjölkkärlen": "mjölkkärl",
    "mjölkkärlens": "mjölkkärl",
    "mjölkkärlet": "mjölkkärl",
    "mjölkkärlets": "mjölkkärl",
    "mjölkkärls": "mjölkkärl",
    "mjölkkörteln": "mjölkkörtel",
    "mjölkkörtelns": "mjölkkörtel",
    "mjölkkörtels": "mjölkkörtel",
    "mjölkkörtlar": "mjölkkörtel",
    "mjölkkörtlarna": "mjölkkörtel",
    "mjölkkörtlarnas": "mjölkkörtel",
    "mjölkkörtlars": "mjölkkörtel",
    "mjölkmagar": "mjölkmage",
    "mjölkmagarna": "mjölkmage",
    "mjölkmagarnas": "mjölkmage",
    "mjölkmagars": "mjölkmage",
    "mjölkmagen": "mjölkmage",
    "mjölkmagens": "mjölkmage",
    "mjölkmages": "mjölkmage",
    "mjölkpaketen": "mjölkpaket",
    "mjölkpaketens": "mjölkpaket",
    "mjölkpaketet": "mjölkpaket",
    "mjölkpaketets": "mjölkpaket",
    "mjölkpakets": "mjölkpaket",
    "mjölkpallar": "mjölkpall",
    "mjölkpallarna": "mjölkpall",
    "mjölkpallarnas": "mjölkpall",
    "mjölkpallars": "mjölkpall",
    "mjölkpallen": "mjölkpall",
    "mjölkpallens": "mjölkpall",
    "mjölkpalls": "mjölkpall",
    "mjölkproducenten": "mjölkproducent",
    "mjölkproducentens": "mjölkproducent",
    "mjölkproducenter": "mjölkproducent",
    "mjölkproducenterna": "mjölkproducent",
    "mjölkproducenternas": "mjölkproducent",
    "mjölkproducenters": "mjölkproducent",
    "mjölkproducents": "mjölkproducent",
    "mjölkprodukten": "mjölkprodukt",
    "mjölkproduktens": "mjölkprodukt",
    "mjölkprodukter": "mjölkprodukt",
    "mjölkprodukterna": "mjölkprodukt",
    "mjölkprodukternas": "mjölkprodukt",
    "mjölkprodukters": "mjölkprodukt",
    "mjölkproduktionen": "mjölkproduktion",
    "mjölkproduktionens": "mjölkproduktion",
    "mjölkproduktioner": "mjölkproduktion",
    "mjölkproduktionerna": "mjölkproduktion",
    "mjölkproduktionernas": "mjölkproduktion",
    "mjölkproduktioners": "mjölkproduktion",
    "mjölkproduktions": "mjölkproduktion",
    "mjölkprodukts": "mjölkprodukt",
    "mjölks": "mjölke",
    "mjölksaften": "mjölksaft",
    "mjölksaftens": "mjölksaft",
    "mjölksafts": "mjölksaft",
    "mjölkskandalen": "mjölkskandal",
    "mjölkskandalens": "mjölkskandal",
    "mjölkskandaler": "mjölkskandal",
    "mjölkskandalerna": "mjölkskandal",
    "mjölkskandalernas": "mjölkskandal",
    "mjölkskandalers": "mjölkskandal",
    "mjölkskandals": "mjölkskandal",
    "mjölkskorven": "mjölkskorv",
    "mjölkskorvens": "mjölkskorv",
    "mjölkskorvs": "mjölkskorv",
    "mjölksockers": "mjölksocker",
    "mjölksockret": "mjölksocker",
    "mjölksockrets": "mjölksocker",
    "mjölkspegeln": "mjölkspegel",
    "mjölkspegelns": "mjölkspegel",
    "mjölkspegels": "mjölkspegel",
    "mjölkspeglar": "mjölkspegel",
    "mjölkspeglarna": "mjölkspegel",
    "mjölkspeglarnas": "mjölkspegel",
    "mjölkspeglars": "mjölkspegel",
    "mjölkstinna": "mjölkstinn",
    "mjölkstinnare": "mjölkstinn",
    "mjölkstinnares": "mjölkstinn",
    "mjölkstinnas": "mjölkstinn",
    "mjölkstinnast": "mjölkstinn",
    "mjölkstinnaste": "mjölkstinn",
    "mjölkstinnastes": "mjölkstinn",
    "mjölkstinnasts": "mjölkstinn",
    "mjölkstinne": "mjölkstinn",
    "mjölkstinnes": "mjölkstinn",
    "mjölkstinnheten": "mjölkstinnhet",
    "mjölkstinnhetens": "mjölkstinnhet",
    "mjölkstinnhets": "mjölkstinnhet",
    "mjölkstinns": "mjölkstinn",
    "mjölkstint": "mjölkstinn",
    "mjölkstints": "mjölkstinn",
    "mjölkstockningar": "mjölkstockning",
    "mjölkstockningarna": "mjölkstockning",
    "mjölkstockningarnas": "mjölkstockning",
    "mjölkstockningars": "mjölkstockning",
    "mjölkstockningen": "mjölkstockning",
    "mjölkstockningens": "mjölkstockning",
    "mjölkstocknings": "mjölkstockning",
    "mjölksvullenheten": "mjölksvullenhet",
    "mjölksvullenhetens": "mjölksvullenhet",
    "mjölksvullenhets": "mjölksvullenhet",
    "mjölksvullens": "mjölksvullen",
    "mjölksvullet": "mjölksvullen",
    "mjölksvullets": "mjölksvullen",
    "mjölksvullna": "mjölksvullen",
    "mjölksvullnas": "mjölksvullen",
    "mjölksvullne": "mjölksvullen",
    "mjölksvullnes": "mjölksvullen",
    "mjölksyran": "mjölksyra",
    "mjölksyrans": "mjölksyra",
    "mjölksyras": "mjölksyra",
    "mjölksyre": "mjölksyra",
    "mjölksyrebakterien": "mjölksyrebakterie",
    "mjölksyrebakteriens": "mjölksyrebakterie",
    "mjölksyrebakterier": "mjölksyrebakterie",
    "mjölksyrebakterierna": "mjölksyrebakterie",
    "mjölksyrebakteriernas": "mjölksyrebakterie",
    "mjölksyrebakteriers": "mjölksyrebakterie",
    "mjölksyrebakteries": "mjölksyrebakterie",
    "mjölksyror": "mjölksyra",
    "mjölksyrorna": "mjölksyra",
    "mjölksyrornas": "mjölksyra",
    "mjölksyrors": "mjölksyra",
    "mjölktanden": "mjölktand",
    "mjölktandens": "mjölktand",
    "mjölktands": "mjölktand",
    "mjölktänder": "mjölktand",
    "mjölktänderna": "mjölktand",
    "mjölktändernas": "mjölktand",
    "mjölktänders": "mjölktand",
    "mjölkvita": "mjölkvit",
    "mjölkvitare": "mjölkvit",
    "mjölkvitares": "mjölkvit",
    "mjölkvitas": "mjölkvit",
    "mjölkvitast": "mjölkvit",
    "mjölkvitaste": "mjölkvit",
    "mjölkvitastes": "mjölkvit",
    "mjölkvitasts": "mjölkvit",
    "mjölkvite": "mjölkvit",
    "mjölkvites": "mjölkvit",
    "mjölkvits": "mjölkvit",
    "mjölkvitt": "mjölkvit",
    "mjölkvitts": "mjölkvit",
    "mjölkådern": "mjölkåder",
    "mjölkåderns": "mjölkåder",
    "mjölkåders": "mjölkåder",
    "mjölkådra": "mjölkåder",
    "mjölkådran": "mjölkåder",
    "mjölkådrans": "mjölkåder",
    "mjölkådras": "mjölkåder",
    "mjölkådre": "mjölkåder",
    "mjölkådror": "mjölkåder",
    "mjölkådrorna": "mjölkåder",
    "mjölkådrornas": "mjölkåder",
    "mjölkådrors": "mjölkåder",
    "mjölkörten": "mjölkört",
    "mjölkörtens": "mjölkört",
    "mjölkörter": "mjölkört",
    "mjölkörterna": "mjölkört",
    "mjölkörternas": "mjölkört",
    "mjölkörters": "mjölkört",
    "mjölkörts": "mjölkört",
    "mjölköverskotten": "mjölköverskott",
    "mjölköverskottens": "mjölköverskott",
    "mjölköverskottet": "mjölköverskott",
    "mjölköverskottets": "mjölköverskott",
    "mjölköverskotts": "mjölköverskott",
    "mjölnar": "mjölnare",
    "mjölnaren": "mjölnare",
    "mjölnarens": "mjölnare",
    "mjölnares": "mjölnare",
    "mjölnarmatten": "mjölnarmatte",
    "mjölnarmattens": "mjölnarmatte",
    "mjölnarmattes": "mjölnarmatte",
    "mjölnarmattet": "mjölnarmatte",
    "mjölnarmattets": "mjölnarmatte",
    "mjölnarna": "mjölnare",
    "mjölnarnas": "mjölnare",
    "mjölonen": "mjölon",
    "mjölonens": "mjölon",
    "mjölonet": "mjölon",
    "mjölonets": "mjölon",
    "mjölons": "mjölon",
    "mjölpås": "mjölpåse",
    "mjölpåsar": "mjölpåse",
    "mjölpåsarna": "mjölpåse",
    "mjölpåsarnas": "mjölpåse",
    "mjölpåsars": "mjölpåse",
    "mjölpåsen": "mjölpåse",
    "mjölpåsens": "mjölpåse",
    "mjölpåses": "mjölpåse",
    "mjöls": "mjöl",
    "mjölskivlingar": "mjölskivling",
    "mjölskivlingarna": "mjölskivling",
    "mjölskivlingarnas": "mjölskivling",
    "mjölskivlingars": "mjölskivling",
    "mjölskivlingen": "mjölskivling",
    "mjölskivlingens": "mjölskivling",
    "mjölskivlings": "mjölskivling",
    "mnemoniska": "mnemonisk",
    "mnemoniskas": "mnemonisk",
    "mnemoniske": "mnemonisk",
    "mnemoniskes": "mnemonisk",
    "mnemonisks": "mnemonisk",
    "mnemoniskt": "mnemonisk",
    "mnemoniskts": "mnemonisk",
    "mnemotekniken": "mnemoteknik",
    "mnemoteknikens": "mnemoteknik",
    "mnemotekniks": "mnemoteknik",
    "mnemotekniska": "mnemoteknisk",
    "mnemotekniskare": "mnemoteknisk",
    "mnemotekniskares": "mnemoteknisk",
    "mnemotekniskas": "mnemoteknisk",
    "mnemotekniskast": "mnemoteknisk",
    "mnemotekniskaste": "mnemoteknisk",
    "mnemotekniskastes": "mnemoteknisk",
    "mnemotekniskasts": "mnemoteknisk",
    "mnemotekniske": "mnemoteknisk",
    "mnemotekniskes": "mnemoteknisk",
    "mnemoteknisks": "mnemoteknisk",
    "mnemotekniskt": "mnemoteknisk",
    "mnemotekniskts": "mnemoteknisk",
    "moar": "mo",
    "moarna": "mo",
    "moarnas": "mo",
    "moars": "mo",
    "moaréer": "moaré",
    "moaréerna": "moaré",
    "moaréernas": "moaré",
    "moaréers": "moaré",
    "moarén": "moaré",
    "moaréns": "moaré",
    "moarés": "moaré",
    "moatjéen": "moatjé",
    "moatjéens": "moatjé",
    "moatjéer": "moatjé",
    "moatjéerna": "moatjé",
    "moatjéernas": "moatjé",
    "moatjéers": "moatjé",
    "moatjén": "moatjé",
    "moatjéns": "moatjé",
    "moatjés": "moatjé",
    "mobb": "mobba",
    "mobbad": "mobba",
    "mobbade": "mobba",
    "mobbades": "mobba",
    "mobbads": "mobba",
    "mobbande": "mobba",
    "mobbanden": "mobbande",
    "mobbandena": "mobbande",
    "mobbandenas": "mobbande",
    "mobbandens": "mobbande",
    "mobbandes": "mobbande",
    "mobbandet": "mobbande",
    "mobbandets": "mobbande",
    "mobbar": "mobba",
    "mobbas": "mobba",
    "mobbat": "mobba",
    "mobbats": "mobba",
    "mobben": "mobb",
    "mobbens": "mobb",
    "mobbingen": "mobbing",
    "mobbingens": "mobbing",
    "mobbings": "mobbing",
    "mobbningen": "mobbning",
    "mobbningens": "mobbning",
    "mobbnings": "mobbning",
    "mobbningskampanjen": "mobbningskampanj",
    "mobbningskampanjens": "mobbningskampanj",
    "mobbningskampanjer": "mobbningskampanj",
    "mobbningskampanjerna": "mobbningskampanj",
    "mobbningskampanjernas": "mobbningskampanj",
    "mobbningskampanjers": "mobbningskampanj",
    "mobbningskampanjs": "mobbningskampanj",
    "mobbs": "mobb",
    "mobila": "mobil",
    "mobilabonnemangen": "mobilabonnemang",
    "mobilabonnemangens": "mobilabonnemang",
    "mobilabonnemanget": "mobilabonnemang",
    "mobilabonnemangets": "mobilabonnemang",
    "mobilabonnemangs": "mobilabonnemang",
    "mobilabonnemangsförsäljar": "mobilabonnemangsförsäljare",
    "mobilabonnemangsförsäljaren": "mobilabonnemangsförsäljare",
    "mobilabonnemangsförsäljarens": "mobilabonnemangsförsäljare",
    "mobilabonnemangsförsäljares": "mobilabonnemangsförsäljare",
    "mobilabonnemangsförsäljarna": "mobilabonnemangsförsäljare",
    "mobilabonnemangsförsäljarnas": "mobilabonnemangsförsäljare",
    "mobilare": "mobil",
    "mobilares": "mobil",
    "mobilas": "mobil",
    "mobilast": "mobil",
    "mobilaste": "mobil",
    "mobilastes": "mobil",
    "mobilasts": "mobil",
    "mobile": "mobil",
    "mobilen": "mobil",
    "mobilens": "mobil",
    "mobiler": "mobil",
    "mobilerna": "mobil",
    "mobilernas": "mobil",
    "mobilers": "mobil",
    "mobiles": "mobil",
    "mobilförsäljningen": "mobilförsäljning",
    "mobilförsäljningens": "mobilförsäljning",
    "mobilförsäljnings": "mobilförsäljning",
    "mobilie": "mobilier",
    "mobilierna": "mobilier",
    "mobiliernas": "mobilier",
    "mobiliers": "mobilier",
    "mobiliserad": "mobilisera",
    "mobiliserade": "mobilisera",
    "mobiliserades": "mobilisera",
    "mobiliserads": "mobilisera",
    "mobiliserande": "mobilisera",
    "mobiliseranden": "mobiliserande",
    "mobiliserandena": "mobiliserande",
    "mobiliserandenas": "mobiliserande",
    "mobiliserandens": "mobiliserande",
    "mobiliserandes": "mobiliserande",
    "mobiliserandet": "mobiliserande",
    "mobiliserandets": "mobiliserande",
    "mobiliserar": "mobilisera",
    "mobiliseras": "mobilisera",
    "mobiliserat": "mobilisera",
    "mobiliserats": "mobilisera",
    "mobiliserbara": "mobiliserbar",
    "mobiliserbarare": "mobiliserbar",
    "mobiliserbarares": "mobiliserbar",
    "mobiliserbaras": "mobiliserbar",
    "mobiliserbarast": "mobiliserbar",
    "mobiliserbaraste": "mobiliserbar",
    "mobiliserbarastes": "mobiliserbar",
    "mobiliserbarasts": "mobiliserbar",
    "mobiliserbare": "mobiliserbar",
    "mobiliserbares": "mobiliserbar",
    "mobiliserbarheten": "mobiliserbarhet",
    "mobiliserbarhetens": "mobiliserbarhet",
    "mobiliserbarhets": "mobiliserbarhet",
    "mobiliserbars": "mobiliserbar",
    "mobiliserbart": "mobiliserbar",
    "mobiliserbarts": "mobiliserbar",
    "mobiliseringar": "mobilisering",
    "mobiliseringarna": "mobilisering",
    "mobiliseringarnas": "mobilisering",
    "mobiliseringars": "mobilisering",
    "mobiliseringen": "mobilisering",
    "mobiliseringens": "mobilisering",
    "mobiliserings": "mobilisering",
    "mobiliseringsplatsen": "mobiliseringsplats",
    "mobiliseringsplatsens": "mobiliseringsplats",
    "mobiliseringsplatser": "mobiliseringsplats",
    "mobiliseringsplatserna": "mobiliseringsplats",
    "mobiliseringsplatsernas": "mobiliseringsplats",
    "mobiliseringsplatsers": "mobiliseringsplats",
    "mobiliteten": "mobilitet",
    "mobilitetens": "mobilitet",
    "mobiliteter": "mobilitet",
    "mobiliteterna": "mobilitet",
    "mobiliteternas": "mobilitet",
    "mobiliteters": "mobilitet",
    "mobilitets": "mobilitet",
    "mobilladdar": "mobilladdare",
    "mobilladdaren": "mobilladdare",
    "mobilladdarens": "mobilladdare",
    "mobilladdares": "mobilladdare",
    "mobilladdarna": "mobilladdare",
    "mobilladdarnas": "mobilladdare",
    "mobilräkningar": "mobilräkning",
    "mobilräkningarna": "mobilräkning",
    "mobilräkningarnas": "mobilräkning",
    "mobilräkningars": "mobilräkning",
    "mobilräkningen": "mobilräkning",
    "mobilräkningens": "mobilräkning",
    "mobilräknings": "mobilräkning",
    "mobils": "mobil",
    "mobilsamtalen": "mobilsamtal",
    "mobilsamtalens": "mobilsamtal",
    "mobilsamtalet": "mobilsamtal",
    "mobilsamtalets": "mobilsamtal",
    "mobilsamtals": "mobilsamtal",
    "mobilt": "mobil",
    "mobiltelefonen": "mobiltelefon",
    "mobiltelefonens": "mobiltelefon",
    "mobiltelefoner": "mobiltelefon",
    "mobiltelefonerna": "mobiltelefon",
    "mobiltelefonernas": "mobiltelefon",
    "mobiltelefoners": "mobiltelefon",
    "mobiltelefonien": "mobiltelefoni",
    "mobiltelefoniens": "mobiltelefoni",
    "mobiltelefonin": "mobiltelefoni",
    "mobiltelefonins": "mobiltelefoni",
    "mobiltelefonis": "mobiltelefoni",
    "mobiltelefons": "mobiltelefon",
    "mobilts": "mobil",
    "mobilvirusen": "mobilvirus",
    "mobilvirusens": "mobilvirus",
    "mobilviruset": "mobilvirus",
    "mobilvirusets": "mobilvirus",
    "mocambikiern": "mocambikier",
    "mocambikierna": "mocambikier",
    "mocambikiernas": "mocambikier",
    "mocambikierns": "mocambikier",
    "mocambikiers": "mocambikier",
    "mocambikiska": "mocambikisk",
    "mocambikiskare": "mocambikisk",
    "mocambikiskares": "mocambikisk",
    "mocambikiskas": "mocambikisk",
    "mocambikiskast": "mocambikisk",
    "mocambikiskaste": "mocambikisk",
    "mocambikiskastes": "mocambikisk",
    "mocambikiskasts": "mocambikisk",
    "mocambikiske": "mocambikisk",
    "mocambikiskes": "mocambikisk",
    "mocambikisks": "mocambikisk",
    "mocambikiskt": "mocambikisk",
    "mocambikiskts": "mocambikisk",
    "mock": "mocka",
    "mockad": "mocka",
    "mockade": "mocka",
    "mockades": "mocka",
    "mockads": "mocka",
    "mockakoppar": "mockakopp",
    "mockakopparna": "mockakopp",
    "mockakopparnas": "mockakopp",
    "mockakoppars": "mockakopp",
    "mockakoppen": "mockakopp",
    "mockakoppens": "mockakopp",
    "mockakopps": "mockakopp",
    "mockan": "mocka",
    "mockande": "mocka",
    "mockanden": "mockande",
    "mockandena": "mockande",
    "mockandenas": "mockande",
    "mockandens": "mockande",
    "mockandes": "mockande",
    "mockandet": "mockande",
    "mockandets": "mockande",
    "mockans": "mocka",
    "mockar": "mocka",
    "mockas": "mocka",
    "mockasinen": "mockasin",
    "mockasinens": "mockasin",
    "mockasiner": "mockasin",
    "mockasinerna": "mockasin",
    "mockasinernas": "mockasin",
    "mockasiners": "mockasin",
    "mockasinformade": "mockasinformad",
    "mockasinformades": "mockasinformad",
    "mockasinformads": "mockasinformad",
    "mockasinformat": "mockasinformad",
    "mockasinformats": "mockasinformad",
    "mockasins": "mockasin",
    "mockaskedar": "mockasked",
    "mockaskedarna": "mockasked",
    "mockaskedarnas": "mockasked",
    "mockaskedars": "mockasked",
    "mockaskeden": "mockasked",
    "mockaskedens": "mockasked",
    "mockaskeds": "mockasked",
    "mockat": "mocka",
    "mockats": "mocka",
    "modala": "modal",
    "modalare": "modal",
    "modalares": "modal",
    "modalas": "modal",
    "modalast": "modal",
    "modalaste": "modal",
    "modalastes": "modal",
    "modalasts": "modal",
    "modale": "modal",
    "modales": "modal",
    "modaliteten": "modalitet",
    "modalitetens": "modalitet",
    "modaliteter": "modalitet",
    "modaliteterna": "modalitet",
    "modaliteternas": "modalitet",
    "modaliteters": "modalitet",
    "modalitets": "modalitet",
    "modallogiken": "modallogik",
    "modallogikens": "modallogik",
    "modallogiks": "modallogik",
    "modals": "modal",
    "modalt": "modal",
    "modalts": "modal",
    "modden": "modd",
    "moddens": "modd",
    "moddlar": "moddlare",
    "moddlaren": "moddlare",
    "moddlarens": "moddlare",
    "moddlares": "moddlare",
    "moddlarna": "moddlare",
    "moddlarnas": "moddlare",
    "modds": "modd",
    "modeateljéer": "modeateljé",
    "modeateljéerna": "modeateljé",
    "modeateljéernas": "modeateljé",
    "modeateljéers": "modeateljé",
    "modeateljén": "modeateljé",
    "modeateljéns": "modeateljé",
    "modeateljés": "modeateljé",
    "modebutiken": "modebutik",
    "modebutikens": "modebutik",
    "modebutiker": "modebutik",
    "modebutikerna": "modebutik",
    "modebutikernas": "modebutik",
    "modebutikers": "modebutik",
    "modebutiks": "modebutik",
    "modedock": "modedocka",
    "modedockan": "modedocka",
    "modedockans": "modedocka",
    "modedockas": "modedocka",
    "modedocke": "modedocka",
    "modedockor": "modedocka",
    "modedockorna": "modedocka",
    "modedockornas": "modedocka",
    "modedockors": "modedocka",
    "modedocks": "modedocka",
    "modehusen": "modehus",
    "modehusens": "modehus",
    "modehuset": "modehus",
    "modehusets": "modehus",
    "modejournalen": "modejournal",
    "modejournalens": "modejournal",
    "modejournaler": "modejournal",
    "modejournalerna": "modejournal",
    "modejournalernas": "modejournal",
    "modejournalers": "modejournal",
    "modejournals": "modejournal",
    "modekarriären": "modekarriär",
    "modekarriärens": "modekarriär",
    "modekarriärer": "modekarriär",
    "modekarriärerna": "modekarriär",
    "modekarriärernas": "modekarriär",
    "modekarriärers": "modekarriär",
    "modekarriärs": "modekarriär",
    "modekedjan": "modekedja",
    "modekedjans": "modekedja",
    "modekedjas": "modekedja",
    "modekedje": "modekedja",
    "modekedjor": "modekedja",
    "modekedjorna": "modekedja",
    "modekedjornas": "modekedja",
    "modekedjors": "modekedja",
    "modelejonen": "modelejon",
    "modelejonens": "modelejon",
    "modelejonet": "modelejon",
    "modelejonets": "modelejon",
    "modelejons": "modelejon",
    "modelinjen": "modelinje",
    "modelinjens": "modelinje",
    "modelinjer": "modelinje",
    "modelinjerna": "modelinje",
    "modelinjernas": "modelinje",
    "modelinjers": "modelinje",
    "modelinjes": "modelinje",
    "modellberäkningar": "modellberäkning",
    "modellberäkningarna": "modellberäkning",
    "modellberäkningarnas": "modellberäkning",
    "modellberäkningars": "modellberäkning",
    "modellberäkningen": "modellberäkning",
    "modellberäkningens": "modellberäkning",
    "modellberäknings": "modellberäkning",
    "modellbyggen": "modellbygge",
    "modellbyggena": "modellbygge",
    "modellbyggenas": "modellbygge",
    "modellbyggens": "modellbygge",
    "modellbygges": "modellbygge",
    "modellbygget": "modellbygge",
    "modellbyggets": "modellbygge",
    "modellen": "modell",
    "modellens": "modell",
    "modeller": "modell",
    "modellerad": "modellera",
    "modellerade": "modellera",
    "modellerades": "modellera",
    "modellerads": "modellera",
    "modelleran": "modellera",
    "modellerande": "modellera",
    "modelleranden": "modellerande",
    "modellerandena": "modellerande",
    "modellerandenas": "modellerande",
    "modellerandens": "modellerande",
    "modellerandes": "modellerande",
    "modellerandet": "modellerande",
    "modellerandets": "modellerande",
    "modellerans": "modellera",
    "modellerar": "modellera",
    "modelleras": "modellera",
    "modellerat": "modellera",
    "modellerats": "modellera",
    "modellerbara": "modellerbar",
    "modellerbarare": "modellerbar",
    "modellerbarares": "modellerbar",
    "modellerbaras": "modellerbar",
    "modellerbarast": "modellerbar",
    "modellerbaraste": "modellerbar",
    "modellerbarastes": "modellerbar",
    "modellerbarasts": "modellerbar",
    "modellerbare": "modellerbar",
    "modellerbares": "modellerbar",
    "modellerbarheten": "modellerbarhet",
    "modellerbarhetens": "modellerbarhet",
    "modellerbarhets": "modellerbarhet",
    "modellerbars": "modellerbar",
    "modellerbart": "modellerbar",
    "modellerbarts": "modellerbar",
    "modelleringar": "modellering",
    "modelleringarna": "modellering",
    "modelleringarnas": "modellering",
    "modelleringars": "modellering",
    "modelleringen": "modellering",
    "modelleringens": "modellering",
    "modellerings": "modellering",
    "modellerna": "modell",
    "modellernas": "modell",
    "modellers": "modell",
    "modellflygplanen": "modellflygplan",
    "modellflygplanens": "modellflygplan",
    "modellflygplanet": "modellflygplan",
    "modellflygplanets": "modellflygplan",
    "modellflygplans": "modellflygplan",
    "modellförsöken": "modellförsök",
    "modellförsökens": "modellförsök",
    "modellförsöket": "modellförsök",
    "modellförsökets": "modellförsök",
    "modellförsöks": "modellförsök",
    "modelljärnvägar": "modelljärnväg",
    "modelljärnvägarna": "modelljärnväg",
    "modelljärnvägarnas": "modelljärnväg",
    "modelljärnvägars": "modelljärnväg",
    "modelljärnvägen": "modelljärnväg",
    "modelljärnvägens": "modelljärnväg",
    "modelljärnvägs": "modelljärnväg",
    "modells": "modell",
    "modellstudien": "modellstudie",
    "modellstudiens": "modellstudie",
    "modellstudier": "modellstudie",
    "modellstudierna": "modellstudie",
    "modellstudiernas": "modellstudie",
    "modellstudiers": "modellstudie",
    "modellstudies": "modellstudie",
    "modemen": "modem",
    "modemens": "modem",
    "modemet": "modem",
    "modemets": "modem",
    "modems": "modem",
    "modemässiga": "modemässig",
    "modemässigare": "modemässig",
    "modemässigares": "modemässig",
    "modemässigas": "modemässig",
    "modemässigast": "modemässig",
    "modemässigaste": "modemässig",
    "modemässigastes": "modemässig",
    "modemässigasts": "modemässig",
    "modemässige": "modemässig",
    "modemässiges": "modemässig",
    "modemässigs": "modemässig",
    "modemässigt": "modemässig",
    "modemässigts": "modemässig",
    "moden": "mode",
    "modena": "mode",
    "modenas": "mode",
    "modens": "mode",
    "modenycken": "modenyck",
    "modenyckens": "modenyck",
    "modenycker": "modenyck",
    "modenyckerna": "modenyck",
    "modenyckernas": "modenyck",
    "modenyckers": "modenyck",
    "modenycks": "modenyck",
    "modeorden": "modeord",
    "modeordens": "modeord",
    "modeordet": "modeord",
    "modeordets": "modeord",
    "modeords": "modeord",
    "moder": "mor",
    "moderata": "moderat",
    "moderatare": "moderat",
    "moderatares": "moderat",
    "moderatas": "moderat",
    "moderatast": "moderat",
    "moderataste": "moderat",
    "moderatastes": "moderat",
    "moderatasts": "moderat",
    "moderate": "moderat",
    "moderaten": "moderat",
    "moderatens": "moderat",
    "moderater": "moderat",
    "moderaterna": "moderat",
    "moderaternas": "moderat",
    "moderaters": "moderat",
    "moderates": "moderat",
    "moderationen": "moderation",
    "moderationens": "moderation",
    "moderationer": "moderation",
    "moderationerna": "moderation",
    "moderationernas": "moderation",
    "moderationers": "moderation",
    "moderations": "moderation",
    "moderatorer": "moderator",
    "moderatorerna": "moderator",
    "moderatorernas": "moderator",
    "moderatorers": "moderator",
    "moderatorn": "moderator",
    "moderatorns": "moderator",
    "moderators": "moderator",
    "moderatpolitikern": "moderatpolitiker",
    "moderatpolitikerna": "moderatpolitiker",
    "moderatpolitikernas": "moderatpolitiker",
    "moderatpolitikerns": "moderatpolitiker",
    "moderatpolitikers": "moderatpolitiker",
    "moderats": "moderat",
    "moderbolagen": "moderbolag",
    "moderbolagens": "moderbolag",
    "moderbolaget": "moderbolag",
    "moderbolagets": "moderbolag",
    "moderbolags": "moderbolag",
    "modercellen": "modercell",
    "modercellens": "modercell",
    "moderceller": "modercell",
    "modercellerna": "modercell",
    "modercellernas": "modercell",
    "modercellers": "modercell",
    "modercells": "modercell",
    "modererad": "moderera",
    "modererade": "moderera",
    "modererades": "moderera",
    "modererads": "moderera",
    "modererande": "moderera",
    "modereranden": "modererande",
    "modererandena": "modererande",
    "modererandenas": "modererande",
    "modererandens": "modererande",
    "modererandes": "modererande",
    "modererandet": "modererande",
    "modererandets": "modererande",
    "modererar": "moderera",
    "modereras": "moderera",
    "modererat": "moderera",
    "modererats": "moderera",
    "modererbara": "modererbar",
    "modererbarare": "modererbar",
    "modererbarares": "modererbar",
    "modererbaras": "modererbar",
    "modererbarast": "modererbar",
    "modererbaraste": "modererbar",
    "modererbarastes": "modererbar",
    "modererbarasts": "modererbar",
    "modererbare": "modererbar",
    "modererbares": "modererbar",
    "modererbarheten": "modererbarhet",
    "modererbarhetens": "modererbarhet",
    "modererbarhets": "modererbarhet",
    "modererbars": "modererbar",
    "modererbart": "modererbar",
    "modererbarts": "modererbar",
    "modereringar": "moderering",
    "modereringarna": "moderering",
    "modereringarnas": "moderering",
    "modereringars": "moderering",
    "modereringen": "moderering",
    "modereringens": "moderering",
    "modererings": "moderering",
    "moderföretagen": "moderföretag",
    "moderföretagens": "moderföretag",
    "moderföretaget": "moderföretag",
    "moderföretagets": "moderföretag",
    "moderföretags": "moderföretag",
    "moderiktiga": "moderiktig",
    "moderiktigare": "moderiktig",
    "moderiktigares": "moderiktig",
    "moderiktigas": "moderiktig",
    "moderiktigast": "moderiktig",
    "moderiktigaste": "moderiktig",
    "moderiktigastes": "moderiktig",
    "moderiktigasts": "moderiktig",
    "moderiktige": "moderiktig",
    "moderiktiges": "moderiktig",
    "moderiktigheten": "moderiktighet",
    "moderiktighetens": "moderiktighet",
    "moderiktighets": "moderiktighet",
    "moderiktigs": "moderiktig",
    "moderiktigt": "moderiktig",
    "moderiktigts": "moderiktig",
    "moderkak": "moderkaka",
    "moderkakan": "moderkaka",
    "moderkakans": "moderkaka",
    "moderkakas": "moderkaka",
    "moderkake": "moderkaka",
    "moderkakor": "moderkaka",
    "moderkakorna": "moderkaka",
    "moderkakornas": "moderkaka",
    "moderkakors": "moderkaka",
    "moderkaks": "moderkaka",
    "moderlandet": "moderland",
    "moderlandets": "moderland",
    "moderlands": "moderland",
    "moderliga": "moderlig",
    "moderligare": "moderlig",
    "moderligares": "moderlig",
    "moderligas": "moderlig",
    "moderligast": "moderlig",
    "moderligaste": "moderlig",
    "moderligastes": "moderlig",
    "moderligasts": "moderlig",
    "moderlige": "moderlig",
    "moderliges": "moderlig",
    "moderligheten": "moderlighet",
    "moderlighetens": "moderlighet",
    "moderlighets": "moderlighet",
    "moderligs": "moderlig",
    "moderligt": "moderlig",
    "moderligts": "moderlig",
    "moderliven": "moderliv",
    "moderlivens": "moderliv",
    "moderlivet": "moderliv",
    "moderlivets": "moderliv",
    "moderlivs": "moderliv",
    "moderlutar": "moderlut",
    "moderlutarna": "moderlut",
    "moderlutarnas": "moderlut",
    "moderlutars": "moderlut",
    "moderluten": "moderlut",
    "moderlutens": "moderlut",
    "moderluts": "moderlut",
    "moderländer": "moderland",
    "moderländerna": "moderland",
    "moderländernas": "moderland",
    "moderländers": "moderland",
    "modermunnar": "modermun",
    "modermunnarna": "modermun",
    "modermunnarnas": "modermun",
    "modermunnars": "modermun",
    "modermunnen": "modermun",
    "modermunnens": "modermun",
    "modermuns": "modermun",
    "modern": "mor",
    "moderna": "modern",
    "modernare": "modern",
    "modernares": "modern",
    "modernas": "modern",
    "modernast": "modern",
    "modernaste": "modern",
    "modernastes": "modern",
    "modernasts": "modern",
    "moderne": "modern",
    "modernes": "modern",
    "moderniserad": "modernisera",
    "moderniserade": "modernisera",
    "moderniserades": "modernisera",
    "moderniserads": "modernisera",
    "moderniserande": "modernisera",
    "moderniseranden": "moderniserande",
    "moderniserandena": "moderniserande",
    "moderniserandenas": "moderniserande",
    "moderniserandens": "moderniserande",
    "moderniserandes": "moderniserande",
    "moderniserandet": "moderniserande",
    "moderniserandets": "moderniserande",
    "moderniserar": "modernisera",
    "moderniseras": "modernisera",
    "moderniserat": "modernisera",
    "moderniserats": "modernisera",
    "moderniserbara": "moderniserbar",
    "moderniserbarare": "moderniserbar",
    "moderniserbarares": "moderniserbar",
    "moderniserbaras": "moderniserbar",
    "moderniserbarast": "moderniserbar",
    "moderniserbaraste": "moderniserbar",
    "moderniserbarastes": "moderniserbar",
    "moderniserbarasts": "moderniserbar",
    "moderniserbare": "moderniserbar",
    "moderniserbares": "moderniserbar",
    "moderniserbarheten": "moderniserbarhet",
    "moderniserbarhetens": "moderniserbarhet",
    "moderniserbarhets": "moderniserbarhet",
    "moderniserbars": "moderniserbar",
    "moderniserbart": "moderniserbar",
    "moderniserbarts": "moderniserbar",
    "moderniseringar": "modernisering",
    "moderniseringarna": "modernisering",
    "moderniseringarnas": "modernisering",
    "moderniseringars": "modernisering",
    "moderniseringen": "modernisering",
    "moderniseringens": "modernisering",
    "moderniserings": "modernisering",
    "moderniseringsprogrammen": "moderniseringsprogram",
    "moderniseringsprogrammens": "moderniseringsprogram",
    "moderniseringsprogrammet": "moderniseringsprogram",
    "moderniseringsprogrammets": "moderniseringsprogram",
    "moderniseringsprograms": "moderniseringsprogram",
    "moderniseringsreformen": "moderniseringsreform",
    "moderniseringsreformens": "moderniseringsreform",
    "moderniseringsreformer": "moderniseringsreform",
    "moderniseringsreformerna": "moderniseringsreform",
    "moderniseringsreformernas": "moderniseringsreform",
    "moderniseringsreformers": "moderniseringsreform",
    "moderniseringsreforms": "moderniseringsreform",
    "modernismen": "modernism",
    "modernismens": "modernism",
    "modernismer": "modernism",
    "modernismerna": "modernism",
    "modernismernas": "modernism",
    "modernismers": "modernism",
    "modernisms": "modernism",
    "modernisten": "modernist",
    "modernistens": "modernist",
    "modernister": "modernist",
    "modernisterna": "modernist",
    "modernisternas": "modernist",
    "modernisters": "modernist",
    "modernistiska": "modernistisk",
    "modernistiskare": "modernistisk",
    "modernistiskares": "modernistisk",
    "modernistiskas": "modernistisk",
    "modernistiskast": "modernistisk",
    "modernistiskaste": "modernistisk",
    "modernistiskastes": "modernistisk",
    "modernistiskasts": "modernistisk",
    "modernistiske": "modernistisk",
    "modernistiskes": "modernistisk",
    "modernistisks": "modernistisk",
    "modernistiskt": "modernistisk",
    "modernistiskts": "modernistisk",
    "modernists": "modernist",
    "moderniteten": "modernitet",
    "modernitetens": "modernitet",
    "moderniteter": "modernitet",
    "moderniteterna": "modernitet",
    "moderniteternas": "modernitet",
    "moderniteters": "modernitet",
    "modernitets": "modernitet",
    "moderns": "mor",
    "modernt": "modern",
    "modernts": "modern",
    "modernäringar": "modernäring",
    "modernäringarna": "modernäring",
    "modernäringarnas": "modernäring",
    "modernäringars": "modernäring",
    "modernäringen": "modernäring",
    "modernäringens": "modernäring",
    "modernärings": "modernäring",
    "moderrätten": "moderrätt",
    "moderrättens": "moderrätt",
    "moderrätts": "moderrätt",
    "moders": "mor",
    "modersfamnar": "modersfamn",
    "modersfamnarna": "modersfamn",
    "modersfamnarnas": "modersfamn",
    "modersfamnars": "modersfamn",
    "modersfamnen": "modersfamn",
    "modersfamnens": "modersfamn",
    "modersfamns": "modersfamn",
    "modersgestalten": "modersgestalt",
    "modersgestaltens": "modersgestalt",
    "modersgestalter": "modersgestalt",
    "modersgestalterna": "modersgestalt",
    "modersgestalternas": "modersgestalt",
    "modersgestalters": "modersgestalt",
    "modersgestalts": "modersgestalt",
    "modershjärt": "modershjärta",
    "modershjärtan": "modershjärta",
    "modershjärtana": "modershjärta",
    "modershjärtanas": "modershjärta",
    "modershjärtans": "modershjärta",
    "modershjärtas": "modershjärta",
    "modershjärtat": "modershjärta",
    "modershjärtats": "modershjärta",
    "modershjärts": "modershjärta",
    "moderskapet": "moderskap",
    "moderskapets": "moderskap",
    "moderskaps": "moderskap",
    "modersmjölken": "modersmjölk",
    "modersmjölkens": "modersmjölk",
    "modersmjölks": "modersmjölk",
    "modersmålen": "modersmål",
    "modersmålens": "modersmål",
    "modersmålet": "modersmål",
    "modersmålets": "modersmål",
    "modersmåls": "modersmål",
    "moderssköten": "moderssköte",
    "modersskötena": "moderssköte",
    "modersskötenas": "moderssköte",
    "modersskötens": "moderssköte",
    "modersskötes": "moderssköte",
    "modersskötet": "moderssköte",
    "modersskötets": "moderssköte",
    "moderstjärnan": "moderstjärna",
    "moderstjärnans": "moderstjärna",
    "moderstjärnas": "moderstjärna",
    "moderstjärne": "moderstjärna",
    "moderstjärnor": "moderstjärna",
    "moderstjärnorna": "moderstjärna",
    "moderstjärnornas": "moderstjärna",
    "moderstjärnors": "moderstjärna",
    "modes": "mode",
    "modeskapar": "modeskapare",
    "modeskaparen": "modeskapare",
    "modeskaparens": "modeskapare",
    "modeskapares": "modeskapare",
    "modeskaparna": "modeskapare",
    "modeskaparnas": "modeskapare",
    "modesta": "modest",
    "modestare": "modest",
    "modestares": "modest",
    "modestas": "modest",
    "modestast": "modest",
    "modestaste": "modest",
    "modestastes": "modest",
    "modestasts": "modest",
    "modeste": "modest",
    "modestes": "modest",
    "modestheten": "modesthet",
    "modesthetens": "modesthet",
    "modesthets": "modesthet",
    "modests": "modest",
    "modet": "mode",
    "modets": "mode",
    "modevisningar": "modevisning",
    "modevisningarna": "modevisning",
    "modevisningarnas": "modevisning",
    "modevisningars": "modevisning",
    "modevisningen": "modevisning",
    "modevisningens": "modevisning",
    "modevisnings": "modevisning",
    "modevärlden": "modevärld",
    "modevärldens": "modevärld",
    "modevärlds": "modevärld",
    "modfällda": "modfälld",
    "modfälldare": "modfälld",
    "modfälldares": "modfälld",
    "modfälldas": "modfälld",
    "modfälldast": "modfälld",
    "modfälldaste": "modfälld",
    "modfälldastes": "modfälld",
    "modfälldasts": "modfälld",
    "modfällde": "modfälld",
    "modfälldes": "modfälld",
    "modfälldheten": "modfälldhet",
    "modfälldhetens": "modfälldhet",
    "modfälldhets": "modfälldhet",
    "modfällds": "modfälld",
    "modfällt": "modfälld",
    "modfällts": "modfälld",
    "modifierad": "modifiera",
    "modifierade": "modifiera",
    "modifierades": "modifiera",
    "modifierads": "modifiera",
    "modifierande": "modifiera",
    "modifieranden": "modifierande",
    "modifierandena": "modifierande",
    "modifierandenas": "modifierande",
    "modifierandens": "modifierande",
    "modifierandes": "modifierande",
    "modifierandet": "modifierande",
    "modifierandets": "modifierande",
    "modifierar": "modifiera",
    "modifieras": "modifiera",
    "modifierat": "modifiera",
    "modifierats": "modifiera",
    "modifierbara": "modifierbar",
    "modifierbarare": "modifierbar",
    "modifierbarares": "modifierbar",
    "modifierbaras": "modifierbar",
    "modifierbarast": "modifierbar",
    "modifierbaraste": "modifierbar",
    "modifierbarastes": "modifierbar",
    "modifierbarasts": "modifierbar",
    "modifierbare": "modifierbar",
    "modifierbares": "modifierbar",
    "modifierbarheten": "modifierbarhet",
    "modifierbarhetens": "modifierbarhet",
    "modifierbarhets": "modifierbarhet",
    "modifierbars": "modifierbar",
    "modifierbart": "modifierbar",
    "modifierbarts": "modifierbar",
    "modifieringar": "modifiering",
    "modifieringarna": "modifiering",
    "modifieringarnas": "modifiering",
    "modifieringars": "modifiering",
    "modifieringen": "modifiering",
    "modifieringens": "modifiering",
    "modifierings": "modifiering",
    "modifikationen": "modifikation",
    "modifikationens": "modifikation",
    "modifikationer": "modifikation",
    "modifikationerna": "modifikation",
    "modifikationernas": "modifikation",
    "modifikationers": "modifikation",
    "modifikations": "modifikation",
    "modiga": "modig",
    "modigare": "modig",
    "modigares": "modig",
    "modigas": "modig",
    "modigast": "modig",
    "modigaste": "modig",
    "modigastes": "modig",
    "modigasts": "modig",
    "modige": "modig",
    "modiges": "modig",
    "modigs": "modig",
    "modigt": "modig",
    "modigts": "modig",
    "modisten": "modist",
    "modistens": "modist",
    "modister": "modist",
    "modisterna": "modist",
    "modisternas": "modist",
    "modisters": "modist",
    "modists": "modist",
    "modlösa": "modlös",
    "modlösare": "modlös",
    "modlösares": "modlös",
    "modlösas": "modlös",
    "modlösast": "modlös",
    "modlösaste": "modlös",
    "modlösastes": "modlös",
    "modlösasts": "modlös",
    "modlöse": "modlös",
    "modlöses": "modlös",
    "modlösheten": "modlöshet",
    "modlöshetens": "modlöshet",
    "modlöshets": "modlöshet",
    "modlöst": "modlös",
    "modlösts": "modlös",
    "mods": "mode",
    "modsen": "mods",
    "modsens": "mods",
    "modset": "mods",
    "modsets": "mods",
    "modstulenheten": "modstulenhet",
    "modstulenhetens": "modstulenhet",
    "modstulenhets": "modstulenhet",
    "modstulens": "modstulen",
    "modstulet": "modstulen",
    "modstulets": "modstulen",
    "modstulna": "modstulen",
    "modstulnare": "modstulen",
    "modstulnares": "modstulen",
    "modstulnas": "modstulen",
    "modstulnast": "modstulen",
    "modstulnaste": "modstulen",
    "modstulnastes": "modstulen",
    "modstulnasts": "modstulen",
    "modstulne": "modstulen",
    "modstulnes": "modstulen",
    "modulationen": "modulation",
    "modulationens": "modulation",
    "modulationer": "modulation",
    "modulationerna": "modulation",
    "modulationernas": "modulation",
    "modulationers": "modulation",
    "modulations": "modulation",
    "modulatorer": "modulator",
    "modulatorerna": "modulator",
    "modulatorernas": "modulator",
    "modulatorers": "modulator",
    "modulatorn": "modulator",
    "modulatorns": "modulator",
    "modulators": "modulator",
    "modulen": "modul",
    "modulens": "modul",
    "moduler": "modul",
    "modulerad": "modulera",
    "modulerade": "modulera",
    "modulerades": "modulera",
    "modulerads": "modulera",
    "modulerande": "modulera",
    "moduleranden": "modulerande",
    "modulerandena": "modulerande",
    "modulerandenas": "modulerande",
    "modulerandens": "modulerande",
    "modulerandes": "modulerande",
    "modulerandet": "modulerande",
    "modulerandets": "modulerande",
    "modulerar": "modulera",
    "moduleras": "modulera",
    "modulerat": "modulera",
    "modulerats": "modulera",
    "modulerbara": "modulerbar",
    "modulerbarare": "modulerbar",
    "modulerbarares": "modulerbar",
    "modulerbaras": "modulerbar",
    "modulerbarast": "modulerbar",
    "modulerbaraste": "modulerbar",
    "modulerbarastes": "modulerbar",
    "modulerbarasts": "modulerbar",
    "modulerbare": "modulerbar",
    "modulerbares": "modulerbar",
    "modulerbarheten": "modulerbarhet",
    "modulerbarhetens": "modulerbarhet",
    "modulerbarhets": "modulerbarhet",
    "modulerbars": "modulerbar",
    "modulerbart": "modulerbar",
    "modulerbarts": "modulerbar",
    "moduleringar": "modulering",
    "moduleringarna": "modulering",
    "moduleringarnas": "modulering",
    "moduleringars": "modulering",
    "moduleringen": "modulering",
    "moduleringens": "modulering",
    "modulerings": "modulering",
    "modulerna": "modul",
    "modulernas": "modul",
    "modulers": "modul",
    "moduls": "modul",
    "modulsystemen": "modulsystem",
    "modulsystemens": "modulsystem",
    "modulsystemet": "modulsystem",
    "modulsystemets": "modulsystem",
    "modulsystems": "modulsystem",
    "modusen": "modus",
    "modusens": "modus",
    "moduset": "modus",
    "modusets": "modus",
    "modärna": "modärn",
    "modärnare": "modärn",
    "modärnares": "modärn",
    "modärnas": "modärn",
    "modärnast": "modärn",
    "modärnaste": "modärn",
    "modärnastes": "modärn",
    "modärnasts": "modärn",
    "modärne": "modärn",
    "modärnes": "modärn",
    "modärniserad": "modärnisera",
    "modärniserade": "modärnisera",
    "modärniserades": "modärnisera",
    "modärniserads": "modärnisera",
    "modärniserande": "modärnisera",
    "modärniseranden": "modärniserande",
    "modärniserandena": "modärniserande",
    "modärniserandenas": "modärniserande",
    "modärniserandens": "modärniserande",
    "modärniserandes": "modärniserande",
    "modärniserandet": "modärniserande",
    "modärniserandets": "modärniserande",
    "modärniserar": "modärnisera",
    "modärniseras": "modärnisera",
    "modärniserat": "modärnisera",
    "modärniserats": "modärnisera",
    "modärniserbara": "modärniserbar",
    "modärniserbarare": "modärniserbar",
    "modärniserbarares": "modärniserbar",
    "modärniserbaras": "modärniserbar",
    "modärniserbarast": "modärniserbar",
    "modärniserbaraste": "modärniserbar",
    "modärniserbarastes": "modärniserbar",
    "modärniserbarasts": "modärniserbar",
    "modärniserbare": "modärniserbar",
    "modärniserbares": "modärniserbar",
    "modärniserbarheten": "modärniserbarhet",
    "modärniserbarhetens": "modärniserbarhet",
    "modärniserbarhets": "modärniserbarhet",
    "modärniserbars": "modärniserbar",
    "modärniserbart": "modärniserbar",
    "modärniserbarts": "modärniserbar",
    "modärniseringar": "modärnisering",
    "modärniseringarna": "modärnisering",
    "modärniseringarnas": "modärnisering",
    "modärniseringars": "modärnisering",
    "modärniseringen": "modärnisering",
    "modärniseringens": "modärnisering",
    "modärniserings": "modärnisering",
    "modärns": "modärn",
    "modärnt": "modärn",
    "modärnts": "modärn",
    "mogenheten": "mogenhet",
    "mogenhetens": "mogenhet",
    "mogenheter": "mogenhet",
    "mogenheterna": "mogenhet",
    "mogenheternas": "mogenhet",
    "mogenheters": "mogenhet",
    "mogenhets": "mogenhet",
    "mogenhetsexamens": "mogenhetsexamen",
    "mogenhetsexamina": "mogenhetsexamen",
    "mogenhetsexaminas": "mogenhetsexamen",
    "mogens": "mogen",
    "moget": "mogen",
    "mogets": "mogen",
    "mogna": "mogen",
    "mognade": "mogna",
    "mognaden": "mognad",
    "mognadens": "mognad",
    "mognader": "mognad",
    "mognaderna": "mognad",
    "mognadernas": "mognad",
    "mognaders": "mognad",
    "mognades": "mogna",
    "mognads": "mognad",
    "mognande": "mogna",
    "mognanden": "mognande",
    "mognandena": "mognande",
    "mognandenas": "mognande",
    "mognandens": "mognande",
    "mognandes": "mognande",
    "mognandet": "mognande",
    "mognandets": "mognande",
    "mognar": "mogna",
    "mognare": "mogen",
    "mognares": "mogen",
    "mognas": "mogna",
    "mognast": "mogen",
    "mognaste": "mogen",
    "mognastes": "mogen",
    "mognasts": "mogen",
    "mognat": "mogna",
    "mognats": "mogna",
    "mogne": "mogen",
    "mognes": "mogen",
    "moguler": "mogul",
    "mogulerna": "mogul",
    "mogulernas": "mogul",
    "mogulers": "mogul",
    "moguln": "mogul",
    "mogulns": "mogul",
    "moguls": "mogul",
    "mohairen": "mohair",
    "mohairens": "mohair",
    "mohairs": "mohair",
    "mohammedanen": "mohammedan",
    "mohammedanens": "mohammedan",
    "mohammedaner": "mohammedan",
    "mohammedanerna": "mohammedan",
    "mohammedanernas": "mohammedan",
    "mohammedaners": "mohammedan",
    "mohammedanismen": "mohammedanism",
    "mohammedanismens": "mohammedanism",
    "mohammedanismer": "mohammedanism",
    "mohammedanismerna": "mohammedanism",
    "mohammedanismernas": "mohammedanism",
    "mohammedanismers": "mohammedanism",
    "mohammedanisms": "mohammedanism",
    "mohammedans": "mohammedan",
    "mohammedanska": "mohammedansk",
    "mohammedanskare": "mohammedansk",
    "mohammedanskares": "mohammedansk",
    "mohammedanskas": "mohammedansk",
    "mohammedanskast": "mohammedansk",
    "mohammedanskaste": "mohammedansk",
    "mohammedanskastes": "mohammedansk",
    "mohammedanskasts": "mohammedansk",
    "mohammedanske": "mohammedansk",
    "mohammedanskes": "mohammedansk",
    "mohammedansks": "mohammedansk",
    "mohammedanskt": "mohammedansk",
    "mohammedanskts": "mohammedansk",
    "mohikanen": "mohikan",
    "mohikanens": "mohikan",
    "mohikaner": "mohikan",
    "mohikanerna": "mohikan",
    "mohikanernas": "mohikan",
    "mohikaners": "mohikan",
    "mohikans": "mohikan",
    "mohären": "mohär",
    "mohärens": "mohär",
    "mohärs": "mohär",
    "moja": "moj",
    "mojar": "moj",
    "mojare": "moj",
    "mojares": "moj",
    "mojarna": "moj",
    "mojarnas": "moj",
    "mojars": "moj",
    "mojas": "moj",
    "mojast": "moj",
    "mojaste": "moj",
    "mojastes": "moj",
    "mojasts": "moj",
    "moje": "moj",
    "mojen": "moj",
    "mojens": "moj",
    "mojes": "moj",
    "mojet": "moj",
    "mojets": "moj",
    "mojheten": "mojhet",
    "mojhetens": "mojhet",
    "mojhets": "mojhet",
    "mojnade": "mojna",
    "mojnades": "mojna",
    "mojnande": "mojna",
    "mojnanden": "mojnande",
    "mojnandena": "mojnande",
    "mojnandenas": "mojnande",
    "mojnandens": "mojnande",
    "mojnandes": "mojnande",
    "mojnandet": "mojnande",
    "mojnandets": "mojnande",
    "mojnar": "mojna",
    "mojnas": "mojna",
    "mojnat": "mojna",
    "mojnats": "mojna",
    "mojs": "moj",
    "mojt": "moj",
    "mojts": "moj",
    "mojängen": "mojäng",
    "mojängens": "mojäng",
    "mojänger": "mojäng",
    "mojängerna": "mojäng",
    "mojängernas": "mojäng",
    "mojängers": "mojäng",
    "mojängs": "mojäng",
    "mokar": "mokare",
    "mokaren": "mokare",
    "mokarens": "mokare",
    "mokares": "mokare",
    "mokarna": "mokare",
    "mokarnas": "mokare",
    "mol": "mola",
    "molade": "mola",
    "molades": "mola",
    "molande": "mola",
    "molanden": "molande",
    "molandena": "molande",
    "molandenas": "molande",
    "molandens": "molande",
    "molandes": "molande",
    "molandet": "molande",
    "molandets": "molande",
    "molar": "mola",
    "molaren": "molar",
    "molarens": "molar",
    "molarer": "molar",
    "molarerna": "molar",
    "molarernas": "molar",
    "molarers": "molar",
    "molariteten": "molaritet",
    "molaritetens": "molaritet",
    "molariteter": "molaritet",
    "molariteterna": "molaritet",
    "molariteternas": "molaritet",
    "molariteters": "molaritet",
    "molaritets": "molaritet",
    "molars": "molar",
    "molas": "mola",
    "molat": "mola",
    "molats": "mola",
    "moldaviern": "moldavier",
    "moldavierna": "moldavier",
    "moldaviernas": "moldavier",
    "moldavierns": "moldavier",
    "moldaviers": "moldavier",
    "moldavisk": "moldaviska",
    "moldaviska": "moldavisk",
    "moldaviskan": "moldaviska",
    "moldaviskans": "moldaviska",
    "moldaviskare": "moldavisk",
    "moldaviskares": "moldavisk",
    "moldaviskas": "moldaviska",
    "moldaviskast": "moldavisk",
    "moldaviskaste": "moldavisk",
    "moldaviskastes": "moldavisk",
    "moldaviskasts": "moldavisk",
    "moldaviske": "moldaviska",
    "moldaviskes": "moldavisk",
    "moldaviskor": "moldaviska",
    "moldaviskorna": "moldaviska",
    "moldaviskornas": "moldaviska",
    "moldaviskors": "moldaviska",
    "moldavisks": "moldavisk",
    "moldaviskt": "moldavisk",
    "moldaviskts": "moldavisk",
    "molekylarattraktionen": "molekylarattraktion",
    "molekylarattraktionens": "molekylarattraktion",
    "molekylarattraktioner": "molekylarattraktion",
    "molekylarattraktionerna": "molekylarattraktion",
    "molekylarattraktionernas": "molekylarattraktion",
    "molekylarattraktioners": "molekylarattraktion",
    "molekylarattraktions": "molekylarattraktion",
    "molekylarkraften": "molekylarkraft",
    "molekylarkraftens": "molekylarkraft",
    "molekylarkrafter": "molekylarkraft",
    "molekylarkrafterna": "molekylarkraft",
    "molekylarkrafternas": "molekylarkraft",
    "molekylarkrafters": "molekylarkraft",
    "molekylarkrafts": "molekylarkraft",
    "molekylen": "molekyl",
    "molekylens": "molekyl",
    "molekyler": "molekyl",
    "molekylerna": "molekyl",
    "molekylernas": "molekyl",
    "molekylers": "molekyl",
    "molekylkedjan": "molekylkedja",
    "molekylkedjans": "molekylkedja",
    "molekylkedjas": "molekylkedja",
    "molekylkedje": "molekylkedja",
    "molekylkedjor": "molekylkedja",
    "molekylkedjorna": "molekylkedja",
    "molekylkedjornas": "molekylkedja",
    "molekylkedjors": "molekylkedja",
    "molekyls": "molekyl",
    "molekylvikten": "molekylvikt",
    "molekylviktens": "molekylvikt",
    "molekylvikter": "molekylvikt",
    "molekylvikterna": "molekylvikt",
    "molekylvikternas": "molekylvikt",
    "molekylvikters": "molekylvikt",
    "molekylvikts": "molekylvikt",
    "molekylära": "molekylär",
    "molekylärare": "molekylär",
    "molekylärares": "molekylär",
    "molekyläras": "molekylär",
    "molekylärast": "molekylär",
    "molekyläraste": "molekylär",
    "molekylärastes": "molekylär",
    "molekylärasts": "molekylär",
    "molekylärbiologen": "molekylärbiolog",
    "molekylärbiologens": "molekylärbiolog",
    "molekylärbiologer": "molekylärbiolog",
    "molekylärbiologerna": "molekylärbiolog",
    "molekylärbiologernas": "molekylärbiolog",
    "molekylärbiologers": "molekylärbiolog",
    "molekylärbiologien": "molekylärbiologi",
    "molekylärbiologiens": "molekylärbiologi",
    "molekylärbiologin": "molekylärbiologi",
    "molekylärbiologins": "molekylärbiologi",
    "molekylärbiologis": "molekylärbiologi",
    "molekylärbiologs": "molekylärbiolog",
    "molekyläre": "molekylär",
    "molekyläres": "molekylär",
    "molekylärs": "molekylär",
    "molekylärt": "molekylär",
    "molekylärts": "molekylär",
    "molen": "mol",
    "molens": "mol",
    "mollen": "moll",
    "mollens": "moll",
    "molls": "moll",
    "mollskinnet": "mollskinn",
    "mollskinnets": "mollskinn",
    "mollskinns": "mollskinn",
    "mollstämda": "mollstämd",
    "mollstämdare": "mollstämd",
    "mollstämdares": "mollstämd",
    "mollstämdas": "mollstämd",
    "mollstämdast": "mollstämd",
    "mollstämdaste": "mollstämd",
    "mollstämdastes": "mollstämd",
    "mollstämdasts": "mollstämd",
    "mollstämde": "mollstämd",
    "mollstämdes": "mollstämd",
    "mollstämdheten": "mollstämdhet",
    "mollstämdhetens": "mollstämdhet",
    "mollstämdhets": "mollstämdhet",
    "mollstämds": "mollstämd",
    "mollstämt": "mollstämd",
    "mollstämts": "mollstämd",
    "mollusken": "mollusk",
    "molluskens": "mollusk",
    "mollusker": "mollusk",
    "molluskerna": "mollusk",
    "molluskernas": "mollusk",
    "molluskers": "mollusk",
    "mollusks": "mollusk",
    "molnbankar": "molnbank",
    "molnbankarna": "molnbank",
    "molnbankarnas": "molnbank",
    "molnbankars": "molnbank",
    "molnbanken": "molnbank",
    "molnbankens": "molnbank",
    "molnbanks": "molnbank",
    "molnbildningar": "molnbildning",
    "molnbildningarna": "molnbildning",
    "molnbildningarnas": "molnbildning",
    "molnbildningars": "molnbildning",
    "molnbildningen": "molnbildning",
    "molnbildningens": "molnbildning",
    "molnbildnings": "molnbildning",
    "molnen": "moln",
    "molnens": "moln",
    "molnet": "moln",
    "molnets": "moln",
    "molnfria": "molnfri",
    "molnfriare": "molnfri",
    "molnfriares": "molnfri",
    "molnfrias": "molnfri",
    "molnfriast": "molnfri",
    "molnfriaste": "molnfri",
    "molnfriastes": "molnfri",
    "molnfriasts": "molnfri",
    "molnfrie": "molnfri",
    "molnfries": "molnfri",
    "molnfris": "molnfri",
    "molnfritt": "molnfri",
    "molnfritts": "molnfri",
    "molngubb": "molngubbe",
    "molngubbar": "molngubbe",
    "molngubbarna": "molngubbe",
    "molngubbarnas": "molngubbe",
    "molngubbars": "molngubbe",
    "molngubben": "molngubbe",
    "molngubbens": "molngubbe",
    "molngubbes": "molngubbe",
    "molngubbs": "molngubbe",
    "molnhopar": "molnhop",
    "molnhoparna": "molnhop",
    "molnhoparnas": "molnhop",
    "molnhopars": "molnhop",
    "molnhopen": "molnhop",
    "molnhopens": "molnhop",
    "molnhops": "molnhop",
    "molnhöjden": "molnhöjd",
    "molnhöjdens": "molnhöjd",
    "molnhöjder": "molnhöjd",
    "molnhöjderna": "molnhöjd",
    "molnhöjdernas": "molnhöjd",
    "molnhöjders": "molnhöjd",
    "molnhöjds": "molnhöjd",
    "molniga": "molnig",
    "molnigare": "molnig",
    "molnigares": "molnig",
    "molnigas": "molnig",
    "molnigast": "molnig",
    "molnigaste": "molnig",
    "molnigastes": "molnig",
    "molnigasts": "molnig",
    "molnige": "molnig",
    "molniges": "molnig",
    "molnigheten": "molnighet",
    "molnighetens": "molnighet",
    "molnigheter": "molnighet",
    "molnigheterna": "molnighet",
    "molnigheternas": "molnighet",
    "molnigheters": "molnighet",
    "molnighets": "molnighet",
    "molnigs": "molnig",
    "molnigt": "molnig",
    "molnigts": "molnig",
    "molnkanten": "molnkant",
    "molnkantens": "molnkant",
    "molnkanter": "molnkant",
    "molnkanterna": "molnkant",
    "molnkanternas": "molnkant",
    "molnkanters": "molnkant",
    "molnkants": "molnkant",
    "molnmassan": "molnmassa",
    "molnmassans": "molnmassa",
    "molnmassas": "molnmassa",
    "molnmasse": "molnmassa",
    "molnmassor": "molnmassa",
    "molnmassorna": "molnmassa",
    "molnmassornas": "molnmassa",
    "molnmassors": "molnmassa",
    "molnresten": "molnrest",
    "molnrestens": "molnrest",
    "molnrester": "molnrest",
    "molnresterna": "molnrest",
    "molnresternas": "molnrest",
    "molnresters": "molnrest",
    "molnrests": "molnrest",
    "molns": "moln",
    "molnstoden": "molnstod",
    "molnstodens": "molnstod",
    "molnstoder": "molnstod",
    "molnstoderna": "molnstod",
    "molnstodernas": "molnstod",
    "molnstoders": "molnstod",
    "molnstods": "molnstod",
    "molntappar": "molntapp",
    "molntapparna": "molntapp",
    "molntapparnas": "molntapp",
    "molntappars": "molntapp",
    "molntappen": "molntapp",
    "molntappens": "molntapp",
    "molntapps": "molntapp",
    "molntäcken": "molntäcke",
    "molntäckena": "molntäcke",
    "molntäckenas": "molntäcke",
    "molntäckens": "molntäcke",
    "molntäckes": "molntäcke",
    "molntäcket": "molntäcke",
    "molntäckets": "molntäcke",
    "molntäcks": "molntäcke",
    "moloer": "molo",
    "moloerna": "molo",
    "moloernas": "molo",
    "moloers": "molo",
    "molohamnar": "molohamn",
    "molohamnarna": "molohamn",
    "molohamnarnas": "molohamn",
    "molohamnars": "molohamn",
    "molohamnen": "molohamn",
    "molohamnens": "molohamn",
    "molohamns": "molohamn",
    "moloken": "molok",
    "molokenheten": "molokenhet",
    "molokenhetens": "molokenhet",
    "molokenhets": "molokenhet",
    "molokens": "moloken",
    "moloket": "moloken",
    "molokets": "moloken",
    "molokna": "moloken",
    "moloknare": "moloken",
    "moloknares": "moloken",
    "moloknas": "moloken",
    "moloknast": "moloken",
    "moloknaste": "moloken",
    "moloknastes": "moloken",
    "moloknasts": "moloken",
    "molokne": "moloken",
    "moloknes": "moloken",
    "moloks": "molok",
    "molon": "molo",
    "molons": "molo",
    "molor": "molo",
    "molorna": "molo",
    "molornas": "molo",
    "molors": "molo",
    "molos": "molo",
    "mols": "mol",
    "molteg": "moltiga",
    "moltegs": "moltiga",
    "moltig": "moltiga",
    "moltigande": "moltiga",
    "moltiganden": "moltigande",
    "moltigandena": "moltigande",
    "moltigandenas": "moltigande",
    "moltigandens": "moltigande",
    "moltigandes": "moltigande",
    "moltigandet": "moltigande",
    "moltigandets": "moltigande",
    "moltigas": "moltiga",
    "moltige": "moltiga",
    "moltiger": "moltiga",
    "moltiges": "moltiga",
    "moltigit": "moltiga",
    "moltigits": "moltiga",
    "moltigs": "moltiga",
    "moltysta": "moltyst",
    "moltystare": "moltyst",
    "moltystares": "moltyst",
    "moltystas": "moltyst",
    "moltystast": "moltyst",
    "moltystaste": "moltyst",
    "moltystastes": "moltyst",
    "moltystasts": "moltyst",
    "moltyste": "moltyst",
    "moltystes": "moltyst",
    "moltysts": "moltyst",
    "molybdenen": "molybden",
    "molybdenens": "molybden",
    "molybdenet": "molybden",
    "molybdenets": "molybden",
    "molybdenglansen": "molybdenglans",
    "molybdenglansens": "molybdenglans",
    "molybdens": "molybden",
    "momangen": "momang",
    "momangens": "momang",
    "momanger": "momang",
    "momangerna": "momang",
    "momangernas": "momang",
    "momangers": "momang",
    "momangs": "momang",
    "momentana": "momentan",
    "momentanare": "momentan",
    "momentanares": "momentan",
    "momentanas": "momentan",
    "momentanast": "momentan",
    "momentanaste": "momentan",
    "momentanastes": "momentan",
    "momentanasts": "momentan",
    "momentane": "momentan",
    "momentanes": "momentan",
    "momentans": "momentan",
    "momentant": "momentan",
    "momentants": "momentan",
    "momenten": "moment",
    "momentens": "moment",
    "momentet": "moment",
    "momentets": "moment",
    "momentnyckeln": "momentnyckel",
    "momentnyckelns": "momentnyckel",
    "momentnyckels": "momentnyckel",
    "momentnycklar": "momentnyckel",
    "momentnycklarna": "momentnyckel",
    "momentnycklarnas": "momentnyckel",
    "momentnycklars": "momentnyckel",
    "moments": "moment",
    "momsen": "moms",
    "momsens": "moms",
    "momsredovis": "momsredovisa",
    "momsredovisade": "momsredovisa",
    "momsredovisades": "momsredovisa",
    "momsredovisande": "momsredovisa",
    "momsredovisanden": "momsredovisande",
    "momsredovisandena": "momsredovisande",
    "momsredovisandenas": "momsredovisande",
    "momsredovisandens": "momsredovisande",
    "momsredovisandes": "momsredovisande",
    "momsredovisandet": "momsredovisande",
    "momsredovisandets": "momsredovisande",
    "momsredovisar": "momsredovisa",
    "momsredovisas": "momsredovisa",
    "momsredovisat": "momsredovisa",
    "momsredovisats": "momsredovisa",
    "momsredovisningar": "momsredovisning",
    "momsredovisningarna": "momsredovisning",
    "momsredovisningarnas": "momsredovisning",
    "momsredovisningars": "momsredovisning",
    "momsredovisningen": "momsredovisning",
    "momsredovisningens": "momsredovisning",
    "momsredovisnings": "momsredovisning",
    "mon": "mo",
    "monaden": "monad",
    "monadens": "monad",
    "monader": "monad",
    "monaderna": "monad",
    "monadernas": "monad",
    "monaders": "monad",
    "monads": "monad",
    "monarken": "monark",
    "monarkens": "monark",
    "monarker": "monark",
    "monarkerna": "monark",
    "monarkernas": "monark",
    "monarkers": "monark",
    "monarkien": "monarki",
    "monarkiens": "monarki",
    "monarkier": "monarki",
    "monarkierna": "monarki",
    "monarkiernas": "monarki",
    "monarkiers": "monarki",
    "monarkin": "monarki",
    "monarkins": "monarki",
    "monarkis": "monarki",
    "monarkiska": "monarkisk",
    "monarkiskare": "monarkisk",
    "monarkiskares": "monarkisk",
    "monarkiskas": "monarkisk",
    "monarkiskast": "monarkisk",
    "monarkiskaste": "monarkisk",
    "monarkiskastes": "monarkisk",
    "monarkiskasts": "monarkisk",
    "monarkiske": "monarkisk",
    "monarkiskes": "monarkisk",
    "monarkisks": "monarkisk",
    "monarkiskt": "monarkisk",
    "monarkiskts": "monarkisk",
    "monarkisten": "monarkist",
    "monarkistens": "monarkist",
    "monarkister": "monarkist",
    "monarkisterna": "monarkist",
    "monarkisternas": "monarkist",
    "monarkisters": "monarkist",
    "monarkists": "monarkist",
    "monarks": "monark",
    "mondiala": "mondial",
    "mondialare": "mondial",
    "mondialares": "mondial",
    "mondialas": "mondial",
    "mondialast": "mondial",
    "mondialaste": "mondial",
    "mondialastes": "mondial",
    "mondialasts": "mondial",
    "mondiale": "mondial",
    "mondiales": "mondial",
    "mondials": "mondial",
    "mondialt": "mondial",
    "mondialts": "mondial",
    "mondäna": "mondän",
    "mondänare": "mondän",
    "mondänares": "mondän",
    "mondänas": "mondän",
    "mondänast": "mondän",
    "mondänaste": "mondän",
    "mondänastes": "mondän",
    "mondänasts": "mondän",
    "mondäne": "mondän",
    "mondänes": "mondän",
    "mondäniteten": "mondänitet",
    "mondänitetens": "mondänitet",
    "mondäniteter": "mondänitet",
    "mondäniteterna": "mondänitet",
    "mondäniteternas": "mondänitet",
    "mondäniteters": "mondänitet",
    "mondänitets": "mondänitet",
    "mondäns": "mondän",
    "mondänt": "mondän",
    "mondänts": "mondän",
    "monegasken": "monegask",
    "monegaskens": "monegask",
    "monegasker": "monegask",
    "monegaskerna": "monegask",
    "monegaskernas": "monegask",
    "monegaskers": "monegask",
    "monegaskiska": "monegaskisk",
    "monegaskiskan": "monegaskiska",
    "monegaskiskans": "monegaskiska",
    "monegaskiskare": "monegaskisk",
    "monegaskiskares": "monegaskisk",
    "monegaskiskas": "monegaskiska",
    "monegaskiskast": "monegaskisk",
    "monegaskiskaste": "monegaskisk",
    "monegaskiskastes": "monegaskisk",
    "monegaskiskasts": "monegaskisk",
    "monegaskiske": "monegaskiska",
    "monegaskiskes": "monegaskisk",
    "monegaskiskor": "monegaskiska",
    "monegaskiskorna": "monegaskiska",
    "monegaskiskornas": "monegaskiska",
    "monegaskiskors": "monegaskiska",
    "monegaskisks": "monegaskisk",
    "monegaskiskt": "monegaskisk",
    "monegaskiskts": "monegaskisk",
    "monegasks": "monegask",
    "monelen": "monel",
    "monelens": "monel",
    "monels": "monel",
    "monetära": "monetär",
    "monetärare": "monetär",
    "monetärares": "monetär",
    "monetäras": "monetär",
    "monetärast": "monetär",
    "monetäraste": "monetär",
    "monetärastes": "monetär",
    "monetärasts": "monetär",
    "monetäre": "monetär",
    "monetäres": "monetär",
    "monetärs": "monetär",
    "monetärt": "monetär",
    "monetärts": "monetär",
    "mongolen": "mongol",
    "mongolens": "mongol",
    "mongoler": "mongol",
    "mongolerna": "mongol",
    "mongolernas": "mongol",
    "mongolers": "mongol",
    "mongolfläckar": "mongolfläck",
    "mongolfläckarna": "mongolfläck",
    "mongolfläckarnas": "mongolfläck",
    "mongolfläckars": "mongolfläck",
    "mongolfläcken": "mongolfläck",
    "mongolfläckens": "mongolfläck",
    "mongolfläcks": "mongolfläck",
    "mongoliska": "mongolisk",
    "mongoliskan": "mongoliska",
    "mongoliskans": "mongoliska",
    "mongoliskare": "mongolisk",
    "mongoliskares": "mongolisk",
    "mongoliskas": "mongoliska",
    "mongoliskast": "mongolisk",
    "mongoliskaste": "mongolisk",
    "mongoliskastes": "mongolisk",
    "mongoliskasts": "mongolisk",
    "mongoliske": "mongoliska",
    "mongoliskes": "mongolisk",
    "mongoliskor": "mongoliska",
    "mongoliskorna": "mongoliska",
    "mongoliskornas": "mongoliska",
    "mongoliskors": "mongoliska",
    "mongolisks": "mongolisk",
    "mongoliskt": "mongolisk",
    "mongoliskts": "mongolisk",
    "mongolismen": "mongolism",
    "mongolismens": "mongolism",
    "mongolismer": "mongolism",
    "mongolismerna": "mongolism",
    "mongolismernas": "mongolism",
    "mongolismers": "mongolism",
    "mongolisms": "mongolism",
    "mongoloida": "mongoloid",
    "mongoloidare": "mongoloid",
    "mongoloidares": "mongoloid",
    "mongoloidas": "mongoloid",
    "mongoloidast": "mongoloid",
    "mongoloidaste": "mongoloid",
    "mongoloidastes": "mongoloid",
    "mongoloidasts": "mongoloid",
    "mongoloide": "mongoloid",
    "mongoloides": "mongoloid",
    "mongoloids": "mongoloid",
    "mongolriken": "mongolrike",
    "mongolrikena": "mongolrike",
    "mongolrikenas": "mongolrike",
    "mongolrikens": "mongolrike",
    "mongolrikes": "mongolrike",
    "mongolriket": "mongolrike",
    "mongolrikets": "mongolrike",
    "mongols": "mongol",
    "mongon": "mongo",
    "mongona": "mongo",
    "mongonas": "mongo",
    "mongons": "mongo",
    "mongos": "mongo",
    "mongot": "mongo",
    "mongots": "mongo",
    "monismen": "monism",
    "monismens": "monism",
    "monismer": "monism",
    "monismerna": "monism",
    "monismernas": "monism",
    "monismers": "monism",
    "monisms": "monism",
    "monisten": "monist",
    "monistens": "monist",
    "monister": "monist",
    "monisterna": "monist",
    "monisternas": "monist",
    "monisters": "monist",
    "monistiska": "monistisk",
    "monistiskas": "monistisk",
    "monistiske": "monistisk",
    "monistiskes": "monistisk",
    "monistisks": "monistisk",
    "monistiskt": "monistisk",
    "monistiskts": "monistisk",
    "monists": "monist",
    "monitorer": "monitor",
    "monitorerna": "monitor",
    "monitorernas": "monitor",
    "monitorers": "monitor",
    "monitorn": "monitor",
    "monitorns": "monitor",
    "monitors": "monitor",
    "monken": "monke",
    "monkens": "monke",
    "monkes": "monke",
    "monoaminoxidasen": "monoaminoxidas",
    "monoaminoxidasens": "monoaminoxidas",
    "monoaminoxidaser": "monoaminoxidas",
    "monoaminoxidaserna": "monoaminoxidas",
    "monoaminoxidasernas": "monoaminoxidas",
    "monoaminoxidasers": "monoaminoxidas",
    "monoaminoxidaset": "monoaminoxidas",
    "monoaminoxidasets": "monoaminoxidas",
    "monoftongen": "monoftong",
    "monoftongens": "monoftong",
    "monoftonger": "monoftong",
    "monoftongerad": "monoftongera",
    "monoftongerade": "monoftongera",
    "monoftongerades": "monoftongera",
    "monoftongerads": "monoftongera",
    "monoftongerande": "monoftongera",
    "monoftongeranden": "monoftongerande",
    "monoftongerandena": "monoftongerande",
    "monoftongerandenas": "monoftongerande",
    "monoftongerandens": "monoftongerande",
    "monoftongerandes": "monoftongerande",
    "monoftongerandet": "monoftongerande",
    "monoftongerandets": "monoftongerande",
    "monoftongerar": "monoftongera",
    "monoftongeras": "monoftongera",
    "monoftongerat": "monoftongera",
    "monoftongerats": "monoftongera",
    "monoftongerbara": "monoftongerbar",
    "monoftongerbarare": "monoftongerbar",
    "monoftongerbarares": "monoftongerbar",
    "monoftongerbaras": "monoftongerbar",
    "monoftongerbarast": "monoftongerbar",
    "monoftongerbaraste": "monoftongerbar",
    "monoftongerbarastes": "monoftongerbar",
    "monoftongerbarasts": "monoftongerbar",
    "monoftongerbare": "monoftongerbar",
    "monoftongerbares": "monoftongerbar",
    "monoftongerbarheten": "monoftongerbarhet",
    "monoftongerbarhetens": "monoftongerbarhet",
    "monoftongerbarhets": "monoftongerbarhet",
    "monoftongerbars": "monoftongerbar",
    "monoftongerbart": "monoftongerbar",
    "monoftongerbarts": "monoftongerbar",
    "monoftongeringar": "monoftongering",
    "monoftongeringarna": "monoftongering",
    "monoftongeringarnas": "monoftongering",
    "monoftongeringars": "monoftongering",
    "monoftongeringen": "monoftongering",
    "monoftongeringens": "monoftongering",
    "monoftongerings": "monoftongering",
    "monoftongerna": "monoftong",
    "monoftongernas": "monoftong",
    "monoftongers": "monoftong",
    "monoftongs": "monoftong",
    "monogama": "monogam",
    "monogamare": "monogam",
    "monogamares": "monogam",
    "monogamas": "monogam",
    "monogamast": "monogam",
    "monogamaste": "monogam",
    "monogamastes": "monogam",
    "monogamasts": "monogam",
    "monogame": "monogam",
    "monogames": "monogam",
    "monogamien": "monogami",
    "monogamiens": "monogami",
    "monogamin": "monogami",
    "monogamins": "monogami",
    "monogamis": "monogami",
    "monogams": "monogam",
    "monogamt": "monogam",
    "monogamts": "monogam",
    "monografien": "monografi",
    "monografiens": "monografi",
    "monografier": "monografi",
    "monografierna": "monografi",
    "monografiernas": "monografi",
    "monografiers": "monografi",
    "monografin": "monografi",
    "monografins": "monografi",
    "monografis": "monografi",
    "monogrammen": "monogram",
    "monogrammens": "monogram",
    "monogrammet": "monogram",
    "monogrammets": "monogram",
    "monograms": "monogram",
    "monokeln": "monokel",
    "monokelns": "monokel",
    "monokels": "monokel",
    "monoklar": "monokel",
    "monoklarna": "monokel",
    "monoklarnas": "monokel",
    "monoklars": "monokel",
    "monokler": "monokel",
    "monoklerna": "monokel",
    "monoklernas": "monokel",
    "monoklers": "monokel",
    "monoklina": "monoklin",
    "monoklinare": "monoklin",
    "monoklinares": "monoklin",
    "monoklinas": "monoklin",
    "monoklinast": "monoklin",
    "monoklinaste": "monoklin",
    "monoklinastes": "monoklin",
    "monoklinasts": "monoklin",
    "monokline": "monoklin",
    "monoklines": "monoklin",
    "monoklins": "monoklin",
    "monoklint": "monoklin",
    "monoklints": "monoklin",
    "monokorden": "monokord",
    "monokordens": "monokord",
    "monokorder": "monokord",
    "monokorderna": "monokord",
    "monokordernas": "monokord",
    "monokorders": "monokord",
    "monokordet": "monokord",
    "monokordets": "monokord",
    "monokords": "monokord",
    "monokotyledonen": "monokotyledon",
    "monokotyledonens": "monokotyledon",
    "monokotyledoner": "monokotyledon",
    "monokotyledonerna": "monokotyledon",
    "monokotyledonernas": "monokotyledon",
    "monokotyledoners": "monokotyledon",
    "monokotyledons": "monokotyledon",
    "monokroma": "monokrom",
    "monokromare": "monokrom",
    "monokromares": "monokrom",
    "monokromas": "monokrom",
    "monokromast": "monokrom",
    "monokromaste": "monokrom",
    "monokromastes": "monokrom",
    "monokromasts": "monokrom",
    "monokromatiska": "monokromatisk",
    "monokromatiskare": "monokromatisk",
    "monokromatiskares": "monokromatisk",
    "monokromatiskas": "monokromatisk",
    "monokromatiskast": "monokromatisk",
    "monokromatiskaste": "monokromatisk",
    "monokromatiskastes": "monokromatisk",
    "monokromatiskasts": "monokromatisk",
    "monokromatiske": "monokromatisk",
    "monokromatiskes": "monokromatisk",
    "monokromatisks": "monokromatisk",
    "monokromatiskt": "monokromatisk",
    "monokromatiskts": "monokromatisk",
    "monokrome": "monokrom",
    "monokromes": "monokrom",
    "monokroms": "monokrom",
    "monokromt": "monokrom",
    "monokromts": "monokrom",
    "monokulturen": "monokultur",
    "monokulturens": "monokultur",
    "monokulturer": "monokultur",
    "monokulturerna": "monokultur",
    "monokulturernas": "monokultur",
    "monokulturers": "monokultur",
    "monokulturs": "monokultur",
    "monoliten": "monolit",
    "monolitens": "monolit",
    "monoliter": "monolit",
    "monoliterna": "monolit",
    "monoliternas": "monolit",
    "monoliters": "monolit",
    "monolitiska": "monolitisk",
    "monolitiskare": "monolitisk",
    "monolitiskares": "monolitisk",
    "monolitiskas": "monolitisk",
    "monolitiskast": "monolitisk",
    "monolitiskaste": "monolitisk",
    "monolitiskastes": "monolitisk",
    "monolitiskasts": "monolitisk",
    "monolitiske": "monolitisk",
    "monolitiskes": "monolitisk",
    "monolitisks": "monolitisk",
    "monolitiskt": "monolitisk",
    "monolitiskts": "monolitisk",
    "monolits": "monolit",
    "monologen": "monolog",
    "monologens": "monolog",
    "monologer": "monolog",
    "monologerna": "monolog",
    "monologernas": "monolog",
    "monologers": "monolog",
    "monologs": "monolog",
    "monomana": "monoman",
    "monomanare": "monoman",
    "monomanares": "monoman",
    "monomanas": "monoman",
    "monomanast": "monoman",
    "monomanaste": "monoman",
    "monomanastes": "monoman",
    "monomanasts": "monoman",
    "monomane": "monoman",
    "monomanes": "monoman",
    "monomanien": "monomani",
    "monomaniens": "monomani",
    "monomanin": "monomani",
    "monomanins": "monomani",
    "monomanis": "monomani",
    "monomans": "monoman",
    "monomant": "monoman",
    "monomants": "monoman",
    "monon": "mono",
    "monons": "mono",
    "monoplanen": "monoplan",
    "monoplanens": "monoplan",
    "monoplanet": "monoplan",
    "monoplanets": "monoplan",
    "monoplans": "monoplan",
    "monopolen": "monopol",
    "monopolens": "monopol",
    "monopolet": "monopol",
    "monopolets": "monopol",
    "monopoliserad": "monopolisera",
    "monopoliserade": "monopolisera",
    "monopoliserades": "monopolisera",
    "monopoliserads": "monopolisera",
    "monopoliserande": "monopolisera",
    "monopoliseranden": "monopoliserande",
    "monopoliserandena": "monopoliserande",
    "monopoliserandenas": "monopoliserande",
    "monopoliserandens": "monopoliserande",
    "monopoliserandes": "monopoliserande",
    "monopoliserandet": "monopoliserande",
    "monopoliserandets": "monopoliserande",
    "monopoliserar": "monopolisera",
    "monopoliseras": "monopolisera",
    "monopoliserat": "monopolisera",
    "monopoliserats": "monopolisera",
    "monopoliserbara": "monopoliserbar",
    "monopoliserbarare": "monopoliserbar",
    "monopoliserbarares": "monopoliserbar",
    "monopoliserbaras": "monopoliserbar",
    "monopoliserbarast": "monopoliserbar",
    "monopoliserbaraste": "monopoliserbar",
    "monopoliserbarastes": "monopoliserbar",
    "monopoliserbarasts": "monopoliserbar",
    "monopoliserbare": "monopoliserbar",
    "monopoliserbares": "monopoliserbar",
    "monopoliserbarheten": "monopoliserbarhet",
    "monopoliserbarhetens": "monopoliserbarhet",
    "monopoliserbarhets": "monopoliserbarhet",
    "monopoliserbars": "monopoliserbar",
    "monopoliserbart": "monopoliserbar",
    "monopoliserbarts": "monopoliserbar",
    "monopoliseringar": "monopolisering",
    "monopoliseringarna": "monopolisering",
    "monopoliseringarnas": "monopolisering",
    "monopoliseringars": "monopolisering",
    "monopoliseringen": "monopolisering",
    "monopoliseringens": "monopolisering",
    "monopoliserings": "monopolisering",
    "monopolismen": "monopolism",
    "monopolismens": "monopolism",
    "monopolismer": "monopolism",
    "monopolismerna": "monopolism",
    "monopolismernas": "monopolism",
    "monopolismers": "monopolism",
    "monopolisms": "monopolism",
    "monopolisten": "monopolist",
    "monopolistens": "monopolist",
    "monopolister": "monopolist",
    "monopolisterna": "monopolist",
    "monopolisternas": "monopolist",
    "monopolisters": "monopolist",
    "monopolistiska": "monopolistisk",
    "monopolistiskas": "monopolistisk",
    "monopolistiske": "monopolistisk",
    "monopolistiskes": "monopolistisk",
    "monopolistisks": "monopolistisk",
    "monopolistiskt": "monopolistisk",
    "monopolistiskts": "monopolistisk",
    "monopolists": "monopolist",
    "monopolkapitalismen": "monopolkapitalism",
    "monopolkapitalismens": "monopolkapitalism",
    "monopolkapitalismer": "monopolkapitalism",
    "monopolkapitalismerna": "monopolkapitalism",
    "monopolkapitalismernas": "monopolkapitalism",
    "monopolkapitalismers": "monopolkapitalism",
    "monopolkapitalisms": "monopolkapitalism",
    "monopolkapitalistiska": "monopolkapitalistisk",
    "monopolkapitalistiskare": "monopolkapitalistisk",
    "monopolkapitalistiskares": "monopolkapitalistisk",
    "monopolkapitalistiskas": "monopolkapitalistisk",
    "monopolkapitalistiskast": "monopolkapitalistisk",
    "monopolkapitalistiskaste": "monopolkapitalistisk",
    "monopolkapitalistiskastes": "monopolkapitalistisk",
    "monopolkapitalistiskasts": "monopolkapitalistisk",
    "monopolkapitalistiske": "monopolkapitalistisk",
    "monopolkapitalistiskes": "monopolkapitalistisk",
    "monopolkapitalistisks": "monopolkapitalistisk",
    "monopolkapitalistiskt": "monopolkapitalistisk",
    "monopolkapitalistiskts": "monopolkapitalistisk",
    "monopols": "monopol",
    "monopolställningar": "monopolställning",
    "monopolställningarna": "monopolställning",
    "monopolställningarnas": "monopolställning",
    "monopolställningars": "monopolställning",
    "monopolställningen": "monopolställning",
    "monopolställningens": "monopolställning",
    "monopolställnings": "monopolställning",
    "monos": "mono",
    "monosackariden": "monosackarid",
    "monosackaridens": "monosackarid",
    "monosackarider": "monosackarid",
    "monosackariderna": "monosackarid",
    "monosackaridernas": "monosackarid",
    "monosackariders": "monosackarid",
    "monosackarids": "monosackarid",
    "monosyllabiska": "monosyllabisk",
    "monosyllabiskare": "monosyllabisk",
    "monosyllabiskares": "monosyllabisk",
    "monosyllabiskas": "monosyllabisk",
    "monosyllabiskast": "monosyllabisk",
    "monosyllabiskaste": "monosyllabisk",
    "monosyllabiskastes": "monosyllabisk",
    "monosyllabiskasts": "monosyllabisk",
    "monosyllabiske": "monosyllabisk",
    "monosyllabiskes": "monosyllabisk",
    "monosyllabisks": "monosyllabisk",
    "monosyllabiskt": "monosyllabisk",
    "monosyllabiskts": "monosyllabisk",
    "monoteismen": "monoteism",
    "monoteismens": "monoteism",
    "monoteismer": "monoteism",
    "monoteismerna": "monoteism",
    "monoteismernas": "monoteism",
    "monoteismers": "monoteism",
    "monoteisms": "monoteism",
    "monoteistiska": "monoteistisk",
    "monoteistiskas": "monoteistisk",
    "monoteistiske": "monoteistisk",
    "monoteistiskes": "monoteistisk",
    "monoteistisks": "monoteistisk",
    "monoteistiskt": "monoteistisk",
    "monoteistiskts": "monoteistisk",
    "monotona": "monoton",
    "monotonare": "monoton",
    "monotonares": "monoton",
    "monotonas": "monoton",
    "monotonast": "monoton",
    "monotonaste": "monoton",
    "monotonastes": "monoton",
    "monotonasts": "monoton",
    "monotone": "monoton",
    "monotones": "monoton",
    "monotonien": "monotoni",
    "monotoniens": "monotoni",
    "monotonin": "monotoni",
    "monotonins": "monotoni",
    "monotonis": "monotoni",
    "monotoniteten": "monotonitet",
    "monotonitetens": "monotonitet",
    "monotoniteter": "monotonitet",
    "monotoniteterna": "monotonitet",
    "monotoniteternas": "monotonitet",
    "monotoniteters": "monotonitet",
    "monotonitets": "monotonitet",
    "monotoniundvikar": "monotoniundvikare",
    "monotoniundvikaren": "monotoniundvikare",
    "monotoniundvikarens": "monotoniundvikare",
    "monotoniundvikares": "monotoniundvikare",
    "monotoniundvikarna": "monotoniundvikare",
    "monotoniundvikarnas": "monotoniundvikare",
    "monotons": "monoton",
    "monotont": "monoton",
    "monotonts": "monoton",
    "monotypen": "monotype",
    "monotypens": "monotype",
    "monotyper": "monotype",
    "monotyperna": "monotype",
    "monotypernas": "monotype",
    "monotypers": "monotype",
    "monotypes": "monotype",
    "mons": "mo",
    "monseigneuren": "monseigneur",
    "monseigneurens": "monseigneur",
    "monseigneurer": "monseigneur",
    "monseigneurerna": "monseigneur",
    "monseigneurernas": "monseigneur",
    "monseigneurers": "monseigneur",
    "monseigneurs": "monseigneur",
    "monsieurs": "monsieur",
    "monsignoren": "monsignore",
    "monsignorens": "monsignore",
    "monsignorer": "monsignore",
    "monsignorerna": "monsignore",
    "monsignorernas": "monsignore",
    "monsignorers": "monsignore",
    "monsignores": "monsignore",
    "monsterfartygen": "monsterfartyg",
    "monsterfartygens": "monsterfartyg",
    "monsterfartyget": "monsterfartyg",
    "monsterfartygets": "monsterfartyg",
    "monsterfartygs": "monsterfartyg",
    "monsterkulturen": "monsterkultur",
    "monsterkulturens": "monsterkultur",
    "monsterkulturer": "monsterkultur",
    "monsterkulturerna": "monsterkultur",
    "monsterkulturernas": "monsterkultur",
    "monsterkulturers": "monsterkultur",
    "monsterkulturs": "monsterkultur",
    "monsterna": "monster",
    "monsternas": "monster",
    "monsters": "monster",
    "monstersvampar": "monstersvamp",
    "monstersvamparna": "monstersvamp",
    "monstersvamparnas": "monstersvamp",
    "monstersvampars": "monstersvamp",
    "monstersvampen": "monstersvamp",
    "monstersvampens": "monstersvamp",
    "monstersvamps": "monstersvamp",
    "monstransen": "monstrans",
    "monstransens": "monstrans",
    "monstranser": "monstrans",
    "monstranserna": "monstrans",
    "monstransernas": "monstrans",
    "monstransers": "monstrans",
    "monstren": "monster",
    "monstrens": "monster",
    "monstret": "monster",
    "monstrets": "monster",
    "monstrums": "monstrum",
    "monstruositeten": "monstruositet",
    "monstruositetens": "monstruositet",
    "monstruositeter": "monstruositet",
    "monstruositeterna": "monstruositet",
    "monstruositeternas": "monstruositet",
    "monstruositeters": "monstruositet",
    "monstruositets": "monstruositet",
    "monstruösa": "monstruös",
    "monstruösare": "monstruös",
    "monstruösares": "monstruös",
    "monstruösas": "monstruös",
    "monstruösast": "monstruös",
    "monstruösaste": "monstruös",
    "monstruösastes": "monstruös",
    "monstruösasts": "monstruös",
    "monstruöse": "monstruös",
    "monstruöses": "monstruös",
    "monstruöst": "monstruös",
    "monstruösts": "monstruös",
    "monsunen": "monsun",
    "monsunens": "monsun",
    "monsuner": "monsun",
    "monsunerna": "monsun",
    "monsunernas": "monsun",
    "monsuners": "monsun",
    "monsunkantringar": "monsunkantring",
    "monsunkantringarna": "monsunkantring",
    "monsunkantringarnas": "monsunkantring",
    "monsunkantringars": "monsunkantring",
    "monsunkantringen": "monsunkantring",
    "monsunkantringens": "monsunkantring",
    "monsunkantrings": "monsunkantring",
    "monsuns": "monsun",
    "montagearmar": "montagearm",
    "montagearmarna": "montagearm",
    "montagearmarnas": "montagearm",
    "montagearmars": "montagearm",
    "montagearmen": "montagearm",
    "montagearmens": "montagearm",
    "montagearms": "montagearm",
    "montagen": "montage",
    "montagens": "montage",
    "montages": "montage",
    "montaget": "montage",
    "montagets": "montage",
    "montenegrinen": "montenegrin",
    "montenegrinens": "montenegrin",
    "montenegriner": "montenegrin",
    "montenegrinerna": "montenegrin",
    "montenegrinernas": "montenegrin",
    "montenegriners": "montenegrin",
    "montenegrins": "montenegrin",
    "montenegrinska": "montenegrinsk",
    "montenegrinskan": "montenegrinska",
    "montenegrinskans": "montenegrinska",
    "montenegrinskare": "montenegrinsk",
    "montenegrinskares": "montenegrinsk",
    "montenegrinskas": "montenegrinska",
    "montenegrinskast": "montenegrinsk",
    "montenegrinskaste": "montenegrinsk",
    "montenegrinskastes": "montenegrinsk",
    "montenegrinskasts": "montenegrinsk",
    "montenegrinske": "montenegrinska",
    "montenegrinskes": "montenegrinsk",
    "montenegrinskor": "montenegrinska",
    "montenegrinskorna": "montenegrinska",
    "montenegrinskornas": "montenegrinska",
    "montenegrinskors": "montenegrinska",
    "montenegrinsks": "montenegrinsk",
    "montenegrinskt": "montenegrinsk",
    "montenegrinskts": "montenegrinsk",
    "monterad": "montera",
    "monterade": "montera",
    "monterades": "montera",
    "monterads": "montera",
    "monterande": "montera",
    "monteranden": "monterande",
    "monterandena": "monterande",
    "monterandenas": "monterande",
    "monterandens": "monterande",
    "monterandes": "monterande",
    "monterandet": "monterande",
    "monterandets": "monterande",
    "monterar": "montera",
    "monteras": "montera",
    "monterat": "montera",
    "monterats": "montera",
    "monterbara": "monterbar",
    "monterbarare": "monterbar",
    "monterbarares": "monterbar",
    "monterbaras": "monterbar",
    "monterbarast": "monterbar",
    "monterbaraste": "monterbar",
    "monterbarastes": "monterbar",
    "monterbarasts": "monterbar",
    "monterbare": "monterbar",
    "monterbares": "monterbar",
    "monterbarheten": "monterbarhet",
    "monterbarhetens": "monterbarhet",
    "monterbarhets": "monterbarhet",
    "monterbars": "monterbar",
    "monterbart": "monterbar",
    "monterbarts": "monterbar",
    "monteringar": "montering",
    "monteringarna": "montering",
    "monteringarnas": "montering",
    "monteringars": "montering",
    "monteringen": "montering",
    "monteringens": "montering",
    "monterings": "montering",
    "monteringsanvisningar": "monteringsanvisning",
    "monteringsanvisningarna": "monteringsanvisning",
    "monteringsanvisningarnas": "monteringsanvisning",
    "monteringsanvisningars": "monteringsanvisning",
    "monteringsanvisningen": "monteringsanvisning",
    "monteringsanvisningens": "monteringsanvisning",
    "monteringsanvisnings": "monteringsanvisning",
    "monteringsfärdiga": "monteringsfärdig",
    "monteringsfärdigare": "monteringsfärdig",
    "monteringsfärdigares": "monteringsfärdig",
    "monteringsfärdigas": "monteringsfärdig",
    "monteringsfärdigast": "monteringsfärdig",
    "monteringsfärdigaste": "monteringsfärdig",
    "monteringsfärdigastes": "monteringsfärdig",
    "monteringsfärdigasts": "monteringsfärdig",
    "monteringsfärdige": "monteringsfärdig",
    "monteringsfärdiges": "monteringsfärdig",
    "monteringsfärdigs": "monteringsfärdig",
    "monteringsfärdigt": "monteringsfärdig",
    "monteringsfärdigts": "monteringsfärdig",
    "monteringshålen": "monteringshål",
    "monteringshålens": "monteringshål",
    "monteringshålet": "monteringshål",
    "monteringshålets": "monteringshål",
    "monteringshåls": "monteringshål",
    "monteringsskruvar": "monteringsskruv",
    "monteringsskruvarna": "monteringsskruv",
    "monteringsskruvarnas": "monteringsskruv",
    "monteringsskruvars": "monteringsskruv",
    "monteringsskruven": "monteringsskruv",
    "monteringsskruvens": "monteringsskruv",
    "monteringsskruvs": "monteringsskruv",
    "monteringstejpen": "monteringstejp",
    "monteringstejpens": "monteringstejp",
    "monteringstejps": "monteringstejp",
    "montern": "monter",
    "monterns": "monter",
    "monters": "monter",
    "montrar": "monter",
    "montrarna": "monter",
    "montrarnas": "monter",
    "montrars": "monter",
    "montrer": "monter",
    "montrerna": "monter",
    "montrernas": "monter",
    "montrers": "monter",
    "montören": "montör",
    "montörens": "montör",
    "montörer": "montör",
    "montörerna": "montör",
    "montörernas": "montör",
    "montörers": "montör",
    "montörs": "montör",
    "monumentala": "monumental",
    "monumentalare": "monumental",
    "monumentalares": "monumental",
    "monumentalas": "monumental",
    "monumentalast": "monumental",
    "monumentalaste": "monumental",
    "monumentalastes": "monumental",
    "monumentalasts": "monumental",
    "monumentalbyggnaden": "monumentalbyggnad",
    "monumentalbyggnadens": "monumentalbyggnad",
    "monumentalbyggnader": "monumentalbyggnad",
    "monumentalbyggnaderna": "monumentalbyggnad",
    "monumentalbyggnadernas": "monumentalbyggnad",
    "monumentalbyggnaders": "monumentalbyggnad",
    "monumentalbyggnads": "monumentalbyggnad",
    "monumentale": "monumental",
    "monumentales": "monumental",
    "monumentaliteten": "monumentalitet",
    "monumentalitetens": "monumentalitet",
    "monumentaliteter": "monumentalitet",
    "monumentaliteterna": "monumentalitet",
    "monumentaliteternas": "monumentalitet",
    "monumentaliteters": "monumentalitet",
    "monumentalitets": "monumentalitet",
    "monumentalkonsten": "monumentalkonst",
    "monumentalkonstens": "monumentalkonst",
    "monumentalkonsts": "monumentalkonst",
    "monumentals": "monumental",
    "monumentalt": "monumental",
    "monumentalts": "monumental",
    "monumenten": "monument",
    "monumentens": "monument",
    "monumentet": "monument",
    "monumentets": "monument",
    "monuments": "monument",
    "mopedade": "mopeda",
    "mopedades": "mopeda",
    "mopedande": "mopeda",
    "mopedanden": "mopedande",
    "mopedandena": "mopedande",
    "mopedandenas": "mopedande",
    "mopedandens": "mopedande",
    "mopedandes": "mopedande",
    "mopedandet": "mopedande",
    "mopedandets": "mopedande",
    "mopedar": "mopeda",
    "mopedas": "mopeda",
    "mopedat": "mopeda",
    "mopedats": "mopeda",
    "mopeden": "moped",
    "mopedens": "moped",
    "mopeder": "moped",
    "mopederna": "moped",
    "mopedernas": "moped",
    "mopeders": "moped",
    "mopedisten": "mopedist",
    "mopedistens": "mopedist",
    "mopedister": "mopedist",
    "mopedisterna": "mopedist",
    "mopedisternas": "mopedist",
    "mopedisters": "mopedist",
    "mopedists": "mopedist",
    "mopeds": "moped",
    "mopp": "moppe",
    "moppad": "moppa",
    "moppade": "moppa",
    "moppades": "moppa",
    "moppads": "moppa",
    "moppande": "moppa",
    "moppanden": "moppande",
    "moppandena": "moppande",
    "moppandenas": "moppande",
    "moppandens": "moppande",
    "moppandes": "moppande",
    "moppandet": "moppande",
    "moppandets": "moppande",
    "moppar": "moppe",
    "mopparna": "moppe",
    "mopparnas": "moppe",
    "moppars": "moppe",
    "moppas": "moppa",
    "moppat": "moppa",
    "moppats": "moppa",
    "moppen": "moppe",
    "moppens": "moppe",
    "moppes": "moppe",
    "mopps": "moppe",
    "mopsar": "mops",
    "mopsarna": "mops",
    "mopsarnas": "mops",
    "mopsars": "mops",
    "mopsen": "mops",
    "mopsens": "mops",
    "mopsiga": "mopsig",
    "mopsigare": "mopsig",
    "mopsigares": "mopsig",
    "mopsigas": "mopsig",
    "mopsigast": "mopsig",
    "mopsigaste": "mopsig",
    "mopsigastes": "mopsig",
    "mopsigasts": "mopsig",
    "mopsige": "mopsig",
    "mopsiges": "mopsig",
    "mopsigheten": "mopsighet",
    "mopsighetens": "mopsighet",
    "mopsighets": "mopsighet",
    "mopsigs": "mopsig",
    "mopsigt": "mopsig",
    "mopsigts": "mopsig",
    "mor": "mora",
    "mor-unge-konflikten": "mor-unge-konflikt",
    "mor-unge-konfliktens": "mor-unge-konflikt",
    "mor-unge-konflikter": "mor-unge-konflikt",
    "mor-unge-konflikterna": "mor-unge-konflikt",
    "mor-unge-konflikternas": "mor-unge-konflikt",
    "mor-unge-konflikters": "mor-unge-konflikt",
    "mor-unge-konflikts": "mor-unge-konflikt",
    "moraklock": "moraklocka",
    "moraklockan": "moraklocka",
    "moraklockans": "moraklocka",
    "moraklockas": "moraklocka",
    "moraklocke": "moraklocka",
    "moraklockor": "moraklocka",
    "moraklockorna": "moraklocka",
    "moraklockornas": "moraklocka",
    "moraklockors": "moraklocka",
    "moraklocks": "moraklocka",
    "moraknivar": "morakniv",
    "moraknivarna": "morakniv",
    "moraknivarnas": "morakniv",
    "moraknivars": "morakniv",
    "morakniven": "morakniv",
    "moraknivens": "morakniv",
    "moraknivs": "morakniv",
    "moralbegreppen": "moralbegrepp",
    "moralbegreppens": "moralbegrepp",
    "moralbegreppet": "moralbegrepp",
    "moralbegreppets": "moralbegrepp",
    "moralbegrepps": "moralbegrepp",
    "moralen": "moral",
    "moralens": "moral",
    "moraler": "moral",
    "moralerna": "moral",
    "moralernas": "moral",
    "moralers": "moral",
    "moralfilosofien": "moralfilosofi",
    "moralfilosofiens": "moralfilosofi",
    "moralfilosofin": "moralfilosofi",
    "moralfilosofins": "moralfilosofi",
    "moralfilosofis": "moralfilosofi",
    "moraliserade": "moralisera",
    "moraliserades": "moralisera",
    "moraliserande": "moralisera",
    "moraliseranden": "moraliserande",
    "moraliserandena": "moraliserande",
    "moraliserandenas": "moraliserande",
    "moraliserandens": "moraliserande",
    "moraliserandes": "moraliserande",
    "moraliserandet": "moraliserande",
    "moraliserandets": "moraliserande",
    "moraliserar": "moralisera",
    "moraliseras": "moralisera",
    "moraliserat": "moralisera",
    "moraliserats": "moralisera",
    "moraliseringar": "moralisering",
    "moraliseringarna": "moralisering",
    "moraliseringarnas": "moralisering",
    "moraliseringars": "moralisering",
    "moraliseringen": "moralisering",
    "moraliseringens": "moralisering",
    "moraliserings": "moralisering",
    "moraliska": "moralisk",
    "moraliskare": "moralisk",
    "moraliskares": "moralisk",
    "moraliskas": "moralisk",
    "moraliskast": "moralisk",
    "moraliskaste": "moralisk",
    "moraliskastes": "moralisk",
    "moraliskasts": "moralisk",
    "moraliske": "moralisk",
    "moraliskes": "moralisk",
    "moralisks": "moralisk",
    "moraliskt": "moralisk",
    "moraliskts": "moralisk",
    "moralismen": "moralism",
    "moralismens": "moralism",
    "moralismer": "moralism",
    "moralismerna": "moralism",
    "moralismernas": "moralism",
    "moralismers": "moralism",
    "moralisms": "moralism",
    "moralisten": "moralist",
    "moralistens": "moralist",
    "moralister": "moralist",
    "moralisterna": "moralist",
    "moralisternas": "moralist",
    "moralisters": "moralist",
    "moralistiska": "moralistisk",
    "moralistiskas": "moralistisk",
    "moralistiske": "moralistisk",
    "moralistiskes": "moralistisk",
    "moralistisks": "moralistisk",
    "moralistiskt": "moralistisk",
    "moralistiskts": "moralistisk",
    "moralists": "moralist",
    "moraliteten": "moralitet",
    "moralitetens": "moralitet",
    "moraliteter": "moralitet",
    "moraliteterna": "moralitet",
    "moraliteternas": "moralitet",
    "moraliteters": "moralitet",
    "moralitets": "moralitet",
    "moralkak": "moralkaka",
    "moralkakan": "moralkaka",
    "moralkakans": "moralkaka",
    "moralkakas": "moralkaka",
    "moralkake": "moralkaka",
    "moralkakor": "moralkaka",
    "moralkakorna": "moralkaka",
    "moralkakornas": "moralkaka",
    "moralkakors": "moralkaka",
    "moralkaks": "moralkaka",
    "moralpaniken": "moralpanik",
    "moralpanikens": "moralpanik",
    "moralpaniks": "moralpanik",
    "morals": "moral",
    "moralseden": "moralsed",
    "moralsedens": "moralsed",
    "moralseder": "moralsed",
    "moralsederna": "moralsed",
    "moralsedernas": "moralsed",
    "moralseders": "moralsed",
    "moralseds": "moralsed",
    "moran": "mora",
    "morans": "mora",
    "morasen": "moras",
    "morasens": "moras",
    "moraset": "moras",
    "morasets": "moras",
    "moratorie": "moratorium",
    "moratorier": "moratorium",
    "moratorierna": "moratorium",
    "moratoriernas": "moratorium",
    "moratoriers": "moratorium",
    "moratoriet": "moratorium",
    "moratoriets": "moratorium",
    "moratoriums": "moratorium",
    "morbida": "morbid",
    "morbidare": "morbid",
    "morbidares": "morbid",
    "morbidas": "morbid",
    "morbidast": "morbid",
    "morbidaste": "morbid",
    "morbidastes": "morbid",
    "morbidasts": "morbid",
    "morbide": "morbid",
    "morbides": "morbid",
    "morbiditeten": "morbiditet",
    "morbiditetens": "morbiditet",
    "morbiditeter": "morbiditet",
    "morbiditeterna": "morbiditet",
    "morbiditeternas": "morbiditet",
    "morbiditeters": "morbiditet",
    "morbiditets": "morbiditet",
    "morbids": "morbid",
    "morbrodern": "morbror",
    "morbroderns": "morbror",
    "morbrorn": "morbror",
    "morbrorns": "morbror",
    "morbrors": "morbror",
    "morbröder": "morbror",
    "morbröderna": "morbror",
    "morbrödernas": "morbror",
    "morbröders": "morbror",
    "mordbranden": "mordbrand",
    "mordbrandens": "mordbrand",
    "mordbrands": "mordbrand",
    "mordbränder": "mordbrand",
    "mordbränderna": "mordbrand",
    "mordbrändernas": "mordbrand",
    "mordbränders": "mordbrand",
    "mordbrännar": "mordbrännare",
    "mordbrännaren": "mordbrännare",
    "mordbrännarens": "mordbrännare",
    "mordbrännares": "mordbrännare",
    "mordbrännarna": "mordbrännare",
    "mordbrännarnas": "mordbrännare",
    "morddömde": "morddömd",
    "morddömdes": "morddömd",
    "morddömds": "morddömd",
    "morddömt": "morddömd",
    "morddömts": "morddömd",
    "morden": "mord",
    "mordens": "mord",
    "mordet": "mord",
    "mordets": "mord",
    "mordförsöken": "mordförsök",
    "mordförsökens": "mordförsök",
    "mordförsöket": "mordförsök",
    "mordförsökets": "mordförsök",
    "mordförsöks": "mordförsök",
    "mordgåt": "mordgåta",
    "mordgåtan": "mordgåta",
    "mordgåtans": "mordgåta",
    "mordgåtas": "mordgåta",
    "mordgåte": "mordgåta",
    "mordgåtor": "mordgåta",
    "mordgåtorna": "mordgåta",
    "mordgåtornas": "mordgåta",
    "mordgåtors": "mordgåta",
    "mordgåts": "mordgåta",
    "mordhotad": "mordhota",
    "mordhotade": "mordhota",
    "mordhotades": "mordhota",
    "mordhotads": "mordhota",
    "mordhotande": "mordhota",
    "mordhotanden": "mordhotande",
    "mordhotandena": "mordhotande",
    "mordhotandenas": "mordhotande",
    "mordhotandens": "mordhotande",
    "mordhotandes": "mordhotande",
    "mordhotandet": "mordhotande",
    "mordhotandets": "mordhotande",
    "mordhotar": "mordhota",
    "mordhotas": "mordhota",
    "mordhotat": "mordhota",
    "mordhotats": "mordhota",
    "mordiska": "mordisk",
    "mordiskare": "mordisk",
    "mordiskares": "mordisk",
    "mordiskas": "mordisk",
    "mordiskast": "mordisk",
    "mordiskaste": "mordisk",
    "mordiskastes": "mordisk",
    "mordiskasts": "mordisk",
    "mordiske": "mordisk",
    "mordiskes": "mordisk",
    "mordisks": "mordisk",
    "mordiskt": "mordisk",
    "mordiskts": "mordisk",
    "mordkommissionen": "mordkommission",
    "mordkommissionens": "mordkommission",
    "mordkommissioner": "mordkommission",
    "mordkommissionerna": "mordkommission",
    "mordkommissionernas": "mordkommission",
    "mordkommissioners": "mordkommission",
    "mordkommissions": "mordkommission",
    "mordkonspirationen": "mordkonspiration",
    "mordkonspirationens": "mordkonspiration",
    "mordkonspirationer": "mordkonspiration",
    "mordkonspirationerna": "mordkonspiration",
    "mordkonspirationernas": "mordkonspiration",
    "mordkonspirationers": "mordkonspiration",
    "mordkonspirations": "mordkonspiration",
    "mordlusten": "mordlust",
    "mordlustens": "mordlust",
    "mordlusts": "mordlust",
    "mordlystenheten": "mordlystenhet",
    "mordlystenhetens": "mordlystenhet",
    "mordlystenhets": "mordlystenhet",
    "mordlystens": "mordlysten",
    "mordlystet": "mordlysten",
    "mordlystets": "mordlysten",
    "mordlystna": "mordlysten",
    "mordlystnaden": "mordlystnad",
    "mordlystnadens": "mordlystnad",
    "mordlystnader": "mordlystnad",
    "mordlystnaderna": "mordlystnad",
    "mordlystnadernas": "mordlystnad",
    "mordlystnaders": "mordlystnad",
    "mordlystnads": "mordlystnad",
    "mordlystnare": "mordlysten",
    "mordlystnares": "mordlysten",
    "mordlystnas": "mordlysten",
    "mordlystnast": "mordlysten",
    "mordlystnaste": "mordlysten",
    "mordlystnastes": "mordlysten",
    "mordlystnasts": "mordlysten",
    "mordlystne": "mordlysten",
    "mordlystnes": "mordlysten",
    "mordmisstänkta": "mordmisstänkt",
    "mordmisstänktare": "mordmisstänkt",
    "mordmisstänktares": "mordmisstänkt",
    "mordmisstänktas": "mordmisstänkt",
    "mordmisstänktast": "mordmisstänkt",
    "mordmisstänktaste": "mordmisstänkt",
    "mordmisstänktastes": "mordmisstänkt",
    "mordmisstänktasts": "mordmisstänkt",
    "mordmisstänkte": "mordmisstänkt",
    "mordmisstänktes": "mordmisstänkt",
    "mordmisstänkts": "mordmisstänkt",
    "mordoffers": "mordoffer",
    "mordoffren": "mordoffer",
    "mordoffrens": "mordoffer",
    "mordoffret": "mordoffer",
    "mordoffrets": "mordoffer",
    "mordrättegångar": "mordrättegång",
    "mordrättegångarna": "mordrättegång",
    "mordrättegångarnas": "mordrättegång",
    "mordrättegångars": "mordrättegång",
    "mordrättegången": "mordrättegång",
    "mordrättegångens": "mordrättegång",
    "mordrättegångs": "mordrättegång",
    "mords": "mord",
    "mordstämplingar": "mordstämpling",
    "mordstämplingarna": "mordstämpling",
    "mordstämplingarnas": "mordstämpling",
    "mordstämplingars": "mordstämpling",
    "mordstämplingen": "mordstämpling",
    "mordstämplingens": "mordstämpling",
    "mordstämplings": "mordstämpling",
    "mordvapens": "mordvapen",
    "mordvapnen": "mordvapen",
    "mordvapnens": "mordvapen",
    "mordvapnet": "mordvapen",
    "mordvapnets": "mordvapen",
    "mordängeln": "mordängel",
    "mordängelns": "mordängel",
    "mordängels": "mordängel",
    "mordängla": "mordängel",
    "mordänglar": "mordängel",
    "mordänglarna": "mordängel",
    "mordänglarnas": "mordängel",
    "mordänglars": "mordängel",
    "more": "mora",
    "morellen": "morell",
    "morellens": "morell",
    "moreller": "morell",
    "morellerna": "morell",
    "morellernas": "morell",
    "morellers": "morell",
    "morells": "morell",
    "moren": "mor",
    "morens": "mor",
    "morer": "mor",
    "morerna": "mor",
    "morernas": "mor",
    "morers": "mor",
    "morfader": "morfar",
    "morfadern": "morfar",
    "morfaderns": "morfar",
    "morfaders": "morfar",
    "morfars": "morfar",
    "morfasder": "morfar",
    "morfemen": "morfem",
    "morfemens": "morfem",
    "morfemet": "morfem",
    "morfemets": "morfem",
    "morfemgränsen": "morfemgräns",
    "morfemgränsens": "morfemgräns",
    "morfemgränser": "morfemgräns",
    "morfemgränserna": "morfemgräns",
    "morfemgränsernas": "morfemgräns",
    "morfemgränsers": "morfemgräns",
    "morfems": "morfem",
    "morfinen": "morfin",
    "morfinens": "morfin",
    "morfinet": "morfin",
    "morfinets": "morfin",
    "morfinisten": "morfinist",
    "morfinistens": "morfinist",
    "morfinister": "morfinist",
    "morfinisterna": "morfinist",
    "morfinisternas": "morfinist",
    "morfinisters": "morfinist",
    "morfinists": "morfinist",
    "morfins": "morfin",
    "morfogenesen": "morfogenes",
    "morfogenesens": "morfogenes",
    "morfogeneser": "morfogenes",
    "morfogeneserna": "morfogenes",
    "morfogenesernas": "morfogenes",
    "morfogenesers": "morfogenes",
    "morfologien": "morfologi",
    "morfologiens": "morfologi",
    "morfologier": "morfologi",
    "morfologierna": "morfologi",
    "morfologiernas": "morfologi",
    "morfologiers": "morfologi",
    "morfologin": "morfologi",
    "morfologins": "morfologi",
    "morfologis": "morfologi",
    "morfologiska": "morfologisk",
    "morfologiskare": "morfologisk",
    "morfologiskares": "morfologisk",
    "morfologiskas": "morfologisk",
    "morfologiskast": "morfologisk",
    "morfologiskaste": "morfologisk",
    "morfologiskastes": "morfologisk",
    "morfologiskasts": "morfologisk",
    "morfologiske": "morfologisk",
    "morfologiskes": "morfologisk",
    "morfologisks": "morfologisk",
    "morfologiskt": "morfologisk",
    "morfologiskts": "morfologisk",
    "morfäder": "morfar",
    "morfäderna": "morfar",
    "morfädernas": "morfar",
    "morfäders": "morfar",
    "morföräldern": "morförälder",
    "morförälderns": "morförälder",
    "morförälders": "morförälder",
    "morföräldrar": "morförälder",
    "morföräldrarna": "morförälder",
    "morföräldrarnas": "morförälder",
    "morföräldrars": "morförälder",
    "morganatiska": "morganatisk",
    "morganatiskare": "morganatisk",
    "morganatiskares": "morganatisk",
    "morganatiskas": "morganatisk",
    "morganatiskast": "morganatisk",
    "morganatiskaste": "morganatisk",
    "morganatiskastes": "morganatisk",
    "morganatiskasts": "morganatisk",
    "morganatiske": "morganatisk",
    "morganatiskes": "morganatisk",
    "morganatisks": "morganatisk",
    "morganatiskt": "morganatisk",
    "morganatiskts": "morganatisk",
    "morgnar": "morgon",
    "morgnarna": "morgon",
    "morgnarnas": "morgon",
    "morgnars": "morgon",
    "morgonandakten": "morgonandakt",
    "morgonandaktens": "morgonandakt",
    "morgonandakter": "morgonandakt",
    "morgonandakterna": "morgonandakt",
    "morgonandakternas": "morgonandakt",
    "morgonandakters": "morgonandakt",
    "morgonandakts": "morgonandakt",
    "morgonavgångar": "morgonavgång",
    "morgonavgångarna": "morgonavgång",
    "morgonavgångarnas": "morgonavgång",
    "morgonavgångars": "morgonavgång",
    "morgonavgången": "morgonavgång",
    "morgonavgångens": "morgonavgång",
    "morgonavgångs": "morgonavgång",
    "morgonbönen": "morgonbön",
    "morgonbönens": "morgonbön",
    "morgonböner": "morgonbön",
    "morgonbönerna": "morgonbön",
    "morgonbönernas": "morgonbön",
    "morgonböners": "morgonbön",
    "morgonböns": "morgonbön",
    "morgondagar": "morgondag",
    "morgondagarna": "morgondag",
    "morgondagarnas": "morgondag",
    "morgondagars": "morgondag",
    "morgondagen": "morgondag",
    "morgondagens": "morgondag",
    "morgondags": "morgondag",
    "morgondim": "morgondimma",
    "morgondimman": "morgondimma",
    "morgondimmans": "morgondimma",
    "morgondimmas": "morgondimma",
    "morgondimme": "morgondimma",
    "morgondimmor": "morgondimma",
    "morgondimmorna": "morgondimma",
    "morgondimmornas": "morgondimma",
    "morgondimmors": "morgondimma",
    "morgondims": "morgondimma",
    "morgonen": "morgon",
    "morgonens": "morgon",
    "morgongudstjänsten": "morgongudstjänst",
    "morgongudstjänstens": "morgongudstjänst",
    "morgongudstjänster": "morgongudstjänst",
    "morgongudstjänsterna": "morgongudstjänst",
    "morgongudstjänsternas": "morgongudstjänst",
    "morgongudstjänsters": "morgongudstjänst",
    "morgongudstjänsts": "morgongudstjänst",
    "morgongåvan": "morgongåva",
    "morgongåvans": "morgongåva",
    "morgongåvas": "morgongåva",
    "morgongåve": "morgongåva",
    "morgongåvo": "morgongåva",
    "morgongåvor": "morgongåva",
    "morgongåvorna": "morgongåva",
    "morgongåvornas": "morgongåva",
    "morgongåvors": "morgongåva",
    "morgonhumöret": "morgonhumör",
    "morgonhumörets": "morgonhumör",
    "morgonhumörs": "morgonhumör",
    "morgonkrökens": "morgonkröken",
    "morgonkulans": "morgonkulan",
    "morgonkvistens": "morgonkvisten",
    "morgonmänniskan": "morgonmänniska",
    "morgonmänniskans": "morgonmänniska",
    "morgonmänniskas": "morgonmänniska",
    "morgonmännisko": "morgonmänniska",
    "morgonmänniskor": "morgonmänniska",
    "morgonmänniskorna": "morgonmänniska",
    "morgonmänniskornas": "morgonmänniska",
    "morgonmänniskors": "morgonmänniska",
    "morgonmöten": "morgonmöte",
    "morgonmötena": "morgonmöte",
    "morgonmötenas": "morgonmöte",
    "morgonmötens": "morgonmöte",
    "morgonmötes": "morgonmöte",
    "morgonmötet": "morgonmöte",
    "morgonmötets": "morgonmöte",
    "morgonpigga": "morgonpigg",
    "morgonpiggare": "morgonpigg",
    "morgonpiggares": "morgonpigg",
    "morgonpiggas": "morgonpigg",
    "morgonpiggast": "morgonpigg",
    "morgonpiggaste": "morgonpigg",
    "morgonpiggastes": "morgonpigg",
    "morgonpiggasts": "morgonpigg",
    "morgonpigge": "morgonpigg",
    "morgonpigges": "morgonpigg",
    "morgonpiggheten": "morgonpigghet",
    "morgonpigghetens": "morgonpigghet",
    "morgonpigghets": "morgonpigghet",
    "morgonpiggs": "morgonpigg",
    "morgonpiggt": "morgonpigg",
    "morgonpiggts": "morgonpigg",
    "morgonritualen": "morgonritual",
    "morgonritualens": "morgonritual",
    "morgonritualer": "morgonritual",
    "morgonritualerna": "morgonritual",
    "morgonritualernas": "morgonritual",
    "morgonritualers": "morgonritual",
    "morgonritualet": "morgonritual",
    "morgonritualets": "morgonritual",
    "morgonrituals": "morgonritual",
    "morgonrockar": "morgonrock",
    "morgonrockarna": "morgonrock",
    "morgonrockarnas": "morgonrock",
    "morgonrockars": "morgonrock",
    "morgonrocken": "morgonrock",
    "morgonrockens": "morgonrock",
    "morgonrocks": "morgonrock",
    "morgonrodnaden": "morgonrodnad",
    "morgonrodnadens": "morgonrodnad",
    "morgonrodnader": "morgonrodnad",
    "morgonrodnaderna": "morgonrodnad",
    "morgonrodnadernas": "morgonrodnad",
    "morgonrodnaders": "morgonrodnad",
    "morgonrodnads": "morgonrodnad",
    "morgons": "morgon",
    "morgonsamlingar": "morgonsamling",
    "morgonsamlingarna": "morgonsamling",
    "morgonsamlingarnas": "morgonsamling",
    "morgonsamlingars": "morgonsamling",
    "morgonsamlingen": "morgonsamling",
    "morgonsamlingens": "morgonsamling",
    "morgonsamlings": "morgonsamling",
    "morgonsidans": "morgonsidan",
    "morgonstjärnan": "morgonstjärna",
    "morgonstjärnans": "morgonstjärna",
    "morgonstjärnas": "morgonstjärna",
    "morgonstjärne": "morgonstjärna",
    "morgonstjärnor": "morgonstjärna",
    "morgonstjärnorna": "morgonstjärna",
    "morgonstjärnornas": "morgonstjärna",
    "morgonstjärnors": "morgonstjärna",
    "morgonstunden": "morgonstund",
    "morgonstundens": "morgonstund",
    "morgonstunder": "morgonstund",
    "morgonstunderna": "morgonstund",
    "morgonstundernas": "morgonstund",
    "morgonstunders": "morgonstund",
    "morgonstunds": "morgonstund",
    "morgonsången": "morgonsång",
    "morgonsångens": "morgonsång",
    "morgonsånger": "morgonsång",
    "morgonsångerna": "morgonsång",
    "morgonsångernas": "morgonsång",
    "morgonsångers": "morgonsång",
    "morgonsångs": "morgonsång",
    "morgontidningar": "morgontidning",
    "morgontidningarna": "morgontidning",
    "morgontidningarnas": "morgontidning",
    "morgontidningars": "morgontidning",
    "morgontidningen": "morgontidning",
    "morgontidningens": "morgontidning",
    "morgontidnings": "morgontidning",
    "morgontim": "morgontimme",
    "morgontimmar": "morgontimme",
    "morgontimmarna": "morgontimme",
    "morgontimmarnas": "morgontimme",
    "morgontimmars": "morgontimme",
    "morgontimmen": "morgontimme",
    "morgontimmens": "morgontimme",
    "morgontimmes": "morgontimme",
    "morgontims": "morgontimme",
    "morgontrötta": "morgontrött",
    "morgontröttare": "morgontrött",
    "morgontröttares": "morgontrött",
    "morgontröttas": "morgontrött",
    "morgontröttast": "morgontrött",
    "morgontröttaste": "morgontrött",
    "morgontröttastes": "morgontrött",
    "morgontröttasts": "morgontrött",
    "morgontrötte": "morgontrött",
    "morgontröttes": "morgontrött",
    "morgontröttheten": "morgontrötthet",
    "morgontrötthetens": "morgontrötthet",
    "morgontrötthets": "morgontrötthet",
    "morgontrötts": "morgontrött",
    "morgonväkten": "morgonväkt",
    "morgonväktens": "morgonväkt",
    "morgonväkts": "morgonväkt",
    "morianen": "morian",
    "morianens": "morian",
    "morianer": "morian",
    "morianerna": "morian",
    "morianernas": "morian",
    "morianers": "morian",
    "morians": "morian",
    "moringar": "moring",
    "moringarna": "moring",
    "moringarnas": "moring",
    "moringars": "moring",
    "moringen": "moring",
    "moringens": "moring",
    "morings": "moring",
    "moringsankar": "moringsankare",
    "moringsankaren": "moringsankare",
    "moringsankarens": "moringsankare",
    "moringsankares": "moringsankare",
    "moringsankaret": "moringsankare",
    "moringsankarets": "moringsankare",
    "moringsankarna": "moringsankare",
    "moringsankarnas": "moringsankare",
    "moringsbojar": "moringsboj",
    "moringsbojarna": "moringsboj",
    "moringsbojarnas": "moringsboj",
    "moringsbojars": "moringsboj",
    "moringsbojen": "moringsboj",
    "moringsbojens": "moringsboj",
    "moringsbojs": "moringsboj",
    "moriska": "morisk",
    "moriskare": "morisk",
    "moriskares": "morisk",
    "moriskas": "morisk",
    "moriskast": "morisk",
    "moriskaste": "morisk",
    "moriskastes": "morisk",
    "moriskasts": "morisk",
    "moriske": "morisk",
    "morisken": "morisk",
    "moriskens": "morisk",
    "morisker": "morisk",
    "moriskerna": "morisk",
    "moriskernas": "morisk",
    "moriskers": "morisk",
    "moriskes": "morisk",
    "morisks": "morisk",
    "moriskt": "morisk",
    "moriskts": "morisk",
    "morkull": "morkulla",
    "morkullan": "morkulla",
    "morkullans": "morkulla",
    "morkullas": "morkulla",
    "morkulle": "morkulla",
    "morkullor": "morkulla",
    "morkullorna": "morkulla",
    "morkullornas": "morkulla",
    "morkullors": "morkulla",
    "morkulls": "morkulla",
    "morkullssträcken": "morkullssträck",
    "morkullssträckens": "morkullssträck",
    "morkullssträcket": "morkullssträck",
    "morkullssträckets": "morkullssträck",
    "morkullssträcks": "morkullssträck",
    "morl": "morla",
    "morlade": "morla",
    "morlades": "morla",
    "morlande": "morla",
    "morlanden": "morlande",
    "morlandena": "morlande",
    "morlandenas": "morlande",
    "morlandens": "morlande",
    "morlandes": "morlande",
    "morlandet": "morlande",
    "morlandets": "morlande",
    "morlar": "morla",
    "morlas": "morla",
    "morlat": "morla",
    "morlats": "morla",
    "mormoder": "mormor",
    "mormodern": "mormor",
    "mormoderns": "mormor",
    "mormoders": "mormor",
    "mormonen": "mormon",
    "mormonens": "mormon",
    "mormoner": "mormon",
    "mormonerna": "mormon",
    "mormonernas": "mormon",
    "mormoners": "mormon",
    "mormonismen": "mormonism",
    "mormonismens": "mormonism",
    "mormonismer": "mormonism",
    "mormonismerna": "mormonism",
    "mormonismernas": "mormonism",
    "mormonismers": "mormonism",
    "mormonisms": "mormonism",
    "mormons": "mormon",
    "mormonska": "mormonsk",
    "mormonskare": "mormonsk",
    "mormonskares": "mormonsk",
    "mormonskas": "mormonsk",
    "mormonskast": "mormonsk",
    "mormonskaste": "mormonsk",
    "mormonskastes": "mormonsk",
    "mormonskasts": "mormonsk",
    "mormonske": "mormonsk",
    "mormonskes": "mormonsk",
    "mormonsks": "mormonsk",
    "mormonskt": "mormonsk",
    "mormonskts": "mormonsk",
    "mormors": "mormor",
    "mormorsstänger": "mormorsstång",
    "mormorsstängerna": "mormorsstång",
    "mormorsstängernas": "mormorsstång",
    "mormorsstängers": "mormorsstång",
    "mormorsstången": "mormorsstång",
    "mormorsstångens": "mormorsstång",
    "mormorsstångs": "mormorsstång",
    "mormödrar": "mormor",
    "mormödrarna": "mormor",
    "mormödrarnas": "mormor",
    "mormödrars": "mormor",
    "mornar": "morgon",
    "mornarna": "morgon",
    "mornarnas": "morgon",
    "mornars": "morgon",
    "moror": "mora",
    "mororna": "mora",
    "morornas": "mora",
    "morors": "mora",
    "morotbladlopp": "morotbladloppa",
    "morotbladloppan": "morotbladloppa",
    "morotbladloppans": "morotbladloppa",
    "morotbladloppas": "morotbladloppa",
    "morotbladloppe": "morotbladloppa",
    "morotbladloppor": "morotbladloppa",
    "morotbladlopporna": "morotbladloppa",
    "morotbladloppornas": "morotbladloppa",
    "morotbladloppors": "morotbladloppa",
    "morotbladlopps": "morotbladloppa",
    "moroten": "morot",
    "morotens": "morot",
    "morots": "morot",
    "morotsflug": "morotsfluga",
    "morotsflugan": "morotsfluga",
    "morotsflugans": "morotsfluga",
    "morotsflugas": "morotsfluga",
    "morotsfluge": "morotsfluga",
    "morotsflugor": "morotsfluga",
    "morotsflugorna": "morotsfluga",
    "morotsflugornas": "morotsfluga",
    "morotsflugors": "morotsfluga",
    "morotsflugs": "morotsfluga",
    "morotskak": "morotskaka",
    "morotskakan": "morotskaka",
    "morotskakans": "morotskaka",
    "morotskakas": "morotskaka",
    "morotskake": "morotskaka",
    "morotskakor": "morotskaka",
    "morotskakorna": "morotskaka",
    "morotskakornas": "morotskaka",
    "morotskakors": "morotskaka",
    "morotskaks": "morotskaka",
    "morrade": "morra",
    "morrades": "morra",
    "morrande": "morra",
    "morranden": "morrande",
    "morrandena": "morrande",
    "morrandenas": "morrande",
    "morrandens": "morrande",
    "morrandes": "morrande",
    "morrandet": "morrande",
    "morrandets": "morrande",
    "morrar": "morra",
    "morras": "morra",
    "morrat": "morra",
    "morrats": "morra",
    "morret": "morr",
    "morrets": "morr",
    "morrhåren": "morrhår",
    "morrhårens": "morrhår",
    "morrhåret": "morrhår",
    "morrhårets": "morrhår",
    "morrhårs": "morrhår",
    "morronen": "morron",
    "morronens": "morron",
    "morrons": "morron",
    "morrs": "morr",
    "mors": "mora",
    "morsade": "morsa",
    "morsades": "morsa",
    "morsan": "morsa",
    "morsande": "morsa",
    "morsanden": "morsande",
    "morsandena": "morsande",
    "morsandenas": "morsande",
    "morsandens": "morsande",
    "morsandes": "morsande",
    "morsandet": "morsande",
    "morsandets": "morsande",
    "morsans": "morsa",
    "morsar": "morsa",
    "morsarven": "morsarv",
    "morsarvens": "morsarv",
    "morsarvet": "morsarv",
    "morsarvets": "morsarv",
    "morsarvs": "morsarv",
    "morsas": "morsa",
    "morsat": "morsa",
    "morsats": "morsa",
    "morsealfabetet": "morsealfabet",
    "morsealfabetets": "morsealfabet",
    "morsealfabets": "morsealfabet",
    "morsefyrar": "morsefyr",
    "morsefyrarna": "morsefyr",
    "morsefyrarnas": "morsefyr",
    "morsefyrars": "morsefyr",
    "morsefyren": "morsefyr",
    "morsefyrens": "morsefyr",
    "morsefyrs": "morsefyr",
    "morserad": "morsera",
    "morserade": "morsera",
    "morserades": "morsera",
    "morserads": "morsera",
    "morserande": "morsera",
    "morseranden": "morserande",
    "morserandena": "morserande",
    "morserandenas": "morserande",
    "morserandens": "morserande",
    "morserandes": "morserande",
    "morserandet": "morserande",
    "morserandets": "morserande",
    "morserar": "morsera",
    "morseras": "morsera",
    "morserat": "morsera",
    "morserats": "morsera",
    "morserbara": "morserbar",
    "morserbarare": "morserbar",
    "morserbarares": "morserbar",
    "morserbaras": "morserbar",
    "morserbarast": "morserbar",
    "morserbaraste": "morserbar",
    "morserbarastes": "morserbar",
    "morserbarasts": "morserbar",
    "morserbare": "morserbar",
    "morserbares": "morserbar",
    "morserbarheten": "morserbarhet",
    "morserbarhetens": "morserbarhet",
    "morserbarhets": "morserbarhet",
    "morserbars": "morserbar",
    "morserbart": "morserbar",
    "morserbarts": "morserbar",
    "morseringar": "morsering",
    "morseringarna": "morsering",
    "morseringarnas": "morsering",
    "morseringars": "morsering",
    "morseringen": "morsering",
    "morseringens": "morsering",
    "morserings": "morsering",
    "morsesignalen": "morsesignal",
    "morsesignalens": "morsesignal",
    "morsesignaler": "morsesignal",
    "morsesignalerna": "morsesignal",
    "morsesignalernas": "morsesignal",
    "morsesignalers": "morsesignal",
    "morsesignals": "morsesignal",
    "morsgrisar": "morsgris",
    "morsgrisarna": "morsgris",
    "morsgrisarnas": "morsgris",
    "morsgrisars": "morsgris",
    "morsgrisen": "morsgris",
    "morsgrisens": "morsgris",
    "morsgum": "morsgumma",
    "morsgumman": "morsgumma",
    "morsgummans": "morsgumma",
    "morsgummas": "morsgumma",
    "morsgumme": "morsgumma",
    "morsgummor": "morsgumma",
    "morsgummorna": "morsgumma",
    "morsgummornas": "morsgumma",
    "morsgummors": "morsgumma",
    "morsgums": "morsgumma",
    "morska": "morsk",
    "morskare": "morsk",
    "morskares": "morsk",
    "morskas": "morsk",
    "morskast": "morsk",
    "morskaste": "morsk",
    "morskastes": "morsk",
    "morskasts": "morsk",
    "morske": "morsk",
    "morskes": "morsk",
    "morskheten": "morskhet",
    "morskhetens": "morskhet",
    "morskhets": "morskhet",
    "morsks": "morsk",
    "morskt": "morsk",
    "morskts": "morsk",
    "morslotten": "morslott",
    "morslottens": "morslott",
    "morslotter": "morslott",
    "morslotterna": "morslott",
    "morslotternas": "morslott",
    "morslotters": "morslott",
    "morslotts": "morslott",
    "morsor": "morsa",
    "morsorna": "morsa",
    "morsornas": "morsa",
    "morsors": "morsa",
    "morssidan": "morssida",
    "morssidans": "morssida",
    "morssidas": "morssida",
    "morsside": "morssida",
    "morssides": "morssida",
    "morssidor": "morssida",
    "morssidorna": "morssida",
    "morssidornas": "morssida",
    "morssidors": "morssida",
    "mortaliteten": "mortalitet",
    "mortalitetens": "mortalitet",
    "mortaliteter": "mortalitet",
    "mortaliteterna": "mortalitet",
    "mortaliteternas": "mortalitet",
    "mortaliteters": "mortalitet",
    "mortalitets": "mortalitet",
    "morteln": "mortel",
    "mortelns": "mortel",
    "mortels": "mortel",
    "mortificerad": "mortificera",
    "mortificerade": "mortificera",
    "mortificerades": "mortificera",
    "mortificerads": "mortificera",
    "mortificerande": "mortificera",
    "mortificeranden": "mortificerande",
    "mortificerandena": "mortificerande",
    "mortificerandenas": "mortificerande",
    "mortificerandens": "mortificerande",
    "mortificerandes": "mortificerande",
    "mortificerandet": "mortificerande",
    "mortificerandets": "mortificerande",
    "mortificerar": "mortificera",
    "mortificeras": "mortificera",
    "mortificerat": "mortificera",
    "mortificerats": "mortificera",
    "mortificerbara": "mortificerbar",
    "mortificerbarare": "mortificerbar",
    "mortificerbarares": "mortificerbar",
    "mortificerbaras": "mortificerbar",
    "mortificerbarast": "mortificerbar",
    "mortificerbaraste": "mortificerbar",
    "mortificerbarastes": "mortificerbar",
    "mortificerbarasts": "mortificerbar",
    "mortificerbare": "mortificerbar",
    "mortificerbares": "mortificerbar",
    "mortificerbarheten": "mortificerbarhet",
    "mortificerbarhetens": "mortificerbarhet",
    "mortificerbarhets": "mortificerbarhet",
    "mortificerbars": "mortificerbar",
    "mortificerbart": "mortificerbar",
    "mortificerbarts": "mortificerbar",
    "mortificeringar": "mortificering",
    "mortificeringarna": "mortificering",
    "mortificeringarnas": "mortificering",
    "mortificeringars": "mortificering",
    "mortificeringen": "mortificering",
    "mortificeringens": "mortificering",
    "mortificerings": "mortificering",
    "mortifierad": "mortifiera",
    "mortifierade": "mortifiera",
    "mortifierades": "mortifiera",
    "mortifierads": "mortifiera",
    "mortifierande": "mortifiera",
    "mortifieranden": "mortifierande",
    "mortifierandena": "mortifierande",
    "mortifierandenas": "mortifierande",
    "mortifierandens": "mortifierande",
    "mortifierandes": "mortifierande",
    "mortifierandet": "mortifierande",
    "mortifierandets": "mortifierande",
    "mortifierar": "mortifiera",
    "mortifieras": "mortifiera",
    "mortifierat": "mortifiera",
    "mortifierats": "mortifiera",
    "mortifierbara": "mortifierbar",
    "mortifierbarare": "mortifierbar",
    "mortifierbarares": "mortifierbar",
    "mortifierbaras": "mortifierbar",
    "mortifierbarast": "mortifierbar",
    "mortifierbaraste": "mortifierbar",
    "mortifierbarastes": "mortifierbar",
    "mortifierbarasts": "mortifierbar",
    "mortifierbare": "mortifierbar",
    "mortifierbares": "mortifierbar",
    "mortifierbarheten": "mortifierbarhet",
    "mortifierbarhetens": "mortifierbarhet",
    "mortifierbarhets": "mortifierbarhet",
    "mortifierbars": "mortifierbar",
    "mortifierbart": "mortifierbar",
    "mortifierbarts": "mortifierbar",
    "mortifieringar": "mortifiering",
    "mortifieringarna": "mortifiering",
    "mortifieringarnas": "mortifiering",
    "mortifieringars": "mortifiering",
    "mortifieringen": "mortifiering",
    "mortifieringens": "mortifiering",
    "mortifierings": "mortifiering",
    "mortifikationen": "mortifikation",
    "mortifikationens": "mortifikation",
    "mortifikationer": "mortifikation",
    "mortifikationerna": "mortifikation",
    "mortifikationernas": "mortifikation",
    "mortifikationers": "mortifikation",
    "mortifikations": "mortifikation",
    "mortlar": "mortel",
    "mortlarna": "mortel",
    "mortlarnas": "mortel",
    "mortlars": "mortel",
    "moränen": "morän",
    "moränens": "morän",
    "moräner": "morän",
    "moränerna": "morän",
    "moränernas": "morän",
    "moräners": "morän",
    "moränmarken": "moränmark",
    "moränmarkens": "moränmark",
    "moränmarker": "moränmark",
    "moränmarkerna": "moränmark",
    "moränmarkernas": "moränmark",
    "moränmarkers": "moränmark",
    "moränmarks": "moränmark",
    "moräns": "morän",
    "moränsluttningar": "moränsluttning",
    "moränsluttningarna": "moränsluttning",
    "moränsluttningarnas": "moränsluttning",
    "moränsluttningars": "moränsluttning",
    "moränsluttningen": "moränsluttning",
    "moränsluttningens": "moränsluttning",
    "moränsluttnings": "moränsluttning",
    "morötter": "morot",
    "morötterna": "morot",
    "morötternas": "morot",
    "morötters": "morot",
    "mos": "mosa",
    "mosad": "mosa",
    "mosade": "mosa",
    "mosades": "mosa",
    "mosads": "mosa",
    "mosaikartade": "mosaikartad",
    "mosaikartades": "mosaikartad",
    "mosaikartads": "mosaikartad",
    "mosaikartat": "mosaikartad",
    "mosaikartats": "mosaikartad",
    "mosaiken": "mosaik",
    "mosaikens": "mosaik",
    "mosaiker": "mosaik",
    "mosaikerna": "mosaik",
    "mosaikernas": "mosaik",
    "mosaikers": "mosaik",
    "mosaikinramade": "mosaikinramad",
    "mosaikinramades": "mosaikinramad",
    "mosaikinramads": "mosaikinramad",
    "mosaikinramat": "mosaikinramad",
    "mosaikinramats": "mosaikinramad",
    "mosaiklandskapen": "mosaiklandskap",
    "mosaiklandskapens": "mosaiklandskap",
    "mosaiklandskapet": "mosaiklandskap",
    "mosaiklandskapets": "mosaiklandskap",
    "mosaiklandskaps": "mosaiklandskap",
    "mosaikmönsterna": "mosaikmönster",
    "mosaikmönsternas": "mosaikmönster",
    "mosaikmönsters": "mosaikmönster",
    "mosaikmönstren": "mosaikmönster",
    "mosaikmönstrens": "mosaikmönster",
    "mosaikmönstret": "mosaikmönster",
    "mosaikmönstrets": "mosaikmönster",
    "mosaiks": "mosaik",
    "mosaiksjukan": "mosaiksjuka",
    "mosaiksjukans": "mosaiksjuka",
    "mosaiksjukas": "mosaiksjuka",
    "mosaiksjuke": "mosaiksjuka",
    "mosaiksjuks": "mosaiksjuka",
    "mosaiksömmar": "mosaiksöm",
    "mosaiksömmarna": "mosaiksöm",
    "mosaiksömmarnas": "mosaiksöm",
    "mosaiksömmars": "mosaiksöm",
    "mosaiksömmen": "mosaiksöm",
    "mosaiksömmens": "mosaiksöm",
    "mosaiksöms": "mosaiksöm",
    "mosaiska": "mosaisk",
    "mosaiskare": "mosaisk",
    "mosaiskares": "mosaisk",
    "mosaiskas": "mosaisk",
    "mosaiskast": "mosaisk",
    "mosaiskaste": "mosaisk",
    "mosaiskastes": "mosaisk",
    "mosaiskasts": "mosaisk",
    "mosaiske": "mosaisk",
    "mosaiskes": "mosaisk",
    "mosaisks": "mosaisk",
    "mosaiskt": "mosaisk",
    "mosaiskts": "mosaisk",
    "mosande": "mosa",
    "mosanden": "mosande",
    "mosandena": "mosande",
    "mosandenas": "mosande",
    "mosandens": "mosande",
    "mosandes": "mosande",
    "mosandet": "mosande",
    "mosandets": "mosande",
    "mosar": "mosa",
    "mosas": "mosa",
    "mosat": "mosa",
    "mosats": "mosa",
    "moseln": "mosel",
    "moselns": "mosel",
    "mosels": "mosel",
    "moselviner": "moselvin",
    "moselvinerna": "moselvin",
    "moselvinernas": "moselvin",
    "moselviners": "moselvin",
    "moselvinet": "moselvin",
    "moselvinets": "moselvin",
    "moselvins": "moselvin",
    "moset": "mos",
    "mosets": "mos",
    "mosiga": "mosig",
    "mosigare": "mosig",
    "mosigares": "mosig",
    "mosigas": "mosig",
    "mosigast": "mosig",
    "mosigaste": "mosig",
    "mosigastes": "mosig",
    "mosigasts": "mosig",
    "mosige": "mosig",
    "mosiges": "mosig",
    "mosigs": "mosig",
    "mosigt": "mosig",
    "mosigts": "mosig",
    "mosipp": "mosippa",
    "mosippan": "mosippa",
    "mosippans": "mosippa",
    "mosippas": "mosippa",
    "mosippe": "mosippa",
    "mosippor": "mosippa",
    "mosipporna": "mosippa",
    "mosippornas": "mosippa",
    "mosippors": "mosippa",
    "mosipps": "mosippa",
    "moskiten": "moskit",
    "moskitens": "moskit",
    "moskiter": "moskit",
    "moskiterna": "moskit",
    "moskiternas": "moskit",
    "moskiters": "moskit",
    "moskitnäten": "moskitnät",
    "moskitnätens": "moskitnät",
    "moskitnätet": "moskitnät",
    "moskitnätets": "moskitnät",
    "moskitnäts": "moskitnät",
    "moskits": "moskit",
    "moskoviten": "moskovit",
    "moskovitens": "moskovit",
    "moskoviter": "moskovit",
    "moskoviterna": "moskovit",
    "moskoviternas": "moskovit",
    "moskoviters": "moskovit",
    "moskovitiska": "moskovitisk",
    "moskovitiskare": "moskovitisk",
    "moskovitiskares": "moskovitisk",
    "moskovitiskas": "moskovitisk",
    "moskovitiskast": "moskovitisk",
    "moskovitiskaste": "moskovitisk",
    "moskovitiskastes": "moskovitisk",
    "moskovitiskasts": "moskovitisk",
    "moskovitiske": "moskovitisk",
    "moskovitiskes": "moskovitisk",
    "moskovitisks": "moskovitisk",
    "moskovitiskt": "moskovitisk",
    "moskovitiskts": "moskovitisk",
    "moskovits": "moskovit",
    "moskéer": "moské",
    "moskéerna": "moské",
    "moskéernas": "moské",
    "moskéers": "moské",
    "moskén": "moské",
    "moskéns": "moské",
    "moskés": "moské",
    "moskévandalen": "moskévandal",
    "moskévandalens": "moskévandal",
    "moskévandaler": "moskévandal",
    "moskévandalerna": "moskévandal",
    "moskévandalernas": "moskévandal",
    "moskévandalers": "moskévandal",
    "moskévandals": "moskévandal",
    "mosnäppan": "mosnäppa",
    "mosnäppans": "mosnäppa",
    "mosnäppas": "mosnäppa",
    "mosnäppe": "mosnäppa",
    "mosnäppor": "mosnäppa",
    "mosnäpporna": "mosnäppa",
    "mosnäppornas": "mosnäppa",
    "mosnäppors": "mosnäppa",
    "moss": "mosse",
    "mossan": "mossa",
    "mossans": "mossa",
    "mossar": "mosse",
    "mossarna": "mosse",
    "mossarnas": "mosse",
    "mossars": "mosse",
    "mossas": "mossa",
    "mossbelupenheten": "mossbelupenhet",
    "mossbelupenhetens": "mossbelupenhet",
    "mossbelupenhets": "mossbelupenhet",
    "mossbelupens": "mossbelupen",
    "mossbelupet": "mossbelupen",
    "mossbelupets": "mossbelupen",
    "mossbelupna": "mossbelupen",
    "mossbelupnare": "mossbelupen",
    "mossbelupnares": "mossbelupen",
    "mossbelupnas": "mossbelupen",
    "mossbelupnast": "mossbelupen",
    "mossbelupnaste": "mossbelupen",
    "mossbelupnastes": "mossbelupen",
    "mossbelupnasts": "mossbelupen",
    "mossbelupne": "mossbelupen",
    "mossbelupnes": "mossbelupen",
    "mosse": "mossa",
    "mossen": "mosse",
    "mossens": "mosse",
    "mosses": "mosse",
    "mossfolken": "mossfolk",
    "mossfolkens": "mossfolk",
    "mossfolket": "mossfolk",
    "mossfolkets": "mossfolk",
    "mossfolks": "mossfolk",
    "mossfynden": "mossfynd",
    "mossfyndens": "mossfynd",
    "mossfyndet": "mossfynd",
    "mossfyndets": "mossfynd",
    "mossfynds": "mossfynd",
    "mossgröna": "mossgrön",
    "mossgrönare": "mossgrön",
    "mossgrönares": "mossgrön",
    "mossgrönas": "mossgrön",
    "mossgrönast": "mossgrön",
    "mossgrönaste": "mossgrön",
    "mossgrönastes": "mossgrön",
    "mossgrönasts": "mossgrön",
    "mossgröne": "mossgrön",
    "mossgrönes": "mossgrön",
    "mossgröns": "mossgrön",
    "mossgrönt": "mossgrön",
    "mossgrönts": "mossgrön",
    "mossiga": "mossig",
    "mossigare": "mossig",
    "mossigares": "mossig",
    "mossigas": "mossig",
    "mossigast": "mossig",
    "mossigaste": "mossig",
    "mossigastes": "mossig",
    "mossigasts": "mossig",
    "mossige": "mossig",
    "mossiges": "mossig",
    "mossigheten": "mossighet",
    "mossighetens": "mossighet",
    "mossighets": "mossighet",
    "mossigs": "mossig",
    "mossigt": "mossig",
    "mossigts": "mossig",
    "mosskulturen": "mosskultur",
    "mosskulturens": "mosskultur",
    "mosskulturer": "mosskultur",
    "mosskulturerna": "mosskultur",
    "mosskulturernas": "mosskultur",
    "mosskulturers": "mosskultur",
    "mosskulturs": "mosskultur",
    "mossliken": "mosslik",
    "mosslikens": "mosslik",
    "mossliket": "mosslik",
    "mosslikets": "mosslik",
    "mossliks": "mosslik",
    "mossljungen": "mossljung",
    "mossljungens": "mossljung",
    "mossljungs": "mossljung",
    "mossor": "mossa",
    "mossorna": "mossa",
    "mossornas": "mossa",
    "mossors": "mossa",
    "mossrosen": "mossros",
    "mossrosens": "mossros",
    "mossrosor": "mossros",
    "mossrosorna": "mossros",
    "mossrosornas": "mossros",
    "mossrosors": "mossros",
    "mossroten": "mossrot",
    "mossrotens": "mossrot",
    "mossrots": "mossrot",
    "mossrötter": "mossrot",
    "mossrötterna": "mossrot",
    "mossrötternas": "mossrot",
    "mossrötters": "mossrot",
    "mosstorven": "mosstorv",
    "mosstorvens": "mosstorv",
    "mosstorvs": "mosstorv",
    "mosterliga": "mosterlig",
    "mosterligare": "mosterlig",
    "mosterligares": "mosterlig",
    "mosterligas": "mosterlig",
    "mosterligast": "mosterlig",
    "mosterligaste": "mosterlig",
    "mosterligastes": "mosterlig",
    "mosterligasts": "mosterlig",
    "mosterlige": "mosterlig",
    "mosterliges": "mosterlig",
    "mosterligheten": "mosterlighet",
    "mosterlighetens": "mosterlighet",
    "mosterlighets": "mosterlighet",
    "mosterligs": "mosterlig",
    "mosterligt": "mosterlig",
    "mosterligts": "mosterlig",
    "mostern": "moster",
    "mosterns": "moster",
    "mosters": "moster",
    "mostrar": "moster",
    "mostrarna": "moster",
    "mostrarnas": "moster",
    "mostrars": "moster",
    "mot": "mota",
    "motad": "mota",
    "motade": "mota",
    "motades": "mota",
    "motads": "mota",
    "motaktionen": "motaktion",
    "motaktionens": "motaktion",
    "motaktioner": "motaktion",
    "motaktionerna": "motaktion",
    "motaktionernas": "motaktion",
    "motaktioners": "motaktion",
    "motaktions": "motaktion",
    "motande": "mota",
    "motanden": "motande",
    "motandena": "motande",
    "motandenas": "motande",
    "motandens": "motande",
    "motandes": "motande",
    "motandet": "motande",
    "motandets": "motande",
    "motanfallen": "motanfall",
    "motanfallens": "motanfall",
    "motanfallet": "motanfall",
    "motanfallets": "motanfall",
    "motanfalls": "motanfall",
    "motangreppen": "motangrepp",
    "motangreppens": "motangrepp",
    "motangreppet": "motangrepp",
    "motangreppets": "motangrepp",
    "motangrepps": "motangrepp",
    "motar": "mota",
    "motarbet": "motarbeta",
    "motarbetad": "motarbeta",
    "motarbetade": "motarbeta",
    "motarbetades": "motarbeta",
    "motarbetads": "motarbeta",
    "motarbetande": "motarbeta",
    "motarbetanden": "motarbetande",
    "motarbetandena": "motarbetande",
    "motarbetandenas": "motarbetande",
    "motarbetandens": "motarbetande",
    "motarbetandes": "motarbetande",
    "motarbetandet": "motarbetande",
    "motarbetandets": "motarbetande",
    "motarbetar": "motarbeta",
    "motarbetas": "motarbeta",
    "motarbetat": "motarbeta",
    "motarbetats": "motarbeta",
    "motargumenten": "motargument",
    "motargumentens": "motargument",
    "motargumentet": "motargument",
    "motargumentets": "motargument",
    "motarguments": "motargument",
    "motas": "mota",
    "motat": "mota",
    "motats": "mota",
    "motbevis": "motbevisa",
    "motbevisad": "motbevisa",
    "motbevisade": "motbevisa",
    "motbevisades": "motbevisa",
    "motbevisads": "motbevisa",
    "motbevisande": "motbevisa",
    "motbevisanden": "motbevisande",
    "motbevisandena": "motbevisande",
    "motbevisandenas": "motbevisande",
    "motbevisandens": "motbevisande",
    "motbevisandes": "motbevisande",
    "motbevisandet": "motbevisande",
    "motbevisandets": "motbevisande",
    "motbevisar": "motbevisa",
    "motbevisas": "motbevisa",
    "motbevisat": "motbevisa",
    "motbevisats": "motbevisa",
    "motbevisen": "motbevis",
    "motbevisens": "motbevis",
    "motbeviset": "motbevis",
    "motbevisets": "motbevis",
    "motbilden": "motbild",
    "motbildens": "motbild",
    "motbilder": "motbild",
    "motbilderna": "motbild",
    "motbildernas": "motbild",
    "motbilders": "motbild",
    "motbilds": "motbild",
    "motboken": "motbok",
    "motbokens": "motbok",
    "motboks": "motbok",
    "motböcker": "motbok",
    "motböckerna": "motbok",
    "motböckernas": "motbok",
    "motböckers": "motbok",
    "motdemonstranten": "motdemonstrant",
    "motdemonstrantens": "motdemonstrant",
    "motdemonstranter": "motdemonstrant",
    "motdemonstranterna": "motdemonstrant",
    "motdemonstranternas": "motdemonstrant",
    "motdemonstranters": "motdemonstrant",
    "motdemonstrants": "motdemonstrant",
    "motdragen": "motdrag",
    "motdragens": "motdrag",
    "motdraget": "motdrag",
    "motdragets": "motdrag",
    "motdrags": "motdrag",
    "motelden": "moteld",
    "moteldens": "moteld",
    "motelds": "moteld",
    "motellchefen": "motellchef",
    "motellchefens": "motellchef",
    "motellchefer": "motellchef",
    "motellcheferna": "motellchef",
    "motellchefernas": "motellchef",
    "motellchefers": "motellchef",
    "motellchefs": "motellchef",
    "motellen": "motell",
    "motellens": "motell",
    "motellet": "motell",
    "motellets": "motell",
    "motells": "motell",
    "moten": "mot",
    "motens": "mot",
    "motet": "mot",
    "motets": "mot",
    "motetten": "motett",
    "motettens": "motett",
    "motetter": "motett",
    "motetterna": "motett",
    "motetternas": "motett",
    "motetters": "motett",
    "motetts": "motett",
    "motfrågan": "motfråga",
    "motfrågans": "motfråga",
    "motfrågas": "motfråga",
    "motfråge": "motfråga",
    "motfrågor": "motfråga",
    "motfrågorna": "motfråga",
    "motfrågornas": "motfråga",
    "motfrågors": "motfråga",
    "motgifter": "motgift",
    "motgifterna": "motgift",
    "motgifternas": "motgift",
    "motgifters": "motgift",
    "motgiftet": "motgift",
    "motgiftets": "motgift",
    "motgifts": "motgift",
    "motgångar": "motgång",
    "motgångarna": "motgång",
    "motgångarnas": "motgång",
    "motgångars": "motgång",
    "motgången": "motgång",
    "motgångens": "motgång",
    "motgångs": "motgång",
    "mothuggen": "mothugg",
    "mothuggens": "mothugg",
    "mothugget": "mothugg",
    "mothuggets": "mothugg",
    "mothuggs": "mothugg",
    "mothållen": "mothåll",
    "mothållens": "mothåll",
    "mothållet": "mothåll",
    "mothållets": "mothåll",
    "mothålls": "mothåll",
    "motiga": "motig",
    "motigare": "motig",
    "motigares": "motig",
    "motigas": "motig",
    "motigast": "motig",
    "motigaste": "motig",
    "motigastes": "motig",
    "motigasts": "motig",
    "motige": "motig",
    "motiges": "motig",
    "motigheten": "motighet",
    "motighetens": "motighet",
    "motigheter": "motighet",
    "motigheterna": "motighet",
    "motigheternas": "motighet",
    "motigheters": "motighet",
    "motighets": "motighet",
    "motigs": "motig",
    "motigt": "motig",
    "motigts": "motig",
    "motionen": "motion",
    "motionens": "motion",
    "motioner": "motion",
    "motionerade": "motionera",
    "motionerades": "motionera",
    "motionerande": "motionera",
    "motioneranden": "motionerande",
    "motionerandena": "motionerande",
    "motionerandenas": "motionerande",
    "motionerandens": "motionerande",
    "motionerandes": "motionerande",
    "motionerandet": "motionerande",
    "motionerandets": "motionerande",
    "motionerar": "motionera",
    "motioneras": "motionera",
    "motionerat": "motionera",
    "motionerats": "motionera",
    "motioneringar": "motionering",
    "motioneringarna": "motionering",
    "motioneringarnas": "motionering",
    "motioneringars": "motionering",
    "motioneringen": "motionering",
    "motioneringens": "motionering",
    "motionerings": "motionering",
    "motionerna": "motion",
    "motionernas": "motion",
    "motioners": "motion",
    "motions": "motion",
    "motionsanläggningar": "motionsanläggning",
    "motionsanläggningarna": "motionsanläggning",
    "motionsanläggningarnas": "motionsanläggning",
    "motionsanläggningars": "motionsanläggning",
    "motionsanläggningen": "motionsanläggning",
    "motionsanläggningens": "motionsanläggning",
    "motionsanläggnings": "motionsanläggning",
    "motionscykeln": "motionscykel",
    "motionscykelns": "motionscykel",
    "motionscykels": "motionscykel",
    "motionscyklar": "motionscykel",
    "motionscyklarna": "motionscykel",
    "motionscyklarnas": "motionscykel",
    "motionscyklars": "motionscykel",
    "motionsfloden": "motionsflod",
    "motionsflodens": "motionsflod",
    "motionsfloder": "motionsflod",
    "motionsfloderna": "motionsflod",
    "motionsflodernas": "motionsflod",
    "motionsfloders": "motionsflod",
    "motionsflods": "motionsflod",
    "motionsgymnastiken": "motionsgymnastik",
    "motionsgymnastikens": "motionsgymnastik",
    "motionsgymnastiks": "motionsgymnastik",
    "motionsidrotten": "motionsidrott",
    "motionsidrottens": "motionsidrott",
    "motionsidrotter": "motionsidrott",
    "motionsidrotterna": "motionsidrott",
    "motionsidrotternas": "motionsidrott",
    "motionsidrotters": "motionsidrott",
    "motionsidrotts": "motionsidrott",
    "motionsrätten": "motionsrätt",
    "motionsrättens": "motionsrätt",
    "motionsrätts": "motionsrätt",
    "motionsspåren": "motionsspår",
    "motionsspårens": "motionsspår",
    "motionsspåret": "motionsspår",
    "motionsspårets": "motionsspår",
    "motionsspårs": "motionsspår",
    "motionstiden": "motionstid",
    "motionstidens": "motionstid",
    "motionstider": "motionstid",
    "motionstiderna": "motionstid",
    "motionstidernas": "motionstid",
    "motionstiders": "motionstid",
    "motionstids": "motionstid",
    "motionsvanan": "motionsvana",
    "motionsvanans": "motionsvana",
    "motionsvanas": "motionsvana",
    "motionsvane": "motionsvana",
    "motionsvanor": "motionsvana",
    "motionsvanorna": "motionsvana",
    "motionsvanornas": "motionsvana",
    "motionsvanors": "motionsvana",
    "motionären": "motionär",
    "motionärens": "motionär",
    "motionärer": "motionär",
    "motionärerna": "motionär",
    "motionärernas": "motionär",
    "motionärers": "motionär",
    "motionärs": "motionär",
    "motivationen": "motivation",
    "motivationens": "motivation",
    "motivationer": "motivation",
    "motivationerna": "motivation",
    "motivationernas": "motivation",
    "motivationers": "motivation",
    "motivations": "motivation",
    "motivationskonsulten": "motivationskonsult",
    "motivationskonsultens": "motivationskonsult",
    "motivationskonsulter": "motivationskonsult",
    "motivationskonsulterna": "motivationskonsult",
    "motivationskonsulternas": "motivationskonsult",
    "motivationskonsulters": "motivationskonsult",
    "motivationskonsults": "motivationskonsult",
    "motivationsmässiga": "motivationsmässig",
    "motivationsmässigare": "motivationsmässig",
    "motivationsmässigares": "motivationsmässig",
    "motivationsmässigas": "motivationsmässig",
    "motivationsmässigast": "motivationsmässig",
    "motivationsmässigaste": "motivationsmässig",
    "motivationsmässigastes": "motivationsmässig",
    "motivationsmässigasts": "motivationsmässig",
    "motivationsmässige": "motivationsmässig",
    "motivationsmässiges": "motivationsmässig",
    "motivationsmässigs": "motivationsmässig",
    "motivationsmässigt": "motivationsmässig",
    "motivationsmässigts": "motivationsmässig",
    "motiven": "motiv",
    "motivens": "motiv",
    "motiverad": "motivera",
    "motiverade": "motiverad",
    "motiverades": "motiverad",
    "motiverads": "motiverad",
    "motiverande": "motivera",
    "motiveranden": "motiverande",
    "motiverandena": "motiverande",
    "motiverandenas": "motiverande",
    "motiverandens": "motiverande",
    "motiverandes": "motiverande",
    "motiverandet": "motiverande",
    "motiverandets": "motiverande",
    "motiverar": "motivera",
    "motiveras": "motivera",
    "motiverat": "motiverad",
    "motiverats": "motiverad",
    "motiverbara": "motiverbar",
    "motiverbarare": "motiverbar",
    "motiverbarares": "motiverbar",
    "motiverbaras": "motiverbar",
    "motiverbarast": "motiverbar",
    "motiverbaraste": "motiverbar",
    "motiverbarastes": "motiverbar",
    "motiverbarasts": "motiverbar",
    "motiverbare": "motiverbar",
    "motiverbares": "motiverbar",
    "motiverbarheten": "motiverbarhet",
    "motiverbarhetens": "motiverbarhet",
    "motiverbarhets": "motiverbarhet",
    "motiverbars": "motiverbar",
    "motiverbart": "motiverbar",
    "motiverbarts": "motiverbar",
    "motiveringar": "motivering",
    "motiveringarna": "motivering",
    "motiveringarnas": "motivering",
    "motiveringars": "motivering",
    "motiveringen": "motivering",
    "motiveringens": "motivering",
    "motiverings": "motivering",
    "motivet": "motiv",
    "motivets": "motiv",
    "motiviska": "motivisk",
    "motiviskare": "motivisk",
    "motiviskares": "motivisk",
    "motiviskas": "motivisk",
    "motiviskast": "motivisk",
    "motiviskaste": "motivisk",
    "motiviskastes": "motivisk",
    "motiviskasts": "motivisk",
    "motiviske": "motivisk",
    "motiviskes": "motivisk",
    "motivisks": "motivisk",
    "motiviskt": "motivisk",
    "motiviskts": "motivisk",
    "motivkretsar": "motivkrets",
    "motivkretsarna": "motivkrets",
    "motivkretsarnas": "motivkrets",
    "motivkretsars": "motivkrets",
    "motivkretsen": "motivkrets",
    "motivkretsens": "motivkrets",
    "motivmässiga": "motivmässig",
    "motivmässigare": "motivmässig",
    "motivmässigares": "motivmässig",
    "motivmässigas": "motivmässig",
    "motivmässigast": "motivmässig",
    "motivmässigaste": "motivmässig",
    "motivmässigastes": "motivmässig",
    "motivmässigasts": "motivmässig",
    "motivmässige": "motivmässig",
    "motivmässiges": "motivmässig",
    "motivmässigs": "motivmässig",
    "motivmässigt": "motivmässig",
    "motivmässigts": "motivmässig",
    "motivs": "motiv",
    "motkraften": "motkraft",
    "motkraftens": "motkraft",
    "motkrafter": "motkraft",
    "motkrafterna": "motkraft",
    "motkrafternas": "motkraft",
    "motkrafters": "motkraft",
    "motkrafts": "motkraft",
    "motkraven": "motkrav",
    "motkravens": "motkrav",
    "motkravet": "motkrav",
    "motkravets": "motkrav",
    "motkravs": "motkrav",
    "motljuset": "motljus",
    "motljusets": "motljus",
    "motluten": "motlut",
    "motlutens": "motlut",
    "motlutet": "motlut",
    "motlutets": "motlut",
    "motluts": "motlut",
    "motläs": "motläsa",
    "motläsande": "motläsa",
    "motläsanden": "motläsande",
    "motläsandena": "motläsande",
    "motläsandenas": "motläsande",
    "motläsandens": "motläsande",
    "motläsandes": "motläsande",
    "motläsandet": "motläsande",
    "motläsandets": "motläsande",
    "motläsas": "motläsa",
    "motläser": "motläsa",
    "motläses": "motläsa",
    "motläst": "motläsa",
    "motlästa": "motläsa",
    "motlästas": "motläsa",
    "motläste": "motläsa",
    "motlästes": "motläsa",
    "motlästs": "motläsa",
    "motocrossen": "motocross",
    "motocrossens": "motocross",
    "motoffensiven": "motoffensiv",
    "motoffensivens": "motoffensiv",
    "motoffensiver": "motoffensiv",
    "motoffensiverna": "motoffensiv",
    "motoffensivernas": "motoffensiv",
    "motoffensivers": "motoffensiv",
    "motoffensivs": "motoffensiv",
    "motorbränslen": "motorbränsle",
    "motorbränslena": "motorbränsle",
    "motorbränslenas": "motorbränsle",
    "motorbränslens": "motorbränsle",
    "motorbränsles": "motorbränsle",
    "motorbränslet": "motorbränsle",
    "motorbränslets": "motorbränsle",
    "motorbåtar": "motorbåt",
    "motorbåtarna": "motorbåt",
    "motorbåtarnas": "motorbåt",
    "motorbåtars": "motorbåt",
    "motorbåten": "motorbåt",
    "motorbåtens": "motorbåt",
    "motorbåts": "motorbåt",
    "motorcykelhjälmar": "motorcykelhjälm",
    "motorcykelhjälmarna": "motorcykelhjälm",
    "motorcykelhjälmarnas": "motorcykelhjälm",
    "motorcykelhjälmars": "motorcykelhjälm",
    "motorcykelhjälmen": "motorcykelhjälm",
    "motorcykelhjälmens": "motorcykelhjälm",
    "motorcykelhjälms": "motorcykelhjälm",
    "motorcykellyftar": "motorcykellyft",
    "motorcykellyftarna": "motorcykellyft",
    "motorcykellyftarnas": "motorcykellyft",
    "motorcykellyftars": "motorcykellyft",
    "motorcykellyften": "motorcykellyft",
    "motorcykellyftens": "motorcykellyft",
    "motorcykellyfts": "motorcykellyft",
    "motorcykeln": "motorcykel",
    "motorcykelns": "motorcykel",
    "motorcykels": "motorcykel",
    "motorcykelställen": "motorcykelställ",
    "motorcykelställens": "motorcykelställ",
    "motorcykelstället": "motorcykelställ",
    "motorcykelställets": "motorcykelställ",
    "motorcykelställs": "motorcykelställ",
    "motorcykeltävlingar": "motorcykeltävling",
    "motorcykeltävlingarna": "motorcykeltävling",
    "motorcykeltävlingarnas": "motorcykeltävling",
    "motorcykeltävlingars": "motorcykeltävling",
    "motorcykeltävlingen": "motorcykeltävling",
    "motorcykeltävlingens": "motorcykeltävling",
    "motorcykeltävlings": "motorcykeltävling",
    "motorcyklar": "motorcykel",
    "motorcyklarna": "motorcykel",
    "motorcyklarnas": "motorcykel",
    "motorcyklars": "motorcykel",
    "motorcyklisten": "motorcyklist",
    "motorcyklistens": "motorcyklist",
    "motorcyklister": "motorcyklist",
    "motorcyklisterna": "motorcyklist",
    "motorcyklisternas": "motorcyklist",
    "motorcyklisters": "motorcyklist",
    "motorcyklists": "motorcyklist",
    "motorcylindern": "motorcylinder",
    "motorcylinderns": "motorcylinder",
    "motorcylinders": "motorcylinder",
    "motorcylindrar": "motorcylinder",
    "motorcylindrarna": "motorcylinder",
    "motorcylindrarnas": "motorcylinder",
    "motorcylindrars": "motorcylinder",
    "motordrivens": "motordriven",
    "motordrivet": "motordriven",
    "motordrivets": "motordriven",
    "motordrivna": "motordriven",
    "motordrivnare": "motordriven",
    "motordrivnares": "motordriven",
    "motordrivnas": "motordriven",
    "motordrivnast": "motordriven",
    "motordrivnaste": "motordriven",
    "motordrivnastes": "motordriven",
    "motordrivnasts": "motordriven",
    "motordrivne": "motordriven",
    "motordrivnes": "motordriven",
    "motoreffekten": "motoreffekt",
    "motoreffektens": "motoreffekt",
    "motoreffekter": "motoreffekt",
    "motoreffekterna": "motoreffekt",
    "motoreffekternas": "motoreffekt",
    "motoreffekters": "motoreffekt",
    "motoreffekts": "motoreffekt",
    "motorer": "motor",
    "motorerna": "motor",
    "motorernas": "motor",
    "motorers": "motor",
    "motorfartygen": "motorfartyg",
    "motorfartygens": "motorfartyg",
    "motorfartyget": "motorfartyg",
    "motorfartygets": "motorfartyg",
    "motorfartygs": "motorfartyg",
    "motorfordonen": "motorfordon",
    "motorfordonens": "motorfordon",
    "motorfordonet": "motorfordon",
    "motorfordonets": "motorfordon",
    "motorfordons": "motorfordon",
    "motorhotellen": "motorhotell",
    "motorhotellens": "motorhotell",
    "motorhotellet": "motorhotell",
    "motorhotellets": "motorhotell",
    "motorhotells": "motorhotell",
    "motorhuvar": "motorhuv",
    "motorhuvarna": "motorhuv",
    "motorhuvarnas": "motorhuv",
    "motorhuvars": "motorhuv",
    "motorhuven": "motorhuv",
    "motorhuvens": "motorhuv",
    "motorhuvs": "motorhuv",
    "motoriken": "motorik",
    "motorikens": "motorik",
    "motoriks": "motorik",
    "motoriserad": "motorisera",
    "motoriserade": "motorisera",
    "motoriserades": "motorisera",
    "motoriserads": "motorisera",
    "motoriserande": "motorisera",
    "motoriseranden": "motoriserande",
    "motoriserandena": "motoriserande",
    "motoriserandenas": "motoriserande",
    "motoriserandens": "motoriserande",
    "motoriserandes": "motoriserande",
    "motoriserandet": "motoriserande",
    "motoriserandets": "motoriserande",
    "motoriserar": "motorisera",
    "motoriseras": "motorisera",
    "motoriserat": "motorisera",
    "motoriserats": "motorisera",
    "motoriserbara": "motoriserbar",
    "motoriserbarare": "motoriserbar",
    "motoriserbarares": "motoriserbar",
    "motoriserbaras": "motoriserbar",
    "motoriserbarast": "motoriserbar",
    "motoriserbaraste": "motoriserbar",
    "motoriserbarastes": "motoriserbar",
    "motoriserbarasts": "motoriserbar",
    "motoriserbare": "motoriserbar",
    "motoriserbares": "motoriserbar",
    "motoriserbarheten": "motoriserbarhet",
    "motoriserbarhetens": "motoriserbarhet",
    "motoriserbarhets": "motoriserbarhet",
    "motoriserbars": "motoriserbar",
    "motoriserbart": "motoriserbar",
    "motoriserbarts": "motoriserbar",
    "motoriseringar": "motorisering",
    "motoriseringarna": "motorisering",
    "motoriseringarnas": "motorisering",
    "motoriseringars": "motorisering",
    "motoriseringen": "motorisering",
    "motoriseringens": "motorisering",
    "motoriserings": "motorisering",
    "motoriska": "motorisk",
    "motoriskare": "motorisk",
    "motoriskares": "motorisk",
    "motoriskas": "motorisk",
    "motoriskast": "motorisk",
    "motoriskaste": "motorisk",
    "motoriskastes": "motorisk",
    "motoriskasts": "motorisk",
    "motoriske": "motorisk",
    "motoriskes": "motorisk",
    "motorisks": "motorisk",
    "motoriskt": "motorisk",
    "motoriskts": "motorisk",
    "motorismen": "motorism",
    "motorismens": "motorism",
    "motorismer": "motorism",
    "motorismerna": "motorism",
    "motorismernas": "motorism",
    "motorismers": "motorism",
    "motorisms": "motorism",
    "motoristen": "motorist",
    "motoristens": "motorist",
    "motorister": "motorist",
    "motoristerna": "motorist",
    "motoristernas": "motorist",
    "motoristers": "motorist",
    "motorists": "motorist",
    "motorkryssar": "motorkryssare",
    "motorkryssaren": "motorkryssare",
    "motorkryssarens": "motorkryssare",
    "motorkryssares": "motorkryssare",
    "motorkryssarna": "motorkryssare",
    "motorkryssarnas": "motorkryssare",
    "motorljuden": "motorljud",
    "motorljudens": "motorljud",
    "motorljudet": "motorljud",
    "motorljudets": "motorljud",
    "motorljuds": "motorljud",
    "motorlyftar": "motorlyft",
    "motorlyftarna": "motorlyft",
    "motorlyftarnas": "motorlyft",
    "motorlyftars": "motorlyft",
    "motorlyften": "motorlyft",
    "motorlyftens": "motorlyft",
    "motorlyfts": "motorlyft",
    "motormannen": "motorman",
    "motormannens": "motorman",
    "motormans": "motorman",
    "motormän": "motorman",
    "motormännen": "motorman",
    "motormännens": "motorman",
    "motormäns": "motorman",
    "motorn": "motor",
    "motorns": "motor",
    "motorrengöringen": "motorrengöring",
    "motorrengöringens": "motorrengöring",
    "motorrengörings": "motorrengöring",
    "motors": "motor",
    "motorseglar": "motorseglare",
    "motorseglaren": "motorseglare",
    "motorseglarens": "motorseglare",
    "motorseglares": "motorseglare",
    "motorseglarna": "motorseglare",
    "motorseglarnas": "motorseglare",
    "motorskydden": "motorskydd",
    "motorskyddens": "motorskydd",
    "motorskyddet": "motorskydd",
    "motorskyddets": "motorskydd",
    "motorskydds": "motorskydd",
    "motorsporten": "motorsport",
    "motorsportens": "motorsport",
    "motorsports": "motorsport",
    "motorstativen": "motorstativ",
    "motorstativens": "motorstativ",
    "motorstativet": "motorstativ",
    "motorstativets": "motorstativ",
    "motorstativs": "motorstativ",
    "motorstoppen": "motorstopp",
    "motorstoppens": "motorstopp",
    "motorstoppet": "motorstopp",
    "motorstoppets": "motorstopp",
    "motorstopps": "motorstopp",
    "motorstyrkan": "motorstyrka",
    "motorstyrkans": "motorstyrka",
    "motorstyrkas": "motorstyrka",
    "motorstyrke": "motorstyrka",
    "motorstyrkor": "motorstyrka",
    "motorstyrkorna": "motorstyrka",
    "motorstyrkornas": "motorstyrka",
    "motorstyrkors": "motorstyrka",
    "motorsågar": "motorsåg",
    "motorsågarna": "motorsåg",
    "motorsågarnas": "motorsåg",
    "motorsågars": "motorsåg",
    "motorsågen": "motorsåg",
    "motorsågens": "motorsåg",
    "motorsågs": "motorsåg",
    "motorsågskedjan": "motorsågskedja",
    "motorsågskedjans": "motorsågskedja",
    "motorsågskedjas": "motorsågskedja",
    "motorsågskedje": "motorsågskedja",
    "motorsågskedjor": "motorsågskedja",
    "motorsågskedjorna": "motorsågskedja",
    "motorsågskedjornas": "motorsågskedja",
    "motorsågskedjors": "motorsågskedja",
    "motortorpedbåtar": "motortorpedbåt",
    "motortorpedbåtarna": "motortorpedbåt",
    "motortorpedbåtarnas": "motortorpedbåt",
    "motortorpedbåtars": "motortorpedbåt",
    "motortorpedbåten": "motortorpedbåt",
    "motortorpedbåtens": "motortorpedbåt",
    "motortorpedbåts": "motortorpedbåt",
    "motortrafikleden": "motortrafikled",
    "motortrafikledens": "motortrafikled",
    "motortrafikleder": "motortrafikled",
    "motortrafiklederna": "motortrafikled",
    "motortrafikledernas": "motortrafikled",
    "motortrafikleders": "motortrafikled",
    "motortrafikleds": "motortrafikled",
    "motortvätten": "motortvätt",
    "motortvättens": "motortvätt",
    "motortvätts": "motortvätt",
    "motorvagnar": "motorvagn",
    "motorvagnarna": "motorvagn",
    "motorvagnarnas": "motorvagn",
    "motorvagnars": "motorvagn",
    "motorvagnen": "motorvagn",
    "motorvagnens": "motorvagn",
    "motorvagns": "motorvagn",
    "motorvägar": "motorväg",
    "motorvägarna": "motorväg",
    "motorvägarnas": "motorväg",
    "motorvägars": "motorväg",
    "motorvägen": "motorväg",
    "motorvägens": "motorväg",
    "motorvägs": "motorväg",
    "motorvägsförbindelsen": "motorvägsförbindelse",
    "motorvägsförbindelsens": "motorvägsförbindelse",
    "motorvägsförbindelser": "motorvägsförbindelse",
    "motorvägsförbindelserna": "motorvägsförbindelse",
    "motorvägsförbindelsernas": "motorvägsförbindelse",
    "motorvägsförbindelsers": "motorvägsförbindelse",
    "motorvägsförbindelses": "motorvägsförbindelse",
    "motorvägsmässiga": "motorvägsmässig",
    "motorvägsmässigare": "motorvägsmässig",
    "motorvägsmässigares": "motorvägsmässig",
    "motorvägsmässigas": "motorvägsmässig",
    "motorvägsmässigast": "motorvägsmässig",
    "motorvägsmässigaste": "motorvägsmässig",
    "motorvägsmässigastes": "motorvägsmässig",
    "motorvägsmässigasts": "motorvägsmässig",
    "motorvägsmässige": "motorvägsmässig",
    "motorvägsmässiges": "motorvägsmässig",
    "motorvägsmässigs": "motorvägsmässig",
    "motorvägsmässigt": "motorvägsmässig",
    "motorvägsmässigts": "motorvägsmässig",
    "motorvärmar": "motorvärmare",
    "motorvärmaren": "motorvärmare",
    "motorvärmarens": "motorvärmare",
    "motorvärmares": "motorvärmare",
    "motorvärmarkabeln": "motorvärmarkabel",
    "motorvärmarkabelns": "motorvärmarkabel",
    "motorvärmarkabels": "motorvärmarkabel",
    "motorvärmarkablar": "motorvärmarkabel",
    "motorvärmarkablarna": "motorvärmarkabel",
    "motorvärmarkablarnas": "motorvärmarkabel",
    "motorvärmarkablars": "motorvärmarkabel",
    "motorvärmarna": "motorvärmare",
    "motorvärmarnas": "motorvärmare",
    "motparten": "motpart",
    "motpartens": "motpart",
    "motparter": "motpart",
    "motparterna": "motpart",
    "motparternas": "motpart",
    "motparters": "motpart",
    "motparts": "motpart",
    "motpolen": "motpol",
    "motpolens": "motpol",
    "motpoler": "motpol",
    "motpolerna": "motpol",
    "motpolernas": "motpol",
    "motpolers": "motpol",
    "motpols": "motpol",
    "motprestationen": "motprestation",
    "motprestationens": "motprestation",
    "motprestationer": "motprestation",
    "motprestationerna": "motprestation",
    "motprestationernas": "motprestation",
    "motprestationers": "motprestation",
    "motprestations": "motprestation",
    "motreformationen": "motreformation",
    "motreformationens": "motreformation",
    "motreformationer": "motreformation",
    "motreformationerna": "motreformation",
    "motreformationernas": "motreformation",
    "motreformationers": "motreformation",
    "motreformations": "motreformation",
    "motrepliken": "motreplik",
    "motreplikens": "motreplik",
    "motrepliker": "motreplik",
    "motreplikerna": "motreplik",
    "motreplikernas": "motreplik",
    "motreplikers": "motreplik",
    "motrepliks": "motreplik",
    "motrevolutionen": "motrevolution",
    "motrevolutionens": "motrevolution",
    "motrevolutioner": "motrevolution",
    "motrevolutionerna": "motrevolution",
    "motrevolutionernas": "motrevolution",
    "motrevolutioners": "motrevolution",
    "motrevolutions": "motrevolution",
    "motriktade": "motriktad",
    "motriktades": "motriktad",
    "motriktads": "motriktad",
    "motriktat": "motriktad",
    "motriktats": "motriktad",
    "mots": "mot",
    "motsade": "motsäga",
    "motsades": "motsäga",
    "motsagd": "motsäga",
    "motsagda": "motsäga",
    "motsagdas": "motsäga",
    "motsagde": "motsäga",
    "motsagdes": "motsäga",
    "motsagds": "motsäga",
    "motsagt": "motsäga",
    "motsagts": "motsäga",
    "motsatsen": "motsats",
    "motsatsens": "motsats",
    "motsatser": "motsats",
    "motsatserna": "motsats",
    "motsatsernas": "motsats",
    "motsatsers": "motsats",
    "motsatsförhållanden": "motsatsförhållande",
    "motsatsförhållandena": "motsatsförhållande",
    "motsatsförhållandenas": "motsatsförhållande",
    "motsatsförhållandens": "motsatsförhållande",
    "motsatsförhållandes": "motsatsförhållande",
    "motsatsförhållandet": "motsatsförhållande",
    "motsatsförhållandets": "motsatsförhållande",
    "motsatta": "motsatt",
    "motsattare": "motsatt",
    "motsattares": "motsatt",
    "motsattas": "motsatt",
    "motsattast": "motsatt",
    "motsattaste": "motsatt",
    "motsattastes": "motsatt",
    "motsattasts": "motsatt",
    "motsatte": "motsatt",
    "motsattes": "motsatt",
    "motsatts": "motsatt",
    "motsedd": "motse",
    "motsedda": "motse",
    "motseddas": "motse",
    "motsedde": "motse",
    "motseddes": "motse",
    "motsedds": "motse",
    "motseende": "motse",
    "motseenden": "motseende",
    "motseendena": "motseende",
    "motseendenas": "motseende",
    "motseendens": "motseende",
    "motseendes": "motseende",
    "motseendet": "motseende",
    "motseendets": "motseende",
    "motser": "motse",
    "motses": "motse",
    "motsett": "motse",
    "motsetts": "motse",
    "motskotten": "motskott",
    "motskottens": "motskott",
    "motskottet": "motskott",
    "motskottets": "motskott",
    "motskotts": "motskott",
    "motspelar": "motspelare",
    "motspelaren": "motspelare",
    "motspelarens": "motspelare",
    "motspelares": "motspelare",
    "motspelarna": "motspelare",
    "motspelarnas": "motspelare",
    "motspelet": "motspel",
    "motspelets": "motspel",
    "motspels": "motspel",
    "motspänstiga": "motspänstig",
    "motspänstigare": "motspänstig",
    "motspänstigares": "motspänstig",
    "motspänstigas": "motspänstig",
    "motspänstigast": "motspänstig",
    "motspänstigaste": "motspänstig",
    "motspänstigastes": "motspänstig",
    "motspänstigasts": "motspänstig",
    "motspänstige": "motspänstig",
    "motspänstiges": "motspänstig",
    "motspänstigheten": "motspänstighet",
    "motspänstighetens": "motspänstighet",
    "motspänstighets": "motspänstighet",
    "motspänstigs": "motspänstig",
    "motspänstigt": "motspänstig",
    "motspänstigts": "motspänstig",
    "motstod": "motstå",
    "motstode": "motstå",
    "motstodes": "motstå",
    "motstods": "motstå",
    "motstridiga": "motstridig",
    "motstridigare": "motstridig",
    "motstridigares": "motstridig",
    "motstridigas": "motstridig",
    "motstridigast": "motstridig",
    "motstridigaste": "motstridig",
    "motstridigastes": "motstridig",
    "motstridigasts": "motstridig",
    "motstridige": "motstridig",
    "motstridiges": "motstridig",
    "motstridigheten": "motstridighet",
    "motstridighetens": "motstridighet",
    "motstridighets": "motstridighet",
    "motstridigs": "motstridig",
    "motstridigt": "motstridig",
    "motstridigts": "motstridig",
    "motstrofen": "motstrof",
    "motstrofens": "motstrof",
    "motstrofer": "motstrof",
    "motstroferna": "motstrof",
    "motstrofernas": "motstrof",
    "motstrofers": "motstrof",
    "motstrofs": "motstrof",
    "motsträviga": "motsträvig",
    "motsträvigare": "motsträvig",
    "motsträvigares": "motsträvig",
    "motsträvigas": "motsträvig",
    "motsträvigast": "motsträvig",
    "motsträvigaste": "motsträvig",
    "motsträvigastes": "motsträvig",
    "motsträvigasts": "motsträvig",
    "motsträvige": "motsträvig",
    "motsträviges": "motsträvig",
    "motsträvigheten": "motsträvighet",
    "motsträvighetens": "motsträvighet",
    "motsträvighets": "motsträvighet",
    "motsträvigs": "motsträvig",
    "motsträvigt": "motsträvig",
    "motsträvigts": "motsträvig",
    "motströmmar": "motström",
    "motströmmarna": "motström",
    "motströmmarnas": "motström",
    "motströmmars": "motström",
    "motströmmen": "motström",
    "motströmmens": "motström",
    "motströms": "motström",
    "motstycken": "motstycke",
    "motstyckena": "motstycke",
    "motstyckenas": "motstycke",
    "motstyckens": "motstycke",
    "motstyckes": "motstycke",
    "motstycket": "motstycke",
    "motstyckets": "motstycke",
    "motstycks": "motstycke",
    "motstående": "motstå",
    "motståenden": "motstående",
    "motståendena": "motstående",
    "motståendenas": "motstående",
    "motståendens": "motstående",
    "motståendes": "motstående",
    "motståendet": "motstående",
    "motståendets": "motstående",
    "motståndar": "motståndare",
    "motståndaren": "motståndare",
    "motståndarens": "motståndare",
    "motståndares": "motståndare",
    "motståndarlagen": "motståndarlag",
    "motståndarlagens": "motståndarlag",
    "motståndarlaget": "motståndarlag",
    "motståndarlagets": "motståndarlag",
    "motståndarlags": "motståndarlag",
    "motståndarna": "motståndare",
    "motståndarnas": "motståndare",
    "motståndarsoldaten": "motståndarsoldat",
    "motståndarsoldatens": "motståndarsoldat",
    "motståndarsoldater": "motståndarsoldat",
    "motståndarsoldaterna": "motståndarsoldat",
    "motståndarsoldaternas": "motståndarsoldat",
    "motståndarsoldaters": "motståndarsoldat",
    "motståndarsoldats": "motståndarsoldat",
    "motstånden": "motstånd",
    "motståndens": "motstånd",
    "motståndet": "motstånd",
    "motståndets": "motstånd",
    "motstånds": "motstånd",
    "motståndskraften": "motståndskraft",
    "motståndskraftens": "motståndskraft",
    "motståndskraftiga": "motståndskraftig",
    "motståndskraftigare": "motståndskraftig",
    "motståndskraftigares": "motståndskraftig",
    "motståndskraftigas": "motståndskraftig",
    "motståndskraftigast": "motståndskraftig",
    "motståndskraftigaste": "motståndskraftig",
    "motståndskraftigastes": "motståndskraftig",
    "motståndskraftigasts": "motståndskraftig",
    "motståndskraftige": "motståndskraftig",
    "motståndskraftiges": "motståndskraftig",
    "motståndskraftigs": "motståndskraftig",
    "motståndskraftigt": "motståndskraftig",
    "motståndskraftigts": "motståndskraftig",
    "motståndskrafts": "motståndskraft",
    "motståndsmannen": "motståndsman",
    "motståndsmannens": "motståndsman",
    "motståndsmans": "motståndsman",
    "motståndsmän": "motståndsman",
    "motståndsmännen": "motståndsman",
    "motståndsmännens": "motståndsman",
    "motståndsmäns": "motståndsman",
    "motståndsnästen": "motståndsnäste",
    "motståndsnästena": "motståndsnäste",
    "motståndsnästenas": "motståndsnäste",
    "motståndsnästens": "motståndsnäste",
    "motståndsnästes": "motståndsnäste",
    "motståndsnästet": "motståndsnäste",
    "motståndsnästets": "motståndsnäste",
    "motståndsområden": "motståndsområde",
    "motståndsområdena": "motståndsområde",
    "motståndsområdenas": "motståndsområde",
    "motståndsområdens": "motståndsområde",
    "motståndsområdes": "motståndsområde",
    "motståndsområdet": "motståndsområde",
    "motståndsområdets": "motståndsområde",
    "motståndsrörelsen": "motståndsrörelse",
    "motståndsrörelsens": "motståndsrörelse",
    "motståndsrörelser": "motståndsrörelse",
    "motståndsrörelserna": "motståndsrörelse",
    "motståndsrörelsernas": "motståndsrörelse",
    "motståndsrörelsers": "motståndsrörelse",
    "motståndsrörelses": "motståndsrörelse",
    "motståndssvetsningar": "motståndssvetsning",
    "motståndssvetsningarna": "motståndssvetsning",
    "motståndssvetsningarnas": "motståndssvetsning",
    "motståndssvetsningars": "motståndssvetsning",
    "motståndssvetsningen": "motståndssvetsning",
    "motståndssvetsningens": "motståndssvetsning",
    "motståndssvetsnings": "motståndssvetsning",
    "motstår": "motstå",
    "motstås": "motstå",
    "motstått": "motstå",
    "motståtts": "motstå",
    "motstötar": "motstöt",
    "motstötarna": "motstöt",
    "motstötarnas": "motstöt",
    "motstötars": "motstöt",
    "motstöten": "motstöt",
    "motstötens": "motstöt",
    "motstöts": "motstöt",
    "motsvarade": "motsvara",
    "motsvarades": "motsvara",
    "motsvarande": "motsvara",
    "motsvaranden": "motsvarande",
    "motsvarandena": "motsvarande",
    "motsvarandenas": "motsvarande",
    "motsvarandens": "motsvarande",
    "motsvarandes": "motsvarande",
    "motsvarandet": "motsvarande",
    "motsvarandets": "motsvarande",
    "motsvarar": "motsvara",
    "motsvaras": "motsvara",
    "motsvarat": "motsvara",
    "motsvarats": "motsvara",
    "motsvarigheten": "motsvarighet",
    "motsvarighetens": "motsvarighet",
    "motsvarigheter": "motsvarighet",
    "motsvarigheterna": "motsvarighet",
    "motsvarigheternas": "motsvarighet",
    "motsvarigheters": "motsvarighet",
    "motsvarighets": "motsvarighet",
    "motsäg": "motsäga",
    "motsägande": "motsäga",
    "motsäganden": "motsägande",
    "motsägandena": "motsägande",
    "motsägandenas": "motsägande",
    "motsägandens": "motsägande",
    "motsägandes": "motsägande",
    "motsägandet": "motsägande",
    "motsägandets": "motsägande",
    "motsägas": "motsäga",
    "motsägelsefulla": "motsägelsefull",
    "motsägelsefullare": "motsägelsefull",
    "motsägelsefullares": "motsägelsefull",
    "motsägelsefullas": "motsägelsefull",
    "motsägelsefullast": "motsägelsefull",
    "motsägelsefullaste": "motsägelsefull",
    "motsägelsefullastes": "motsägelsefull",
    "motsägelsefullasts": "motsägelsefull",
    "motsägelsefulle": "motsägelsefull",
    "motsägelsefulles": "motsägelsefull",
    "motsägelsefullheten": "motsägelsefullhet",
    "motsägelsefullhetens": "motsägelsefullhet",
    "motsägelsefullhets": "motsägelsefullhet",
    "motsägelsefulls": "motsägelsefull",
    "motsägelsefullt": "motsägelsefull",
    "motsägelsefullts": "motsägelsefull",
    "motsägelsen": "motsägelse",
    "motsägelsens": "motsägelse",
    "motsägelser": "motsägelse",
    "motsägelserna": "motsägelse",
    "motsägelsernas": "motsägelse",
    "motsägelsers": "motsägelse",
    "motsägelses": "motsägelse",
    "motsäger": "motsäga",
    "motsäges": "motsäga",
    "motsägs": "motsäga",
    "motsättliga": "motsättlig",
    "motsättligare": "motsättlig",
    "motsättligares": "motsättlig",
    "motsättligas": "motsättlig",
    "motsättligast": "motsättlig",
    "motsättligaste": "motsättlig",
    "motsättligastes": "motsättlig",
    "motsättligasts": "motsättlig",
    "motsättlige": "motsättlig",
    "motsättliges": "motsättlig",
    "motsättligheten": "motsättlighet",
    "motsättlighetens": "motsättlighet",
    "motsättlighets": "motsättlighet",
    "motsättligs": "motsättlig",
    "motsättligt": "motsättlig",
    "motsättligts": "motsättlig",
    "motsättningar": "motsättning",
    "motsättningarna": "motsättning",
    "motsättningarnas": "motsättning",
    "motsättningars": "motsättning",
    "motsättningen": "motsättning",
    "motsättningens": "motsättning",
    "motsättnings": "motsättning",
    "motsåg": "motse",
    "motsåge": "motse",
    "motsåges": "motse",
    "motsågs": "motse",
    "mottag": "motta",
    "mottaga": "motta",
    "mottagande": "motta",
    "mottaganden": "mottagande",
    "mottagandena": "mottagande",
    "mottagandenas": "mottagande",
    "mottagandens": "mottagande",
    "mottagandes": "mottagande",
    "mottagandet": "mottagande",
    "mottagandets": "mottagande",
    "mottagar": "mottagare",
    "mottagaren": "mottagare",
    "mottagarens": "mottagare",
    "mottagares": "mottagare",
    "mottagarna": "mottagare",
    "mottagarnas": "mottagare",
    "mottagarsäckar": "mottagarsäck",
    "mottagarsäckarna": "mottagarsäck",
    "mottagarsäckarnas": "mottagarsäck",
    "mottagarsäckars": "mottagarsäck",
    "mottagarsäcken": "mottagarsäck",
    "mottagarsäckens": "mottagarsäck",
    "mottagarsäcks": "mottagarsäck",
    "mottagas": "motta",
    "mottage": "motta",
    "mottagen": "motta",
    "mottagens": "motta",
    "mottager": "motta",
    "mottages": "motta",
    "mottaget": "motta",
    "mottagets": "motta",
    "mottagit": "motta",
    "mottagits": "motta",
    "mottagliga": "mottaglig",
    "mottagligare": "mottaglig",
    "mottagligares": "mottaglig",
    "mottagligas": "mottaglig",
    "mottagligast": "mottaglig",
    "mottagligaste": "mottaglig",
    "mottagligastes": "mottaglig",
    "mottagligasts": "mottaglig",
    "mottaglige": "mottaglig",
    "mottagliges": "mottaglig",
    "mottagligheten": "mottaglighet",
    "mottaglighetens": "mottaglighet",
    "mottaglighets": "mottaglighet",
    "mottagligs": "mottaglig",
    "mottagligt": "mottaglig",
    "mottagligts": "mottaglig",
    "mottagna": "motta",
    "mottagnas": "motta",
    "mottagne": "motta",
    "mottagnes": "motta",
    "mottagningar": "mottagning",
    "mottagningarna": "mottagning",
    "mottagningarnas": "mottagning",
    "mottagningars": "mottagning",
    "mottagningen": "mottagning",
    "mottagningens": "mottagning",
    "mottagnings": "mottagning",
    "mottagningsbevisen": "mottagningsbevis",
    "mottagningsbevisens": "mottagningsbevis",
    "mottagningsbeviset": "mottagningsbevis",
    "mottagningsbevisets": "mottagningsbevis",
    "mottagningshemmen": "mottagningshem",
    "mottagningshemmens": "mottagningshem",
    "mottagningshemmet": "mottagningshem",
    "mottagningshemmets": "mottagningshem",
    "mottagningshems": "mottagningshem",
    "mottagningsrummen": "mottagningsrum",
    "mottagningsrummens": "mottagningsrum",
    "mottagningsrummet": "mottagningsrum",
    "mottagningsrummets": "mottagningsrum",
    "mottagningsrums": "mottagningsrum",
    "mottags": "motta",
    "mottar": "motta",
    "mottas": "motta",
    "motten": "mott",
    "mottens": "mott",
    "mottet": "mott",
    "mottets": "mott",
    "mottin": "motti",
    "mottina": "motti",
    "mottinas": "motti",
    "mottins": "motti",
    "mottis": "motti",
    "mottog": "motta",
    "mottoge": "motta",
    "mottoges": "motta",
    "mottogs": "motta",
    "motton": "motto",
    "mottona": "motto",
    "mottonas": "motto",
    "mottons": "motto",
    "mottos": "motto",
    "mottot": "motto",
    "mottots": "motto",
    "mottrycket": "mottryck",
    "mottryckets": "mottryck",
    "mottrycks": "mottryck",
    "motts": "mott",
    "motverk": "motverka",
    "motverkad": "motverka",
    "motverkade": "motverka",
    "motverkades": "motverka",
    "motverkads": "motverka",
    "motverkande": "motverka",
    "motverkanden": "motverkande",
    "motverkandena": "motverkande",
    "motverkandenas": "motverkande",
    "motverkandens": "motverkande",
    "motverkandes": "motverkande",
    "motverkandet": "motverkande",
    "motverkandets": "motverkande",
    "motverkar": "motverka",
    "motverkas": "motverka",
    "motverkat": "motverka",
    "motverkats": "motverka",
    "motvikten": "motvikt",
    "motviktens": "motvikt",
    "motvikter": "motvikt",
    "motvikterna": "motvikt",
    "motvikternas": "motvikt",
    "motvikters": "motvikt",
    "motvikts": "motvikt",
    "motviljan": "motvilja",
    "motviljans": "motvilja",
    "motviljas": "motvilja",
    "motvilliga": "motvillig",
    "motvilligare": "motvillig",
    "motvilligares": "motvillig",
    "motvilligas": "motvillig",
    "motvilligast": "motvillig",
    "motvilligaste": "motvillig",
    "motvilligastes": "motvillig",
    "motvilligasts": "motvillig",
    "motvillige": "motvillig",
    "motvilliges": "motvillig",
    "motvilligheten": "motvillighet",
    "motvillighetens": "motvillighet",
    "motvillighets": "motvillighet",
    "motvilligs": "motvillig",
    "motvilligt": "motvillig",
    "motvilligts": "motvillig",
    "motvindar": "motvind",
    "motvindarna": "motvind",
    "motvindarnas": "motvind",
    "motvindars": "motvind",
    "motvinden": "motvind",
    "motvindens": "motvind",
    "motvinds": "motvind",
    "motväg": "motväga",
    "motvägande": "motväga",
    "motväganden": "motvägande",
    "motvägandena": "motvägande",
    "motvägandenas": "motvägande",
    "motvägandens": "motvägande",
    "motvägandes": "motvägande",
    "motvägandet": "motvägande",
    "motvägandets": "motvägande",
    "motvägas": "motväga",
    "motvägd": "motväga",
    "motvägda": "motväga",
    "motvägdas": "motväga",
    "motvägde": "motväga",
    "motvägdes": "motväga",
    "motvägds": "motväga",
    "motväger": "motväga",
    "motväges": "motväga",
    "motvägs": "motväga",
    "motvägt": "motväga",
    "motvägts": "motväga",
    "motvärns": "motvärn",
    "motylen": "motyl",
    "motylens": "motyl",
    "motyls": "motyl",
    "motåtgärden": "motåtgärd",
    "motåtgärdens": "motåtgärd",
    "motåtgärder": "motåtgärd",
    "motåtgärderna": "motåtgärd",
    "motåtgärdernas": "motåtgärd",
    "motåtgärders": "motåtgärd",
    "motåtgärds": "motåtgärd",
    "moulinégarnet": "moulinégarn",
    "moulinégarnets": "moulinégarn",
    "moulinégarns": "moulinégarn",
    "moussen": "mousse",
    "moussens": "mousse",
    "mousser": "mousse",
    "mousserade": "moussera",
    "mousserades": "moussera",
    "mousserande": "moussera",
    "mousseranden": "mousserande",
    "mousserandena": "mousserande",
    "mousserandenas": "mousserande",
    "mousserandens": "mousserande",
    "mousserandes": "mousserande",
    "mousserandet": "mousserande",
    "mousserandets": "mousserande",
    "mousserar": "moussera",
    "mousseras": "moussera",
    "mousserat": "moussera",
    "mousserats": "moussera",
    "mousseringar": "moussering",
    "mousseringarna": "moussering",
    "mousseringarnas": "moussering",
    "mousseringars": "moussering",
    "mousseringen": "moussering",
    "mousseringens": "moussering",
    "mousserings": "moussering",
    "mousserna": "mousse",
    "moussernas": "mousse",
    "moussers": "mousse",
    "mousses": "mousse",
    "movip": "movipa",
    "movipan": "movipa",
    "movipans": "movipa",
    "movipas": "movipa",
    "movipe": "movipa",
    "movipor": "movipa",
    "moviporna": "movipa",
    "movipornas": "movipa",
    "movipors": "movipa",
    "movips": "movipa",
    "moçambikiern": "moçambikier",
    "moçambikierna": "moçambikier",
    "moçambikiernas": "moçambikier",
    "moçambikierns": "moçambikier",
    "moçambikiers": "moçambikier",
    "moçambikiska": "moçambikisk",
    "moçambikiskan": "moçambikiska",
    "moçambikiskans": "moçambikiska",
    "moçambikiskare": "moçambikisk",
    "moçambikiskares": "moçambikisk",
    "moçambikiskas": "moçambikiska",
    "moçambikiskast": "moçambikisk",
    "moçambikiskaste": "moçambikisk",
    "moçambikiskastes": "moçambikisk",
    "moçambikiskasts": "moçambikisk",
    "moçambikiske": "moçambikiska",
    "moçambikiskes": "moçambikisk",
    "moçambikiskor": "moçambikiska",
    "moçambikiskorna": "moçambikiska",
    "moçambikiskornas": "moçambikiska",
    "moçambikiskors": "moçambikiska",
    "moçambikisks": "moçambikisk",
    "moçambikiskt": "moçambikisk",
    "moçambikiskts": "moçambikisk",
    "mp-s": "mp",
    "mp3-boken": "mp3-bok",
    "mp3-boks": "mp3-bok",
    "mp3-böcker": "mp3-bok",
    "mp3-böckernas": "mp3-bok",
    "mp3-s": "mp3",
    "mp3-spelaren": "mp3-spelare",
    "mp3-spelares": "mp3-spelare",
    "mp3-spelarnas": "mp3-spelare",
    "mp3:s": "mp3",
    "muckade": "mucka",
    "muckades": "mucka",
    "muckande": "mucka",
    "muckanden": "muckande",
    "muckandena": "muckande",
    "muckandenas": "muckande",
    "muckandens": "muckande",
    "muckandes": "muckande",
    "muckandet": "muckande",
    "muckandets": "muckande",
    "muckar": "muckare",
    "muckaren": "muckare",
    "muckarens": "muckare",
    "muckares": "muckare",
    "muckarna": "muckare",
    "muckarnas": "muckare",
    "muckas": "mucka",
    "muckat": "mucka",
    "muckats": "mucka",
    "mucken": "muck",
    "muckens": "muck",
    "mucks": "muck",
    "muddar": "mudd",
    "muddarna": "mudd",
    "muddarnas": "mudd",
    "muddars": "mudd",
    "mudden": "mudd",
    "muddens": "mudd",
    "mudder": "muddra",
    "mudders": "mudder",
    "mudderverken": "mudderverk",
    "mudderverkens": "mudderverk",
    "mudderverket": "mudderverk",
    "mudderverkets": "mudderverk",
    "mudderverks": "mudderverk",
    "muddrad": "muddra",
    "muddrade": "muddra",
    "muddrades": "muddra",
    "muddrads": "muddra",
    "muddrande": "muddra",
    "muddranden": "muddrande",
    "muddrandena": "muddrande",
    "muddrandenas": "muddrande",
    "muddrandens": "muddrande",
    "muddrandes": "muddrande",
    "muddrandet": "muddrande",
    "muddrandets": "muddrande",
    "muddrar": "muddra",
    "muddras": "muddra",
    "muddrat": "muddra",
    "muddrats": "muddra",
    "muddret": "mudder",
    "muddrets": "mudder",
    "muddriga": "muddrig",
    "muddrigare": "muddrig",
    "muddrigares": "muddrig",
    "muddrigas": "muddrig",
    "muddrigast": "muddrig",
    "muddrigaste": "muddrig",
    "muddrigastes": "muddrig",
    "muddrigasts": "muddrig",
    "muddrige": "muddrig",
    "muddriges": "muddrig",
    "muddrigheten": "muddrighet",
    "muddrighetens": "muddrighet",
    "muddrighets": "muddrighet",
    "muddrigs": "muddrig",
    "muddrigt": "muddrig",
    "muddrigts": "muddrig",
    "mudds": "mudd",
    "muffar": "muff",
    "muffarna": "muff",
    "muffarnas": "muff",
    "muffars": "muff",
    "muffelfärgen": "muffelfärg",
    "muffelfärgens": "muffelfärg",
    "muffelfärger": "muffelfärg",
    "muffelfärgerna": "muffelfärg",
    "muffelfärgernas": "muffelfärg",
    "muffelfärgers": "muffelfärg",
    "muffelfärgs": "muffelfärg",
    "muffeln": "muffel",
    "muffelns": "muffel",
    "muffels": "muffel",
    "muffelugnar": "muffelugn",
    "muffelugnarna": "muffelugn",
    "muffelugnarnas": "muffelugn",
    "muffelugnars": "muffelugn",
    "muffelugnen": "muffelugn",
    "muffelugnens": "muffelugn",
    "muffelugns": "muffelugn",
    "muffen": "muff",
    "muffens": "muff",
    "muffinsen": "muffins",
    "muffinsens": "muffins",
    "mufflar": "muffel",
    "mufflarna": "muffel",
    "mufflarnas": "muffel",
    "mufflars": "muffel",
    "mufflonen": "mufflon",
    "mufflonens": "mufflon",
    "muffloner": "mufflon",
    "mufflonerna": "mufflon",
    "mufflonernas": "mufflon",
    "muffloners": "mufflon",
    "mufflonfåren": "mufflonfår",
    "mufflonfårens": "mufflonfår",
    "mufflonfåret": "mufflonfår",
    "mufflonfårets": "mufflonfår",
    "mufflonfårs": "mufflonfår",
    "mufflons": "mufflon",
    "muffs": "muff",
    "muftier": "mufti",
    "muftierna": "mufti",
    "muftiernas": "mufti",
    "muftiers": "mufti",
    "muftin": "mufti",
    "muftins": "mufti",
    "muftis": "mufti",
    "muggar": "mugg",
    "muggarna": "mugg",
    "muggarnas": "mugg",
    "muggars": "mugg",
    "muggen": "mugg",
    "muggens": "mugg",
    "muggs": "mugg",
    "muhammedanen": "muhammedan",
    "muhammedanens": "muhammedan",
    "muhammedaner": "muhammedan",
    "muhammedanerna": "muhammedan",
    "muhammedanernas": "muhammedan",
    "muhammedaners": "muhammedan",
    "muhammedanismen": "muhammedanism",
    "muhammedanismens": "muhammedanism",
    "muhammedanismer": "muhammedanism",
    "muhammedanismerna": "muhammedanism",
    "muhammedanismernas": "muhammedanism",
    "muhammedanismers": "muhammedanism",
    "muhammedanisms": "muhammedanism",
    "muhammedans": "muhammedan",
    "muhammedanska": "muhammedansk",
    "muhammedanskare": "muhammedansk",
    "muhammedanskares": "muhammedansk",
    "muhammedanskas": "muhammedansk",
    "muhammedanskast": "muhammedansk",
    "muhammedanskaste": "muhammedansk",
    "muhammedanskastes": "muhammedansk",
    "muhammedanskasts": "muhammedansk",
    "muhammedanske": "muhammedansk",
    "muhammedanskes": "muhammedansk",
    "muhammedansks": "muhammedansk",
    "muhammedanskt": "muhammedansk",
    "muhammedanskts": "muhammedansk",
    "mul": "mule",
    "mulan": "mula",
    "mulans": "mula",
    "mular": "mule",
    "mularna": "mule",
    "mularnas": "mule",
    "mulars": "mule",
    "mulas": "mula",
    "mulatten": "mulatt",
    "mulattens": "mulatt",
    "mulatter": "mulatt",
    "mulatterna": "mulatt",
    "mulatternas": "mulatt",
    "mulatters": "mulatt",
    "mulatts": "mulatt",
    "mule": "mula",
    "mulen": "mule",
    "mulenheten": "mulenhet",
    "mulenhetens": "mulenhet",
    "mulenhets": "mulenhet",
    "mulens": "mulen",
    "mules": "mule",
    "mulet": "mulen",
    "mulets": "mulen",
    "muljerad": "muljera",
    "muljerade": "muljera",
    "muljerades": "muljera",
    "muljerads": "muljera",
    "muljerande": "muljera",
    "muljeranden": "muljerande",
    "muljerandena": "muljerande",
    "muljerandenas": "muljerande",
    "muljerandens": "muljerande",
    "muljerandes": "muljerande",
    "muljerandet": "muljerande",
    "muljerandets": "muljerande",
    "muljerar": "muljera",
    "muljeras": "muljera",
    "muljerat": "muljera",
    "muljerats": "muljera",
    "muljerbara": "muljerbar",
    "muljerbarare": "muljerbar",
    "muljerbarares": "muljerbar",
    "muljerbaras": "muljerbar",
    "muljerbarast": "muljerbar",
    "muljerbaraste": "muljerbar",
    "muljerbarastes": "muljerbar",
    "muljerbarasts": "muljerbar",
    "muljerbare": "muljerbar",
    "muljerbares": "muljerbar",
    "muljerbarheten": "muljerbarhet",
    "muljerbarhetens": "muljerbarhet",
    "muljerbarhets": "muljerbarhet",
    "muljerbars": "muljerbar",
    "muljerbart": "muljerbar",
    "muljerbarts": "muljerbar",
    "muljeringar": "muljering",
    "muljeringarna": "muljering",
    "muljeringarnas": "muljering",
    "muljeringars": "muljering",
    "muljeringen": "muljering",
    "muljeringens": "muljering",
    "muljerings": "muljering",
    "mullbänkar": "mullbänk",
    "mullbänkarna": "mullbänk",
    "mullbänkarnas": "mullbänk",
    "mullbänkars": "mullbänk",
    "mullbänken": "mullbänk",
    "mullbänkens": "mullbänk",
    "mullbänks": "mullbänk",
    "mullbären": "mullbär",
    "mullbärens": "mullbär",
    "mullbäret": "mullbär",
    "mullbärets": "mullbär",
    "mullbärs": "mullbär",
    "mullbärsfikonen": "mullbärsfikon",
    "mullbärsfikonens": "mullbärsfikon",
    "mullbärsfikonet": "mullbärsfikon",
    "mullbärsfikonets": "mullbärsfikon",
    "mullbärsfikons": "mullbärsfikon",
    "mullbärsfikonträden": "mullbärsfikonträd",
    "mullbärsfikonträdens": "mullbärsfikonträd",
    "mullbärsfikonträdet": "mullbärsfikonträd",
    "mullbärsfikonträdets": "mullbärsfikonträd",
    "mullbärsfikonträds": "mullbärsfikonträd",
    "mullbärsfikonträn": "mullbärsfikonträd",
    "mullbärsfikonträna": "mullbärsfikonträd",
    "mullbärsfikontränas": "mullbärsfikonträd",
    "mullbärsfikonträns": "mullbärsfikonträd",
    "mullbärsspinnar": "mullbärsspinnare",
    "mullbärsspinnaren": "mullbärsspinnare",
    "mullbärsspinnarens": "mullbärsspinnare",
    "mullbärsspinnares": "mullbärsspinnare",
    "mullbärsspinnarna": "mullbärsspinnare",
    "mullbärsspinnarnas": "mullbärsspinnare",
    "mullbärsträden": "mullbärsträd",
    "mullbärsträdens": "mullbärsträd",
    "mullbärsträdet": "mullbärsträd",
    "mullbärsträdets": "mullbärsträd",
    "mullbärsträds": "mullbärsträd",
    "mullen": "mull",
    "mullens": "mull",
    "muller": "mullra",
    "mullers": "muller",
    "mullhalten": "mullhalt",
    "mullhaltens": "mullhalt",
    "mullhalter": "mullhalt",
    "mullhalterna": "mullhalt",
    "mullhalternas": "mullhalt",
    "mullhalters": "mullhalt",
    "mullhalts": "mullhalt",
    "mulliga": "mullig",
    "mulligare": "mullig",
    "mulligares": "mullig",
    "mulligas": "mullig",
    "mulligast": "mullig",
    "mulligaste": "mullig",
    "mulligastes": "mullig",
    "mulligasts": "mullig",
    "mullige": "mullig",
    "mulliges": "mullig",
    "mulligheten": "mullighet",
    "mullighetens": "mullighet",
    "mullighets": "mullighet",
    "mulligs": "mullig",
    "mulligt": "mullig",
    "mulligts": "mullig",
    "mullrade": "mullra",
    "mullrades": "mullra",
    "mullrande": "mullra",
    "mullranden": "mullrande",
    "mullrandena": "mullrande",
    "mullrandenas": "mullrande",
    "mullrandens": "mullrande",
    "mullrandes": "mullrande",
    "mullrandet": "mullrande",
    "mullrandets": "mullrande",
    "mullrar": "mullra",
    "mullras": "mullra",
    "mullrat": "mullra",
    "mullrats": "mullra",
    "mullret": "muller",
    "mullrets": "muller",
    "mulls": "mull",
    "mullsorkar": "mullsork",
    "mullsorkarna": "mullsork",
    "mullsorkarnas": "mullsork",
    "mullsorkars": "mullsork",
    "mullsorken": "mullsork",
    "mullsorkens": "mullsork",
    "mullsorks": "mullsork",
    "mullsyran": "mullsyra",
    "mullsyrans": "mullsyra",
    "mullsyras": "mullsyra",
    "mullsyre": "mullsyra",
    "mullsyror": "mullsyra",
    "mullsyrorna": "mullsyra",
    "mullsyrornas": "mullsyra",
    "mullsyrors": "mullsyra",
    "mullto": "mulltoa",
    "mulltoan": "mulltoa",
    "mulltoans": "mulltoa",
    "mulltoas": "mulltoa",
    "mulltoe": "mulltoa",
    "mulltoor": "mulltoa",
    "mulltoorna": "mulltoa",
    "mulltoornas": "mulltoa",
    "mulltoors": "mulltoa",
    "mulltos": "mulltoa",
    "mullvadar": "mullvad",
    "mullvadarna": "mullvad",
    "mullvadarnas": "mullvad",
    "mullvadars": "mullvad",
    "mullvaden": "mullvad",
    "mullvadens": "mullvad",
    "mullvads": "mullvad",
    "mullvadsarbeten": "mullvadsarbete",
    "mullvadsarbetena": "mullvadsarbete",
    "mullvadsarbetenas": "mullvadsarbete",
    "mullvadsarbetens": "mullvadsarbete",
    "mullvadsarbetes": "mullvadsarbete",
    "mullvadsarbetet": "mullvadsarbete",
    "mullvadsarbetets": "mullvadsarbete",
    "mullvadsarbets": "mullvadsarbete",
    "mullvadshögar": "mullvadshög",
    "mullvadshögarna": "mullvadshög",
    "mullvadshögarnas": "mullvadshög",
    "mullvadshögars": "mullvadshög",
    "mullvadshögen": "mullvadshög",
    "mullvadshögens": "mullvadshög",
    "mullvadshögs": "mullvadshög",
    "mullvadssyrs": "mullvadssyrsa",
    "mullvadssyrsan": "mullvadssyrsa",
    "mullvadssyrsans": "mullvadssyrsa",
    "mullvadssyrsas": "mullvadssyrsa",
    "mullvadssyrse": "mullvadssyrsa",
    "mullvadssyrsor": "mullvadssyrsa",
    "mullvadssyrsorna": "mullvadssyrsa",
    "mullvadssyrsornas": "mullvadssyrsa",
    "mullvadssyrsors": "mullvadssyrsa",
    "mulna": "mulen",
    "mulnade": "mulna",
    "mulnades": "mulna",
    "mulnande": "mulna",
    "mulnanden": "mulnande",
    "mulnandena": "mulnande",
    "mulnandenas": "mulnande",
    "mulnandens": "mulnande",
    "mulnandes": "mulnande",
    "mulnandet": "mulnande",
    "mulnandets": "mulnande",
    "mulnar": "mulna",
    "mulnare": "mulen",
    "mulnares": "mulen",
    "mulnas": "mulna",
    "mulnast": "mulen",
    "mulnaste": "mulen",
    "mulnastes": "mulen",
    "mulnasts": "mulen",
    "mulnat": "mulna",
    "mulnats": "mulna",
    "mulne": "mulen",
    "mulnes": "mulen",
    "mulor": "mula",
    "mulorna": "mula",
    "mulornas": "mula",
    "mulors": "mula",
    "muls": "mule",
    "mult": "multe",
    "multar": "multe",
    "multarna": "multe",
    "multarnas": "multe",
    "multars": "multe",
    "multegröten": "multegröt",
    "multegrötens": "multegröt",
    "multegröts": "multegröt",
    "multen": "multe",
    "multenheten": "multenhet",
    "multenhetens": "multenhet",
    "multenhets": "multenhet",
    "multens": "multen",
    "multes": "multe",
    "multet": "multen",
    "multets": "multen",
    "multihandikappade": "multihandikappad",
    "multihandikappades": "multihandikappad",
    "multihandikappads": "multihandikappad",
    "multihandikappat": "multihandikappad",
    "multihandikappats": "multihandikappad",
    "multihandikappen": "multihandikapp",
    "multihandikappens": "multihandikapp",
    "multihandikappet": "multihandikapp",
    "multihandikappets": "multihandikapp",
    "multihandikapps": "multihandikapp",
    "multikonsten": "multikonst",
    "multikonstens": "multikonst",
    "multikonsts": "multikonst",
    "multikulturella": "multikulturell",
    "multikulturellare": "multikulturell",
    "multikulturellares": "multikulturell",
    "multikulturellas": "multikulturell",
    "multikulturellast": "multikulturell",
    "multikulturellaste": "multikulturell",
    "multikulturellastes": "multikulturell",
    "multikulturellasts": "multikulturell",
    "multikulturelle": "multikulturell",
    "multikulturelles": "multikulturell",
    "multikulturells": "multikulturell",
    "multikulturellt": "multikulturell",
    "multikulturellts": "multikulturell",
    "multilaterala": "multilateral",
    "multilateralare": "multilateral",
    "multilateralares": "multilateral",
    "multilateralas": "multilateral",
    "multilateralast": "multilateral",
    "multilateralaste": "multilateral",
    "multilateralastes": "multilateral",
    "multilateralasts": "multilateral",
    "multilaterale": "multilateral",
    "multilaterales": "multilateral",
    "multilaterals": "multilateral",
    "multilateralt": "multilateral",
    "multilateralts": "multilateral",
    "multimedia": "multimedium",
    "multimediana": "multimedium",
    "multimedianas": "multimedium",
    "multimedias": "multimedium",
    "multimedie": "multimedium",
    "multimedier": "multimedium",
    "multimedierna": "multimedium",
    "multimediernas": "multimedium",
    "multimediers": "multimedium",
    "multimediet": "multimedium",
    "multimediets": "multimedium",
    "multimediums": "multimedium",
    "multimiljardären": "multimiljardär",
    "multimiljardärens": "multimiljardär",
    "multimiljardärer": "multimiljardär",
    "multimiljardärerna": "multimiljardär",
    "multimiljardärernas": "multimiljardär",
    "multimiljardärers": "multimiljardär",
    "multimiljardärs": "multimiljardär",
    "multimiljonären": "multimiljonär",
    "multimiljonärens": "multimiljonär",
    "multimiljonärer": "multimiljonär",
    "multimiljonärerna": "multimiljonär",
    "multimiljonärernas": "multimiljonär",
    "multimiljonärers": "multimiljonär",
    "multimiljonärs": "multimiljonär",
    "multinationella": "multinationell",
    "multinationellare": "multinationell",
    "multinationellares": "multinationell",
    "multinationellas": "multinationell",
    "multinationellast": "multinationell",
    "multinationellaste": "multinationell",
    "multinationellastes": "multinationell",
    "multinationellasts": "multinationell",
    "multinationelle": "multinationell",
    "multinationelles": "multinationell",
    "multinationells": "multinationell",
    "multinationellt": "multinationell",
    "multinationellts": "multinationell",
    "multipels": "multipel",
    "multipelt": "multipel",
    "multipelts": "multipel",
    "multipeltågen": "multipeltåg",
    "multipeltågens": "multipeltåg",
    "multipeltåget": "multipeltåg",
    "multipeltågets": "multipeltåg",
    "multipeltågs": "multipeltåg",
    "multipla": "multipel",
    "multiplare": "multipel",
    "multiplares": "multipel",
    "multiplas": "multipel",
    "multiplast": "multipel",
    "multiplaste": "multipel",
    "multiplastes": "multipel",
    "multiplasts": "multipel",
    "multiple": "multipel",
    "multiples": "multipel",
    "multiplicerad": "multiplicera",
    "multiplicerade": "multiplicera",
    "multiplicerades": "multiplicera",
    "multiplicerads": "multiplicera",
    "multiplicerande": "multiplicera",
    "multipliceranden": "multiplicerande",
    "multiplicerandena": "multiplicerande",
    "multiplicerandenas": "multiplicerande",
    "multiplicerandens": "multiplicerande",
    "multiplicerandes": "multiplicerande",
    "multiplicerandet": "multiplicerande",
    "multiplicerandets": "multiplicerande",
    "multiplicerar": "multiplicera",
    "multipliceras": "multiplicera",
    "multiplicerat": "multiplicera",
    "multiplicerats": "multiplicera",
    "multiplicerbara": "multiplicerbar",
    "multiplicerbarare": "multiplicerbar",
    "multiplicerbarares": "multiplicerbar",
    "multiplicerbaras": "multiplicerbar",
    "multiplicerbarast": "multiplicerbar",
    "multiplicerbaraste": "multiplicerbar",
    "multiplicerbarastes": "multiplicerbar",
    "multiplicerbarasts": "multiplicerbar",
    "multiplicerbare": "multiplicerbar",
    "multiplicerbares": "multiplicerbar",
    "multiplicerbarheten": "multiplicerbarhet",
    "multiplicerbarhetens": "multiplicerbarhet",
    "multiplicerbarhets": "multiplicerbarhet",
    "multiplicerbars": "multiplicerbar",
    "multiplicerbart": "multiplicerbar",
    "multiplicerbarts": "multiplicerbar",
    "multipliceringar": "multiplicering",
    "multipliceringarna": "multiplicering",
    "multipliceringarnas": "multiplicering",
    "multipliceringars": "multiplicering",
    "multipliceringen": "multiplicering",
    "multipliceringens": "multiplicering",
    "multiplicerings": "multiplicering",
    "multiplikanden": "multiplikand",
    "multiplikandens": "multiplikand",
    "multiplikander": "multiplikand",
    "multiplikanderna": "multiplikand",
    "multiplikandernas": "multiplikand",
    "multiplikanders": "multiplikand",
    "multiplikands": "multiplikand",
    "multiplikationen": "multiplikation",
    "multiplikationens": "multiplikation",
    "multiplikationer": "multiplikation",
    "multiplikationerna": "multiplikation",
    "multiplikationernas": "multiplikation",
    "multiplikationers": "multiplikation",
    "multiplikations": "multiplikation",
    "multiplikationstabellen": "multiplikationstabell",
    "multiplikationstabellens": "multiplikationstabell",
    "multiplikationstabeller": "multiplikationstabell",
    "multiplikationstabellerna": "multiplikationstabell",
    "multiplikationstabellernas": "multiplikationstabell",
    "multiplikationstabellers": "multiplikationstabell",
    "multiplikationstabells": "multiplikationstabell",
    "multiplikationsteckens": "multiplikationstecken",
    "multiplikationstecknen": "multiplikationstecken",
    "multiplikationstecknens": "multiplikationstecken",
    "multiplikationstecknet": "multiplikationstecken",
    "multiplikationstecknets": "multiplikationstecken",
    "multiplikatorer": "multiplikator",
    "multiplikatorerna": "multiplikator",
    "multiplikatorernas": "multiplikator",
    "multiplikatorers": "multiplikator",
    "multiplikatorn": "multiplikator",
    "multiplikatorns": "multiplikator",
    "multiplikators": "multiplikator",
    "multisjuka": "multisjuk",
    "multisjukas": "multisjuk",
    "multisjuke": "multisjuk",
    "multisjukes": "multisjuk",
    "multisjukheten": "multisjukhet",
    "multisjukhetens": "multisjukhet",
    "multisjukhets": "multisjukhet",
    "multisjuks": "multisjuk",
    "multisjukt": "multisjuk",
    "multisjukts": "multisjuk",
    "multituberkulaten": "multituberkulat",
    "multituberkulatens": "multituberkulat",
    "multituberkulatet": "multituberkulat",
    "multituberkulatets": "multituberkulat",
    "multituberkulats": "multituberkulat",
    "multna": "multen",
    "multnade": "multna",
    "multnades": "multna",
    "multnande": "multna",
    "multnanden": "multnande",
    "multnandena": "multnande",
    "multnandenas": "multnande",
    "multnandens": "multnande",
    "multnandes": "multnande",
    "multnandet": "multnande",
    "multnandets": "multnande",
    "multnar": "multna",
    "multnare": "multen",
    "multnares": "multen",
    "multnas": "multna",
    "multnast": "multen",
    "multnaste": "multen",
    "multnastes": "multen",
    "multnasts": "multen",
    "multnat": "multna",
    "multnats": "multna",
    "multne": "multen",
    "multnes": "multen",
    "mults": "multe",
    "multums": "multum",
    "mulåsnan": "mulåsna",
    "mulåsnans": "mulåsna",
    "mulåsnas": "mulåsna",
    "mulåsne": "mulåsna",
    "mulåsnor": "mulåsna",
    "mulåsnorna": "mulåsna",
    "mulåsnornas": "mulåsna",
    "mulåsnors": "mulåsna",
    "mumien": "mumie",
    "mumiens": "mumie",
    "mumier": "mumie",
    "mumierna": "mumie",
    "mumiernas": "mumie",
    "mumiers": "mumie",
    "mumies": "mumie",
    "mumifierad": "mumifiera",
    "mumifierade": "mumifiera",
    "mumifierades": "mumifiera",
    "mumifierads": "mumifiera",
    "mumifierande": "mumifiera",
    "mumifieranden": "mumifierande",
    "mumifierandena": "mumifierande",
    "mumifierandenas": "mumifierande",
    "mumifierandens": "mumifierande",
    "mumifierandes": "mumifierande",
    "mumifierandet": "mumifierande",
    "mumifierandets": "mumifierande",
    "mumifierar": "mumifiera",
    "mumifieras": "mumifiera",
    "mumifierat": "mumifiera",
    "mumifierats": "mumifiera",
    "mumifierbara": "mumifierbar",
    "mumifierbarare": "mumifierbar",
    "mumifierbarares": "mumifierbar",
    "mumifierbaras": "mumifierbar",
    "mumifierbarast": "mumifierbar",
    "mumifierbaraste": "mumifierbar",
    "mumifierbarastes": "mumifierbar",
    "mumifierbarasts": "mumifierbar",
    "mumifierbare": "mumifierbar",
    "mumifierbares": "mumifierbar",
    "mumifierbarheten": "mumifierbarhet",
    "mumifierbarhetens": "mumifierbarhet",
    "mumifierbarhets": "mumifierbarhet",
    "mumifierbars": "mumifierbar",
    "mumifierbart": "mumifierbar",
    "mumifierbarts": "mumifierbar",
    "mumifieringar": "mumifiering",
    "mumifieringarna": "mumifiering",
    "mumifieringarnas": "mumifiering",
    "mumifieringars": "mumifiering",
    "mumifieringen": "mumifiering",
    "mumifieringens": "mumifiering",
    "mumifierings": "mumifiering",
    "mumifikationen": "mumifikation",
    "mumifikationens": "mumifikation",
    "mumifikationer": "mumifikation",
    "mumifikationerna": "mumifikation",
    "mumifikationernas": "mumifikation",
    "mumifikationers": "mumifikation",
    "mumifikations": "mumifikation",
    "mumlade": "mumla",
    "mumlades": "mumla",
    "mumlande": "mumla",
    "mumlanden": "mumlande",
    "mumlandena": "mumlande",
    "mumlandenas": "mumlande",
    "mumlandens": "mumlande",
    "mumlandes": "mumlande",
    "mumlandet": "mumlande",
    "mumlandets": "mumlande",
    "mumlar": "mumla",
    "mumlas": "mumla",
    "mumlat": "mumla",
    "mumlats": "mumla",
    "mumlet": "mummel",
    "mumlets": "mummel",
    "mumman": "mumma",
    "mummans": "mumma",
    "mummas": "mumma",
    "mummels": "mummel",
    "mumrikar": "mumrik",
    "mumrikarna": "mumrik",
    "mumrikarnas": "mumrik",
    "mumrikars": "mumrik",
    "mumriken": "mumrik",
    "mumrikens": "mumrik",
    "mumriks": "mumrik",
    "mums": "mumsa",
    "mumsade": "mumsa",
    "mumsades": "mumsa",
    "mumsande": "mumsa",
    "mumsanden": "mumsande",
    "mumsandena": "mumsande",
    "mumsandenas": "mumsande",
    "mumsandens": "mumsande",
    "mumsandes": "mumsande",
    "mumsandet": "mumsande",
    "mumsandets": "mumsande",
    "mumsar": "mumsa",
    "mumsas": "mumsa",
    "mumsat": "mumsa",
    "mumsats": "mumsa",
    "mumsiga": "mumsig",
    "mumsigare": "mumsig",
    "mumsigares": "mumsig",
    "mumsigas": "mumsig",
    "mumsigast": "mumsig",
    "mumsigaste": "mumsig",
    "mumsigastes": "mumsig",
    "mumsigasts": "mumsig",
    "mumsige": "mumsig",
    "mumsiges": "mumsig",
    "mumsigheten": "mumsighet",
    "mumsighetens": "mumsighet",
    "mumsighets": "mumsighet",
    "mumsigs": "mumsig",
    "mumsigt": "mumsig",
    "mumsigts": "mumsig",
    "mumsmumsar": "mumsmums",
    "mumsmumsarna": "mumsmums",
    "mumsmumsarnas": "mumsmums",
    "mumsmumsars": "mumsmums",
    "mumsmumsen": "mumsmums",
    "mumsmumsens": "mumsmums",
    "mumsmumset": "mumsmums",
    "mumsmumsets": "mumsmums",
    "mun-mot-muninblåsningar": "mun-mot-muninblåsning",
    "mun-mot-muninblåsningarna": "mun-mot-muninblåsning",
    "mun-mot-muninblåsningarnas": "mun-mot-muninblåsning",
    "mun-mot-muninblåsningars": "mun-mot-muninblåsning",
    "mun-mot-muninblåsningen": "mun-mot-muninblåsning",
    "mun-mot-muninblåsningens": "mun-mot-muninblåsning",
    "mun-mot-muninblåsnings": "mun-mot-muninblåsning",
    "mun-mot-munmetodens": "mun-mot-munmetoden",
    "munarten": "munart",
    "munartens": "munart",
    "munarter": "munart",
    "munarterna": "munart",
    "munarternas": "munart",
    "munarters": "munart",
    "munarts": "munart",
    "munderingar": "mundering",
    "munderingarna": "mundering",
    "munderingarnas": "mundering",
    "munderingars": "mundering",
    "munderingen": "mundering",
    "munderingens": "mundering",
    "munderings": "mundering",
    "mundiarrén": "mundiarré",
    "mundiarréns": "mundiarré",
    "mundiarrés": "mundiarré",
    "mungigan": "mungiga",
    "mungigans": "mungiga",
    "mungigas": "mungiga",
    "mungige": "mungiga",
    "mungigor": "mungiga",
    "mungigorna": "mungiga",
    "mungigornas": "mungiga",
    "mungigors": "mungiga",
    "mungip": "mungipa",
    "mungipan": "mungipa",
    "mungipans": "mungipa",
    "mungipas": "mungipa",
    "mungipe": "mungipa",
    "mungipor": "mungipa",
    "mungiporna": "mungipa",
    "mungipornas": "mungipa",
    "mungipors": "mungipa",
    "mungips": "mungipa",
    "mungoer": "mungo",
    "mungoerna": "mungo",
    "mungoernas": "mungo",
    "mungoers": "mungo",
    "mungon": "mungo",
    "mungons": "mungo",
    "mungor": "mungo",
    "mungorna": "mungo",
    "mungornas": "mungo",
    "mungors": "mungo",
    "mungos": "mungo",
    "munharmonikan": "munharmonika",
    "munharmonikans": "munharmonika",
    "munharmonikas": "munharmonika",
    "munharmonike": "munharmonika",
    "munharmonikor": "munharmonika",
    "munharmonikorna": "munharmonika",
    "munharmonikornas": "munharmonika",
    "munharmonikors": "munharmonika",
    "munhugges": "munhuggas",
    "munhuggits": "munhuggas",
    "munhuggs": "munhuggas",
    "munhygienen": "munhygien",
    "munhygienens": "munhygien",
    "munhygiens": "munhygien",
    "munhäftan": "munhäfta",
    "munhäftans": "munhäfta",
    "munhäftas": "munhäfta",
    "munhål": "munhåla",
    "munhålan": "munhåla",
    "munhålans": "munhåla",
    "munhålas": "munhåla",
    "munhåle": "munhåla",
    "munhålor": "munhåla",
    "munhålorna": "munhåla",
    "munhålornas": "munhåla",
    "munhålors": "munhåla",
    "munhåls": "munhåla",
    "munhöggs": "munhuggas",
    "municipala": "municipal",
    "municipalare": "municipal",
    "municipalares": "municipal",
    "municipalas": "municipal",
    "municipalast": "municipal",
    "municipalaste": "municipal",
    "municipalastes": "municipal",
    "municipalasts": "municipal",
    "municipale": "municipal",
    "municipales": "municipal",
    "municipals": "municipal",
    "municipalsamhällen": "municipalsamhälle",
    "municipalsamhällena": "municipalsamhälle",
    "municipalsamhällenas": "municipalsamhälle",
    "municipalsamhällens": "municipalsamhälle",
    "municipalsamhälles": "municipalsamhälle",
    "municipalsamhället": "municipalsamhälle",
    "municipalsamhällets": "municipalsamhälle",
    "municipalsamhälls": "municipalsamhälle",
    "municipalt": "municipal",
    "municipalts": "municipal",
    "municipie": "municipium",
    "municipier": "municipium",
    "municipierna": "municipium",
    "municipiernas": "municipium",
    "municipiers": "municipium",
    "municipiet": "municipium",
    "municipiets": "municipium",
    "municipiums": "municipium",
    "munkabälten": "munkabälte",
    "munkabältena": "munkabälte",
    "munkabältenas": "munkabälte",
    "munkabältens": "munkabälte",
    "munkabältes": "munkabälte",
    "munkabältet": "munkabälte",
    "munkabältets": "munkabälte",
    "munkar": "munk",
    "munkarna": "munk",
    "munkarnas": "munk",
    "munkars": "munk",
    "munkaveln": "munkavel",
    "munkavelns": "munkavel",
    "munkavels": "munkavel",
    "munkavl": "munkavle",
    "munkavlar": "munkavle",
    "munkavlarna": "munkavle",
    "munkavlarnas": "munkavle",
    "munkavlars": "munkavle",
    "munkavlen": "munkavle",
    "munkavlens": "munkavle",
    "munkavles": "munkavle",
    "munkavls": "munkavle",
    "munkcellen": "munkcell",
    "munkcellens": "munkcell",
    "munkceller": "munkcell",
    "munkcellerna": "munkcell",
    "munkcellernas": "munkcell",
    "munkcellers": "munkcell",
    "munkcells": "munkcell",
    "munken": "munk",
    "munkens": "munk",
    "munkförbanden": "munkförband",
    "munkförbandens": "munkförband",
    "munkförbandet": "munkförband",
    "munkförbandets": "munkförband",
    "munkförbands": "munkförband",
    "munkhätt": "munkhätta",
    "munkhättan": "munkhätta",
    "munkhättans": "munkhätta",
    "munkhättas": "munkhätta",
    "munkhätte": "munkhätta",
    "munkhättor": "munkhätta",
    "munkhättorna": "munkhätta",
    "munkhättornas": "munkhätta",
    "munkhättors": "munkhätta",
    "munkhätts": "munkhätta",
    "munkkåp": "munkkåpa",
    "munkkåpan": "munkkåpa",
    "munkkåpans": "munkkåpa",
    "munkkåpas": "munkkåpa",
    "munkkåpe": "munkkåpa",
    "munkkåpor": "munkkåpa",
    "munkkåporna": "munkkåpa",
    "munkkåpornas": "munkkåpa",
    "munkkåpors": "munkkåpa",
    "munkkåps": "munkkåpa",
    "munklatinet": "munklatin",
    "munklatinets": "munklatin",
    "munklatins": "munklatin",
    "munklikören": "munklikör",
    "munklikörens": "munklikör",
    "munklikörer": "munklikör",
    "munklikörerna": "munklikör",
    "munklikörernas": "munklikör",
    "munklikörers": "munklikör",
    "munklikörs": "munklikör",
    "munklöften": "munklöfte",
    "munklöftena": "munklöfte",
    "munklöftenas": "munklöfte",
    "munklöftens": "munklöfte",
    "munklöftes": "munklöfte",
    "munklöftet": "munklöfte",
    "munklöftets": "munklöfte",
    "munkordens": "munkorden",
    "munkordnar": "munkorden",
    "munkordnarna": "munkorden",
    "munkordnarnas": "munkorden",
    "munkordnars": "munkorden",
    "munkordnen": "munkorden",
    "munkordnens": "munkorden",
    "munkorgar": "munkorg",
    "munkorgarna": "munkorg",
    "munkorgarnas": "munkorg",
    "munkorgars": "munkorg",
    "munkorgen": "munkorg",
    "munkorgens": "munkorg",
    "munkorgs": "munkorg",
    "munkorgslagar": "munkorgslag",
    "munkorgslagarna": "munkorgslag",
    "munkorgslagarnas": "munkorgslag",
    "munkorgslagars": "munkorgslag",
    "munkorgslagen": "munkorgslag",
    "munkorgslagens": "munkorgslag",
    "munkorgslags": "munkorgslag",
    "munks": "munk",
    "munkskriften": "munkskrift",
    "munkskriftens": "munkskrift",
    "munkskrifts": "munkskrift",
    "munkstolar": "munkstol",
    "munkstolarna": "munkstol",
    "munkstolarnas": "munkstol",
    "munkstolars": "munkstol",
    "munkstolen": "munkstol",
    "munkstolens": "munkstol",
    "munkstols": "munkstol",
    "munlagen": "munlag",
    "munlagens": "munlag",
    "munlaget": "munlag",
    "munlagets": "munlag",
    "munlags": "munlag",
    "munläders": "munläder",
    "munlädren": "munläder",
    "munlädrens": "munläder",
    "munlädret": "munläder",
    "munlädrets": "munläder",
    "munläsan": "munläsa",
    "munläsans": "munläsa",
    "munläsas": "munläsa",
    "munnar": "mun",
    "munnarna": "mun",
    "munnarnas": "mun",
    "munnars": "mun",
    "munnen": "mun",
    "munnens": "mun",
    "muns": "mun",
    "munsbitar": "munsbit",
    "munsbitarna": "munsbit",
    "munsbitarnas": "munsbit",
    "munsbitars": "munsbit",
    "munsbiten": "munsbit",
    "munsbitens": "munsbit",
    "munsbits": "munsbit",
    "munskydden": "munskydd",
    "munskyddens": "munskydd",
    "munskyddet": "munskydd",
    "munskyddets": "munskydd",
    "munskydds": "munskydd",
    "munskänkar": "munskänk",
    "munskänkarna": "munskänk",
    "munskänkarnas": "munskänk",
    "munskänkars": "munskänk",
    "munskänken": "munskänk",
    "munskänkens": "munskänk",
    "munskänks": "munskänk",
    "munslemhinnan": "munslemhinna",
    "munslemhinnans": "munslemhinna",
    "munslemhinnas": "munslemhinna",
    "munslemhinne": "munslemhinna",
    "munslemhinnor": "munslemhinna",
    "munslemhinnorna": "munslemhinna",
    "munslemhinnornas": "munslemhinna",
    "munslemhinnors": "munslemhinna",
    "munspelen": "munspel",
    "munspelens": "munspel",
    "munspelet": "munspel",
    "munspelets": "munspel",
    "munspels": "munspel",
    "munstycken": "munstycke",
    "munstyckena": "munstycke",
    "munstyckenas": "munstycke",
    "munstyckens": "munstycke",
    "munstyckes": "munstycke",
    "munstycket": "munstycke",
    "munstyckets": "munstycke",
    "munstycks": "munstycke",
    "munstycksbyten": "munstycksbyte",
    "munstycksbytena": "munstycksbyte",
    "munstycksbytenas": "munstycksbyte",
    "munstycksbytens": "munstycksbyte",
    "munstycksbytes": "munstycksbyte",
    "munstycksbytet": "munstycksbyte",
    "munstycksbytets": "munstycksbyte",
    "munsåren": "munsår",
    "munsårens": "munsår",
    "munsåret": "munsår",
    "munsårets": "munsår",
    "munsårs": "munsår",
    "muntan": "munta",
    "muntans": "munta",
    "muntas": "munta",
    "muntergökar": "muntergök",
    "muntergökarna": "muntergök",
    "muntergökarnas": "muntergök",
    "muntergökars": "muntergök",
    "muntergöken": "muntergök",
    "muntergökens": "muntergök",
    "muntergöks": "muntergök",
    "munterheten": "munterhet",
    "munterhetens": "munterhet",
    "munterheter": "munterhet",
    "munterheterna": "munterhet",
    "munterheternas": "munterhet",
    "munterheters": "munterhet",
    "munterhets": "munterhet",
    "munters": "munter",
    "muntert": "munter",
    "munterts": "munter",
    "muntliga": "muntlig",
    "muntligare": "muntlig",
    "muntligares": "muntlig",
    "muntligas": "muntlig",
    "muntligast": "muntlig",
    "muntligaste": "muntlig",
    "muntligastes": "muntlig",
    "muntligasts": "muntlig",
    "muntlige": "muntlig",
    "muntliges": "muntlig",
    "muntligheten": "muntlighet",
    "muntlighetens": "muntlighet",
    "muntlighets": "muntlighet",
    "muntligs": "muntlig",
    "muntligt": "muntlig",
    "muntligts": "muntlig",
    "muntor": "munta",
    "muntorna": "munta",
    "muntornas": "munta",
    "muntors": "munta",
    "muntra": "munter",
    "muntrare": "munter",
    "muntrares": "munter",
    "muntras": "munter",
    "muntrast": "munter",
    "muntraste": "munter",
    "muntrastes": "munter",
    "muntrasts": "munter",
    "muntrationen": "muntration",
    "muntrationens": "muntration",
    "muntrationer": "muntration",
    "muntrationerna": "muntration",
    "muntrationernas": "muntration",
    "muntrationers": "muntration",
    "muntrations": "muntration",
    "muntre": "munter",
    "muntres": "munter",
    "munvattens": "munvatten",
    "munvattnen": "munvatten",
    "munvattnens": "munvatten",
    "munvattnet": "munvatten",
    "munvattnets": "munvatten",
    "munviga": "munvig",
    "munvigare": "munvig",
    "munvigares": "munvig",
    "munvigas": "munvig",
    "munvigast": "munvig",
    "munvigaste": "munvig",
    "munvigastes": "munvig",
    "munvigasts": "munvig",
    "munvige": "munvig",
    "munviges": "munvig",
    "munvigheten": "munvighet",
    "munvighetens": "munvighet",
    "munvighets": "munvighet",
    "munvigs": "munvig",
    "munvigt": "munvig",
    "munvigts": "munvig",
    "munväderna": "munväder",
    "munvädernas": "munväder",
    "munväders": "munväder",
    "munvädren": "munväder",
    "munvädrens": "munväder",
    "munvädret": "munväder",
    "munvädrets": "munväder",
    "muppar": "mupp",
    "mupparna": "mupp",
    "mupparnas": "mupp",
    "muppars": "mupp",
    "muppen": "mupp",
    "muppens": "mupp",
    "muppiga": "muppig",
    "muppigare": "muppig",
    "muppigares": "muppig",
    "muppigas": "muppig",
    "muppigast": "muppig",
    "muppigaste": "muppig",
    "muppigastes": "muppig",
    "muppigasts": "muppig",
    "muppige": "muppig",
    "muppiges": "muppig",
    "muppigheten": "muppighet",
    "muppighetens": "muppighet",
    "muppighets": "muppighet",
    "muppigs": "muppig",
    "muppigt": "muppig",
    "muppigts": "muppig",
    "mupps": "mupp",
    "mur": "mura",
    "murad": "mura",
    "murade": "mura",
    "murades": "mura",
    "murads": "mura",
    "murala": "mural",
    "muralare": "mural",
    "muralares": "mural",
    "muralas": "mural",
    "muralast": "mural",
    "muralaste": "mural",
    "muralastes": "mural",
    "muralasts": "mural",
    "murale": "mural",
    "murales": "mural",
    "muralmålningar": "muralmålning",
    "muralmålningarna": "muralmålning",
    "muralmålningarnas": "muralmålning",
    "muralmålningars": "muralmålning",
    "muralmålningen": "muralmålning",
    "muralmålningens": "muralmålning",
    "muralmålnings": "muralmålning",
    "murals": "mural",
    "muralt": "mural",
    "muralts": "mural",
    "murande": "mura",
    "muranden": "murande",
    "murandena": "murande",
    "murandenas": "murande",
    "murandens": "murande",
    "murandes": "murande",
    "murandet": "murande",
    "murandets": "murande",
    "murankar": "murankare",
    "murankaren": "murankare",
    "murankarens": "murankare",
    "murankares": "murankare",
    "murankaret": "murankare",
    "murankarets": "murankare",
    "murankarna": "murankare",
    "murankarnas": "murankare",
    "murar": "murare",
    "muraren": "murare",
    "murarens": "murare",
    "murares": "murare",
    "murarna": "murare",
    "murarnas": "murare",
    "murars": "mur",
    "murarskjort": "murarskjorta",
    "murarskjortan": "murarskjorta",
    "murarskjortans": "murarskjorta",
    "murarskjortas": "murarskjorta",
    "murarskjorte": "murarskjorta",
    "murarskjortor": "murarskjorta",
    "murarskjortorna": "murarskjorta",
    "murarskjortornas": "murarskjorta",
    "murarskjortors": "murarskjorta",
    "murarskjorts": "murarskjorta",
    "murarverktygen": "murarverktyg",
    "murarverktygens": "murarverktyg",
    "murarverktyget": "murarverktyg",
    "murarverktygets": "murarverktyg",
    "murarverktygs": "murarverktyg",
    "muras": "mura",
    "murat": "mura",
    "murats": "mura",
    "murbanden": "murband",
    "murbandens": "murband",
    "murbandet": "murband",
    "murbandets": "murband",
    "murbands": "murband",
    "murbruket": "murbruk",
    "murbrukets": "murbruk",
    "murbruks": "murbruk",
    "murbräck": "murbräcka",
    "murbräckan": "murbräcka",
    "murbräckans": "murbräcka",
    "murbräckas": "murbräcka",
    "murbräcke": "murbräcka",
    "murbräckor": "murbräcka",
    "murbräckorna": "murbräcka",
    "murbräckornas": "murbräcka",
    "murbräckors": "murbräcka",
    "murbräcks": "murbräcka",
    "muren": "mur",
    "murens": "mur",
    "murfogar": "murfog",
    "murfogarna": "murfog",
    "murfogarnas": "murfog",
    "murfogars": "murfog",
    "murfogen": "murfog",
    "murfogens": "murfog",
    "murfogs": "murfog",
    "murförbanden": "murförband",
    "murförbandens": "murförband",
    "murförbandet": "murförband",
    "murförbandets": "murförband",
    "murförbands": "murförband",
    "murgrön": "murgröna",
    "murgrönan": "murgröna",
    "murgrönans": "murgröna",
    "murgrönas": "murgröna",
    "murgröne": "murgröna",
    "murgrönemönsterna": "murgrönemönster",
    "murgrönemönsternas": "murgrönemönster",
    "murgrönemönsters": "murgrönemönster",
    "murgrönemönstren": "murgrönemönster",
    "murgrönemönstrens": "murgrönemönster",
    "murgrönemönstret": "murgrönemönster",
    "murgrönemönstrets": "murgrönemönster",
    "murgrönor": "murgröna",
    "murgrönorna": "murgröna",
    "murgrönornas": "murgröna",
    "murgrönors": "murgröna",
    "murgröns": "murgröna",
    "murhörnen": "murhörn",
    "murhörnens": "murhörn",
    "murhörnet": "murhörn",
    "murhörnets": "murhörn",
    "murhörns": "murhörn",
    "murintagen": "murintag",
    "murintagens": "murintag",
    "murintaget": "murintag",
    "murintagets": "murintag",
    "murintags": "murintag",
    "murkel": "murkla",
    "murkenheten": "murkenhet",
    "murkenhetens": "murkenhet",
    "murkenhets": "murkenhet",
    "murkens": "murken",
    "murket": "murken",
    "murkets": "murken",
    "murklan": "murkla",
    "murklans": "murkla",
    "murklas": "murkla",
    "murkle": "murkla",
    "murklor": "murkla",
    "murklorna": "murkla",
    "murklornas": "murkla",
    "murklors": "murkla",
    "murkna": "murken",
    "murknade": "murkna",
    "murknades": "murkna",
    "murknande": "murkna",
    "murknanden": "murknande",
    "murknandena": "murknande",
    "murknandenas": "murknande",
    "murknandens": "murknande",
    "murknandes": "murknande",
    "murknandet": "murknande",
    "murknandets": "murknande",
    "murknar": "murkna",
    "murknare": "murken",
    "murknares": "murken",
    "murknas": "murkna",
    "murknast": "murken",
    "murknaste": "murken",
    "murknastes": "murken",
    "murknasts": "murken",
    "murknat": "murkna",
    "murknats": "murkna",
    "murkne": "murken",
    "murknes": "murken",
    "murkron": "murkrona",
    "murkronan": "murkrona",
    "murkronans": "murkrona",
    "murkronas": "murkrona",
    "murkrone": "murkrona",
    "murkronor": "murkrona",
    "murkronorna": "murkrona",
    "murkronornas": "murkrona",
    "murkronors": "murkrona",
    "murkrons": "murkrona",
    "murkrönen": "murkrön",
    "murkrönens": "murkrön",
    "murkrönet": "murkrön",
    "murkrönets": "murkrön",
    "murkröns": "murkrön",
    "murliven": "murliv",
    "murlivens": "murliv",
    "murlivet": "murliv",
    "murlivets": "murliv",
    "murlivs": "murliv",
    "murmeldjuren": "murmeldjur",
    "murmeldjurens": "murmeldjur",
    "murmeldjuret": "murmeldjur",
    "murmeldjurets": "murmeldjur",
    "murmeldjurs": "murmeldjur",
    "murmeln": "murmel",
    "murmelns": "murmel",
    "murmels": "murmel",
    "murmlar": "murmel",
    "murmlarna": "murmel",
    "murmlarnas": "murmel",
    "murmlars": "murmel",
    "muromgärdade": "muromgärdad",
    "muromgärdades": "muromgärdad",
    "muromgärdads": "muromgärdad",
    "muromgärdat": "muromgärdad",
    "muromgärdats": "muromgärdad",
    "murr": "murre",
    "murrade": "murra",
    "murrades": "murra",
    "murrande": "murra",
    "murranden": "murrande",
    "murrandena": "murrande",
    "murrandenas": "murrande",
    "murrandens": "murrande",
    "murrandes": "murrande",
    "murrandet": "murrande",
    "murrandets": "murrande",
    "murrar": "murre",
    "murrarna": "murre",
    "murrarnas": "murre",
    "murrars": "murre",
    "murras": "murra",
    "murrat": "murra",
    "murrats": "murra",
    "murren": "murre",
    "murrens": "murre",
    "murres": "murre",
    "murret": "murr",
    "murrets": "murr",
    "murriga": "murrig",
    "murrigare": "murrig",
    "murrigares": "murrig",
    "murrigas": "murrig",
    "murrigast": "murrig",
    "murrigaste": "murrig",
    "murrigastes": "murrig",
    "murrigasts": "murrig",
    "murrige": "murrig",
    "murriges": "murrig",
    "murrigheten": "murrighet",
    "murrighetens": "murrighet",
    "murrighets": "murrighet",
    "murrigs": "murrig",
    "murrigt": "murrig",
    "murrigts": "murrig",
    "murrs": "murre",
    "murs": "mur",
    "murskiften": "murskift",
    "murskiftens": "murskift",
    "murskiftet": "murskift",
    "murskiftets": "murskift",
    "murskifts": "murskift",
    "murslevar": "murslev",
    "murslevarna": "murslev",
    "murslevarnas": "murslev",
    "murslevars": "murslev",
    "mursleven": "murslev",
    "murslevens": "murslev",
    "murslevs": "murslev",
    "murstenar": "mursten",
    "murstenarna": "mursten",
    "murstenarnas": "mursten",
    "murstenars": "mursten",
    "murstenen": "mursten",
    "murstenens": "mursten",
    "murstens": "mursten",
    "murveln": "murvel",
    "murvelns": "murvel",
    "murvels": "murvel",
    "murverken": "murverk",
    "murverkens": "murverk",
    "murverket": "murverk",
    "murverkets": "murverk",
    "murverks": "murverk",
    "murvlar": "murvel",
    "murvlarna": "murvel",
    "murvlarnas": "murvel",
    "murvlars": "murvel",
    "musan": "musa",
    "musans": "musa",
    "musar": "mus",
    "musarmar": "musarm",
    "musarmarna": "musarm",
    "musarmarnas": "musarm",
    "musarmars": "musarm",
    "musarmen": "musarm",
    "musarmens": "musarm",
    "musarms": "musarm",
    "musarna": "mus",
    "musarnas": "mus",
    "musars": "mus",
    "musas": "musa",
    "muschen": "musch",
    "muschens": "musch",
    "muscher": "musch",
    "muscherna": "musch",
    "muschernas": "musch",
    "muschers": "musch",
    "muschs": "musch",
    "museala": "museal",
    "musealare": "museal",
    "musealares": "museal",
    "musealas": "museal",
    "musealast": "museal",
    "musealaste": "museal",
    "musealastes": "museal",
    "musealasts": "museal",
    "museale": "museal",
    "museales": "museal",
    "museals": "museal",
    "musealt": "museal",
    "musealts": "museal",
    "museer": "museum",
    "museerna": "museum",
    "museernas": "museum",
    "museers": "museum",
    "museet": "museum",
    "museets": "museum",
    "musei": "museum",
    "museichefen": "museichef",
    "museichefens": "museichef",
    "museichefer": "museichef",
    "museicheferna": "museichef",
    "museichefernas": "museichef",
    "museichefers": "museichef",
    "museichefs": "museichef",
    "museiföremålen": "museiföremål",
    "museiföremålens": "museiföremål",
    "museiföremålet": "museiföremål",
    "museiföremålets": "museiföremål",
    "museiföremåls": "museiföremål",
    "museiföreningar": "museiförening",
    "museiföreningarna": "museiförening",
    "museiföreningarnas": "museiförening",
    "museiföreningars": "museiförening",
    "museiföreningen": "museiförening",
    "museiföreningens": "museiförening",
    "museiförenings": "museiförening",
    "museiintendenten": "museiintendent",
    "museiintendentens": "museiintendent",
    "museiintendenter": "museiintendent",
    "museiintendenterna": "museiintendent",
    "museiintendenternas": "museiintendent",
    "museiintendenters": "museiintendent",
    "museiintendents": "museiintendent",
    "museikatalogen": "museikatalog",
    "museikatalogens": "museikatalog",
    "museikataloger": "museikatalog",
    "museikatalogerna": "museikatalog",
    "museikatalogernas": "museikatalog",
    "museikatalogers": "museikatalog",
    "museikatalogs": "museikatalog",
    "museikonflikten": "museikonflikt",
    "museikonfliktens": "museikonflikt",
    "museikonflikter": "museikonflikt",
    "museikonflikterna": "museikonflikt",
    "museikonflikternas": "museikonflikt",
    "museikonflikters": "museikonflikt",
    "museikonflikts": "museikonflikt",
    "museimontern": "museimonter",
    "museimonterns": "museimonter",
    "museimonters": "museimonter",
    "museimontrar": "museimonter",
    "museimontrarna": "museimonter",
    "museimontrarnas": "museimonter",
    "museimontrars": "museimonter",
    "museimässiga": "museimässig",
    "museimässigare": "museimässig",
    "museimässigares": "museimässig",
    "museimässigas": "museimässig",
    "museimässigast": "museimässig",
    "museimässigaste": "museimässig",
    "museimässigastes": "museimässig",
    "museimässigasts": "museimässig",
    "museimässige": "museimässig",
    "museimässiges": "museimässig",
    "museimässigheten": "museimässighet",
    "museimässighetens": "museimässighet",
    "museimässighets": "museimässighet",
    "museimässigs": "museimässig",
    "museimässigt": "museimässig",
    "museimässigts": "museimässig",
    "museisalar": "museisal",
    "museisalarna": "museisal",
    "museisalarnas": "museisal",
    "museisalars": "museisal",
    "museisalen": "museisal",
    "museisalens": "museisal",
    "museisals": "museisal",
    "museivaktmästar": "museivaktmästare",
    "museivaktmästaren": "museivaktmästare",
    "museivaktmästarens": "museivaktmästare",
    "museivaktmästares": "museivaktmästare",
    "museivaktmästarna": "museivaktmästare",
    "museivaktmästarnas": "museivaktmästare",
    "muselmanen": "muselman",
    "muselmanens": "muselman",
    "muselmaner": "muselman",
    "muselmanerna": "muselman",
    "muselmanernas": "muselman",
    "muselmaners": "muselman",
    "muselmans": "muselman",
    "muselmanska": "muselmansk",
    "muselmanskare": "muselmansk",
    "muselmanskares": "muselmansk",
    "muselmanskas": "muselmansk",
    "muselmanskast": "muselmansk",
    "muselmanskaste": "muselmansk",
    "muselmanskastes": "muselmansk",
    "muselmanskasts": "muselmansk",
    "muselmanske": "muselmansk",
    "muselmanskes": "muselmansk",
    "muselmansks": "muselmansk",
    "muselmanskt": "muselmansk",
    "muselmanskts": "muselmansk",
    "musen": "mus",
    "musens": "mus",
    "muser": "musa",
    "muserna": "musa",
    "musernas": "musa",
    "musers": "musa",
    "musettedragspelen": "musettedragspel",
    "musettedragspelens": "musettedragspel",
    "musettedragspelet": "musettedragspel",
    "musettedragspelets": "musettedragspel",
    "musettedragspels": "musettedragspel",
    "museums": "museum",
    "musgråa": "musgrå",
    "musgråare": "musgrå",
    "musgråares": "musgrå",
    "musgråas": "musgrå",
    "musgråast": "musgrå",
    "musgråaste": "musgrå",
    "musgråastes": "musgrå",
    "musgråasts": "musgrå",
    "musgråe": "musgrå",
    "musgråes": "musgrå",
    "musgrås": "musgrå",
    "musgrått": "musgrå",
    "musgråtts": "musgrå",
    "musicalen": "musical",
    "musicalens": "musical",
    "musicaler": "musical",
    "musicalerna": "musical",
    "musicalernas": "musical",
    "musicalers": "musical",
    "musicals": "musical",
    "musicerade": "musicera",
    "musicerades": "musicera",
    "musicerande": "musicera",
    "musiceranden": "musicerande",
    "musicerandena": "musicerande",
    "musicerandenas": "musicerande",
    "musicerandens": "musicerande",
    "musicerandes": "musicerande",
    "musicerandet": "musicerande",
    "musicerandets": "musicerande",
    "musicerar": "musicera",
    "musiceras": "musicera",
    "musicerat": "musicera",
    "musicerats": "musicera",
    "musiceringar": "musicering",
    "musiceringarna": "musicering",
    "musiceringarnas": "musicering",
    "musiceringars": "musicering",
    "musiceringen": "musicering",
    "musiceringens": "musicering",
    "musicerings": "musicering",
    "musikala": "musikal",
    "musikalare": "musikal",
    "musikalares": "musikal",
    "musikalas": "musikal",
    "musikalast": "musikal",
    "musikalaste": "musikal",
    "musikalastes": "musikal",
    "musikalasts": "musikal",
    "musikalbumen": "musikalbum",
    "musikalbumens": "musikalbum",
    "musikalbumet": "musikalbum",
    "musikalbumets": "musikalbum",
    "musikalbums": "musikalbum",
    "musikale": "musikal",
    "musikalen": "musikal",
    "musikalens": "musikal",
    "musikaler": "musikal",
    "musikalerna": "musikal",
    "musikalernas": "musikal",
    "musikalers": "musikal",
    "musikales": "musikal",
    "musikalie": "musikalier",
    "musikalierna": "musikalier",
    "musikaliernas": "musikalier",
    "musikaliers": "musikalier",
    "musikaliska": "musikalisk",
    "musikaliskare": "musikalisk",
    "musikaliskares": "musikalisk",
    "musikaliskas": "musikalisk",
    "musikaliskast": "musikalisk",
    "musikaliskaste": "musikalisk",
    "musikaliskastes": "musikalisk",
    "musikaliskasts": "musikalisk",
    "musikaliske": "musikalisk",
    "musikaliskes": "musikalisk",
    "musikalisks": "musikalisk",
    "musikaliskt": "musikalisk",
    "musikaliskts": "musikalisk",
    "musikaliteten": "musikalitet",
    "musikalitetens": "musikalitet",
    "musikaliteter": "musikalitet",
    "musikaliteterna": "musikalitet",
    "musikaliteternas": "musikalitet",
    "musikaliteters": "musikalitet",
    "musikalitets": "musikalitet",
    "musikals": "musikal",
    "musikalt": "musikal",
    "musikalts": "musikal",
    "musikanläggningar": "musikanläggning",
    "musikanläggningarna": "musikanläggning",
    "musikanläggningarnas": "musikanläggning",
    "musikanläggningars": "musikanläggning",
    "musikanläggningen": "musikanläggning",
    "musikanläggningens": "musikanläggning",
    "musikanläggnings": "musikanläggning",
    "musikanten": "musikant",
    "musikantens": "musikant",
    "musikanter": "musikant",
    "musikanterna": "musikant",
    "musikanternas": "musikant",
    "musikanters": "musikant",
    "musikants": "musikant",
    "musikdirektören": "musikdirektör",
    "musikdirektörens": "musikdirektör",
    "musikdirektörer": "musikdirektör",
    "musikdirektörerna": "musikdirektör",
    "musikdirektörernas": "musikdirektör",
    "musikdirektörers": "musikdirektör",
    "musikdirektörn": "musikdirektör",
    "musikdirektörns": "musikdirektör",
    "musikdirektörs": "musikdirektör",
    "musikdraman": "musikdrama",
    "musikdramana": "musikdrama",
    "musikdramanas": "musikdrama",
    "musikdramans": "musikdrama",
    "musikdramas": "musikdrama",
    "musikdramat": "musikdrama",
    "musikdramats": "musikdrama",
    "musikdramer": "musikdrama",
    "musikdramerna": "musikdrama",
    "musikdramernas": "musikdrama",
    "musikdramers": "musikdrama",
    "musikeleven": "musikelev",
    "musikelevens": "musikelev",
    "musikelever": "musikelev",
    "musikeleverna": "musikelev",
    "musikelevernas": "musikelev",
    "musikelevers": "musikelev",
    "musikelevs": "musikelev",
    "musiken": "musik",
    "musikens": "musik",
    "musikensemblen": "musikensemble",
    "musikensemblens": "musikensemble",
    "musikensembler": "musikensemble",
    "musikensemblerna": "musikensemble",
    "musikensemblernas": "musikensemble",
    "musikensemblers": "musikensemble",
    "musikensembles": "musikensemble",
    "musikermiljöer": "musikermiljö",
    "musikermiljöerna": "musikermiljö",
    "musikermiljöernas": "musikermiljö",
    "musikermiljöers": "musikermiljö",
    "musikermiljön": "musikermiljö",
    "musikermiljöns": "musikermiljö",
    "musikermiljös": "musikermiljö",
    "musikern": "musiker",
    "musikerna": "musiker",
    "musikernas": "musiker",
    "musikerns": "musiker",
    "musikers": "musiker",
    "musikfestivalen": "musikfestival",
    "musikfestivalens": "musikfestival",
    "musikfestivaler": "musikfestival",
    "musikfestivalerna": "musikfestival",
    "musikfestivalernas": "musikfestival",
    "musikfestivalers": "musikfestival",
    "musikfestivals": "musikfestival",
    "musikförlagen": "musikförlag",
    "musikförlagens": "musikförlag",
    "musikförlaget": "musikförlag",
    "musikförlagets": "musikförlag",
    "musikförlags": "musikförlag",
    "musikgruppen": "musikgrupp",
    "musikgruppens": "musikgrupp",
    "musikgrupper": "musikgrupp",
    "musikgrupperna": "musikgrupp",
    "musikgruppernas": "musikgrupp",
    "musikgruppers": "musikgrupp",
    "musikgrupps": "musikgrupp",
    "musikgudstjänsten": "musikgudstjänst",
    "musikgudstjänstens": "musikgudstjänst",
    "musikgudstjänster": "musikgudstjänst",
    "musikgudstjänsterna": "musikgudstjänst",
    "musikgudstjänsternas": "musikgudstjänst",
    "musikgudstjänsters": "musikgudstjänst",
    "musikgudstjänsts": "musikgudstjänst",
    "musikgymnasie": "musikgymnasium",
    "musikgymnasier": "musikgymnasium",
    "musikgymnasierna": "musikgymnasium",
    "musikgymnasiernas": "musikgymnasium",
    "musikgymnasiers": "musikgymnasium",
    "musikgymnasiet": "musikgymnasium",
    "musikgymnasiets": "musikgymnasium",
    "musikgymnasiums": "musikgymnasium",
    "musikhögskolan": "musikhögskola",
    "musikhögskolans": "musikhögskola",
    "musikhögskolas": "musikhögskola",
    "musikhögskole": "musikhögskola",
    "musikhögskolor": "musikhögskola",
    "musikhögskolorna": "musikhögskola",
    "musikhögskolornas": "musikhögskola",
    "musikhögskolors": "musikhögskola",
    "musikinstrumenten": "musikinstrument",
    "musikinstrumentens": "musikinstrument",
    "musikinstrumentet": "musikinstrument",
    "musikinstrumentets": "musikinstrument",
    "musikinstruments": "musikinstrument",
    "musikkaféer": "musikkafé",
    "musikkaféerna": "musikkafé",
    "musikkaféernas": "musikkafé",
    "musikkaféers": "musikkafé",
    "musikkaféet": "musikkafé",
    "musikkaféets": "musikkafé",
    "musikkafés": "musikkafé",
    "musikkafét": "musikkafé",
    "musikkaféts": "musikkafé",
    "musikkompositionen": "musikkomposition",
    "musikkompositionens": "musikkomposition",
    "musikkompositioner": "musikkomposition",
    "musikkompositionerna": "musikkomposition",
    "musikkompositionernas": "musikkomposition",
    "musikkompositioners": "musikkomposition",
    "musikkompositions": "musikkomposition",
    "musikkonservatorie": "musikkonservatorium",
    "musikkonservatorier": "musikkonservatorium",
    "musikkonservatorierna": "musikkonservatorium",
    "musikkonservatoriernas": "musikkonservatorium",
    "musikkonservatoriers": "musikkonservatorium",
    "musikkonservatoriet": "musikkonservatorium",
    "musikkonservatoriets": "musikkonservatorium",
    "musikkonservatoriums": "musikkonservatorium",
    "musikkvartetten": "musikkvartett",
    "musikkvartettens": "musikkvartett",
    "musikkvartetter": "musikkvartett",
    "musikkvartetterna": "musikkvartett",
    "musikkvartetternas": "musikkvartett",
    "musikkvartetters": "musikkvartett",
    "musikkvartetts": "musikkvartett",
    "musikkåren": "musikkår",
    "musikkårens": "musikkår",
    "musikkårer": "musikkår",
    "musikkårerna": "musikkår",
    "musikkårernas": "musikkår",
    "musikkårers": "musikkår",
    "musikkårs": "musikkår",
    "musikliven": "musikliv",
    "musiklivens": "musikliv",
    "musiklivet": "musikliv",
    "musiklivets": "musikliv",
    "musiklivs": "musikliv",
    "musiklärar": "musiklärare",
    "musikläraren": "musiklärare",
    "musiklärarens": "musiklärare",
    "musiklärares": "musiklärare",
    "musiklärarna": "musiklärare",
    "musiklärarnas": "musiklärare",
    "musikmässiga": "musikmässig",
    "musikmässigare": "musikmässig",
    "musikmässigares": "musikmässig",
    "musikmässigas": "musikmässig",
    "musikmässigast": "musikmässig",
    "musikmässigaste": "musikmässig",
    "musikmässigastes": "musikmässig",
    "musikmässigasts": "musikmässig",
    "musikmässige": "musikmässig",
    "musikmässiges": "musikmässig",
    "musikmässigs": "musikmässig",
    "musikmässigt": "musikmässig",
    "musikmässigts": "musikmässig",
    "musikologen": "musikolog",
    "musikologens": "musikolog",
    "musikologer": "musikolog",
    "musikologerna": "musikolog",
    "musikologernas": "musikolog",
    "musikologers": "musikolog",
    "musikologs": "musikolog",
    "musiks": "musik",
    "musikskal": "musikskala",
    "musikskalan": "musikskala",
    "musikskalans": "musikskala",
    "musikskalas": "musikskala",
    "musikskale": "musikskala",
    "musikskalor": "musikskala",
    "musikskalorna": "musikskala",
    "musikskalornas": "musikskala",
    "musikskalors": "musikskala",
    "musikskals": "musikskala",
    "musikskolan": "musikskola",
    "musikskolans": "musikskola",
    "musikskolas": "musikskola",
    "musikskole": "musikskola",
    "musikskolor": "musikskola",
    "musikskolorna": "musikskola",
    "musikskolornas": "musikskola",
    "musikskolors": "musikskola",
    "musikstilar": "musikstil",
    "musikstilarna": "musikstil",
    "musikstilarnas": "musikstil",
    "musikstilars": "musikstil",
    "musikstilen": "musikstil",
    "musikstilens": "musikstil",
    "musikstils": "musikstil",
    "musikstycken": "musikstycke",
    "musikstyckena": "musikstycke",
    "musikstyckenas": "musikstycke",
    "musikstyckens": "musikstycke",
    "musikstyckes": "musikstycke",
    "musikstycket": "musikstycke",
    "musikstyckets": "musikstycke",
    "musikstycks": "musikstycke",
    "musikstämman": "musikstämma",
    "musikstämmans": "musikstämma",
    "musikstämmas": "musikstämma",
    "musikstämme": "musikstämma",
    "musikstämmo": "musikstämma",
    "musikstämmor": "musikstämma",
    "musikstämmorna": "musikstämma",
    "musikstämmornas": "musikstämma",
    "musikstämmors": "musikstämma",
    "musikteckens": "musiktecken",
    "musiktecknen": "musiktecken",
    "musiktecknens": "musiktecken",
    "musiktecknet": "musiktecken",
    "musiktecknets": "musiktecken",
    "musiktomtar": "musiktomte",
    "musiktomtarna": "musiktomte",
    "musiktomtarnas": "musiktomte",
    "musiktomtars": "musiktomte",
    "musiktomten": "musiktomte",
    "musiktomtens": "musiktomte",
    "musiktomtes": "musiktomte",
    "musikverken": "musikverk",
    "musikverkens": "musikverk",
    "musikverket": "musikverk",
    "musikverkets": "musikverk",
    "musikverks": "musikverk",
    "musikverksamheten": "musikverksamhet",
    "musikverksamhetens": "musikverksamhet",
    "musikverksamheter": "musikverksamhet",
    "musikverksamheterna": "musikverksamhet",
    "musikverksamheternas": "musikverksamhet",
    "musikverksamheters": "musikverksamhet",
    "musikverksamhets": "musikverksamhet",
    "musikvetenskapen": "musikvetenskap",
    "musikvetenskapens": "musikvetenskap",
    "musikvetenskaper": "musikvetenskap",
    "musikvetenskaperna": "musikvetenskap",
    "musikvetenskapernas": "musikvetenskap",
    "musikvetenskapers": "musikvetenskap",
    "musikvetenskaps": "musikvetenskap",
    "musiköras": "musiköra",
    "musikörat": "musiköra",
    "musikörats": "musiköra",
    "musiska": "musisk",
    "musiskare": "musisk",
    "musiskares": "musisk",
    "musiskas": "musisk",
    "musiskast": "musisk",
    "musiskaste": "musisk",
    "musiskastes": "musisk",
    "musiskasts": "musisk",
    "musiske": "musisk",
    "musiskes": "musisk",
    "musisks": "musisk",
    "musiskt": "musisk",
    "musiskts": "musisk",
    "musivguldet": "musivguld",
    "musivguldets": "musivguld",
    "musivgulds": "musivguld",
    "musjiken": "musjik",
    "musjikens": "musjik",
    "musjiker": "musjik",
    "musjikerna": "musjik",
    "musjikernas": "musjik",
    "musjikers": "musjik",
    "musjiks": "musjik",
    "muskatdruv": "muskatdruva",
    "muskatdruvan": "muskatdruva",
    "muskatdruvans": "muskatdruva",
    "muskatdruvas": "muskatdruva",
    "muskatdruve": "muskatdruva",
    "muskatdruvor": "muskatdruva",
    "muskatdruvorna": "muskatdruva",
    "muskatdruvornas": "muskatdruva",
    "muskatdruvors": "muskatdruva",
    "muskatdruvs": "muskatdruva",
    "muskatellen": "muskatell",
    "muskatellens": "muskatell",
    "muskatells": "muskatell",
    "muskaten": "muskat",
    "muskatens": "muskat",
    "muskats": "muskat",
    "muskedunders": "muskedunder",
    "muskedundren": "muskedunder",
    "muskedundrens": "muskedunder",
    "muskedundret": "muskedunder",
    "muskedundrets": "muskedunder",
    "muskelarbeten": "muskelarbete",
    "muskelarbetena": "muskelarbete",
    "muskelarbetenas": "muskelarbete",
    "muskelarbetens": "muskelarbete",
    "muskelarbetes": "muskelarbete",
    "muskelarbetet": "muskelarbete",
    "muskelarbetets": "muskelarbete",
    "muskelarbets": "muskelarbete",
    "muskelatrofien": "muskelatrofi",
    "muskelatrofiens": "muskelatrofi",
    "muskelatrofier": "muskelatrofi",
    "muskelatrofierna": "muskelatrofi",
    "muskelatrofiernas": "muskelatrofi",
    "muskelatrofiers": "muskelatrofi",
    "muskelatrofin": "muskelatrofi",
    "muskelatrofins": "muskelatrofi",
    "muskelatrofis": "muskelatrofi",
    "muskelbristningar": "muskelbristning",
    "muskelbristningarna": "muskelbristning",
    "muskelbristningarnas": "muskelbristning",
    "muskelbristningars": "muskelbristning",
    "muskelbristningen": "muskelbristning",
    "muskelbristningens": "muskelbristning",
    "muskelbristnings": "muskelbristning",
    "muskelbyggar": "muskelbyggare",
    "muskelbyggaren": "muskelbyggare",
    "muskelbyggarens": "muskelbyggare",
    "muskelbyggares": "muskelbyggare",
    "muskelbyggarna": "muskelbyggare",
    "muskelbyggarnas": "muskelbyggare",
    "muskelbyggnaden": "muskelbyggnad",
    "muskelbyggnadens": "muskelbyggnad",
    "muskelbyggnader": "muskelbyggnad",
    "muskelbyggnaderna": "muskelbyggnad",
    "muskelbyggnadernas": "muskelbyggnad",
    "muskelbyggnaders": "muskelbyggnad",
    "muskelbyggnads": "muskelbyggnad",
    "muskelbåtar": "muskelbåt",
    "muskelbåtarna": "muskelbåt",
    "muskelbåtarnas": "muskelbåt",
    "muskelbåtars": "muskelbåt",
    "muskelbåten": "muskelbåt",
    "muskelbåtens": "muskelbåt",
    "muskelbåts": "muskelbåt",
    "muskelcellen": "muskelcell",
    "muskelcellens": "muskelcell",
    "muskelceller": "muskelcell",
    "muskelcellerna": "muskelcell",
    "muskelcellernas": "muskelcell",
    "muskelcellers": "muskelcell",
    "muskelcells": "muskelcell",
    "muskelfibern": "muskelfiber",
    "muskelfiberns": "muskelfiber",
    "muskelfibers": "muskelfiber",
    "muskelfibrer": "muskelfiber",
    "muskelfibrerna": "muskelfiber",
    "muskelfibrernas": "muskelfiber",
    "muskelfibrers": "muskelfiber",
    "muskelförlamningar": "muskelförlamning",
    "muskelförlamningarna": "muskelförlamning",
    "muskelförlamningarnas": "muskelförlamning",
    "muskelförlamningars": "muskelförlamning",
    "muskelförlamningen": "muskelförlamning",
    "muskelförlamningens": "muskelförlamning",
    "muskelförlamnings": "muskelförlamning",
    "muskelförtviningar": "muskelförtvining",
    "muskelförtviningarna": "muskelförtvining",
    "muskelförtviningarnas": "muskelförtvining",
    "muskelförtviningars": "muskelförtvining",
    "muskelförtviningen": "muskelförtvining",
    "muskelförtviningens": "muskelförtvining",
    "muskelförtvinings": "muskelförtvining",
    "muskelknipp": "muskelknippe",
    "muskelknippen": "muskelknippe",
    "muskelknippena": "muskelknippe",
    "muskelknippenas": "muskelknippe",
    "muskelknippens": "muskelknippe",
    "muskelknippes": "muskelknippe",
    "muskelknippet": "muskelknippe",
    "muskelknippets": "muskelknippe",
    "muskelknipps": "muskelknippe",
    "muskelknutt": "muskelknutte",
    "muskelknuttar": "muskelknutte",
    "muskelknuttarna": "muskelknutte",
    "muskelknuttarnas": "muskelknutte",
    "muskelknuttars": "muskelknutte",
    "muskelknutten": "muskelknutte",
    "muskelknuttens": "muskelknutte",
    "muskelknuttes": "muskelknutte",
    "muskelknutts": "muskelknutte",
    "muskelkraften": "muskelkraft",
    "muskelkraftens": "muskelkraft",
    "muskelkrafter": "muskelkraft",
    "muskelkrafterna": "muskelkraft",
    "muskelkrafternas": "muskelkraft",
    "muskelkrafters": "muskelkraft",
    "muskelkrafts": "muskelkraft",
    "muskelkrampen": "muskelkramp",
    "muskelkrampens": "muskelkramp",
    "muskelkramper": "muskelkramp",
    "muskelkramperna": "muskelkramp",
    "muskelkrampernas": "muskelkramp",
    "muskelkrampers": "muskelkramp",
    "muskelkramps": "muskelkramp",
    "muskellängden": "muskellängd",
    "muskellängdens": "muskellängd",
    "muskellängder": "muskellängd",
    "muskellängderna": "muskellängd",
    "muskellängdernas": "muskellängd",
    "muskellängders": "muskellängd",
    "muskellängds": "muskellängd",
    "muskelmag": "muskelmage",
    "muskelmagar": "muskelmage",
    "muskelmagarna": "muskelmage",
    "muskelmagarnas": "muskelmage",
    "muskelmagars": "muskelmage",
    "muskelmagen": "muskelmage",
    "muskelmagens": "muskelmage",
    "muskelmages": "muskelmage",
    "muskelmags": "muskelmage",
    "muskeln": "muskel",
    "muskelns": "muskel",
    "muskelreumatismen": "muskelreumatism",
    "muskelreumatismens": "muskelreumatism",
    "muskelreumatismer": "muskelreumatism",
    "muskelreumatismerna": "muskelreumatism",
    "muskelreumatismernas": "muskelreumatism",
    "muskelreumatismers": "muskelreumatism",
    "muskelreumatisms": "muskelreumatism",
    "muskelringar": "muskelring",
    "muskelringarna": "muskelring",
    "muskelringarnas": "muskelring",
    "muskelringars": "muskelring",
    "muskelringen": "muskelring",
    "muskelringens": "muskelring",
    "muskelrings": "muskelring",
    "muskelryckningar": "muskelryckning",
    "muskelryckningarna": "muskelryckning",
    "muskelryckningarnas": "muskelryckning",
    "muskelryckningars": "muskelryckning",
    "muskelryckningen": "muskelryckning",
    "muskelryckningens": "muskelryckning",
    "muskelrycknings": "muskelryckning",
    "muskels": "muskel",
    "muskelsammandragningar": "muskelsammandragning",
    "muskelsammandragningarna": "muskelsammandragning",
    "muskelsammandragningarnas": "muskelsammandragning",
    "muskelsammandragningars": "muskelsammandragning",
    "muskelsammandragningen": "muskelsammandragning",
    "muskelsammandragningens": "muskelsammandragning",
    "muskelsammandragnings": "muskelsammandragning",
    "muskelsen": "muskelsena",
    "muskelsenan": "muskelsena",
    "muskelsenans": "muskelsena",
    "muskelsenas": "muskelsena",
    "muskelsene": "muskelsena",
    "muskelsenor": "muskelsena",
    "muskelsenorna": "muskelsena",
    "muskelsenornas": "muskelsena",
    "muskelsenors": "muskelsena",
    "muskelsens": "muskelsena",
    "muskelsinnes": "muskelsinne",
    "muskelsinnet": "muskelsinne",
    "muskelsinnets": "muskelsinne",
    "muskelspelet": "muskelspel",
    "muskelspelets": "muskelspel",
    "muskelspels": "muskelspel",
    "muskelspol": "muskelspole",
    "muskelspolar": "muskelspole",
    "muskelspolarna": "muskelspole",
    "muskelspolarnas": "muskelspole",
    "muskelspolars": "muskelspole",
    "muskelspolen": "muskelspole",
    "muskelspolens": "muskelspole",
    "muskelspoles": "muskelspole",
    "muskelspols": "muskelspole",
    "muskelspänningar": "muskelspänning",
    "muskelspänningarna": "muskelspänning",
    "muskelspänningarnas": "muskelspänning",
    "muskelspänningars": "muskelspänning",
    "muskelspänningen": "muskelspänning",
    "muskelspänningens": "muskelspänning",
    "muskelspännings": "muskelspänning",
    "muskelsträckningar": "muskelsträckning",
    "muskelsträckningarna": "muskelsträckning",
    "muskelsträckningarnas": "muskelsträckning",
    "muskelsträckningars": "muskelsträckning",
    "muskelsträckningen": "muskelsträckning",
    "muskelsträckningens": "muskelsträckning",
    "muskelsträcknings": "muskelsträckning",
    "muskelstyrkan": "muskelstyrka",
    "muskelstyrkans": "muskelstyrka",
    "muskelstyrkas": "muskelstyrka",
    "muskelstyrke": "muskelstyrka",
    "muskelstyrkor": "muskelstyrka",
    "muskelstyrkorna": "muskelstyrka",
    "muskelstyrkornas": "muskelstyrka",
    "muskelstyrkors": "muskelstyrka",
    "muskelstärkar": "muskelstärkare",
    "muskelstärkaren": "muskelstärkare",
    "muskelstärkarens": "muskelstärkare",
    "muskelstärkares": "muskelstärkare",
    "muskelstärkarna": "muskelstärkare",
    "muskelstärkarnas": "muskelstärkare",
    "muskeltrådar": "muskeltråd",
    "muskeltrådarna": "muskeltråd",
    "muskeltrådarnas": "muskeltråd",
    "muskeltrådars": "muskeltråd",
    "muskeltråden": "muskeltråd",
    "muskeltrådens": "muskeltråd",
    "muskeltråds": "muskeltråd",
    "muskelvärken": "muskelvärk",
    "muskelvärkens": "muskelvärk",
    "muskelvärks": "muskelvärk",
    "muskelvävnaden": "muskelvävnad",
    "muskelvävnadens": "muskelvävnad",
    "muskelvävnader": "muskelvävnad",
    "muskelvävnaderna": "muskelvävnad",
    "muskelvävnadernas": "muskelvävnad",
    "muskelvävnaders": "muskelvävnad",
    "muskelvävnads": "muskelvävnad",
    "musketerar": "musketerare",
    "musketeraren": "musketerare",
    "musketerarens": "musketerare",
    "musketerares": "musketerare",
    "musketerarna": "musketerare",
    "musketerarnas": "musketerare",
    "musketören": "musketör",
    "musketörens": "musketör",
    "musketörer": "musketör",
    "musketörerna": "musketör",
    "musketörernas": "musketör",
    "musketörers": "musketör",
    "musketörs": "musketör",
    "muskler": "muskel",
    "musklerna": "muskel",
    "musklernas": "muskel",
    "musklers": "muskel",
    "muskotblom": "muskotblomma",
    "muskotblomman": "muskotblomma",
    "muskotblommans": "muskotblomma",
    "muskotblommas": "muskotblomma",
    "muskotblomme": "muskotblomma",
    "muskotblommor": "muskotblomma",
    "muskotblommorna": "muskotblomma",
    "muskotblommornas": "muskotblomma",
    "muskotblommors": "muskotblomma",
    "muskotbloms": "muskotblomma",
    "muskoten": "muskot",
    "muskotens": "muskot",
    "muskotnöten": "muskotnöt",
    "muskotnötens": "muskotnöt",
    "muskotnöts": "muskotnöt",
    "muskotnötter": "muskotnöt",
    "muskotnötterna": "muskotnöt",
    "muskotnötternas": "muskotnöt",
    "muskotnötters": "muskotnöt",
    "muskots": "muskot",
    "muskotträden": "muskotträd",
    "muskotträdens": "muskotträd",
    "muskotträdet": "muskotträd",
    "muskotträdets": "muskotträd",
    "muskotträds": "muskotträd",
    "muskulaturen": "muskulatur",
    "muskulaturens": "muskulatur",
    "muskulaturer": "muskulatur",
    "muskulaturerna": "muskulatur",
    "muskulaturernas": "muskulatur",
    "muskulaturers": "muskulatur",
    "muskulaturs": "muskulatur",
    "muskulösa": "muskulös",
    "muskulösare": "muskulös",
    "muskulösares": "muskulös",
    "muskulösas": "muskulös",
    "muskulösast": "muskulös",
    "muskulösaste": "muskulös",
    "muskulösastes": "muskulös",
    "muskulösasts": "muskulös",
    "muskulöse": "muskulös",
    "muskulöses": "muskulös",
    "muskulöst": "muskulös",
    "muskulösts": "muskulös",
    "musköten": "musköt",
    "muskötens": "musköt",
    "musköter": "musköt",
    "musköterna": "musköt",
    "musköternas": "musköt",
    "musköters": "musköt",
    "muskötgaffeln": "muskötgaffel",
    "muskötgaffelns": "muskötgaffel",
    "muskötgaffels": "muskötgaffel",
    "muskötgafflar": "muskötgaffel",
    "muskötgafflarna": "muskötgaffel",
    "muskötgafflarnas": "muskötgaffel",
    "muskötgafflars": "muskötgaffel",
    "musköts": "musköt",
    "muslimen": "muslim",
    "muslimens": "muslim",
    "muslimer": "muslim",
    "muslimerna": "muslim",
    "muslimernas": "muslim",
    "muslimers": "muslim",
    "muslims": "muslim",
    "muslimska": "muslimsk",
    "muslimskare": "muslimsk",
    "muslimskares": "muslimsk",
    "muslimskas": "muslimsk",
    "muslimskast": "muslimsk",
    "muslimskaste": "muslimsk",
    "muslimskastes": "muslimsk",
    "muslimskasts": "muslimsk",
    "muslimske": "muslimsk",
    "muslimskes": "muslimsk",
    "muslimsks": "muslimsk",
    "muslimskt": "muslimsk",
    "muslimskts": "muslimsk",
    "muslinen": "muslin",
    "muslinens": "muslin",
    "musliner": "muslin",
    "muslinerna": "muslin",
    "muslinernas": "muslin",
    "musliners": "muslin",
    "muslinet": "muslin",
    "muslinets": "muslin",
    "muslins": "muslin",
    "muslinsklänningar": "muslinsklänning",
    "muslinsklänningarna": "muslinsklänning",
    "muslinsklänningarnas": "muslinsklänning",
    "muslinsklänningars": "muslinsklänning",
    "muslinsklänningen": "muslinsklänning",
    "muslinsklänningens": "muslinsklänning",
    "muslinsklännings": "muslinsklänning",
    "musmamman": "musmamma",
    "musmammans": "musmamma",
    "musmammas": "musmamma",
    "musmamme": "musmamma",
    "musmammor": "musmamma",
    "musmammorna": "musmamma",
    "musmammornas": "musmamma",
    "musmammors": "musmamma",
    "musor": "musa",
    "musorna": "musa",
    "musornas": "musa",
    "musors": "musa",
    "mussel": "mussla",
    "musselformen": "musselform",
    "musselformens": "musselform",
    "musselformer": "musselform",
    "musselformerna": "musselform",
    "musselformernas": "musselform",
    "musselformers": "musselform",
    "musselforms": "musselform",
    "musselodlingar": "musselodling",
    "musselodlingarna": "musselodling",
    "musselodlingarnas": "musselodling",
    "musselodlingars": "musselodling",
    "musselodlingen": "musselodling",
    "musselodlingens": "musselodling",
    "musselodlings": "musselodling",
    "musselskalen": "musselskal",
    "musselskalens": "musselskal",
    "musselskalet": "musselskal",
    "musselskalets": "musselskal",
    "musselskals": "musselskal",
    "mussemajjar": "mussemajje",
    "mussemajjarna": "mussemajje",
    "mussemajjarnas": "mussemajje",
    "mussemajjars": "mussemajje",
    "mussemajjen": "mussemajje",
    "mussemajjens": "mussemajje",
    "mussemajjes": "mussemajje",
    "musserade": "mussera",
    "musserades": "mussera",
    "musserande": "mussera",
    "musseranden": "musserande",
    "musserandena": "musserande",
    "musserandenas": "musserande",
    "musserandens": "musserande",
    "musserandes": "musserande",
    "musserandet": "musserande",
    "musserandets": "musserande",
    "musserar": "mussera",
    "musseras": "mussera",
    "musserat": "mussera",
    "musserats": "mussera",
    "musseringar": "mussering",
    "musseringarna": "mussering",
    "musseringarnas": "mussering",
    "musseringars": "mussering",
    "musseringen": "mussering",
    "musseringens": "mussering",
    "musserings": "mussering",
    "musseronen": "musseron",
    "musseronens": "musseron",
    "musseroner": "musseron",
    "musseronerna": "musseron",
    "musseronernas": "musseron",
    "musseroners": "musseron",
    "musserons": "musseron",
    "musslan": "mussla",
    "musslans": "mussla",
    "musslas": "mussla",
    "mussle": "mussla",
    "musslor": "mussla",
    "musslorna": "mussla",
    "musslornas": "mussla",
    "musslors": "mussla",
    "mustangen": "mustang",
    "mustangens": "mustang",
    "mustanger": "mustang",
    "mustangerna": "mustang",
    "mustangernas": "mustang",
    "mustangers": "mustang",
    "mustangs": "mustang",
    "mustaschen": "mustasch",
    "mustaschens": "mustasch",
    "mustascher": "mustasch",
    "mustascherna": "mustasch",
    "mustaschernas": "mustasch",
    "mustaschers": "mustasch",
    "mustaschs": "mustasch",
    "musten": "must",
    "mustens": "must",
    "muster": "must",
    "musterier": "musteri",
    "musterierna": "musteri",
    "musteriernas": "musteri",
    "musteriers": "musteri",
    "musteriet": "musteri",
    "musteriets": "musteri",
    "musteris": "musteri",
    "musterit": "musteri",
    "musterits": "musteri",
    "musterna": "must",
    "musternas": "must",
    "musters": "must",
    "mustiga": "mustig",
    "mustigare": "mustig",
    "mustigares": "mustig",
    "mustigas": "mustig",
    "mustigast": "mustig",
    "mustigaste": "mustig",
    "mustigastes": "mustig",
    "mustigasts": "mustig",
    "mustige": "mustig",
    "mustiges": "mustig",
    "mustigheten": "mustighet",
    "mustighetens": "mustighet",
    "mustighets": "mustighet",
    "mustigs": "mustig",
    "mustigt": "mustig",
    "mustigts": "mustig",
    "mustrakten": "mustrakt",
    "mustraktens": "mustrakt",
    "mustrakter": "mustrakt",
    "mustrakterna": "mustrakt",
    "mustrakternas": "mustrakt",
    "mustrakters": "mustrakt",
    "mustrakts": "mustrakt",
    "musts": "must",
    "musöras": "musöra",
    "musörat": "musöra",
    "musörats": "musöra",
    "musöron": "musöra",
    "musöronen": "musöra",
    "musöronens": "musöra",
    "musörons": "musöra",
    "mut": "muta",
    "mutad": "muta",
    "mutade": "muta",
    "mutades": "muta",
    "mutads": "muta",
    "mutagena": "mutagen",
    "mutagenare": "mutagen",
    "mutagenares": "mutagen",
    "mutagenas": "mutagen",
    "mutagenast": "mutagen",
    "mutagenaste": "mutagen",
    "mutagenastes": "mutagen",
    "mutagenasts": "mutagen",
    "mutagene": "mutagen",
    "mutagenen": "mutagen",
    "mutagenens": "mutagen",
    "mutagener": "mutagen",
    "mutagenerna": "mutagen",
    "mutagenernas": "mutagen",
    "mutageners": "mutagen",
    "mutagenes": "mutagen",
    "mutagens": "mutagen",
    "mutagent": "mutagen",
    "mutagents": "mutagen",
    "mutan": "muta",
    "mutande": "muta",
    "mutanden": "mutande",
    "mutandena": "mutande",
    "mutandenas": "mutande",
    "mutandens": "mutande",
    "mutandes": "mutande",
    "mutandet": "mutande",
    "mutandets": "mutande",
    "mutanklagade": "mutanklagad",
    "mutanklagades": "mutanklagad",
    "mutanklagads": "mutanklagad",
    "mutanklagat": "mutanklagad",
    "mutanklagats": "mutanklagad",
    "mutans": "muta",
    "mutanten": "mutant",
    "mutantens": "mutant",
    "mutanter": "mutant",
    "mutanterna": "mutant",
    "mutanternas": "mutant",
    "mutanters": "mutant",
    "mutants": "mutant",
    "mutar": "muta",
    "mutas": "muta",
    "mutat": "muta",
    "mutationen": "mutation",
    "mutationens": "mutation",
    "mutationer": "mutation",
    "mutationerna": "mutation",
    "mutationernas": "mutation",
    "mutationers": "mutation",
    "mutations": "mutation",
    "mutats": "muta",
    "mutbrotten": "mutbrott",
    "mutbrottens": "mutbrott",
    "mutbrottet": "mutbrott",
    "mutbrottets": "mutbrott",
    "mutbrotts": "mutbrott",
    "mute": "muta",
    "muterad": "mutera",
    "muterade": "mutera",
    "muterades": "mutera",
    "muterads": "mutera",
    "muterande": "mutera",
    "muteranden": "muterande",
    "muterandena": "muterande",
    "muterandenas": "muterande",
    "muterandens": "muterande",
    "muterandes": "muterande",
    "muterandet": "muterande",
    "muterandets": "muterande",
    "muterar": "mutera",
    "muteras": "mutera",
    "muterat": "mutera",
    "muterats": "mutera",
    "muterbara": "muterbar",
    "muterbarare": "muterbar",
    "muterbarares": "muterbar",
    "muterbaras": "muterbar",
    "muterbarast": "muterbar",
    "muterbaraste": "muterbar",
    "muterbarastes": "muterbar",
    "muterbarasts": "muterbar",
    "muterbare": "muterbar",
    "muterbares": "muterbar",
    "muterbarheten": "muterbarhet",
    "muterbarhetens": "muterbarhet",
    "muterbarhets": "muterbarhet",
    "muterbars": "muterbar",
    "muterbart": "muterbar",
    "muterbarts": "muterbar",
    "muteringar": "mutering",
    "muteringarna": "mutering",
    "muteringarnas": "mutering",
    "muteringars": "mutering",
    "muteringen": "mutering",
    "muteringens": "mutering",
    "muterings": "mutering",
    "mutexperten": "mutexpert",
    "mutexpertens": "mutexpert",
    "mutexperter": "mutexpert",
    "mutexperterna": "mutexpert",
    "mutexperternas": "mutexpert",
    "mutexperters": "mutexpert",
    "mutexperts": "mutexpert",
    "muthärvan": "muthärva",
    "muthärvans": "muthärva",
    "muthärvas": "muthärva",
    "muthärve": "muthärva",
    "muthärvor": "muthärva",
    "muthärvorna": "muthärva",
    "muthärvornas": "muthärva",
    "muthärvors": "muthärva",
    "mutkolvar": "mutkolv",
    "mutkolvarna": "mutkolv",
    "mutkolvarnas": "mutkolv",
    "mutkolvars": "mutkolv",
    "mutkolven": "mutkolv",
    "mutkolvens": "mutkolv",
    "mutkolvs": "mutkolv",
    "mutor": "muta",
    "mutorna": "muta",
    "mutornas": "muta",
    "mutors": "muta",
    "mutpeng": "mutpengar",
    "mutpengarna": "mutpengar",
    "mutpengarnas": "mutpengar",
    "mutpengars": "mutpengar",
    "mutpengs": "mutpengar",
    "muts": "muta",
    "mutsedeln": "mutsedel",
    "mutsedelns": "mutsedel",
    "mutsedels": "mutsedel",
    "mutsedlar": "mutsedel",
    "mutsedlarna": "mutsedel",
    "mutsedlarnas": "mutsedel",
    "mutsedlars": "mutsedel",
    "mutskandalen": "mutskandal",
    "mutskandalens": "mutskandal",
    "mutskandaler": "mutskandal",
    "mutskandalerna": "mutskandal",
    "mutskandalernas": "mutskandal",
    "mutskandalers": "mutskandal",
    "mutskandals": "mutskandal",
    "mutter": "muttra",
    "mutterbrick": "mutterbricka",
    "mutterbrickan": "mutterbricka",
    "mutterbrickans": "mutterbricka",
    "mutterbrickas": "mutterbricka",
    "mutterbricke": "mutterbricka",
    "mutterbrickor": "mutterbricka",
    "mutterbrickorna": "mutterbricka",
    "mutterbrickornas": "mutterbricka",
    "mutterbrickors": "mutterbricka",
    "mutterbricks": "mutterbricka",
    "mutterdragar": "mutterdragare",
    "mutterdragaren": "mutterdragare",
    "mutterdragarens": "mutterdragare",
    "mutterdragares": "mutterdragare",
    "mutterdragarna": "mutterdragare",
    "mutterdragarnas": "mutterdragare",
    "mutterknacken": "mutterknack",
    "mutterknackens": "mutterknack",
    "mutterknacket": "mutterknack",
    "mutterknackets": "mutterknack",
    "mutterknacks": "mutterknack",
    "muttern": "mutter",
    "mutterns": "mutter",
    "mutters": "mutter",
    "muttrade": "muttra",
    "muttrades": "muttra",
    "muttrande": "muttra",
    "muttranden": "muttrande",
    "muttrandena": "muttrande",
    "muttrandenas": "muttrande",
    "muttrandens": "muttrande",
    "muttrandes": "muttrande",
    "muttrandet": "muttrande",
    "muttrandets": "muttrande",
    "muttrar": "muttra",
    "muttrarna": "mutter",
    "muttrarnas": "mutter",
    "muttrars": "mutter",
    "muttras": "muttra",
    "muttrat": "muttra",
    "muttrats": "muttra",
    "muzaken": "muzak",
    "muzakens": "muzak",
    "muzaks": "muzak",
    "mycelie": "mycelium",
    "mycelier": "mycelium",
    "mycelierna": "mycelium",
    "myceliernas": "mycelium",
    "myceliers": "mycelium",
    "myceliet": "mycelium",
    "myceliets": "mycelium",
    "myceliums": "mycelium",
    "myckens": "mycken",
    "mycket": "mycken",
    "myckets": "mycken",
    "myckna": "mycken",
    "mycknas": "mycken",
    "myckne": "mycken",
    "mycknes": "mycken",
    "myen": "my",
    "myens": "my",
    "myet": "my",
    "myets": "my",
    "mygel": "mygla",
    "mygels": "mygel",
    "mygg": "mygga",
    "myggan": "mygga",
    "myggans": "mygga",
    "myggas": "mygga",
    "myggbetten": "myggbett",
    "myggbettens": "myggbett",
    "myggbettet": "myggbett",
    "myggbettets": "myggbett",
    "myggbetts": "myggbett",
    "mygge": "mygga",
    "myggen": "mygg",
    "myggens": "mygg",
    "mygget": "mygg",
    "myggets": "mygg",
    "myggfönsterna": "myggfönster",
    "myggfönsternas": "myggfönster",
    "myggfönsters": "myggfönster",
    "myggfönstren": "myggfönster",
    "myggfönstrens": "myggfönster",
    "myggfönstret": "myggfönster",
    "myggfönstrets": "myggfönster",
    "mygglarven": "mygglarv",
    "mygglarvens": "mygglarv",
    "mygglarver": "mygglarv",
    "mygglarverna": "mygglarv",
    "mygglarvernas": "mygglarv",
    "mygglarvers": "mygglarv",
    "mygglarvs": "mygglarv",
    "myggmedels": "myggmedel",
    "myggmedlen": "myggmedel",
    "myggmedlens": "myggmedel",
    "myggmedlet": "myggmedel",
    "myggmedlets": "myggmedel",
    "myggnäten": "myggnät",
    "myggnätens": "myggnät",
    "myggnätet": "myggnät",
    "myggnätets": "myggnät",
    "myggnäts": "myggnät",
    "myggnätsdörrar": "myggnätsdörr",
    "myggnätsdörrarna": "myggnätsdörr",
    "myggnätsdörrarnas": "myggnätsdörr",
    "myggnätsdörrars": "myggnätsdörr",
    "myggnätsdörren": "myggnätsdörr",
    "myggnätsdörrens": "myggnätsdörr",
    "myggnätsdörrs": "myggnätsdörr",
    "myggor": "mygga",
    "myggorna": "mygga",
    "myggornas": "mygga",
    "myggors": "mygga",
    "myggs": "mygga",
    "myglade": "mygla",
    "myglades": "mygla",
    "myglande": "mygla",
    "myglanden": "myglande",
    "myglandena": "myglande",
    "myglandenas": "myglande",
    "myglandens": "myglande",
    "myglandes": "myglande",
    "myglandet": "myglande",
    "myglandets": "myglande",
    "myglar": "myglare",
    "myglaren": "myglare",
    "myglarens": "myglare",
    "myglares": "myglare",
    "myglarna": "myglare",
    "myglarnas": "myglare",
    "myglas": "mygla",
    "myglat": "mygla",
    "myglats": "mygla",
    "myglet": "mygel",
    "myglets": "mygel",
    "mykologen": "mykolog",
    "mykologens": "mykolog",
    "mykologer": "mykolog",
    "mykologerna": "mykolog",
    "mykologernas": "mykolog",
    "mykologers": "mykolog",
    "mykologien": "mykologi",
    "mykologiens": "mykologi",
    "mykologin": "mykologi",
    "mykologins": "mykologi",
    "mykologis": "mykologi",
    "mykologiska": "mykologisk",
    "mykologiskare": "mykologisk",
    "mykologiskares": "mykologisk",
    "mykologiskas": "mykologisk",
    "mykologiskast": "mykologisk",
    "mykologiskaste": "mykologisk",
    "mykologiskastes": "mykologisk",
    "mykologiskasts": "mykologisk",
    "mykologiske": "mykologisk",
    "mykologiskes": "mykologisk",
    "mykologisks": "mykologisk",
    "mykologiskt": "mykologisk",
    "mykologiskts": "mykologisk",
    "mykologs": "mykolog",
    "mylingar": "myling",
    "mylingarna": "myling",
    "mylingarnas": "myling",
    "mylingars": "myling",
    "mylingen": "myling",
    "mylingens": "myling",
    "mylings": "myling",
    "myll": "mylla",
    "myllad": "mylla",
    "myllade": "mylla",
    "myllades": "mylla",
    "myllads": "mylla",
    "myllan": "mylla",
    "myllande": "mylla",
    "myllanden": "myllande",
    "myllandena": "myllande",
    "myllandenas": "myllande",
    "myllandens": "myllande",
    "myllandes": "myllande",
    "myllandet": "myllande",
    "myllandets": "myllande",
    "myllans": "mylla",
    "myllar": "mylla",
    "myllas": "mylla",
    "myllat": "mylla",
    "myllats": "mylla",
    "mylle": "mylla",
    "myller": "myllra",
    "myllers": "myller",
    "mylliga": "myllig",
    "mylligare": "myllig",
    "mylligares": "myllig",
    "mylligas": "myllig",
    "mylligast": "myllig",
    "mylligaste": "myllig",
    "mylligastes": "myllig",
    "mylligasts": "myllig",
    "myllige": "myllig",
    "mylliges": "myllig",
    "mylligheten": "myllighet",
    "myllighetens": "myllighet",
    "myllighets": "myllighet",
    "mylligs": "myllig",
    "mylligt": "myllig",
    "mylligts": "myllig",
    "myllor": "mylla",
    "myllorna": "mylla",
    "myllornas": "mylla",
    "myllors": "mylla",
    "myllrade": "myllra",
    "myllrades": "myllra",
    "myllrande": "myllra",
    "myllranden": "myllrande",
    "myllrandena": "myllrande",
    "myllrandenas": "myllrande",
    "myllrandens": "myllrande",
    "myllrandes": "myllrande",
    "myllrandet": "myllrande",
    "myllrandets": "myllrande",
    "myllrar": "myllra",
    "myllras": "myllra",
    "myllrat": "myllra",
    "myllrats": "myllra",
    "myllret": "myller",
    "myllrets": "myller",
    "mylls": "mylla",
    "myltan": "mylta",
    "myltans": "mylta",
    "myltas": "mylta",
    "myn": "my",
    "myna": "my",
    "mynas": "my",
    "myndiga": "myndig",
    "myndigare": "myndig",
    "myndigares": "myndig",
    "myndigas": "myndig",
    "myndigast": "myndig",
    "myndigaste": "myndig",
    "myndigastes": "myndig",
    "myndigasts": "myndig",
    "myndige": "myndig",
    "myndiges": "myndig",
    "myndigheten": "myndighet",
    "myndighetens": "myndighet",
    "myndigheter": "myndighet",
    "myndigheterna": "myndighet",
    "myndigheternas": "myndighet",
    "myndigheters": "myndighet",
    "myndighets": "myndighet",
    "myndighetschefen": "myndighetschef",
    "myndighetschefens": "myndighetschef",
    "myndighetschefer": "myndighetschef",
    "myndighetscheferna": "myndighetschef",
    "myndighetschefernas": "myndighetschef",
    "myndighetschefers": "myndighetschef",
    "myndighetschefs": "myndighetschef",
    "myndighetsförklaringar": "myndighetsförklaring",
    "myndighetsförklaringarna": "myndighetsförklaring",
    "myndighetsförklaringarnas": "myndighetsförklaring",
    "myndighetsförklaringars": "myndighetsförklaring",
    "myndighetsförklaringen": "myndighetsförklaring",
    "myndighetsförklaringens": "myndighetsförklaring",
    "myndighetsförklarings": "myndighetsförklaring",
    "myndighetspersonen": "myndighetsperson",
    "myndighetspersonens": "myndighetsperson",
    "myndighetspersoner": "myndighetsperson",
    "myndighetspersonerna": "myndighetsperson",
    "myndighetspersonernas": "myndighetsperson",
    "myndighetspersoners": "myndighetsperson",
    "myndighetspersons": "myndighetsperson",
    "myndighetssnacket": "myndighetssnack",
    "myndighetssnackets": "myndighetssnack",
    "myndighetssnacks": "myndighetssnack",
    "myndighetsutövar": "myndighetsutövare",
    "myndighetsutövaren": "myndighetsutövare",
    "myndighetsutövarens": "myndighetsutövare",
    "myndighetsutövares": "myndighetsutövare",
    "myndighetsutövarna": "myndighetsutövare",
    "myndighetsutövarnas": "myndighetsutövare",
    "myndighetsutövningen": "myndighetsutövning",
    "myndighetsutövningens": "myndighetsutövning",
    "myndighetsutövnings": "myndighetsutövning",
    "myndighetsåldern": "myndighetsålder",
    "myndighetsålderns": "myndighetsålder",
    "myndighetsålders": "myndighetsålder",
    "myndighetsåldrar": "myndighetsålder",
    "myndighetsåldrarna": "myndighetsålder",
    "myndighetsåldrarnas": "myndighetsålder",
    "myndighetsåldrars": "myndighetsålder",
    "myndigs": "myndig",
    "myndigt": "myndig",
    "myndigts": "myndig",
    "myndlingar": "myndling",
    "myndlingarna": "myndling",
    "myndlingarnas": "myndling",
    "myndlingars": "myndling",
    "myndlingen": "myndling",
    "myndlingens": "myndling",
    "myndlings": "myndling",
    "mynnade": "mynna",
    "mynnades": "mynna",
    "mynnande": "mynna",
    "mynnanden": "mynnande",
    "mynnandena": "mynnande",
    "mynnandenas": "mynnande",
    "mynnandens": "mynnande",
    "mynnandes": "mynnande",
    "mynnandet": "mynnande",
    "mynnandets": "mynnande",
    "mynnar": "mynna",
    "mynnas": "mynna",
    "mynnat": "mynna",
    "mynnats": "mynna",
    "mynningar": "mynning",
    "mynningarna": "mynning",
    "mynningarnas": "mynning",
    "mynningars": "mynning",
    "mynningen": "mynning",
    "mynningens": "mynning",
    "mynnings": "mynning",
    "mynningsarmar": "mynningsarm",
    "mynningsarmarna": "mynningsarm",
    "mynningsarmarnas": "mynningsarm",
    "mynningsarmars": "mynningsarm",
    "mynningsarmen": "mynningsarm",
    "mynningsarmens": "mynningsarm",
    "mynningsarms": "mynningsarm",
    "mynningsbromsar": "mynningsbroms",
    "mynningsbromsarna": "mynningsbroms",
    "mynningsbromsarnas": "mynningsbroms",
    "mynningsbromsars": "mynningsbroms",
    "mynningsbromsen": "mynningsbroms",
    "mynningsbromsens": "mynningsbroms",
    "mynningsladdar": "mynningsladdare",
    "mynningsladdaren": "mynningsladdare",
    "mynningsladdarens": "mynningsladdare",
    "mynningsladdares": "mynningsladdare",
    "mynningsladdarna": "mynningsladdare",
    "mynningsladdarnas": "mynningsladdare",
    "myns": "my",
    "mynt": "mynta",
    "myntad": "mynta",
    "myntade": "mynta",
    "myntades": "mynta",
    "myntads": "mynta",
    "myntan": "mynta",
    "myntande": "mynta",
    "myntanden": "myntande",
    "myntandena": "myntande",
    "myntandenas": "myntande",
    "myntandens": "myntande",
    "myntandes": "myntande",
    "myntandet": "myntande",
    "myntandets": "myntande",
    "myntans": "mynta",
    "myntar": "mynta",
    "myntas": "mynta",
    "myntat": "mynta",
    "myntats": "mynta",
    "myntautomaten": "myntautomat",
    "myntautomatens": "myntautomat",
    "myntautomater": "myntautomat",
    "myntautomaterna": "myntautomat",
    "myntautomaternas": "myntautomat",
    "myntautomaters": "myntautomat",
    "myntautomats": "myntautomat",
    "myntcirkulationen": "myntcirkulation",
    "myntcirkulationens": "myntcirkulation",
    "myntcirkulationer": "myntcirkulation",
    "myntcirkulationerna": "myntcirkulation",
    "myntcirkulationernas": "myntcirkulation",
    "myntcirkulationers": "myntcirkulation",
    "myntcirkulations": "myntcirkulation",
    "mynte": "mynta",
    "mynten": "mynt",
    "myntenheten": "myntenhet",
    "myntenhetens": "myntenhet",
    "myntenheter": "myntenhet",
    "myntenheterna": "myntenhet",
    "myntenheternas": "myntenhet",
    "myntenheters": "myntenhet",
    "myntenhets": "myntenhet",
    "myntens": "mynt",
    "myntet": "mynt",
    "myntets": "mynt",
    "myntfoten": "myntfot",
    "myntfotens": "myntfot",
    "myntfots": "myntfot",
    "myntmetallen": "myntmetall",
    "myntmetallens": "myntmetall",
    "myntmetaller": "myntmetall",
    "myntmetallerna": "myntmetall",
    "myntmetallernas": "myntmetall",
    "myntmetallers": "myntmetall",
    "myntmetalls": "myntmetall",
    "myntor": "mynta",
    "myntorna": "mynta",
    "myntornas": "mynta",
    "myntors": "mynta",
    "myntrealisationen": "myntrealisation",
    "myntrealisationens": "myntrealisation",
    "myntrealisationer": "myntrealisation",
    "myntrealisationerna": "myntrealisation",
    "myntrealisationernas": "myntrealisation",
    "myntrealisationers": "myntrealisation",
    "myntrealisations": "myntrealisation",
    "mynts": "mynta",
    "myntsamlingar": "myntsamling",
    "myntsamlingarna": "myntsamling",
    "myntsamlingarnas": "myntsamling",
    "myntsamlingars": "myntsamling",
    "myntsamlingen": "myntsamling",
    "myntsamlingens": "myntsamling",
    "myntsamlings": "myntsamling",
    "myntsystemen": "myntsystem",
    "myntsystemens": "myntsystem",
    "myntsystemet": "myntsystem",
    "myntsystemets": "myntsystem",
    "myntsystems": "myntsystem",
    "myntteckens": "mynttecken",
    "mynttecknen": "mynttecken",
    "mynttecknens": "mynttecken",
    "mynttecknet": "mynttecken",
    "mynttecknets": "mynttecken",
    "myntunionen": "myntunion",
    "myntunionens": "myntunion",
    "myntunioner": "myntunion",
    "myntunionerna": "myntunion",
    "myntunionernas": "myntunion",
    "myntunioners": "myntunion",
    "myntunions": "myntunion",
    "myntvalören": "myntvalör",
    "myntvalörens": "myntvalör",
    "myntvalörer": "myntvalör",
    "myntvalörerna": "myntvalör",
    "myntvalörernas": "myntvalör",
    "myntvalörers": "myntvalör",
    "myntvalörs": "myntvalör",
    "myntverken": "myntverk",
    "myntverkens": "myntverk",
    "myntverket": "myntverk",
    "myntverkets": "myntverk",
    "myntverks": "myntverk",
    "myntvikten": "myntvikt",
    "myntviktens": "myntvikt",
    "myntvikter": "myntvikt",
    "myntvikterna": "myntvikt",
    "myntvikternas": "myntvikt",
    "myntvikters": "myntvikt",
    "myntvikts": "myntvikt",
    "myntväsendet": "myntväsen",
    "myntväsendets": "myntväsen",
    "myntväsenet": "myntväsen",
    "myntväsenets": "myntväsen",
    "myntväsens": "myntväsen",
    "myogenet": "myogen",
    "myogenets": "myogen",
    "myogens": "myogen",
    "myomen": "myom",
    "myomens": "myom",
    "myomet": "myom",
    "myomets": "myom",
    "myoms": "myom",
    "myonen": "myon",
    "myonens": "myon",
    "myoner": "myon",
    "myonerna": "myon",
    "myonernas": "myon",
    "myoners": "myon",
    "myons": "myon",
    "myopien": "myopi",
    "myopiens": "myopi",
    "myopin": "myopi",
    "myopins": "myopi",
    "myopis": "myopi",
    "myopiska": "myopisk",
    "myopiskare": "myopisk",
    "myopiskares": "myopisk",
    "myopiskas": "myopisk",
    "myopiskast": "myopisk",
    "myopiskaste": "myopisk",
    "myopiskastes": "myopisk",
    "myopiskasts": "myopisk",
    "myopiske": "myopisk",
    "myopiskes": "myopisk",
    "myopisks": "myopisk",
    "myopiskt": "myopisk",
    "myopiskts": "myopisk",
    "myosinen": "myosin",
    "myosinens": "myosin",
    "myosiner": "myosin",
    "myosinerna": "myosin",
    "myosinernas": "myosin",
    "myosiners": "myosin",
    "myosinet": "myosin",
    "myosinets": "myosin",
    "myosins": "myosin",
    "myr": "myra",
    "myran": "myra",
    "myrans": "myra",
    "myrar": "myr",
    "myrarna": "myr",
    "myrarnas": "myr",
    "myrars": "myr",
    "myras": "myra",
    "myrbagg": "myrbagge",
    "myrbaggar": "myrbagge",
    "myrbaggarna": "myrbagge",
    "myrbaggarnas": "myrbagge",
    "myrbaggars": "myrbagge",
    "myrbaggen": "myrbagge",
    "myrbaggens": "myrbagge",
    "myrbagges": "myrbagge",
    "myrbaggs": "myrbagge",
    "myrdrottningar": "myrdrottning",
    "myrdrottningarna": "myrdrottning",
    "myrdrottningarnas": "myrdrottning",
    "myrdrottningars": "myrdrottning",
    "myrdrottningen": "myrdrottning",
    "myrdrottningens": "myrdrottning",
    "myrdrottnings": "myrdrottning",
    "myre": "myra",
    "myren": "myr",
    "myrens": "myr",
    "myrforskar": "myrforskare",
    "myrforskaren": "myrforskare",
    "myrforskarens": "myrforskare",
    "myrforskares": "myrforskare",
    "myrforskarna": "myrforskare",
    "myrforskarnas": "myrforskare",
    "myrgästen": "myrgäst",
    "myrgästens": "myrgäst",
    "myrgäster": "myrgäst",
    "myrgästerna": "myrgäst",
    "myrgästernas": "myrgäst",
    "myrgästers": "myrgäst",
    "myrgästs": "myrgäst",
    "myrholm": "myrholme",
    "myrholmar": "myrholme",
    "myrholmarna": "myrholme",
    "myrholmarnas": "myrholme",
    "myrholmars": "myrholme",
    "myrholmen": "myrholme",
    "myrholmens": "myrholme",
    "myrholmes": "myrholme",
    "myrholms": "myrholme",
    "myriaden": "myriad",
    "myriadens": "myriad",
    "myriader": "myriad",
    "myriaderna": "myriad",
    "myriadernas": "myriad",
    "myriaders": "myriad",
    "myriads": "myriad",
    "myrkanten": "myrkant",
    "myrkantens": "myrkant",
    "myrkanter": "myrkant",
    "myrkanterna": "myrkant",
    "myrkanternas": "myrkant",
    "myrkanters": "myrkant",
    "myrkants": "myrkant",
    "myrkottar": "myrkott",
    "myrkottarna": "myrkott",
    "myrkottarnas": "myrkott",
    "myrkottars": "myrkott",
    "myrkotten": "myrkott",
    "myrkottens": "myrkott",
    "myrkotts": "myrkott",
    "myrkrypningar": "myrkrypning",
    "myrkrypningarna": "myrkrypning",
    "myrkrypningarnas": "myrkrypning",
    "myrkrypningars": "myrkrypning",
    "myrkrypningen": "myrkrypning",
    "myrkrypningens": "myrkrypning",
    "myrkrypnings": "myrkrypning",
    "myrlanden": "myrland",
    "myrlandens": "myrland",
    "myrlandet": "myrland",
    "myrlandets": "myrland",
    "myrlands": "myrland",
    "myrlejonen": "myrlejon",
    "myrlejonens": "myrlejon",
    "myrlejonet": "myrlejon",
    "myrlejonets": "myrlejon",
    "myrlejons": "myrlejon",
    "myrlejonsländ": "myrlejonslända",
    "myrlejonsländan": "myrlejonslända",
    "myrlejonsländans": "myrlejonslända",
    "myrlejonsländas": "myrlejonslända",
    "myrlejonslände": "myrlejonslända",
    "myrlejonsländor": "myrlejonslända",
    "myrlejonsländorna": "myrlejonslända",
    "myrlejonsländornas": "myrlejonslända",
    "myrlejonsländors": "myrlejonslända",
    "myrlejonsländs": "myrlejonslända",
    "myrliljan": "myrlilja",
    "myrliljans": "myrlilja",
    "myrliljas": "myrlilja",
    "myrlilje": "myrlilja",
    "myrliljor": "myrlilja",
    "myrliljorna": "myrlilja",
    "myrliljornas": "myrlilja",
    "myrliljors": "myrlilja",
    "myrmalmen": "myrmalm",
    "myrmalmens": "myrmalm",
    "myrmalmer": "myrmalm",
    "myrmalmerna": "myrmalm",
    "myrmalmernas": "myrmalm",
    "myrmalmers": "myrmalm",
    "myrmalms": "myrmalm",
    "myrmarken": "myrmark",
    "myrmarkens": "myrmark",
    "myrmarker": "myrmark",
    "myrmarkerna": "myrmark",
    "myrmarkernas": "myrmark",
    "myrmarkers": "myrmark",
    "myrmarks": "myrmark",
    "myror": "myra",
    "myrorna": "myra",
    "myrornas": "myra",
    "myrors": "myra",
    "myrran": "myrra",
    "myrrans": "myrra",
    "myrras": "myrra",
    "myrs": "myra",
    "myrsamhällen": "myrsamhälle",
    "myrsamhällena": "myrsamhälle",
    "myrsamhällenas": "myrsamhälle",
    "myrsamhällens": "myrsamhälle",
    "myrsamhälles": "myrsamhälle",
    "myrsamhället": "myrsamhälle",
    "myrsamhällets": "myrsamhälle",
    "myrsamhälls": "myrsamhälle",
    "myrslokar": "myrslok",
    "myrslokarna": "myrslok",
    "myrslokarnas": "myrslok",
    "myrslokars": "myrslok",
    "myrsloken": "myrslok",
    "myrslokens": "myrslok",
    "myrsloks": "myrslok",
    "myrstackar": "myrstack",
    "myrstackarna": "myrstack",
    "myrstackarnas": "myrstack",
    "myrstackars": "myrstack",
    "myrstacken": "myrstack",
    "myrstackens": "myrstack",
    "myrstacks": "myrstack",
    "myrstegen": "myrsteg",
    "myrstegens": "myrsteg",
    "myrsteget": "myrsteg",
    "myrstegets": "myrsteg",
    "myrstegs": "myrsteg",
    "myrstigar": "myrstig",
    "myrstigarna": "myrstig",
    "myrstigarnas": "myrstig",
    "myrstigars": "myrstig",
    "myrstigen": "myrstig",
    "myrstigens": "myrstig",
    "myrstigs": "myrstig",
    "myrsyran": "myrsyra",
    "myrsyrans": "myrsyra",
    "myrsyras": "myrsyra",
    "myrsyre": "myrsyra",
    "myrsyror": "myrsyra",
    "myrsyrorna": "myrsyra",
    "myrsyrornas": "myrsyra",
    "myrsyrors": "myrsyra",
    "myrtenkron": "myrtenkrona",
    "myrtenkronan": "myrtenkrona",
    "myrtenkronans": "myrtenkrona",
    "myrtenkronas": "myrtenkrona",
    "myrtenkrone": "myrtenkrona",
    "myrtenkronor": "myrtenkrona",
    "myrtenkronorna": "myrtenkrona",
    "myrtenkronornas": "myrtenkrona",
    "myrtenkronors": "myrtenkrona",
    "myrtenkrons": "myrtenkrona",
    "myrtenn": "myrten",
    "myrtenns": "myrten",
    "myrtens": "myrten",
    "myrtnar": "myrten",
    "myrtnarna": "myrten",
    "myrtnarnas": "myrten",
    "myrtnars": "myrten",
    "myrväxten": "myrväxt",
    "myrväxtens": "myrväxt",
    "myrväxter": "myrväxt",
    "myrväxterna": "myrväxt",
    "myrväxternas": "myrväxt",
    "myrväxters": "myrväxt",
    "myrväxts": "myrväxt",
    "myräggen": "myrägg",
    "myräggens": "myrägg",
    "myrägget": "myrägg",
    "myräggets": "myrägg",
    "myräggs": "myrägg",
    "mys": "mysa",
    "mysande": "mysa",
    "mysanden": "mysande",
    "mysandena": "mysande",
    "mysandenas": "mysande",
    "mysandens": "mysande",
    "mysandes": "mysande",
    "mysandet": "mysande",
    "mysandets": "mysande",
    "mysas": "mysa",
    "mysdressar": "mysdress",
    "mysdressarna": "mysdress",
    "mysdressarnas": "mysdress",
    "mysdressars": "mysdress",
    "mysdressen": "mysdress",
    "mysdressens": "mysdress",
    "mysdresser": "mysdress",
    "mysdresserna": "mysdress",
    "mysdressernas": "mysdress",
    "mysdressers": "mysdress",
    "mysen": "mys",
    "mysens": "mys",
    "myser": "mysa",
    "myses": "mysa",
    "myset": "mys",
    "mysets": "mys",
    "mysiga": "mysig",
    "mysigare": "mysig",
    "mysigares": "mysig",
    "mysigas": "mysig",
    "mysigast": "mysig",
    "mysigaste": "mysig",
    "mysigastes": "mysig",
    "mysigasts": "mysig",
    "mysige": "mysig",
    "mysiges": "mysig",
    "mysigs": "mysig",
    "mysigt": "mysig",
    "mysigts": "mysig",
    "myskdjuren": "myskdjur",
    "myskdjurens": "myskdjur",
    "myskdjuret": "myskdjur",
    "myskdjurets": "myskdjur",
    "myskdjurs": "myskdjur",
    "mysken": "mysk",
    "myskens": "mysk",
    "myskhjortar": "myskhjort",
    "myskhjortarna": "myskhjort",
    "myskhjortarnas": "myskhjort",
    "myskhjortars": "myskhjort",
    "myskhjorten": "myskhjort",
    "myskhjortens": "myskhjort",
    "myskhjorts": "myskhjort",
    "myskmadran": "myskmadra",
    "myskmadrans": "myskmadra",
    "myskmadras": "myskmadra",
    "myskmadre": "myskmadra",
    "myskmadror": "myskmadra",
    "myskmadrorna": "myskmadra",
    "myskmadrornas": "myskmadra",
    "myskmadrors": "myskmadra",
    "myskoljan": "myskolja",
    "myskoljans": "myskolja",
    "myskoljas": "myskolja",
    "myskolje": "myskolja",
    "myskoljor": "myskolja",
    "myskoljorna": "myskolja",
    "myskoljornas": "myskolja",
    "myskoljors": "myskolja",
    "myskox": "myskoxe",
    "myskoxar": "myskoxe",
    "myskoxarna": "myskoxe",
    "myskoxarnas": "myskoxe",
    "myskoxars": "myskoxe",
    "myskoxen": "myskoxe",
    "myskoxens": "myskoxe",
    "myskoxes": "myskoxe",
    "mysks": "mysk",
    "myst": "mysa",
    "myste": "mysa",
    "mysterie": "mysterium",
    "mysterier": "mysterium",
    "mysteriereligionen": "mysteriereligion",
    "mysteriereligionens": "mysteriereligion",
    "mysteriereligioner": "mysteriereligion",
    "mysteriereligionerna": "mysteriereligion",
    "mysteriereligionernas": "mysteriereligion",
    "mysteriereligioners": "mysteriereligion",
    "mysteriereligions": "mysteriereligion",
    "mysterierna": "mysterium",
    "mysteriernas": "mysterium",
    "mysteriers": "mysterium",
    "mysteriespelen": "mysteriespel",
    "mysteriespelens": "mysteriespel",
    "mysteriespelet": "mysteriespel",
    "mysteriespelets": "mysteriespel",
    "mysteriespels": "mysteriespel",
    "mysteriet": "mysterium",
    "mysteriets": "mysterium",
    "mysteriums": "mysterium",
    "mysteriösa": "mysteriös",
    "mysteriösare": "mysteriös",
    "mysteriösares": "mysteriös",
    "mysteriösas": "mysteriös",
    "mysteriösast": "mysteriös",
    "mysteriösaste": "mysteriös",
    "mysteriösastes": "mysteriös",
    "mysteriösasts": "mysteriös",
    "mysteriöse": "mysteriös",
    "mysteriöses": "mysteriös",
    "mysteriöst": "mysteriös",
    "mysteriösts": "mysteriös",
    "mystes": "mysa",
    "mysticismen": "mysticism",
    "mysticismens": "mysticism",
    "mysticismer": "mysticism",
    "mysticismerna": "mysticism",
    "mysticismernas": "mysticism",
    "mysticismers": "mysticism",
    "mysticisms": "mysticism",
    "mysticistiska": "mysticistisk",
    "mysticistiskas": "mysticistisk",
    "mysticistiske": "mysticistisk",
    "mysticistiskes": "mysticistisk",
    "mysticistisks": "mysticistisk",
    "mysticistiskt": "mysticistisk",
    "mysticistiskts": "mysticistisk",
    "mystifierad": "mystifiera",
    "mystifierade": "mystifiera",
    "mystifierades": "mystifiera",
    "mystifierads": "mystifiera",
    "mystifierande": "mystifiera",
    "mystifieranden": "mystifierande",
    "mystifierandena": "mystifierande",
    "mystifierandenas": "mystifierande",
    "mystifierandens": "mystifierande",
    "mystifierandes": "mystifierande",
    "mystifierandet": "mystifierande",
    "mystifierandets": "mystifierande",
    "mystifierar": "mystifiera",
    "mystifieras": "mystifiera",
    "mystifierat": "mystifiera",
    "mystifierats": "mystifiera",
    "mystifierbara": "mystifierbar",
    "mystifierbarare": "mystifierbar",
    "mystifierbarares": "mystifierbar",
    "mystifierbaras": "mystifierbar",
    "mystifierbarast": "mystifierbar",
    "mystifierbaraste": "mystifierbar",
    "mystifierbarastes": "mystifierbar",
    "mystifierbarasts": "mystifierbar",
    "mystifierbare": "mystifierbar",
    "mystifierbares": "mystifierbar",
    "mystifierbarheten": "mystifierbarhet",
    "mystifierbarhetens": "mystifierbarhet",
    "mystifierbarhets": "mystifierbarhet",
    "mystifierbars": "mystifierbar",
    "mystifierbart": "mystifierbar",
    "mystifierbarts": "mystifierbar",
    "mystifieringar": "mystifiering",
    "mystifieringarna": "mystifiering",
    "mystifieringarnas": "mystifiering",
    "mystifieringars": "mystifiering",
    "mystifieringen": "mystifiering",
    "mystifieringens": "mystifiering",
    "mystifierings": "mystifiering",
    "mystifika": "mystifik",
    "mystifikare": "mystifik",
    "mystifikares": "mystifik",
    "mystifikas": "mystifik",
    "mystifikast": "mystifik",
    "mystifikaste": "mystifik",
    "mystifikastes": "mystifik",
    "mystifikasts": "mystifik",
    "mystifikationen": "mystifikation",
    "mystifikationens": "mystifikation",
    "mystifikationer": "mystifikation",
    "mystifikationerna": "mystifikation",
    "mystifikationernas": "mystifikation",
    "mystifikationers": "mystifikation",
    "mystifikations": "mystifikation",
    "mystifike": "mystifik",
    "mystifikes": "mystifik",
    "mystifiks": "mystifik",
    "mystifikt": "mystifik",
    "mystifikts": "mystifik",
    "mystiken": "mystik",
    "mystikens": "mystik",
    "mystikern": "mystiker",
    "mystikerna": "mystiker",
    "mystikernas": "mystiker",
    "mystikerns": "mystiker",
    "mystikers": "mystiker",
    "mystiks": "mystik",
    "mystiska": "mystisk",
    "mystiskare": "mystisk",
    "mystiskares": "mystisk",
    "mystiskas": "mystisk",
    "mystiskast": "mystisk",
    "mystiskaste": "mystisk",
    "mystiskastes": "mystisk",
    "mystiskasts": "mystisk",
    "mystiske": "mystisk",
    "mystiskes": "mystisk",
    "mystisks": "mystisk",
    "mystiskt": "mystisk",
    "mystiskts": "mystisk",
    "mysts": "mysa",
    "myt": "my",
    "mytbildningar": "mytbildning",
    "mytbildningarna": "mytbildning",
    "mytbildningarnas": "mytbildning",
    "mytbildningars": "mytbildning",
    "mytbildningen": "mytbildning",
    "mytbildningens": "mytbildning",
    "mytbildnings": "mytbildning",
    "myten": "myt",
    "mytens": "myt",
    "myter": "myt",
    "myterier": "myteri",
    "myterierna": "myteri",
    "myteriernas": "myteri",
    "myteriers": "myteri",
    "myteriet": "myteri",
    "myteriets": "myteri",
    "myteris": "myteri",
    "myteristen": "myterist",
    "myteristens": "myterist",
    "myterister": "myterist",
    "myteristerna": "myterist",
    "myteristernas": "myterist",
    "myteristers": "myterist",
    "myterists": "myterist",
    "myterit": "myteri",
    "myterits": "myteri",
    "myterna": "myt",
    "myternas": "myt",
    "myters": "myt",
    "mytiska": "mytisk",
    "mytiskare": "mytisk",
    "mytiskares": "mytisk",
    "mytiskas": "mytisk",
    "mytiskast": "mytisk",
    "mytiskaste": "mytisk",
    "mytiskastes": "mytisk",
    "mytiskasts": "mytisk",
    "mytiske": "mytisk",
    "mytiskes": "mytisk",
    "mytisks": "mytisk",
    "mytiskt": "mytisk",
    "mytiskts": "mytisk",
    "mytologien": "mytologi",
    "mytologiens": "mytologi",
    "mytologier": "mytologi",
    "mytologierna": "mytologi",
    "mytologiernas": "mytologi",
    "mytologiers": "mytologi",
    "mytologin": "mytologi",
    "mytologins": "mytologi",
    "mytologis": "mytologi",
    "mytologiska": "mytologisk",
    "mytologiskare": "mytologisk",
    "mytologiskares": "mytologisk",
    "mytologiskas": "mytologisk",
    "mytologiskast": "mytologisk",
    "mytologiskaste": "mytologisk",
    "mytologiskastes": "mytologisk",
    "mytologiskasts": "mytologisk",
    "mytologiske": "mytologisk",
    "mytologiskes": "mytologisk",
    "mytologisks": "mytologisk",
    "mytologiskt": "mytologisk",
    "mytologiskts": "mytologisk",
    "mytomanen": "mytoman",
    "mytomanens": "mytoman",
    "mytomaner": "mytoman",
    "mytomanerna": "mytoman",
    "mytomanernas": "mytoman",
    "mytomaners": "mytoman",
    "mytomanien": "mytomani",
    "mytomaniens": "mytomani",
    "mytomanin": "mytomani",
    "mytomanins": "mytomani",
    "mytomanis": "mytomani",
    "mytomans": "mytoman",
    "mytomspunna": "mytomspunnen",
    "mytomspunnare": "mytomspunnen",
    "mytomspunnares": "mytomspunnen",
    "mytomspunnas": "mytomspunnen",
    "mytomspunnast": "mytomspunnen",
    "mytomspunnaste": "mytomspunnen",
    "mytomspunnastes": "mytomspunnen",
    "mytomspunnasts": "mytomspunnen",
    "mytomspunne": "mytomspunnen",
    "mytomspunnens": "mytomspunnen",
    "mytomspunnes": "mytomspunnen",
    "mytomspunnet": "mytomspunnen",
    "mytomspunnets": "mytomspunnen",
    "myts": "myt",
    "mytspridningar": "mytspridning",
    "mytspridningarna": "mytspridning",
    "mytspridningarnas": "mytspridning",
    "mytspridningars": "mytspridning",
    "mytspridningen": "mytspridning",
    "mytspridningens": "mytspridning",
    "mytspridnings": "mytspridning",
    "myxödemet": "myxödem",
    "myxödemets": "myxödem",
    "myxödems": "myxödem",
    "mähäet": "mähä",
    "mähäets": "mähä",
    "mähän": "mähä",
    "mähäna": "mähä",
    "mähänas": "mähä",
    "mähäns": "mähä",
    "mähäs": "mähä",
    "mähät": "mähä",
    "mähäts": "mähä",
    "mäklad": "mäkla",
    "mäklade": "mäkla",
    "mäklades": "mäkla",
    "mäklads": "mäkla",
    "mäklande": "mäkla",
    "mäklanden": "mäklande",
    "mäklandena": "mäklande",
    "mäklandenas": "mäklande",
    "mäklandens": "mäklande",
    "mäklandes": "mäklande",
    "mäklandet": "mäklande",
    "mäklandets": "mäklande",
    "mäklar": "mäklare",
    "mäklararvoden": "mäklararvode",
    "mäklararvodena": "mäklararvode",
    "mäklararvodenas": "mäklararvode",
    "mäklararvodens": "mäklararvode",
    "mäklararvodes": "mäklararvode",
    "mäklararvodet": "mäklararvode",
    "mäklararvodets": "mäklararvode",
    "mäklaren": "mäklare",
    "mäklarens": "mäklare",
    "mäklares": "mäklare",
    "mäklarinformationen": "mäklarinformation",
    "mäklarinformationens": "mäklarinformation",
    "mäklarinformationer": "mäklarinformation",
    "mäklarinformationerna": "mäklarinformation",
    "mäklarinformationernas": "mäklarinformation",
    "mäklarinformationers": "mäklarinformation",
    "mäklarinformations": "mäklarinformation",
    "mäklarna": "mäklare",
    "mäklarnas": "mäklare",
    "mäklas": "mäkla",
    "mäklat": "mäkla",
    "mäklats": "mäkla",
    "mäktade": "mäkta",
    "mäktades": "mäkta",
    "mäktande": "mäkta",
    "mäktanden": "mäktande",
    "mäktandena": "mäktande",
    "mäktandenas": "mäktande",
    "mäktandens": "mäktande",
    "mäktandes": "mäktande",
    "mäktandet": "mäktande",
    "mäktandets": "mäktande",
    "mäktar": "mäkta",
    "mäktas": "mäkta",
    "mäktat": "mäkta",
    "mäktats": "mäkta",
    "mäktiga": "mäktig",
    "mäktigare": "mäktig",
    "mäktigares": "mäktig",
    "mäktigas": "mäktig",
    "mäktigast": "mäktig",
    "mäktigaste": "mäktig",
    "mäktigastes": "mäktig",
    "mäktigasts": "mäktig",
    "mäktige": "mäktig",
    "mäktiges": "mäktig",
    "mäktigheten": "mäktighet",
    "mäktighetens": "mäktighet",
    "mäktigheter": "mäktighet",
    "mäktigheterna": "mäktighet",
    "mäktigheternas": "mäktighet",
    "mäktigheters": "mäktighet",
    "mäktighets": "mäktighet",
    "mäktigs": "mäktig",
    "mäktigt": "mäktig",
    "mäktigts": "mäktig",
    "mäl": "mäla",
    "mälande": "mäla",
    "mälanden": "mälande",
    "mälandena": "mälande",
    "mälandenas": "mälande",
    "mälandens": "mälande",
    "mälandes": "mälande",
    "mälandet": "mälande",
    "mälandets": "mälande",
    "mälarlandskapen": "mälarlandskap",
    "mälarlandskapens": "mälarlandskap",
    "mälarlandskapet": "mälarlandskap",
    "mälarlandskapets": "mälarlandskap",
    "mälarlandskaps": "mälarlandskap",
    "mälas": "mäla",
    "mäld": "mäla",
    "mälda": "mäla",
    "mäldas": "mäla",
    "mälde": "mäla",
    "mälden": "mäld",
    "mäldens": "mäld",
    "mälder": "mäld",
    "mälderna": "mäld",
    "mäldernas": "mäld",
    "mälders": "mäld",
    "mäldes": "mäla",
    "mälds": "mäld",
    "mäler": "mäla",
    "mäles": "mäla",
    "mällen": "mäll",
    "mällens": "mäll",
    "mälls": "mäll",
    "mäls": "mäla",
    "mält": "mälta",
    "mältad": "mälta",
    "mältade": "mälta",
    "mältades": "mälta",
    "mältads": "mälta",
    "mältan": "mälta",
    "mältande": "mälta",
    "mältanden": "mältande",
    "mältandena": "mältande",
    "mältandenas": "mältande",
    "mältandens": "mältande",
    "mältandes": "mältande",
    "mältandet": "mältande",
    "mältandets": "mältande",
    "mältans": "mälta",
    "mältar": "mälta",
    "mältas": "mälta",
    "mältat": "mälta",
    "mältats": "mälta",
    "mälte": "mälta",
    "mälterier": "mälteri",
    "mälterierna": "mälteri",
    "mälteriernas": "mälteri",
    "mälteriers": "mälteri",
    "mälteriet": "mälteri",
    "mälteriets": "mälteri",
    "mälteris": "mälteri",
    "mälterit": "mälteri",
    "mälterits": "mälteri",
    "mältes": "mäla",
    "mältor": "mälta",
    "mältorna": "mälta",
    "mältornas": "mälta",
    "mältors": "mälta",
    "mälts": "mälta",
    "män": "man",
    "mäng": "mänga",
    "mängande": "mänga",
    "mänganden": "mängande",
    "mängandena": "mängande",
    "mängandenas": "mängande",
    "mängandens": "mängande",
    "mängandes": "mängande",
    "mängandet": "mängande",
    "mängandets": "mängande",
    "mängas": "mänga",
    "mängd": "mänga",
    "mängda": "mänga",
    "mängdas": "mänga",
    "mängddiagrammen": "mängddiagram",
    "mängddiagrammens": "mängddiagram",
    "mängddiagrammet": "mängddiagram",
    "mängddiagrammets": "mängddiagram",
    "mängddiagrams": "mängddiagram",
    "mängde": "mänga",
    "mängden": "mängd",
    "mängdens": "mängd",
    "mängder": "mängd",
    "mängderna": "mängd",
    "mängdernas": "mängd",
    "mängders": "mängd",
    "mängdes": "mänga",
    "mängdläran": "mängdlära",
    "mängdlärans": "mängdlära",
    "mängdläras": "mängdlära",
    "mängds": "mängd",
    "mänger": "mänga",
    "mänges": "mänga",
    "mängs": "mänga",
    "mängt": "mänga",
    "mängts": "mänga",
    "männen": "man",
    "männens": "man",
    "människan": "människa",
    "människans": "människa",
    "människas": "människa",
    "människo": "människa",
    "människoanden": "människoande",
    "människoandens": "människoande",
    "människoandes": "människoande",
    "människoansikten": "människoansikte",
    "människoansiktena": "människoansikte",
    "människoansiktenas": "människoansikte",
    "människoansiktens": "människoansikte",
    "människoansiktes": "människoansikte",
    "människoansiktet": "människoansikte",
    "människoansiktets": "människoansikte",
    "människoansikts": "människoansikte",
    "människoap": "människoapa",
    "människoapan": "människoapa",
    "människoapans": "människoapa",
    "människoapas": "människoapa",
    "människoape": "människoapa",
    "människoapor": "människoapa",
    "människoaporna": "människoapa",
    "människoapornas": "människoapa",
    "människoapors": "människoapa",
    "människoaps": "människoapa",
    "människoblodet": "människoblod",
    "människoblodets": "människoblod",
    "människoblods": "människoblod",
    "människobrösten": "människobröst",
    "människobröstens": "människobröst",
    "människobröstet": "människobröst",
    "människobröstets": "människobröst",
    "människobrösts": "människobröst",
    "människobördan": "människobörda",
    "människobördans": "människobörda",
    "människobördas": "människobörda",
    "människobörde": "människobörda",
    "människobördor": "människobörda",
    "människobördorna": "människobörda",
    "människobördornas": "människobörda",
    "människobördors": "människobörda",
    "människocentrerade": "människocentrerad",
    "människocentrerades": "människocentrerad",
    "människocentrerads": "människocentrerad",
    "människocentrerat": "människocentrerad",
    "människocentrerats": "människocentrerad",
    "människofientliga": "människofientlig",
    "människofientligare": "människofientlig",
    "människofientligares": "människofientlig",
    "människofientligas": "människofientlig",
    "människofientligast": "människofientlig",
    "människofientligaste": "människofientlig",
    "människofientligastes": "människofientlig",
    "människofientligasts": "människofientlig",
    "människofientlige": "människofientlig",
    "människofientliges": "människofientlig",
    "människofientligheten": "människofientlighet",
    "människofientlighetens": "människofientlighet",
    "människofientlighets": "människofientlighet",
    "människofientligs": "människofientlig",
    "människofientligt": "människofientlig",
    "människofientligts": "människofientlig",
    "människofiguren": "människofigur",
    "människofigurens": "människofigur",
    "människofigurer": "människofigur",
    "människofigurerna": "människofigur",
    "människofigurernas": "människofigur",
    "människofigurers": "människofigur",
    "människofigurs": "människofigur",
    "människofosterna": "människofoster",
    "människofosternas": "människofoster",
    "människofosters": "människofoster",
    "människofostren": "människofoster",
    "människofostrens": "människofoster",
    "människofostret": "människofoster",
    "människofostrets": "människofoster",
    "människofödan": "människoföda",
    "människofödans": "människoföda",
    "människofödas": "människoföda",
    "människoföraktet": "människoförakt",
    "människoföraktets": "människoförakt",
    "människoförakts": "människoförakt",
    "människogestaltade": "människogestaltad",
    "människogestaltades": "människogestaltad",
    "människogestaltads": "människogestaltad",
    "människogestaltat": "människogestaltad",
    "människogestaltats": "människogestaltad",
    "människogestalten": "människogestalt",
    "människogestaltens": "människogestalt",
    "människogestalter": "människogestalt",
    "människogestalterna": "människogestalt",
    "människogestalternas": "människogestalt",
    "människogestalters": "människogestalt",
    "människogestalts": "människogestalt",
    "människohajar": "människohaj",
    "människohajarna": "människohaj",
    "människohajarnas": "människohaj",
    "människohajars": "människohaj",
    "människohajen": "människohaj",
    "människohajens": "människohaj",
    "människohajs": "människohaj",
    "människohamnar": "människohamn",
    "människohamnarna": "människohamn",
    "människohamnarnas": "människohamn",
    "människohamnars": "människohamn",
    "människohamnen": "människohamn",
    "människohamnens": "människohamn",
    "människohamns": "människohamn",
    "människohandeln": "människohandel",
    "människohandelns": "människohandel",
    "människohandels": "människohandel",
    "människohanden": "människohand",
    "människohandens": "människohand",
    "människohands": "människohand",
    "människohatar": "människohatare",
    "människohataren": "människohatare",
    "människohatarens": "människohatare",
    "människohatares": "människohatare",
    "människohatarna": "människohatare",
    "människohatarnas": "människohatare",
    "människohjärt": "människohjärta",
    "människohjärtan": "människohjärta",
    "människohjärtana": "människohjärta",
    "människohjärtanas": "människohjärta",
    "människohjärtans": "människohjärta",
    "människohjärtas": "människohjärta",
    "människohjärtat": "människohjärta",
    "människohjärtats": "människohjärta",
    "människohjärts": "människohjärta",
    "människohänder": "människohand",
    "människohänderna": "människohand",
    "människohändernas": "människohand",
    "människohänders": "människohand",
    "människointresses": "människointresse",
    "människointresset": "människointresse",
    "människointressets": "människointresse",
    "människojakten": "människojakt",
    "människojaktens": "människojakt",
    "människojakter": "människojakt",
    "människojakterna": "människojakt",
    "människojakternas": "människojakt",
    "människojakters": "människojakt",
    "människojakts": "människojakt",
    "människokroppar": "människokropp",
    "människokropparna": "människokropp",
    "människokropparnas": "människokropp",
    "människokroppars": "människokropp",
    "människokroppen": "människokropp",
    "människokroppens": "människokropp",
    "människokropps": "människokropp",
    "människokännar": "människokännare",
    "människokännaren": "människokännare",
    "människokännarens": "människokännare",
    "människokännares": "människokännare",
    "människokännarna": "människokännare",
    "människokännarnas": "människokännare",
    "människokännedomar": "människokännedom",
    "människokännedomarna": "människokännedom",
    "människokännedomarnas": "människokännedom",
    "människokännedomars": "människokännedom",
    "människokännedomen": "människokännedom",
    "människokännedomens": "människokännedom",
    "människokännedoms": "människokännedom",
    "människokärlekar": "människokärlek",
    "människokärlekarna": "människokärlek",
    "människokärlekarnas": "människokärlek",
    "människokärlekars": "människokärlek",
    "människokärleken": "människokärlek",
    "människokärlekens": "människokärlek",
    "människokärleks": "människokärlek",
    "människolika": "människolik",
    "människolikare": "människolik",
    "människolikares": "människolik",
    "människolikas": "människolik",
    "människolikast": "människolik",
    "människolikaste": "människolik",
    "människolikastes": "människolik",
    "människolikasts": "människolik",
    "människolike": "människolik",
    "människoliken": "människolik",
    "människolikens": "människolik",
    "människolikes": "människolik",
    "människoliket": "människolik",
    "människolikets": "människolik",
    "människolikheten": "människolikhet",
    "människolikhetens": "människolikhet",
    "människolikhets": "människolikhet",
    "människoliks": "människolik",
    "människolikt": "människolik",
    "människolikts": "människolik",
    "människoliven": "människoliv",
    "människolivens": "människoliv",
    "människolivet": "människoliv",
    "människolivets": "människoliv",
    "människolivs": "människoliv",
    "människomaterialet": "människomaterial",
    "människomaterialets": "människomaterial",
    "människomaterials": "människomaterial",
    "människooffers": "människooffer",
    "människooffren": "människooffer",
    "människooffrens": "människooffer",
    "människooffret": "människooffer",
    "människooffrets": "människooffer",
    "människor": "människa",
    "människorasen": "människoras",
    "människorasens": "människoras",
    "människoraser": "människoras",
    "människoraserna": "människoras",
    "människorasernas": "människoras",
    "människorasers": "människoras",
    "människorna": "människa",
    "människornas": "människa",
    "människoroven": "människorov",
    "människorovens": "människorov",
    "människorovet": "människorov",
    "människorovets": "människorov",
    "människorovs": "människorov",
    "människorovshärvan": "människorovshärva",
    "människorovshärvans": "människorovshärva",
    "människorovshärvas": "människorovshärva",
    "människorovshärve": "människorovshärva",
    "människorovshärvor": "människorovshärva",
    "människorovshärvorna": "människorovshärva",
    "människorovshärvornas": "människorovshärva",
    "människorovshärvors": "människorovshärva",
    "människors": "människa",
    "människorättsaktivisten": "människorättsaktivist",
    "människorättsaktivistens": "människorättsaktivist",
    "människorättsaktivister": "människorättsaktivist",
    "människorättsaktivisterna": "människorättsaktivist",
    "människorättsaktivisternas": "människorättsaktivist",
    "människorättsaktivisters": "människorättsaktivist",
    "människorättsaktivists": "människorättsaktivist",
    "människorättsbrotten": "människorättsbrott",
    "människorättsbrottens": "människorättsbrott",
    "människorättsbrottet": "människorättsbrott",
    "människorättsbrottets": "människorättsbrott",
    "människorättsbrotts": "människorättsbrott",
    "människorättsföreträdar": "människorättsföreträdare",
    "människorättsföreträdaren": "människorättsföreträdare",
    "människorättsföreträdarens": "människorättsföreträdare",
    "människorättsföreträdares": "människorättsföreträdare",
    "människorättsföreträdarna": "människorättsföreträdare",
    "människorättsföreträdarnas": "människorättsföreträdare",
    "människorättsorganisationen": "människorättsorganisation",
    "människorättsorganisationens": "människorättsorganisation",
    "människorättsorganisationer": "människorättsorganisation",
    "människorättsorganisationerna": "människorättsorganisation",
    "människorättsorganisationernas": "människorättsorganisation",
    "människorättsorganisationers": "människorättsorganisation",
    "människorättsorganisations": "människorättsorganisation",
    "människoskildringar": "människoskildring",
    "människoskildringarna": "människoskildring",
    "människoskildringarnas": "människoskildring",
    "människoskildringars": "människoskildring",
    "människoskildringen": "människoskildring",
    "människoskildringens": "människoskildring",
    "människoskildrings": "människoskildring",
    "människosläkten": "människosläkte",
    "människosläktena": "människosläkte",
    "människosläktenas": "människosläkte",
    "människosläktens": "människosläkte",
    "människosläktes": "människosläkte",
    "människosläktet": "människosläkte",
    "människosläktets": "människosläkte",
    "människosläkts": "människosläkte",
    "människosonen": "människoson",
    "människosonens": "människoson",
    "människosons": "människoson",
    "människospermien": "människospermie",
    "människospermiens": "människospermie",
    "människospermier": "människospermie",
    "människospermierna": "människospermie",
    "människospermiernas": "människospermie",
    "människospermiers": "människospermie",
    "människospermies": "människospermie",
    "människosynen": "människosyn",
    "människosynens": "människosyn",
    "människosyns": "människosyn",
    "människotanden": "människotand",
    "människotandens": "människotand",
    "människotands": "människotand",
    "människotänder": "människotand",
    "människotänderna": "människotand",
    "människotändernas": "människotand",
    "människotänders": "människotand",
    "människouppfattningar": "människouppfattning",
    "människouppfattningarna": "människouppfattning",
    "människouppfattningarnas": "människouppfattning",
    "människouppfattningars": "människouppfattning",
    "människouppfattningen": "människouppfattning",
    "människouppfattningens": "människouppfattning",
    "människouppfattnings": "människouppfattning",
    "människovänliga": "människovänlig",
    "människovänligare": "människovänlig",
    "människovänligares": "människovänlig",
    "människovänligas": "människovänlig",
    "människovänligast": "människovänlig",
    "människovänligaste": "människovänlig",
    "människovänligastes": "människovänlig",
    "människovänligasts": "människovänlig",
    "människovänlige": "människovänlig",
    "människovänliges": "människovänlig",
    "människovänligheten": "människovänlighet",
    "människovänlighetens": "människovänlighet",
    "människovänligheter": "människovänlighet",
    "människovänligheterna": "människovänlighet",
    "människovänligheternas": "människovänlighet",
    "människovänligheters": "människovänlighet",
    "människovänlighets": "människovänlighet",
    "människovänligs": "människovänlig",
    "människovänligt": "människovänlig",
    "människovänligts": "människovänlig",
    "människovännen": "människovän",
    "människovännens": "människovän",
    "människovänner": "människovän",
    "människovännerna": "människovän",
    "människovännernas": "människovän",
    "människovänners": "människovän",
    "människoväns": "människovän",
    "människovärden": "människovärde",
    "människovärdena": "människovärde",
    "människovärdenas": "människovärde",
    "människovärdens": "människovärde",
    "människovärdes": "människovärde",
    "människovärdet": "människovärde",
    "människovärdets": "människovärde",
    "människovärdiga": "människovärdig",
    "människovärdigare": "människovärdig",
    "människovärdigares": "människovärdig",
    "människovärdigas": "människovärdig",
    "människovärdigast": "människovärdig",
    "människovärdigaste": "människovärdig",
    "människovärdigastes": "människovärdig",
    "människovärdigasts": "människovärdig",
    "människovärdige": "människovärdig",
    "människovärdiges": "människovärdig",
    "människovärdigheten": "människovärdighet",
    "människovärdighetens": "människovärdighet",
    "människovärdighets": "människovärdighet",
    "människovärdigs": "människovärdig",
    "människovärdigt": "människovärdig",
    "människovärdigts": "människovärdig",
    "människoätar": "människoätare",
    "människoätaren": "människoätare",
    "människoätarens": "människoätare",
    "människoätares": "människoätare",
    "människoätarna": "människoätare",
    "människoätarnas": "människoätare",
    "mäns": "man",
    "mänskan": "mänska",
    "mänskans": "mänska",
    "mänskas": "mänska",
    "mänskliga": "mänsklig",
    "mänskligare": "mänsklig",
    "mänskligares": "mänsklig",
    "mänskligas": "mänsklig",
    "mänskligast": "mänsklig",
    "mänskligaste": "mänsklig",
    "mänskligastes": "mänsklig",
    "mänskligasts": "mänsklig",
    "mänsklige": "mänsklig",
    "mänskliges": "mänsklig",
    "mänskligheten": "mänsklighet",
    "mänsklighetens": "mänsklighet",
    "mänskligheter": "mänsklighet",
    "mänskligheterna": "mänsklighet",
    "mänskligheternas": "mänsklighet",
    "mänskligheters": "mänsklighet",
    "mänsklighets": "mänsklighet",
    "mänskligs": "mänsklig",
    "mänskligt": "mänsklig",
    "mänskligts": "mänsklig",
    "mänsko": "mänska",
    "mänskor": "mänska",
    "mänskorna": "mänska",
    "mänskornas": "mänska",
    "mänskors": "mänska",
    "mären": "mär",
    "märens": "mär",
    "märer": "mär",
    "märerna": "mär",
    "märernas": "mär",
    "märers": "mär",
    "märgbenen": "märgben",
    "märgbenens": "märgben",
    "märgbenet": "märgben",
    "märgbenets": "märgben",
    "märgbens": "märgben",
    "märgel": "märgla",
    "märgelgravar": "märgelgrav",
    "märgelgravarna": "märgelgrav",
    "märgelgravarnas": "märgelgrav",
    "märgelgravars": "märgelgrav",
    "märgelgraven": "märgelgrav",
    "märgelgravens": "märgelgrav",
    "märgelgravs": "märgelgrav",
    "märgeln": "märgel",
    "märgelns": "märgel",
    "märgels": "märgel",
    "märgelskiffern": "märgelskiffer",
    "märgelskifferns": "märgelskiffer",
    "märgelskiffers": "märgelskiffer",
    "märgelskiffrar": "märgelskiffer",
    "märgelskiffrarna": "märgelskiffer",
    "märgelskiffrarnas": "märgelskiffer",
    "märgelskiffrars": "märgelskiffer",
    "märgelstenen": "märgelsten",
    "märgelstenens": "märgelsten",
    "märgelstens": "märgelsten",
    "märgen": "märg",
    "märgens": "märg",
    "märgfläckar": "märgfläck",
    "märgfläckarna": "märgfläck",
    "märgfläckarnas": "märgfläck",
    "märgfläckars": "märgfläck",
    "märgfläcken": "märgfläck",
    "märgfläckens": "märgfläck",
    "märgfläcks": "märgfläck",
    "märgfulla": "märgfull",
    "märgfullare": "märgfull",
    "märgfullares": "märgfull",
    "märgfullas": "märgfull",
    "märgfullast": "märgfull",
    "märgfullaste": "märgfull",
    "märgfullastes": "märgfull",
    "märgfullasts": "märgfull",
    "märgfulle": "märgfull",
    "märgfulles": "märgfull",
    "märgfullheten": "märgfullhet",
    "märgfullhetens": "märgfullhet",
    "märgfullhets": "märgfullhet",
    "märgfulls": "märgfull",
    "märgfullt": "märgfull",
    "märgfullts": "märgfull",
    "märglad": "märgla",
    "märglade": "märgla",
    "märglades": "märgla",
    "märglads": "märgla",
    "märglande": "märgla",
    "märglanden": "märglande",
    "märglandena": "märglande",
    "märglandenas": "märglande",
    "märglandens": "märglande",
    "märglandes": "märglande",
    "märglandet": "märglande",
    "märglandets": "märglande",
    "märglar": "märgla",
    "märglas": "märgla",
    "märglat": "märgla",
    "märglats": "märgla",
    "märglösa": "märglös",
    "märglösare": "märglös",
    "märglösares": "märglös",
    "märglösas": "märglös",
    "märglösast": "märglös",
    "märglösaste": "märglös",
    "märglösastes": "märglös",
    "märglösasts": "märglös",
    "märglöse": "märglös",
    "märglöses": "märglös",
    "märglösheten": "märglöshet",
    "märglöshetens": "märglöshet",
    "märglöshets": "märglöshet",
    "märglöst": "märglös",
    "märglösts": "märglös",
    "märgpip": "märgpipa",
    "märgpipan": "märgpipa",
    "märgpipans": "märgpipa",
    "märgpipas": "märgpipa",
    "märgpipe": "märgpipa",
    "märgpipor": "märgpipa",
    "märgpiporna": "märgpipa",
    "märgpipornas": "märgpipa",
    "märgpipors": "märgpipa",
    "märgpips": "märgpipa",
    "märgs": "märg",
    "märgskid": "märgskida",
    "märgskidan": "märgskida",
    "märgskidans": "märgskida",
    "märgskidas": "märgskida",
    "märgskide": "märgskida",
    "märgskidor": "märgskida",
    "märgskidorna": "märgskida",
    "märgskidornas": "märgskida",
    "märgskidors": "märgskida",
    "märgskids": "märgskida",
    "märgstrål": "märgstråle",
    "märgstrålar": "märgstråle",
    "märgstrålarna": "märgstråle",
    "märgstrålarnas": "märgstråle",
    "märgstrålars": "märgstråle",
    "märgstrålen": "märgstråle",
    "märgstrålens": "märgstråle",
    "märgstråles": "märgstråle",
    "märgstråls": "märgstråle",
    "märk": "märka",
    "märkande": "märka",
    "märkanden": "märkande",
    "märkandena": "märkande",
    "märkandenas": "märkande",
    "märkandens": "märkande",
    "märkandes": "märkande",
    "märkandet": "märkande",
    "märkandets": "märkande",
    "märkas": "märka",
    "märkbanden": "märkband",
    "märkbandens": "märkband",
    "märkbandet": "märkband",
    "märkbandets": "märkband",
    "märkbands": "märkband",
    "märkbara": "märkbar",
    "märkbarare": "märkbar",
    "märkbarares": "märkbar",
    "märkbaras": "märkbar",
    "märkbarast": "märkbar",
    "märkbaraste": "märkbar",
    "märkbarastes": "märkbar",
    "märkbarasts": "märkbar",
    "märkbare": "märkbar",
    "märkbares": "märkbar",
    "märkbarheten": "märkbarhet",
    "märkbarhetens": "märkbarhet",
    "märkbarhets": "märkbarhet",
    "märkbars": "märkbar",
    "märkbart": "märkbar",
    "märkbarts": "märkbar",
    "märkbläcket": "märkbläck",
    "märkbläckets": "märkbläck",
    "märkbläcks": "märkbläck",
    "märkdukar": "märkduk",
    "märkdukarna": "märkduk",
    "märkdukarnas": "märkduk",
    "märkdukars": "märkduk",
    "märkduken": "märkduk",
    "märkdukens": "märkduk",
    "märkduks": "märkduk",
    "märken": "märke",
    "märkena": "märke",
    "märkenas": "märke",
    "märkens": "märke",
    "märker": "märka",
    "märkes": "märke",
    "märkesdagar": "märkesdag",
    "märkesdagarna": "märkesdag",
    "märkesdagarnas": "märkesdag",
    "märkesdagars": "märkesdag",
    "märkesdagen": "märkesdag",
    "märkesdagens": "märkesdag",
    "märkesdags": "märkesdag",
    "märkeskläderna": "märkeskläder",
    "märkesklädernas": "märkeskläder",
    "märkeskläders": "märkeskläder",
    "märkesklädes": "märkeskläder",
    "märkeskläds": "märkeskläder",
    "märkesmannen": "märkesman",
    "märkesmannens": "märkesman",
    "märkesmans": "märkesman",
    "märkesmystiken": "märkesmystik",
    "märkesmystikens": "märkesmystik",
    "märkesmystiks": "märkesmystik",
    "märkesmän": "märkesman",
    "märkesmännen": "märkesman",
    "märkesmännens": "märkesman",
    "märkesmäns": "märkesman",
    "märkesrätten": "märkesrätt",
    "märkesrättens": "märkesrätt",
    "märkesrätts": "märkesrätt",
    "märkesskjort": "märkesskjorta",
    "märkesskjortan": "märkesskjorta",
    "märkesskjortans": "märkesskjorta",
    "märkesskjortas": "märkesskjorta",
    "märkesskjorte": "märkesskjorta",
    "märkesskjortor": "märkesskjorta",
    "märkesskjortorna": "märkesskjorta",
    "märkesskjortornas": "märkesskjorta",
    "märkesskjortors": "märkesskjorta",
    "märkesskjorts": "märkesskjorta",
    "märkesvar": "märkesvara",
    "märkesvaran": "märkesvara",
    "märkesvarans": "märkesvara",
    "märkesvaras": "märkesvara",
    "märkesvare": "märkesvara",
    "märkesvaror": "märkesvara",
    "märkesvarorna": "märkesvara",
    "märkesvarornas": "märkesvara",
    "märkesvarors": "märkesvara",
    "märkesvars": "märkesvara",
    "märket": "märke",
    "märkets": "märke",
    "märkgarnen": "märkgarn",
    "märkgarnens": "märkgarn",
    "märkgarner": "märkgarn",
    "märkgarnerna": "märkgarn",
    "märkgarnernas": "märkgarn",
    "märkgarners": "märkgarn",
    "märkgarnet": "märkgarn",
    "märkgarnets": "märkgarn",
    "märkgarns": "märkgarn",
    "märkhammar": "märkhammare",
    "märkhammaren": "märkhammare",
    "märkhammarens": "märkhammare",
    "märkhammares": "märkhammare",
    "märkhamrar": "märkhammare",
    "märkhamrarna": "märkhammare",
    "märkhamrarnas": "märkhammare",
    "märkhamrars": "märkhammare",
    "märkliga": "märklig",
    "märkligare": "märklig",
    "märkligares": "märklig",
    "märkligas": "märklig",
    "märkligast": "märklig",
    "märkligaste": "märklig",
    "märkligastes": "märklig",
    "märkligasts": "märklig",
    "märklige": "märklig",
    "märkliges": "märklig",
    "märkligheten": "märklighet",
    "märklighetens": "märklighet",
    "märkligheter": "märklighet",
    "märkligheterna": "märklighet",
    "märkligheternas": "märklighet",
    "märkligheters": "märklighet",
    "märklighets": "märklighet",
    "märkligs": "märklig",
    "märkligt": "märklig",
    "märkligts": "märklig",
    "märkningar": "märkning",
    "märkningarna": "märkning",
    "märkningarnas": "märkning",
    "märkningars": "märkning",
    "märkningen": "märkning",
    "märkningens": "märkning",
    "märknings": "märkning",
    "märkpenn": "märkpenna",
    "märkpennan": "märkpenna",
    "märkpennans": "märkpenna",
    "märkpennas": "märkpenna",
    "märkpenne": "märkpenna",
    "märkpennor": "märkpenna",
    "märkpennorna": "märkpenna",
    "märkpennornas": "märkpenna",
    "märkpennors": "märkpenna",
    "märkpenns": "märkpenna",
    "märkrull": "märkrulla",
    "märkrullan": "märkrulla",
    "märkrullans": "märkrulla",
    "märkrullas": "märkrulla",
    "märkrulle": "märkrulla",
    "märkrullor": "märkrulla",
    "märkrullorna": "märkrulla",
    "märkrullornas": "märkrulla",
    "märkrullors": "märkrulla",
    "märkrulls": "märkrulla",
    "märks": "märka",
    "märksnör": "märksnöre",
    "märksnören": "märksnöre",
    "märksnörena": "märksnöre",
    "märksnörenas": "märksnöre",
    "märksnörens": "märksnöre",
    "märksnöres": "märksnöre",
    "märksnöret": "märksnöre",
    "märksnörets": "märksnöre",
    "märksnörs": "märksnöre",
    "märkt": "märka",
    "märkta": "märka",
    "märktas": "märka",
    "märkte": "märka",
    "märktes": "märka",
    "märkts": "märka",
    "märkvärdiga": "märkvärdig",
    "märkvärdigare": "märkvärdig",
    "märkvärdigares": "märkvärdig",
    "märkvärdigas": "märkvärdig",
    "märkvärdigast": "märkvärdig",
    "märkvärdigaste": "märkvärdig",
    "märkvärdigastes": "märkvärdig",
    "märkvärdigasts": "märkvärdig",
    "märkvärdige": "märkvärdig",
    "märkvärdiges": "märkvärdig",
    "märkvärdiggjord": "märkvärdiggöra",
    "märkvärdiggjorda": "märkvärdiggöra",
    "märkvärdiggjordas": "märkvärdiggöra",
    "märkvärdiggjorde": "märkvärdiggöra",
    "märkvärdiggjordes": "märkvärdiggöra",
    "märkvärdiggjords": "märkvärdiggöra",
    "märkvärdiggjort": "märkvärdiggöra",
    "märkvärdiggjorts": "märkvärdiggöra",
    "märkvärdiggör": "märkvärdiggöra",
    "märkvärdiggörande": "märkvärdiggöra",
    "märkvärdiggörandes": "märkvärdiggöra",
    "märkvärdiggöras": "märkvärdiggöra",
    "märkvärdiggöres": "märkvärdiggöra",
    "märkvärdiggörs": "märkvärdiggöra",
    "märkvärdigheten": "märkvärdighet",
    "märkvärdighetens": "märkvärdighet",
    "märkvärdigheter": "märkvärdighet",
    "märkvärdigheterna": "märkvärdighet",
    "märkvärdigheternas": "märkvärdighet",
    "märkvärdigheters": "märkvärdighet",
    "märkvärdighets": "märkvärdighet",
    "märkvärdigs": "märkvärdig",
    "märkvärdigt": "märkvärdig",
    "märkvärdigts": "märkvärdig",
    "märl": "märla",
    "märlan": "märla",
    "märlans": "märla",
    "märlas": "märla",
    "märle": "märla",
    "märlingar": "märling",
    "märlingarna": "märling",
    "märlingarnas": "märling",
    "märlingars": "märling",
    "märlingen": "märling",
    "märlingens": "märling",
    "märlings": "märling",
    "märlor": "märla",
    "märlorna": "märla",
    "märlornas": "märla",
    "märlors": "märla",
    "märls": "märla",
    "märlspikar": "märlspik",
    "märlspikarna": "märlspik",
    "märlspikarnas": "märlspik",
    "märlspikars": "märlspik",
    "märlspiken": "märlspik",
    "märlspikens": "märlspik",
    "märlspiks": "märlspik",
    "märrar": "märr",
    "märrarna": "märr",
    "märrarnas": "märr",
    "märrars": "märr",
    "märren": "märr",
    "märrens": "märr",
    "märrs": "märr",
    "märs": "mär",
    "märsar": "märs",
    "märsarna": "märs",
    "märsarnas": "märs",
    "märsars": "märs",
    "märsen": "märs",
    "märsens": "märs",
    "märsrån": "märsrå",
    "märsråns": "märsrå",
    "märsrår": "märsrå",
    "märsrårna": "märsrå",
    "märsrårnas": "märsrå",
    "märsrårs": "märsrå",
    "märsrås": "märsrå",
    "märssegels": "märssegel",
    "märsseglen": "märssegel",
    "märsseglens": "märssegel",
    "märsseglet": "märssegel",
    "märsseglets": "märssegel",
    "märsstänger": "märsstång",
    "märsstängerna": "märsstång",
    "märsstängernas": "märsstång",
    "märsstängers": "märsstång",
    "märsstången": "märsstång",
    "märsstångens": "märsstång",
    "märsstångs": "märsstång",
    "mäsk": "mäska",
    "mäskad": "mäska",
    "mäskade": "mäska",
    "mäskades": "mäska",
    "mäskads": "mäska",
    "mäskande": "mäska",
    "mäskanden": "mäskande",
    "mäskandena": "mäskande",
    "mäskandenas": "mäskande",
    "mäskandens": "mäskande",
    "mäskandes": "mäskande",
    "mäskandet": "mäskande",
    "mäskandets": "mäskande",
    "mäskar": "mäska",
    "mäskas": "mäska",
    "mäskat": "mäska",
    "mäskats": "mäska",
    "mäsken": "mäsk",
    "mäskens": "mäsk",
    "mäskningar": "mäskning",
    "mäskningarna": "mäskning",
    "mäskningarnas": "mäskning",
    "mäskningars": "mäskning",
    "mäskningen": "mäskning",
    "mäskningens": "mäskning",
    "mäsknings": "mäskning",
    "mäskprovar": "mäskprovare",
    "mäskprovaren": "mäskprovare",
    "mäskprovarens": "mäskprovare",
    "mäskprovares": "mäskprovare",
    "mäskprovarna": "mäskprovare",
    "mäskprovarnas": "mäskprovare",
    "mäsks": "mäsk",
    "mäss": "mässa",
    "mässade": "mässa",
    "mässades": "mässa",
    "mässan": "mässa",
    "mässande": "mässa",
    "mässanden": "mässande",
    "mässandena": "mässande",
    "mässandenas": "mässande",
    "mässandens": "mässande",
    "mässandes": "mässande",
    "mässandet": "mässande",
    "mässandets": "mässande",
    "mässans": "mässa",
    "mässar": "mässa",
    "mässarna": "mäss",
    "mässarnas": "mäss",
    "mässars": "mäss",
    "mässas": "mässa",
    "mässat": "mässa",
    "mässats": "mässa",
    "mässboken": "mässbok",
    "mässbokens": "mässbok",
    "mässboks": "mässbok",
    "mässböcker": "mässbok",
    "mässböckerna": "mässbok",
    "mässböckernas": "mässbok",
    "mässböckers": "mässbok",
    "mässdräkten": "mässdräkt",
    "mässdräktens": "mässdräkt",
    "mässdräkter": "mässdräkt",
    "mässdräkterna": "mässdräkt",
    "mässdräkternas": "mässdräkt",
    "mässdräkters": "mässdräkt",
    "mässdräkts": "mässdräkt",
    "mässe": "mässa",
    "mässen": "mäss",
    "mässens": "mäss",
    "mässfallen": "mässfall",
    "mässfallens": "mässfall",
    "mässfallet": "mässfall",
    "mässfallets": "mässfall",
    "mässfalls": "mässfall",
    "mässhakar": "mässhake",
    "mässhakarna": "mässhake",
    "mässhakarnas": "mässhake",
    "mässhakars": "mässhake",
    "mässhaken": "mässhake",
    "mässhakens": "mässhake",
    "mässhakes": "mässhake",
    "mässhallar": "mässhall",
    "mässhallarna": "mässhall",
    "mässhallarnas": "mässhall",
    "mässhallars": "mässhall",
    "mässhallen": "mässhall",
    "mässhallens": "mässhall",
    "mässhalls": "mässhall",
    "mässiga": "mässig",
    "mässigare": "mässig",
    "mässigares": "mässig",
    "mässigas": "mässig",
    "mässigast": "mässig",
    "mässigaste": "mässig",
    "mässigastes": "mässig",
    "mässigasts": "mässig",
    "mässige": "mässig",
    "mässiges": "mässig",
    "mässigs": "mässig",
    "mässigt": "mässig",
    "mässigts": "mässig",
    "mässingblåsinstrumenten": "mässingblåsinstrument",
    "mässingblåsinstrumentens": "mässingblåsinstrument",
    "mässingblåsinstrumentet": "mässingblåsinstrument",
    "mässingblåsinstrumentets": "mässingblåsinstrument",
    "mässingblåsinstruments": "mässingblåsinstrument",
    "mässingen": "mässing",
    "mässingens": "mässing",
    "mässinginstrumenten": "mässinginstrument",
    "mässinginstrumentens": "mässinginstrument",
    "mässinginstrumentet": "mässinginstrument",
    "mässinginstrumentets": "mässinginstrument",
    "mässinginstruments": "mässinginstrument",
    "mässings": "mässing",
    "mässingsblänket": "mässingsblänk",
    "mässingsblänkets": "mässingsblänk",
    "mässingsblänks": "mässingsblänk",
    "mässingsdetaljen": "mässingsdetalj",
    "mässingsdetaljens": "mässingsdetalj",
    "mässingsdetaljer": "mässingsdetalj",
    "mässingsdetaljerna": "mässingsdetalj",
    "mässingsdetaljernas": "mässingsdetalj",
    "mässingsdetaljers": "mässingsdetalj",
    "mässingsdetaljs": "mässingsdetalj",
    "mässingsinstrumenten": "mässingsinstrument",
    "mässingsinstrumentens": "mässingsinstrument",
    "mässingsinstrumentet": "mässingsinstrument",
    "mässingsinstrumentets": "mässingsinstrument",
    "mässingsinstruments": "mässingsinstrument",
    "mässingsknappar": "mässingsknapp",
    "mässingsknapparna": "mässingsknapp",
    "mässingsknapparnas": "mässingsknapp",
    "mässingsknappars": "mässingsknapp",
    "mässingsknappen": "mässingsknapp",
    "mässingsknappens": "mässingsknapp",
    "mässingsknapps": "mässingsknapp",
    "mässingsmusiken": "mässingsmusik",
    "mässingsmusikens": "mässingsmusik",
    "mässingsmusiks": "mässingsmusik",
    "mässingsspikar": "mässingsspik",
    "mässingsspikarna": "mässingsspik",
    "mässingsspikarnas": "mässingsspik",
    "mässingsspikars": "mässingsspik",
    "mässingsspiken": "mässingsspik",
    "mässingsspikens": "mässingsspik",
    "mässingsspiks": "mässingsspik",
    "mässingsstänger": "mässingsstång",
    "mässingsstängerna": "mässingsstång",
    "mässingsstängernas": "mässingsstång",
    "mässingsstängers": "mässingsstång",
    "mässingsstången": "mässingsstång",
    "mässingsstångens": "mässingsstång",
    "mässingsstångs": "mässingsstång",
    "mässingstrådar": "mässingstråd",
    "mässingstrådarna": "mässingstråd",
    "mässingstrådarnas": "mässingstråd",
    "mässingstrådars": "mässingstråd",
    "mässingstråden": "mässingstråd",
    "mässingstrådens": "mässingstråd",
    "mässingstråds": "mässingstråd",
    "mässingsvattens": "mässingsvatten",
    "mässingsvattnet": "mässingsvatten",
    "mässingsvattnets": "mässingsvatten",
    "mässjack": "mässjacka",
    "mässjackan": "mässjacka",
    "mässjackans": "mässjacka",
    "mässjackas": "mässjacka",
    "mässjacke": "mässjacka",
    "mässjackor": "mässjacka",
    "mässjackorna": "mässjacka",
    "mässjackornas": "mässjacka",
    "mässjackors": "mässjacka",
    "mässjacks": "mässjacka",
    "mässkrudar": "mässkrud",
    "mässkrudarna": "mässkrud",
    "mässkrudarnas": "mässkrud",
    "mässkrudars": "mässkrud",
    "mässkruden": "mässkrud",
    "mässkrudens": "mässkrud",
    "mässkruds": "mässkrud",
    "mässlingen": "mässling",
    "mässlingens": "mässling",
    "mässlings": "mässling",
    "mässo": "mässa",
    "mässoffers": "mässoffer",
    "mässoffren": "mässoffer",
    "mässoffrens": "mässoffer",
    "mässoffret": "mässoffer",
    "mässoffrets": "mässoffer",
    "mässor": "mässa",
    "mässorna": "mässa",
    "mässornas": "mässa",
    "mässors": "mässa",
    "mässpojk": "mässpojke",
    "mässpojkar": "mässpojke",
    "mässpojkarna": "mässpojke",
    "mässpojkarnas": "mässpojke",
    "mässpojkars": "mässpojke",
    "mässpojken": "mässpojke",
    "mässpojkens": "mässpojke",
    "mässpojkes": "mässpojke",
    "mässpojks": "mässpojke",
    "mästar": "mästare",
    "mästarbreven": "mästarbrev",
    "mästarbrevens": "mästarbrev",
    "mästarbrevet": "mästarbrev",
    "mästarbrevets": "mästarbrev",
    "mästarbrevs": "mästarbrev",
    "mästaren": "mästare",
    "mästarens": "mästare",
    "mästares": "mästare",
    "mästarinnan": "mästarinna",
    "mästarinnans": "mästarinna",
    "mästarinnas": "mästarinna",
    "mästarinne": "mästarinna",
    "mästarinnor": "mästarinna",
    "mästarinnorna": "mästarinna",
    "mästarinnornas": "mästarinna",
    "mästarinnors": "mästarinna",
    "mästarklassen": "mästarklass",
    "mästarklassens": "mästarklass",
    "mästarklasser": "mästarklass",
    "mästarklasserna": "mästarklass",
    "mästarklassernas": "mästarklass",
    "mästarklassers": "mästarklass",
    "mästarna": "mästare",
    "mästarnas": "mästare",
    "mästarproven": "mästarprov",
    "mästarprovens": "mästarprov",
    "mästarprovet": "mästarprov",
    "mästarprovets": "mästarprov",
    "mästarprovs": "mästarprov",
    "mästerliga": "mästerlig",
    "mästerligare": "mästerlig",
    "mästerligares": "mästerlig",
    "mästerligas": "mästerlig",
    "mästerligast": "mästerlig",
    "mästerligaste": "mästerlig",
    "mästerligastes": "mästerlig",
    "mästerligasts": "mästerlig",
    "mästerlige": "mästerlig",
    "mästerliges": "mästerlig",
    "mästerligheten": "mästerlighet",
    "mästerlighetens": "mästerlighet",
    "mästerlighets": "mästerlighet",
    "mästerligs": "mästerlig",
    "mästerligt": "mästerlig",
    "mästerligts": "mästerlig",
    "mästerlotsar": "mästerlots",
    "mästerlotsarna": "mästerlots",
    "mästerlotsarnas": "mästerlots",
    "mästerlotsars": "mästerlots",
    "mästerlotsen": "mästerlots",
    "mästerlotsens": "mästerlots",
    "mästermannen": "mästerman",
    "mästermannens": "mästerman",
    "mästermans": "mästerman",
    "mästermän": "mästerman",
    "mästermännen": "mästerman",
    "mästermännens": "mästerman",
    "mästermäns": "mästerman",
    "mästers": "mäster",
    "mästerskapen": "mästerskap",
    "mästerskapens": "mästerskap",
    "mästerskapet": "mästerskap",
    "mästerskapets": "mästerskap",
    "mästerskaps": "mästerskap",
    "mästerskapstiteln": "mästerskapstitel",
    "mästerskapstitelns": "mästerskapstitel",
    "mästerskapstitels": "mästerskapstitel",
    "mästerskapstitlar": "mästerskapstitel",
    "mästerskapstitlarna": "mästerskapstitel",
    "mästerskapstitlarnas": "mästerskapstitel",
    "mästerskapstitlars": "mästerskapstitel",
    "mästerstycken": "mästerstycke",
    "mästerstyckena": "mästerstycke",
    "mästerstyckenas": "mästerstycke",
    "mästerstyckens": "mästerstycke",
    "mästerstyckes": "mästerstycke",
    "mästerstycket": "mästerstycke",
    "mästerstyckets": "mästerstycke",
    "mästerstycks": "mästerstycke",
    "mästersångar": "mästersångare",
    "mästersångaren": "mästersångare",
    "mästersångarens": "mästersångare",
    "mästersångares": "mästersångare",
    "mästersångarna": "mästersångare",
    "mästersångarnas": "mästersångare",
    "mästersången": "mästersång",
    "mästersångens": "mästersång",
    "mästersångs": "mästersång",
    "mästertänkar": "mästertänkare",
    "mästertänkaren": "mästertänkare",
    "mästertänkarens": "mästertänkare",
    "mästertänkares": "mästertänkare",
    "mästertänkarna": "mästertänkare",
    "mästertänkarnas": "mästertänkare",
    "mästerverken": "mästerverk",
    "mästerverkens": "mästerverk",
    "mästerverket": "mästerverk",
    "mästerverkets": "mästerverk",
    "mästerverks": "mästerverk",
    "mästrad": "mästra",
    "mästrade": "mästra",
    "mästrades": "mästra",
    "mästrads": "mästra",
    "mästrande": "mästra",
    "mästranden": "mästrande",
    "mästrandena": "mästrande",
    "mästrandenas": "mästrande",
    "mästrandens": "mästrande",
    "mästrandes": "mästrande",
    "mästrandet": "mästrande",
    "mästrandets": "mästrande",
    "mästrar": "mästra",
    "mästras": "mästra",
    "mästrat": "mästra",
    "mästrats": "mästra",
    "mät": "mäta",
    "mätande": "mäta",
    "mätanden": "mätande",
    "mätandena": "mätande",
    "mätandenas": "mätande",
    "mätandens": "mätande",
    "mätandes": "mätande",
    "mätandet": "mätande",
    "mätandets": "mätande",
    "mätapparaten": "mätapparat",
    "mätapparatens": "mätapparat",
    "mätapparater": "mätapparat",
    "mätapparaterna": "mätapparat",
    "mätapparaternas": "mätapparat",
    "mätapparaters": "mätapparat",
    "mätapparats": "mätapparat",
    "mätapparaturen": "mätapparatur",
    "mätapparaturens": "mätapparatur",
    "mätapparaturer": "mätapparatur",
    "mätapparaturerna": "mätapparatur",
    "mätapparaturernas": "mätapparatur",
    "mätapparaturers": "mätapparatur",
    "mätapparaturs": "mätapparatur",
    "mätar": "mätare",
    "mätaren": "mätare",
    "mätarens": "mätare",
    "mätares": "mätare",
    "mätarfjärilar": "mätarfjäril",
    "mätarfjärilarna": "mätarfjäril",
    "mätarfjärilarnas": "mätarfjäril",
    "mätarfjärilars": "mätarfjäril",
    "mätarfjärilen": "mätarfjäril",
    "mätarfjärilens": "mätarfjäril",
    "mätarfjäriln": "mätarfjäril",
    "mätarfjärilns": "mätarfjäril",
    "mätarfjärils": "mätarfjäril",
    "mätarhusen": "mätarhus",
    "mätarhusens": "mätarhus",
    "mätarhuset": "mätarhus",
    "mätarhusets": "mätarhus",
    "mätarlarven": "mätarlarv",
    "mätarlarvens": "mätarlarv",
    "mätarlarver": "mätarlarv",
    "mätarlarverna": "mätarlarv",
    "mätarlarvernas": "mätarlarv",
    "mätarlarvers": "mätarlarv",
    "mätarlarvs": "mätarlarv",
    "mätarna": "mätare",
    "mätarnas": "mätare",
    "mätas": "mäta",
    "mätbara": "mätbar",
    "mätbarare": "mätbar",
    "mätbarares": "mätbar",
    "mätbaras": "mätbar",
    "mätbarast": "mätbar",
    "mätbaraste": "mätbar",
    "mätbarastes": "mätbar",
    "mätbarasts": "mätbar",
    "mätbare": "mätbar",
    "mätbares": "mätbar",
    "mätbarheten": "mätbarhet",
    "mätbarhetens": "mätbarhet",
    "mätbarheter": "mätbarhet",
    "mätbarheterna": "mätbarhet",
    "mätbarheternas": "mätbarhet",
    "mätbarheters": "mätbarhet",
    "mätbarhets": "mätbarhet",
    "mätbars": "mätbar",
    "mätbart": "mätbar",
    "mätbarts": "mätbar",
    "mätborden": "mätbord",
    "mätbordens": "mätbord",
    "mätbordet": "mätbord",
    "mätbordets": "mätbord",
    "mätbords": "mätbord",
    "mätbreven": "mätbrev",
    "mätbrevens": "mätbrev",
    "mätbrevet": "mätbrev",
    "mätbrevets": "mätbrev",
    "mätbrevs": "mätbrev",
    "mätdatan": "mätdata",
    "mätdatana": "mätdata",
    "mätdatanas": "mätdata",
    "mätdatans": "mätdata",
    "mätdatas": "mätdata",
    "mätdatat": "mätdata",
    "mätdatats": "mätdata",
    "mäter": "mäta",
    "mätes": "mäta",
    "mätetalen": "mätetal",
    "mätetalens": "mätetal",
    "mätetalet": "mätetal",
    "mätetalets": "mätetal",
    "mätetals": "mätetal",
    "mätglasen": "mätglas",
    "mätglasens": "mätglas",
    "mätglaset": "mätglas",
    "mätglasets": "mätglas",
    "mätinstrumenten": "mätinstrument",
    "mätinstrumentens": "mätinstrument",
    "mätinstrumentet": "mätinstrument",
    "mätinstrumentets": "mätinstrument",
    "mätinstruments": "mätinstrument",
    "mätmässiga": "mätmässig",
    "mätmässigare": "mätmässig",
    "mätmässigares": "mätmässig",
    "mätmässigas": "mätmässig",
    "mätmässigast": "mätmässig",
    "mätmässigaste": "mätmässig",
    "mätmässigastes": "mätmässig",
    "mätmässigasts": "mätmässig",
    "mätmässige": "mätmässig",
    "mätmässiges": "mätmässig",
    "mätmässigs": "mätmässig",
    "mätmässigt": "mätmässig",
    "mätmässigts": "mätmässig",
    "mätningar": "mätning",
    "mätningarna": "mätning",
    "mätningarnas": "mätning",
    "mätningars": "mätning",
    "mätningen": "mätning",
    "mätningens": "mätning",
    "mätnings": "mätning",
    "mätningsfartygen": "mätningsfartyg",
    "mätningsfartygens": "mätningsfartyg",
    "mätningsfartyget": "mätningsfartyg",
    "mätningsfartygets": "mätningsfartyg",
    "mätningsfartygs": "mätningsfartyg",
    "mätningsregeln": "mätningsregel",
    "mätningsregelns": "mätningsregel",
    "mätningsregels": "mätningsregel",
    "mätningsregler": "mätningsregel",
    "mätningsreglerna": "mätningsregel",
    "mätningsreglernas": "mätningsregel",
    "mätningsreglers": "mätningsregel",
    "mätningstalen": "mätningstal",
    "mätningstalens": "mätningstal",
    "mätningstalet": "mätningstal",
    "mätningstalets": "mätningstal",
    "mätningstals": "mätningstal",
    "mätområden": "mätområde",
    "mätområdena": "mätområde",
    "mätområdenas": "mätområde",
    "mätområdens": "mätområde",
    "mätområdes": "mätområde",
    "mätområdet": "mätområde",
    "mätområdets": "mätområde",
    "mätperioden": "mätperiod",
    "mätperiodens": "mätperiod",
    "mätperioder": "mätperiod",
    "mätperioderna": "mätperiod",
    "mätperiodernas": "mätperiod",
    "mätperioders": "mätperiod",
    "mätperiods": "mätperiod",
    "mätredskapen": "mätredskap",
    "mätredskapens": "mätredskap",
    "mätredskapet": "mätredskap",
    "mätredskapets": "mätredskap",
    "mätredskaps": "mätredskap",
    "mätressen": "mätress",
    "mätressens": "mätress",
    "mätresser": "mätress",
    "mätresserna": "mätress",
    "mätressernas": "mätress",
    "mätressers": "mätress",
    "mäts": "mäta",
    "mätstick": "mätsticka",
    "mätstickan": "mätsticka",
    "mätstickans": "mätsticka",
    "mätstickas": "mätsticka",
    "mätsticke": "mätsticka",
    "mätstickor": "mätsticka",
    "mätstickorna": "mätsticka",
    "mätstickornas": "mätsticka",
    "mätstickors": "mätsticka",
    "mätsticks": "mätsticka",
    "mätt": "mätta",
    "mätta": "mätt",
    "mättad": "mätta",
    "mättade": "mättad",
    "mättades": "mättad",
    "mättads": "mättad",
    "mättande": "mätta",
    "mättanden": "mättande",
    "mättandena": "mättande",
    "mättandenas": "mättande",
    "mättandens": "mättande",
    "mättandes": "mättande",
    "mättandet": "mättande",
    "mättandets": "mättande",
    "mättar": "mätta",
    "mättare": "mätt",
    "mättares": "mätt",
    "mättas": "mätta",
    "mättast": "mätt",
    "mättaste": "mätt",
    "mättastes": "mätt",
    "mättasts": "mätt",
    "mättat": "mättad",
    "mättats": "mättad",
    "mätte": "mätt",
    "mättes": "mätt",
    "mättheten": "mätthet",
    "mätthetens": "mätthet",
    "mätthets": "mätthet",
    "mättnaden": "mättnad",
    "mättnadens": "mättnad",
    "mättnader": "mättnad",
    "mättnaderna": "mättnad",
    "mättnadernas": "mättnad",
    "mättnaders": "mättnad",
    "mättnads": "mättnad",
    "mättningstrycken": "mättningstryck",
    "mättningstryckens": "mättningstryck",
    "mättningstrycket": "mättningstryck",
    "mättningstryckets": "mättningstryck",
    "mättningstrycks": "mättningstryck",
    "mätts": "mätt",
    "mättsamheten": "mättsamhet",
    "mättsamhetens": "mättsamhet",
    "mättsamhets": "mättsamhet",
    "mättsamma": "mättsam",
    "mättsammare": "mättsam",
    "mättsammares": "mättsam",
    "mättsammas": "mättsam",
    "mättsammast": "mättsam",
    "mättsammaste": "mättsam",
    "mättsammastes": "mättsam",
    "mättsammasts": "mättsam",
    "mättsamme": "mättsam",
    "mättsammes": "mättsam",
    "mättsams": "mättsam",
    "mättsamt": "mättsam",
    "mättsamts": "mättsam",
    "mätverktygen": "mätverktyg",
    "mätverktygens": "mätverktyg",
    "mätverktyget": "mätverktyg",
    "mätverktygets": "mätverktyg",
    "mätverktygs": "mätverktyg",
    "mätvärden": "mätvärde",
    "mätvärdena": "mätvärde",
    "mätvärdenas": "mätvärde",
    "mätvärdens": "mätvärde",
    "mätvärdes": "mätvärde",
    "mätvärdet": "mätvärde",
    "mätvärdets": "mätvärde",
    "måbären": "måbär",
    "måbärens": "måbär",
    "måbäret": "måbär",
    "måbärets": "måbär",
    "måbärs": "måbär",
    "måbärsbusk": "måbärsbuske",
    "måbärsbuskar": "måbärsbuske",
    "måbärsbuskarna": "måbärsbuske",
    "måbärsbuskarnas": "måbärsbuske",
    "måbärsbuskars": "måbärsbuske",
    "måbärsbusken": "måbärsbuske",
    "måbärsbuskens": "måbärsbuske",
    "måbärsbuskes": "måbärsbuske",
    "mådd": "må",
    "mådda": "må",
    "måddas": "må",
    "mådde": "må",
    "måddes": "må",
    "mådds": "må",
    "mående": "må",
    "måenden": "mående",
    "måendena": "mående",
    "måendenas": "mående",
    "måendens": "mående",
    "måendes": "mående",
    "måendet": "mående",
    "måendets": "mående",
    "mågar": "måg",
    "mågarna": "måg",
    "mågarnas": "måg",
    "mågars": "måg",
    "mågen": "måg",
    "mågens": "måg",
    "mågs": "måg",
    "måkar": "måkare",
    "måkaren": "måkare",
    "måkarens": "måkare",
    "måkares": "måkare",
    "måkarna": "måkare",
    "måkarnas": "måkare",
    "mål": "måla",
    "målad": "måla",
    "målade": "måla",
    "målades": "måla",
    "målads": "måla",
    "målande": "måla",
    "målanden": "målande",
    "målandena": "målande",
    "målandenas": "målande",
    "målandens": "målande",
    "målandes": "målande",
    "målandet": "målande",
    "målandets": "målande",
    "målangivningar": "målangivning",
    "målangivningarna": "målangivning",
    "målangivningarnas": "målangivning",
    "målangivningars": "målangivning",
    "målangivningen": "målangivning",
    "målangivningens": "målangivning",
    "målangivnings": "målangivning",
    "målar": "målare",
    "målarboken": "målarbok",
    "målarbokens": "målarbok",
    "målarboks": "målarbok",
    "målarborst": "målarborste",
    "målarborstar": "målarborste",
    "målarborstarna": "målarborste",
    "målarborstarnas": "målarborste",
    "målarborstars": "målarborste",
    "målarborsten": "målarborste",
    "målarborstens": "målarborste",
    "målarborstes": "målarborste",
    "målarböcker": "målarbok",
    "målarböckerna": "målarbok",
    "målarböckernas": "målarbok",
    "målarböckers": "målarbok",
    "målardukar": "målarduk",
    "målardukarna": "målarduk",
    "målardukarnas": "målarduk",
    "målardukars": "målarduk",
    "målarduken": "målarduk",
    "målardukens": "målarduk",
    "målarduks": "målarduk",
    "målaren": "målare",
    "målarens": "målare",
    "målares": "målare",
    "målarfärgen": "målarfärg",
    "målarfärgens": "målarfärg",
    "målarfärger": "målarfärg",
    "målarfärgerna": "målarfärg",
    "målarfärgernas": "målarfärg",
    "målarfärgers": "målarfärg",
    "målarfärgs": "målarfärg",
    "målarkluddar": "målarkludd",
    "målarkluddarna": "målarkludd",
    "målarkluddarnas": "målarkludd",
    "målarkluddars": "målarkludd",
    "målarkludden": "målarkludd",
    "målarkluddens": "målarkludd",
    "målarkludds": "målarkludd",
    "målarknivar": "målarkniv",
    "målarknivarna": "målarkniv",
    "målarknivarnas": "målarkniv",
    "målarknivars": "målarkniv",
    "målarkniven": "målarkniv",
    "målarknivens": "målarkniv",
    "målarknivs": "målarkniv",
    "målarmästar": "målarmästare",
    "målarmästaren": "målarmästare",
    "målarmästarens": "målarmästare",
    "målarmästares": "målarmästare",
    "målarmästarna": "målarmästare",
    "målarmästarnas": "målarmästare",
    "målarna": "målare",
    "målarnas": "målare",
    "målarrockar": "målarrock",
    "målarrockarna": "målarrock",
    "målarrockarnas": "målarrock",
    "målarrockars": "målarrock",
    "målarrocken": "målarrock",
    "målarrockens": "målarrock",
    "målarrocks": "målarrock",
    "målarskolan": "målarskola",
    "målarskolans": "målarskola",
    "målarskolas": "målarskola",
    "målarskole": "målarskola",
    "målarskolor": "målarskola",
    "målarskolorna": "målarskola",
    "målarskolornas": "målarskola",
    "målarskolors": "målarskola",
    "målarställningar": "målarställning",
    "målarställningarna": "målarställning",
    "målarställningarnas": "målarställning",
    "målarställningars": "målarställning",
    "målarställningen": "målarställning",
    "målarställningens": "målarställning",
    "målarställnings": "målarställning",
    "målas": "måla",
    "målat": "måla",
    "målats": "måla",
    "målbrottet": "målbrott",
    "målbrottets": "målbrott",
    "målbrotts": "målbrott",
    "målbrottsrösten": "målbrottsröst",
    "målbrottsröstens": "målbrottsröst",
    "målbrottsröster": "målbrottsröst",
    "målbrottsrösterna": "målbrottsröst",
    "målbrottsrösternas": "målbrottsröst",
    "målbrottsrösters": "målbrottsröst",
    "målbrottsrösts": "målbrottsröst",
    "målburar": "målbur",
    "målburarna": "målbur",
    "målburarnas": "målbur",
    "målburars": "målbur",
    "målburen": "målbur",
    "målburens": "målbur",
    "målburs": "målbur",
    "målchansen": "målchans",
    "målchansens": "målchans",
    "målchanser": "målchans",
    "målchanserna": "målchans",
    "målchansernas": "målchans",
    "målchansers": "målchans",
    "måldomar": "måldomare",
    "måldomaren": "måldomare",
    "måldomarens": "måldomare",
    "måldomares": "måldomare",
    "måldomarna": "måldomare",
    "måldomarnas": "måldomare",
    "målen": "mål",
    "målens": "mål",
    "måleriarbeten": "måleriarbete",
    "måleriarbetena": "måleriarbete",
    "måleriarbetenas": "måleriarbete",
    "måleriarbetens": "måleriarbete",
    "måleriarbetes": "måleriarbete",
    "måleriarbetet": "måleriarbete",
    "måleriarbetets": "måleriarbete",
    "måleriarbets": "måleriarbete",
    "målerier": "måleri",
    "målerierna": "måleri",
    "måleriernas": "måleri",
    "måleriers": "måleri",
    "måleriet": "måleri",
    "måleriets": "måleri",
    "måleris": "måleri",
    "måleriska": "målerisk",
    "måleriskare": "målerisk",
    "måleriskares": "målerisk",
    "måleriskas": "målerisk",
    "måleriskast": "målerisk",
    "måleriskaste": "målerisk",
    "måleriskastes": "målerisk",
    "måleriskasts": "målerisk",
    "måleriske": "målerisk",
    "måleriskes": "målerisk",
    "målerisks": "målerisk",
    "måleriskt": "målerisk",
    "måleriskts": "målerisk",
    "målerit": "måleri",
    "målerits": "måleri",
    "målet": "mål",
    "målets": "mål",
    "målfarliga": "målfarlig",
    "målfarligare": "målfarlig",
    "målfarligares": "målfarlig",
    "målfarligas": "målfarlig",
    "målfarligast": "målfarlig",
    "målfarligaste": "målfarlig",
    "målfarligastes": "målfarlig",
    "målfarligasts": "målfarlig",
    "målfarlige": "målfarlig",
    "målfarliges": "målfarlig",
    "målfarligheten": "målfarlighet",
    "målfarlighetens": "målfarlighet",
    "målfarlighets": "målfarlighet",
    "målfarligs": "målfarlig",
    "målfarligt": "målfarlig",
    "målfarligts": "målfarlig",
    "målfiguren": "målfigur",
    "målfigurens": "målfigur",
    "målfigurer": "målfigur",
    "målfigurerna": "målfigur",
    "målfigurernas": "målfigur",
    "målfigurers": "målfigur",
    "målfigurs": "målfigur",
    "målforskningar": "målforskning",
    "målforskningarna": "målforskning",
    "målforskningarnas": "målforskning",
    "målforskningars": "målforskning",
    "målforskningen": "målforskning",
    "målforskningens": "målforskning",
    "målforsknings": "målforskning",
    "målfoton": "målfoto",
    "målfotona": "målfoto",
    "målfotonas": "målfoto",
    "målfotons": "målfoto",
    "målfotos": "målfoto",
    "målfotot": "målfoto",
    "målfotots": "målfoto",
    "målföres": "målföre",
    "målföret": "målföre",
    "målförets": "målföre",
    "målgruppen": "målgrupp",
    "målgruppens": "målgrupp",
    "målgrupper": "målgrupp",
    "målgrupperna": "målgrupp",
    "målgruppernas": "målgrupp",
    "målgruppers": "målgrupp",
    "målgrupps": "målgrupp",
    "målgårdar": "målgård",
    "målgårdarna": "målgård",
    "målgårdarnas": "målgård",
    "målgårdars": "målgård",
    "målgården": "målgård",
    "målgårdens": "målgård",
    "målgårds": "målgård",
    "målinriktade": "målinriktad",
    "målinriktades": "målinriktad",
    "målinriktads": "målinriktad",
    "målinriktat": "målinriktad",
    "målinriktats": "målinriktad",
    "målkameran": "målkamera",
    "målkamerans": "målkamera",
    "målkameras": "målkamera",
    "målkameror": "målkamera",
    "målkamerorna": "målkamera",
    "målkamerornas": "målkamera",
    "målkamerors": "målkamera",
    "målkonflikten": "målkonflikt",
    "målkonfliktens": "målkonflikt",
    "målkonflikter": "målkonflikt",
    "målkonflikterna": "målkonflikt",
    "målkonflikternas": "målkonflikt",
    "målkonflikters": "målkonflikt",
    "målkonflikts": "målkonflikt",
    "målkungar": "målkung",
    "målkungarna": "målkung",
    "målkungarnas": "målkung",
    "målkungars": "målkung",
    "målkungen": "målkung",
    "målkungens": "målkung",
    "målkungs": "målkung",
    "målkvoten": "målkvot",
    "målkvotens": "målkvot",
    "målkvoter": "målkvot",
    "målkvoterna": "målkvot",
    "målkvoternas": "målkvot",
    "målkvoters": "målkvot",
    "målkvots": "målkvot",
    "måll": "målla",
    "mållan": "målla",
    "mållans": "målla",
    "mållas": "målla",
    "målle": "målla",
    "mållinjen": "mållinje",
    "mållinjens": "mållinje",
    "mållinjer": "mållinje",
    "mållinjerna": "mållinje",
    "mållinjernas": "mållinje",
    "mållinjers": "mållinje",
    "mållinjes": "mållinje",
    "mållor": "målla",
    "mållorna": "målla",
    "mållornas": "målla",
    "mållors": "målla",
    "målls": "målla",
    "mållösa": "mållös",
    "mållösare": "mållös",
    "mållösares": "mållös",
    "mållösas": "mållös",
    "mållösast": "mållös",
    "mållösaste": "mållös",
    "mållösastes": "mållös",
    "mållösasts": "mållös",
    "mållöse": "mållös",
    "mållöses": "mållös",
    "mållösheten": "mållöshet",
    "mållöshetens": "mållöshet",
    "mållöshets": "mållöshet",
    "mållöst": "mållös",
    "mållösts": "mållös",
    "målmedvetenheten": "målmedvetenhet",
    "målmedvetenhetens": "målmedvetenhet",
    "målmedvetenhets": "målmedvetenhet",
    "målmedvetens": "målmedveten",
    "målmedvetet": "målmedveten",
    "målmedvetets": "målmedveten",
    "målmedvetna": "målmedveten",
    "målmedvetnare": "målmedveten",
    "målmedvetnares": "målmedveten",
    "målmedvetnas": "målmedveten",
    "målmedvetnast": "målmedveten",
    "målmedvetnaste": "målmedveten",
    "målmedvetnastes": "målmedveten",
    "målmedvetnasts": "målmedveten",
    "målmedvetne": "målmedveten",
    "målmedvetnes": "målmedveten",
    "målmässiga": "målmässig",
    "målmässigare": "målmässig",
    "målmässigares": "målmässig",
    "målmässigas": "målmässig",
    "målmässigast": "målmässig",
    "målmässigaste": "målmässig",
    "målmässigastes": "målmässig",
    "målmässigasts": "målmässig",
    "målmässige": "målmässig",
    "målmässiges": "målmässig",
    "målmässigs": "målmässig",
    "målmässigt": "målmässig",
    "målmässigts": "målmässig",
    "målningar": "målning",
    "målningarna": "målning",
    "målningarnas": "målning",
    "målningars": "målning",
    "målningen": "målning",
    "målningens": "målning",
    "målnings": "målning",
    "målområden": "målområde",
    "målområdena": "målområde",
    "målområdenas": "målområde",
    "målområdens": "målområde",
    "målområdes": "målområde",
    "målområdet": "målområde",
    "målområdets": "målområde",
    "målrelaterade": "målrelaterad",
    "målrelaterades": "målrelaterad",
    "målrelaterads": "målrelaterad",
    "målrelaterat": "målrelaterad",
    "målrelaterats": "målrelaterad",
    "måls": "mål",
    "målskillnaden": "målskillnad",
    "målskillnadens": "målskillnad",
    "målskillnader": "målskillnad",
    "målskillnaderna": "målskillnad",
    "målskillnadernas": "målskillnad",
    "målskillnaders": "målskillnad",
    "målskillnads": "målskillnad",
    "målskjutningar": "målskjutning",
    "målskjutningarna": "målskjutning",
    "målskjutningarnas": "målskjutning",
    "målskjutningars": "målskjutning",
    "målskjutningen": "målskjutning",
    "målskjutningens": "målskjutning",
    "målskjutnings": "målskjutning",
    "målskyttar": "målskytt",
    "målskyttarna": "målskytt",
    "målskyttarnas": "målskytt",
    "målskyttars": "målskytt",
    "målskytten": "målskytte",
    "målskyttena": "målskytte",
    "målskyttenas": "målskytte",
    "målskyttens": "målskytte",
    "målskyttes": "målskytte",
    "målskyttet": "målskytte",
    "målskyttets": "målskytte",
    "målskytts": "målskytt",
    "målsmannen": "målsman",
    "målsmannens": "målsman",
    "målsmans": "målsman",
    "målsmän": "målsman",
    "målsmännen": "målsman",
    "målsmännens": "målsman",
    "målsmäns": "målsman",
    "målsnör": "målsnöre",
    "målsnören": "målsnöre",
    "målsnörena": "målsnöre",
    "målsnörenas": "målsnöre",
    "målsnörens": "målsnöre",
    "målsnöres": "målsnöre",
    "målsnöret": "målsnöre",
    "målsnörets": "målsnöre",
    "målsnörs": "målsnöre",
    "målspaningar": "målspaning",
    "målspaningarna": "målspaning",
    "målspaningarnas": "målspaning",
    "målspaningars": "målspaning",
    "målspaningen": "målspaning",
    "målspaningens": "målspaning",
    "målspanings": "målspaning",
    "målspottar": "målspottare",
    "målspottaren": "målspottare",
    "målspottarens": "målspottare",
    "målspottares": "målspottare",
    "målspottarna": "målspottare",
    "målspottarnas": "målspottare",
    "målspråken": "målspråk",
    "målspråkens": "målspråk",
    "målspråket": "målspråk",
    "målspråkets": "målspråk",
    "målspråks": "målspråk",
    "målstolp": "målstolpe",
    "målstolpar": "målstolpe",
    "målstolparna": "målstolpe",
    "målstolparnas": "målstolpe",
    "målstolpars": "målstolpe",
    "målstolpen": "målstolpe",
    "målstolpens": "målstolpe",
    "målstolpes": "målstolpe",
    "målstolps": "målstolpe",
    "målstyrningar": "målstyrning",
    "målstyrningarna": "målstyrning",
    "målstyrningarnas": "målstyrning",
    "målstyrningars": "målstyrning",
    "målstyrningen": "målstyrning",
    "målstyrningens": "målstyrning",
    "målstyrnings": "målstyrning",
    "målställningar": "målställning",
    "målställningarna": "målställning",
    "målställningarnas": "målställning",
    "målställningars": "målställning",
    "målställningen": "målställning",
    "målställningens": "målställning",
    "målställnings": "målställning",
    "målsäganden": "målsägande",
    "målsägandena": "målsägande",
    "målsägandenas": "målsägande",
    "målsägandens": "målsägande",
    "målsägandes": "målsägande",
    "målsägar": "målsägare",
    "målsägarbiträden": "målsägarbiträde",
    "målsägarbiträdena": "målsägarbiträde",
    "målsägarbiträdenas": "målsägarbiträde",
    "målsägarbiträdens": "målsägarbiträde",
    "målsägarbiträdes": "målsägarbiträde",
    "målsägarbiträdet": "målsägarbiträde",
    "målsägarbiträdets": "målsägarbiträde",
    "målsägaren": "målsägare",
    "målsägarens": "målsägare",
    "målsägares": "målsägare",
    "målsägarna": "målsägare",
    "målsägarnas": "målsägare",
    "målsättningar": "målsättning",
    "målsättningarna": "målsättning",
    "målsättningarnas": "målsättning",
    "målsättningars": "målsättning",
    "målsättningen": "målsättning",
    "målsättningens": "målsättning",
    "målsättnings": "målsättning",
    "målsökar": "målsökare",
    "målsökaren": "målsökare",
    "målsökarens": "målsökare",
    "målsökares": "målsökare",
    "målsökarna": "målsökare",
    "målsökarnas": "målsökare",
    "måltavel": "måltavla",
    "måltavlan": "måltavla",
    "måltavlans": "måltavla",
    "måltavlas": "måltavla",
    "måltavle": "måltavla",
    "måltavlor": "måltavla",
    "måltavlorna": "måltavla",
    "måltavlornas": "måltavla",
    "måltavlors": "måltavla",
    "måltiden": "måltid",
    "måltidens": "måltid",
    "måltider": "måltid",
    "måltiderna": "måltid",
    "måltidernas": "måltid",
    "måltiders": "måltid",
    "måltids": "måltid",
    "måltidsdrick": "måltidsdricka",
    "måltidsdrickan": "måltidsdricka",
    "måltidsdrickans": "måltidsdricka",
    "måltidsdrickas": "måltidsdricka",
    "måltidsdricke": "måltidsdricka",
    "måltidsdrickor": "måltidsdricka",
    "måltidsdrickorna": "måltidsdricka",
    "måltidsdrickornas": "måltidsdricka",
    "måltidsdrickors": "måltidsdricka",
    "måltidsdricks": "måltidsdricka",
    "måltidsdrycken": "måltidsdryck",
    "måltidsdryckens": "måltidsdryck",
    "måltidsdrycker": "måltidsdryck",
    "måltidsdryckerna": "måltidsdryck",
    "måltidsdryckernas": "måltidsdryck",
    "måltidsdryckers": "måltidsdryck",
    "måltidsdrycks": "måltidsdryck",
    "måltidstvånget": "måltidstvång",
    "måltidstvångets": "måltidstvång",
    "måltidstvångs": "måltidstvång",
    "måltorkan": "måltorka",
    "måltorkans": "måltorka",
    "måltorkas": "måltorka",
    "måltorke": "måltorka",
    "målvakten": "målvakt",
    "målvaktens": "målvakt",
    "målvakter": "målvakt",
    "målvakterna": "målvakt",
    "målvakternas": "målvakt",
    "målvakters": "målvakt",
    "målvakts": "målvakt",
    "målytan": "målyta",
    "målytans": "målyta",
    "målytas": "målyta",
    "målyte": "målyta",
    "målytor": "målyta",
    "målytorna": "målyta",
    "målytornas": "målyta",
    "målytors": "målyta",
    "mån": "måne",
    "måna": "mån",
    "månade": "måna",
    "månaden": "månad",
    "månadens": "månad",
    "månader": "månad",
    "månaderna": "månad",
    "månadernas": "månad",
    "månaders": "månad",
    "månades": "måna",
    "månads": "månad",
    "månadskontrollen": "månadskontroll",
    "månadskontrollens": "månadskontroll",
    "månadskontroller": "månadskontroll",
    "månadskontrollerna": "månadskontroll",
    "månadskontrollernas": "månadskontroll",
    "månadskontrollers": "månadskontroll",
    "månadskontrolls": "månadskontroll",
    "månadskorten": "månadskort",
    "månadskortens": "månadskort",
    "månadskortet": "månadskort",
    "månadskortets": "månadskort",
    "månadskorts": "månadskort",
    "månadslånga": "månadslång",
    "månadslångas": "månadslång",
    "månadslånge": "månadslång",
    "månadslånges": "månadslång",
    "månadslångs": "månadslång",
    "månadslångt": "månadslång",
    "månadslångts": "månadslång",
    "månadslönen": "månadslön",
    "månadslönens": "månadslön",
    "månadslöner": "månadslön",
    "månadslönerna": "månadslön",
    "månadslönernas": "månadslön",
    "månadslöners": "månadslön",
    "månadslöns": "månadslön",
    "månadspengar": "månadspeng",
    "månadspengarna": "månadspeng",
    "månadspengarnas": "månadspeng",
    "månadspengars": "månadspeng",
    "månadspengen": "månadspeng",
    "månadspengens": "månadspeng",
    "månadspengs": "månadspeng",
    "månadsrosen": "månadsros",
    "månadsrosens": "månadsros",
    "månadsrosor": "månadsros",
    "månadsrosorna": "månadsros",
    "månadsrosornas": "månadsros",
    "månadsrosors": "månadsros",
    "månadsskiften": "månadsskifte",
    "månadsskiftena": "månadsskifte",
    "månadsskiftenas": "månadsskifte",
    "månadsskiftens": "månadsskifte",
    "månadsskiftes": "månadsskifte",
    "månadsskiftet": "månadsskifte",
    "månadsskiftets": "månadsskifte",
    "månadssmultronen": "månadssmultron",
    "månadssmultronens": "månadssmultron",
    "månadssmultronet": "månadssmultron",
    "månadssmultronets": "månadssmultron",
    "månadssmultrons": "månadssmultron",
    "månadstidskriften": "månadstidskrift",
    "månadstidskriftens": "månadstidskrift",
    "månadstidskrifter": "månadstidskrift",
    "månadstidskrifterna": "månadstidskrift",
    "månadstidskrifternas": "månadstidskrift",
    "månadstidskrifters": "månadstidskrift",
    "månadstidskrifts": "månadstidskrift",
    "månadtalen": "månadtal",
    "månadtalens": "månadtal",
    "månadtalet": "månadtal",
    "månadtalets": "månadtal",
    "månadtals": "månadtal",
    "månande": "måna",
    "månanden": "månande",
    "månandena": "månande",
    "månandenas": "månande",
    "månandens": "månande",
    "månandes": "månande",
    "månandet": "månande",
    "månandets": "månande",
    "månansikten": "månansikte",
    "månansiktena": "månansikte",
    "månansiktenas": "månansikte",
    "månansiktens": "månansikte",
    "månansiktes": "månansikte",
    "månansiktet": "månansikte",
    "månansiktets": "månansikte",
    "månansikts": "månansikte",
    "månar": "måne",
    "månare": "mån",
    "månares": "mån",
    "månarna": "måne",
    "månarnas": "måne",
    "månars": "måne",
    "månas": "måna",
    "månast": "mån",
    "månaste": "mån",
    "månastes": "mån",
    "månasts": "mån",
    "månat": "måna",
    "månatliga": "månatlig",
    "månatligare": "månatlig",
    "månatligares": "månatlig",
    "månatligas": "månatlig",
    "månatligast": "månatlig",
    "månatligaste": "månatlig",
    "månatligastes": "månatlig",
    "månatligasts": "månatlig",
    "månatlige": "månatlig",
    "månatliges": "månatlig",
    "månatligs": "månatlig",
    "månatligt": "månatlig",
    "månatligts": "månatlig",
    "månats": "måna",
    "månbanan": "månbana",
    "månbanans": "månbana",
    "månbanas": "månbana",
    "månbane": "månbana",
    "månbanor": "månbana",
    "månbanorna": "månbana",
    "månbanornas": "månbana",
    "månbanors": "månbana",
    "månbelysta": "månbelyst",
    "månbelystare": "månbelyst",
    "månbelystares": "månbelyst",
    "månbelystas": "månbelyst",
    "månbelystast": "månbelyst",
    "månbelystaste": "månbelyst",
    "månbelystastes": "månbelyst",
    "månbelystasts": "månbelyst",
    "månbelyste": "månbelyst",
    "månbelystes": "månbelyst",
    "månbelysts": "månbelyst",
    "månbävningar": "månbävning",
    "månbävningarna": "månbävning",
    "månbävningarnas": "månbävning",
    "månbävningars": "månbävning",
    "månbävningen": "månbävning",
    "månbävningens": "månbävning",
    "månbävnings": "månbävning",
    "måncykeln": "måncykel",
    "måncykelns": "måncykel",
    "måncykels": "måncykel",
    "måncyklar": "måncykel",
    "måncyklarna": "måncykel",
    "måncyklarnas": "måncykel",
    "måncyklars": "måncykel",
    "måncykler": "måncykel",
    "måncyklerna": "måncykel",
    "måncyklernas": "måncykel",
    "måncyklers": "måncykel",
    "måndagar": "måndag",
    "måndagarna": "måndag",
    "måndagarnas": "måndag",
    "måndagars": "måndag",
    "måndageftermiddagar": "måndageftermiddag",
    "måndageftermiddagarna": "måndageftermiddag",
    "måndageftermiddagarnas": "måndageftermiddag",
    "måndageftermiddagars": "måndageftermiddag",
    "måndageftermiddagen": "måndageftermiddag",
    "måndageftermiddagens": "måndageftermiddag",
    "måndageftermiddags": "måndageftermiddag",
    "måndagen": "måndag",
    "måndagens": "måndag",
    "måndagkvällar": "måndagkväll",
    "måndagkvällarna": "måndagkväll",
    "måndagkvällarnas": "måndagkväll",
    "måndagkvällars": "måndagkväll",
    "måndagkvällen": "måndagkväll",
    "måndagkvällens": "måndagkväll",
    "måndagkvälls": "måndagkväll",
    "måndagmorgnar": "måndagmorgon",
    "måndagmorgnarna": "måndagmorgon",
    "måndagmorgnarnas": "måndagmorgon",
    "måndagmorgnars": "måndagmorgon",
    "måndagmorgonen": "måndagmorgon",
    "måndagmorgonens": "måndagmorgon",
    "måndagmorgons": "måndagmorgon",
    "måndagmornar": "måndagmorgon",
    "måndagmornarna": "måndagmorgon",
    "måndagmornarnas": "måndagmorgon",
    "måndagmornars": "måndagmorgon",
    "måndags": "måndag",
    "måndagseftermiddagar": "måndagseftermiddag",
    "måndagseftermiddagarna": "måndagseftermiddag",
    "måndagseftermiddagarnas": "måndagseftermiddag",
    "måndagseftermiddagars": "måndagseftermiddag",
    "måndagseftermiddagen": "måndagseftermiddag",
    "måndagseftermiddagens": "måndagseftermiddag",
    "måndagseftermiddags": "måndagseftermiddag",
    "måndagsexemplaren": "måndagsexemplar",
    "måndagsexemplarens": "måndagsexemplar",
    "måndagsexemplaret": "måndagsexemplar",
    "måndagsexemplarets": "måndagsexemplar",
    "måndagsexemplars": "måndagsexemplar",
    "måndagskvällar": "måndagskväll",
    "måndagskvällarna": "måndagskväll",
    "måndagskvällarnas": "måndagskväll",
    "måndagskvällars": "måndagskväll",
    "måndagskvällen": "måndagskväll",
    "måndagskvällens": "måndagskväll",
    "måndagskvälls": "måndagskväll",
    "måndagsmorgnar": "måndagsmorgon",
    "måndagsmorgnarna": "måndagsmorgon",
    "måndagsmorgnarnas": "måndagsmorgon",
    "måndagsmorgnars": "måndagsmorgon",
    "måndagsmorgonen": "måndagsmorgon",
    "måndagsmorgonens": "måndagsmorgon",
    "måndagsmorgons": "måndagsmorgon",
    "måndagsmornar": "måndagsmorgon",
    "måndagsmornarna": "måndagsmorgon",
    "måndagsmornarnas": "måndagsmorgon",
    "måndagsmornars": "måndagsmorgon",
    "måndistansen": "måndistans",
    "måndistansens": "måndistans",
    "måndistanser": "måndistans",
    "måndistanserna": "måndistans",
    "måndistansernas": "måndistans",
    "måndistansers": "måndistans",
    "måndygnen": "måndygn",
    "måndygnens": "måndygn",
    "måndygnet": "måndygn",
    "måndygnets": "måndygn",
    "måndygns": "måndygn",
    "måne": "mån",
    "månen": "måne",
    "månens": "måne",
    "månes": "måne",
    "månfasen": "månfas",
    "månfasens": "månfas",
    "månfaser": "månfas",
    "månfaserna": "månfas",
    "månfasernas": "månfas",
    "månfasers": "månfas",
    "månfloden": "månflod",
    "månflodens": "månflod",
    "månfloder": "månflod",
    "månfloderna": "månflod",
    "månflodernas": "månflod",
    "månfloders": "månflod",
    "månflods": "månflod",
    "månfärden": "månfärd",
    "månfärdens": "månfärd",
    "månfärder": "månfärd",
    "månfärderna": "månfärd",
    "månfärdernas": "månfärd",
    "månfärders": "månfärd",
    "månfärds": "månfärd",
    "månförmörkelsen": "månförmörkelse",
    "månförmörkelsens": "månförmörkelse",
    "månförmörkelser": "månförmörkelse",
    "månförmörkelserna": "månförmörkelse",
    "månförmörkelsernas": "månförmörkelse",
    "månförmörkelsers": "månförmörkelse",
    "månförmörkelses": "månförmörkelse",
    "många": "mången",
    "mångarmade": "mångarmad",
    "mångarmades": "mångarmad",
    "mångarmads": "mångarmad",
    "mångarmat": "mångarmad",
    "mångarmats": "mångarmad",
    "mångas": "mången",
    "mångat": "mångata",
    "mångatan": "mångata",
    "mångatans": "mångata",
    "mångatas": "mångata",
    "mångate": "mångata",
    "mångator": "mångata",
    "mångatorna": "mångata",
    "mångatornas": "mångata",
    "mångators": "mångata",
    "mångats": "mångata",
    "mångbeprövade": "mångbeprövad",
    "mångbeprövades": "mångbeprövad",
    "mångbeprövads": "mångbeprövad",
    "mångbeprövat": "mångbeprövad",
    "mångbeprövats": "mångbeprövad",
    "mångbesjungens": "mångbesjungen",
    "mångbesjunget": "mångbesjungen",
    "mångbesjungets": "mångbesjungen",
    "mångbesjungna": "mångbesjungen",
    "mångbesjungnare": "mångbesjungen",
    "mångbesjungnares": "mångbesjungen",
    "mångbesjungnas": "mångbesjungen",
    "mångbesjungnast": "mångbesjungen",
    "mångbesjungnaste": "mångbesjungen",
    "mångbesjungnastes": "mångbesjungen",
    "mångbesjungnasts": "mångbesjungen",
    "mångbesjungne": "mångbesjungen",
    "mångbesjungnes": "mångbesjungen",
    "mångbyggar": "mångbyggare",
    "mångbyggaren": "mångbyggare",
    "mångbyggarens": "mångbyggare",
    "mångbyggares": "mångbyggare",
    "mångbyggarna": "mångbyggare",
    "mångbyggarnas": "mångbyggare",
    "mångdubbels": "mångdubbel",
    "mångdubbelt": "mångdubbel",
    "mångdubbelts": "mångdubbel",
    "mångdubbla": "mångdubbel",
    "mångdubblad": "mångdubbla",
    "mångdubblade": "mångdubbla",
    "mångdubblades": "mångdubbla",
    "mångdubblads": "mångdubbla",
    "mångdubblande": "mångdubbla",
    "mångdubblanden": "mångdubblande",
    "mångdubblandena": "mångdubblande",
    "mångdubblandenas": "mångdubblande",
    "mångdubblandens": "mångdubblande",
    "mångdubblandes": "mångdubblande",
    "mångdubblandet": "mångdubblande",
    "mångdubblandets": "mångdubblande",
    "mångdubblar": "mångdubbla",
    "mångdubblare": "mångdubbel",
    "mångdubblares": "mångdubbel",
    "mångdubblas": "mångdubbla",
    "mångdubblast": "mångdubbel",
    "mångdubblaste": "mångdubbel",
    "mångdubblastes": "mångdubbel",
    "mångdubblasts": "mångdubbel",
    "mångdubblat": "mångdubbla",
    "mångdubblats": "mångdubbla",
    "mångdubble": "mångdubbel",
    "mångdubbles": "mångdubbel",
    "mångel": "mångla",
    "mångens": "mången",
    "månget": "mången",
    "mångets": "mången",
    "mångfacetterade": "mångfacetterad",
    "mångfacetterades": "mångfacetterad",
    "mångfacetterads": "mångfacetterad",
    "mångfacetterat": "mångfacetterad",
    "mångfacetterats": "mångfacetterad",
    "mångfalden": "mångfald",
    "mångfaldens": "mångfald",
    "mångfalder": "mångfald",
    "mångfalderna": "mångfald",
    "mångfaldernas": "mångfald",
    "mångfalders": "mångfald",
    "mångfaldiga": "mångfaldig",
    "mångfaldigad": "mångfaldiga",
    "mångfaldigade": "mångfaldiga",
    "mångfaldigades": "mångfaldiga",
    "mångfaldigads": "mångfaldiga",
    "mångfaldigande": "mångfaldiga",
    "mångfaldiganden": "mångfaldigande",
    "mångfaldigandena": "mångfaldigande",
    "mångfaldigandenas": "mångfaldigande",
    "mångfaldigandens": "mångfaldigande",
    "mångfaldigandes": "mångfaldigande",
    "mångfaldigandet": "mångfaldigande",
    "mångfaldigandets": "mångfaldigande",
    "mångfaldigar": "mångfaldiga",
    "mångfaldigare": "mångfaldig",
    "mångfaldigares": "mångfaldig",
    "mångfaldigas": "mångfaldiga",
    "mångfaldigast": "mångfaldig",
    "mångfaldigaste": "mångfaldig",
    "mångfaldigastes": "mångfaldig",
    "mångfaldigasts": "mångfaldig",
    "mångfaldigat": "mångfaldiga",
    "mångfaldigats": "mångfaldiga",
    "mångfaldige": "mångfaldig",
    "mångfaldiges": "mångfaldig",
    "mångfaldigs": "mångfaldig",
    "mångfaldigt": "mångfaldig",
    "mångfaldigts": "mångfaldig",
    "mångfalds": "mångfald",
    "mångfasetterade": "mångfasetterad",
    "mångfasetterades": "mångfasetterad",
    "mångfasetterads": "mångfasetterad",
    "mångfasetterat": "mångfasetterad",
    "mångfasetterats": "mångfasetterad",
    "mångformiga": "mångformig",
    "mångformigare": "mångformig",
    "mångformigares": "mångformig",
    "mångformigas": "mångformig",
    "mångformigast": "mångformig",
    "mångformigaste": "mångformig",
    "mångformigastes": "mångformig",
    "mångformigasts": "mångformig",
    "mångformige": "mångformig",
    "mångformiges": "mångformig",
    "mångformigheten": "mångformighet",
    "mångformighetens": "mångformighet",
    "mångformigheter": "mångformighet",
    "mångformigheterna": "mångformighet",
    "mångformigheternas": "mångformighet",
    "mångformigheters": "mångformighet",
    "mångformighets": "mångformighet",
    "mångformigs": "mångformig",
    "mångformigt": "mångformig",
    "mångformigts": "mångformig",
    "mångfotingar": "mångfoting",
    "mångfotingarna": "mångfoting",
    "mångfotingarnas": "mångfoting",
    "mångfotingars": "mångfoting",
    "mångfotingen": "mångfoting",
    "mångfotingens": "mångfoting",
    "mångfotings": "mångfoting",
    "mångfrestar": "mångfrestare",
    "mångfrestaren": "mångfrestare",
    "mångfrestarens": "mångfrestare",
    "mångfrestares": "mångfrestare",
    "mångfrestarna": "mångfrestare",
    "mångfrestarnas": "mångfrestare",
    "mångfärgade": "mångfärgad",
    "mångfärgades": "mångfärgad",
    "mångfärgads": "mångfärgad",
    "mångfärgat": "mångfärgad",
    "mångfärgats": "mångfärgad",
    "månggiftes": "månggifte",
    "månggiftet": "månggifte",
    "månggiftets": "månggifte",
    "månggudadyrkans": "månggudadyrkan",
    "mångguderiet": "mångguderi",
    "mångguderiets": "mångguderi",
    "mångguderis": "mångguderi",
    "mångguderit": "mångguderi",
    "mångguderits": "mångguderi",
    "månghörningar": "månghörning",
    "månghörningarna": "månghörning",
    "månghörningarnas": "månghörning",
    "månghörningars": "månghörning",
    "månghörningen": "månghörning",
    "månghörningens": "månghörning",
    "månghörnings": "månghörning",
    "månghövdade": "månghövdad",
    "månghövdades": "månghövdad",
    "månghövdads": "månghövdad",
    "månghövdat": "månghövdad",
    "månghövdats": "månghövdad",
    "mångkampen": "mångkamp",
    "mångkampens": "mångkamp",
    "mångkamper": "mångkamp",
    "mångkamperna": "mångkamp",
    "mångkampernas": "mångkamp",
    "mångkampers": "mångkamp",
    "mångkamps": "mångkamp",
    "mångkulturella": "mångkulturell",
    "mångkulturellare": "mångkulturell",
    "mångkulturellares": "mångkulturell",
    "mångkulturellas": "mångkulturell",
    "mångkulturellast": "mångkulturell",
    "mångkulturellaste": "mångkulturell",
    "mångkulturellastes": "mångkulturell",
    "mångkulturellasts": "mångkulturell",
    "mångkulturelle": "mångkulturell",
    "mångkulturelles": "mångkulturell",
    "mångkulturells": "mångkulturell",
    "mångkulturellt": "mångkulturell",
    "mångkulturellts": "mångkulturell",
    "mångkunniga": "mångkunnig",
    "mångkunnigare": "mångkunnig",
    "mångkunnigares": "mångkunnig",
    "mångkunnigas": "mångkunnig",
    "mångkunnigast": "mångkunnig",
    "mångkunnigaste": "mångkunnig",
    "mångkunnigastes": "mångkunnig",
    "mångkunnigasts": "mångkunnig",
    "mångkunnige": "mångkunnig",
    "mångkunniges": "mångkunnig",
    "mångkunnigheten": "mångkunnighet",
    "mångkunnighetens": "mångkunnighet",
    "mångkunnighets": "mångkunnighet",
    "mångkunnigs": "mångkunnig",
    "mångkunnigt": "mångkunnig",
    "mångkunnigts": "mångkunnig",
    "månglad": "mångla",
    "månglade": "mångla",
    "månglades": "mångla",
    "månglads": "mångla",
    "månglande": "mångla",
    "månglanden": "månglande",
    "månglandena": "månglande",
    "månglandenas": "månglande",
    "månglandens": "månglande",
    "månglandes": "månglande",
    "månglandet": "månglande",
    "månglandets": "månglande",
    "månglar": "månglare",
    "månglaren": "månglare",
    "månglarens": "månglare",
    "månglares": "månglare",
    "månglarna": "månglare",
    "månglarnas": "månglare",
    "månglas": "mångla",
    "månglat": "mångla",
    "månglats": "mångla",
    "mångleriet": "mångleri",
    "mångleriets": "mångleri",
    "mångleris": "mångleri",
    "månglerit": "mångleri",
    "månglerits": "mångleri",
    "mångmiljardaffären": "mångmiljardaffär",
    "mångmiljardaffärens": "mångmiljardaffär",
    "mångmiljardaffärer": "mångmiljardaffär",
    "mångmiljardaffärerna": "mångmiljardaffär",
    "mångmiljardaffärernas": "mångmiljardaffär",
    "mångmiljardaffärers": "mångmiljardaffär",
    "mångmiljardaffärs": "mångmiljardaffär",
    "mångmiljardbeloppen": "mångmiljardbelopp",
    "mångmiljardbeloppens": "mångmiljardbelopp",
    "mångmiljardbeloppet": "mångmiljardbelopp",
    "mångmiljardbeloppets": "mångmiljardbelopp",
    "mångmiljardbelopps": "mångmiljardbelopp",
    "mångmiljoninvesteringar": "mångmiljoninvestering",
    "mångmiljoninvesteringarna": "mångmiljoninvestering",
    "mångmiljoninvesteringarnas": "mångmiljoninvestering",
    "mångmiljoninvesteringars": "mångmiljoninvestering",
    "mångmiljoninvesteringen": "mångmiljoninvestering",
    "mångmiljoninvesteringens": "mångmiljoninvestering",
    "mångmiljoninvesterings": "mångmiljoninvestering",
    "mångmiljonären": "mångmiljonär",
    "mångmiljonärens": "mångmiljonär",
    "mångmiljonärer": "mångmiljonär",
    "mångmiljonärerna": "mångmiljonär",
    "mångmiljonärernas": "mångmiljonär",
    "mångmiljonärers": "mångmiljonär",
    "mångmiljonärs": "mångmiljonär",
    "mångordiga": "mångordig",
    "mångordigare": "mångordig",
    "mångordigares": "mångordig",
    "mångordigas": "mångordig",
    "mångordigast": "mångordig",
    "mångordigaste": "mångordig",
    "mångordigastes": "mångordig",
    "mångordigasts": "mångordig",
    "mångordige": "mångordig",
    "mångordiges": "mångordig",
    "mångordigheten": "mångordighet",
    "mångordighetens": "mångordighet",
    "mångordighets": "mångordighet",
    "mångordigs": "mångordig",
    "mångordigt": "mångordig",
    "mångordigts": "mångordig",
    "mångsidiga": "mångsidig",
    "mångsidigare": "mångsidig",
    "mångsidigares": "mångsidig",
    "mångsidigas": "mångsidig",
    "mångsidigast": "mångsidig",
    "mångsidigaste": "mångsidig",
    "mångsidigastes": "mångsidig",
    "mångsidigasts": "mångsidig",
    "mångsidige": "mångsidig",
    "mångsidiges": "mångsidig",
    "mångsidigheten": "mångsidighet",
    "mångsidighetens": "mångsidighet",
    "mångsidigheter": "mångsidighet",
    "mångsidigheterna": "mångsidighet",
    "mångsidigheternas": "mångsidighet",
    "mångsidigheters": "mångsidighet",
    "mångsidighets": "mångsidighet",
    "mångsidigs": "mångsidig",
    "mångsidigt": "mångsidig",
    "mångsidigts": "mångsidig",
    "mångsidingar": "mångsiding",
    "mångsidingarna": "mångsiding",
    "mångsidingarnas": "mångsiding",
    "mångsidingars": "mångsiding",
    "mångsidingen": "mångsiding",
    "mångsidingens": "mångsiding",
    "mångsidings": "mångsiding",
    "mångskriveriet": "mångskriveri",
    "mångskriveriets": "mångskriveri",
    "mångskriveris": "mångskriveri",
    "mångskriverit": "mångskriveri",
    "mångskriverits": "mångskriveri",
    "mångspråkiga": "mångspråkig",
    "mångspråkigare": "mångspråkig",
    "mångspråkigares": "mångspråkig",
    "mångspråkigas": "mångspråkig",
    "mångspråkigast": "mångspråkig",
    "mångspråkigaste": "mångspråkig",
    "mångspråkigastes": "mångspråkig",
    "mångspråkigasts": "mångspråkig",
    "mångspråkige": "mångspråkig",
    "mångspråkiges": "mångspråkig",
    "mångspråkigheten": "mångspråkighet",
    "mångspråkighetens": "mångspråkighet",
    "mångspråkighets": "mångspråkighet",
    "mångspråkigs": "mångspråkig",
    "mångspråkigt": "mångspråkig",
    "mångspråkigts": "mångspråkig",
    "mångstaviga": "mångstavig",
    "mångstavigare": "mångstavig",
    "mångstavigares": "mångstavig",
    "mångstavigas": "mångstavig",
    "mångstavigast": "mångstavig",
    "mångstavigaste": "mångstavig",
    "mångstavigastes": "mångstavig",
    "mångstavigasts": "mångstavig",
    "mångstavige": "mångstavig",
    "mångstaviges": "mångstavig",
    "mångstavigheten": "mångstavighet",
    "mångstavighetens": "mångstavighet",
    "mångstavighets": "mångstavighet",
    "mångstavigs": "mångstavig",
    "mångstavigt": "mångstavig",
    "mångstavigts": "mångstavig",
    "mångstämmiga": "mångstämmig",
    "mångstämmigare": "mångstämmig",
    "mångstämmigares": "mångstämmig",
    "mångstämmigas": "mångstämmig",
    "mångstämmigast": "mångstämmig",
    "mångstämmigaste": "mångstämmig",
    "mångstämmigastes": "mångstämmig",
    "mångstämmigasts": "mångstämmig",
    "mångstämmige": "mångstämmig",
    "mångstämmiges": "mångstämmig",
    "mångstämmigheten": "mångstämmighet",
    "mångstämmighetens": "mångstämmighet",
    "mångstämmighets": "mångstämmighet",
    "mångstämmigs": "mångstämmig",
    "mångstämmigt": "mångstämmig",
    "mångstämmigts": "mångstämmig",
    "mångsysslar": "mångsysslare",
    "mångsysslaren": "mångsysslare",
    "mångsysslarens": "mångsysslare",
    "mångsysslares": "mångsysslare",
    "mångsysslarna": "mångsysslare",
    "mångsysslarnas": "mångsysslare",
    "mångsyssleriet": "mångsyssleri",
    "mångsyssleriets": "mångsyssleri",
    "mångsyssleris": "mångsyssleri",
    "mångsysslerit": "mångsyssleri",
    "mångsysslerits": "mångsyssleri",
    "mångt": "mången",
    "mångts": "mången",
    "mångtusenåriga": "mångtusenårig",
    "mångtusenårigas": "mångtusenårig",
    "mångtusenårige": "mångtusenårig",
    "mångtusenåriges": "mångtusenårig",
    "mångtusenårigs": "mångtusenårig",
    "mångtusenårigt": "mångtusenårig",
    "mångtusenårigts": "mångtusenårig",
    "mångtydiga": "mångtydig",
    "mångtydigare": "mångtydig",
    "mångtydigares": "mångtydig",
    "mångtydigas": "mångtydig",
    "mångtydigast": "mångtydig",
    "mångtydigaste": "mångtydig",
    "mångtydigastes": "mångtydig",
    "mångtydigasts": "mångtydig",
    "mångtydige": "mångtydig",
    "mångtydiges": "mångtydig",
    "mångtydigheten": "mångtydighet",
    "mångtydighetens": "mångtydighet",
    "mångtydigheter": "mångtydighet",
    "mångtydigheterna": "mångtydighet",
    "mångtydigheternas": "mångtydighet",
    "mångtydigheters": "mångtydighet",
    "mångtydighets": "mångtydighet",
    "mångtydigs": "mångtydig",
    "mångtydigt": "mångtydig",
    "mångtydigts": "mångtydig",
    "mångubbar": "mångubbe",
    "mångubbarna": "mångubbe",
    "mångubbarnas": "mångubbe",
    "mångubbars": "mångubbe",
    "mångubben": "mångubbe",
    "mångubbens": "mångubbe",
    "mångubbes": "mångubbe",
    "mångvetenskapliga": "mångvetenskaplig",
    "mångvetenskapligare": "mångvetenskaplig",
    "mångvetenskapligares": "mångvetenskaplig",
    "mångvetenskapligas": "mångvetenskaplig",
    "mångvetenskapligast": "mångvetenskaplig",
    "mångvetenskapligaste": "mångvetenskaplig",
    "mångvetenskapligastes": "mångvetenskaplig",
    "mångvetenskapligasts": "mångvetenskaplig",
    "mångvetenskaplige": "mångvetenskaplig",
    "mångvetenskapliges": "mångvetenskaplig",
    "mångvetenskapligheten": "mångvetenskaplighet",
    "mångvetenskaplighetens": "mångvetenskaplighet",
    "mångvetenskaplighets": "mångvetenskaplighet",
    "mångvetenskapligs": "mångvetenskaplig",
    "mångvetenskapligt": "mångvetenskaplig",
    "mångvetenskapligts": "mångvetenskaplig",
    "mångårdar": "mångård",
    "mångårdarna": "mångård",
    "mångårdarnas": "mångård",
    "mångårdars": "mångård",
    "mångården": "mångård",
    "mångårdens": "mångård",
    "mångårds": "mångård",
    "mångåriga": "mångårig",
    "mångårigas": "mångårig",
    "mångårige": "mångårig",
    "mångåriges": "mångårig",
    "mångårigs": "mångårig",
    "mångårigt": "mångårig",
    "mångårigts": "mångårig",
    "månkalendern": "månkalender",
    "månkalenderns": "månkalender",
    "månkalenders": "månkalender",
    "månkalendrar": "månkalender",
    "månkalendrarna": "månkalender",
    "månkalendrarnas": "månkalender",
    "månkalendrars": "månkalender",
    "månkratern": "månkrater",
    "månkraterns": "månkrater",
    "månkraters": "månkrater",
    "månkratrar": "månkrater",
    "månkratrarna": "månkrater",
    "månkratrarnas": "månkrater",
    "månkratrars": "månkrater",
    "månlandar": "månlandare",
    "månlandaren": "månlandare",
    "månlandarens": "månlandare",
    "månlandares": "månlandare",
    "månlandarna": "månlandare",
    "månlandarnas": "månlandare",
    "månlandningar": "månlandning",
    "månlandningarna": "månlandning",
    "månlandningarnas": "månlandning",
    "månlandningars": "månlandning",
    "månlandningen": "månlandning",
    "månlandningens": "månlandning",
    "månlandnings": "månlandning",
    "månlandskapen": "månlandskap",
    "månlandskapens": "månlandskap",
    "månlandskapet": "månlandskap",
    "månlandskapets": "månlandskap",
    "månlandskaps": "månlandskap",
    "månljusa": "månljus",
    "månljusare": "månljus",
    "månljusares": "månljus",
    "månljusas": "månljus",
    "månljusast": "månljus",
    "månljusaste": "månljus",
    "månljusastes": "månljus",
    "månljusasts": "månljus",
    "månljuse": "månljus",
    "månljuses": "månljus",
    "månljuset": "månljus",
    "månljusets": "månljus",
    "månljust": "månljus",
    "månljusts": "månljus",
    "månmarken": "månmark",
    "månmarkens": "månmark",
    "månmarks": "månmark",
    "måns": "måne",
    "månsingen": "månsing",
    "månsingens": "månsing",
    "månsings": "månsing",
    "månskenet": "månsken",
    "månskenets": "månsken",
    "månskens": "månsken",
    "månskiften": "månskifte",
    "månskiftena": "månskifte",
    "månskiftenas": "månskifte",
    "månskiftens": "månskifte",
    "månskiftes": "månskifte",
    "månskiftet": "månskifte",
    "månskiftets": "månskifte",
    "månskivan": "månskiva",
    "månskivans": "månskiva",
    "månskivas": "månskiva",
    "månskive": "månskiva",
    "månskivor": "månskiva",
    "månskivorna": "månskiva",
    "månskivornas": "månskiva",
    "månskivors": "månskiva",
    "månskugg": "månskugga",
    "månskuggan": "månskugga",
    "månskuggans": "månskugga",
    "månskuggas": "månskugga",
    "månskugge": "månskugga",
    "månskuggor": "månskugga",
    "månskuggorna": "månskugga",
    "månskuggornas": "månskugga",
    "månskuggors": "månskugga",
    "månskuggs": "månskugga",
    "månskär": "månskära",
    "månskäran": "månskära",
    "månskärans": "månskära",
    "månskäras": "månskära",
    "månskäre": "månskära",
    "månskäror": "månskära",
    "månskärorna": "månskära",
    "månskärornas": "månskära",
    "månskärors": "månskära",
    "månskärs": "månskära",
    "månstenar": "månsten",
    "månstenarna": "månsten",
    "månstenarnas": "månsten",
    "månstenars": "månsten",
    "månstenen": "månsten",
    "månstenens": "månsten",
    "månstens": "månsten",
    "månt": "mån",
    "månts": "mån",
    "månvarven": "månvarv",
    "månvarvens": "månvarv",
    "månvarvet": "månvarv",
    "månvarvets": "månvarv",
    "månvarvs": "månvarv",
    "månviolen": "månviol",
    "månviolens": "månviol",
    "månvioler": "månviol",
    "månviolerna": "månviol",
    "månviolernas": "månviol",
    "månviolers": "månviol",
    "månviols": "månviol",
    "månåren": "månår",
    "månårens": "månår",
    "månåret": "månår",
    "månårets": "månår",
    "månårs": "månår",
    "mår": "måra",
    "måran": "måra",
    "mårans": "måra",
    "måras": "måra",
    "mårdar": "mård",
    "mårdarna": "mård",
    "mårdarnas": "mård",
    "mårdars": "mård",
    "mårddjuren": "mårddjur",
    "mårddjurens": "mårddjur",
    "mårddjuret": "mårddjur",
    "mårddjurets": "mårddjur",
    "mårddjurs": "mårddjur",
    "mården": "mård",
    "mårdens": "mård",
    "mårds": "mård",
    "måre": "måra",
    "måren": "mår",
    "mårens": "mår",
    "måror": "måra",
    "mårorna": "måra",
    "mårornas": "måra",
    "mårors": "måra",
    "mårs": "måra",
    "mårtens": "mårten",
    "mås": "må",
    "måsar": "mås",
    "måsarna": "mås",
    "måsarnas": "mås",
    "måsars": "mås",
    "måsen": "mås",
    "måsens": "mås",
    "måsfågeln": "måsfågel",
    "måsfågelns": "måsfågel",
    "måsfågels": "måsfågel",
    "måsfåglar": "måsfågel",
    "måsfåglarna": "måsfågel",
    "måsfåglarnas": "måsfågel",
    "måsfåglars": "måsfågel",
    "måst": "måste",
    "måsta": "måste",
    "måstande": "måste",
    "måstandes": "måste",
    "måsten": "måste",
    "måstena": "måste",
    "måstenas": "måste",
    "måstens": "måste",
    "måstes": "måste",
    "måstet": "måste",
    "måstets": "måste",
    "måsäggen": "måsägg",
    "måsäggens": "måsägg",
    "måsägget": "måsägg",
    "måsäggets": "måsägg",
    "måsäggs": "måsägg",
    "mått": "måtta",
    "måttad": "måtta",
    "måttade": "måtta",
    "måttades": "måtta",
    "måttads": "måtta",
    "måttagningar": "måttagning",
    "måttagningarna": "måttagning",
    "måttagningarnas": "måttagning",
    "måttagningars": "måttagning",
    "måttagningen": "måttagning",
    "måttagningens": "måttagning",
    "måttagnings": "måttagning",
    "måttan": "måtta",
    "måttande": "måtta",
    "måttanden": "måttande",
    "måttandena": "måttande",
    "måttandenas": "måttande",
    "måttandens": "måttande",
    "måttandes": "måttande",
    "måttandet": "måttande",
    "måttandets": "måttande",
    "måttans": "måtta",
    "måttar": "måtta",
    "måttas": "måtta",
    "måttat": "måtta",
    "måttats": "måtta",
    "måttbanden": "måttband",
    "måttbandens": "måttband",
    "måttbandet": "måttband",
    "måttbandets": "måttband",
    "måttbands": "måttband",
    "måttbeställda": "måttbeställd",
    "måttbeställdare": "måttbeställd",
    "måttbeställdares": "måttbeställd",
    "måttbeställdas": "måttbeställd",
    "måttbeställdast": "måttbeställd",
    "måttbeställdaste": "måttbeställd",
    "måttbeställdastes": "måttbeställd",
    "måttbeställdasts": "måttbeställd",
    "måttbeställde": "måttbeställd",
    "måttbeställdes": "måttbeställd",
    "måttbeställds": "måttbeställd",
    "måttbeställt": "måttbeställd",
    "måttbeställts": "måttbeställd",
    "måtte": "må",
    "måtten": "mått",
    "måttenheten": "måttenhet",
    "måttenhetens": "måttenhet",
    "måttenheter": "måttenhet",
    "måttenheterna": "måttenhet",
    "måttenheternas": "måttenhet",
    "måttenheters": "måttenhet",
    "måttenhets": "måttenhet",
    "måttens": "mått",
    "måttes": "må",
    "måttet": "mått",
    "måttets": "mått",
    "måttfulla": "måttfull",
    "måttfullare": "måttfull",
    "måttfullares": "måttfull",
    "måttfullas": "måttfull",
    "måttfullast": "måttfull",
    "måttfullaste": "måttfull",
    "måttfullastes": "måttfull",
    "måttfullasts": "måttfull",
    "måttfulle": "måttfull",
    "måttfulles": "måttfull",
    "måttfullheten": "måttfullhet",
    "måttfullhetens": "måttfullhet",
    "måttfullhets": "måttfullhet",
    "måttfulls": "måttfull",
    "måttfullt": "måttfull",
    "måttfullts": "måttfull",
    "måttliga": "måttlig",
    "måttligare": "måttlig",
    "måttligares": "måttlig",
    "måttligas": "måttlig",
    "måttligast": "måttlig",
    "måttligaste": "måttlig",
    "måttligastes": "måttlig",
    "måttligasts": "måttlig",
    "måttlige": "måttlig",
    "måttliges": "måttlig",
    "måttligheten": "måttlighet",
    "måttlighetens": "måttlighet",
    "måttlighets": "måttlighet",
    "måttligs": "måttlig",
    "måttligt": "måttlig",
    "måttligts": "måttlig",
    "måttlösa": "måttlös",
    "måttlösare": "måttlös",
    "måttlösares": "måttlös",
    "måttlösas": "måttlös",
    "måttlösast": "måttlös",
    "måttlösaste": "måttlös",
    "måttlösastes": "måttlös",
    "måttlösasts": "måttlös",
    "måttlöse": "måttlös",
    "måttlöses": "måttlös",
    "måttlösheten": "måttlöshet",
    "måttlöshetens": "måttlöshet",
    "måttlöshets": "måttlöshet",
    "måttlöst": "måttlös",
    "måttlösts": "måttlös",
    "måtts": "mått",
    "måttsatsen": "måttsats",
    "måttsatsens": "måttsats",
    "måttsatser": "måttsats",
    "måttsatserna": "måttsats",
    "måttsatsernas": "måttsats",
    "måttsatsers": "måttsats",
    "måttsenheten": "måttsenhet",
    "måttsenhetens": "måttsenhet",
    "måttsenheter": "måttsenhet",
    "måttsenheterna": "måttsenhet",
    "måttsenheternas": "måttsenhet",
    "måttsenheters": "måttsenhet",
    "måttsenhets": "måttsenhet",
    "måttstockar": "måttstock",
    "måttstockarna": "måttstock",
    "måttstockarnas": "måttstock",
    "måttstockars": "måttstock",
    "måttstocken": "måttstock",
    "måttstockens": "måttstock",
    "måttstocks": "måttstock",
    "måttsydda": "måttsydd",
    "måttsyddare": "måttsydd",
    "måttsyddares": "måttsydd",
    "måttsyddas": "måttsydd",
    "måttsyddast": "måttsydd",
    "måttsyddaste": "måttsydd",
    "måttsyddastes": "måttsydd",
    "måttsyddasts": "måttsydd",
    "måttsydde": "måttsydd",
    "måttsyddes": "måttsydd",
    "måttsydds": "måttsydd",
    "måttsystemen": "måttsystem",
    "måttsystemens": "måttsystem",
    "måttsystemet": "måttsystem",
    "måttsystemets": "måttsystem",
    "måttsystems": "måttsystem",
    "måttsytt": "måttsydd",
    "måttsytts": "måttsydd",
    "måttverktygen": "måttverktyg",
    "måttverktygens": "måttverktyg",
    "måttverktyget": "måttverktyg",
    "måttverktygets": "måttverktyg",
    "måttverktygs": "måttverktyg",
    "möbelbussar": "möbelbuss",
    "möbelbussarna": "möbelbuss",
    "möbelbussarnas": "möbelbuss",
    "möbelbussars": "möbelbuss",
    "möbelbussen": "möbelbuss",
    "möbelbussens": "möbelbuss",
    "möbelfirman": "möbelfirma",
    "möbelfirmans": "möbelfirma",
    "möbelfirmas": "möbelfirma",
    "möbelfirme": "möbelfirma",
    "möbelfirmor": "möbelfirma",
    "möbelfirmorna": "möbelfirma",
    "möbelfirmornas": "möbelfirma",
    "möbelfirmors": "möbelfirma",
    "möbelflyttningar": "möbelflyttning",
    "möbelflyttningarna": "möbelflyttning",
    "möbelflyttningarnas": "möbelflyttning",
    "möbelflyttningars": "möbelflyttning",
    "möbelflyttningen": "möbelflyttning",
    "möbelflyttningens": "möbelflyttning",
    "möbelflyttnings": "möbelflyttning",
    "möbelfoten": "möbelfot",
    "möbelfotens": "möbelfot",
    "möbelfots": "möbelfot",
    "möbelföretagen": "möbelföretag",
    "möbelföretagens": "möbelföretag",
    "möbelföretaget": "möbelföretag",
    "möbelföretagets": "möbelföretag",
    "möbelföretags": "möbelföretag",
    "möbelförsäljningar": "möbelförsäljning",
    "möbelförsäljningarna": "möbelförsäljning",
    "möbelförsäljningarnas": "möbelförsäljning",
    "möbelförsäljningars": "möbelförsäljning",
    "möbelförsäljningen": "möbelförsäljning",
    "möbelförsäljningens": "möbelförsäljning",
    "möbelförsäljnings": "möbelförsäljning",
    "möbelfötter": "möbelfot",
    "möbelfötterna": "möbelfot",
    "möbelfötternas": "möbelfot",
    "möbelfötters": "möbelfot",
    "möbeljättar": "möbeljätte",
    "möbeljättarna": "möbeljätte",
    "möbeljättarnas": "möbeljätte",
    "möbeljättars": "möbeljätte",
    "möbeljätten": "möbeljätte",
    "möbeljättens": "möbeljätte",
    "möbeljättes": "möbeljätte",
    "möbelklädseln": "möbelklädsel",
    "möbelklädselns": "möbelklädsel",
    "möbelklädsels": "möbelklädsel",
    "möbelklädslar": "möbelklädsel",
    "möbelklädslarna": "möbelklädsel",
    "möbelklädslarnas": "möbelklädsel",
    "möbelklädslars": "möbelklädsel",
    "möbelmäss": "möbelmässa",
    "möbelmässan": "möbelmässa",
    "möbelmässans": "möbelmässa",
    "möbelmässas": "möbelmässa",
    "möbelmässe": "möbelmässa",
    "möbelmässor": "möbelmässa",
    "möbelmässorna": "möbelmässa",
    "möbelmässornas": "möbelmässa",
    "möbelmässors": "möbelmässa",
    "möbeln": "möbel",
    "möbelns": "möbel",
    "möbels": "möbel",
    "möbelsnickar": "möbelsnickare",
    "möbelsnickaren": "möbelsnickare",
    "möbelsnickarens": "möbelsnickare",
    "möbelsnickares": "möbelsnickare",
    "möbelsnickarna": "möbelsnickare",
    "möbelsnickarnas": "möbelsnickare",
    "möbelsnickerier": "möbelsnickeri",
    "möbelsnickerierna": "möbelsnickeri",
    "möbelsnickeriernas": "möbelsnickeri",
    "möbelsnickeriers": "möbelsnickeri",
    "möbelsnickeriet": "möbelsnickeri",
    "möbelsnickeriets": "möbelsnickeri",
    "möbelsnickeris": "möbelsnickeri",
    "möbelsnickerit": "möbelsnickeri",
    "möbelsnickerits": "möbelsnickeri",
    "möbelspikar": "möbelspik",
    "möbelspikarna": "möbelspik",
    "möbelspikarnas": "möbelspik",
    "möbelspikars": "möbelspik",
    "möbelspiken": "möbelspik",
    "möbelspikens": "möbelspik",
    "möbelspiks": "möbelspik",
    "möbelstilar": "möbelstil",
    "möbelstilarna": "möbelstil",
    "möbelstilarnas": "möbelstil",
    "möbelstilars": "möbelstil",
    "möbelstilen": "möbelstil",
    "möbelstilens": "möbelstil",
    "möbelstils": "möbelstil",
    "möbeltassar": "möbeltass",
    "möbeltassarna": "möbeltass",
    "möbeltassarnas": "möbeltass",
    "möbeltassars": "möbeltass",
    "möbeltassen": "möbeltass",
    "möbeltassens": "möbeltass",
    "möbeltriss": "möbeltrissa",
    "möbeltrissan": "möbeltrissa",
    "möbeltrissans": "möbeltrissa",
    "möbeltrissas": "möbeltrissa",
    "möbeltrisse": "möbeltrissa",
    "möbeltrissor": "möbeltrissa",
    "möbeltrissorna": "möbeltrissa",
    "möbeltrissornas": "möbeltrissa",
    "möbeltrissors": "möbeltrissa",
    "möbeltygen": "möbeltyg",
    "möbeltygens": "möbeltyg",
    "möbeltyger": "möbeltyg",
    "möbeltygerna": "möbeltyg",
    "möbeltygernas": "möbeltyg",
    "möbeltygers": "möbeltyg",
    "möbeltyget": "möbeltyg",
    "möbeltygets": "möbeltyg",
    "möbeltygs": "möbeltyg",
    "möbelvaruhusen": "möbelvaruhus",
    "möbelvaruhusens": "möbelvaruhus",
    "möbelvaruhuset": "möbelvaruhus",
    "möbelvaruhusets": "möbelvaruhus",
    "möbelvinkeln": "möbelvinkel",
    "möbelvinkelns": "möbelvinkel",
    "möbelvinkels": "möbelvinkel",
    "möbelvinklar": "möbelvinkel",
    "möbelvinklarna": "möbelvinkel",
    "möbelvinklarnas": "möbelvinkel",
    "möbelvinklars": "möbelvinkel",
    "möbelöverdragen": "möbelöverdrag",
    "möbelöverdragens": "möbelöverdrag",
    "möbelöverdraget": "möbelöverdrag",
    "möbelöverdragets": "möbelöverdrag",
    "möbelöverdrags": "möbelöverdrag",
    "möblemangen": "möblemang",
    "möblemangens": "möblemang",
    "möblemanger": "möblemang",
    "möblemangerna": "möblemang",
    "möblemangernas": "möblemang",
    "möblemangers": "möblemang",
    "möblemanget": "möblemang",
    "möblemangets": "möblemang",
    "möblemangs": "möblemang",
    "möbler": "möbel",
    "möblerad": "möblera",
    "möblerade": "möblera",
    "möblerades": "möblera",
    "möblerads": "möblera",
    "möblerande": "möblera",
    "möbleranden": "möblerande",
    "möblerandena": "möblerande",
    "möblerandenas": "möblerande",
    "möblerandens": "möblerande",
    "möblerandes": "möblerande",
    "möblerandet": "möblerande",
    "möblerandets": "möblerande",
    "möblerar": "möblera",
    "möbleras": "möblera",
    "möblerat": "möblera",
    "möblerats": "möblera",
    "möblerbara": "möblerbar",
    "möblerbarare": "möblerbar",
    "möblerbarares": "möblerbar",
    "möblerbaras": "möblerbar",
    "möblerbarast": "möblerbar",
    "möblerbaraste": "möblerbar",
    "möblerbarastes": "möblerbar",
    "möblerbarasts": "möblerbar",
    "möblerbare": "möblerbar",
    "möblerbares": "möblerbar",
    "möblerbarheten": "möblerbarhet",
    "möblerbarhetens": "möblerbarhet",
    "möblerbarhets": "möblerbarhet",
    "möblerbars": "möblerbar",
    "möblerbart": "möblerbar",
    "möblerbarts": "möblerbar",
    "möbleringar": "möblering",
    "möbleringarna": "möblering",
    "möbleringarnas": "möblering",
    "möbleringars": "möblering",
    "möbleringen": "möblering",
    "möbleringens": "möblering",
    "möblerings": "möblering",
    "möblerna": "möbel",
    "möblernas": "möbel",
    "möblers": "möbel",
    "möd": "möda",
    "mödan": "möda",
    "mödans": "möda",
    "mödas": "möda",
    "möde": "möda",
    "mödernes": "möderne",
    "mödernet": "möderne",
    "mödernets": "möderne",
    "mödo": "möda",
    "mödofyllda": "mödofylld",
    "mödofylldare": "mödofylld",
    "mödofylldares": "mödofylld",
    "mödofylldas": "mödofylld",
    "mödofylldast": "mödofylld",
    "mödofylldaste": "mödofylld",
    "mödofylldastes": "mödofylld",
    "mödofylldasts": "mödofylld",
    "mödofyllde": "mödofylld",
    "mödofylldes": "mödofylld",
    "mödofyllds": "mödofylld",
    "mödofyllt": "mödofylld",
    "mödofyllts": "mödofylld",
    "mödomar": "mödom",
    "mödomarna": "mödom",
    "mödomarnas": "mödom",
    "mödomars": "mödom",
    "mödomen": "mödom",
    "mödomens": "mödom",
    "mödoms": "mödom",
    "mödomshinnan": "mödomshinna",
    "mödomshinnans": "mödomshinna",
    "mödomshinnas": "mödomshinna",
    "mödomshinne": "mödomshinna",
    "mödomshinnor": "mödomshinna",
    "mödomshinnorna": "mödomshinna",
    "mödomshinnornas": "mödomshinna",
    "mödomshinnors": "mödomshinna",
    "mödor": "möda",
    "mödorna": "möda",
    "mödornas": "möda",
    "mödors": "möda",
    "mödosamheten": "mödosamhet",
    "mödosamhetens": "mödosamhet",
    "mödosamhets": "mödosamhet",
    "mödosamma": "mödosam",
    "mödosammare": "mödosam",
    "mödosammares": "mödosam",
    "mödosammas": "mödosam",
    "mödosammast": "mödosam",
    "mödosammaste": "mödosam",
    "mödosammastes": "mödosam",
    "mödosammasts": "mödosam",
    "mödosamme": "mödosam",
    "mödosammes": "mödosam",
    "mödosams": "mödosam",
    "mödosamt": "mödosam",
    "mödosamts": "mödosam",
    "mödrar": "mor",
    "mödrarna": "mor",
    "mödrarnas": "mor",
    "mödrars": "mor",
    "mödravården": "mödravård",
    "mödravårdens": "mödravård",
    "mödravårds": "mödravård",
    "mödravårdscentralen": "mödravårdscentral",
    "mödravårdscentralens": "mödravårdscentral",
    "mödravårdscentraler": "mödravårdscentral",
    "mödravårdscentralerna": "mödravårdscentral",
    "mödravårdscentralernas": "mödravårdscentral",
    "mödravårdscentralers": "mödravårdscentral",
    "mödravårdscentrals": "mödravårdscentral",
    "möds": "möda",
    "mögel": "mögla",
    "mögelhundar": "mögelhund",
    "mögelhundarna": "mögelhund",
    "mögelhundarnas": "mögelhund",
    "mögelhundars": "mögelhund",
    "mögelhunden": "mögelhund",
    "mögelhundens": "mögelhund",
    "mögelhunds": "mögelhund",
    "mögelostar": "mögelost",
    "mögelostarna": "mögelost",
    "mögelostarnas": "mögelost",
    "mögelostars": "mögelost",
    "mögelosten": "mögelost",
    "mögelostens": "mögelost",
    "mögelosts": "mögelost",
    "mögels": "mögel",
    "mögelsvampar": "mögelsvamp",
    "mögelsvamparna": "mögelsvamp",
    "mögelsvamparnas": "mögelsvamp",
    "mögelsvampars": "mögelsvamp",
    "mögelsvampen": "mögelsvamp",
    "mögelsvampens": "mögelsvamp",
    "mögelsvamps": "mögelsvamp",
    "mögeltrådar": "mögeltråd",
    "mögeltrådarna": "mögeltråd",
    "mögeltrådarnas": "mögeltråd",
    "mögeltrådars": "mögeltråd",
    "mögeltråden": "mögeltråd",
    "mögeltrådens": "mögeltråd",
    "mögeltråds": "mögeltråd",
    "mögeltvätten": "mögeltvätt",
    "mögeltvättens": "mögeltvätt",
    "mögeltvätts": "mögeltvätt",
    "möglade": "mögla",
    "möglades": "mögla",
    "möglande": "mögla",
    "möglanden": "möglande",
    "möglandena": "möglande",
    "möglandenas": "möglande",
    "möglandens": "möglande",
    "möglandes": "möglande",
    "möglandet": "möglande",
    "möglandets": "möglande",
    "möglar": "mögla",
    "möglas": "mögla",
    "möglat": "mögla",
    "möglats": "mögla",
    "möglet": "mögel",
    "möglets": "mögel",
    "mögliga": "möglig",
    "mögligare": "möglig",
    "mögligares": "möglig",
    "mögligas": "möglig",
    "mögligast": "möglig",
    "mögligaste": "möglig",
    "mögligastes": "möglig",
    "mögligasts": "möglig",
    "möglige": "möglig",
    "mögliges": "möglig",
    "mögligheten": "möglighet",
    "möglighetens": "möglighet",
    "möglighets": "möglighet",
    "mögligs": "möglig",
    "mögligt": "möglig",
    "mögligts": "möglig",
    "möhipp": "möhippa",
    "möhippan": "möhippa",
    "möhippans": "möhippa",
    "möhippas": "möhippa",
    "möhippe": "möhippa",
    "möhippor": "möhippa",
    "möhipporna": "möhippa",
    "möhippornas": "möhippa",
    "möhippors": "möhippa",
    "möhipps": "möhippa",
    "möjliga": "möjlig",
    "möjligare": "möjlig",
    "möjligares": "möjlig",
    "möjligas": "möjlig",
    "möjligast": "möjlig",
    "möjligaste": "möjlig",
    "möjligastes": "möjlig",
    "möjligasts": "möjlig",
    "möjlige": "möjlig",
    "möjliges": "möjlig",
    "möjliggjord": "möjliggöra",
    "möjliggjorda": "möjliggöra",
    "möjliggjordas": "möjliggöra",
    "möjliggjorde": "möjliggöra",
    "möjliggjordes": "möjliggöra",
    "möjliggjords": "möjliggöra",
    "möjliggjort": "möjliggöra",
    "möjliggjorts": "möjliggöra",
    "möjliggör": "möjliggöra",
    "möjliggörande": "möjliggöra",
    "möjliggöranden": "möjliggörande",
    "möjliggörandena": "möjliggörande",
    "möjliggörandenas": "möjliggörande",
    "möjliggörandens": "möjliggörande",
    "möjliggörandes": "möjliggörande",
    "möjliggörandet": "möjliggörande",
    "möjliggörandets": "möjliggörande",
    "möjliggöras": "möjliggöra",
    "möjliggöres": "möjliggöra",
    "möjliggörs": "möjliggöra",
    "möjligheten": "möjlighet",
    "möjlighetens": "möjlighet",
    "möjligheter": "möjlighet",
    "möjligheterna": "möjlighet",
    "möjligheternas": "möjlighet",
    "möjligheters": "möjlighet",
    "möjlighets": "möjlighet",
    "möjligs": "möjlig",
    "möjligt": "möjlig",
    "möjligts": "möjlig",
    "möll": "mölla",
    "möllan": "mölla",
    "möllans": "mölla",
    "möllas": "mölla",
    "mölle": "mölla",
    "möllor": "mölla",
    "möllorna": "mölla",
    "möllornas": "mölla",
    "möllors": "mölla",
    "mölls": "mölla",
    "mön": "mö",
    "mönjan": "mönja",
    "mönjans": "mönja",
    "mönjas": "mönja",
    "mönjefärgen": "mönjefärg",
    "mönjefärgens": "mönjefärg",
    "mönjefärger": "mönjefärg",
    "mönjefärgerna": "mönjefärg",
    "mönjefärgernas": "mönjefärg",
    "mönjefärgers": "mönjefärg",
    "mönjefärgs": "mönjefärg",
    "möns": "mö",
    "mönsterboken": "mönsterbok",
    "mönsterbokens": "mönsterbok",
    "mönsterboks": "mönsterbok",
    "mönsterböcker": "mönsterbok",
    "mönsterböckerna": "mönsterbok",
    "mönsterböckernas": "mönsterbok",
    "mönsterböckers": "mönsterbok",
    "mönsterdjupen": "mönsterdjup",
    "mönsterdjupens": "mönsterdjup",
    "mönsterdjupet": "mönsterdjup",
    "mönsterdjupets": "mönsterdjup",
    "mönsterdjups": "mönsterdjup",
    "mönstergarnen": "mönstergarn",
    "mönstergarnens": "mönstergarn",
    "mönstergarner": "mönstergarn",
    "mönstergarnerna": "mönstergarn",
    "mönstergarnernas": "mönstergarn",
    "mönstergarners": "mönstergarn",
    "mönstergarnet": "mönstergarn",
    "mönstergarnets": "mönstergarn",
    "mönstergarns": "mönstergarn",
    "mönstergilla": "mönstergill",
    "mönstergillare": "mönstergill",
    "mönstergillares": "mönstergill",
    "mönstergillas": "mönstergill",
    "mönstergillast": "mönstergill",
    "mönstergillaste": "mönstergill",
    "mönstergillastes": "mönstergill",
    "mönstergillasts": "mönstergill",
    "mönstergille": "mönstergill",
    "mönstergilles": "mönstergill",
    "mönstergillheten": "mönstergillhet",
    "mönstergillhetens": "mönstergillhet",
    "mönstergillhets": "mönstergillhet",
    "mönstergills": "mönstergill",
    "mönstergillt": "mönstergill",
    "mönstergillts": "mönstergill",
    "mönstergoss": "mönstergosse",
    "mönstergossar": "mönstergosse",
    "mönstergossarna": "mönstergosse",
    "mönstergossarnas": "mönstergosse",
    "mönstergossars": "mönstergosse",
    "mönstergossen": "mönstergosse",
    "mönstergossens": "mönstergosse",
    "mönstergosses": "mönstergosse",
    "mönstergårdar": "mönstergård",
    "mönstergårdarna": "mönstergård",
    "mönstergårdarnas": "mönstergård",
    "mönstergårdars": "mönstergård",
    "mönstergården": "mönstergård",
    "mönstergårdens": "mönstergård",
    "mönstergårds": "mönstergård",
    "mönsterjordbruken": "mönsterjordbruk",
    "mönsterjordbrukens": "mönsterjordbruk",
    "mönsterjordbruket": "mönsterjordbruk",
    "mönsterjordbrukets": "mönsterjordbruk",
    "mönsterjordbruks": "mönsterjordbruk",
    "mönsterkart": "mönsterkarta",
    "mönsterkartan": "mönsterkarta",
    "mönsterkartans": "mönsterkarta",
    "mönsterkartas": "mönsterkarta",
    "mönsterkarte": "mönsterkarta",
    "mönsterkartor": "mönsterkarta",
    "mönsterkartorna": "mönsterkarta",
    "mönsterkartornas": "mönsterkarta",
    "mönsterkartors": "mönsterkarta",
    "mönsterkarts": "mönsterkarta",
    "mönsterna": "mönster",
    "mönsternas": "mönster",
    "mönsters": "mönster",
    "mönstersamhällen": "mönstersamhälle",
    "mönstersamhällena": "mönstersamhälle",
    "mönstersamhällenas": "mönstersamhälle",
    "mönstersamhällens": "mönstersamhälle",
    "mönstersamhälles": "mönstersamhälle",
    "mönstersamhället": "mönstersamhälle",
    "mönstersamhällets": "mönstersamhälle",
    "mönstersamhälls": "mönstersamhälle",
    "mönsterskydden": "mönsterskydd",
    "mönsterskyddens": "mönsterskydd",
    "mönsterskyddet": "mönsterskydd",
    "mönsterskyddets": "mönsterskydd",
    "mönsterskydds": "mönsterskydd",
    "mönsterstickade": "mönsterstickad",
    "mönsterstickades": "mönsterstickad",
    "mönsterstickads": "mönsterstickad",
    "mönsterstickat": "mönsterstickad",
    "mönsterstickats": "mönsterstickad",
    "mönstervävda": "mönstervävd",
    "mönstervävdare": "mönstervävd",
    "mönstervävdares": "mönstervävd",
    "mönstervävdas": "mönstervävd",
    "mönstervävdast": "mönstervävd",
    "mönstervävdaste": "mönstervävd",
    "mönstervävdastes": "mönstervävd",
    "mönstervävdasts": "mönstervävd",
    "mönstervävde": "mönstervävd",
    "mönstervävdes": "mönstervävd",
    "mönstervävds": "mönstervävd",
    "mönstervävt": "mönstervävd",
    "mönstervävts": "mönstervävd",
    "mönstrad": "mönstra",
    "mönstrade": "mönstra",
    "mönstrades": "mönstra",
    "mönstrads": "mönstra",
    "mönstrande": "mönstra",
    "mönstranden": "mönstrande",
    "mönstrandena": "mönstrande",
    "mönstrandenas": "mönstrande",
    "mönstrandens": "mönstrande",
    "mönstrandes": "mönstrande",
    "mönstrandet": "mönstrande",
    "mönstrandets": "mönstrande",
    "mönstrar": "mönstra",
    "mönstras": "mönstra",
    "mönstrat": "mönstra",
    "mönstrats": "mönstra",
    "mönstren": "mönster",
    "mönstrens": "mönster",
    "mönstret": "mönster",
    "mönstrets": "mönster",
    "mönstringar": "mönstring",
    "mönstringarna": "mönstring",
    "mönstringarnas": "mönstring",
    "mönstringars": "mönstring",
    "mönstringen": "mönstring",
    "mönstringens": "mönstring",
    "mönstrings": "mönstring",
    "mönstringsbevisen": "mönstringsbevis",
    "mönstringsbevisens": "mönstringsbevis",
    "mönstringsbeviset": "mönstringsbevis",
    "mönstringsbevisets": "mönstringsbevis",
    "mönstringsexpeditionen": "mönstringsexpedition",
    "mönstringsexpeditionens": "mönstringsexpedition",
    "mönstringsexpeditioner": "mönstringsexpedition",
    "mönstringsexpeditionerna": "mönstringsexpedition",
    "mönstringsexpeditionernas": "mönstringsexpedition",
    "mönstringsexpeditioners": "mönstringsexpedition",
    "mönstringsexpeditions": "mönstringsexpedition",
    "mönstringsliggar": "mönstringsliggare",
    "mönstringsliggaren": "mönstringsliggare",
    "mönstringsliggarens": "mönstringsliggare",
    "mönstringsliggares": "mönstringsliggare",
    "mönstringsliggarna": "mönstringsliggare",
    "mönstringsliggarnas": "mönstringsliggare",
    "mör": "möra",
    "möra": "mör",
    "mörad": "möra",
    "mörade": "möra",
    "mörades": "möra",
    "mörads": "möra",
    "mörande": "möra",
    "möranden": "mörande",
    "mörandena": "mörande",
    "mörandenas": "mörande",
    "mörandens": "mörande",
    "mörandes": "mörande",
    "mörandet": "mörande",
    "mörandets": "mörande",
    "mörar": "möra",
    "mörare": "mör",
    "mörares": "mör",
    "möras": "möra",
    "mörast": "mör",
    "möraste": "mör",
    "mörastes": "mör",
    "mörasts": "mör",
    "mörat": "möra",
    "mörats": "möra",
    "mörbult": "mörbulta",
    "mörbultad": "mörbulta",
    "mörbultade": "mörbulta",
    "mörbultades": "mörbulta",
    "mörbultads": "mörbulta",
    "mörbultande": "mörbulta",
    "mörbultanden": "mörbultande",
    "mörbultandena": "mörbultande",
    "mörbultandenas": "mörbultande",
    "mörbultandens": "mörbultande",
    "mörbultandes": "mörbultande",
    "mörbultandet": "mörbultande",
    "mörbultandets": "mörbultande",
    "mörbultar": "mörbulta",
    "mörbultas": "mörbulta",
    "mörbultat": "mörbulta",
    "mörbultats": "mörbulta",
    "mörd": "mörda",
    "mördad": "mörda",
    "mördade": "mörda",
    "mördades": "mörda",
    "mördads": "mörda",
    "mördande": "mörda",
    "mördanden": "mördande",
    "mördandena": "mördande",
    "mördandenas": "mördande",
    "mördandens": "mördande",
    "mördandes": "mördande",
    "mördandet": "mördande",
    "mördandets": "mördande",
    "mördar": "mördare",
    "mördaren": "mördare",
    "mördarens": "mördare",
    "mördares": "mördare",
    "mördarhundar": "mördarhund",
    "mördarhundarna": "mördarhund",
    "mördarhundarnas": "mördarhund",
    "mördarhundars": "mördarhund",
    "mördarhunden": "mördarhund",
    "mördarhundens": "mördarhund",
    "mördarhunds": "mördarhund",
    "mördarjakten": "mördarjakt",
    "mördarjaktens": "mördarjakt",
    "mördarjakter": "mördarjakt",
    "mördarjakterna": "mördarjakt",
    "mördarjakternas": "mördarjakt",
    "mördarjakters": "mördarjakt",
    "mördarjakts": "mördarjakt",
    "mördarna": "mördare",
    "mördarnas": "mördare",
    "mördas": "mörda",
    "mördat": "mörda",
    "mördats": "mörda",
    "mördegar": "mördeg",
    "mördegarna": "mördeg",
    "mördegarnas": "mördeg",
    "mördegars": "mördeg",
    "mördegen": "mördeg",
    "mördegens": "mördeg",
    "mördegs": "mördeg",
    "möre": "mör",
    "möres": "mör",
    "mörheten": "mörhet",
    "mörhetens": "mörhet",
    "mörhets": "mörhet",
    "mörjan": "mörja",
    "mörjans": "mörja",
    "mörjas": "mörja",
    "mörjiga": "mörjig",
    "mörjigare": "mörjig",
    "mörjigares": "mörjig",
    "mörjigas": "mörjig",
    "mörjigast": "mörjig",
    "mörjigaste": "mörjig",
    "mörjigastes": "mörjig",
    "mörjigasts": "mörjig",
    "mörjige": "mörjig",
    "mörjiges": "mörjig",
    "mörjigheten": "mörjighet",
    "mörjighetens": "mörjighet",
    "mörjighets": "mörjighet",
    "mörjigs": "mörjig",
    "mörjigt": "mörjig",
    "mörjigts": "mörjig",
    "mörka": "mörk",
    "mörkad": "mörka",
    "mörkade": "mörka",
    "mörkades": "mörka",
    "mörkads": "mörka",
    "mörkalfen": "mörkalf",
    "mörkalfens": "mörkalf",
    "mörkalfer": "mörkalf",
    "mörkalferna": "mörkalf",
    "mörkalfernas": "mörkalf",
    "mörkalfers": "mörkalf",
    "mörkalfs": "mörkalf",
    "mörkalven": "mörkalv",
    "mörkalvens": "mörkalv",
    "mörkalver": "mörkalv",
    "mörkalverna": "mörkalv",
    "mörkalvernas": "mörkalv",
    "mörkalvers": "mörkalv",
    "mörkalvs": "mörkalv",
    "mörkande": "mörka",
    "mörkanden": "mörkande",
    "mörkandena": "mörkande",
    "mörkandenas": "mörkande",
    "mörkandens": "mörkande",
    "mörkandes": "mörkande",
    "mörkandet": "mörkande",
    "mörkandets": "mörkande",
    "mörkar": "mörka",
    "mörkare": "mörk",
    "mörkares": "mörk",
    "mörkas": "mörka",
    "mörkast": "mörk",
    "mörkaste": "mörk",
    "mörkastes": "mörk",
    "mörkasts": "mörk",
    "mörkat": "mörka",
    "mörkats": "mörka",
    "mörkblonda": "mörkblond",
    "mörkblondare": "mörkblond",
    "mörkblondares": "mörkblond",
    "mörkblondas": "mörkblond",
    "mörkblondast": "mörkblond",
    "mörkblondaste": "mörkblond",
    "mörkblondastes": "mörkblond",
    "mörkblondasts": "mörkblond",
    "mörkblonde": "mörkblond",
    "mörkblondes": "mörkblond",
    "mörkblondheten": "mörkblondhet",
    "mörkblondhetens": "mörkblondhet",
    "mörkblondhets": "mörkblondhet",
    "mörkblonds": "mörkblond",
    "mörkblont": "mörkblond",
    "mörkblonts": "mörkblond",
    "mörkblåa": "mörkblå",
    "mörkblåare": "mörkblå",
    "mörkblåares": "mörkblå",
    "mörkblåas": "mörkblå",
    "mörkblåast": "mörkblå",
    "mörkblåaste": "mörkblå",
    "mörkblåastes": "mörkblå",
    "mörkblåasts": "mörkblå",
    "mörkblåe": "mörkblå",
    "mörkblåes": "mörkblå",
    "mörkblås": "mörkblå",
    "mörkblått": "mörkblå",
    "mörkblåtts": "mörkblå",
    "mörkbruna": "mörkbrun",
    "mörkbrunare": "mörkbrun",
    "mörkbrunares": "mörkbrun",
    "mörkbrunas": "mörkbrun",
    "mörkbrunast": "mörkbrun",
    "mörkbrunaste": "mörkbrun",
    "mörkbrunastes": "mörkbrun",
    "mörkbrunasts": "mörkbrun",
    "mörkbrune": "mörkbrun",
    "mörkbrunes": "mörkbrun",
    "mörkbruns": "mörkbrun",
    "mörkbrunt": "mörkbrun",
    "mörkbrunts": "mörkbrun",
    "mörke": "mörk",
    "mörkerdöden": "mörkerdöd",
    "mörkerdödens": "mörkerdöd",
    "mörkerdöds": "mörkerdöd",
    "mörkerkörningar": "mörkerkörning",
    "mörkerkörningarna": "mörkerkörning",
    "mörkerkörningarnas": "mörkerkörning",
    "mörkerkörningars": "mörkerkörning",
    "mörkerkörningen": "mörkerkörning",
    "mörkerkörningens": "mörkerkörning",
    "mörkerkörnings": "mörkerkörning",
    "mörkermannen": "mörkerman",
    "mörkermannens": "mörkerman",
    "mörkermans": "mörkerman",
    "mörkermän": "mörkerman",
    "mörkermännen": "mörkerman",
    "mörkermännens": "mörkerman",
    "mörkermäns": "mörkerman",
    "mörkers": "mörker",
    "mörkerseendes": "mörkerseende",
    "mörkerseendet": "mörkerseende",
    "mörkerseendets": "mörkerseende",
    "mörkertalen": "mörkertal",
    "mörkertalens": "mörkertal",
    "mörkertalet": "mörkertal",
    "mörkertalets": "mörkertal",
    "mörkertals": "mörkertal",
    "mörkes": "mörk",
    "mörkgröna": "mörkgrön",
    "mörkgrönare": "mörkgrön",
    "mörkgrönares": "mörkgrön",
    "mörkgrönas": "mörkgrön",
    "mörkgrönast": "mörkgrön",
    "mörkgrönaste": "mörkgrön",
    "mörkgrönastes": "mörkgrön",
    "mörkgrönasts": "mörkgrön",
    "mörkgröne": "mörkgrön",
    "mörkgrönes": "mörkgrön",
    "mörkgröns": "mörkgrön",
    "mörkgrönt": "mörkgrön",
    "mörkgrönts": "mörkgrön",
    "mörkheten": "mörkhet",
    "mörkhetens": "mörkhet",
    "mörkhets": "mörkhet",
    "mörkhyade": "mörkhyad",
    "mörkhyades": "mörkhyad",
    "mörkhyads": "mörkhyad",
    "mörkhyat": "mörkhyad",
    "mörkhyats": "mörkhyad",
    "mörkklädda": "mörkklädd",
    "mörkkläddare": "mörkklädd",
    "mörkkläddares": "mörkklädd",
    "mörkkläddas": "mörkklädd",
    "mörkkläddast": "mörkklädd",
    "mörkkläddaste": "mörkklädd",
    "mörkkläddastes": "mörkklädd",
    "mörkkläddasts": "mörkklädd",
    "mörkklädde": "mörkklädd",
    "mörkkläddes": "mörkklädd",
    "mörkklädds": "mörkklädd",
    "mörkklätt": "mörkklädd",
    "mörkklätts": "mörkklädd",
    "mörkla": "mörklägga",
    "mörklade": "mörklägga",
    "mörklades": "mörklägga",
    "mörklagd": "mörklägga",
    "mörklagda": "mörklägga",
    "mörklagdare": "mörklagd",
    "mörklagdares": "mörklagd",
    "mörklagdas": "mörklägga",
    "mörklagdast": "mörklagd",
    "mörklagdaste": "mörklagd",
    "mörklagdastes": "mörklagd",
    "mörklagdasts": "mörklagd",
    "mörklagde": "mörklägga",
    "mörklagdes": "mörklägga",
    "mörklagds": "mörklägga",
    "mörklagt": "mörklägga",
    "mörklagts": "mörklägga",
    "mörklas": "mörklägga",
    "mörklägg": "mörklägga",
    "mörkläggande": "mörklägga",
    "mörklägganden": "mörkläggande",
    "mörkläggandena": "mörkläggande",
    "mörkläggandenas": "mörkläggande",
    "mörkläggandens": "mörkläggande",
    "mörkläggandes": "mörkläggande",
    "mörkläggandet": "mörkläggande",
    "mörkläggandets": "mörkläggande",
    "mörkläggas": "mörklägga",
    "mörklägger": "mörklägga",
    "mörklägges": "mörklägga",
    "mörkläggningar": "mörkläggning",
    "mörkläggningarna": "mörkläggning",
    "mörkläggningarnas": "mörkläggning",
    "mörkläggningars": "mörkläggning",
    "mörkläggningen": "mörkläggning",
    "mörkläggningens": "mörkläggning",
    "mörkläggnings": "mörkläggning",
    "mörkläggningsgardinen": "mörkläggningsgardin",
    "mörkläggningsgardinens": "mörkläggningsgardin",
    "mörkläggningsgardiner": "mörkläggningsgardin",
    "mörkläggningsgardinerna": "mörkläggningsgardin",
    "mörkläggningsgardinernas": "mörkläggningsgardin",
    "mörkläggningsgardiners": "mörkläggningsgardin",
    "mörkläggningsgardins": "mörkläggningsgardin",
    "mörkläggs": "mörklägga",
    "mörkmannen": "mörkman",
    "mörkmannens": "mörkman",
    "mörkmans": "mörkman",
    "mörkmän": "mörkman",
    "mörkmännen": "mörkman",
    "mörkmännens": "mörkman",
    "mörkmäns": "mörkman",
    "mörknade": "mörkna",
    "mörknades": "mörkna",
    "mörknande": "mörkna",
    "mörknanden": "mörknande",
    "mörknandena": "mörknande",
    "mörknandenas": "mörknande",
    "mörknandens": "mörknande",
    "mörknandes": "mörknande",
    "mörknandet": "mörknande",
    "mörknandets": "mörknande",
    "mörknar": "mörkna",
    "mörknas": "mörkna",
    "mörknat": "mörkna",
    "mörknats": "mörkna",
    "mörkningens": "mörkningen",
    "mörkren": "mörker",
    "mörkrens": "mörker",
    "mörkret": "mörker",
    "mörkrets": "mörker",
    "mörkrummen": "mörkrum",
    "mörkrummens": "mörkrum",
    "mörkrummet": "mörkrum",
    "mörkrummets": "mörkrum",
    "mörkrums": "mörkrum",
    "mörkrädda": "mörkrädd",
    "mörkräddare": "mörkrädd",
    "mörkräddares": "mörkrädd",
    "mörkräddas": "mörkrädd",
    "mörkräddast": "mörkrädd",
    "mörkräddaste": "mörkrädd",
    "mörkräddastes": "mörkrädd",
    "mörkräddasts": "mörkrädd",
    "mörkrädde": "mörkrädd",
    "mörkräddes": "mörkrädd",
    "mörkrädds": "mörkrädd",
    "mörkrädslan": "mörkrädsla",
    "mörkrädslans": "mörkrädsla",
    "mörkrädslas": "mörkrädsla",
    "mörkrädsle": "mörkrädsla",
    "mörkrädslo": "mörkrädsla",
    "mörkröda": "mörkröd",
    "mörkrödare": "mörkröd",
    "mörkrödares": "mörkröd",
    "mörkrödas": "mörkröd",
    "mörkrödast": "mörkröd",
    "mörkrödaste": "mörkröd",
    "mörkrödastes": "mörkröd",
    "mörkrödasts": "mörkröd",
    "mörkröde": "mörkröd",
    "mörkrödes": "mörkröd",
    "mörkröds": "mörkröd",
    "mörkrött": "mörkröd",
    "mörkrötts": "mörkröd",
    "mörks": "mörk",
    "mörksynen": "mörksyn",
    "mörksynens": "mörksyn",
    "mörksyns": "mörksyn",
    "mörkt": "mörk",
    "mörkts": "mörk",
    "mörna": "mö",
    "mörnas": "mö",
    "mörs": "mör",
    "mörsar": "mörsare",
    "mörsaren": "mörsare",
    "mörsarens": "mörsare",
    "mörsares": "mörsare",
    "mörsarna": "mörsare",
    "mörsarnas": "mörsare",
    "mört": "mör",
    "mörtar": "mört",
    "mörtarna": "mört",
    "mörtarnas": "mört",
    "mörtars": "mört",
    "mörten": "mört",
    "mörtens": "mört",
    "mörts": "mört",
    "mös": "mö",
    "möss": "mus",
    "mössan": "mössa",
    "mössans": "mössa",
    "mössas": "mössa",
    "mösse": "mössa",
    "mössen": "mus",
    "mössens": "mus",
    "mösskapellen": "mösskapell",
    "mösskapellens": "mösskapell",
    "mösskapellet": "mösskapell",
    "mösskapellets": "mösskapell",
    "mösskapells": "mösskapell",
    "mössor": "mössa",
    "mössorna": "mössa",
    "mössornas": "mössa",
    "mössors": "mössa",
    "mösspartiet": "mössparti",
    "mösspartiets": "mössparti",
    "mösspartis": "mössparti",
    "mösspartit": "mössparti",
    "mösspartits": "mössparti",
    "mössremmar": "mössrem",
    "mössremmarna": "mössrem",
    "mössremmarnas": "mössrem",
    "mössremmars": "mössrem",
    "mössremmen": "mössrem",
    "mössremmens": "mössrem",
    "mössrems": "mössrem",
    "mössöras": "mössöra",
    "mössörat": "mössöra",
    "mössörats": "mössöra",
    "mössöron": "mössöra",
    "mössöronen": "mössöra",
    "mössöronens": "mössöra",
    "mössörons": "mössöra",
    "möt": "möta",
    "mötande": "möta",
    "mötanden": "mötande",
    "mötandena": "mötande",
    "mötandenas": "mötande",
    "mötandens": "mötande",
    "mötandes": "mötande",
    "mötandet": "mötande",
    "mötandets": "mötande",
    "mötas": "möta",
    "möten": "möte",
    "mötena": "möte",
    "mötenas": "möte",
    "mötens": "möte",
    "möter": "möta",
    "mötes": "möte",
    "mötesfriheten": "mötesfrihet",
    "mötesfrihetens": "mötesfrihet",
    "mötesfriheter": "mötesfrihet",
    "mötesfriheterna": "mötesfrihet",
    "mötesfriheternas": "mötesfrihet",
    "mötesfriheters": "mötesfrihet",
    "mötesfrihets": "mötesfrihet",
    "mötesförbuden": "mötesförbud",
    "mötesförbudens": "mötesförbud",
    "mötesförbudet": "mötesförbud",
    "mötesförbudets": "mötesförbud",
    "mötesförbuds": "mötesförbud",
    "mötesordföranden": "mötesordförande",
    "mötesordförandena": "mötesordförande",
    "mötesordförandenas": "mötesordförande",
    "mötesordförandens": "mötesordförande",
    "mötesordförandes": "mötesordförande",
    "mötesplatsen": "mötesplats",
    "mötesplatsens": "mötesplats",
    "mötesplatser": "mötesplats",
    "mötesplatserna": "mötesplats",
    "mötesplatsernas": "mötesplats",
    "mötesplatsers": "mötesplats",
    "mötespunkten": "mötespunkt",
    "mötespunktens": "mötespunkt",
    "mötespunkter": "mötespunkt",
    "mötespunkterna": "mötespunkt",
    "mötespunkternas": "mötespunkt",
    "mötespunkters": "mötespunkt",
    "mötespunkts": "mötespunkt",
    "mötesspåren": "mötesspår",
    "mötesspårens": "mötesspår",
    "mötesspåret": "mötesspår",
    "mötesspårets": "mötesspår",
    "mötesspårs": "mötesspår",
    "mötesstationen": "mötesstation",
    "mötesstationens": "mötesstation",
    "mötesstationer": "mötesstation",
    "mötesstationerna": "mötesstation",
    "mötesstationernas": "mötesstation",
    "mötesstationers": "mötesstation",
    "mötesstations": "mötesstation",
    "mötet": "möte",
    "mötets": "möte",
    "möts": "möta",
    "mött": "möta",
    "mötta": "möta",
    "möttas": "möta",
    "mötte": "möta",
    "möttes": "mötas",
    "mötts": "mötas",
    "müslin": "müsli",
    "müslins": "müsli",
    "müslis": "müsli",
    "n-en": "n",
    "n-ens": "n",
    "n-et": "n",
    "n-ets": "n",
    "n-grammen": "n-gram",
    "n-grammens": "n-gram",
    "n-grammet": "n-gram",
    "n-grammets": "n-gram",
    "n-grams": "n-gram",
    "n-s": "n",
    "n:en": "n",
    "n:ens": "n",
    "n:et": "n",
    "n:ets": "n",
    "n:s": "n",
    "nabb": "nabbe",
    "nabbade": "nabbad",
    "nabbades": "nabbad",
    "nabbads": "nabbad",
    "nabbar": "nabbe",
    "nabbarna": "nabbe",
    "nabbarnas": "nabbe",
    "nabbars": "nabbe",
    "nabbat": "nabbad",
    "nabbats": "nabbad",
    "nabben": "nabbe",
    "nabbens": "nabbe",
    "nabbes": "nabbe",
    "nabbs": "nabbe",
    "naboben": "nabob",
    "nabobens": "nabob",
    "nabober": "nabob",
    "naboberna": "nabob",
    "nabobernas": "nabob",
    "nabobers": "nabob",
    "nabobs": "nabob",
    "nabolaget": "nabolag",
    "nabolagets": "nabolag",
    "nabolags": "nabolag",
    "nabon": "nabo",
    "nabons": "nabo",
    "nabor": "nabo",
    "naborna": "nabo",
    "nabornas": "nabo",
    "nabors": "nabo",
    "naborätten": "naborätt",
    "naborättens": "naborätt",
    "naborätts": "naborätt",
    "nabos": "nabo",
    "nachspilen": "nachspil",
    "nachspilens": "nachspil",
    "nachspilet": "nachspil",
    "nachspilets": "nachspil",
    "nachspils": "nachspil",
    "nack": "nacke",
    "nackad": "nacka",
    "nackade": "nacka",
    "nackades": "nacka",
    "nackads": "nacka",
    "nackande": "nacka",
    "nackanden": "nackande",
    "nackandena": "nackande",
    "nackandenas": "nackande",
    "nackandens": "nackande",
    "nackandes": "nackande",
    "nackandet": "nackande",
    "nackandets": "nackande",
    "nackar": "nacke",
    "nackarna": "nacke",
    "nackarnas": "nacke",
    "nackars": "nacke",
    "nackas": "nacka",
    "nackat": "nacka",
    "nackats": "nacka",
    "nackbenen": "nackben",
    "nackbenens": "nackben",
    "nackbenet": "nackben",
    "nackbenets": "nackben",
    "nackbens": "nackben",
    "nackbjudningar": "nackbjudning",
    "nackbjudningarna": "nackbjudning",
    "nackbjudningarnas": "nackbjudning",
    "nackbjudningars": "nackbjudning",
    "nackbjudningen": "nackbjudning",
    "nackbjudningens": "nackbjudning",
    "nackbjudnings": "nackbjudning",
    "nackdelar": "nackdel",
    "nackdelarna": "nackdel",
    "nackdelarnas": "nackdel",
    "nackdelars": "nackdel",
    "nackdelen": "nackdel",
    "nackdelens": "nackdel",
    "nackdels": "nackdel",
    "nacken": "nacke",
    "nackens": "nacke",
    "nackes": "nacke",
    "nackknutar": "nackknut",
    "nackknutarna": "nackknut",
    "nackknutarnas": "nackknut",
    "nackknutars": "nackknut",
    "nackknuten": "nackknut",
    "nackknutens": "nackknut",
    "nackknuts": "nackknut",
    "nackmanar": "nackman",
    "nackmanarna": "nackman",
    "nackmanarnas": "nackman",
    "nackmanars": "nackman",
    "nackmanen": "nackman",
    "nackmanens": "nackman",
    "nackmans": "nackman",
    "nacks": "nacke",
    "nackskadan": "nackskada",
    "nackskadans": "nackskada",
    "nackskadas": "nackskada",
    "nackskade": "nackskada",
    "nackskador": "nackskada",
    "nackskadorna": "nackskada",
    "nackskadornas": "nackskada",
    "nackskadors": "nackskada",
    "nackspärrar": "nackspärr",
    "nackspärrarna": "nackspärr",
    "nackspärrarnas": "nackspärr",
    "nackspärrars": "nackspärr",
    "nackspärren": "nackspärr",
    "nackspärrens": "nackspärr",
    "nackspärrs": "nackspärr",
    "nackstyva": "nackstyv",
    "nackstyvare": "nackstyv",
    "nackstyvares": "nackstyv",
    "nackstyvas": "nackstyv",
    "nackstyvast": "nackstyv",
    "nackstyvaste": "nackstyv",
    "nackstyvastes": "nackstyv",
    "nackstyvasts": "nackstyv",
    "nackstyve": "nackstyv",
    "nackstyves": "nackstyv",
    "nackstyvheten": "nackstyvhet",
    "nackstyvhetens": "nackstyvhet",
    "nackstyvhets": "nackstyvhet",
    "nackstyvs": "nackstyv",
    "nackstyvt": "nackstyv",
    "nackstyvts": "nackstyv",
    "nacksvingen": "nacksving",
    "nacksvingens": "nacksving",
    "nacksvinget": "nacksving",
    "nacksvingets": "nacksving",
    "nacksvings": "nacksving",
    "nacktofsar": "nacktofs",
    "nacktofsarna": "nacktofs",
    "nacktofsarnas": "nacktofs",
    "nacktofsars": "nacktofs",
    "nacktofsen": "nacktofs",
    "nacktofsens": "nacktofs",
    "nackvärken": "nackvärk",
    "nackvärkens": "nackvärk",
    "nackvärks": "nackvärk",
    "nadirs": "nadir",
    "nafs": "nafsa",
    "nafsad": "nafsa",
    "nafsade": "nafsa",
    "nafsades": "nafsa",
    "nafsads": "nafsa",
    "nafsande": "nafsa",
    "nafsanden": "nafsande",
    "nafsandena": "nafsande",
    "nafsandenas": "nafsande",
    "nafsandens": "nafsande",
    "nafsandes": "nafsande",
    "nafsandet": "nafsande",
    "nafsandets": "nafsande",
    "nafsar": "nafsa",
    "nafsas": "nafsa",
    "nafsat": "nafsa",
    "nafsats": "nafsa",
    "nafsen": "nafs",
    "nafsens": "nafs",
    "nafset": "nafs",
    "nafsets": "nafs",
    "naftalenen": "naftalen",
    "naftalenens": "naftalen",
    "naftalenet": "naftalen",
    "naftalenets": "naftalen",
    "naftalens": "naftalen",
    "naftalinen": "naftalin",
    "naftalinens": "naftalin",
    "naftalinet": "naftalin",
    "naftalinets": "naftalin",
    "naftalins": "naftalin",
    "naftan": "nafta",
    "naftans": "nafta",
    "naftas": "nafta",
    "nagajk": "nagajka",
    "nagajkan": "nagajka",
    "nagajkans": "nagajka",
    "nagajkas": "nagajka",
    "nagajke": "nagajka",
    "nagajkor": "nagajka",
    "nagajkorna": "nagajka",
    "nagajkornas": "nagajka",
    "nagajkors": "nagajka",
    "nagajks": "nagajka",
    "nagelbanden": "nagelband",
    "nagelbandens": "nagelband",
    "nagelbandet": "nagelband",
    "nagelbandets": "nagelband",
    "nagelbands": "nagelband",
    "nagelbitningar": "nagelbitning",
    "nagelbitningarna": "nagelbitning",
    "nagelbitningarnas": "nagelbitning",
    "nagelbitningars": "nagelbitning",
    "nagelbitningen": "nagelbitning",
    "nagelbitningens": "nagelbitning",
    "nagelbitnings": "nagelbitning",
    "nagelbäddar": "nagelbädd",
    "nagelbäddarna": "nagelbädd",
    "nagelbäddarnas": "nagelbädd",
    "nagelbäddars": "nagelbädd",
    "nagelbädden": "nagelbädd",
    "nagelbäddens": "nagelbädd",
    "nagelbädds": "nagelbädd",
    "nagelbänkar": "nagelbänk",
    "nagelbänkarna": "nagelbänk",
    "nagelbänkarnas": "nagelbänk",
    "nagelbänkars": "nagelbänk",
    "nagelbänken": "nagelbänk",
    "nagelbänkens": "nagelbänk",
    "nagelbänks": "nagelbänk",
    "nagelfar": "nagelfara",
    "nagelfarande": "nagelfara",
    "nagelfaranden": "nagelfarande",
    "nagelfarandena": "nagelfarande",
    "nagelfarandenas": "nagelfarande",
    "nagelfarandens": "nagelfarande",
    "nagelfarandes": "nagelfarande",
    "nagelfarandet": "nagelfarande",
    "nagelfarandets": "nagelfarande",
    "nagelfaras": "nagelfara",
    "nagelfare": "nagelfara",
    "nagelfaren": "nagelfara",
    "nagelfarens": "nagelfara",
    "nagelfares": "nagelfara",
    "nagelfaret": "nagelfara",
    "nagelfarets": "nagelfara",
    "nagelfarit": "nagelfara",
    "nagelfarits": "nagelfara",
    "nagelfarna": "nagelfara",
    "nagelfarnas": "nagelfara",
    "nagelfarne": "nagelfara",
    "nagelfarnes": "nagelfara",
    "nagelfars": "nagelfara",
    "nagelfilar": "nagelfil",
    "nagelfilarna": "nagelfil",
    "nagelfilarnas": "nagelfil",
    "nagelfilars": "nagelfil",
    "nagelfilen": "nagelfil",
    "nagelfilens": "nagelfil",
    "nagelfils": "nagelfil",
    "nagelfor": "nagelfara",
    "nagelfore": "nagelfara",
    "nagelfores": "nagelfara",
    "nagelfors": "nagelfara",
    "nagelklippningar": "nagelklippning",
    "nagelklippningarna": "nagelklippning",
    "nagelklippningarnas": "nagelklippning",
    "nagelklippningars": "nagelklippning",
    "nagelklippningen": "nagelklippning",
    "nagelklippningens": "nagelklippning",
    "nagelklippnings": "nagelklippning",
    "nagelklippningslöften": "nagelklippningslöfte",
    "nagelklippningslöftena": "nagelklippningslöfte",
    "nagelklippningslöftenas": "nagelklippningslöfte",
    "nagelklippningslöftens": "nagelklippningslöfte",
    "nagelklippningslöftes": "nagelklippningslöfte",
    "nagelklippningslöftet": "nagelklippningslöfte",
    "nagelklippningslöftets": "nagelklippningslöfte",
    "nagellacken": "nagellack",
    "nagellackens": "nagellack",
    "nagellacket": "nagellack",
    "nagellackets": "nagellack",
    "nagellacks": "nagellack",
    "nageln": "nagel",
    "nagelns": "nagel",
    "nagelpetar": "nagelpetare",
    "nagelpetaren": "nagelpetare",
    "nagelpetarens": "nagelpetare",
    "nagelpetares": "nagelpetare",
    "nagelpetarna": "nagelpetare",
    "nagelpetarnas": "nagelpetare",
    "nagelroten": "nagelrot",
    "nagelrotens": "nagelrot",
    "nagelrots": "nagelrot",
    "nagelrötter": "nagelrot",
    "nagelrötterna": "nagelrot",
    "nagelrötternas": "nagelrot",
    "nagelrötters": "nagelrot",
    "nagels": "nagel",
    "nagelsaxar": "nagelsax",
    "nagelsaxarna": "nagelsax",
    "nagelsaxarnas": "nagelsax",
    "nagelsaxars": "nagelsax",
    "nagelsaxen": "nagelsax",
    "nagelsaxens": "nagelsax",
    "nagelspetsar": "nagelspets",
    "nagelspetsarna": "nagelspets",
    "nagelspetsarnas": "nagelspets",
    "nagelspetsars": "nagelspets",
    "nagelspetsen": "nagelspets",
    "nagelspetsens": "nagelspets",
    "nagelsömmar": "nagelsöm",
    "nagelsömmarna": "nagelsöm",
    "nagelsömmarnas": "nagelsöm",
    "nagelsömmars": "nagelsöm",
    "nagelsömmen": "nagelsöm",
    "nagelsömmens": "nagelsöm",
    "nagelsöms": "nagelsöm",
    "nageltrånget": "nageltrång",
    "nageltrångets": "nageltrång",
    "nageltrångs": "nageltrång",
    "nagelörten": "nagelört",
    "nagelörtens": "nagelört",
    "nagelörter": "nagelört",
    "nagelörterna": "nagelört",
    "nagelörternas": "nagelört",
    "nagelörters": "nagelört",
    "nagelörts": "nagelört",
    "nagg": "nagga",
    "naggad": "nagga",
    "naggade": "nagga",
    "naggades": "nagga",
    "naggads": "nagga",
    "naggande": "nagga",
    "nagganden": "naggande",
    "naggandena": "naggande",
    "naggandenas": "naggande",
    "naggandens": "naggande",
    "naggandes": "naggande",
    "naggandet": "naggande",
    "naggandets": "naggande",
    "naggar": "nagga",
    "naggarna": "nagg",
    "naggarnas": "nagg",
    "naggars": "nagg",
    "naggas": "nagga",
    "naggat": "nagga",
    "naggats": "nagga",
    "naggen": "nagg",
    "naggens": "nagg",
    "nagget": "nagg",
    "naggets": "nagg",
    "naggs": "nagg",
    "naggsågade": "naggsågad",
    "naggsågades": "naggsågad",
    "naggsågads": "naggsågad",
    "naggsågat": "naggsågad",
    "naggsågats": "naggsågad",
    "naglad": "nagla",
    "naglade": "nagla",
    "naglades": "nagla",
    "naglads": "nagla",
    "naglande": "nagla",
    "naglanden": "naglande",
    "naglandena": "naglande",
    "naglandenas": "naglande",
    "naglandens": "naglande",
    "naglandes": "naglande",
    "naglandet": "naglande",
    "naglandets": "naglande",
    "naglar": "nagla",
    "naglarna": "nagel",
    "naglarnas": "nagel",
    "naglars": "nagel",
    "naglas": "nagla",
    "naglat": "nagla",
    "naglats": "nagla",
    "naiva": "naiv",
    "naivare": "naiv",
    "naivares": "naiv",
    "naivas": "naiv",
    "naivast": "naiv",
    "naivaste": "naiv",
    "naivastes": "naiv",
    "naivasts": "naiv",
    "naive": "naiv",
    "naives": "naiv",
    "naivheten": "naivhet",
    "naivhetens": "naivhet",
    "naivhets": "naivhet",
    "naivismen": "naivism",
    "naivismens": "naivism",
    "naivismer": "naivism",
    "naivismerna": "naivism",
    "naivismernas": "naivism",
    "naivismers": "naivism",
    "naivisms": "naivism",
    "naivisten": "naivist",
    "naivistens": "naivist",
    "naivister": "naivist",
    "naivisterna": "naivist",
    "naivisternas": "naivist",
    "naivisters": "naivist",
    "naivistiska": "naivistisk",
    "naivistiskare": "naivistisk",
    "naivistiskares": "naivistisk",
    "naivistiskas": "naivistisk",
    "naivistiskast": "naivistisk",
    "naivistiskaste": "naivistisk",
    "naivistiskastes": "naivistisk",
    "naivistiskasts": "naivistisk",
    "naivistiske": "naivistisk",
    "naivistiskes": "naivistisk",
    "naivistisks": "naivistisk",
    "naivistiskt": "naivistisk",
    "naivistiskts": "naivistisk",
    "naivists": "naivist",
    "naiviteten": "naivitet",
    "naivitetens": "naivitet",
    "naiviteter": "naivitet",
    "naiviteterna": "naivitet",
    "naiviteternas": "naivitet",
    "naiviteters": "naivitet",
    "naivitets": "naivitet",
    "naivs": "naiv",
    "naivt": "naiv",
    "naivts": "naiv",
    "naj": "naja",
    "najad": "naja",
    "najade": "naja",
    "najaden": "najad",
    "najadens": "najad",
    "najader": "najad",
    "najaderna": "najad",
    "najadernas": "najad",
    "najaders": "najad",
    "najades": "naja",
    "najads": "najad",
    "najande": "naja",
    "najanden": "najande",
    "najandena": "najande",
    "najandenas": "najande",
    "najandens": "najande",
    "najandes": "najande",
    "najandet": "najande",
    "najandets": "najande",
    "najar": "naja",
    "najas": "naja",
    "najat": "naja",
    "najats": "naja",
    "najtågen": "najtåg",
    "najtågens": "najtåg",
    "najtåget": "najtåg",
    "najtågets": "najtåg",
    "najtågs": "najtåg",
    "najögonstroppar": "najögonstropp",
    "najögonstropparna": "najögonstropp",
    "najögonstropparnas": "najögonstropp",
    "najögonstroppars": "najögonstropp",
    "najögonstroppen": "najögonstropp",
    "najögonstroppens": "najögonstropp",
    "najögonstropps": "najögonstropp",
    "nakenbadar": "nakenbadare",
    "nakenbadaren": "nakenbadare",
    "nakenbadarens": "nakenbadare",
    "nakenbadares": "nakenbadare",
    "nakenbadarna": "nakenbadare",
    "nakenbadarnas": "nakenbadare",
    "nakenbaden": "nakenbad",
    "nakenbadens": "nakenbad",
    "nakenbadet": "nakenbad",
    "nakenbadets": "nakenbad",
    "nakenbads": "nakenbad",
    "nakenbilden": "nakenbild",
    "nakenbildens": "nakenbild",
    "nakenbilder": "nakenbild",
    "nakenbilderna": "nakenbild",
    "nakenbildernas": "nakenbild",
    "nakenbilders": "nakenbild",
    "nakenbilds": "nakenbild",
    "nakenblankningar": "nakenblankning",
    "nakenblankningarna": "nakenblankning",
    "nakenblankningarnas": "nakenblankning",
    "nakenblankningars": "nakenblankning",
    "nakenblankningen": "nakenblankning",
    "nakenblankningens": "nakenblankning",
    "nakenblanknings": "nakenblankning",
    "nakendansen": "nakendans",
    "nakendansens": "nakendans",
    "nakendanser": "nakendans",
    "nakendanserna": "nakendans",
    "nakendansernas": "nakendans",
    "nakendansers": "nakendans",
    "nakendansösen": "nakendansös",
    "nakendansösens": "nakendansös",
    "nakendansöser": "nakendansös",
    "nakendansöserna": "nakendansös",
    "nakendansösernas": "nakendansös",
    "nakendansösers": "nakendansös",
    "nakenfröiga": "nakenfröig",
    "nakenfröigare": "nakenfröig",
    "nakenfröigares": "nakenfröig",
    "nakenfröigas": "nakenfröig",
    "nakenfröigast": "nakenfröig",
    "nakenfröigaste": "nakenfröig",
    "nakenfröigastes": "nakenfröig",
    "nakenfröigasts": "nakenfröig",
    "nakenfröige": "nakenfröig",
    "nakenfröiges": "nakenfröig",
    "nakenfröigs": "nakenfröig",
    "nakenfröigt": "nakenfröig",
    "nakenfröigts": "nakenfröig",
    "nakenheten": "nakenhet",
    "nakenhetens": "nakenhet",
    "nakenheter": "nakenhet",
    "nakenheterna": "nakenhet",
    "nakenheternas": "nakenhet",
    "nakenheters": "nakenhet",
    "nakenhets": "nakenhet",
    "nakenkindade": "nakenkindad",
    "nakenkindades": "nakenkindad",
    "nakenkindads": "nakenkindad",
    "nakenkindat": "nakenkindad",
    "nakenkindats": "nakenkindad",
    "nakenkulten": "nakenkult",
    "nakenkultens": "nakenkult",
    "nakenkulter": "nakenkult",
    "nakenkulterna": "nakenkult",
    "nakenkulternas": "nakenkult",
    "nakenkulters": "nakenkult",
    "nakenkults": "nakenkult",
    "nakenkulturen": "nakenkultur",
    "nakenkulturens": "nakenkultur",
    "nakenkulturer": "nakenkultur",
    "nakenkulturerna": "nakenkultur",
    "nakenkulturernas": "nakenkultur",
    "nakenkulturers": "nakenkultur",
    "nakenkulturs": "nakenkultur",
    "nakenmodellen": "nakenmodell",
    "nakenmodellens": "nakenmodell",
    "nakenmodeller": "nakenmodell",
    "nakenmodellerna": "nakenmodell",
    "nakenmodellernas": "nakenmodell",
    "nakenmodellers": "nakenmodell",
    "nakenmodells": "nakenmodell",
    "nakens": "naken",
    "nakenscenen": "nakenscen",
    "nakenscenens": "nakenscen",
    "nakenscener": "nakenscen",
    "nakenscenerna": "nakenscen",
    "nakenscenernas": "nakenscen",
    "nakensceners": "nakenscen",
    "nakenscens": "nakenscen",
    "nakenvandrar": "nakenvandrare",
    "nakenvandraren": "nakenvandrare",
    "nakenvandrarens": "nakenvandrare",
    "nakenvandrares": "nakenvandrare",
    "nakenvandrarna": "nakenvandrare",
    "nakenvandrarnas": "nakenvandrare",
    "naket": "naken",
    "naketbilden": "naketbild",
    "naketbildens": "naketbild",
    "naketbilder": "naketbild",
    "naketbilderna": "naketbild",
    "naketbildernas": "naketbild",
    "naketbilders": "naketbild",
    "naketbilds": "naketbild",
    "naketmåleriet": "naketmåleri",
    "naketmåleriets": "naketmåleri",
    "naketmåleris": "naketmåleri",
    "naketmålerit": "naketmåleri",
    "naketmålerits": "naketmåleri",
    "nakets": "naken",
    "nakna": "naken",
    "naknare": "naken",
    "naknares": "naken",
    "naknas": "naken",
    "naknast": "naken",
    "naknaste": "naken",
    "naknastes": "naken",
    "naknasts": "naken",
    "nakne": "naken",
    "naknes": "naken",
    "nakterhusen": "nakterhus",
    "nakterhusens": "nakterhus",
    "nakterhuset": "nakterhus",
    "nakterhusets": "nakterhus",
    "nalkades": "nalkas",
    "nalkats": "nalkas",
    "nall": "nalla",
    "nallad": "nalla",
    "nallade": "nalla",
    "nallades": "nalla",
    "nallads": "nalla",
    "nallande": "nalla",
    "nallanden": "nallande",
    "nallandena": "nallande",
    "nallandenas": "nallande",
    "nallandens": "nallande",
    "nallandes": "nallande",
    "nallandet": "nallande",
    "nallandets": "nallande",
    "nallar": "nalle",
    "nallarna": "nalle",
    "nallarnas": "nalle",
    "nallars": "nalle",
    "nallas": "nalla",
    "nallat": "nalla",
    "nallats": "nalla",
    "nallen": "nalle",
    "nallens": "nalle",
    "nalles": "nalle",
    "namibiern": "namibier",
    "namibierna": "namibier",
    "namibiernas": "namibier",
    "namibierns": "namibier",
    "namibiers": "namibier",
    "namibiska": "namibisk",
    "namibiskan": "namibiska",
    "namibiskans": "namibiska",
    "namibiskare": "namibisk",
    "namibiskares": "namibisk",
    "namibiskas": "namibiska",
    "namibiskast": "namibisk",
    "namibiskaste": "namibisk",
    "namibiskastes": "namibisk",
    "namibiskasts": "namibisk",
    "namibiske": "namibiska",
    "namibiskes": "namibisk",
    "namibiskor": "namibiska",
    "namibiskorna": "namibiska",
    "namibiskornas": "namibiska",
    "namibiskors": "namibiska",
    "namibisks": "namibisk",
    "namibiskt": "namibisk",
    "namibiskts": "namibisk",
    "namn": "namne",
    "namnad": "namna",
    "namnade": "namna",
    "namnades": "namna",
    "namnads": "namna",
    "namnaktien": "namnaktie",
    "namnaktiens": "namnaktie",
    "namnaktier": "namnaktie",
    "namnaktierna": "namnaktie",
    "namnaktiernas": "namnaktie",
    "namnaktiers": "namnaktie",
    "namnakties": "namnaktie",
    "namnamet": "namnam",
    "namnamets": "namnam",
    "namnams": "namnam",
    "namnande": "namna",
    "namnanden": "namnande",
    "namnandena": "namnande",
    "namnandenas": "namnande",
    "namnandens": "namnande",
    "namnandes": "namnande",
    "namnandet": "namnande",
    "namnandets": "namnande",
    "namnanropen": "namnanrop",
    "namnanropens": "namnanrop",
    "namnanropet": "namnanrop",
    "namnanropets": "namnanrop",
    "namnanrops": "namnanrop",
    "namnar": "namne",
    "namnarna": "namne",
    "namnarnas": "namne",
    "namnars": "namne",
    "namnas": "namna",
    "namnat": "namna",
    "namnats": "namna",
    "namnberedningar": "namnberedning",
    "namnberedningarna": "namnberedning",
    "namnberedningarnas": "namnberedning",
    "namnberedningars": "namnberedning",
    "namnberedningen": "namnberedning",
    "namnberedningens": "namnberedning",
    "namnberednings": "namnberedning",
    "namnbläcket": "namnbläck",
    "namnbläckets": "namnbläck",
    "namnbläcks": "namnbläck",
    "namnbyten": "namnbyte",
    "namnbytena": "namnbyte",
    "namnbytenas": "namnbyte",
    "namnbytens": "namnbyte",
    "namnbytes": "namnbyte",
    "namnbytet": "namnbyte",
    "namnbytets": "namnbyte",
    "namnbärar": "namnbärare",
    "namnbäraren": "namnbärare",
    "namnbärarens": "namnbärare",
    "namnbärares": "namnbärare",
    "namnbärarna": "namnbärare",
    "namnbärarnas": "namnbärare",
    "namnchiffern": "namnchiffer",
    "namnchifferns": "namnchiffer",
    "namnchiffers": "namnchiffer",
    "namnchiffren": "namnchiffer",
    "namnchiffrens": "namnchiffer",
    "namnchiffrer": "namnchiffer",
    "namnchiffrerna": "namnchiffer",
    "namnchiffrernas": "namnchiffer",
    "namnchiffrers": "namnchiffer",
    "namnchiffret": "namnchiffer",
    "namnchiffrets": "namnchiffer",
    "namndikten": "namndikt",
    "namndiktens": "namndikt",
    "namndikter": "namndikt",
    "namndikterna": "namndikt",
    "namndikternas": "namndikt",
    "namndikters": "namndikt",
    "namndikts": "namndikt",
    "namnen": "namne",
    "namnens": "namne",
    "namnes": "namne",
    "namnet": "namn",
    "namnets": "namn",
    "namnfrejden": "namnfrejd",
    "namnfrejdens": "namnfrejd",
    "namnfrejds": "namnfrejd",
    "namnfäst": "namnfästa",
    "namnfästande": "namnfästa",
    "namnfästanden": "namnfästande",
    "namnfästandena": "namnfästande",
    "namnfästandenas": "namnfästande",
    "namnfästandens": "namnfästande",
    "namnfästandes": "namnfästande",
    "namnfästandet": "namnfästande",
    "namnfästandets": "namnfästande",
    "namnfästas": "namnfästa",
    "namnfäste": "namnfästa",
    "namnfäster": "namnfästa",
    "namnfästes": "namnfästa",
    "namnfästs": "namnfästa",
    "namnförklaringar": "namnförklaring",
    "namnförklaringarna": "namnförklaring",
    "namnförklaringarnas": "namnförklaring",
    "namnförklaringars": "namnförklaring",
    "namnförklaringen": "namnförklaring",
    "namnförklaringens": "namnförklaring",
    "namnförklarings": "namnförklaring",
    "namngav": "namnge",
    "namngavs": "namnge",
    "namngeende": "namnge",
    "namngeendes": "namnge",
    "namnger": "namnge",
    "namnges": "namnge",
    "namngett": "namnge",
    "namngetts": "namnge",
    "namngiv": "namnge",
    "namngiva": "namnge",
    "namngivande": "namnge",
    "namngivanden": "namngivande",
    "namngivandena": "namngivande",
    "namngivandenas": "namngivande",
    "namngivandens": "namngivande",
    "namngivandes": "namngivande",
    "namngivandet": "namngivande",
    "namngivandets": "namngivande",
    "namngivas": "namnge",
    "namngive": "namnge",
    "namngiven": "namnge",
    "namngivens": "namnge",
    "namngiver": "namnge",
    "namngives": "namnge",
    "namngivet": "namnge",
    "namngivets": "namnge",
    "namngivit": "namnge",
    "namngivits": "namnge",
    "namngivna": "namnge",
    "namngivnas": "namnge",
    "namngivne": "namnge",
    "namngivnes": "namnge",
    "namngivs": "namnge",
    "namngåve": "namnge",
    "namngåves": "namnge",
    "namninsamlingar": "namninsamling",
    "namninsamlingarna": "namninsamling",
    "namninsamlingarnas": "namninsamling",
    "namninsamlingars": "namninsamling",
    "namninsamlingen": "namninsamling",
    "namninsamlingens": "namninsamling",
    "namninsamlings": "namninsamling",
    "namnkrediten": "namnkredit",
    "namnkreditens": "namnkredit",
    "namnkrediter": "namnkredit",
    "namnkrediterna": "namnkredit",
    "namnkrediternas": "namnkredit",
    "namnkrediters": "namnkredit",
    "namnkredits": "namnkredit",
    "namnkristens": "namnkristen",
    "namnkristet": "namnkristen",
    "namnkristets": "namnkristen",
    "namnkristna": "namnkristen",
    "namnkristnare": "namnkristen",
    "namnkristnares": "namnkristen",
    "namnkristnas": "namnkristen",
    "namnkristnast": "namnkristen",
    "namnkristnaste": "namnkristen",
    "namnkristnastes": "namnkristen",
    "namnkristnasts": "namnkristen",
    "namnkristne": "namnkristen",
    "namnkristnes": "namnkristen",
    "namnkunniga": "namnkunnig",
    "namnkunnigare": "namnkunnig",
    "namnkunnigares": "namnkunnig",
    "namnkunnigas": "namnkunnig",
    "namnkunnigast": "namnkunnig",
    "namnkunnigaste": "namnkunnig",
    "namnkunnigastes": "namnkunnig",
    "namnkunnigasts": "namnkunnig",
    "namnkunnige": "namnkunnig",
    "namnkunniges": "namnkunnig",
    "namnkunnigheten": "namnkunnighet",
    "namnkunnighetens": "namnkunnighet",
    "namnkunnigheter": "namnkunnighet",
    "namnkunnigheterna": "namnkunnighet",
    "namnkunnigheternas": "namnkunnighet",
    "namnkunnigheters": "namnkunnighet",
    "namnkunnighets": "namnkunnighet",
    "namnkunnigs": "namnkunnig",
    "namnkunnigt": "namnkunnig",
    "namnkunnigts": "namnkunnig",
    "namnlagar": "namnlag",
    "namnlagarna": "namnlag",
    "namnlagarnas": "namnlag",
    "namnlagars": "namnlag",
    "namnlagen": "namnlag",
    "namnlagens": "namnlag",
    "namnlags": "namnlag",
    "namnlistan": "namnlista",
    "namnlistans": "namnlista",
    "namnlistas": "namnlista",
    "namnliste": "namnlista",
    "namnlistor": "namnlista",
    "namnlistorna": "namnlista",
    "namnlistornas": "namnlista",
    "namnlistors": "namnlista",
    "namnlängden": "namnlängd",
    "namnlängdens": "namnlängd",
    "namnlängder": "namnlängd",
    "namnlängderna": "namnlängd",
    "namnlängdernas": "namnlängd",
    "namnlängders": "namnlängd",
    "namnlängds": "namnlängd",
    "namnlösa": "namnlös",
    "namnlösare": "namnlös",
    "namnlösares": "namnlös",
    "namnlösas": "namnlös",
    "namnlösast": "namnlös",
    "namnlösaste": "namnlös",
    "namnlösastes": "namnlös",
    "namnlösasts": "namnlös",
    "namnlöse": "namnlös",
    "namnlöses": "namnlös",
    "namnlösheten": "namnlöshet",
    "namnlöshetens": "namnlöshet",
    "namnlöshets": "namnlöshet",
    "namnlöst": "namnlös",
    "namnlösts": "namnlös",
    "namnminnes": "namnminne",
    "namnminnet": "namnminne",
    "namnminnets": "namnminne",
    "namnmässiga": "namnmässig",
    "namnmässigare": "namnmässig",
    "namnmässigares": "namnmässig",
    "namnmässigas": "namnmässig",
    "namnmässigast": "namnmässig",
    "namnmässigaste": "namnmässig",
    "namnmässigastes": "namnmässig",
    "namnmässigasts": "namnmässig",
    "namnmässige": "namnmässig",
    "namnmässiges": "namnmässig",
    "namnmässigs": "namnmässig",
    "namnmässigt": "namnmässig",
    "namnmässigts": "namnmässig",
    "namnplåtar": "namnplåt",
    "namnplåtarna": "namnplåt",
    "namnplåtarnas": "namnplåt",
    "namnplåtars": "namnplåt",
    "namnplåten": "namnplåt",
    "namnplåtens": "namnplåt",
    "namnplåts": "namnplåt",
    "namns": "namne",
    "namnsdagar": "namnsdag",
    "namnsdagarna": "namnsdag",
    "namnsdagarnas": "namnsdag",
    "namnsdagars": "namnsdag",
    "namnsdagen": "namnsdag",
    "namnsdagens": "namnsdag",
    "namnsdags": "namnsdag",
    "namnsdagsbarnen": "namnsdagsbarn",
    "namnsdagsbarnens": "namnsdagsbarn",
    "namnsdagsbarnet": "namnsdagsbarn",
    "namnsdagsbarnets": "namnsdagsbarn",
    "namnsdagsbarns": "namnsdagsbarn",
    "namnsedeln": "namnsedel",
    "namnsedelns": "namnsedel",
    "namnsedels": "namnsedel",
    "namnsedlar": "namnsedel",
    "namnsedlarna": "namnsedel",
    "namnsedlarnas": "namnsedel",
    "namnsedlars": "namnsedel",
    "namnskyddade": "namnskyddad",
    "namnskyddades": "namnskyddad",
    "namnskyddads": "namnskyddad",
    "namnskyddat": "namnskyddad",
    "namnskyddats": "namnskyddad",
    "namnskydden": "namnskydd",
    "namnskyddens": "namnskydd",
    "namnskyddet": "namnskydd",
    "namnskyddets": "namnskydd",
    "namnskydds": "namnskydd",
    "namnskyltar": "namnskylt",
    "namnskyltarna": "namnskylt",
    "namnskyltarnas": "namnskylt",
    "namnskyltars": "namnskylt",
    "namnskylten": "namnskylt",
    "namnskyltens": "namnskylt",
    "namnskylts": "namnskylt",
    "namnstandertar": "namnstandert",
    "namnstandertarna": "namnstandert",
    "namnstandertarnas": "namnstandert",
    "namnstandertars": "namnstandert",
    "namnstanderten": "namnstandert",
    "namnstandertens": "namnstandert",
    "namnstanderts": "namnstandert",
    "namnstämpeln": "namnstämpel",
    "namnstämpelns": "namnstämpel",
    "namnstämpels": "namnstämpel",
    "namnstämplar": "namnstämpel",
    "namnstämplarna": "namnstämpel",
    "namnstämplarnas": "namnstämpel",
    "namnstämplars": "namnstämpel",
    "namnsäkerheten": "namnsäkerhet",
    "namnsäkerhetens": "namnsäkerhet",
    "namnsäkerheter": "namnsäkerhet",
    "namnsäkerheterna": "namnsäkerhet",
    "namnsäkerheternas": "namnsäkerhet",
    "namnsäkerheters": "namnsäkerhet",
    "namnsäkerhets": "namnsäkerhet",
    "namntavel": "namntavla",
    "namntavlan": "namntavla",
    "namntavlans": "namntavla",
    "namntavlas": "namntavla",
    "namntavle": "namntavla",
    "namntavlor": "namntavla",
    "namntavlorna": "namntavla",
    "namntavlornas": "namntavla",
    "namntavlors": "namntavla",
    "namnteckningar": "namnteckning",
    "namnteckningarna": "namnteckning",
    "namnteckningarnas": "namnteckning",
    "namnteckningars": "namnteckning",
    "namnteckningen": "namnteckning",
    "namnteckningens": "namnteckning",
    "namntecknings": "namnteckning",
    "namnunderskriften": "namnunderskrift",
    "namnunderskriftens": "namnunderskrift",
    "namnunderskrifter": "namnunderskrift",
    "namnunderskrifterna": "namnunderskrift",
    "namnunderskrifternas": "namnunderskrift",
    "namnunderskrifters": "namnunderskrift",
    "namnunderskrifts": "namnunderskrift",
    "namnuppgiften": "namnuppgift",
    "namnuppgiftens": "namnuppgift",
    "namnuppgifter": "namnuppgift",
    "namnuppgifterna": "namnuppgift",
    "namnuppgifternas": "namnuppgift",
    "namnuppgifters": "namnuppgift",
    "namnuppgifts": "namnuppgift",
    "namnuppropen": "namnupprop",
    "namnuppropens": "namnupprop",
    "namnuppropet": "namnupprop",
    "namnuppropets": "namnupprop",
    "namnupprops": "namnupprop",
    "namnvärden": "namnvärde",
    "namnvärdena": "namnvärde",
    "namnvärdenas": "namnvärde",
    "namnvärdens": "namnvärde",
    "namnvärdes": "namnvärde",
    "namnvärdet": "namnvärde",
    "namnvärdets": "namnvärde",
    "nankinen": "nankin",
    "nankinens": "nankin",
    "nankinet": "nankin",
    "nankinets": "nankin",
    "nankingen": "nanking",
    "nankingens": "nanking",
    "nankinget": "nanking",
    "nankingets": "nanking",
    "nankings": "nanking",
    "nankins": "nankin",
    "nanoblomman": "nanoblomma",
    "nanoblommans": "nanoblomma",
    "nanoblommas": "nanoblomma",
    "nanoblomme": "nanoblomma",
    "nanoblommor": "nanoblomma",
    "nanoblommorna": "nanoblomma",
    "nanoblommornas": "nanoblomma",
    "nanoblommors": "nanoblomma",
    "nanobotar": "nanobot",
    "nanobotarna": "nanobot",
    "nanobotarnas": "nanobot",
    "nanobotars": "nanobot",
    "nanoboten": "nanobot",
    "nanobotens": "nanobot",
    "nanobots": "nanobot",
    "nanogrammen": "nanogram",
    "nanogrammens": "nanogram",
    "nanogrammet": "nanogram",
    "nanogrammets": "nanogram",
    "nanograms": "nanogram",
    "nanokolrören": "nanokolrör",
    "nanokolrörens": "nanokolrör",
    "nanokolröret": "nanokolrör",
    "nanokolrörets": "nanokolrör",
    "nanokolrörs": "nanokolrör",
    "nanometern": "nanometer",
    "nanometerna": "nanometer",
    "nanometernas": "nanometer",
    "nanometerns": "nanometer",
    "nanometers": "nanometer",
    "nanometrar": "nanometer",
    "nanometrarna": "nanometer",
    "nanometrarnas": "nanometer",
    "nanometrars": "nanometer",
    "nanopartikeln": "nanopartikel",
    "nanopartikelns": "nanopartikel",
    "nanopartikels": "nanopartikel",
    "nanopartiklar": "nanopartikel",
    "nanopartiklarna": "nanopartikel",
    "nanopartiklarnas": "nanopartikel",
    "nanopartiklars": "nanopartikel",
    "nanorören": "nanorör",
    "nanorörens": "nanorör",
    "nanoröret": "nanorör",
    "nanorörets": "nanorör",
    "nanorörs": "nanorör",
    "nanosekunden": "nanosekund",
    "nanosekundens": "nanosekund",
    "nanosekunder": "nanosekund",
    "nanosekunderna": "nanosekund",
    "nanosekundernas": "nanosekund",
    "nanosekunders": "nanosekund",
    "nanosekunds": "nanosekund",
    "nanotekniken": "nanoteknik",
    "nanoteknikens": "nanoteknik",
    "nanotekniks": "nanoteknik",
    "nanoteknologien": "nanoteknologi",
    "nanoteknologiens": "nanoteknologi",
    "nanoteknologier": "nanoteknologi",
    "nanoteknologierna": "nanoteknologi",
    "nanoteknologiernas": "nanoteknologi",
    "nanoteknologiers": "nanoteknologi",
    "nanoteknologin": "nanoteknologi",
    "nanoteknologins": "nanoteknologi",
    "nanoteknologis": "nanoteknologi",
    "nanotrådar": "nanotråd",
    "nanotrådarna": "nanotråd",
    "nanotrådarnas": "nanotråd",
    "nanotrådars": "nanotråd",
    "nanotråden": "nanotråd",
    "nanotrådens": "nanotråd",
    "nanotråds": "nanotråd",
    "napalmen": "napalm",
    "napalmens": "napalm",
    "napalms": "napalm",
    "napoleonbakelsen": "napoleonbakelse",
    "napoleonbakelsens": "napoleonbakelse",
    "napoleonbakelser": "napoleonbakelse",
    "napoleonbakelserna": "napoleonbakelse",
    "napoleonbakelsernas": "napoleonbakelse",
    "napoleonbakelsers": "napoleonbakelse",
    "napoleonbakelses": "napoleonbakelse",
    "napolitanar": "napolitanare",
    "napolitanaren": "napolitanare",
    "napolitanarens": "napolitanare",
    "napolitanares": "napolitanare",
    "napolitanarna": "napolitanare",
    "napolitanarnas": "napolitanare",
    "napolitanska": "napolitansk",
    "napolitanskare": "napolitansk",
    "napolitanskares": "napolitansk",
    "napolitanskas": "napolitansk",
    "napolitanskast": "napolitansk",
    "napolitanskaste": "napolitansk",
    "napolitanskastes": "napolitansk",
    "napolitanskasts": "napolitansk",
    "napolitanske": "napolitansk",
    "napolitanskes": "napolitansk",
    "napolitansks": "napolitansk",
    "napolitanskt": "napolitansk",
    "napolitanskts": "napolitansk",
    "napp": "nappa",
    "nappad": "nappa",
    "nappade": "nappa",
    "nappades": "nappas",
    "nappads": "nappa",
    "nappan": "nappa",
    "nappande": "nappa",
    "nappanden": "nappande",
    "nappandena": "nappande",
    "nappandenas": "nappande",
    "nappandens": "nappande",
    "nappandes": "nappande",
    "nappandet": "nappande",
    "nappandets": "nappande",
    "nappans": "nappa",
    "nappar": "nappa",
    "napparna": "napp",
    "napparnas": "napp",
    "nappars": "napp",
    "nappas": "nappa",
    "nappat": "nappa",
    "nappatagen": "nappatag",
    "nappatagens": "nappatag",
    "nappataget": "nappatag",
    "nappatagets": "nappatag",
    "nappatags": "nappatag",
    "nappats": "nappas",
    "nappen": "napp",
    "nappens": "napp",
    "nappet": "napp",
    "nappets": "napp",
    "nappflask": "nappflaska",
    "nappflaskan": "nappflaska",
    "nappflaskans": "nappflaska",
    "nappflaskas": "nappflaska",
    "nappflaske": "nappflaska",
    "nappflaskor": "nappflaska",
    "nappflaskorna": "nappflaska",
    "nappflaskornas": "nappflaska",
    "nappflaskors": "nappflaska",
    "napps": "napp",
    "naprapaten": "naprapat",
    "naprapatens": "naprapat",
    "naprapater": "naprapat",
    "naprapaterna": "naprapat",
    "naprapaternas": "naprapat",
    "naprapaters": "naprapat",
    "naprapats": "naprapat",
    "nar": "nara",
    "narad": "nara",
    "narade": "nara",
    "narades": "nara",
    "narads": "nara",
    "narande": "nara",
    "naranden": "narande",
    "narandena": "narande",
    "narandenas": "narande",
    "narandens": "narande",
    "narandes": "narande",
    "narandet": "narande",
    "narandets": "narande",
    "narar": "nara",
    "nararna": "nar",
    "nararnas": "nar",
    "narars": "nar",
    "naras": "nara",
    "narat": "nara",
    "narats": "nara",
    "narcissen": "narciss",
    "narcissens": "narciss",
    "narcisser": "narciss",
    "narcisserna": "narciss",
    "narcissernas": "narciss",
    "narcissers": "narciss",
    "narcissismen": "narcissism",
    "narcissismens": "narcissism",
    "narcissismer": "narcissism",
    "narcissismerna": "narcissism",
    "narcissismernas": "narcissism",
    "narcissismers": "narcissism",
    "narcissisms": "narcissism",
    "narcissistiska": "narcissistisk",
    "narcissistiskas": "narcissistisk",
    "narcissistiske": "narcissistisk",
    "narcissistiskes": "narcissistisk",
    "narcissistisks": "narcissistisk",
    "narcissistiskt": "narcissistisk",
    "narcissistiskts": "narcissistisk",
    "nardusen": "nardus",
    "nardusens": "nardus",
    "nardusliljan": "narduslilja",
    "nardusliljans": "narduslilja",
    "nardusliljas": "narduslilja",
    "narduslilje": "narduslilja",
    "nardusliljor": "narduslilja",
    "nardusliljorna": "narduslilja",
    "nardusliljornas": "narduslilja",
    "nardusliljors": "narduslilja",
    "naren": "nare",
    "narens": "nare",
    "nares": "nare",
    "nariga": "narig",
    "narigare": "narig",
    "narigares": "narig",
    "narigas": "narig",
    "narigast": "narig",
    "narigaste": "narig",
    "narigastes": "narig",
    "narigasts": "narig",
    "narige": "narig",
    "nariges": "narig",
    "narigheten": "narighet",
    "narighetens": "narighet",
    "narigheter": "narighet",
    "narigheterna": "narighet",
    "narigheternas": "narighet",
    "narigheters": "narighet",
    "narighets": "narighet",
    "narigs": "narig",
    "narigt": "narig",
    "narigts": "narig",
    "narkoanalysen": "narkoanalys",
    "narkoanalysens": "narkoanalys",
    "narkoanalyser": "narkoanalys",
    "narkoanalyserna": "narkoanalys",
    "narkoanalysernas": "narkoanalys",
    "narkoanalysers": "narkoanalys",
    "narkomanen": "narkoman",
    "narkomanens": "narkoman",
    "narkomaner": "narkoman",
    "narkomanerna": "narkoman",
    "narkomanernas": "narkoman",
    "narkomaners": "narkoman",
    "narkomanien": "narkomani",
    "narkomaniens": "narkomani",
    "narkomanin": "narkomani",
    "narkomanins": "narkomani",
    "narkomanis": "narkomani",
    "narkomans": "narkoman",
    "narkomanvården": "narkomanvård",
    "narkomanvårdens": "narkomanvård",
    "narkomanvårds": "narkomanvård",
    "narkosen": "narkos",
    "narkosens": "narkos",
    "narkoser": "narkos",
    "narkoserna": "narkos",
    "narkosernas": "narkos",
    "narkosers": "narkos",
    "narkosläkar": "narkosläkare",
    "narkosläkaren": "narkosläkare",
    "narkosläkarens": "narkosläkare",
    "narkosläkares": "narkosläkare",
    "narkosläkarna": "narkosläkare",
    "narkosläkarnas": "narkosläkare",
    "narkosmedels": "narkosmedel",
    "narkosmedlen": "narkosmedel",
    "narkosmedlens": "narkosmedel",
    "narkosmedlet": "narkosmedel",
    "narkosmedlets": "narkosmedel",
    "narkotika": "narkotikum",
    "narkotikabekämpningen": "narkotikabekämpning",
    "narkotikabekämpningens": "narkotikabekämpning",
    "narkotikabekämpnings": "narkotikabekämpning",
    "narkotikaberoenden": "narkotikaberoende",
    "narkotikaberoendena": "narkotikaberoende",
    "narkotikaberoendenas": "narkotikaberoende",
    "narkotikaberoendens": "narkotikaberoende",
    "narkotikaberoendes": "narkotikaberoende",
    "narkotikaberoendet": "narkotikaberoende",
    "narkotikaberoendets": "narkotikaberoende",
    "narkotikabrotten": "narkotikabrott",
    "narkotikabrottens": "narkotikabrott",
    "narkotikabrottet": "narkotikabrott",
    "narkotikabrottets": "narkotikabrott",
    "narkotikabrotts": "narkotikabrott",
    "narkotikaförsäljningar": "narkotikaförsäljning",
    "narkotikaförsäljningarna": "narkotikaförsäljning",
    "narkotikaförsäljningarnas": "narkotikaförsäljning",
    "narkotikaförsäljningars": "narkotikaförsäljning",
    "narkotikaförsäljningen": "narkotikaförsäljning",
    "narkotikaförsäljningens": "narkotikaförsäljning",
    "narkotikaförsäljnings": "narkotikaförsäljning",
    "narkotikahajar": "narkotikahaj",
    "narkotikahajarna": "narkotikahaj",
    "narkotikahajarnas": "narkotikahaj",
    "narkotikahajars": "narkotikahaj",
    "narkotikahajen": "narkotikahaj",
    "narkotikahajens": "narkotikahaj",
    "narkotikahajs": "narkotikahaj",
    "narkotikahandeln": "narkotikahandel",
    "narkotikahandelns": "narkotikahandel",
    "narkotikahandels": "narkotikahandel",
    "narkotikahundar": "narkotikahund",
    "narkotikahundarna": "narkotikahund",
    "narkotikahundarnas": "narkotikahund",
    "narkotikahundars": "narkotikahund",
    "narkotikahunden": "narkotikahund",
    "narkotikahundens": "narkotikahund",
    "narkotikahunds": "narkotikahund",
    "narkotikakliniken": "narkotikaklinik",
    "narkotikaklinikens": "narkotikaklinik",
    "narkotikakliniker": "narkotikaklinik",
    "narkotikaklinikerna": "narkotikaklinik",
    "narkotikaklinikernas": "narkotikaklinik",
    "narkotikaklinikers": "narkotikaklinik",
    "narkotikakliniks": "narkotikaklinik",
    "narkotikan": "narkotika",
    "narkotikana": "narkotikum",
    "narkotikanas": "narkotikum",
    "narkotikans": "narkotika",
    "narkotikas": "narkotikum",
    "narkotikautredningar": "narkotikautredning",
    "narkotikautredningarna": "narkotikautredning",
    "narkotikautredningarnas": "narkotikautredning",
    "narkotikautredningars": "narkotikautredning",
    "narkotikautredningen": "narkotikautredning",
    "narkotikautredningens": "narkotikautredning",
    "narkotikautrednings": "narkotikautredning",
    "narkotikumet": "narkotikum",
    "narkotikumets": "narkotikum",
    "narkotikums": "narkotikum",
    "narkotiska": "narkotisk",
    "narkotiskare": "narkotisk",
    "narkotiskares": "narkotisk",
    "narkotiskas": "narkotisk",
    "narkotiskast": "narkotisk",
    "narkotiskaste": "narkotisk",
    "narkotiskastes": "narkotisk",
    "narkotiskasts": "narkotisk",
    "narkotiske": "narkotisk",
    "narkotiskes": "narkotisk",
    "narkotisks": "narkotisk",
    "narkotiskt": "narkotisk",
    "narkotiskts": "narkotisk",
    "narr": "narra",
    "narrad": "narra",
    "narrade": "narra",
    "narrades": "narras",
    "narrads": "narra",
    "narraktiga": "narraktig",
    "narraktigare": "narraktig",
    "narraktigares": "narraktig",
    "narraktigas": "narraktig",
    "narraktigast": "narraktig",
    "narraktigaste": "narraktig",
    "narraktigastes": "narraktig",
    "narraktigasts": "narraktig",
    "narraktige": "narraktig",
    "narraktiges": "narraktig",
    "narraktigheten": "narraktighet",
    "narraktighetens": "narraktighet",
    "narraktighets": "narraktighet",
    "narraktigs": "narraktig",
    "narraktigt": "narraktig",
    "narraktigts": "narraktig",
    "narrande": "narra",
    "narranden": "narrande",
    "narrandena": "narrande",
    "narrandenas": "narrande",
    "narrandens": "narrande",
    "narrandes": "narrande",
    "narrandet": "narrande",
    "narrandets": "narrande",
    "narrar": "narra",
    "narrarna": "narr",
    "narrarnas": "narr",
    "narrars": "narr",
    "narras": "narra",
    "narrat": "narra",
    "narrativa": "narrativ",
    "narrativare": "narrativ",
    "narrativares": "narrativ",
    "narrativas": "narrativ",
    "narrativast": "narrativ",
    "narrativaste": "narrativ",
    "narrativastes": "narrativ",
    "narrativasts": "narrativ",
    "narrative": "narrativ",
    "narratives": "narrativ",
    "narrativs": "narrativ",
    "narrativt": "narrativ",
    "narrativts": "narrativ",
    "narrats": "narras",
    "narrdräkten": "narrdräkt",
    "narrdräktens": "narrdräkt",
    "narrdräkter": "narrdräkt",
    "narrdräkterna": "narrdräkt",
    "narrdräkternas": "narrdräkt",
    "narrdräkters": "narrdräkt",
    "narrdräkts": "narrdräkt",
    "narren": "narr",
    "narrens": "narr",
    "narrkåp": "narrkåpa",
    "narrkåpan": "narrkåpa",
    "narrkåpans": "narrkåpa",
    "narrkåpas": "narrkåpa",
    "narrkåpe": "narrkåpa",
    "narrkåpor": "narrkåpa",
    "narrkåporna": "narrkåpa",
    "narrkåpornas": "narrkåpa",
    "narrkåpors": "narrkåpa",
    "narrkåps": "narrkåpa",
    "narrluvan": "narrluva",
    "narrluvans": "narrluva",
    "narrluvas": "narrluva",
    "narrluve": "narrluva",
    "narrluvor": "narrluva",
    "narrluvorna": "narrluva",
    "narrluvornas": "narrluva",
    "narrluvors": "narrluva",
    "narrs": "narr",
    "narrspegeln": "narrspegel",
    "narrspegelns": "narrspegel",
    "narrspegels": "narrspegel",
    "narrspeglar": "narrspegel",
    "narrspeglarna": "narrspegel",
    "narrspeglarnas": "narrspegel",
    "narrspeglars": "narrspegel",
    "narrspelen": "narrspel",
    "narrspelens": "narrspel",
    "narrspelet": "narrspel",
    "narrspelets": "narrspel",
    "narrspels": "narrspel",
    "narrstrecken": "narrstreck",
    "narrstreckens": "narrstreck",
    "narrstrecket": "narrstreck",
    "narrstreckets": "narrstreck",
    "narrstrecks": "narrstreck",
    "nars": "nar",
    "narv": "narva",
    "narvad": "narva",
    "narvade": "narva",
    "narvades": "narva",
    "narvads": "narva",
    "narvalar": "narval",
    "narvalarna": "narval",
    "narvalarnas": "narval",
    "narvalars": "narval",
    "narvalen": "narval",
    "narvalens": "narval",
    "narvals": "narval",
    "narvande": "narva",
    "narvanden": "narvande",
    "narvandena": "narvande",
    "narvandenas": "narvande",
    "narvandens": "narvande",
    "narvandes": "narvande",
    "narvandet": "narvande",
    "narvandets": "narvande",
    "narvar": "narva",
    "narvas": "narva",
    "narvat": "narva",
    "narvats": "narva",
    "narven": "narv",
    "narvens": "narv",
    "narvfelen": "narvfel",
    "narvfelens": "narvfel",
    "narvfelet": "narvfel",
    "narvfelets": "narvfel",
    "narvfels": "narvfel",
    "narvhuggens": "narvhuggen",
    "narvhugget": "narvhuggen",
    "narvhuggets": "narvhuggen",
    "narvhuggna": "narvhuggen",
    "narvhuggnare": "narvhuggen",
    "narvhuggnares": "narvhuggen",
    "narvhuggnas": "narvhuggen",
    "narvhuggnast": "narvhuggen",
    "narvhuggnaste": "narvhuggen",
    "narvhuggnastes": "narvhuggen",
    "narvhuggnasts": "narvhuggen",
    "narvhuggne": "narvhuggen",
    "narvhuggnes": "narvhuggen",
    "narvs": "narv",
    "narvspalten": "narvspalt",
    "narvspaltens": "narvspalt",
    "narvspalter": "narvspalt",
    "narvspalterna": "narvspalt",
    "narvspalternas": "narvspalt",
    "narvspalters": "narvspalt",
    "narvspalts": "narvspalt",
    "nasad": "nasa",
    "nasade": "nasa",
    "nasades": "nasa",
    "nasads": "nasa",
    "nasala": "nasal",
    "nasalare": "nasal",
    "nasalares": "nasal",
    "nasalas": "nasal",
    "nasalast": "nasal",
    "nasalaste": "nasal",
    "nasalastes": "nasal",
    "nasalasts": "nasal",
    "nasale": "nasal",
    "nasalen": "nasal",
    "nasalens": "nasal",
    "nasaler": "nasal",
    "nasalerad": "nasalera",
    "nasalerade": "nasalera",
    "nasalerades": "nasalera",
    "nasalerads": "nasalera",
    "nasalerande": "nasalera",
    "nasaleranden": "nasalerande",
    "nasalerandena": "nasalerande",
    "nasalerandenas": "nasalerande",
    "nasalerandens": "nasalerande",
    "nasalerandes": "nasalerande",
    "nasalerandet": "nasalerande",
    "nasalerandets": "nasalerande",
    "nasalerar": "nasalera",
    "nasaleras": "nasalera",
    "nasalerat": "nasalera",
    "nasalerats": "nasalera",
    "nasalerbara": "nasalerbar",
    "nasalerbarare": "nasalerbar",
    "nasalerbarares": "nasalerbar",
    "nasalerbaras": "nasalerbar",
    "nasalerbarast": "nasalerbar",
    "nasalerbaraste": "nasalerbar",
    "nasalerbarastes": "nasalerbar",
    "nasalerbarasts": "nasalerbar",
    "nasalerbare": "nasalerbar",
    "nasalerbares": "nasalerbar",
    "nasalerbarheten": "nasalerbarhet",
    "nasalerbarhetens": "nasalerbarhet",
    "nasalerbarhets": "nasalerbarhet",
    "nasalerbars": "nasalerbar",
    "nasalerbart": "nasalerbar",
    "nasalerbarts": "nasalerbar",
    "nasaleringar": "nasalering",
    "nasaleringarna": "nasalering",
    "nasaleringarnas": "nasalering",
    "nasaleringars": "nasalering",
    "nasaleringen": "nasalering",
    "nasaleringens": "nasalering",
    "nasalerings": "nasalering",
    "nasalerna": "nasal",
    "nasalernas": "nasal",
    "nasalers": "nasal",
    "nasales": "nasal",
    "nasaliserad": "nasalisera",
    "nasaliserade": "nasalisera",
    "nasaliserades": "nasalisera",
    "nasaliserads": "nasalisera",
    "nasaliserande": "nasalisera",
    "nasaliseranden": "nasaliserande",
    "nasaliserandena": "nasaliserande",
    "nasaliserandenas": "nasaliserande",
    "nasaliserandens": "nasaliserande",
    "nasaliserandes": "nasaliserande",
    "nasaliserandet": "nasaliserande",
    "nasaliserandets": "nasaliserande",
    "nasaliserar": "nasalisera",
    "nasaliseras": "nasalisera",
    "nasaliserat": "nasalisera",
    "nasaliserats": "nasalisera",
    "nasaliserbara": "nasaliserbar",
    "nasaliserbarare": "nasaliserbar",
    "nasaliserbarares": "nasaliserbar",
    "nasaliserbaras": "nasaliserbar",
    "nasaliserbarast": "nasaliserbar",
    "nasaliserbaraste": "nasaliserbar",
    "nasaliserbarastes": "nasaliserbar",
    "nasaliserbarasts": "nasaliserbar",
    "nasaliserbare": "nasaliserbar",
    "nasaliserbares": "nasaliserbar",
    "nasaliserbarheten": "nasaliserbarhet",
    "nasaliserbarhetens": "nasaliserbarhet",
    "nasaliserbarhets": "nasaliserbarhet",
    "nasaliserbars": "nasaliserbar",
    "nasaliserbart": "nasaliserbar",
    "nasaliserbarts": "nasaliserbar",
    "nasaliseringar": "nasalisering",
    "nasaliseringarna": "nasalisering",
    "nasaliseringarnas": "nasalisering",
    "nasaliseringars": "nasalisering",
    "nasaliseringen": "nasalisering",
    "nasaliseringens": "nasalisering",
    "nasaliserings": "nasalisering",
    "nasals": "nasal",
    "nasalt": "nasal",
    "nasalts": "nasal",
    "nasande": "nasa",
    "nasanden": "nasande",
    "nasandena": "nasande",
    "nasandenas": "nasande",
    "nasandens": "nasande",
    "nasandes": "nasande",
    "nasandet": "nasande",
    "nasandets": "nasande",
    "nasar": "nasare",
    "nasaren": "nasare",
    "nasarens": "nasare",
    "nasares": "nasare",
    "nasarna": "nasare",
    "nasarnas": "nasare",
    "nasaréen": "nasaré",
    "nasaréens": "nasaré",
    "nasaréer": "nasaré",
    "nasaréerna": "nasaré",
    "nasaréernas": "nasaré",
    "nasaréers": "nasaré",
    "nasarén": "nasaré",
    "nasaréns": "nasaré",
    "nasarés": "nasaré",
    "nasat": "nasa",
    "nasats": "nasa",
    "nasiren": "nasir",
    "nasirens": "nasir",
    "nasirer": "nasir",
    "nasirerna": "nasir",
    "nasirernas": "nasir",
    "nasirers": "nasir",
    "nasirs": "nasir",
    "nassar": "nasse",
    "nassarna": "nasse",
    "nassarnas": "nasse",
    "nassars": "nasse",
    "nassen": "nasse",
    "nassens": "nasse",
    "nasses": "nasse",
    "nat": "nate",
    "natar": "nate",
    "natarna": "nate",
    "natarnas": "nate",
    "natars": "nate",
    "naten": "nate",
    "natens": "nate",
    "nates": "nate",
    "nationalbegreppen": "nationalbegrepp",
    "nationalbegreppens": "nationalbegrepp",
    "nationalbegreppet": "nationalbegrepp",
    "nationalbegreppets": "nationalbegrepp",
    "nationalbegrepps": "nationalbegrepp",
    "nationalbudgetar": "nationalbudget",
    "nationalbudgetarna": "nationalbudget",
    "nationalbudgetarnas": "nationalbudget",
    "nationalbudgetars": "nationalbudget",
    "nationalbudgeten": "nationalbudget",
    "nationalbudgetens": "nationalbudget",
    "nationalbudgeter": "nationalbudget",
    "nationalbudgeterna": "nationalbudget",
    "nationalbudgeternas": "nationalbudget",
    "nationalbudgeters": "nationalbudget",
    "nationalbudgets": "nationalbudget",
    "nationaldagar": "nationaldag",
    "nationaldagarna": "nationaldag",
    "nationaldagarnas": "nationaldag",
    "nationaldagars": "nationaldag",
    "nationaldagen": "nationaldag",
    "nationaldagens": "nationaldag",
    "nationaldags": "nationaldag",
    "nationaldragen": "nationaldrag",
    "nationaldragens": "nationaldrag",
    "nationaldraget": "nationaldrag",
    "nationaldragets": "nationaldrag",
    "nationaldrags": "nationaldrag",
    "nationaldräkten": "nationaldräkt",
    "nationaldräktens": "nationaldräkt",
    "nationaldräkter": "nationaldräkt",
    "nationaldräkterna": "nationaldräkt",
    "nationaldräkternas": "nationaldräkt",
    "nationaldräkters": "nationaldräkt",
    "nationaldräkts": "nationaldräkt",
    "nationalekonomen": "nationalekonom",
    "nationalekonomens": "nationalekonom",
    "nationalekonomer": "nationalekonom",
    "nationalekonomerna": "nationalekonom",
    "nationalekonomernas": "nationalekonom",
    "nationalekonomers": "nationalekonom",
    "nationalekonomien": "nationalekonomi",
    "nationalekonomiens": "nationalekonomi",
    "nationalekonomin": "nationalekonomi",
    "nationalekonomins": "nationalekonomi",
    "nationalekonomis": "nationalekonomi",
    "nationalekonomiska": "nationalekonomisk",
    "nationalekonomiskare": "nationalekonomisk",
    "nationalekonomiskares": "nationalekonomisk",
    "nationalekonomiskas": "nationalekonomisk",
    "nationalekonomiskast": "nationalekonomisk",
    "nationalekonomiskaste": "nationalekonomisk",
    "nationalekonomiskastes": "nationalekonomisk",
    "nationalekonomiskasts": "nationalekonomisk",
    "nationalekonomiske": "nationalekonomisk",
    "nationalekonomiskes": "nationalekonomisk",
    "nationalekonomisks": "nationalekonomisk",
    "nationalekonomiskt": "nationalekonomisk",
    "nationalekonomiskts": "nationalekonomisk",
    "nationalekonoms": "nationalekonom",
    "nationalflagg": "nationalflagga",
    "nationalflaggan": "nationalflagga",
    "nationalflaggans": "nationalflagga",
    "nationalflaggas": "nationalflagga",
    "nationalflagge": "nationalflagga",
    "nationalflaggor": "nationalflagga",
    "nationalflaggorna": "nationalflagga",
    "nationalflaggornas": "nationalflagga",
    "nationalflaggors": "nationalflagga",
    "nationalflaggs": "nationalflagga",
    "nationalföreningar": "nationalförening",
    "nationalföreningarna": "nationalförening",
    "nationalföreningarnas": "nationalförening",
    "nationalföreningars": "nationalförening",
    "nationalföreningen": "nationalförening",
    "nationalföreningens": "nationalförening",
    "nationalförenings": "nationalförening",
    "nationalförmögenheten": "nationalförmögenhet",
    "nationalförmögenhetens": "nationalförmögenhet",
    "nationalförmögenheter": "nationalförmögenhet",
    "nationalförmögenheterna": "nationalförmögenhet",
    "nationalförmögenheternas": "nationalförmögenhet",
    "nationalförmögenheters": "nationalförmögenhet",
    "nationalförmögenhets": "nationalförmögenhet",
    "nationalförsamlingar": "nationalförsamling",
    "nationalförsamlingarna": "nationalförsamling",
    "nationalförsamlingarnas": "nationalförsamling",
    "nationalförsamlingars": "nationalförsamling",
    "nationalförsamlingen": "nationalförsamling",
    "nationalförsamlingens": "nationalförsamling",
    "nationalförsamlings": "nationalförsamling",
    "nationalgallerier": "nationalgalleri",
    "nationalgallerierna": "nationalgalleri",
    "nationalgalleriernas": "nationalgalleri",
    "nationalgalleriers": "nationalgalleri",
    "nationalgalleriet": "nationalgalleri",
    "nationalgalleriets": "nationalgalleri",
    "nationalgalleris": "nationalgalleri",
    "nationalgallerit": "nationalgalleri",
    "nationalgallerits": "nationalgalleri",
    "nationalhelgonen": "nationalhelgon",
    "nationalhelgonens": "nationalhelgon",
    "nationalhelgonet": "nationalhelgon",
    "nationalhelgonets": "nationalhelgon",
    "nationalhelgons": "nationalhelgon",
    "nationalhjältar": "nationalhjälte",
    "nationalhjältarna": "nationalhjälte",
    "nationalhjältarnas": "nationalhjälte",
    "nationalhjältars": "nationalhjälte",
    "nationalhjälten": "nationalhjälte",
    "nationalhjältens": "nationalhjälte",
    "nationalhjältes": "nationalhjälte",
    "nationalinkomsten": "nationalinkomst",
    "nationalinkomstens": "nationalinkomst",
    "nationalinkomster": "nationalinkomst",
    "nationalinkomsterna": "nationalinkomst",
    "nationalinkomsternas": "nationalinkomst",
    "nationalinkomsters": "nationalinkomst",
    "nationalinkomsts": "nationalinkomst",
    "nationaliserad": "nationalisera",
    "nationaliserade": "nationalisera",
    "nationaliserades": "nationalisera",
    "nationaliserads": "nationalisera",
    "nationaliserande": "nationalisera",
    "nationaliseranden": "nationaliserande",
    "nationaliserandena": "nationaliserande",
    "nationaliserandenas": "nationaliserande",
    "nationaliserandens": "nationaliserande",
    "nationaliserandes": "nationaliserande",
    "nationaliserandet": "nationaliserande",
    "nationaliserandets": "nationaliserande",
    "nationaliserar": "nationalisera",
    "nationaliseras": "nationalisera",
    "nationaliserat": "nationalisera",
    "nationaliserats": "nationalisera",
    "nationaliserbara": "nationaliserbar",
    "nationaliserbarare": "nationaliserbar",
    "nationaliserbarares": "nationaliserbar",
    "nationaliserbaras": "nationaliserbar",
    "nationaliserbarast": "nationaliserbar",
    "nationaliserbaraste": "nationaliserbar",
    "nationaliserbarastes": "nationaliserbar",
    "nationaliserbarasts": "nationaliserbar",
    "nationaliserbare": "nationaliserbar",
    "nationaliserbares": "nationaliserbar",
    "nationaliserbarheten": "nationaliserbarhet",
    "nationaliserbarhetens": "nationaliserbarhet",
    "nationaliserbarhets": "nationaliserbarhet",
    "nationaliserbars": "nationaliserbar",
    "nationaliserbart": "nationaliserbar",
    "nationaliserbarts": "nationaliserbar",
    "nationaliseringar": "nationalisering",
    "nationaliseringarna": "nationalisering",
    "nationaliseringarnas": "nationalisering",
    "nationaliseringars": "nationalisering",
    "nationaliseringen": "nationalisering",
    "nationaliseringens": "nationalisering",
    "nationaliserings": "nationalisering",
    "nationalismen": "nationalism",
    "nationalismens": "nationalism",
    "nationalismer": "nationalism",
    "nationalismerna": "nationalism",
    "nationalismernas": "nationalism",
    "nationalismers": "nationalism",
    "nationalisms": "nationalism",
    "nationalisten": "nationalist",
    "nationalistens": "nationalist",
    "nationalister": "nationalist",
    "nationalisterna": "nationalist",
    "nationalisternas": "nationalist",
    "nationalisters": "nationalist",
    "nationalistiska": "nationalistisk",
    "nationalistiskare": "nationalistisk",
    "nationalistiskares": "nationalistisk",
    "nationalistiskas": "nationalistisk",
    "nationalistiskast": "nationalistisk",
    "nationalistiskaste": "nationalistisk",
    "nationalistiskastes": "nationalistisk",
    "nationalistiskasts": "nationalistisk",
    "nationalistiske": "nationalistisk",
    "nationalistiskes": "nationalistisk",
    "nationalistisks": "nationalistisk",
    "nationalistiskt": "nationalistisk",
    "nationalistiskts": "nationalistisk",
    "nationalistledar": "nationalistledare",
    "nationalistledaren": "nationalistledare",
    "nationalistledarens": "nationalistledare",
    "nationalistledares": "nationalistledare",
    "nationalistledarna": "nationalistledare",
    "nationalistledarnas": "nationalistledare",
    "nationalists": "nationalist",
    "nationaliteten": "nationalitet",
    "nationalitetens": "nationalitet",
    "nationaliteter": "nationalitet",
    "nationaliteterna": "nationalitet",
    "nationaliteternas": "nationalitet",
    "nationaliteters": "nationalitet",
    "nationalitets": "nationalitet",
    "nationalitetsbeteckningar": "nationalitetsbeteckning",
    "nationalitetsbeteckningarna": "nationalitetsbeteckning",
    "nationalitetsbeteckningarnas": "nationalitetsbeteckning",
    "nationalitetsbeteckningars": "nationalitetsbeteckning",
    "nationalitetsbeteckningen": "nationalitetsbeteckning",
    "nationalitetsbeteckningens": "nationalitetsbeteckning",
    "nationalitetsbetecknings": "nationalitetsbeteckning",
    "nationalitetsbevisen": "nationalitetsbevis",
    "nationalitetsbevisens": "nationalitetsbevis",
    "nationalitetsbeviset": "nationalitetsbevis",
    "nationalitetsbevisets": "nationalitetsbevis",
    "nationalitetsbokstaven": "nationalitetsbokstav",
    "nationalitetsbokstavens": "nationalitetsbokstav",
    "nationalitetsbokstavs": "nationalitetsbokstav",
    "nationalitetsbokstäver": "nationalitetsbokstav",
    "nationalitetsbokstäverna": "nationalitetsbokstav",
    "nationalitetsbokstävernas": "nationalitetsbokstav",
    "nationalitetsbokstävers": "nationalitetsbokstav",
    "nationalitetscertifikaten": "nationalitetscertifikat",
    "nationalitetscertifikatens": "nationalitetscertifikat",
    "nationalitetscertifikatet": "nationalitetscertifikat",
    "nationalitetscertifikatets": "nationalitetscertifikat",
    "nationalitetscertifikats": "nationalitetscertifikat",
    "nationalitetsflagg": "nationalitetsflagga",
    "nationalitetsflaggan": "nationalitetsflagga",
    "nationalitetsflaggans": "nationalitetsflagga",
    "nationalitetsflaggas": "nationalitetsflagga",
    "nationalitetsflagge": "nationalitetsflagga",
    "nationalitetsflaggor": "nationalitetsflagga",
    "nationalitetsflaggorna": "nationalitetsflagga",
    "nationalitetsflaggornas": "nationalitetsflagga",
    "nationalitetsflaggors": "nationalitetsflagga",
    "nationalitetsflaggs": "nationalitetsflagga",
    "nationalitetshandlingar": "nationalitetshandling",
    "nationalitetshandlingarna": "nationalitetshandling",
    "nationalitetshandlingarnas": "nationalitetshandling",
    "nationalitetshandlingars": "nationalitetshandling",
    "nationalitetshandlingen": "nationalitetshandling",
    "nationalitetshandlingens": "nationalitetshandling",
    "nationalitetshandlings": "nationalitetshandling",
    "nationalitetsintygen": "nationalitetsintyg",
    "nationalitetsintygens": "nationalitetsintyg",
    "nationalitetsintyget": "nationalitetsintyg",
    "nationalitetsintygets": "nationalitetsintyg",
    "nationalitetsintygs": "nationalitetsintyg",
    "nationalitetsmatrikeln": "nationalitetsmatrikel",
    "nationalitetsmatrikelns": "nationalitetsmatrikel",
    "nationalitetsmatrikels": "nationalitetsmatrikel",
    "nationalitetsmatriklar": "nationalitetsmatrikel",
    "nationalitetsmatriklarna": "nationalitetsmatrikel",
    "nationalitetsmatriklarnas": "nationalitetsmatrikel",
    "nationalitetsmatriklars": "nationalitetsmatrikel",
    "nationalitetsmärken": "nationalitetsmärke",
    "nationalitetsmärkena": "nationalitetsmärke",
    "nationalitetsmärkenas": "nationalitetsmärke",
    "nationalitetsmärkens": "nationalitetsmärke",
    "nationalitetsmärkes": "nationalitetsmärke",
    "nationalitetsmärket": "nationalitetsmärke",
    "nationalitetsmärkets": "nationalitetsmärke",
    "nationalitetsprincipen": "nationalitetsprincip",
    "nationalitetsprincipens": "nationalitetsprincip",
    "nationalitetsprincips": "nationalitetsprincip",
    "nationalitetsspiller": "nationalitetsspillra",
    "nationalitetsspillran": "nationalitetsspillra",
    "nationalitetsspillrans": "nationalitetsspillra",
    "nationalitetsspillras": "nationalitetsspillra",
    "nationalitetsspillre": "nationalitetsspillra",
    "nationalitetsspillror": "nationalitetsspillra",
    "nationalitetsspillrorna": "nationalitetsspillra",
    "nationalitetsspillrornas": "nationalitetsspillra",
    "nationalitetsspillrors": "nationalitetsspillra",
    "nationalitetssträvanden": "nationalitetssträvande",
    "nationalitetssträvandena": "nationalitetssträvande",
    "nationalitetssträvandenas": "nationalitetssträvande",
    "nationalitetssträvandens": "nationalitetssträvande",
    "nationalitetssträvandes": "nationalitetssträvande",
    "nationalitetssträvandet": "nationalitetssträvande",
    "nationalitetssträvandets": "nationalitetssträvande",
    "nationalitetssträvans": "nationalitetssträvan",
    "nationalkapitalen": "nationalkapital",
    "nationalkapitalens": "nationalkapital",
    "nationalkapitalet": "nationalkapital",
    "nationalkapitalets": "nationalkapital",
    "nationalkapitals": "nationalkapital",
    "nationalkaraktären": "nationalkaraktär",
    "nationalkaraktärens": "nationalkaraktär",
    "nationalkaraktärer": "nationalkaraktär",
    "nationalkaraktärerna": "nationalkaraktär",
    "nationalkaraktärernas": "nationalkaraktär",
    "nationalkaraktärers": "nationalkaraktär",
    "nationalkaraktärs": "nationalkaraktär",
    "nationalkyrk": "nationalkyrka",
    "nationalkyrkan": "nationalkyrka",
    "nationalkyrkans": "nationalkyrka",
    "nationalkyrkas": "nationalkyrka",
    "nationalkyrke": "nationalkyrka",
    "nationalkyrko": "nationalkyrka",
    "nationalkyrkor": "nationalkyrka",
    "nationalkyrkorna": "nationalkyrka",
    "nationalkyrkornas": "nationalkyrka",
    "nationalkyrkors": "nationalkyrka",
    "nationalkyrks": "nationalkyrka",
    "nationalkänslan": "nationalkänsla",
    "nationalkänslans": "nationalkänsla",
    "nationalkänslas": "nationalkänsla",
    "nationalkänsle": "nationalkänsla",
    "nationalkänslo": "nationalkänsla",
    "nationalmedvetanden": "nationalmedvetande",
    "nationalmedvetandena": "nationalmedvetande",
    "nationalmedvetandenas": "nationalmedvetande",
    "nationalmedvetandens": "nationalmedvetande",
    "nationalmedvetandes": "nationalmedvetande",
    "nationalmedvetandet": "nationalmedvetande",
    "nationalmedvetandets": "nationalmedvetande",
    "nationalmuseer": "nationalmuseum",
    "nationalmuseerna": "nationalmuseum",
    "nationalmuseernas": "nationalmuseum",
    "nationalmuseers": "nationalmuseum",
    "nationalmuseet": "nationalmuseum",
    "nationalmuseets": "nationalmuseum",
    "nationalmusei": "nationalmuseum",
    "nationalmuseums": "nationalmuseum",
    "nationalparken": "nationalpark",
    "nationalparkens": "nationalpark",
    "nationalparker": "nationalpark",
    "nationalparkerna": "nationalpark",
    "nationalparkernas": "nationalpark",
    "nationalparkers": "nationalpark",
    "nationalparks": "nationalpark",
    "nationalprodukten": "nationalprodukt",
    "nationalproduktens": "nationalprodukt",
    "nationalprodukter": "nationalprodukt",
    "nationalprodukterna": "nationalprodukt",
    "nationalprodukternas": "nationalprodukt",
    "nationalprodukters": "nationalprodukt",
    "nationalprodukts": "nationalprodukt",
    "nationalromantiken": "nationalromantik",
    "nationalromantikens": "nationalromantik",
    "nationalromantiks": "nationalromantik",
    "nationalromantiska": "nationalromantisk",
    "nationalromantiskare": "nationalromantisk",
    "nationalromantiskares": "nationalromantisk",
    "nationalromantiskas": "nationalromantisk",
    "nationalromantiskast": "nationalromantisk",
    "nationalromantiskaste": "nationalromantisk",
    "nationalromantiskastes": "nationalromantisk",
    "nationalromantiskasts": "nationalromantisk",
    "nationalromantiske": "nationalromantisk",
    "nationalromantiskes": "nationalromantisk",
    "nationalromantisks": "nationalromantisk",
    "nationalromantiskt": "nationalromantisk",
    "nationalromantiskts": "nationalromantisk",
    "nationalrätten": "nationalrätt",
    "nationalrättens": "nationalrätt",
    "nationalrätter": "nationalrätt",
    "nationalrätterna": "nationalrätt",
    "nationalrätternas": "nationalrätt",
    "nationalrätters": "nationalrätt",
    "nationalrätts": "nationalrätt",
    "nationalscenen": "nationalscen",
    "nationalscenens": "nationalscen",
    "nationalscener": "nationalscen",
    "nationalscenerna": "nationalscen",
    "nationalscenernas": "nationalscen",
    "nationalsceners": "nationalscen",
    "nationalscens": "nationalscen",
    "nationalskalden": "nationalskald",
    "nationalskaldens": "nationalskald",
    "nationalskalder": "nationalskald",
    "nationalskalderna": "nationalskald",
    "nationalskaldernas": "nationalskald",
    "nationalskalders": "nationalskald",
    "nationalskalds": "nationalskald",
    "nationalsocialismen": "nationalsocialism",
    "nationalsocialismens": "nationalsocialism",
    "nationalsocialismer": "nationalsocialism",
    "nationalsocialismerna": "nationalsocialism",
    "nationalsocialismernas": "nationalsocialism",
    "nationalsocialismers": "nationalsocialism",
    "nationalsocialisms": "nationalsocialism",
    "nationalsocialisten": "nationalsocialist",
    "nationalsocialistens": "nationalsocialist",
    "nationalsocialister": "nationalsocialist",
    "nationalsocialisterna": "nationalsocialist",
    "nationalsocialisternas": "nationalsocialist",
    "nationalsocialisters": "nationalsocialist",
    "nationalsocialistiska": "nationalsocialistisk",
    "nationalsocialistiskare": "nationalsocialistisk",
    "nationalsocialistiskares": "nationalsocialistisk",
    "nationalsocialistiskas": "nationalsocialistisk",
    "nationalsocialistiskast": "nationalsocialistisk",
    "nationalsocialistiskaste": "nationalsocialistisk",
    "nationalsocialistiskastes": "nationalsocialistisk",
    "nationalsocialistiskasts": "nationalsocialistisk",
    "nationalsocialistiske": "nationalsocialistisk",
    "nationalsocialistiskes": "nationalsocialistisk",
    "nationalsocialistisks": "nationalsocialistisk",
    "nationalsocialistiskt": "nationalsocialistisk",
    "nationalsocialistiskts": "nationalsocialistisk",
    "nationalsocialists": "nationalsocialist",
    "nationalsporten": "nationalsport",
    "nationalsportens": "nationalsport",
    "nationalsporter": "nationalsport",
    "nationalsporterna": "nationalsport",
    "nationalsporternas": "nationalsport",
    "nationalsporters": "nationalsport",
    "nationalsports": "nationalsport",
    "nationalspråken": "nationalspråk",
    "nationalspråkens": "nationalspråk",
    "nationalspråket": "nationalspråk",
    "nationalspråkets": "nationalspråk",
    "nationalspråks": "nationalspråk",
    "nationalstaten": "nationalstat",
    "nationalstatens": "nationalstat",
    "nationalstater": "nationalstat",
    "nationalstaterna": "nationalstat",
    "nationalstaternas": "nationalstat",
    "nationalstaters": "nationalstat",
    "nationalstats": "nationalstat",
    "nationalsången": "nationalsång",
    "nationalsångens": "nationalsång",
    "nationalsånger": "nationalsång",
    "nationalsångerna": "nationalsång",
    "nationalsångernas": "nationalsång",
    "nationalsångers": "nationalsång",
    "nationalsångs": "nationalsång",
    "nationalteatern": "nationalteater",
    "nationalteaterns": "nationalteater",
    "nationalteaters": "nationalteater",
    "nationalteatrar": "nationalteater",
    "nationalteatrarna": "nationalteater",
    "nationalteatrarnas": "nationalteater",
    "nationalteatrars": "nationalteater",
    "nationella": "nationell",
    "nationellare": "nationell",
    "nationellares": "nationell",
    "nationellas": "nationell",
    "nationellast": "nationell",
    "nationellaste": "nationell",
    "nationellastes": "nationell",
    "nationellasts": "nationell",
    "nationelle": "nationell",
    "nationelles": "nationell",
    "nationells": "nationell",
    "nationellt": "nationell",
    "nationellts": "nationell",
    "nationen": "nation",
    "nationens": "nation",
    "nationer": "nation",
    "nationerna": "nation",
    "nationernas": "nation",
    "nationers": "nation",
    "nations": "nation",
    "nationsavgiften": "nationsavgift",
    "nationsavgiftens": "nationsavgift",
    "nationsavgifter": "nationsavgift",
    "nationsavgifterna": "nationsavgift",
    "nationsavgifternas": "nationsavgift",
    "nationsavgifters": "nationsavgift",
    "nationsavgifts": "nationsavgift",
    "nationsbyggen": "nationsbygge",
    "nationsbyggena": "nationsbygge",
    "nationsbyggenas": "nationsbygge",
    "nationsbyggens": "nationsbygge",
    "nationsbygges": "nationsbygge",
    "nationsbygget": "nationsbygge",
    "nationsbyggets": "nationsbygge",
    "nationsflagg": "nationsflagga",
    "nationsflaggan": "nationsflagga",
    "nationsflaggans": "nationsflagga",
    "nationsflaggas": "nationsflagga",
    "nationsflagge": "nationsflagga",
    "nationsflaggor": "nationsflagga",
    "nationsflaggorna": "nationsflagga",
    "nationsflaggornas": "nationsflagga",
    "nationsflaggors": "nationsflagga",
    "nationsflaggs": "nationsflagga",
    "nationsinspektorer": "nationsinspektor",
    "nationsinspektorerna": "nationsinspektor",
    "nationsinspektorernas": "nationsinspektor",
    "nationsinspektorers": "nationsinspektor",
    "nationsinspektorn": "nationsinspektor",
    "nationsinspektorns": "nationsinspektor",
    "nationsinspektors": "nationsinspektor",
    "nationskuratorer": "nationskurator",
    "nationskuratorerna": "nationskurator",
    "nationskuratorernas": "nationskurator",
    "nationskuratorers": "nationskurator",
    "nationskuratorn": "nationskurator",
    "nationskuratorns": "nationskurator",
    "nationskurators": "nationskurator",
    "nativa": "nativ",
    "nativare": "nativ",
    "nativares": "nativ",
    "nativas": "nativ",
    "nativast": "nativ",
    "nativaste": "nativ",
    "nativastes": "nativ",
    "nativasts": "nativ",
    "native": "nativ",
    "natives": "nativ",
    "nativiteten": "nativitet",
    "nativitetens": "nativitet",
    "nativiteter": "nativitet",
    "nativiteterna": "nativitet",
    "nativiteternas": "nativitet",
    "nativiteters": "nativitet",
    "nativitets": "nativitet",
    "nativs": "nativ",
    "nativt": "nativ",
    "nativts": "nativ",
    "natriet": "natrium",
    "natriets": "natrium",
    "natriumbikarbonaten": "natriumbikarbonat",
    "natriumbikarbonatens": "natriumbikarbonat",
    "natriumbikarbonatet": "natriumbikarbonat",
    "natriumbikarbonatets": "natriumbikarbonat",
    "natriumbikarbonats": "natriumbikarbonat",
    "natriumet": "natrium",
    "natriumets": "natrium",
    "natriumhalten": "natriumhalt",
    "natriumhaltens": "natriumhalt",
    "natriumhalter": "natriumhalt",
    "natriumhalterna": "natriumhalt",
    "natriumhalternas": "natriumhalt",
    "natriumhalters": "natriumhalt",
    "natriumhalts": "natriumhalt",
    "natriumhydroxiden": "natriumhydroxid",
    "natriumhydroxidens": "natriumhydroxid",
    "natriumhydroxider": "natriumhydroxid",
    "natriumhydroxiderna": "natriumhydroxid",
    "natriumhydroxidernas": "natriumhydroxid",
    "natriumhydroxiders": "natriumhydroxid",
    "natriumhydroxids": "natriumhydroxid",
    "natriumkloriden": "natriumklorid",
    "natriumkloridens": "natriumklorid",
    "natriumklorids": "natriumklorid",
    "natriumkonsumtionen": "natriumkonsumtion",
    "natriumkonsumtionens": "natriumkonsumtion",
    "natriumkonsumtioner": "natriumkonsumtion",
    "natriumkonsumtionerna": "natriumkonsumtion",
    "natriumkonsumtionernas": "natriumkonsumtion",
    "natriumkonsumtioners": "natriumkonsumtion",
    "natriumkonsumtions": "natriumkonsumtion",
    "natriumlamp": "natriumlampa",
    "natriumlampan": "natriumlampa",
    "natriumlampans": "natriumlampa",
    "natriumlampas": "natriumlampa",
    "natriumlampe": "natriumlampa",
    "natriumlampor": "natriumlampa",
    "natriumlamporna": "natriumlampa",
    "natriumlampornas": "natriumlampa",
    "natriumlampors": "natriumlampa",
    "natriumlamps": "natriumlampa",
    "natriumnitraten": "natriumnitrat",
    "natriumnitratens": "natriumnitrat",
    "natriumnitrater": "natriumnitrat",
    "natriumnitraterna": "natriumnitrat",
    "natriumnitraternas": "natriumnitrat",
    "natriumnitraters": "natriumnitrat",
    "natriumnitratet": "natriumnitrat",
    "natriumnitratets": "natriumnitrat",
    "natriumnitrats": "natriumnitrat",
    "natriums": "natrium",
    "natriumsulfaten": "natriumsulfat",
    "natriumsulfatens": "natriumsulfat",
    "natriumsulfater": "natriumsulfat",
    "natriumsulfaterna": "natriumsulfat",
    "natriumsulfaternas": "natriumsulfat",
    "natriumsulfaters": "natriumsulfat",
    "natriumsulfatet": "natriumsulfat",
    "natriumsulfatets": "natriumsulfat",
    "natriumsulfats": "natriumsulfat",
    "natriumtiosulfaten": "natriumtiosulfat",
    "natriumtiosulfatens": "natriumtiosulfat",
    "natriumtiosulfater": "natriumtiosulfat",
    "natriumtiosulfaterna": "natriumtiosulfat",
    "natriumtiosulfaternas": "natriumtiosulfat",
    "natriumtiosulfaters": "natriumtiosulfat",
    "natriumtiosulfatet": "natriumtiosulfat",
    "natriumtiosulfatets": "natriumtiosulfat",
    "natriumtiosulfats": "natriumtiosulfat",
    "natroncellulosan": "natroncellulosa",
    "natroncellulosans": "natroncellulosa",
    "natroncellulosas": "natroncellulosa",
    "natronet": "natron",
    "natronets": "natron",
    "natronglaset": "natronglas",
    "natronglasets": "natronglas",
    "natronlutar": "natronlut",
    "natronlutarna": "natronlut",
    "natronlutarnas": "natronlut",
    "natronlutars": "natronlut",
    "natronluten": "natronlut",
    "natronlutens": "natronlut",
    "natronluts": "natronlut",
    "natrons": "natron",
    "natronsalpetern": "natronsalpeter",
    "natronsalpeterns": "natronsalpeter",
    "natronsalpeters": "natronsalpeter",
    "nats": "nate",
    "natt": "natta",
    "nattad": "natta",
    "nattade": "natta",
    "nattades": "nattas",
    "nattads": "natta",
    "nattaktiva": "nattaktiv",
    "nattaktivare": "nattaktiv",
    "nattaktivares": "nattaktiv",
    "nattaktivas": "nattaktiv",
    "nattaktivast": "nattaktiv",
    "nattaktivaste": "nattaktiv",
    "nattaktivastes": "nattaktiv",
    "nattaktivasts": "nattaktiv",
    "nattaktive": "nattaktiv",
    "nattaktives": "nattaktiv",
    "nattaktivs": "nattaktiv",
    "nattaktivt": "nattaktiv",
    "nattaktivts": "nattaktiv",
    "nattande": "natta",
    "nattanden": "nattande",
    "nattandena": "nattande",
    "nattandenas": "nattande",
    "nattandens": "nattande",
    "nattandes": "nattande",
    "nattandet": "nattande",
    "nattandets": "nattande",
    "nattar": "natta",
    "nattas": "natta",
    "nattat": "natta",
    "nattats": "nattas",
    "nattblack": "nattblacka",
    "nattblackan": "nattblacka",
    "nattblackans": "nattblacka",
    "nattblackas": "nattblacka",
    "nattblacke": "nattblacka",
    "nattblackor": "nattblacka",
    "nattblackorna": "nattblacka",
    "nattblackornas": "nattblacka",
    "nattblackors": "nattblacka",
    "nattblacks": "nattblacka",
    "nattblinda": "nattblind",
    "nattblindare": "nattblind",
    "nattblindares": "nattblind",
    "nattblindas": "nattblind",
    "nattblindast": "nattblind",
    "nattblindaste": "nattblind",
    "nattblindastes": "nattblind",
    "nattblindasts": "nattblind",
    "nattblinde": "nattblind",
    "nattblindes": "nattblind",
    "nattblindheten": "nattblindhet",
    "nattblindhetens": "nattblindhet",
    "nattblindheter": "nattblindhet",
    "nattblindheterna": "nattblindhet",
    "nattblindheternas": "nattblindhet",
    "nattblindheters": "nattblindhet",
    "nattblindhets": "nattblindhet",
    "nattblinds": "nattblind",
    "nattblint": "nattblind",
    "nattblints": "nattblind",
    "nattblom": "nattblomma",
    "nattblomman": "nattblomma",
    "nattblommans": "nattblomma",
    "nattblommas": "nattblomma",
    "nattblomme": "nattblomma",
    "nattblommor": "nattblomma",
    "nattblommorna": "nattblomma",
    "nattblommornas": "nattblomma",
    "nattblommors": "nattblomma",
    "nattbloms": "nattblomma",
    "nattblåa": "nattblå",
    "nattblåare": "nattblå",
    "nattblåares": "nattblå",
    "nattblåas": "nattblå",
    "nattblåast": "nattblå",
    "nattblåaste": "nattblå",
    "nattblåastes": "nattblå",
    "nattblåasts": "nattblå",
    "nattblåe": "nattblå",
    "nattblåes": "nattblå",
    "nattblås": "nattblå",
    "nattblått": "nattblå",
    "nattblåtts": "nattblå",
    "nattborden": "nattbord",
    "nattbordens": "nattbord",
    "nattbordet": "nattbord",
    "nattbordets": "nattbord",
    "nattbords": "nattbord",
    "nattdjuren": "nattdjur",
    "nattdjurens": "nattdjur",
    "nattdjuret": "nattdjur",
    "nattdjurets": "nattdjur",
    "nattdjurs": "nattdjur",
    "nattdräkten": "nattdräkt",
    "nattdräktens": "nattdräkt",
    "nattdräkter": "nattdräkt",
    "nattdräkterna": "nattdräkt",
    "nattdräkternas": "nattdräkt",
    "nattdräkters": "nattdräkt",
    "nattdräkts": "nattdräkt",
    "nattduksborden": "nattduksbord",
    "nattduksbordens": "nattduksbord",
    "nattduksbordet": "nattduksbord",
    "nattduksbordets": "nattduksbord",
    "nattduksbords": "nattduksbord",
    "nattduksbordslåd": "nattduksbordslåda",
    "nattduksbordslådan": "nattduksbordslåda",
    "nattduksbordslådans": "nattduksbordslåda",
    "nattduksbordslådas": "nattduksbordslåda",
    "nattduksbordslåde": "nattduksbordslåda",
    "nattduksbordslådor": "nattduksbordslåda",
    "nattduksbordslådorna": "nattduksbordslåda",
    "nattduksbordslådornas": "nattduksbordslåda",
    "nattduksbordslådors": "nattduksbordslåda",
    "nattduksbordslåds": "nattduksbordslåda",
    "natteffekten": "natteffekt",
    "natteffektens": "natteffekt",
    "natteffekts": "natteffekt",
    "natten": "natt",
    "nattens": "natt",
    "nattfacken": "nattfack",
    "nattfackens": "nattfack",
    "nattfacket": "nattfack",
    "nattfackets": "nattfack",
    "nattfacks": "nattfack",
    "nattfjärilar": "nattfjäril",
    "nattfjärilarna": "nattfjäril",
    "nattfjärilarnas": "nattfjäril",
    "nattfjärilars": "nattfjäril",
    "nattfjärilen": "nattfjäril",
    "nattfjärilens": "nattfjäril",
    "nattfjäriln": "nattfjäril",
    "nattfjärilns": "nattfjäril",
    "nattfjärils": "nattfjäril",
    "nattflyen": "nattfly",
    "nattflyens": "nattfly",
    "nattflyet": "nattfly",
    "nattflyets": "nattfly",
    "nattflyn": "nattfly",
    "nattflyna": "nattfly",
    "nattflynas": "nattfly",
    "nattflyns": "nattfly",
    "nattflys": "nattfly",
    "nattflyt": "nattfly",
    "nattflyts": "nattfly",
    "nattfriar": "nattfriare",
    "nattfriaren": "nattfriare",
    "nattfriarens": "nattfriare",
    "nattfriares": "nattfriare",
    "nattfriarna": "nattfriare",
    "nattfriarnas": "nattfriare",
    "nattfrierier": "nattfrieri",
    "nattfrierierna": "nattfrieri",
    "nattfrieriernas": "nattfrieri",
    "nattfrieriers": "nattfrieri",
    "nattfrieriet": "nattfrieri",
    "nattfrieriets": "nattfrieri",
    "nattfrieris": "nattfrieri",
    "nattfrierit": "nattfrieri",
    "nattfrierits": "nattfrieri",
    "nattfrosten": "nattfrost",
    "nattfrostens": "nattfrost",
    "nattfrosts": "nattfrost",
    "nattfrusens": "nattfrusen",
    "nattfruset": "nattfrusen",
    "nattfrusets": "nattfrusen",
    "nattfrusna": "nattfrusen",
    "nattfrusnare": "nattfrusen",
    "nattfrusnares": "nattfrusen",
    "nattfrusnas": "nattfrusen",
    "nattfrusnast": "nattfrusen",
    "nattfrusnaste": "nattfrusen",
    "nattfrusnastes": "nattfrusen",
    "nattfrusnasts": "nattfrusen",
    "nattfrusne": "nattfrusen",
    "nattfrusnes": "nattfrusen",
    "nattfrämmandes": "nattfrämmande",
    "nattfrämmandet": "nattfrämmande",
    "nattfrämmandets": "nattfrämmande",
    "nattfågeln": "nattfågel",
    "nattfågelns": "nattfågel",
    "nattfågels": "nattfågel",
    "nattfåglar": "nattfågel",
    "nattfåglarna": "nattfågel",
    "nattfåglarnas": "nattfågel",
    "nattfåglars": "nattfågel",
    "nattgamla": "nattgammal",
    "nattgamlas": "nattgammal",
    "nattgamle": "nattgammal",
    "nattgamles": "nattgammal",
    "nattgammals": "nattgammal",
    "nattgammalt": "nattgammal",
    "nattgammalts": "nattgammal",
    "nattglimmen": "nattglim",
    "nattglimmens": "nattglim",
    "nattglims": "nattglim",
    "nattgångens": "nattgången",
    "nattgånget": "nattgången",
    "nattgångets": "nattgången",
    "nattgångna": "nattgången",
    "nattgångnare": "nattgången",
    "nattgångnares": "nattgången",
    "nattgångnas": "nattgången",
    "nattgångnast": "nattgången",
    "nattgångnaste": "nattgången",
    "nattgångnastes": "nattgången",
    "nattgångnasts": "nattgången",
    "nattgångne": "nattgången",
    "nattgångnes": "nattgången",
    "natthamnar": "natthamn",
    "natthamnarna": "natthamn",
    "natthamnarnas": "natthamn",
    "natthamnars": "natthamn",
    "natthamnen": "natthamn",
    "natthamnens": "natthamn",
    "natthamns": "natthamn",
    "natthimlar": "natthimmel",
    "natthimlarna": "natthimmel",
    "natthimlarnas": "natthimmel",
    "natthimlars": "natthimmel",
    "natthimlen": "natthimmel",
    "natthimlens": "natthimmel",
    "natthimmelen": "natthimmel",
    "natthimmelens": "natthimmel",
    "natthimmeln": "natthimmel",
    "natthimmelns": "natthimmel",
    "natthimmels": "natthimmel",
    "nattinéer": "nattiné",
    "nattinéerna": "nattiné",
    "nattinéernas": "nattiné",
    "nattinéers": "nattiné",
    "nattinén": "nattiné",
    "nattinéns": "nattiné",
    "nattinés": "nattiné",
    "nattisar": "nattis",
    "nattisarna": "nattis",
    "nattisarnas": "nattis",
    "nattisars": "nattis",
    "nattisen": "nattis",
    "nattisens": "nattis",
    "nattiset": "nattis",
    "nattisets": "nattis",
    "nattjouren": "nattjour",
    "nattjourens": "nattjour",
    "nattjourer": "nattjour",
    "nattjourerna": "nattjour",
    "nattjourernas": "nattjour",
    "nattjourers": "nattjour",
    "nattjours": "nattjour",
    "nattkappan": "nattkappa",
    "nattkappans": "nattkappa",
    "nattkappas": "nattkappa",
    "nattkappe": "nattkappa",
    "nattkappor": "nattkappa",
    "nattkapporna": "nattkappa",
    "nattkappornas": "nattkappa",
    "nattkappors": "nattkappa",
    "nattkikar": "nattkikare",
    "nattkikaren": "nattkikare",
    "nattkikarens": "nattkikare",
    "nattkikares": "nattkikare",
    "nattkikarna": "nattkikare",
    "nattkikarnas": "nattkikare",
    "nattklock": "nattklocka",
    "nattklockan": "nattklocka",
    "nattklockans": "nattklocka",
    "nattklockas": "nattklocka",
    "nattklocke": "nattklocka",
    "nattklockor": "nattklocka",
    "nattklockorna": "nattklocka",
    "nattklockornas": "nattklocka",
    "nattklockors": "nattklocka",
    "nattklocks": "nattklocka",
    "nattklubbar": "nattklubb",
    "nattklubbarna": "nattklubb",
    "nattklubbarnas": "nattklubb",
    "nattklubbars": "nattklubb",
    "nattklubben": "nattklubb",
    "nattklubbens": "nattklubb",
    "nattklubbs": "nattklubb",
    "nattkläderna": "nattkläder",
    "nattklädernas": "nattkläder",
    "nattkläders": "nattkläder",
    "nattklädes": "nattkläder",
    "nattkläds": "nattkläder",
    "nattkrämen": "nattkräm",
    "nattkrämens": "nattkräm",
    "nattkrämer": "nattkräm",
    "nattkrämerna": "nattkräm",
    "nattkrämernas": "nattkräm",
    "nattkrämers": "nattkräm",
    "nattkräms": "nattkräm",
    "nattkrökens": "nattkröken",
    "nattkulans": "nattkulan",
    "nattkvistens": "nattkvisten",
    "nattkylan": "nattkyla",
    "nattkylans": "nattkyla",
    "nattkylas": "nattkyla",
    "nattkyle": "nattkyla",
    "nattkärlen": "nattkärl",
    "nattkärlens": "nattkärl",
    "nattkärlet": "nattkärl",
    "nattkärlets": "nattkärl",
    "nattkärls": "nattkärl",
    "nattlamp": "nattlampa",
    "nattlampan": "nattlampa",
    "nattlampans": "nattlampa",
    "nattlampas": "nattlampa",
    "nattlampe": "nattlampa",
    "nattlampor": "nattlampa",
    "nattlamporna": "nattlampa",
    "nattlampornas": "nattlampa",
    "nattlampors": "nattlampa",
    "nattlamps": "nattlampa",
    "nattliga": "nattlig",
    "nattligare": "nattlig",
    "nattligares": "nattlig",
    "nattligas": "nattlig",
    "nattligast": "nattlig",
    "nattligaste": "nattlig",
    "nattligastes": "nattlig",
    "nattligasts": "nattlig",
    "nattlige": "nattlig",
    "nattliges": "nattlig",
    "nattligs": "nattlig",
    "nattligt": "nattlig",
    "nattligts": "nattlig",
    "nattlika": "nattlik",
    "nattlikare": "nattlik",
    "nattlikares": "nattlik",
    "nattlikas": "nattlik",
    "nattlikast": "nattlik",
    "nattlikaste": "nattlik",
    "nattlikastes": "nattlik",
    "nattlikasts": "nattlik",
    "nattlike": "nattlik",
    "nattlikes": "nattlik",
    "nattliks": "nattlik",
    "nattlikt": "nattlik",
    "nattlikts": "nattlik",
    "nattlinnen": "nattlinne",
    "nattlinnena": "nattlinne",
    "nattlinnenas": "nattlinne",
    "nattlinnens": "nattlinne",
    "nattlinnes": "nattlinne",
    "nattlinnet": "nattlinne",
    "nattlinnets": "nattlinne",
    "nattlinns": "nattlinne",
    "nattlivet": "nattliv",
    "nattlivets": "nattliv",
    "nattlivs": "nattliv",
    "nattljusen": "nattljus",
    "nattljusens": "nattljus",
    "nattljuset": "nattljus",
    "nattljusets": "nattljus",
    "nattlogerar": "nattlogerare",
    "nattlogeraren": "nattlogerare",
    "nattlogerarens": "nattlogerare",
    "nattlogerares": "nattlogerare",
    "nattlogerarna": "nattlogerare",
    "nattlogerarnas": "nattlogerare",
    "nattlogiet": "nattlogi",
    "nattlogiets": "nattlogi",
    "nattlogis": "nattlogi",
    "nattlogit": "nattlogi",
    "nattlogits": "nattlogi",
    "nattluck": "nattlucka",
    "nattluckan": "nattlucka",
    "nattluckans": "nattlucka",
    "nattluckas": "nattlucka",
    "nattlucke": "nattlucka",
    "nattluckor": "nattlucka",
    "nattluckorna": "nattlucka",
    "nattluckornas": "nattlucka",
    "nattluckors": "nattlucka",
    "nattlucks": "nattlucka",
    "nattlägerna": "nattläger",
    "nattlägernas": "nattläger",
    "nattlägers": "nattläger",
    "nattlägren": "nattläger",
    "nattlägrens": "nattläger",
    "nattlägret": "nattläger",
    "nattlägrets": "nattläger",
    "nattlängden": "nattlängd",
    "nattlängdens": "nattlängd",
    "nattlängder": "nattlängd",
    "nattlängderna": "nattlängd",
    "nattlängdernas": "nattlängd",
    "nattlängders": "nattlängd",
    "nattlängds": "nattlängd",
    "nattmanglingar": "nattmangling",
    "nattmanglingarna": "nattmangling",
    "nattmanglingarnas": "nattmangling",
    "nattmanglingars": "nattmangling",
    "nattmanglingen": "nattmangling",
    "nattmanglingens": "nattmangling",
    "nattmanglings": "nattmangling",
    "nattmar": "nattmara",
    "nattmaran": "nattmara",
    "nattmarans": "nattmara",
    "nattmaras": "nattmara",
    "nattmare": "nattmara",
    "nattmaror": "nattmara",
    "nattmarorna": "nattmara",
    "nattmarornas": "nattmara",
    "nattmarors": "nattmara",
    "nattmars": "nattmara",
    "nattmarschen": "nattmarsch",
    "nattmarschens": "nattmarsch",
    "nattmarscher": "nattmarsch",
    "nattmarscherna": "nattmarsch",
    "nattmarschernas": "nattmarsch",
    "nattmarschers": "nattmarsch",
    "nattmarschs": "nattmarsch",
    "nattmolnen": "nattmoln",
    "nattmolnens": "nattmoln",
    "nattmolnet": "nattmoln",
    "nattmolnets": "nattmoln",
    "nattmolns": "nattmoln",
    "nattmörkers": "nattmörker",
    "nattmörkret": "nattmörker",
    "nattmörkrets": "nattmörker",
    "nattmöss": "nattmössa",
    "nattmössan": "nattmössa",
    "nattmössans": "nattmössa",
    "nattmössas": "nattmössa",
    "nattmösse": "nattmössa",
    "nattmössor": "nattmössa",
    "nattmössorna": "nattmössa",
    "nattmössornas": "nattmössa",
    "nattmössors": "nattmössa",
    "nattorienteringar": "nattorientering",
    "nattorienteringarna": "nattorientering",
    "nattorienteringarnas": "nattorientering",
    "nattorienteringars": "nattorientering",
    "nattorienteringen": "nattorientering",
    "nattorienteringens": "nattorientering",
    "nattorienterings": "nattorientering",
    "nattpatrullen": "nattpatrull",
    "nattpatrullens": "nattpatrull",
    "nattpatruller": "nattpatrull",
    "nattpatrullerna": "nattpatrull",
    "nattpatrullernas": "nattpatrull",
    "nattpatrullers": "nattpatrull",
    "nattpatrulls": "nattpatrull",
    "nattrajen": "nattraj",
    "nattrajens": "nattraj",
    "nattrajet": "nattraj",
    "nattrajets": "nattraj",
    "nattrajs": "nattraj",
    "natts": "natt",
    "nattsex": "nattsexa",
    "nattsexan": "nattsexa",
    "nattsexans": "nattsexa",
    "nattsexas": "nattsexa",
    "nattsexe": "nattsexa",
    "nattsexor": "nattsexa",
    "nattsexorna": "nattsexa",
    "nattsexornas": "nattsexa",
    "nattsexors": "nattsexa",
    "nattsidans": "nattsidan",
    "nattsikten": "nattsikte",
    "nattsiktena": "nattsikte",
    "nattsiktenas": "nattsikte",
    "nattsiktens": "nattsikte",
    "nattsiktes": "nattsikte",
    "nattsiktet": "nattsikte",
    "nattsiktets": "nattsikte",
    "nattskatt": "nattskatta",
    "nattskattan": "nattskatta",
    "nattskattans": "nattskatta",
    "nattskattas": "nattskatta",
    "nattskatte": "nattskatta",
    "nattskattor": "nattskatta",
    "nattskattorna": "nattskatta",
    "nattskattornas": "nattskatta",
    "nattskattors": "nattskatta",
    "nattskatts": "nattskatta",
    "nattskiften": "nattskift",
    "nattskiftens": "nattskift",
    "nattskiftet": "nattskift",
    "nattskiftets": "nattskift",
    "nattskifts": "nattskift",
    "nattskjort": "nattskjorta",
    "nattskjortan": "nattskjorta",
    "nattskjortans": "nattskjorta",
    "nattskjortas": "nattskjorta",
    "nattskjorte": "nattskjorta",
    "nattskjortor": "nattskjorta",
    "nattskjortorna": "nattskjorta",
    "nattskjortornas": "nattskjorta",
    "nattskjortors": "nattskjorta",
    "nattskjorts": "nattskjorta",
    "nattskärr": "nattskärra",
    "nattskärran": "nattskärra",
    "nattskärrans": "nattskärra",
    "nattskärras": "nattskärra",
    "nattskärre": "nattskärra",
    "nattskärror": "nattskärra",
    "nattskärrorna": "nattskärra",
    "nattskärrornas": "nattskärra",
    "nattskärrors": "nattskärra",
    "nattskärrs": "nattskärra",
    "nattsköterskan": "nattsköterska",
    "nattsköterskans": "nattsköterska",
    "nattsköterskas": "nattsköterska",
    "nattsköterske": "nattsköterska",
    "nattsköterskor": "nattsköterska",
    "nattsköterskorna": "nattsköterska",
    "nattsköterskornas": "nattsköterska",
    "nattsköterskors": "nattsköterska",
    "nattslagen": "nattslag",
    "nattslagens": "nattslag",
    "nattslaget": "nattslag",
    "nattslagets": "nattslag",
    "nattslags": "nattslag",
    "nattsländ": "nattslända",
    "nattsländan": "nattslända",
    "nattsländans": "nattslända",
    "nattsländas": "nattslända",
    "nattslände": "nattslända",
    "nattsländor": "nattslända",
    "nattsländorna": "nattslända",
    "nattsländornas": "nattslända",
    "nattsländors": "nattslända",
    "nattsländs": "nattslända",
    "nattsmygar": "nattsmyg",
    "nattsmygarna": "nattsmyg",
    "nattsmygarnas": "nattsmyg",
    "nattsmygars": "nattsmyg",
    "nattsmygen": "nattsmyg",
    "nattsmygens": "nattsmyg",
    "nattsmygs": "nattsmyg",
    "nattspåren": "nattspår",
    "nattspårens": "nattspår",
    "nattspåret": "nattspår",
    "nattspårets": "nattspår",
    "nattspårs": "nattspår",
    "nattstolar": "nattstol",
    "nattstolarna": "nattstol",
    "nattstolarnas": "nattstol",
    "nattstolars": "nattstol",
    "nattstolen": "nattstol",
    "nattstolens": "nattstol",
    "nattstols": "nattstol",
    "nattstriden": "nattstrid",
    "nattstridens": "nattstrid",
    "nattstrider": "nattstrid",
    "nattstriderna": "nattstrid",
    "nattstridernas": "nattstrid",
    "nattstriders": "nattstrid",
    "nattstrids": "nattstrid",
    "nattställningar": "nattställning",
    "nattställningarna": "nattställning",
    "nattställningarnas": "nattställning",
    "nattställningars": "nattställning",
    "nattställningen": "nattställning",
    "nattställningens": "nattställning",
    "nattställnings": "nattställning",
    "nattståndens": "nattstånden",
    "nattståndet": "nattstånden",
    "nattståndets": "nattstånden",
    "nattståndna": "nattstånden",
    "nattståndnare": "nattstånden",
    "nattståndnares": "nattstånden",
    "nattståndnas": "nattstånden",
    "nattståndnast": "nattstånden",
    "nattståndnaste": "nattstånden",
    "nattståndnastes": "nattstånden",
    "nattståndnasts": "nattstånden",
    "nattståndne": "nattstånden",
    "nattståndnes": "nattstånden",
    "nattsuddet": "nattsudd",
    "nattsuddets": "nattsudd",
    "nattsudds": "nattsudd",
    "nattsvarta": "nattsvart",
    "nattsvartare": "nattsvart",
    "nattsvartares": "nattsvart",
    "nattsvartas": "nattsvart",
    "nattsvartast": "nattsvart",
    "nattsvartaste": "nattsvart",
    "nattsvartastes": "nattsvart",
    "nattsvartasts": "nattsvart",
    "nattsvarte": "nattsvart",
    "nattsvartes": "nattsvart",
    "nattsvartheten": "nattsvarthet",
    "nattsvarthetens": "nattsvarthet",
    "nattsvarthets": "nattsvarthet",
    "nattsvarts": "nattsvart",
    "nattsystern": "nattsyster",
    "nattsysterns": "nattsyster",
    "nattsysters": "nattsyster",
    "nattsystrar": "nattsyster",
    "nattsystrarna": "nattsyster",
    "nattsystrarnas": "nattsyster",
    "nattsystrars": "nattsyster",
    "nattsäckar": "nattsäck",
    "nattsäckarna": "nattsäck",
    "nattsäckarnas": "nattsäck",
    "nattsäckars": "nattsäck",
    "nattsäcken": "nattsäck",
    "nattsäckens": "nattsäck",
    "nattsäcks": "nattsäck",
    "nattsömnen": "nattsömn",
    "nattsömnens": "nattsömn",
    "nattsömns": "nattsömn",
    "nattugglan": "nattuggla",
    "nattugglans": "nattuggla",
    "nattugglas": "nattuggla",
    "nattuggle": "nattuggla",
    "nattugglor": "nattuggla",
    "nattugglorna": "nattuggla",
    "nattugglornas": "nattuggla",
    "nattugglors": "nattuggla",
    "nattvaken": "nattvak",
    "nattvakens": "nattvak",
    "nattvaket": "nattvak",
    "nattvakets": "nattvak",
    "nattvaks": "nattvak",
    "nattvakten": "nattvakt",
    "nattvaktens": "nattvakt",
    "nattvakter": "nattvakt",
    "nattvakterna": "nattvakt",
    "nattvakternas": "nattvakt",
    "nattvakters": "nattvakt",
    "nattvakts": "nattvakt",
    "nattvarden": "nattvard",
    "nattvardens": "nattvard",
    "nattvarder": "nattvard",
    "nattvarderna": "nattvard",
    "nattvardernas": "nattvard",
    "nattvarders": "nattvard",
    "nattvards": "nattvard",
    "nattvardsbarnen": "nattvardsbarn",
    "nattvardsbarnens": "nattvardsbarn",
    "nattvardsbarnet": "nattvardsbarn",
    "nattvardsbarnets": "nattvardsbarn",
    "nattvardsbarns": "nattvardsbarn",
    "nattvardsberedelsen": "nattvardsberedelse",
    "nattvardsberedelsens": "nattvardsberedelse",
    "nattvardsberedelser": "nattvardsberedelse",
    "nattvardsberedelserna": "nattvardsberedelse",
    "nattvardsberedelsernas": "nattvardsberedelse",
    "nattvardsberedelsers": "nattvardsberedelse",
    "nattvardsberedelses": "nattvardsberedelse",
    "nattvardsborden": "nattvardsbord",
    "nattvardsbordens": "nattvardsbord",
    "nattvardsbordet": "nattvardsbord",
    "nattvardsbordets": "nattvardsbord",
    "nattvardsbords": "nattvardsbord",
    "nattvardsbröden": "nattvardsbröd",
    "nattvardsbrödens": "nattvardsbröd",
    "nattvardsbrödet": "nattvardsbröd",
    "nattvardsbrödets": "nattvardsbröd",
    "nattvardsbröds": "nattvardsbröd",
    "nattvardsgemenskapen": "nattvardsgemenskap",
    "nattvardsgemenskapens": "nattvardsgemenskap",
    "nattvardsgemenskaps": "nattvardsgemenskap",
    "nattvardsgudstjänsten": "nattvardsgudstjänst",
    "nattvardsgudstjänstens": "nattvardsgudstjänst",
    "nattvardsgudstjänster": "nattvardsgudstjänst",
    "nattvardsgudstjänsterna": "nattvardsgudstjänst",
    "nattvardsgudstjänsternas": "nattvardsgudstjänst",
    "nattvardsgudstjänsters": "nattvardsgudstjänst",
    "nattvardsgudstjänsts": "nattvardsgudstjänst",
    "nattvardsgångar": "nattvardsgång",
    "nattvardsgångarna": "nattvardsgång",
    "nattvardsgångarnas": "nattvardsgång",
    "nattvardsgångars": "nattvardsgång",
    "nattvardsgången": "nattvardsgång",
    "nattvardsgångens": "nattvardsgång",
    "nattvardsgångs": "nattvardsgång",
    "nattvardskalkar": "nattvardskalk",
    "nattvardskalkarna": "nattvardskalk",
    "nattvardskalkarnas": "nattvardskalk",
    "nattvardskalkars": "nattvardskalk",
    "nattvardskalken": "nattvardskalk",
    "nattvardskalkens": "nattvardskalk",
    "nattvardskalks": "nattvardskalk",
    "nattvardskärlen": "nattvardskärl",
    "nattvardskärlens": "nattvardskärl",
    "nattvardskärlet": "nattvardskärl",
    "nattvardskärlets": "nattvardskärl",
    "nattvardskärls": "nattvardskärl",
    "nattvardsundervisningar": "nattvardsundervisning",
    "nattvardsundervisningarna": "nattvardsundervisning",
    "nattvardsundervisningarnas": "nattvardsundervisning",
    "nattvardsundervisningars": "nattvardsundervisning",
    "nattvardsundervisningen": "nattvardsundervisning",
    "nattvardsundervisningens": "nattvardsundervisning",
    "nattvardsundervisnings": "nattvardsundervisning",
    "nattvardsviner": "nattvardsvin",
    "nattvardsvinerna": "nattvardsvin",
    "nattvardsvinernas": "nattvardsvin",
    "nattvardsviners": "nattvardsvin",
    "nattvardsvinet": "nattvardsvin",
    "nattvardsvinets": "nattvardsvin",
    "nattvardsvins": "nattvardsvin",
    "nattviolen": "nattviol",
    "nattviolens": "nattviol",
    "nattvioler": "nattviol",
    "nattviolerna": "nattviol",
    "nattviolernas": "nattviol",
    "nattviolers": "nattviol",
    "nattviols": "nattviol",
    "nattväktar": "nattväktare",
    "nattväktaren": "nattväktare",
    "nattväktarens": "nattväktare",
    "nattväktares": "nattväktare",
    "nattväktarna": "nattväktare",
    "nattväktarnas": "nattväktare",
    "nattväkten": "nattväkt",
    "nattväktens": "nattväkt",
    "nattväkter": "nattväkt",
    "nattväkterna": "nattväkt",
    "nattväkternas": "nattväkt",
    "nattväkters": "nattväkt",
    "nattväkts": "nattväkt",
    "nattygsborden": "nattygsbord",
    "nattygsbordens": "nattygsbord",
    "nattygsbordet": "nattygsbord",
    "nattygsbordets": "nattygsbord",
    "nattygsbords": "nattygsbord",
    "nattyxnes": "nattyxne",
    "nattyxnet": "nattyxne",
    "nattyxnets": "nattyxne",
    "nattågen": "nattåg",
    "nattågens": "nattåg",
    "nattåget": "nattåg",
    "nattågets": "nattåg",
    "nattågs": "nattåg",
    "naturahushållningar": "naturahushållning",
    "naturahushållningarna": "naturahushållning",
    "naturahushållningarnas": "naturahushållning",
    "naturahushållningars": "naturahushållning",
    "naturahushållningen": "naturahushållning",
    "naturahushållningens": "naturahushållning",
    "naturahushållnings": "naturahushållning",
    "naturalhistorian": "naturalhistoria",
    "naturalhistorians": "naturalhistoria",
    "naturalhistorias": "naturalhistoria",
    "naturalhistorien": "naturalhistoria",
    "naturalhistoriens": "naturalhistoria",
    "naturalie": "naturalier",
    "naturaliekabinetten": "naturaliekabinett",
    "naturaliekabinettens": "naturaliekabinett",
    "naturaliekabinettet": "naturaliekabinett",
    "naturaliekabinettets": "naturaliekabinett",
    "naturaliekabinetts": "naturaliekabinett",
    "naturalierna": "naturalier",
    "naturaliernas": "naturalier",
    "naturaliers": "naturalier",
    "naturalisationen": "naturalisation",
    "naturalisationens": "naturalisation",
    "naturalisationer": "naturalisation",
    "naturalisationerna": "naturalisation",
    "naturalisationernas": "naturalisation",
    "naturalisationers": "naturalisation",
    "naturalisations": "naturalisation",
    "naturaliserad": "naturalisera",
    "naturaliserade": "naturalisera",
    "naturaliserades": "naturalisera",
    "naturaliserads": "naturalisera",
    "naturaliserande": "naturalisera",
    "naturaliseranden": "naturaliserande",
    "naturaliserandena": "naturaliserande",
    "naturaliserandenas": "naturaliserande",
    "naturaliserandens": "naturaliserande",
    "naturaliserandes": "naturaliserande",
    "naturaliserandet": "naturaliserande",
    "naturaliserandets": "naturaliserande",
    "naturaliserar": "naturalisera",
    "naturaliseras": "naturalisera",
    "naturaliserat": "naturalisera",
    "naturaliserats": "naturalisera",
    "naturaliserbara": "naturaliserbar",
    "naturaliserbarare": "naturaliserbar",
    "naturaliserbarares": "naturaliserbar",
    "naturaliserbaras": "naturaliserbar",
    "naturaliserbarast": "naturaliserbar",
    "naturaliserbaraste": "naturaliserbar",
    "naturaliserbarastes": "naturaliserbar",
    "naturaliserbarasts": "naturaliserbar",
    "naturaliserbare": "naturaliserbar",
    "naturaliserbares": "naturaliserbar",
    "naturaliserbarheten": "naturaliserbarhet",
    "naturaliserbarhetens": "naturaliserbarhet",
    "naturaliserbarhets": "naturaliserbarhet",
    "naturaliserbars": "naturaliserbar",
    "naturaliserbart": "naturaliserbar",
    "naturaliserbarts": "naturaliserbar",
    "naturaliseringar": "naturalisering",
    "naturaliseringarna": "naturalisering",
    "naturaliseringarnas": "naturalisering",
    "naturaliseringars": "naturalisering",
    "naturaliseringen": "naturalisering",
    "naturaliseringens": "naturalisering",
    "naturaliserings": "naturalisering",
    "naturalismen": "naturalism",
    "naturalismens": "naturalism",
    "naturalismer": "naturalism",
    "naturalismerna": "naturalism",
    "naturalismernas": "naturalism",
    "naturalismers": "naturalism",
    "naturalisms": "naturalism",
    "naturalisten": "naturalist",
    "naturalistens": "naturalist",
    "naturalister": "naturalist",
    "naturalisterna": "naturalist",
    "naturalisternas": "naturalist",
    "naturalisters": "naturalist",
    "naturalistiska": "naturalistisk",
    "naturalistiskare": "naturalistisk",
    "naturalistiskares": "naturalistisk",
    "naturalistiskas": "naturalistisk",
    "naturalistiskast": "naturalistisk",
    "naturalistiskaste": "naturalistisk",
    "naturalistiskastes": "naturalistisk",
    "naturalistiskasts": "naturalistisk",
    "naturalistiske": "naturalistisk",
    "naturalistiskes": "naturalistisk",
    "naturalistisks": "naturalistisk",
    "naturalistiskt": "naturalistisk",
    "naturalistiskts": "naturalistisk",
    "naturalists": "naturalist",
    "naturaportionen": "naturaportion",
    "naturaportionens": "naturaportion",
    "naturaportioner": "naturaportion",
    "naturaportionerna": "naturaportion",
    "naturaportionernas": "naturaportion",
    "naturaportioners": "naturaportion",
    "naturaportions": "naturaportion",
    "naturbarnen": "naturbarn",
    "naturbarnens": "naturbarn",
    "naturbarnet": "naturbarn",
    "naturbarnets": "naturbarn",
    "naturbarns": "naturbarn",
    "naturbegåvade": "naturbegåvad",
    "naturbegåvades": "naturbegåvad",
    "naturbegåvads": "naturbegåvad",
    "naturbegåvat": "naturbegåvad",
    "naturbegåvats": "naturbegåvad",
    "naturbegåvningar": "naturbegåvning",
    "naturbegåvningarna": "naturbegåvning",
    "naturbegåvningarnas": "naturbegåvning",
    "naturbegåvningars": "naturbegåvning",
    "naturbegåvningen": "naturbegåvning",
    "naturbegåvningens": "naturbegåvning",
    "naturbegåvnings": "naturbegåvning",
    "naturbehandlade": "naturbehandlad",
    "naturbehandlades": "naturbehandlad",
    "naturbehandlads": "naturbehandlad",
    "naturbehandlat": "naturbehandlad",
    "naturbehandlats": "naturbehandlad",
    "naturbehoven": "naturbehov",
    "naturbehovens": "naturbehov",
    "naturbehovet": "naturbehov",
    "naturbehovets": "naturbehov",
    "naturbehovs": "naturbehov",
    "naturbesjälningar": "naturbesjälning",
    "naturbesjälningarna": "naturbesjälning",
    "naturbesjälningarnas": "naturbesjälning",
    "naturbesjälningars": "naturbesjälning",
    "naturbesjälningen": "naturbesjälning",
    "naturbesjälningens": "naturbesjälning",
    "naturbesjälnings": "naturbesjälning",
    "naturbetingelsen": "naturbetingelse",
    "naturbetingelsens": "naturbetingelse",
    "naturbetingelser": "naturbetingelse",
    "naturbetingelserna": "naturbetingelse",
    "naturbetingelsernas": "naturbetingelse",
    "naturbetingelsers": "naturbetingelse",
    "naturbetingelses": "naturbetingelse",
    "naturbundens": "naturbunden",
    "naturbundet": "naturbunden",
    "naturbundets": "naturbunden",
    "naturbundna": "naturbunden",
    "naturbundnare": "naturbunden",
    "naturbundnares": "naturbunden",
    "naturbundnas": "naturbunden",
    "naturbundnast": "naturbunden",
    "naturbundnaste": "naturbunden",
    "naturbundnastes": "naturbunden",
    "naturbundnasts": "naturbunden",
    "naturbundne": "naturbunden",
    "naturbundnes": "naturbunden",
    "naturdyrkans": "naturdyrkan",
    "naturella": "naturell",
    "naturellare": "naturell",
    "naturellares": "naturell",
    "naturellas": "naturell",
    "naturellast": "naturell",
    "naturellaste": "naturell",
    "naturellastes": "naturell",
    "naturellasts": "naturell",
    "naturelle": "naturell",
    "naturelles": "naturell",
    "naturells": "naturell",
    "naturellt": "naturell",
    "naturelltapeten": "naturelltapet",
    "naturelltapetens": "naturelltapet",
    "naturelltapeter": "naturelltapet",
    "naturelltapeterna": "naturelltapet",
    "naturelltapeternas": "naturelltapet",
    "naturelltapeters": "naturelltapet",
    "naturelltapets": "naturelltapet",
    "naturellts": "naturell",
    "naturen": "natur",
    "naturenliga": "naturenlig",
    "naturenligare": "naturenlig",
    "naturenligares": "naturenlig",
    "naturenligas": "naturenlig",
    "naturenligast": "naturenlig",
    "naturenligaste": "naturenlig",
    "naturenligastes": "naturenlig",
    "naturenligasts": "naturenlig",
    "naturenlige": "naturenlig",
    "naturenliges": "naturenlig",
    "naturenligheten": "naturenlighet",
    "naturenlighetens": "naturenlighet",
    "naturenlighets": "naturenlighet",
    "naturenligs": "naturenlig",
    "naturenligt": "naturenlig",
    "naturenligts": "naturenlig",
    "naturens": "natur",
    "naturer": "natur",
    "naturerna": "natur",
    "naturernas": "natur",
    "naturers": "natur",
    "naturfenomenen": "naturfenomen",
    "naturfenomenens": "naturfenomen",
    "naturfenomenet": "naturfenomen",
    "naturfenomenets": "naturfenomen",
    "naturfenomens": "naturfenomen",
    "naturfibern": "naturfiber",
    "naturfiberns": "naturfiber",
    "naturfibers": "naturfiber",
    "naturfibrer": "naturfiber",
    "naturfibrerna": "naturfiber",
    "naturfibrernas": "naturfiber",
    "naturfibrers": "naturfiber",
    "naturfilosofen": "naturfilosof",
    "naturfilosofens": "naturfilosof",
    "naturfilosofer": "naturfilosof",
    "naturfilosoferna": "naturfilosof",
    "naturfilosofernas": "naturfilosof",
    "naturfilosofers": "naturfilosof",
    "naturfilosofien": "naturfilosofi",
    "naturfilosofiens": "naturfilosofi",
    "naturfilosofin": "naturfilosofi",
    "naturfilosofins": "naturfilosofi",
    "naturfilosofis": "naturfilosofi",
    "naturfilosofs": "naturfilosof",
    "naturfolken": "naturfolk",
    "naturfolkens": "naturfolk",
    "naturfolket": "naturfolk",
    "naturfolkets": "naturfolk",
    "naturfolks": "naturfolk",
    "naturformationen": "naturformation",
    "naturformationens": "naturformation",
    "naturformationer": "naturformation",
    "naturformationerna": "naturformation",
    "naturformationernas": "naturformation",
    "naturformationers": "naturformation",
    "naturformations": "naturformation",
    "naturfärgade": "naturfärgad",
    "naturfärgades": "naturfärgad",
    "naturfärgads": "naturfärgad",
    "naturfärgat": "naturfärgad",
    "naturfärgats": "naturfärgad",
    "naturfärgen": "naturfärg",
    "naturfärgens": "naturfärg",
    "naturfärger": "naturfärg",
    "naturfärgerna": "naturfärg",
    "naturfärgernas": "naturfärg",
    "naturfärgers": "naturfärg",
    "naturfärgs": "naturfärg",
    "naturgasen": "naturgas",
    "naturgasens": "naturgas",
    "naturgaser": "naturgas",
    "naturgaserna": "naturgas",
    "naturgasernas": "naturgas",
    "naturgasers": "naturgas",
    "naturgeografien": "naturgeografi",
    "naturgeografiens": "naturgeografi",
    "naturgeografin": "naturgeografi",
    "naturgeografins": "naturgeografi",
    "naturgeografis": "naturgeografi",
    "naturgummis": "naturgummi",
    "naturgummit": "naturgummi",
    "naturgummits": "naturgummi",
    "naturgödseln": "naturgödsel",
    "naturgödselns": "naturgödsel",
    "naturgödsels": "naturgödsel",
    "naturhamnar": "naturhamn",
    "naturhamnarna": "naturhamn",
    "naturhamnarnas": "naturhamn",
    "naturhamnars": "naturhamn",
    "naturhamnen": "naturhamn",
    "naturhamnens": "naturhamn",
    "naturhamns": "naturhamn",
    "naturhistorian": "naturhistoria",
    "naturhistorians": "naturhistoria",
    "naturhistorias": "naturhistoria",
    "naturhistorien": "naturhistoria",
    "naturhistoriens": "naturhistoria",
    "naturhistoriska": "naturhistorisk",
    "naturhistoriskare": "naturhistorisk",
    "naturhistoriskares": "naturhistorisk",
    "naturhistoriskas": "naturhistorisk",
    "naturhistoriskast": "naturhistorisk",
    "naturhistoriskaste": "naturhistorisk",
    "naturhistoriskastes": "naturhistorisk",
    "naturhistoriskasts": "naturhistorisk",
    "naturhistoriske": "naturhistorisk",
    "naturhistoriskes": "naturhistorisk",
    "naturhistorisks": "naturhistorisk",
    "naturhistoriskt": "naturhistorisk",
    "naturhistoriskts": "naturhistorisk",
    "naturhornen": "naturhorn",
    "naturhornens": "naturhorn",
    "naturhornet": "naturhorn",
    "naturhornets": "naturhorn",
    "naturhorns": "naturhorn",
    "naturinstinkten": "naturinstinkt",
    "naturinstinktens": "naturinstinkt",
    "naturinstinkter": "naturinstinkt",
    "naturinstinkterna": "naturinstinkt",
    "naturinstinkternas": "naturinstinkt",
    "naturinstinkters": "naturinstinkt",
    "naturinstinkts": "naturinstinkt",
    "naturisen": "naturis",
    "naturisens": "naturis",
    "naturismen": "naturism",
    "naturismens": "naturism",
    "naturismer": "naturism",
    "naturismerna": "naturism",
    "naturismernas": "naturism",
    "naturismers": "naturism",
    "naturisms": "naturism",
    "naturisten": "naturist",
    "naturistens": "naturist",
    "naturister": "naturist",
    "naturisterna": "naturist",
    "naturisternas": "naturist",
    "naturisters": "naturist",
    "naturists": "naturist",
    "naturkatastrofen": "naturkatastrof",
    "naturkatastrofens": "naturkatastrof",
    "naturkatastrofer": "naturkatastrof",
    "naturkatastroferna": "naturkatastrof",
    "naturkatastrofernas": "naturkatastrof",
    "naturkatastrofers": "naturkatastrof",
    "naturkatastrofs": "naturkatastrof",
    "naturkonstanten": "naturkonstant",
    "naturkonstantens": "naturkonstant",
    "naturkonstanter": "naturkonstant",
    "naturkonstanterna": "naturkonstant",
    "naturkonstanternas": "naturkonstant",
    "naturkonstanters": "naturkonstant",
    "naturkonstants": "naturkonstant",
    "naturkraften": "naturkraft",
    "naturkraftens": "naturkraft",
    "naturkrafter": "naturkraft",
    "naturkrafterna": "naturkraft",
    "naturkrafternas": "naturkraft",
    "naturkrafters": "naturkraft",
    "naturkrafts": "naturkraft",
    "naturkunskapen": "naturkunskap",
    "naturkunskapens": "naturkunskap",
    "naturkunskaps": "naturkunskap",
    "naturkunskapsundervisningen": "naturkunskapsundervisning",
    "naturkunskapsundervisningens": "naturkunskapsundervisning",
    "naturkunskapsundervisnings": "naturkunskapsundervisning",
    "naturlagar": "naturlag",
    "naturlagarna": "naturlag",
    "naturlagarnas": "naturlag",
    "naturlagars": "naturlag",
    "naturlagen": "naturlag",
    "naturlagens": "naturlag",
    "naturlags": "naturlag",
    "naturliga": "naturlig",
    "naturligare": "naturlig",
    "naturligares": "naturlig",
    "naturligas": "naturlig",
    "naturligast": "naturlig",
    "naturligaste": "naturlig",
    "naturligastes": "naturlig",
    "naturligasts": "naturlig",
    "naturlige": "naturlig",
    "naturliges": "naturlig",
    "naturligheten": "naturlighet",
    "naturlighetens": "naturlighet",
    "naturlighets": "naturlighet",
    "naturligs": "naturlig",
    "naturligt": "naturlig",
    "naturligts": "naturlig",
    "naturlivet": "naturliv",
    "naturlivets": "naturliv",
    "naturlivs": "naturliv",
    "naturläkar": "naturläkare",
    "naturläkaren": "naturläkare",
    "naturläkarens": "naturläkare",
    "naturläkares": "naturläkare",
    "naturläkarna": "naturläkare",
    "naturläkarnas": "naturläkare",
    "naturläkemedels": "naturläkemedel",
    "naturläkemedlen": "naturläkemedel",
    "naturläkemedlens": "naturläkemedel",
    "naturläkemedlet": "naturläkemedel",
    "naturläkemedlets": "naturläkemedel",
    "naturläkemetoden": "naturläkemetod",
    "naturläkemetodens": "naturläkemetod",
    "naturläkemetoder": "naturläkemetod",
    "naturläkemetoderna": "naturläkemetod",
    "naturläkemetodernas": "naturläkemetod",
    "naturläkemetoders": "naturläkemetod",
    "naturläkemetods": "naturläkemetod",
    "naturläran": "naturlära",
    "naturlärans": "naturlära",
    "naturläras": "naturlära",
    "naturmedicinen": "naturmedicin",
    "naturmedicinens": "naturmedicin",
    "naturmediciner": "naturmedicin",
    "naturmedicinerna": "naturmedicin",
    "naturmedicinernas": "naturmedicin",
    "naturmediciners": "naturmedicin",
    "naturmedicins": "naturmedicin",
    "naturmetoden": "naturmetod",
    "naturmetodens": "naturmetod",
    "naturmetoder": "naturmetod",
    "naturmetoderna": "naturmetod",
    "naturmetodernas": "naturmetod",
    "naturmetoders": "naturmetod",
    "naturmetods": "naturmetod",
    "naturmiljöer": "naturmiljö",
    "naturmiljöerna": "naturmiljö",
    "naturmiljöernas": "naturmiljö",
    "naturmiljöers": "naturmiljö",
    "naturmiljön": "naturmiljö",
    "naturmiljöns": "naturmiljö",
    "naturmiljös": "naturmiljö",
    "naturminnen": "naturminne",
    "naturminnena": "naturminne",
    "naturminnenas": "naturminne",
    "naturminnens": "naturminne",
    "naturminnes": "naturminne",
    "naturminnesmärken": "naturminnesmärke",
    "naturminnesmärkena": "naturminnesmärke",
    "naturminnesmärkenas": "naturminnesmärke",
    "naturminnesmärkens": "naturminnesmärke",
    "naturminnesmärkes": "naturminnesmärke",
    "naturminnesmärket": "naturminnesmärke",
    "naturminnesmärkets": "naturminnesmärke",
    "naturminnet": "naturminne",
    "naturminnets": "naturminne",
    "naturmystiken": "naturmystik",
    "naturmystikens": "naturmystik",
    "naturmystiks": "naturmystik",
    "naturmänniskan": "naturmänniska",
    "naturmänniskans": "naturmänniska",
    "naturmänniskas": "naturmänniska",
    "naturmännisko": "naturmänniska",
    "naturmänniskor": "naturmänniska",
    "naturmänniskorna": "naturmänniska",
    "naturmänniskornas": "naturmänniska",
    "naturmänniskors": "naturmänniska",
    "naturmässiga": "naturmässig",
    "naturmässigare": "naturmässig",
    "naturmässigares": "naturmässig",
    "naturmässigas": "naturmässig",
    "naturmässigast": "naturmässig",
    "naturmässigaste": "naturmässig",
    "naturmässigastes": "naturmässig",
    "naturmässigasts": "naturmässig",
    "naturmässige": "naturmässig",
    "naturmässiges": "naturmässig",
    "naturmässigs": "naturmässig",
    "naturmässigt": "naturmässig",
    "naturmässigts": "naturmässig",
    "naturnamnen": "naturnamn",
    "naturnamnens": "naturnamn",
    "naturnamnet": "naturnamn",
    "naturnamnets": "naturnamn",
    "naturnamns": "naturnamn",
    "naturnödvändiga": "naturnödvändig",
    "naturnödvändigare": "naturnödvändig",
    "naturnödvändigares": "naturnödvändig",
    "naturnödvändigas": "naturnödvändig",
    "naturnödvändigast": "naturnödvändig",
    "naturnödvändigaste": "naturnödvändig",
    "naturnödvändigastes": "naturnödvändig",
    "naturnödvändigasts": "naturnödvändig",
    "naturnödvändige": "naturnödvändig",
    "naturnödvändiges": "naturnödvändig",
    "naturnödvändigheten": "naturnödvändighet",
    "naturnödvändighetens": "naturnödvändighet",
    "naturnödvändigheter": "naturnödvändighet",
    "naturnödvändigheterna": "naturnödvändighet",
    "naturnödvändigheternas": "naturnödvändighet",
    "naturnödvändigheters": "naturnödvändighet",
    "naturnödvändighets": "naturnödvändighet",
    "naturnödvändigs": "naturnödvändig",
    "naturnödvändigt": "naturnödvändig",
    "naturnödvändigts": "naturnödvändig",
    "naturparken": "naturpark",
    "naturparkens": "naturpark",
    "naturparker": "naturpark",
    "naturparkerna": "naturpark",
    "naturparkernas": "naturpark",
    "naturparkers": "naturpark",
    "naturparks": "naturpark",
    "naturreligionen": "naturreligion",
    "naturreligionens": "naturreligion",
    "naturreligioner": "naturreligion",
    "naturreligionerna": "naturreligion",
    "naturreligionernas": "naturreligion",
    "naturreligioners": "naturreligion",
    "naturreligions": "naturreligion",
    "naturreservaten": "naturreservat",
    "naturreservatens": "naturreservat",
    "naturreservatet": "naturreservat",
    "naturreservatets": "naturreservat",
    "naturreservats": "naturreservat",
    "naturresursen": "naturresurs",
    "naturresursens": "naturresurs",
    "naturresurser": "naturresurs",
    "naturresurserna": "naturresurs",
    "naturresursernas": "naturresurs",
    "naturresursers": "naturresurs",
    "naturrikedomar": "naturrikedom",
    "naturrikedomarna": "naturrikedom",
    "naturrikedomarnas": "naturrikedom",
    "naturrikedomars": "naturrikedom",
    "naturrikedomen": "naturrikedom",
    "naturrikedomens": "naturrikedom",
    "naturrikedoms": "naturrikedom",
    "naturrätten": "naturrätt",
    "naturrättens": "naturrätt",
    "naturrätts": "naturrätt",
    "naturs": "natur",
    "naturscenerier": "natursceneri",
    "naturscenerierna": "natursceneri",
    "natursceneriernas": "natursceneri",
    "natursceneriers": "natursceneri",
    "natursceneriet": "natursceneri",
    "natursceneriets": "natursceneri",
    "natursceneris": "natursceneri",
    "naturscenerit": "natursceneri",
    "naturscenerits": "natursceneri",
    "naturskogar": "naturskog",
    "naturskogarna": "naturskog",
    "naturskogarnas": "naturskog",
    "naturskogars": "naturskog",
    "naturskogen": "naturskog",
    "naturskogens": "naturskog",
    "naturskogs": "naturskog",
    "naturskyddade": "naturskyddad",
    "naturskyddades": "naturskyddad",
    "naturskyddads": "naturskyddad",
    "naturskyddat": "naturskyddad",
    "naturskyddats": "naturskyddad",
    "naturskyddet": "naturskydd",
    "naturskyddets": "naturskydd",
    "naturskydds": "naturskydd",
    "natursköna": "naturskön",
    "naturskönare": "naturskön",
    "naturskönares": "naturskön",
    "naturskönas": "naturskön",
    "naturskönast": "naturskön",
    "naturskönaste": "naturskön",
    "naturskönastes": "naturskön",
    "naturskönasts": "naturskön",
    "natursköne": "naturskön",
    "naturskönes": "naturskön",
    "naturskönheten": "naturskönhet",
    "naturskönhetens": "naturskönhet",
    "naturskönhets": "naturskönhet",
    "natursköns": "naturskön",
    "naturskönt": "naturskön",
    "naturskönts": "naturskön",
    "naturstenar": "natursten",
    "naturstenarna": "natursten",
    "naturstenarnas": "natursten",
    "naturstenars": "natursten",
    "naturstenen": "natursten",
    "naturstenens": "natursten",
    "naturstens": "natursten",
    "naturstigar": "naturstig",
    "naturstigarna": "naturstig",
    "naturstigarnas": "naturstig",
    "naturstigars": "naturstig",
    "naturstigen": "naturstig",
    "naturstigens": "naturstig",
    "naturstigs": "naturstig",
    "naturstridiga": "naturstridig",
    "naturstridigare": "naturstridig",
    "naturstridigares": "naturstridig",
    "naturstridigas": "naturstridig",
    "naturstridigast": "naturstridig",
    "naturstridigaste": "naturstridig",
    "naturstridigastes": "naturstridig",
    "naturstridigasts": "naturstridig",
    "naturstridige": "naturstridig",
    "naturstridiges": "naturstridig",
    "naturstridigheten": "naturstridighet",
    "naturstridighetens": "naturstridighet",
    "naturstridighets": "naturstridighet",
    "naturstridigs": "naturstridig",
    "naturstridigt": "naturstridig",
    "naturstridigts": "naturstridig",
    "natursångar": "natursångare",
    "natursångaren": "natursångare",
    "natursångarens": "natursångare",
    "natursångares": "natursångare",
    "natursångarna": "natursångare",
    "natursångarnas": "natursångare",
    "naturtillgångar": "naturtillgång",
    "naturtillgångarna": "naturtillgångar",
    "naturtillgångarnas": "naturtillgångar",
    "naturtillgångars": "naturtillgångar",
    "naturtillgången": "naturtillgång",
    "naturtillgångens": "naturtillgång",
    "naturtillgångs": "naturtillgångar",
    "naturtomten": "naturtomt",
    "naturtomtens": "naturtomt",
    "naturtomter": "naturtomt",
    "naturtomterna": "naturtomt",
    "naturtomternas": "naturtomt",
    "naturtomters": "naturtomt",
    "naturtomts": "naturtomt",
    "naturtrogens": "naturtrogen",
    "naturtroget": "naturtrogen",
    "naturtrogets": "naturtrogen",
    "naturtrogna": "naturtrogen",
    "naturtrognare": "naturtrogen",
    "naturtrognares": "naturtrogen",
    "naturtrognas": "naturtrogen",
    "naturtrognast": "naturtrogen",
    "naturtrognaste": "naturtrogen",
    "naturtrognastes": "naturtrogen",
    "naturtrognasts": "naturtrogen",
    "naturtrogne": "naturtrogen",
    "naturtrognes": "naturtrogen",
    "naturträet": "naturträ",
    "naturträets": "naturträ",
    "naturträs": "naturträ",
    "naturträt": "naturträ",
    "naturträts": "naturträ",
    "naturtypen": "naturtyp",
    "naturtypens": "naturtyp",
    "naturtyper": "naturtyp",
    "naturtyperna": "naturtyp",
    "naturtypernas": "naturtyp",
    "naturtypers": "naturtyp",
    "naturtyps": "naturtyp",
    "naturvandrade": "naturvandra",
    "naturvandrades": "naturvandra",
    "naturvandrande": "naturvandra",
    "naturvandrandes": "naturvandra",
    "naturvandrar": "naturvandra",
    "naturvandras": "naturvandra",
    "naturvandrat": "naturvandra",
    "naturvandrats": "naturvandra",
    "naturvetar": "naturvetare",
    "naturvetaren": "naturvetare",
    "naturvetarens": "naturvetare",
    "naturvetares": "naturvetare",
    "naturvetarna": "naturvetare",
    "naturvetarnas": "naturvetare",
    "naturvetenskapen": "naturvetenskap",
    "naturvetenskapens": "naturvetenskap",
    "naturvetenskaper": "naturvetenskap",
    "naturvetenskaperna": "naturvetenskap",
    "naturvetenskapernas": "naturvetenskap",
    "naturvetenskapers": "naturvetenskap",
    "naturvetenskapliga": "naturvetenskaplig",
    "naturvetenskapligare": "naturvetenskaplig",
    "naturvetenskapligares": "naturvetenskaplig",
    "naturvetenskapligas": "naturvetenskaplig",
    "naturvetenskapligast": "naturvetenskaplig",
    "naturvetenskapligaste": "naturvetenskaplig",
    "naturvetenskapligastes": "naturvetenskaplig",
    "naturvetenskapligasts": "naturvetenskaplig",
    "naturvetenskaplige": "naturvetenskaplig",
    "naturvetenskapliges": "naturvetenskaplig",
    "naturvetenskapligheten": "naturvetenskaplighet",
    "naturvetenskaplighetens": "naturvetenskaplighet",
    "naturvetenskaplighets": "naturvetenskaplighet",
    "naturvetenskapligs": "naturvetenskaplig",
    "naturvetenskapligt": "naturvetenskaplig",
    "naturvetenskapligts": "naturvetenskaplig",
    "naturvetenskaps": "naturvetenskap",
    "naturvetenskapsmannen": "naturvetenskapsman",
    "naturvetenskapsmannens": "naturvetenskapsman",
    "naturvetenskapsmans": "naturvetenskapsman",
    "naturvetenskapsmän": "naturvetenskapsman",
    "naturvetenskapsmännen": "naturvetenskapsman",
    "naturvetenskapsmännens": "naturvetenskapsman",
    "naturvetenskapsmäns": "naturvetenskapsman",
    "naturvidriga": "naturvidrig",
    "naturvidrigare": "naturvidrig",
    "naturvidrigares": "naturvidrig",
    "naturvidrigas": "naturvidrig",
    "naturvidrigast": "naturvidrig",
    "naturvidrigaste": "naturvidrig",
    "naturvidrigastes": "naturvidrig",
    "naturvidrigasts": "naturvidrig",
    "naturvidrige": "naturvidrig",
    "naturvidriges": "naturvidrig",
    "naturvidrigheten": "naturvidrighet",
    "naturvidrighetens": "naturvidrighet",
    "naturvidrighets": "naturvidrighet",
    "naturvidrigs": "naturvidrig",
    "naturvidrigt": "naturvidrig",
    "naturvidrigts": "naturvidrig",
    "naturvännen": "naturvän",
    "naturvännens": "naturvän",
    "naturvänner": "naturvän",
    "naturvännerna": "naturvän",
    "naturvännernas": "naturvän",
    "naturvänners": "naturvän",
    "naturväns": "naturvän",
    "naturväsena": "naturväsen",
    "naturväsenas": "naturväsen",
    "naturväsendet": "naturväsen",
    "naturväsendets": "naturväsen",
    "naturväsens": "naturväsen",
    "naturvårdar": "naturvårdare",
    "naturvårdaren": "naturvårdare",
    "naturvårdarens": "naturvårdare",
    "naturvårdares": "naturvårdare",
    "naturvårdarna": "naturvårdare",
    "naturvårdarnas": "naturvårdare",
    "naturvården": "naturvård",
    "naturvårdens": "naturvård",
    "naturvårds": "naturvård",
    "naturvårdsverken": "naturvårdsverk",
    "naturvårdsverkens": "naturvårdsverk",
    "naturvårdsverket": "naturvårdsverk",
    "naturvårdsverkets": "naturvårdsverk",
    "naturvårdsverks": "naturvårdsverk",
    "nauriska": "naurisk",
    "nauriskan": "nauriska",
    "nauriskans": "nauriska",
    "nauriskare": "naurisk",
    "nauriskares": "naurisk",
    "nauriskas": "nauriska",
    "nauriskast": "naurisk",
    "nauriskaste": "naurisk",
    "nauriskastes": "naurisk",
    "nauriskasts": "naurisk",
    "nauriske": "nauriska",
    "nauriskes": "naurisk",
    "nauriskor": "nauriska",
    "nauriskorna": "nauriska",
    "nauriskornas": "nauriska",
    "nauriskors": "nauriska",
    "naurisks": "naurisk",
    "nauriskt": "naurisk",
    "nauriskts": "naurisk",
    "nauruern": "nauruer",
    "nauruerna": "nauruer",
    "nauruernas": "nauruer",
    "nauruerns": "nauruer",
    "nauruers": "nauruer",
    "nautiken": "nautik",
    "nautikens": "nautik",
    "nautikern": "nautiker",
    "nautikerna": "nautiker",
    "nautikernas": "nautiker",
    "nautikerns": "nautiker",
    "nautikers": "nautiker",
    "nautiks": "nautik",
    "nautiska": "nautisk",
    "nautiskare": "nautisk",
    "nautiskares": "nautisk",
    "nautiskas": "nautisk",
    "nautiskast": "nautisk",
    "nautiskaste": "nautisk",
    "nautiskastes": "nautisk",
    "nautiskasts": "nautisk",
    "nautiske": "nautisk",
    "nautiskes": "nautisk",
    "nautisks": "nautisk",
    "nautiskt": "nautisk",
    "nautiskts": "nautisk",
    "navahoen": "navaho",
    "navahoens": "navaho",
    "navahoer": "navaho",
    "navahoerna": "navaho",
    "navahoernas": "navaho",
    "navahoers": "navaho",
    "navahoreservaten": "navahoreservat",
    "navahoreservatens": "navahoreservat",
    "navahoreservatet": "navahoreservat",
    "navahoreservatets": "navahoreservat",
    "navahoreservats": "navahoreservat",
    "navahos": "navaho",
    "navajoen": "navajo",
    "navajoens": "navajo",
    "navajoer": "navajo",
    "navajoerna": "navajo",
    "navajoernas": "navajo",
    "navajoers": "navajo",
    "navajoreservaten": "navajoreservat",
    "navajoreservatens": "navajoreservat",
    "navajoreservatet": "navajoreservat",
    "navajoreservatets": "navajoreservat",
    "navajoreservats": "navajoreservat",
    "navajos": "navajo",
    "navalmedicinen": "navalmedicin",
    "navalmedicinens": "navalmedicin",
    "navalmedicins": "navalmedicin",
    "navalmedicinska": "navalmedicinsk",
    "navalmedicinskare": "navalmedicinsk",
    "navalmedicinskares": "navalmedicinsk",
    "navalmedicinskas": "navalmedicinsk",
    "navalmedicinskast": "navalmedicinsk",
    "navalmedicinskaste": "navalmedicinsk",
    "navalmedicinskastes": "navalmedicinsk",
    "navalmedicinskasts": "navalmedicinsk",
    "navalmedicinske": "navalmedicinsk",
    "navalmedicinskes": "navalmedicinsk",
    "navalmedicinsks": "navalmedicinsk",
    "navalmedicinskt": "navalmedicinsk",
    "navalmedicinskts": "navalmedicinsk",
    "navar": "navare",
    "navarborrar": "navarborr",
    "navarborrarna": "navarborr",
    "navarborrarnas": "navarborr",
    "navarborrars": "navarborr",
    "navarborren": "navarborr",
    "navarborrens": "navarborr",
    "navarborret": "navarborr",
    "navarborrets": "navarborr",
    "navarborrs": "navarborr",
    "navaren": "navare",
    "navarens": "navare",
    "navares": "navare",
    "navarna": "navare",
    "navarnas": "navare",
    "navelbanden": "navelband",
    "navelbandens": "navelband",
    "navelbandet": "navelband",
    "navelbandets": "navelband",
    "navelbands": "navelband",
    "navelbind": "navelbinda",
    "navelbindan": "navelbinda",
    "navelbindans": "navelbinda",
    "navelbindas": "navelbinda",
    "navelbinde": "navelbinda",
    "navelbindor": "navelbinda",
    "navelbindorna": "navelbinda",
    "navelbindornas": "navelbinda",
    "navelbindors": "navelbinda",
    "navelbinds": "navelbinda",
    "navelfläckar": "navelfläck",
    "navelfläckarna": "navelfläck",
    "navelfläckarnas": "navelfläck",
    "navelfläckars": "navelfläck",
    "navelfläcken": "navelfläck",
    "navelfläckens": "navelfläck",
    "navelfläcks": "navelfläck",
    "navelludden": "navelludd",
    "navelluddens": "navelludd",
    "navelluddet": "navelludd",
    "navelluddets": "navelludd",
    "navelludds": "navelludd",
    "naveln": "navel",
    "navelns": "navel",
    "navels": "navel",
    "navelskådar": "navelskådare",
    "navelskådaren": "navelskådare",
    "navelskådarens": "navelskådare",
    "navelskådares": "navelskådare",
    "navelskådarna": "navelskådare",
    "navelskådarnas": "navelskådare",
    "navelskådningar": "navelskådning",
    "navelskådningarna": "navelskådning",
    "navelskådningarnas": "navelskådning",
    "navelskådningars": "navelskådning",
    "navelskådningen": "navelskådning",
    "navelskådningens": "navelskådning",
    "navelskådnings": "navelskådning",
    "navelsträngar": "navelsträng",
    "navelsträngarna": "navelsträng",
    "navelsträngarnas": "navelsträng",
    "navelsträngars": "navelsträng",
    "navelsträngen": "navelsträng",
    "navelsträngens": "navelsträng",
    "navelsträngs": "navelsträng",
    "navelsvinen": "navelsvin",
    "navelsvinens": "navelsvin",
    "navelsvinet": "navelsvin",
    "navelsvinets": "navelsvin",
    "navelsvins": "navelsvin",
    "naven": "nav",
    "navens": "nav",
    "navern": "naver",
    "naverns": "naver",
    "navers": "naver",
    "navet": "nav",
    "navets": "nav",
    "navigabela": "navigabel",
    "navigabelare": "navigabel",
    "navigabelares": "navigabel",
    "navigabelas": "navigabel",
    "navigabelast": "navigabel",
    "navigabelaste": "navigabel",
    "navigabelastes": "navigabel",
    "navigabelasts": "navigabel",
    "navigabele": "navigabel",
    "navigabeles": "navigabel",
    "navigabels": "navigabel",
    "navigabelt": "navigabel",
    "navigabelts": "navigabel",
    "navigationen": "navigation",
    "navigationens": "navigation",
    "navigationer": "navigation",
    "navigationerna": "navigation",
    "navigationernas": "navigation",
    "navigationers": "navigation",
    "navigations": "navigation",
    "navigationssatelliten": "navigationssatellit",
    "navigationssatellitens": "navigationssatellit",
    "navigationssatelliter": "navigationssatellit",
    "navigationssatelliterna": "navigationssatellit",
    "navigationssatelliternas": "navigationssatellit",
    "navigationssatelliters": "navigationssatellit",
    "navigationssatellits": "navigationssatellit",
    "navigationsvarningar": "navigationsvarning",
    "navigationsvarningarna": "navigationsvarning",
    "navigationsvarningarnas": "navigationsvarning",
    "navigationsvarningars": "navigationsvarning",
    "navigationsvarningen": "navigationsvarning",
    "navigationsvarningens": "navigationsvarning",
    "navigationsvarnings": "navigationsvarning",
    "navigatören": "navigatör",
    "navigatörens": "navigatör",
    "navigatörer": "navigatör",
    "navigatörerna": "navigatör",
    "navigatörernas": "navigatör",
    "navigatörers": "navigatör",
    "navigatörs": "navigatör",
    "navigerad": "navigera",
    "navigerade": "navigera",
    "navigerades": "navigera",
    "navigerads": "navigera",
    "navigerande": "navigera",
    "navigeranden": "navigerande",
    "navigerandena": "navigerande",
    "navigerandenas": "navigerande",
    "navigerandens": "navigerande",
    "navigerandes": "navigerande",
    "navigerandet": "navigerande",
    "navigerandets": "navigerande",
    "navigerar": "navigera",
    "navigeras": "navigera",
    "navigerat": "navigera",
    "navigerats": "navigera",
    "navigerbara": "navigerbar",
    "navigerbarare": "navigerbar",
    "navigerbarares": "navigerbar",
    "navigerbaras": "navigerbar",
    "navigerbarast": "navigerbar",
    "navigerbaraste": "navigerbar",
    "navigerbarastes": "navigerbar",
    "navigerbarasts": "navigerbar",
    "navigerbare": "navigerbar",
    "navigerbares": "navigerbar",
    "navigerbarheten": "navigerbarhet",
    "navigerbarhetens": "navigerbarhet",
    "navigerbarhets": "navigerbarhet",
    "navigerbars": "navigerbar",
    "navigerbart": "navigerbar",
    "navigerbarts": "navigerbar",
    "navigeringar": "navigering",
    "navigeringarna": "navigering",
    "navigeringarnas": "navigering",
    "navigeringars": "navigering",
    "navigeringen": "navigering",
    "navigeringens": "navigering",
    "navigerings": "navigering",
    "navigeringssystemen": "navigeringssystem",
    "navigeringssystemens": "navigeringssystem",
    "navigeringssystemet": "navigeringssystem",
    "navigeringssystemets": "navigeringssystem",
    "navigeringssystems": "navigeringssystem",
    "navkapseln": "navkapsel",
    "navkapselns": "navkapsel",
    "navkapsels": "navkapsel",
    "navkapslar": "navkapsel",
    "navkapslarna": "navkapsel",
    "navkapslarnas": "navkapsel",
    "navkapslars": "navkapsel",
    "navlad": "navla",
    "navlade": "navla",
    "navlades": "navla",
    "navlads": "navla",
    "navlande": "navla",
    "navlanden": "navlande",
    "navlandena": "navlande",
    "navlandenas": "navlande",
    "navlandens": "navlande",
    "navlandes": "navlande",
    "navlandet": "navlande",
    "navlandets": "navlande",
    "navlar": "navla",
    "navlarna": "navel",
    "navlarnas": "navel",
    "navlars": "navel",
    "navlas": "navla",
    "navlat": "navla",
    "navlats": "navla",
    "navs": "nav",
    "naziarkitekturen": "naziarkitektur",
    "naziarkitekturens": "naziarkitektur",
    "naziarkitekturer": "naziarkitektur",
    "naziarkitekturerna": "naziarkitektur",
    "naziarkitekturernas": "naziarkitektur",
    "naziarkitekturers": "naziarkitektur",
    "naziarkitekturs": "naziarkitektur",
    "nazibrotten": "nazibrott",
    "nazibrottens": "nazibrott",
    "nazibrottet": "nazibrott",
    "nazibrottets": "nazibrott",
    "nazibrotts": "nazibrott",
    "nazismen": "nazism",
    "nazismens": "nazism",
    "nazismer": "nazism",
    "nazismerna": "nazism",
    "nazismernas": "nazism",
    "nazismers": "nazism",
    "nazisms": "nazism",
    "nazisten": "nazist",
    "nazistens": "nazist",
    "nazister": "nazist",
    "nazisterna": "nazist",
    "nazisternas": "nazist",
    "nazisters": "nazist",
    "nazistiska": "nazistisk",
    "nazistiskare": "nazistisk",
    "nazistiskares": "nazistisk",
    "nazistiskas": "nazistisk",
    "nazistiskast": "nazistisk",
    "nazistiskaste": "nazistisk",
    "nazistiskastes": "nazistisk",
    "nazistiskasts": "nazistisk",
    "nazistiske": "nazistisk",
    "nazistiskes": "nazistisk",
    "nazistisks": "nazistisk",
    "nazistiskt": "nazistisk",
    "nazistiskts": "nazistisk",
    "nazistofficerare": "nazistofficer",
    "nazistofficerares": "nazistofficer",
    "nazistofficerarna": "nazistofficer",
    "nazistofficerarnas": "nazistofficer",
    "nazistofficeren": "nazistofficer",
    "nazistofficerens": "nazistofficer",
    "nazistofficern": "nazistofficer",
    "nazistofficerns": "nazistofficer",
    "nazistofficers": "nazistofficer",
    "nazists": "nazist",
    "nazistsympatisören": "nazistsympatisör",
    "nazistsympatisörens": "nazistsympatisör",
    "nazistsympatisörer": "nazistsympatisör",
    "nazistsympatisörerna": "nazistsympatisör",
    "nazistsympatisörernas": "nazistsympatisör",
    "nazistsympatisörers": "nazistsympatisör",
    "nazistsympatisörs": "nazistsympatisör",
    "neandertalar": "neandertalare",
    "neandertalaren": "neandertalare",
    "neandertalarens": "neandertalare",
    "neandertalares": "neandertalare",
    "neandertalarna": "neandertalare",
    "neandertalarnas": "neandertalare",
    "neandertalmänniskan": "neandertalmänniska",
    "neandertalmänniskans": "neandertalmänniska",
    "neandertalmänniskas": "neandertalmänniska",
    "neandertalmännisko": "neandertalmänniska",
    "neandertalmänniskor": "neandertalmänniska",
    "neandertalmänniskorna": "neandertalmänniska",
    "neandertalmänniskornas": "neandertalmänniska",
    "neandertalmänniskors": "neandertalmänniska",
    "neapolitanen": "neapolitan",
    "neapolitanens": "neapolitan",
    "neapolitaner": "neapolitan",
    "neapolitanerna": "neapolitan",
    "neapolitanernas": "neapolitan",
    "neapolitaners": "neapolitan",
    "neapolitans": "neapolitan",
    "neapolitanska": "neapolitansk",
    "neapolitanskare": "neapolitansk",
    "neapolitanskares": "neapolitansk",
    "neapolitanskas": "neapolitansk",
    "neapolitanskast": "neapolitansk",
    "neapolitanskaste": "neapolitansk",
    "neapolitanskastes": "neapolitansk",
    "neapolitanskasts": "neapolitansk",
    "neapolitanske": "neapolitansk",
    "neapolitanskes": "neapolitansk",
    "neapolitansks": "neapolitansk",
    "neapolitanskt": "neapolitansk",
    "neapolitanskts": "neapolitansk",
    "nebulos": "nebulosa",
    "nebulosalinjen": "nebulosalinje",
    "nebulosalinjens": "nebulosalinje",
    "nebulosalinjer": "nebulosalinje",
    "nebulosalinjerna": "nebulosalinje",
    "nebulosalinjernas": "nebulosalinje",
    "nebulosalinjers": "nebulosalinje",
    "nebulosalinjes": "nebulosalinje",
    "nebulosan": "nebulosa",
    "nebulosans": "nebulosa",
    "nebulosas": "nebulosa",
    "nebulose": "nebulosa",
    "nebulosor": "nebulosa",
    "nebulosorna": "nebulosa",
    "nebulosornas": "nebulosa",
    "nebulosors": "nebulosa",
    "nebulösa": "nebulös",
    "nebulösare": "nebulös",
    "nebulösares": "nebulös",
    "nebulösas": "nebulös",
    "nebulösast": "nebulös",
    "nebulösaste": "nebulös",
    "nebulösastes": "nebulös",
    "nebulösasts": "nebulös",
    "nebulöse": "nebulös",
    "nebulöses": "nebulös",
    "nebulöst": "nebulös",
    "nebulösts": "nebulös",
    "necessären": "necessär",
    "necessärens": "necessär",
    "necessärer": "necessär",
    "necessärerna": "necessär",
    "necessärernas": "necessär",
    "necessärers": "necessär",
    "necessärs": "necessär",
    "nedanen": "nedan",
    "nedanens": "nedan",
    "nedanet": "nedan",
    "nedanets": "nedan",
    "nedans": "nedan",
    "nedarbet": "nedarbeta",
    "nedarbetad": "nedarbeta",
    "nedarbetade": "nedarbeta",
    "nedarbetades": "nedarbeta",
    "nedarbetads": "nedarbeta",
    "nedarbetande": "nedarbeta",
    "nedarbetanden": "nedarbetande",
    "nedarbetandena": "nedarbetande",
    "nedarbetandenas": "nedarbetande",
    "nedarbetandens": "nedarbetande",
    "nedarbetandes": "nedarbetande",
    "nedarbetandet": "nedarbetande",
    "nedarbetandets": "nedarbetande",
    "nedarbetar": "nedarbeta",
    "nedarbetas": "nedarbeta",
    "nedarbetat": "nedarbeta",
    "nedarbetats": "nedarbeta",
    "nedbantade": "nedbantad",
    "nedbantades": "nedbantad",
    "nedbantads": "nedbantad",
    "nedbantat": "nedbantad",
    "nedbantats": "nedbantad",
    "nedblodade": "nedblodad",
    "nedblodades": "nedblodad",
    "nedblodads": "nedblodad",
    "nedblodat": "nedblodad",
    "nedblodats": "nedblodad",
    "nedblås": "nedblåsa",
    "nedblåsande": "nedblåsa",
    "nedblåsanden": "nedblåsande",
    "nedblåsandena": "nedblåsande",
    "nedblåsandenas": "nedblåsande",
    "nedblåsandens": "nedblåsande",
    "nedblåsandes": "nedblåsande",
    "nedblåsandet": "nedblåsande",
    "nedblåsandets": "nedblåsande",
    "nedblåsas": "nedblåsa",
    "nedblåser": "nedblåsa",
    "nedblåses": "nedblåsa",
    "nedblåst": "nedblåsa",
    "nedblåsta": "nedblåsa",
    "nedblåstas": "nedblåsa",
    "nedblåste": "nedblåsa",
    "nedblåstes": "nedblåsa",
    "nedblåsts": "nedblåsa",
    "nedborrade": "nedborrad",
    "nedborrades": "nedborrad",
    "nedborrads": "nedborrad",
    "nedborrat": "nedborrad",
    "nedborrats": "nedborrad",
    "nedbragt": "nedbringa",
    "nedbragte": "nedbringa",
    "nedbragtes": "nedbringa",
    "nedbragts": "nedbringa",
    "nedbring": "nedbringa",
    "nedbringad": "nedbringa",
    "nedbringade": "nedbringa",
    "nedbringades": "nedbringa",
    "nedbringads": "nedbringa",
    "nedbringande": "nedbringa",
    "nedbringanden": "nedbringande",
    "nedbringandena": "nedbringande",
    "nedbringandenas": "nedbringande",
    "nedbringandens": "nedbringande",
    "nedbringandes": "nedbringande",
    "nedbringandet": "nedbringande",
    "nedbringandets": "nedbringande",
    "nedbringar": "nedbringa",
    "nedbringas": "nedbringa",
    "nedbringat": "nedbringa",
    "nedbringats": "nedbringa",
    "nedbruten": "nedbryta",
    "nedbrutens": "nedbryta",
    "nedbrutet": "nedbryta",
    "nedbrutets": "nedbryta",
    "nedbrutit": "nedbryta",
    "nedbrutits": "nedbryta",
    "nedbrutna": "nedbryta",
    "nedbrutnare": "nedbruten",
    "nedbrutnares": "nedbruten",
    "nedbrutnas": "nedbryta",
    "nedbrutnast": "nedbruten",
    "nedbrutnaste": "nedbruten",
    "nedbrutnastes": "nedbruten",
    "nedbrutnasts": "nedbruten",
    "nedbrutne": "nedbryta",
    "nedbrutnes": "nedbryta",
    "nedbryt": "nedbryta",
    "nedbrytande": "nedbryta",
    "nedbrytanden": "nedbrytande",
    "nedbrytandena": "nedbrytande",
    "nedbrytandenas": "nedbrytande",
    "nedbrytandens": "nedbrytande",
    "nedbrytandes": "nedbrytande",
    "nedbrytandet": "nedbrytande",
    "nedbrytandets": "nedbrytande",
    "nedbrytas": "nedbryta",
    "nedbryte": "nedbryta",
    "nedbryter": "nedbryta",
    "nedbrytes": "nedbryta",
    "nedbrytningar": "nedbrytning",
    "nedbrytningarna": "nedbrytning",
    "nedbrytningarnas": "nedbrytning",
    "nedbrytningars": "nedbrytning",
    "nedbrytningen": "nedbrytning",
    "nedbrytningens": "nedbrytning",
    "nedbrytnings": "nedbrytning",
    "nedbrytningsstationen": "nedbrytningsstation",
    "nedbrytningsstationens": "nedbrytningsstation",
    "nedbrytningsstationer": "nedbrytningsstation",
    "nedbrytningsstationerna": "nedbrytningsstation",
    "nedbrytningsstationernas": "nedbrytningsstation",
    "nedbrytningsstationers": "nedbrytningsstation",
    "nedbrytningsstations": "nedbrytningsstation",
    "nedbryts": "nedbryta",
    "nedbröt": "nedbryta",
    "nedbröte": "nedbryta",
    "nedbrötes": "nedbryta",
    "nedbröts": "nedbryta",
    "nedbusade": "nedbusad",
    "nedbusades": "nedbusad",
    "nedbusads": "nedbusad",
    "nedbusat": "nedbusad",
    "nedbusats": "nedbusad",
    "nedbusningar": "nedbusning",
    "nedbusningarna": "nedbusning",
    "nedbusningarnas": "nedbusning",
    "nedbusningars": "nedbusning",
    "nedbusningen": "nedbusning",
    "nedbusningens": "nedbusning",
    "nedbusnings": "nedbusning",
    "neddekade": "neddekad",
    "neddekades": "neddekad",
    "neddekads": "neddekad",
    "neddekat": "neddekad",
    "neddekats": "neddekad",
    "neddragens": "neddragen",
    "neddraget": "neddragen",
    "neddragets": "neddragen",
    "neddragna": "neddragen",
    "neddragnare": "neddragen",
    "neddragnares": "neddragen",
    "neddragnas": "neddragen",
    "neddragnast": "neddragen",
    "neddragnaste": "neddragen",
    "neddragnastes": "neddragen",
    "neddragnasts": "neddragen",
    "neddragne": "neddragen",
    "neddragnes": "neddragen",
    "neddragningar": "neddragning",
    "neddragningarna": "neddragning",
    "neddragningarnas": "neddragning",
    "neddragningars": "neddragning",
    "neddragningen": "neddragning",
    "neddragningens": "neddragning",
    "neddragnings": "neddragning",
    "nederbörden": "nederbörd",
    "nederbördens": "nederbörd",
    "nederbörds": "nederbörd",
    "nederbördsmängden": "nederbördsmängd",
    "nederbördsmängdens": "nederbördsmängd",
    "nederbördsmängder": "nederbördsmängd",
    "nederbördsmängderna": "nederbördsmängd",
    "nederbördsmängdernas": "nederbördsmängd",
    "nederbördsmängders": "nederbördsmängd",
    "nederbördsmängds": "nederbördsmängd",
    "nederbördsområden": "nederbördsområde",
    "nederbördsområdena": "nederbördsområde",
    "nederbördsområdenas": "nederbördsområde",
    "nederbördsområdens": "nederbördsområde",
    "nederbördsområdes": "nederbördsområde",
    "nederbördsområdet": "nederbördsområde",
    "nederbördsområdets": "nederbördsområde",
    "nederdelar": "nederdel",
    "nederdelarna": "nederdel",
    "nederdelarnas": "nederdel",
    "nederdelars": "nederdel",
    "nederdelen": "nederdel",
    "nederdelens": "nederdel",
    "nederdels": "nederdel",
    "nederkanten": "nederkant",
    "nederkantens": "nederkant",
    "nederkanter": "nederkant",
    "nederkanterna": "nederkant",
    "nederkanternas": "nederkant",
    "nederkanters": "nederkant",
    "nederkants": "nederkant",
    "nederlagen": "nederlag",
    "nederlagens": "nederlag",
    "nederlaget": "nederlag",
    "nederlagets": "nederlag",
    "nederlags": "nederlag",
    "nederländar": "nederländare",
    "nederländaren": "nederländare",
    "nederländarens": "nederländare",
    "nederländares": "nederländare",
    "nederländarna": "nederländare",
    "nederländarnas": "nederländare",
    "nederländsk": "nederländska",
    "nederländska": "nederländsk",
    "nederländskan": "nederländska",
    "nederländskans": "nederländska",
    "nederländskare": "nederländsk",
    "nederländskares": "nederländsk",
    "nederländskas": "nederländska",
    "nederländskast": "nederländsk",
    "nederländskaste": "nederländsk",
    "nederländskastes": "nederländsk",
    "nederländskasts": "nederländsk",
    "nederländske": "nederländska",
    "nederländskes": "nederländsk",
    "nederländskor": "nederländska",
    "nederländskorna": "nederländska",
    "nederländskornas": "nederländska",
    "nederländskors": "nederländska",
    "nederländsks": "nederländsk",
    "nederländskt": "nederländsk",
    "nederländskts": "nederländsk",
    "nedersta": "nedre",
    "nederstas": "nedre",
    "nederste": "nedre",
    "nederstes": "nedre",
    "nedfallen": "nedfall",
    "nedfallens": "nedfall",
    "nedfallet": "nedfall",
    "nedfallets": "nedfall",
    "nedfalls": "nedfall",
    "nedfarten": "nedfart",
    "nedfartens": "nedfart",
    "nedfarter": "nedfart",
    "nedfarterna": "nedfart",
    "nedfarternas": "nedfart",
    "nedfarters": "nedfart",
    "nedfarts": "nedfart",
    "nedfruse": "nedfrysa",
    "nedfrusen": "nedfrysa",
    "nedfrusens": "nedfrysa",
    "nedfruses": "nedfrysa",
    "nedfruset": "nedfrysa",
    "nedfrusets": "nedfrysa",
    "nedfrusit": "nedfrysa",
    "nedfrusits": "nedfrysa",
    "nedfrusna": "nedfrysa",
    "nedfrusnas": "nedfrysa",
    "nedfrusne": "nedfrysa",
    "nedfrusnes": "nedfrysa",
    "nedfrys": "nedfrysa",
    "nedfrysande": "nedfrysa",
    "nedfrysanden": "nedfrysande",
    "nedfrysandena": "nedfrysande",
    "nedfrysandenas": "nedfrysande",
    "nedfrysandens": "nedfrysande",
    "nedfrysandes": "nedfrysande",
    "nedfrysandet": "nedfrysande",
    "nedfrysandets": "nedfrysande",
    "nedfrysas": "nedfrysa",
    "nedfryse": "nedfrysa",
    "nedfryser": "nedfrysa",
    "nedfryses": "nedfrysa",
    "nedfrysningar": "nedfrysning",
    "nedfrysningarna": "nedfrysning",
    "nedfrysningarnas": "nedfrysning",
    "nedfrysningars": "nedfrysning",
    "nedfrysningen": "nedfrysning",
    "nedfrysningens": "nedfrysning",
    "nedfrysnings": "nedfrysning",
    "nedfryst": "nedfrysa",
    "nedfrysta": "nedfrysa",
    "nedfrystas": "nedfrysa",
    "nedfryste": "nedfrysa",
    "nedfrystes": "nedfrysa",
    "nedfrysts": "nedfrysa",
    "nedfrös": "nedfrysa",
    "nedfällde": "nedfälld",
    "nedfälldes": "nedfälld",
    "nedfällds": "nedfälld",
    "nedfällt": "nedfälld",
    "nedfällts": "nedfälld",
    "nedförsback": "nedförsbacke",
    "nedförsbackar": "nedförsbacke",
    "nedförsbackarna": "nedförsbacke",
    "nedförsbackarnas": "nedförsbacke",
    "nedförsbackars": "nedförsbacke",
    "nedförsbacken": "nedförsbacke",
    "nedförsbackens": "nedförsbacke",
    "nedförsbackes": "nedförsbacke",
    "nedförsbacks": "nedförsbacke",
    "nedgjord": "nedgöra",
    "nedgjorda": "nedgöra",
    "nedgjordas": "nedgöra",
    "nedgjorde": "nedgöra",
    "nedgjordes": "nedgöra",
    "nedgjords": "nedgöra",
    "nedgjort": "nedgöra",
    "nedgjorts": "nedgöra",
    "nedgrisade": "nedgrisad",
    "nedgrisades": "nedgrisad",
    "nedgrisads": "nedgrisad",
    "nedgrisat": "nedgrisad",
    "nedgrisats": "nedgrisad",
    "nedgräv": "nedgräva",
    "nedgrävande": "nedgräva",
    "nedgrävanden": "nedgrävande",
    "nedgrävandena": "nedgrävande",
    "nedgrävandenas": "nedgrävande",
    "nedgrävandens": "nedgrävande",
    "nedgrävandes": "nedgrävande",
    "nedgrävandet": "nedgrävande",
    "nedgrävandets": "nedgrävande",
    "nedgrävas": "nedgräva",
    "nedgrävd": "nedgräva",
    "nedgrävda": "nedgräva",
    "nedgrävdas": "nedgräva",
    "nedgrävde": "nedgräva",
    "nedgrävdes": "nedgräva",
    "nedgrävds": "nedgräva",
    "nedgräver": "nedgräva",
    "nedgräves": "nedgräva",
    "nedgrävs": "nedgräva",
    "nedgrävt": "nedgräva",
    "nedgrävts": "nedgräva",
    "nedgåendes": "nedgående",
    "nedgåendet": "nedgående",
    "nedgåendets": "nedgående",
    "nedgångar": "nedgång",
    "nedgångarna": "nedgång",
    "nedgångarnas": "nedgång",
    "nedgångars": "nedgång",
    "nedgången": "nedgång",
    "nedgångens": "nedgången",
    "nedgånget": "nedgången",
    "nedgångets": "nedgången",
    "nedgångna": "nedgången",
    "nedgångnare": "nedgången",
    "nedgångnares": "nedgången",
    "nedgångnas": "nedgången",
    "nedgångnast": "nedgången",
    "nedgångnaste": "nedgången",
    "nedgångnastes": "nedgången",
    "nedgångnasts": "nedgången",
    "nedgångne": "nedgången",
    "nedgångnes": "nedgången",
    "nedgångs": "nedgång",
    "nedgör": "nedgöra",
    "nedgörande": "nedgöra",
    "nedgöranden": "nedgörande",
    "nedgörandena": "nedgörande",
    "nedgörandenas": "nedgörande",
    "nedgörandens": "nedgörande",
    "nedgörandes": "nedgörande",
    "nedgörandet": "nedgörande",
    "nedgörandets": "nedgörande",
    "nedgöras": "nedgöra",
    "nedgöres": "nedgöra",
    "nedgörs": "nedgöra",
    "nedhalar": "nedhalare",
    "nedhalaren": "nedhalare",
    "nedhalarens": "nedhalare",
    "nedhalares": "nedhalare",
    "nedhalarna": "nedhalare",
    "nedhalarnas": "nedhalare",
    "nedhukade": "nedhukad",
    "nedhukades": "nedhukad",
    "nedhukads": "nedhukad",
    "nedhukat": "nedhukad",
    "nedhukats": "nedhukad",
    "nedis": "nedisa",
    "nedisad": "nedisa",
    "nedisade": "nedisa",
    "nedisades": "nedisa",
    "nedisads": "nedisa",
    "nedisande": "nedisa",
    "nedisanden": "nedisande",
    "nedisandena": "nedisande",
    "nedisandenas": "nedisande",
    "nedisandens": "nedisande",
    "nedisandes": "nedisande",
    "nedisandet": "nedisande",
    "nedisandets": "nedisande",
    "nedisar": "nedisa",
    "nedisas": "nedisa",
    "nedisat": "nedisa",
    "nedisats": "nedisa",
    "nedkall": "nedkalla",
    "nedkallad": "nedkalla",
    "nedkallade": "nedkalla",
    "nedkallades": "nedkalla",
    "nedkallads": "nedkalla",
    "nedkallande": "nedkalla",
    "nedkallanden": "nedkallande",
    "nedkallandena": "nedkallande",
    "nedkallandenas": "nedkallande",
    "nedkallandens": "nedkallande",
    "nedkallandes": "nedkallande",
    "nedkallandet": "nedkallande",
    "nedkallandets": "nedkallande",
    "nedkallar": "nedkalla",
    "nedkallas": "nedkalla",
    "nedkallat": "nedkalla",
    "nedkallats": "nedkalla",
    "nedkast": "nedkasta",
    "nedkastad": "nedkasta",
    "nedkastade": "nedkasta",
    "nedkastades": "nedkasta",
    "nedkastads": "nedkasta",
    "nedkastande": "nedkasta",
    "nedkastanden": "nedkastande",
    "nedkastandena": "nedkastande",
    "nedkastandenas": "nedkastande",
    "nedkastandens": "nedkastande",
    "nedkastandes": "nedkastande",
    "nedkastandet": "nedkastande",
    "nedkastandets": "nedkastande",
    "nedkastar": "nedkasta",
    "nedkastas": "nedkasta",
    "nedkastat": "nedkasta",
    "nedkastats": "nedkasta",
    "nedkavlad": "nedkavla",
    "nedkavlade": "nedkavla",
    "nedkavlades": "nedkavla",
    "nedkavlads": "nedkavla",
    "nedkavlande": "nedkavla",
    "nedkavlanden": "nedkavlande",
    "nedkavlandena": "nedkavlande",
    "nedkavlandenas": "nedkavlande",
    "nedkavlandens": "nedkavlande",
    "nedkavlandes": "nedkavlande",
    "nedkavlandet": "nedkavlande",
    "nedkavlandets": "nedkavlande",
    "nedkavlar": "nedkavla",
    "nedkavlas": "nedkavla",
    "nedkavlat": "nedkavla",
    "nedkavlats": "nedkavla",
    "nedkippade": "nedkippad",
    "nedkippades": "nedkippad",
    "nedkippads": "nedkippad",
    "nedkippat": "nedkippad",
    "nedkippats": "nedkippad",
    "nedklass": "nedklassa",
    "nedklassad": "nedklassa",
    "nedklassade": "nedklassa",
    "nedklassades": "nedklassa",
    "nedklassads": "nedklassa",
    "nedklassande": "nedklassa",
    "nedklassanden": "nedklassande",
    "nedklassandena": "nedklassande",
    "nedklassandenas": "nedklassande",
    "nedklassandens": "nedklassande",
    "nedklassandes": "nedklassande",
    "nedklassandet": "nedklassande",
    "nedklassandets": "nedklassande",
    "nedklassar": "nedklassa",
    "nedklassas": "nedklassa",
    "nedklassat": "nedklassa",
    "nedklassats": "nedklassa",
    "nedkletade": "nedkletad",
    "nedkletades": "nedkletad",
    "nedkletads": "nedkletad",
    "nedkletat": "nedkletad",
    "nedkletats": "nedkletad",
    "nedknarkade": "nedknarkad",
    "nedknarkades": "nedknarkad",
    "nedknarkads": "nedknarkad",
    "nedknarkat": "nedknarkad",
    "nedknarkats": "nedknarkad",
    "nedkom": "nedkomma",
    "nedkomet": "nedkomma",
    "nedkomets": "nedkomma",
    "nedkommande": "nedkomma",
    "nedkommanden": "nedkommande",
    "nedkommandena": "nedkommande",
    "nedkommandenas": "nedkommande",
    "nedkommandens": "nedkommande",
    "nedkommandes": "nedkommande",
    "nedkommandet": "nedkommande",
    "nedkommandets": "nedkommande",
    "nedkommas": "nedkomma",
    "nedkomme": "nedkomma",
    "nedkommen": "nedkomma",
    "nedkommens": "nedkomma",
    "nedkommer": "nedkomma",
    "nedkommes": "nedkomma",
    "nedkommit": "nedkomma",
    "nedkommits": "nedkomma",
    "nedkomna": "nedkomma",
    "nedkomnas": "nedkomma",
    "nedkomne": "nedkomma",
    "nedkomnes": "nedkomma",
    "nedkoms": "nedkomma",
    "nedkomsten": "nedkomst",
    "nedkomstens": "nedkomst",
    "nedkomsts": "nedkomst",
    "nedla": "nedlägga",
    "nedladdningar": "nedladdning",
    "nedladdningarna": "nedladdning",
    "nedladdningarnas": "nedladdning",
    "nedladdningars": "nedladdning",
    "nedladdningen": "nedladdning",
    "nedladdningens": "nedladdning",
    "nedladdnings": "nedladdning",
    "nedlade": "nedlägga",
    "nedlades": "nedlägga",
    "nedlagd": "nedlägga",
    "nedlagda": "nedlägga",
    "nedlagdas": "nedlägga",
    "nedlagde": "nedlägga",
    "nedlagdes": "nedlägga",
    "nedlagds": "nedlägga",
    "nedlagt": "nedlägga",
    "nedlagts": "nedlägga",
    "nedlas": "nedlägga",
    "nedlegade": "nedlegad",
    "nedlegades": "nedlegad",
    "nedlegads": "nedlegad",
    "nedlegat": "nedlegad",
    "nedlegats": "nedlegad",
    "nedlusade": "nedlusad",
    "nedlusades": "nedlusad",
    "nedlusads": "nedlusad",
    "nedlusat": "nedlusad",
    "nedlusats": "nedlusad",
    "nedlägg": "nedlägga",
    "nedläggande": "nedlägga",
    "nedlägganden": "nedläggande",
    "nedläggandena": "nedläggande",
    "nedläggandenas": "nedläggande",
    "nedläggandens": "nedläggande",
    "nedläggandes": "nedläggande",
    "nedläggandet": "nedläggande",
    "nedläggandets": "nedläggande",
    "nedläggas": "nedlägga",
    "nedläggelsen": "nedläggelse",
    "nedläggelsens": "nedläggelse",
    "nedläggelser": "nedläggelse",
    "nedläggelserna": "nedläggelse",
    "nedläggelsernas": "nedläggelse",
    "nedläggelsers": "nedläggelse",
    "nedläggelses": "nedläggelse",
    "nedlägger": "nedlägga",
    "nedlägges": "nedlägga",
    "nedläggningar": "nedläggning",
    "nedläggningarna": "nedläggning",
    "nedläggningarnas": "nedläggning",
    "nedläggningars": "nedläggning",
    "nedläggningen": "nedläggning",
    "nedläggningens": "nedläggning",
    "nedläggnings": "nedläggning",
    "nedläggningshoten": "nedläggningshot",
    "nedläggningshotens": "nedläggningshot",
    "nedläggningshotet": "nedläggningshot",
    "nedläggningshotets": "nedläggningshot",
    "nedläggningshots": "nedläggningshot",
    "nedläggs": "nedlägga",
    "nedlåtenheten": "nedlåtenhet",
    "nedlåtenhetens": "nedlåtenhet",
    "nedlåtenheter": "nedlåtenhet",
    "nedlåtenheterna": "nedlåtenhet",
    "nedlåtenheternas": "nedlåtenhet",
    "nedlåtenheters": "nedlåtenhet",
    "nedlåtenhets": "nedlåtenhet",
    "nedlåtens": "nedlåten",
    "nedlåtet": "nedlåten",
    "nedlåtets": "nedlåten",
    "nedlåtna": "nedlåten",
    "nedlåtnare": "nedlåten",
    "nedlåtnares": "nedlåten",
    "nedlåtnas": "nedlåten",
    "nedlåtnast": "nedlåten",
    "nedlåtnaste": "nedlåten",
    "nedlåtnastes": "nedlåten",
    "nedlåtnasts": "nedlåten",
    "nedlåtne": "nedlåten",
    "nedlåtnes": "nedlåten",
    "nedmörka": "nedmörk",
    "nedmörkare": "nedmörk",
    "nedmörkares": "nedmörk",
    "nedmörkas": "nedmörk",
    "nedmörkast": "nedmörk",
    "nedmörkaste": "nedmörk",
    "nedmörkastes": "nedmörk",
    "nedmörkasts": "nedmörk",
    "nedmörke": "nedmörk",
    "nedmörkes": "nedmörk",
    "nedmörks": "nedmörk",
    "nedmörkt": "nedmörk",
    "nedmörkts": "nedmörk",
    "nedres": "nedre",
    "nedriga": "nedrig",
    "nedrigare": "nedrig",
    "nedrigares": "nedrig",
    "nedrigas": "nedrig",
    "nedrigast": "nedrig",
    "nedrigaste": "nedrig",
    "nedrigastes": "nedrig",
    "nedrigasts": "nedrig",
    "nedrige": "nedrig",
    "nedriges": "nedrig",
    "nedrigheten": "nedrighet",
    "nedrighetens": "nedrighet",
    "nedrigheter": "nedrighet",
    "nedrigheterna": "nedrighet",
    "nedrigheternas": "nedrighet",
    "nedrigheters": "nedrighet",
    "nedrighets": "nedrighet",
    "nedrigs": "nedrig",
    "nedrigt": "nedrig",
    "nedrigts": "nedrig",
    "nedringda": "nedringd",
    "nedringdare": "nedringd",
    "nedringdares": "nedringd",
    "nedringdas": "nedringd",
    "nedringdast": "nedringd",
    "nedringdaste": "nedringd",
    "nedringdastes": "nedringd",
    "nedringdasts": "nedringd",
    "nedringde": "nedringd",
    "nedringdes": "nedringd",
    "nedringds": "nedringd",
    "nedringt": "nedringd",
    "nedringts": "nedringd",
    "nedrust": "nedrusta",
    "nedrustad": "nedrusta",
    "nedrustade": "nedrusta",
    "nedrustades": "nedrusta",
    "nedrustads": "nedrusta",
    "nedrustande": "nedrusta",
    "nedrustanden": "nedrustande",
    "nedrustandena": "nedrustande",
    "nedrustandenas": "nedrustande",
    "nedrustandens": "nedrustande",
    "nedrustandes": "nedrustande",
    "nedrustandet": "nedrustande",
    "nedrustandets": "nedrustande",
    "nedrustar": "nedrusta",
    "nedrustas": "nedrusta",
    "nedrustat": "nedrusta",
    "nedrustats": "nedrusta",
    "nedrustningar": "nedrustning",
    "nedrustningarna": "nedrustning",
    "nedrustningarnas": "nedrustning",
    "nedrustningars": "nedrustning",
    "nedrustningen": "nedrustning",
    "nedrustningens": "nedrustning",
    "nedrustnings": "nedrustning",
    "nedräkningar": "nedräkning",
    "nedräkningarna": "nedräkning",
    "nedräkningarnas": "nedräkning",
    "nedräkningars": "nedräkning",
    "nedräkningen": "nedräkning",
    "nedräkningens": "nedräkning",
    "nedräknings": "nedräkning",
    "nedsalt": "nedsalta",
    "nedsaltad": "nedsalta",
    "nedsaltade": "nedsalta",
    "nedsaltades": "nedsalta",
    "nedsaltads": "nedsalta",
    "nedsaltande": "nedsalta",
    "nedsaltanden": "nedsaltande",
    "nedsaltandena": "nedsaltande",
    "nedsaltandenas": "nedsaltande",
    "nedsaltandens": "nedsaltande",
    "nedsaltandes": "nedsaltande",
    "nedsaltandet": "nedsaltande",
    "nedsaltandets": "nedsaltande",
    "nedsaltar": "nedsalta",
    "nedsaltas": "nedsalta",
    "nedsaltat": "nedsalta",
    "nedsaltats": "nedsalta",
    "nedsatt": "nedsätta",
    "nedsatta": "nedsätta",
    "nedsattare": "nedsatt",
    "nedsattares": "nedsatt",
    "nedsattas": "nedsätta",
    "nedsattast": "nedsatt",
    "nedsattaste": "nedsatt",
    "nedsattastes": "nedsatt",
    "nedsattasts": "nedsatt",
    "nedsatte": "nedsätta",
    "nedsattes": "nedsätta",
    "nedsatts": "nedsätta",
    "nedskrev": "nedskriva",
    "nedskrevs": "nedskriva",
    "nedskriv": "nedskriva",
    "nedskrivande": "nedskriva",
    "nedskrivanden": "nedskrivande",
    "nedskrivandena": "nedskrivande",
    "nedskrivandenas": "nedskrivande",
    "nedskrivandens": "nedskrivande",
    "nedskrivandes": "nedskrivande",
    "nedskrivandet": "nedskrivande",
    "nedskrivandets": "nedskrivande",
    "nedskrivas": "nedskriva",
    "nedskrive": "nedskriva",
    "nedskriven": "nedskriva",
    "nedskrivens": "nedskriva",
    "nedskriver": "nedskriva",
    "nedskrives": "nedskriva",
    "nedskrivet": "nedskriva",
    "nedskrivets": "nedskriva",
    "nedskrivit": "nedskriva",
    "nedskrivits": "nedskriva",
    "nedskrivna": "nedskriva",
    "nedskrivnas": "nedskriva",
    "nedskrivne": "nedskriva",
    "nedskrivnes": "nedskriva",
    "nedskrivs": "nedskriva",
    "nedskällda": "nedskälld",
    "nedskälldare": "nedskälld",
    "nedskälldares": "nedskälld",
    "nedskälldas": "nedskälld",
    "nedskälldast": "nedskälld",
    "nedskälldaste": "nedskälld",
    "nedskälldastes": "nedskälld",
    "nedskälldasts": "nedskälld",
    "nedskällde": "nedskälld",
    "nedskälldes": "nedskälld",
    "nedskällds": "nedskälld",
    "nedskällt": "nedskälld",
    "nedskällts": "nedskälld",
    "nedskärningar": "nedskärning",
    "nedskärningarna": "nedskärning",
    "nedskärningarnas": "nedskärning",
    "nedskärningars": "nedskärning",
    "nedskärningen": "nedskärning",
    "nedskärningens": "nedskärning",
    "nedskärnings": "nedskärning",
    "nedslagen": "nedslag",
    "nedslagens": "nedslagen",
    "nedslaget": "nedslagen",
    "nedslagets": "nedslagen",
    "nedslagit": "nedslå",
    "nedslagits": "nedslå",
    "nedslagna": "nedslagen",
    "nedslagnare": "nedslagen",
    "nedslagnares": "nedslagen",
    "nedslagnas": "nedslagen",
    "nedslagnast": "nedslagen",
    "nedslagnaste": "nedslagen",
    "nedslagnastes": "nedslagen",
    "nedslagnasts": "nedslagen",
    "nedslagne": "nedslagen",
    "nedslagnes": "nedslagen",
    "nedslags": "nedslag",
    "nedslagskratern": "nedslagskrater",
    "nedslagskraterns": "nedslagskrater",
    "nedslagskraters": "nedslagskrater",
    "nedslagskratrar": "nedslagskrater",
    "nedslagskratrarna": "nedslagskrater",
    "nedslagskratrarnas": "nedslagskrater",
    "nedslagskratrars": "nedslagskrater",
    "nedslagsplatsen": "nedslagsplats",
    "nedslagsplatsens": "nedslagsplats",
    "nedslagsplatser": "nedslagsplats",
    "nedslagsplatserna": "nedslagsplats",
    "nedslagsplatsernas": "nedslagsplats",
    "nedslagsplatsers": "nedslagsplats",
    "nedslagsteorien": "nedslagsteori",
    "nedslagsteoriens": "nedslagsteori",
    "nedslagsteorier": "nedslagsteori",
    "nedslagsteorierna": "nedslagsteori",
    "nedslagsteoriernas": "nedslagsteori",
    "nedslagsteoriers": "nedslagsteori",
    "nedslagsteorin": "nedslagsteori",
    "nedslagsteorins": "nedslagsteori",
    "nedslagsteoris": "nedslagsteori",
    "nedslaktningar": "nedslaktning",
    "nedslaktningarna": "nedslaktning",
    "nedslaktningarnas": "nedslaktning",
    "nedslaktningars": "nedslaktning",
    "nedslaktningen": "nedslaktning",
    "nedslaktningens": "nedslaktning",
    "nedslaktnings": "nedslaktning",
    "nedslitens": "nedsliten",
    "nedslitet": "nedsliten",
    "nedslitets": "nedsliten",
    "nedslitna": "nedsliten",
    "nedslitnare": "nedsliten",
    "nedslitnares": "nedsliten",
    "nedslitnas": "nedsliten",
    "nedslitnast": "nedsliten",
    "nedslitnaste": "nedsliten",
    "nedslitnastes": "nedsliten",
    "nedslitnasts": "nedsliten",
    "nedslitne": "nedsliten",
    "nedslitnes": "nedsliten",
    "nedslog": "nedslå",
    "nedsloge": "nedslå",
    "nedsloges": "nedslå",
    "nedslogs": "nedslå",
    "nedsläppen": "nedsläpp",
    "nedsläppens": "nedsläpp",
    "nedsläppet": "nedsläpp",
    "nedsläppets": "nedsläpp",
    "nedsläpps": "nedsläpp",
    "nedslående": "nedslå",
    "nedslåenden": "nedslående",
    "nedslåendena": "nedslående",
    "nedslåendenas": "nedslående",
    "nedslåendens": "nedslående",
    "nedslåendes": "nedslående",
    "nedslåendet": "nedslående",
    "nedslåendets": "nedslående",
    "nedslår": "nedslå",
    "nedslås": "nedslå",
    "nedsmorda": "nedsmord",
    "nedsmordare": "nedsmord",
    "nedsmordares": "nedsmord",
    "nedsmordas": "nedsmord",
    "nedsmordast": "nedsmord",
    "nedsmordaste": "nedsmord",
    "nedsmordastes": "nedsmord",
    "nedsmordasts": "nedsmord",
    "nedsmorde": "nedsmord",
    "nedsmordes": "nedsmord",
    "nedsmords": "nedsmord",
    "nedsmort": "nedsmord",
    "nedsmorts": "nedsmord",
    "nedsmutsar": "nedsmutsare",
    "nedsmutsaren": "nedsmutsare",
    "nedsmutsarens": "nedsmutsare",
    "nedsmutsares": "nedsmutsare",
    "nedsmutsarna": "nedsmutsare",
    "nedsmutsarnas": "nedsmutsare",
    "nedspillda": "nedspilld",
    "nedspilldare": "nedspilld",
    "nedspilldares": "nedspilld",
    "nedspilldas": "nedspilld",
    "nedspilldast": "nedspilld",
    "nedspilldaste": "nedspilld",
    "nedspilldastes": "nedspilld",
    "nedspilldasts": "nedspilld",
    "nedspillde": "nedspilld",
    "nedspilldes": "nedspilld",
    "nedspillds": "nedspilld",
    "nedspillt": "nedspilld",
    "nedspillts": "nedspilld",
    "nedstrykningar": "nedstrykning",
    "nedstrykningarna": "nedstrykning",
    "nedstrykningarnas": "nedstrykning",
    "nedstrykningars": "nedstrykning",
    "nedstrykningen": "nedstrykning",
    "nedstrykningens": "nedstrykning",
    "nedstryknings": "nedstrykning",
    "nedstråken": "nedstråk",
    "nedstråkens": "nedstråk",
    "nedstråket": "nedstråk",
    "nedstråkets": "nedstråk",
    "nedstråks": "nedstråk",
    "nedstämda": "nedstämd",
    "nedstämdare": "nedstämd",
    "nedstämdares": "nedstämd",
    "nedstämdas": "nedstämd",
    "nedstämdast": "nedstämd",
    "nedstämdaste": "nedstämd",
    "nedstämdastes": "nedstämd",
    "nedstämdasts": "nedstämd",
    "nedstämde": "nedstämd",
    "nedstämdes": "nedstämd",
    "nedstämdheten": "nedstämdhet",
    "nedstämdhetens": "nedstämdhet",
    "nedstämdhets": "nedstämdhet",
    "nedstämds": "nedstämd",
    "nedstämt": "nedstämd",
    "nedstämts": "nedstämd",
    "nedsupens": "nedsupen",
    "nedsupet": "nedsupen",
    "nedsupets": "nedsupen",
    "nedsupna": "nedsupen",
    "nedsupnare": "nedsupen",
    "nedsupnares": "nedsupen",
    "nedsupnas": "nedsupen",
    "nedsupnast": "nedsupen",
    "nedsupnaste": "nedsupen",
    "nedsupnastes": "nedsupen",
    "nedsupnasts": "nedsupen",
    "nedsupne": "nedsupen",
    "nedsupnes": "nedsupen",
    "nedsuttens": "nedsutten",
    "nedsuttet": "nedsutten",
    "nedsuttets": "nedsutten",
    "nedsuttna": "nedsutten",
    "nedsuttnare": "nedsutten",
    "nedsuttnares": "nedsutten",
    "nedsuttnas": "nedsutten",
    "nedsuttnast": "nedsutten",
    "nedsuttnaste": "nedsutten",
    "nedsuttnastes": "nedsutten",
    "nedsuttnasts": "nedsutten",
    "nedsuttne": "nedsutten",
    "nedsuttnes": "nedsutten",
    "nedsvärtningar": "nedsvärtning",
    "nedsvärtningarna": "nedsvärtning",
    "nedsvärtningarnas": "nedsvärtning",
    "nedsvärtningars": "nedsvärtning",
    "nedsvärtningen": "nedsvärtning",
    "nedsvärtningens": "nedsvärtning",
    "nedsvärtnings": "nedsvärtning",
    "nedsänk": "nedsänka",
    "nedsänkande": "nedsänka",
    "nedsänkanden": "nedsänkande",
    "nedsänkandena": "nedsänkande",
    "nedsänkandenas": "nedsänkande",
    "nedsänkandens": "nedsänkande",
    "nedsänkandes": "nedsänkande",
    "nedsänkandet": "nedsänkande",
    "nedsänkandets": "nedsänkande",
    "nedsänkas": "nedsänka",
    "nedsänker": "nedsänka",
    "nedsänkes": "nedsänka",
    "nedsänks": "nedsänka",
    "nedsänkt": "nedsänka",
    "nedsänkta": "nedsänka",
    "nedsänktas": "nedsänka",
    "nedsänkte": "nedsänka",
    "nedsänktes": "nedsänka",
    "nedsänkts": "nedsänka",
    "nedsätt": "nedsätta",
    "nedsättande": "nedsätta",
    "nedsättanden": "nedsättande",
    "nedsättandena": "nedsättande",
    "nedsättandenas": "nedsättande",
    "nedsättandens": "nedsättande",
    "nedsättandes": "nedsättande",
    "nedsättandet": "nedsättande",
    "nedsättandets": "nedsättande",
    "nedsättas": "nedsätta",
    "nedsätter": "nedsätta",
    "nedsättes": "nedsätta",
    "nedsättningar": "nedsättning",
    "nedsättningarna": "nedsättning",
    "nedsättningarnas": "nedsättning",
    "nedsättningars": "nedsättning",
    "nedsättningen": "nedsättning",
    "nedsättningens": "nedsättning",
    "nedsättnings": "nedsättning",
    "nedsättningsbevisen": "nedsättningsbevis",
    "nedsättningsbevisens": "nedsättningsbevis",
    "nedsättningsbeviset": "nedsättningsbevis",
    "nedsättningsbevisets": "nedsättningsbevis",
    "nedsätts": "nedsätta",
    "nedsölade": "nedsölad",
    "nedsölades": "nedsölad",
    "nedsölads": "nedsölad",
    "nedsölat": "nedsölad",
    "nedsölats": "nedsölad",
    "nedtagningar": "nedtagning",
    "nedtagningarna": "nedtagning",
    "nedtagningarnas": "nedtagning",
    "nedtagningars": "nedtagning",
    "nedtagningen": "nedtagning",
    "nedtagningens": "nedtagning",
    "nedtagnings": "nedtagning",
    "nedteckn": "nedteckna",
    "nedtecknad": "nedteckna",
    "nedtecknade": "nedteckna",
    "nedtecknades": "nedteckna",
    "nedtecknads": "nedteckna",
    "nedtecknande": "nedteckna",
    "nedtecknanden": "nedtecknande",
    "nedtecknandena": "nedtecknande",
    "nedtecknandenas": "nedtecknande",
    "nedtecknandens": "nedtecknande",
    "nedtecknandes": "nedtecknande",
    "nedtecknandet": "nedtecknande",
    "nedtecknandets": "nedtecknande",
    "nedtecknar": "nedteckna",
    "nedtecknas": "nedteckna",
    "nedtecknat": "nedteckna",
    "nedtecknats": "nedteckna",
    "nedtoningar": "nedtoning",
    "nedtoningarna": "nedtoning",
    "nedtoningarnas": "nedtoning",
    "nedtoningars": "nedtoning",
    "nedtoningen": "nedtoning",
    "nedtoningens": "nedtoning",
    "nedtonings": "nedtoning",
    "nedtrampade": "nedtrampad",
    "nedtrampades": "nedtrampad",
    "nedtrampads": "nedtrampad",
    "nedtrampat": "nedtrampad",
    "nedtrampats": "nedtrampad",
    "nedtransformerad": "nedtransformera",
    "nedtransformerade": "nedtransformera",
    "nedtransformerades": "nedtransformera",
    "nedtransformerads": "nedtransformera",
    "nedtransformerande": "nedtransformera",
    "nedtransformeranden": "nedtransformerande",
    "nedtransformerandena": "nedtransformerande",
    "nedtransformerandenas": "nedtransformerande",
    "nedtransformerandens": "nedtransformerande",
    "nedtransformerandes": "nedtransformerande",
    "nedtransformerandet": "nedtransformerande",
    "nedtransformerandets": "nedtransformerande",
    "nedtransformerar": "nedtransformera",
    "nedtransformeras": "nedtransformera",
    "nedtransformerat": "nedtransformera",
    "nedtransformerats": "nedtransformera",
    "nedtransformerbara": "nedtransformerbar",
    "nedtransformerbarare": "nedtransformerbar",
    "nedtransformerbarares": "nedtransformerbar",
    "nedtransformerbaras": "nedtransformerbar",
    "nedtransformerbarast": "nedtransformerbar",
    "nedtransformerbaraste": "nedtransformerbar",
    "nedtransformerbarastes": "nedtransformerbar",
    "nedtransformerbarasts": "nedtransformerbar",
    "nedtransformerbare": "nedtransformerbar",
    "nedtransformerbares": "nedtransformerbar",
    "nedtransformerbarheten": "nedtransformerbarhet",
    "nedtransformerbarhetens": "nedtransformerbarhet",
    "nedtransformerbarhets": "nedtransformerbarhet",
    "nedtransformerbars": "nedtransformerbar",
    "nedtransformerbart": "nedtransformerbar",
    "nedtransformerbarts": "nedtransformerbar",
    "nedtransformeringar": "nedtransformering",
    "nedtransformeringarna": "nedtransformering",
    "nedtransformeringarnas": "nedtransformering",
    "nedtransformeringars": "nedtransformering",
    "nedtransformeringen": "nedtransformering",
    "nedtransformeringens": "nedtransformering",
    "nedtransformerings": "nedtransformering",
    "nedtransponerad": "nedtransponera",
    "nedtransponerade": "nedtransponera",
    "nedtransponerades": "nedtransponera",
    "nedtransponerads": "nedtransponera",
    "nedtransponerande": "nedtransponera",
    "nedtransponeranden": "nedtransponerande",
    "nedtransponerandena": "nedtransponerande",
    "nedtransponerandenas": "nedtransponerande",
    "nedtransponerandens": "nedtransponerande",
    "nedtransponerandes": "nedtransponerande",
    "nedtransponerandet": "nedtransponerande",
    "nedtransponerandets": "nedtransponerande",
    "nedtransponerar": "nedtransponera",
    "nedtransponeras": "nedtransponera",
    "nedtransponerat": "nedtransponera",
    "nedtransponerats": "nedtransponera",
    "nedtransponerbara": "nedtransponerbar",
    "nedtransponerbarare": "nedtransponerbar",
    "nedtransponerbarares": "nedtransponerbar",
    "nedtransponerbaras": "nedtransponerbar",
    "nedtransponerbarast": "nedtransponerbar",
    "nedtransponerbaraste": "nedtransponerbar",
    "nedtransponerbarastes": "nedtransponerbar",
    "nedtransponerbarasts": "nedtransponerbar",
    "nedtransponerbare": "nedtransponerbar",
    "nedtransponerbares": "nedtransponerbar",
    "nedtransponerbarheten": "nedtransponerbarhet",
    "nedtransponerbarhetens": "nedtransponerbarhet",
    "nedtransponerbarhets": "nedtransponerbarhet",
    "nedtransponerbars": "nedtransponerbar",
    "nedtransponerbart": "nedtransponerbar",
    "nedtransponerbarts": "nedtransponerbar",
    "nedtransponeringar": "nedtransponering",
    "nedtransponeringarna": "nedtransponering",
    "nedtransponeringarnas": "nedtransponering",
    "nedtransponeringars": "nedtransponering",
    "nedtransponeringen": "nedtransponering",
    "nedtransponeringens": "nedtransponering",
    "nedtransponerings": "nedtransponering",
    "nedtrapp": "nedtrappa",
    "nedtrappad": "nedtrappa",
    "nedtrappade": "nedtrappa",
    "nedtrappades": "nedtrappa",
    "nedtrappads": "nedtrappa",
    "nedtrappande": "nedtrappa",
    "nedtrappanden": "nedtrappande",
    "nedtrappandena": "nedtrappande",
    "nedtrappandenas": "nedtrappande",
    "nedtrappandens": "nedtrappande",
    "nedtrappandes": "nedtrappande",
    "nedtrappandet": "nedtrappande",
    "nedtrappandets": "nedtrappande",
    "nedtrappar": "nedtrappa",
    "nedtrappas": "nedtrappa",
    "nedtrappat": "nedtrappa",
    "nedtrappats": "nedtrappa",
    "nedtrappningar": "nedtrappning",
    "nedtrappningarna": "nedtrappning",
    "nedtrappningarnas": "nedtrappning",
    "nedtrappningars": "nedtrappning",
    "nedtrappningen": "nedtrappning",
    "nedtrappningens": "nedtrappning",
    "nedtrappnings": "nedtrappning",
    "nedtryckta": "nedtryckt",
    "nedtrycktare": "nedtryckt",
    "nedtrycktares": "nedtryckt",
    "nedtrycktas": "nedtryckt",
    "nedtrycktast": "nedtryckt",
    "nedtrycktaste": "nedtryckt",
    "nedtrycktastes": "nedtryckt",
    "nedtrycktasts": "nedtryckt",
    "nedtryckte": "nedtryckt",
    "nedtrycktes": "nedtryckt",
    "nedtrycktheten": "nedtryckthet",
    "nedtryckthetens": "nedtryckthet",
    "nedtryckthets": "nedtryckthet",
    "nedtryckts": "nedtryckt",
    "nedtvingade": "nedtvingad",
    "nedtvingades": "nedtvingad",
    "nedtvingads": "nedtvingad",
    "nedtvingat": "nedtvingad",
    "nedtvingats": "nedtvingad",
    "nedvärderad": "nedvärdera",
    "nedvärderade": "nedvärdera",
    "nedvärderades": "nedvärdera",
    "nedvärderads": "nedvärdera",
    "nedvärderande": "nedvärdera",
    "nedvärderanden": "nedvärderande",
    "nedvärderandena": "nedvärderande",
    "nedvärderandenas": "nedvärderande",
    "nedvärderandens": "nedvärderande",
    "nedvärderandes": "nedvärderande",
    "nedvärderandet": "nedvärderande",
    "nedvärderandets": "nedvärderande",
    "nedvärderar": "nedvärdera",
    "nedvärderas": "nedvärdera",
    "nedvärderat": "nedvärdera",
    "nedvärderats": "nedvärdera",
    "nedvärderbara": "nedvärderbar",
    "nedvärderbarare": "nedvärderbar",
    "nedvärderbarares": "nedvärderbar",
    "nedvärderbaras": "nedvärderbar",
    "nedvärderbarast": "nedvärderbar",
    "nedvärderbaraste": "nedvärderbar",
    "nedvärderbarastes": "nedvärderbar",
    "nedvärderbarasts": "nedvärderbar",
    "nedvärderbare": "nedvärderbar",
    "nedvärderbares": "nedvärderbar",
    "nedvärderbarheten": "nedvärderbarhet",
    "nedvärderbarhetens": "nedvärderbarhet",
    "nedvärderbarhets": "nedvärderbarhet",
    "nedvärderbars": "nedvärderbar",
    "nedvärderbart": "nedvärderbar",
    "nedvärderbarts": "nedvärderbar",
    "nedvärderingar": "nedvärdering",
    "nedvärderingarna": "nedvärdering",
    "nedvärderingarnas": "nedvärdering",
    "nedvärderingars": "nedvärdering",
    "nedvärderingen": "nedvärdering",
    "nedvärderingens": "nedvärdering",
    "nedvärderings": "nedvärdering",
    "nedärvda": "nedärvd",
    "nedärvdare": "nedärvd",
    "nedärvdares": "nedärvd",
    "nedärvdas": "nedärvd",
    "nedärvdast": "nedärvd",
    "nedärvdaste": "nedärvd",
    "nedärvdastes": "nedärvd",
    "nedärvdasts": "nedärvd",
    "nedärvde": "nedärvd",
    "nedärvdes": "nedärvd",
    "nedärvds": "nedärvd",
    "nedärvt": "nedärvd",
    "nedärvts": "nedärvd",
    "nedåtböjde": "nedåtböjd",
    "nedåtböjdes": "nedåtböjd",
    "nedåtböjds": "nedåtböjd",
    "nedåtböjt": "nedåtböjd",
    "nedåtböjts": "nedåtböjd",
    "nedåtgåendes": "nedåtgående",
    "nedåtgåendet": "nedåtgående",
    "nedåtgåendets": "nedåtgående",
    "nedåtgången": "nedåtgång",
    "nedåtgångens": "nedåtgång",
    "nedåtgångs": "nedåtgång",
    "nefriten": "nefrit",
    "nefritens": "nefrit",
    "nefriter": "nefrit",
    "nefriterna": "nefrit",
    "nefriternas": "nefrit",
    "nefriters": "nefrit",
    "nefritiska": "nefritisk",
    "nefritiskare": "nefritisk",
    "nefritiskares": "nefritisk",
    "nefritiskas": "nefritisk",
    "nefritiskast": "nefritisk",
    "nefritiskaste": "nefritisk",
    "nefritiskastes": "nefritisk",
    "nefritiskasts": "nefritisk",
    "nefritiske": "nefritisk",
    "nefritiskes": "nefritisk",
    "nefritisks": "nefritisk",
    "nefritiskt": "nefritisk",
    "nefritiskts": "nefritisk",
    "nefrits": "nefrit",
    "neg": "niga",
    "negationen": "negation",
    "negationens": "negation",
    "negationer": "negation",
    "negationerna": "negation",
    "negationernas": "negation",
    "negationers": "negation",
    "negations": "negation",
    "negativa": "negativ",
    "negativare": "negativ",
    "negativares": "negativ",
    "negativas": "negativ",
    "negativast": "negativ",
    "negativaste": "negativ",
    "negativastes": "negativ",
    "negativasts": "negativ",
    "negative": "negativ",
    "negativen": "negativ",
    "negativens": "negativ",
    "negatives": "negativ",
    "negativet": "negativ",
    "negativets": "negativ",
    "negativismen": "negativism",
    "negativismens": "negativism",
    "negativismer": "negativism",
    "negativismerna": "negativism",
    "negativismernas": "negativism",
    "negativismers": "negativism",
    "negativisms": "negativism",
    "negativistiska": "negativistisk",
    "negativistiskas": "negativistisk",
    "negativistiske": "negativistisk",
    "negativistiskes": "negativistisk",
    "negativistisks": "negativistisk",
    "negativistiskt": "negativistisk",
    "negativistiskts": "negativistisk",
    "negativs": "negativ",
    "negativt": "negativ",
    "negativts": "negativ",
    "negerad": "negera",
    "negerade": "negera",
    "negerades": "negera",
    "negerads": "negera",
    "negerande": "negera",
    "negeranden": "negerande",
    "negerandena": "negerande",
    "negerandenas": "negerande",
    "negerandens": "negerande",
    "negerandes": "negerande",
    "negerandet": "negerande",
    "negerandets": "negerande",
    "negerar": "negera",
    "negeras": "negera",
    "negerat": "negera",
    "negerats": "negera",
    "negerbara": "negerbar",
    "negerbarare": "negerbar",
    "negerbarares": "negerbar",
    "negerbaras": "negerbar",
    "negerbarast": "negerbar",
    "negerbaraste": "negerbar",
    "negerbarastes": "negerbar",
    "negerbarasts": "negerbar",
    "negerbare": "negerbar",
    "negerbares": "negerbar",
    "negerbarheten": "negerbarhet",
    "negerbarhetens": "negerbarhet",
    "negerbarhets": "negerbarhet",
    "negerbars": "negerbar",
    "negerbart": "negerbar",
    "negerbarts": "negerbar",
    "negerbollar": "negerboll",
    "negerbollarna": "negerboll",
    "negerbollarnas": "negerboll",
    "negerbollars": "negerboll",
    "negerbollen": "negerboll",
    "negerbollens": "negerboll",
    "negerbolls": "negerboll",
    "negeringar": "negering",
    "negeringarna": "negering",
    "negeringarnas": "negering",
    "negeringars": "negering",
    "negeringen": "negering",
    "negeringens": "negering",
    "negerings": "negering",
    "negerkornet": "negerkorn",
    "negerkornets": "negerkorn",
    "negerkorns": "negerkorn",
    "negern": "neger",
    "negerns": "neger",
    "negers": "neger",
    "negligeabels": "negligeabel",
    "negligeabelt": "negligeabel",
    "negligeabelts": "negligeabel",
    "negligeabla": "negligeabel",
    "negligeablare": "negligeabel",
    "negligeablares": "negligeabel",
    "negligeablas": "negligeabel",
    "negligeablast": "negligeabel",
    "negligeablaste": "negligeabel",
    "negligeablastes": "negligeabel",
    "negligeablasts": "negligeabel",
    "negligeable": "negligeabel",
    "negligeables": "negligeabel",
    "negligerad": "negligera",
    "negligerade": "negligera",
    "negligerades": "negligera",
    "negligerads": "negligera",
    "negligerande": "negligera",
    "negligeranden": "negligerande",
    "negligerandena": "negligerande",
    "negligerandenas": "negligerande",
    "negligerandens": "negligerande",
    "negligerandes": "negligerande",
    "negligerandet": "negligerande",
    "negligerandets": "negligerande",
    "negligerar": "negligera",
    "negligeras": "negligera",
    "negligerat": "negligera",
    "negligerats": "negligera",
    "negligerbara": "negligerbar",
    "negligerbarare": "negligerbar",
    "negligerbarares": "negligerbar",
    "negligerbaras": "negligerbar",
    "negligerbarast": "negligerbar",
    "negligerbaraste": "negligerbar",
    "negligerbarastes": "negligerbar",
    "negligerbarasts": "negligerbar",
    "negligerbare": "negligerbar",
    "negligerbares": "negligerbar",
    "negligerbarheten": "negligerbarhet",
    "negligerbarhetens": "negligerbarhet",
    "negligerbarhets": "negligerbarhet",
    "negligerbars": "negligerbar",
    "negligerbart": "negligerbar",
    "negligerbarts": "negligerbar",
    "negligeringar": "negligering",
    "negligeringarna": "negligering",
    "negligeringarnas": "negligering",
    "negligeringars": "negligering",
    "negligeringen": "negligering",
    "negligeringens": "negligering",
    "negligerings": "negligering",
    "negligibels": "negligibel",
    "negligibelt": "negligibel",
    "negligibelts": "negligibel",
    "negligibla": "negligibel",
    "negligiblare": "negligibel",
    "negligiblares": "negligibel",
    "negligiblas": "negligibel",
    "negligiblast": "negligibel",
    "negligiblaste": "negligibel",
    "negligiblastes": "negligibel",
    "negligiblasts": "negligibel",
    "negligible": "negligibel",
    "negligibles": "negligibel",
    "negligéer": "negligé",
    "negligéerna": "negligé",
    "negligéernas": "negligé",
    "negligéers": "negligé",
    "negligén": "negligé",
    "negligéns": "negligé",
    "negligés": "negligé",
    "negocierad": "negociera",
    "negocierade": "negociera",
    "negocierades": "negociera",
    "negocierads": "negociera",
    "negocierande": "negociera",
    "negocieranden": "negocierande",
    "negocierandena": "negocierande",
    "negocierandenas": "negocierande",
    "negocierandens": "negocierande",
    "negocierandes": "negocierande",
    "negocierandet": "negocierande",
    "negocierandets": "negocierande",
    "negocierar": "negociera",
    "negocieras": "negociera",
    "negocierat": "negociera",
    "negocierats": "negociera",
    "negocierbara": "negocierbar",
    "negocierbarare": "negocierbar",
    "negocierbarares": "negocierbar",
    "negocierbaras": "negocierbar",
    "negocierbarast": "negocierbar",
    "negocierbaraste": "negocierbar",
    "negocierbarastes": "negocierbar",
    "negocierbarasts": "negocierbar",
    "negocierbare": "negocierbar",
    "negocierbares": "negocierbar",
    "negocierbarheten": "negocierbarhet",
    "negocierbarhetens": "negocierbarhet",
    "negocierbarhets": "negocierbarhet",
    "negocierbars": "negocierbar",
    "negocierbart": "negocierbar",
    "negocierbarts": "negocierbar",
    "negocieringar": "negociering",
    "negocieringarna": "negociering",
    "negocieringarnas": "negociering",
    "negocieringars": "negociering",
    "negocieringen": "negociering",
    "negocieringens": "negociering",
    "negocierings": "negociering",
    "negotierad": "negotiera",
    "negotierade": "negotiera",
    "negotierades": "negotiera",
    "negotierads": "negotiera",
    "negotierande": "negotiera",
    "negotieranden": "negotierande",
    "negotierandena": "negotierande",
    "negotierandenas": "negotierande",
    "negotierandens": "negotierande",
    "negotierandes": "negotierande",
    "negotierandet": "negotierande",
    "negotierandets": "negotierande",
    "negotierar": "negotiera",
    "negotieras": "negotiera",
    "negotierat": "negotiera",
    "negotierats": "negotiera",
    "negotierbara": "negotierbar",
    "negotierbarare": "negotierbar",
    "negotierbarares": "negotierbar",
    "negotierbaras": "negotierbar",
    "negotierbarast": "negotierbar",
    "negotierbaraste": "negotierbar",
    "negotierbarastes": "negotierbar",
    "negotierbarasts": "negotierbar",
    "negotierbare": "negotierbar",
    "negotierbares": "negotierbar",
    "negotierbarheten": "negotierbarhet",
    "negotierbarhetens": "negotierbarhet",
    "negotierbarhets": "negotierbarhet",
    "negotierbars": "negotierbar",
    "negotierbart": "negotierbar",
    "negotierbarts": "negotierbar",
    "negotieringar": "negotiering",
    "negotieringarna": "negotiering",
    "negotieringarnas": "negotiering",
    "negotieringars": "negotiering",
    "negotieringen": "negotiering",
    "negotieringens": "negotiering",
    "negotierings": "negotiering",
    "negrer": "neger",
    "negrerna": "neger",
    "negrernas": "neger",
    "negrers": "neger",
    "negressen": "negress",
    "negressens": "negress",
    "negresser": "negress",
    "negresserna": "negress",
    "negressernas": "negress",
    "negressers": "negress",
    "negroiden": "negroid",
    "negroidens": "negroid",
    "negroider": "negroid",
    "negroiderna": "negroid",
    "negroidernas": "negroid",
    "negroiders": "negroid",
    "negroids": "negroid",
    "negs": "niga",
    "nejden": "nejd",
    "nejdens": "nejd",
    "nejder": "nejd",
    "nejderna": "nejd",
    "nejdernas": "nejd",
    "nejders": "nejd",
    "nejds": "nejd",
    "nejen": "nej",
    "nejens": "nej",
    "nejet": "nej",
    "nejets": "nej",
    "nejlik": "nejlika",
    "nejlikan": "nejlika",
    "nejlikans": "nejlika",
    "nejlikas": "nejlika",
    "nejlike": "nejlika",
    "nejlikoljan": "nejlikolja",
    "nejlikoljans": "nejlikolja",
    "nejlikoljas": "nejlikolja",
    "nejlikolje": "nejlikolja",
    "nejlikor": "nejlika",
    "nejlikorna": "nejlika",
    "nejlikornas": "nejlika",
    "nejlikors": "nejlika",
    "nejlikroten": "nejlikrot",
    "nejlikrotens": "nejlikrot",
    "nejlikrots": "nejlikrot",
    "nejlikrötter": "nejlikrot",
    "nejlikrötterna": "nejlikrot",
    "nejlikrötternas": "nejlikrot",
    "nejlikrötters": "nejlikrot",
    "nejliks": "nejlika",
    "nejlikväxten": "nejlikväxt",
    "nejlikväxtens": "nejlikväxt",
    "nejlikväxter": "nejlikväxt",
    "nejlikväxterna": "nejlikväxt",
    "nejlikväxternas": "nejlikväxt",
    "nejlikväxters": "nejlikväxt",
    "nejlikväxts": "nejlikväxt",
    "nejonögas": "nejonöga",
    "nejonögat": "nejonöga",
    "nejonögats": "nejonöga",
    "nejonögon": "nejonöga",
    "nejonögonen": "nejonöga",
    "nejonögonens": "nejonöga",
    "nejonögons": "nejonöga",
    "nejrösten": "nejröst",
    "nejröstens": "nejröst",
    "nejröster": "nejröst",
    "nejrösterna": "nejröst",
    "nejrösternas": "nejröst",
    "nejrösters": "nejröst",
    "nejrösts": "nejröst",
    "nejs": "nej",
    "nejsägar": "nejsägare",
    "nejsägaren": "nejsägare",
    "nejsägarens": "nejsägare",
    "nejsägares": "nejsägare",
    "nejsägarna": "nejsägare",
    "nejsägarnas": "nejsägare",
    "nek": "neka",
    "nekad": "neka",
    "nekade": "neka",
    "nekades": "neka",
    "nekads": "neka",
    "nekande": "neka",
    "nekanden": "nekande",
    "nekandena": "nekande",
    "nekandenas": "nekande",
    "nekandens": "nekande",
    "nekandes": "nekande",
    "nekandet": "nekande",
    "nekandets": "nekande",
    "nekar": "neka",
    "nekarna": "nek",
    "nekarnas": "nek",
    "nekars": "nek",
    "nekas": "neka",
    "nekat": "neka",
    "nekats": "neka",
    "neken": "nek",
    "nekens": "nek",
    "neker": "nek",
    "nekerna": "nek",
    "nekernas": "nek",
    "nekers": "nek",
    "nekrofila": "nekrofil",
    "nekrofilas": "nekrofil",
    "nekrofile": "nekrofil",
    "nekrofilen": "nekrofil",
    "nekrofilens": "nekrofil",
    "nekrofiler": "nekrofil",
    "nekrofilerna": "nekrofil",
    "nekrofilernas": "nekrofil",
    "nekrofilers": "nekrofil",
    "nekrofiles": "nekrofil",
    "nekrofilien": "nekrofili",
    "nekrofiliens": "nekrofili",
    "nekrofilin": "nekrofili",
    "nekrofilins": "nekrofili",
    "nekrofilis": "nekrofili",
    "nekrofils": "nekrofil",
    "nekrofilt": "nekrofil",
    "nekrofilts": "nekrofil",
    "nekrologen": "nekrolog",
    "nekrologens": "nekrolog",
    "nekrologer": "nekrolog",
    "nekrologerna": "nekrolog",
    "nekrologernas": "nekrolog",
    "nekrologers": "nekrolog",
    "nekrologs": "nekrolog",
    "nekrosen": "nekros",
    "nekrosens": "nekros",
    "neks": "nek",
    "nektardragen": "nektardrag",
    "nektardragens": "nektardrag",
    "nektardraget": "nektardrag",
    "nektardragets": "nektardrag",
    "nektardrags": "nektardrag",
    "nektarie": "nektarium",
    "nektarier": "nektarium",
    "nektarierna": "nektarium",
    "nektariernas": "nektarium",
    "nektariers": "nektarium",
    "nektariet": "nektarium",
    "nektariets": "nektarium",
    "nektarinen": "nektarin",
    "nektarinens": "nektarin",
    "nektariner": "nektarin",
    "nektarinerna": "nektarin",
    "nektarinernas": "nektarin",
    "nektariners": "nektarin",
    "nektarins": "nektarin",
    "nektariums": "nektarium",
    "nektarn": "nektar",
    "nektarns": "nektar",
    "nektars": "nektar",
    "nematoden": "nematod",
    "nematodens": "nematod",
    "nematoder": "nematod",
    "nematoderna": "nematod",
    "nematodernas": "nematod",
    "nematoders": "nematod",
    "nematods": "nematod",
    "nemesistank": "nemesistanke",
    "nemesistankar": "nemesistanke",
    "nemesistankarna": "nemesistanke",
    "nemesistankarnas": "nemesistanke",
    "nemesistankars": "nemesistanke",
    "nemesistanken": "nemesistanke",
    "nemesistankens": "nemesistanke",
    "nemesistankes": "nemesistanke",
    "nemesistanks": "nemesistanke",
    "nen": "n",
    "nens": "nen",
    "neodymen": "neodym",
    "neodymens": "neodym",
    "neodymer": "neodym",
    "neodymerna": "neodym",
    "neodymernas": "neodym",
    "neodymers": "neodym",
    "neodymet": "neodym",
    "neodymets": "neodym",
    "neodymmagneten": "neodymmagnet",
    "neodymmagnetens": "neodymmagnet",
    "neodymmagneter": "neodymmagnet",
    "neodymmagneterna": "neodymmagnet",
    "neodymmagneternas": "neodymmagnet",
    "neodymmagneters": "neodymmagnet",
    "neodymmagnets": "neodymmagnet",
    "neodyms": "neodym",
    "neofilien": "neofili",
    "neofiliens": "neofili",
    "neofilin": "neofili",
    "neofilins": "neofili",
    "neofilis": "neofili",
    "neogens": "neogen",
    "neoimpressionismen": "neoimpressionism",
    "neoimpressionismens": "neoimpressionism",
    "neoimpressionismer": "neoimpressionism",
    "neoimpressionismerna": "neoimpressionism",
    "neoimpressionismernas": "neoimpressionism",
    "neoimpressionismers": "neoimpressionism",
    "neoimpressionisms": "neoimpressionism",
    "neoimpressionistiska": "neoimpressionistisk",
    "neoimpressionistiskas": "neoimpressionistisk",
    "neoimpressionistiske": "neoimpressionistisk",
    "neoimpressionistiskes": "neoimpressionistisk",
    "neoimpressionistisks": "neoimpressionistisk",
    "neoimpressionistiskt": "neoimpressionistisk",
    "neoimpressionistiskts": "neoimpressionistisk",
    "neoklassicismen": "neoklassicism",
    "neoklassicismens": "neoklassicism",
    "neoklassicismer": "neoklassicism",
    "neoklassicismerna": "neoklassicism",
    "neoklassicismernas": "neoklassicism",
    "neoklassicismers": "neoklassicism",
    "neoklassicisms": "neoklassicism",
    "neoklassicistiska": "neoklassicistisk",
    "neoklassicistiskas": "neoklassicistisk",
    "neoklassicistiske": "neoklassicistisk",
    "neoklassicistiskes": "neoklassicistisk",
    "neoklassicistisks": "neoklassicistisk",
    "neoklassicistiskt": "neoklassicistisk",
    "neoklassicistiskts": "neoklassicistisk",
    "neokolonialismen": "neokolonialism",
    "neokolonialismens": "neokolonialism",
    "neokolonialismer": "neokolonialism",
    "neokolonialismerna": "neokolonialism",
    "neokolonialismernas": "neokolonialism",
    "neokolonialismers": "neokolonialism",
    "neokolonialisms": "neokolonialism",
    "neokolonialistiska": "neokolonialistisk",
    "neokolonialistiskare": "neokolonialistisk",
    "neokolonialistiskares": "neokolonialistisk",
    "neokolonialistiskas": "neokolonialistisk",
    "neokolonialistiskast": "neokolonialistisk",
    "neokolonialistiskaste": "neokolonialistisk",
    "neokolonialistiskastes": "neokolonialistisk",
    "neokolonialistiskasts": "neokolonialistisk",
    "neokolonialistiske": "neokolonialistisk",
    "neokolonialistiskes": "neokolonialistisk",
    "neokolonialistisks": "neokolonialistisk",
    "neokolonialistiskt": "neokolonialistisk",
    "neokolonialistiskts": "neokolonialistisk",
    "neolitiska": "neolitisk",
    "neolitiskare": "neolitisk",
    "neolitiskares": "neolitisk",
    "neolitiskas": "neolitisk",
    "neolitiskast": "neolitisk",
    "neolitiskaste": "neolitisk",
    "neolitiskastes": "neolitisk",
    "neolitiskasts": "neolitisk",
    "neolitiske": "neolitisk",
    "neolitiskes": "neolitisk",
    "neolitisks": "neolitisk",
    "neolitiskt": "neolitisk",
    "neolitiskts": "neolitisk",
    "neologen": "neolog",
    "neologens": "neolog",
    "neologer": "neolog",
    "neologerna": "neolog",
    "neologernas": "neolog",
    "neologers": "neolog",
    "neologien": "neologi",
    "neologiens": "neologi",
    "neologin": "neologi",
    "neologins": "neologi",
    "neologis": "neologi",
    "neologs": "neolog",
    "neonet": "neon",
    "neonets": "neon",
    "neongasen": "neongas",
    "neongasens": "neongas",
    "neongaser": "neongas",
    "neongaserna": "neongas",
    "neongasernas": "neongas",
    "neongasers": "neongas",
    "neonljusen": "neonljus",
    "neonljusens": "neonljus",
    "neonljuset": "neonljus",
    "neonljusets": "neonljus",
    "neonrören": "neonrör",
    "neonrörens": "neonrör",
    "neonröret": "neonrör",
    "neonrörets": "neonrör",
    "neonrörs": "neonrör",
    "neons": "neon",
    "neonskyltar": "neonskylt",
    "neonskyltarna": "neonskylt",
    "neonskyltarnas": "neonskylt",
    "neonskyltars": "neonskylt",
    "neonskylten": "neonskylt",
    "neonskyltens": "neonskylt",
    "neonskylts": "neonskylt",
    "neotektoniken": "neotektonik",
    "neotektonikens": "neotektonik",
    "neotektoniker": "neotektonik",
    "neotektonikerna": "neotektonik",
    "neotektonikernas": "neotektonik",
    "neotektonikers": "neotektonik",
    "neotektoniks": "neotektonik",
    "neotektoniska": "neotektonisk",
    "neotektoniskare": "neotektonisk",
    "neotektoniskares": "neotektonisk",
    "neotektoniskas": "neotektonisk",
    "neotektoniskast": "neotektonisk",
    "neotektoniskaste": "neotektonisk",
    "neotektoniskastes": "neotektonisk",
    "neotektoniskasts": "neotektonisk",
    "neotektoniske": "neotektonisk",
    "neotektoniskes": "neotektonisk",
    "neotektonisks": "neotektonisk",
    "neotektoniskt": "neotektonisk",
    "neotektoniskts": "neotektonisk",
    "nepalesen": "nepales",
    "nepalesens": "nepales",
    "nepaleser": "nepales",
    "nepaleserna": "nepales",
    "nepalesernas": "nepales",
    "nepalesers": "nepales",
    "nepalesisk": "nepalesiska",
    "nepalesiska": "nepalesisk",
    "nepalesiskan": "nepalesiska",
    "nepalesiskans": "nepalesiska",
    "nepalesiskare": "nepalesisk",
    "nepalesiskares": "nepalesisk",
    "nepalesiskas": "nepalesiska",
    "nepalesiskast": "nepalesisk",
    "nepalesiskaste": "nepalesisk",
    "nepalesiskastes": "nepalesisk",
    "nepalesiskasts": "nepalesisk",
    "nepalesiske": "nepalesiska",
    "nepalesiskes": "nepalesisk",
    "nepalesiskor": "nepalesiska",
    "nepalesiskorna": "nepalesiska",
    "nepalesiskornas": "nepalesiska",
    "nepalesiskors": "nepalesiska",
    "nepalesisks": "nepalesisk",
    "nepalesiskt": "nepalesisk",
    "nepalesiskts": "nepalesisk",
    "nepalis": "nepali",
    "nepotismen": "nepotism",
    "nepotismens": "nepotism",
    "nepotismer": "nepotism",
    "nepotismerna": "nepotism",
    "nepotismernas": "nepotism",
    "nepotismers": "nepotism",
    "nepotisms": "nepotism",
    "neptuniet": "neptunium",
    "neptuniets": "neptunium",
    "neptuniska": "neptunisk",
    "neptuniskare": "neptunisk",
    "neptuniskares": "neptunisk",
    "neptuniskas": "neptunisk",
    "neptuniskast": "neptunisk",
    "neptuniskaste": "neptunisk",
    "neptuniskastes": "neptunisk",
    "neptuniskasts": "neptunisk",
    "neptuniske": "neptunisk",
    "neptuniskes": "neptunisk",
    "neptunisks": "neptunisk",
    "neptuniskt": "neptunisk",
    "neptuniskts": "neptunisk",
    "neptuniumet": "neptunium",
    "neptuniumets": "neptunium",
    "neptuniums": "neptunium",
    "nerarbet": "nerarbeta",
    "nerarbetad": "nerarbeta",
    "nerarbetade": "nerarbeta",
    "nerarbetades": "nerarbeta",
    "nerarbetads": "nerarbeta",
    "nerarbetande": "nerarbeta",
    "nerarbetanden": "nerarbetande",
    "nerarbetandena": "nerarbetande",
    "nerarbetandenas": "nerarbetande",
    "nerarbetandens": "nerarbetande",
    "nerarbetandes": "nerarbetande",
    "nerarbetandet": "nerarbetande",
    "nerarbetandets": "nerarbetande",
    "nerarbetar": "nerarbeta",
    "nerarbetas": "nerarbeta",
    "nerarbetat": "nerarbeta",
    "nerarbetats": "nerarbeta",
    "nerbantade": "nerbantad",
    "nerbantades": "nerbantad",
    "nerbantads": "nerbantad",
    "nerbantat": "nerbantad",
    "nerbantats": "nerbantad",
    "nerblodade": "nerblodad",
    "nerblodades": "nerblodad",
    "nerblodads": "nerblodad",
    "nerblodat": "nerblodad",
    "nerblodats": "nerblodad",
    "nerblås": "nerblåsa",
    "nerblåsande": "nerblåsa",
    "nerblåsanden": "nerblåsande",
    "nerblåsandena": "nerblåsande",
    "nerblåsandenas": "nerblåsande",
    "nerblåsandens": "nerblåsande",
    "nerblåsandes": "nerblåsande",
    "nerblåsandet": "nerblåsande",
    "nerblåsandets": "nerblåsande",
    "nerblåsas": "nerblåsa",
    "nerblåser": "nerblåsa",
    "nerblåses": "nerblåsa",
    "nerblåst": "nerblåsa",
    "nerblåsta": "nerblåsa",
    "nerblåstas": "nerblåsa",
    "nerblåste": "nerblåsa",
    "nerblåstes": "nerblåsa",
    "nerblåsts": "nerblåsa",
    "nerborrade": "nerborrad",
    "nerborrades": "nerborrad",
    "nerborrads": "nerborrad",
    "nerborrat": "nerborrad",
    "nerborrats": "nerborrad",
    "nerbragt": "nerbringa",
    "nerbragte": "nerbringa",
    "nerbragtes": "nerbringa",
    "nerbragts": "nerbringa",
    "nerbring": "nerbringa",
    "nerbringad": "nerbringa",
    "nerbringade": "nerbringa",
    "nerbringades": "nerbringa",
    "nerbringads": "nerbringa",
    "nerbringande": "nerbringa",
    "nerbringanden": "nerbringande",
    "nerbringandena": "nerbringande",
    "nerbringandenas": "nerbringande",
    "nerbringandens": "nerbringande",
    "nerbringandes": "nerbringande",
    "nerbringandet": "nerbringande",
    "nerbringandets": "nerbringande",
    "nerbringar": "nerbringa",
    "nerbringas": "nerbringa",
    "nerbringat": "nerbringa",
    "nerbringats": "nerbringa",
    "nerbruten": "nerbryta",
    "nerbrutens": "nerbryta",
    "nerbrutet": "nerbryta",
    "nerbrutets": "nerbryta",
    "nerbrutit": "nerbryta",
    "nerbrutits": "nerbryta",
    "nerbrutna": "nerbryta",
    "nerbrutnare": "nerbruten",
    "nerbrutnares": "nerbruten",
    "nerbrutnas": "nerbryta",
    "nerbrutnast": "nerbruten",
    "nerbrutnaste": "nerbruten",
    "nerbrutnastes": "nerbruten",
    "nerbrutnasts": "nerbruten",
    "nerbrutne": "nerbryta",
    "nerbrutnes": "nerbryta",
    "nerbryt": "nerbryta",
    "nerbrytande": "nerbryta",
    "nerbrytanden": "nerbrytande",
    "nerbrytandena": "nerbrytande",
    "nerbrytandenas": "nerbrytande",
    "nerbrytandens": "nerbrytande",
    "nerbrytandes": "nerbrytande",
    "nerbrytandet": "nerbrytande",
    "nerbrytandets": "nerbrytande",
    "nerbrytas": "nerbryta",
    "nerbryte": "nerbryta",
    "nerbryter": "nerbryta",
    "nerbrytes": "nerbryta",
    "nerbrytningar": "nerbrytning",
    "nerbrytningarna": "nerbrytning",
    "nerbrytningarnas": "nerbrytning",
    "nerbrytningars": "nerbrytning",
    "nerbrytningen": "nerbrytning",
    "nerbrytningens": "nerbrytning",
    "nerbrytnings": "nerbrytning",
    "nerbrytningsstationen": "nerbrytningsstation",
    "nerbrytningsstationens": "nerbrytningsstation",
    "nerbrytningsstationer": "nerbrytningsstation",
    "nerbrytningsstationerna": "nerbrytningsstation",
    "nerbrytningsstationernas": "nerbrytningsstation",
    "nerbrytningsstationers": "nerbrytningsstation",
    "nerbrytningsstations": "nerbrytningsstation",
    "nerbryts": "nerbryta",
    "nerbröt": "nerbryta",
    "nerbröte": "nerbryta",
    "nerbrötes": "nerbryta",
    "nerbröts": "nerbryta",
    "nerbusade": "nerbusad",
    "nerbusades": "nerbusad",
    "nerbusads": "nerbusad",
    "nerbusat": "nerbusad",
    "nerbusats": "nerbusad",
    "nerbusningar": "nerbusning",
    "nerbusningarna": "nerbusning",
    "nerbusningarnas": "nerbusning",
    "nerbusningars": "nerbusning",
    "nerbusningen": "nerbusning",
    "nerbusningens": "nerbusning",
    "nerbusnings": "nerbusning",
    "nerdekade": "nerdekad",
    "nerdekades": "nerdekad",
    "nerdekads": "nerdekad",
    "nerdekat": "nerdekad",
    "nerdekats": "nerdekad",
    "nerdragens": "nerdragen",
    "nerdraget": "nerdragen",
    "nerdragets": "nerdragen",
    "nerdragna": "nerdragen",
    "nerdragnare": "nerdragen",
    "nerdragnares": "nerdragen",
    "nerdragnas": "nerdragen",
    "nerdragnast": "nerdragen",
    "nerdragnaste": "nerdragen",
    "nerdragnastes": "nerdragen",
    "nerdragnasts": "nerdragen",
    "nerdragne": "nerdragen",
    "nerdragnes": "nerdragen",
    "nerdragningar": "nerdragning",
    "nerdragningarna": "nerdragning",
    "nerdragningarnas": "nerdragning",
    "nerdragningars": "nerdragning",
    "nerdragningen": "nerdragning",
    "nerdragningens": "nerdragning",
    "nerdragnings": "nerdragning",
    "nereiden": "nereid",
    "nereidens": "nereid",
    "nereider": "nereid",
    "nereiderna": "nereid",
    "nereidernas": "nereid",
    "nereiders": "nereid",
    "nereids": "nereid",
    "nerfallen": "nerfall",
    "nerfallens": "nerfall",
    "nerfallet": "nerfall",
    "nerfallets": "nerfall",
    "nerfalls": "nerfall",
    "nerfarten": "nerfart",
    "nerfartens": "nerfart",
    "nerfarter": "nerfart",
    "nerfarterna": "nerfart",
    "nerfarternas": "nerfart",
    "nerfarters": "nerfart",
    "nerfarts": "nerfart",
    "nerfruse": "nerfrysa",
    "nerfrusen": "nerfrysa",
    "nerfrusens": "nerfrysa",
    "nerfruses": "nerfrysa",
    "nerfruset": "nerfrysa",
    "nerfrusets": "nerfrysa",
    "nerfrusit": "nerfrysa",
    "nerfrusits": "nerfrysa",
    "nerfrusna": "nerfrysa",
    "nerfrusnas": "nerfrysa",
    "nerfrusne": "nerfrysa",
    "nerfrusnes": "nerfrysa",
    "nerfrys": "nerfrysa",
    "nerfrysande": "nerfrysa",
    "nerfrysanden": "nerfrysande",
    "nerfrysandena": "nerfrysande",
    "nerfrysandenas": "nerfrysande",
    "nerfrysandens": "nerfrysande",
    "nerfrysandes": "nerfrysande",
    "nerfrysandet": "nerfrysande",
    "nerfrysandets": "nerfrysande",
    "nerfrysas": "nerfrysa",
    "nerfryse": "nerfrysa",
    "nerfryser": "nerfrysa",
    "nerfryses": "nerfrysa",
    "nerfrysningar": "nerfrysning",
    "nerfrysningarna": "nerfrysning",
    "nerfrysningarnas": "nerfrysning",
    "nerfrysningars": "nerfrysning",
    "nerfrysningen": "nerfrysning",
    "nerfrysningens": "nerfrysning",
    "nerfrysnings": "nerfrysning",
    "nerfryst": "nerfrysa",
    "nerfrysta": "nerfrysa",
    "nerfrystas": "nerfrysa",
    "nerfryste": "nerfrysa",
    "nerfrystes": "nerfrysa",
    "nerfrysts": "nerfrysa",
    "nerfrös": "nerfrysa",
    "nerfällde": "nerfälld",
    "nerfälldes": "nerfälld",
    "nerfällds": "nerfälld",
    "nerfällt": "nerfälld",
    "nerfällts": "nerfälld",
    "nerförsback": "nerförsbacke",
    "nerförsbackar": "nerförsbacke",
    "nerförsbackarna": "nerförsbacke",
    "nerförsbackarnas": "nerförsbacke",
    "nerförsbackars": "nerförsbacke",
    "nerförsbacken": "nerförsbacke",
    "nerförsbackens": "nerförsbacke",
    "nerförsbackes": "nerförsbacke",
    "nerförsbacks": "nerförsbacke",
    "nergjord": "nergöra",
    "nergjorda": "nergöra",
    "nergjordas": "nergöra",
    "nergjorde": "nergöra",
    "nergjordes": "nergöra",
    "nergjords": "nergöra",
    "nergjort": "nergöra",
    "nergjorts": "nergöra",
    "nergrisade": "nergrisad",
    "nergrisades": "nergrisad",
    "nergrisads": "nergrisad",
    "nergrisat": "nergrisad",
    "nergrisats": "nergrisad",
    "nergåendes": "nergående",
    "nergåendet": "nergående",
    "nergåendets": "nergående",
    "nergångar": "nergång",
    "nergångarna": "nergång",
    "nergångarnas": "nergång",
    "nergångars": "nergång",
    "nergången": "nergång",
    "nergångens": "nergången",
    "nergånget": "nergången",
    "nergångets": "nergången",
    "nergångna": "nergången",
    "nergångnare": "nergången",
    "nergångnares": "nergången",
    "nergångnas": "nergången",
    "nergångnast": "nergången",
    "nergångnaste": "nergången",
    "nergångnastes": "nergången",
    "nergångnasts": "nergången",
    "nergångne": "nergången",
    "nergångnes": "nergången",
    "nergångs": "nergång",
    "nergör": "nergöra",
    "nergörande": "nergöra",
    "nergöranden": "nergörande",
    "nergörandena": "nergörande",
    "nergörandenas": "nergörande",
    "nergörandens": "nergörande",
    "nergörandes": "nergörande",
    "nergörandet": "nergörande",
    "nergörandets": "nergörande",
    "nergöras": "nergöra",
    "nergöres": "nergöra",
    "nergörs": "nergöra",
    "nerhalar": "nerhalare",
    "nerhalaren": "nerhalare",
    "nerhalarens": "nerhalare",
    "nerhalares": "nerhalare",
    "nerhalarna": "nerhalare",
    "nerhalarnas": "nerhalare",
    "nerhukade": "nerhukad",
    "nerhukades": "nerhukad",
    "nerhukads": "nerhukad",
    "nerhukat": "nerhukad",
    "nerhukats": "nerhukad",
    "nerien": "nerium",
    "neriens": "nerium",
    "nerier": "nerium",
    "nerierna": "nerium",
    "neriernas": "nerium",
    "neriers": "nerium",
    "neris": "nerisa",
    "nerisad": "nerisa",
    "nerisade": "nerisa",
    "nerisades": "nerisa",
    "nerisads": "nerisa",
    "nerisande": "nerisa",
    "nerisanden": "nerisande",
    "nerisandena": "nerisande",
    "nerisandenas": "nerisande",
    "nerisandens": "nerisande",
    "nerisandes": "nerisande",
    "nerisandet": "nerisande",
    "nerisandets": "nerisande",
    "nerisar": "nerisa",
    "nerisas": "nerisa",
    "nerisat": "nerisa",
    "nerisats": "nerisa",
    "neriums": "nerium",
    "nerkall": "nerkalla",
    "nerkallad": "nerkalla",
    "nerkallade": "nerkalla",
    "nerkallades": "nerkalla",
    "nerkallads": "nerkalla",
    "nerkallande": "nerkalla",
    "nerkallanden": "nerkallande",
    "nerkallandena": "nerkallande",
    "nerkallandenas": "nerkallande",
    "nerkallandens": "nerkallande",
    "nerkallandes": "nerkallande",
    "nerkallandet": "nerkallande",
    "nerkallandets": "nerkallande",
    "nerkallar": "nerkalla",
    "nerkallas": "nerkalla",
    "nerkallat": "nerkalla",
    "nerkallats": "nerkalla",
    "nerkast": "nerkasta",
    "nerkastad": "nerkasta",
    "nerkastade": "nerkasta",
    "nerkastades": "nerkasta",
    "nerkastads": "nerkasta",
    "nerkastande": "nerkasta",
    "nerkastanden": "nerkastande",
    "nerkastandena": "nerkastande",
    "nerkastandenas": "nerkastande",
    "nerkastandens": "nerkastande",
    "nerkastandes": "nerkastande",
    "nerkastandet": "nerkastande",
    "nerkastandets": "nerkastande",
    "nerkastar": "nerkasta",
    "nerkastas": "nerkasta",
    "nerkastat": "nerkasta",
    "nerkastats": "nerkasta",
    "nerkavlad": "nerkavla",
    "nerkavlade": "nerkavla",
    "nerkavlades": "nerkavla",
    "nerkavlads": "nerkavla",
    "nerkavlande": "nerkavla",
    "nerkavlanden": "nerkavlande",
    "nerkavlandena": "nerkavlande",
    "nerkavlandenas": "nerkavlande",
    "nerkavlandens": "nerkavlande",
    "nerkavlandes": "nerkavlande",
    "nerkavlandet": "nerkavlande",
    "nerkavlandets": "nerkavlande",
    "nerkavlar": "nerkavla",
    "nerkavlas": "nerkavla",
    "nerkavlat": "nerkavla",
    "nerkavlats": "nerkavla",
    "nerkilade": "nerkilad",
    "nerkilades": "nerkilad",
    "nerkilads": "nerkilad",
    "nerkilat": "nerkilad",
    "nerkilats": "nerkilad",
    "nerkippade": "nerkippad",
    "nerkippades": "nerkippad",
    "nerkippads": "nerkippad",
    "nerkippat": "nerkippad",
    "nerkippats": "nerkippad",
    "nerklass": "nerklassa",
    "nerklassad": "nerklassa",
    "nerklassade": "nerklassa",
    "nerklassades": "nerklassa",
    "nerklassads": "nerklassa",
    "nerklassande": "nerklassa",
    "nerklassanden": "nerklassande",
    "nerklassandena": "nerklassande",
    "nerklassandenas": "nerklassande",
    "nerklassandens": "nerklassande",
    "nerklassandes": "nerklassande",
    "nerklassandet": "nerklassande",
    "nerklassandets": "nerklassande",
    "nerklassar": "nerklassa",
    "nerklassas": "nerklassa",
    "nerklassat": "nerklassa",
    "nerklassats": "nerklassa",
    "nerknarkade": "nerknarkad",
    "nerknarkades": "nerknarkad",
    "nerknarkads": "nerknarkad",
    "nerknarkat": "nerknarkad",
    "nerknarkats": "nerknarkad",
    "nerkom": "nerkomma",
    "nerkomet": "nerkomma",
    "nerkomets": "nerkomma",
    "nerkommande": "nerkomma",
    "nerkommanden": "nerkommande",
    "nerkommandena": "nerkommande",
    "nerkommandenas": "nerkommande",
    "nerkommandens": "nerkommande",
    "nerkommandes": "nerkommande",
    "nerkommandet": "nerkommande",
    "nerkommandets": "nerkommande",
    "nerkommas": "nerkomma",
    "nerkomme": "nerkomma",
    "nerkommen": "nerkomma",
    "nerkommens": "nerkomma",
    "nerkommer": "nerkomma",
    "nerkommes": "nerkomma",
    "nerkommit": "nerkomma",
    "nerkommits": "nerkomma",
    "nerkomna": "nerkomma",
    "nerkomnas": "nerkomma",
    "nerkomne": "nerkomma",
    "nerkomnes": "nerkomma",
    "nerkoms": "nerkomma",
    "nerkomsten": "nerkomst",
    "nerkomstens": "nerkomst",
    "nerkomsts": "nerkomst",
    "nerla": "nerlägga",
    "nerladdningar": "nerladdning",
    "nerladdningarna": "nerladdning",
    "nerladdningarnas": "nerladdning",
    "nerladdningars": "nerladdning",
    "nerladdningen": "nerladdning",
    "nerladdningens": "nerladdning",
    "nerladdnings": "nerladdning",
    "nerlade": "nerlägga",
    "nerlades": "nerlägga",
    "nerlagd": "nerlägga",
    "nerlagda": "nerlägga",
    "nerlagdas": "nerlägga",
    "nerlagde": "nerlägga",
    "nerlagdes": "nerlägga",
    "nerlagds": "nerlägga",
    "nerlagt": "nerlägga",
    "nerlagts": "nerlägga",
    "nerlas": "nerlägga",
    "nerlegade": "nerlegad",
    "nerlegades": "nerlegad",
    "nerlegads": "nerlegad",
    "nerlegat": "nerlegad",
    "nerlegats": "nerlegad",
    "nerlusade": "nerlusad",
    "nerlusades": "nerlusad",
    "nerlusads": "nerlusad",
    "nerlusat": "nerlusad",
    "nerlusats": "nerlusad",
    "nerlägg": "nerlägga",
    "nerläggande": "nerlägga",
    "nerlägganden": "nerläggande",
    "nerläggandena": "nerläggande",
    "nerläggandenas": "nerläggande",
    "nerläggandens": "nerläggande",
    "nerläggandes": "nerläggande",
    "nerläggandet": "nerläggande",
    "nerläggandets": "nerläggande",
    "nerläggas": "nerlägga",
    "nerläggelsen": "nerläggelse",
    "nerläggelsens": "nerläggelse",
    "nerläggelser": "nerläggelse",
    "nerläggelserna": "nerläggelse",
    "nerläggelsernas": "nerläggelse",
    "nerläggelsers": "nerläggelse",
    "nerläggelses": "nerläggelse",
    "nerlägger": "nerlägga",
    "nerlägges": "nerlägga",
    "nerläggningar": "nerläggning",
    "nerläggningarna": "nerläggning",
    "nerläggningarnas": "nerläggning",
    "nerläggningars": "nerläggning",
    "nerläggningen": "nerläggning",
    "nerläggningens": "nerläggning",
    "nerläggnings": "nerläggning",
    "nerläggs": "nerlägga",
    "nerlåtenheten": "nerlåtenhet",
    "nerlåtenhetens": "nerlåtenhet",
    "nerlåtenheter": "nerlåtenhet",
    "nerlåtenheterna": "nerlåtenhet",
    "nerlåtenheternas": "nerlåtenhet",
    "nerlåtenheters": "nerlåtenhet",
    "nerlåtenhets": "nerlåtenhet",
    "nerlåtens": "nerlåten",
    "nerlåtet": "nerlåten",
    "nerlåtets": "nerlåten",
    "nerlåtna": "nerlåten",
    "nerlåtnare": "nerlåten",
    "nerlåtnares": "nerlåten",
    "nerlåtnas": "nerlåten",
    "nerlåtnast": "nerlåten",
    "nerlåtnaste": "nerlåten",
    "nerlåtnastes": "nerlåten",
    "nerlåtnasts": "nerlåten",
    "nerlåtne": "nerlåten",
    "nerlåtnes": "nerlåten",
    "nermörka": "nermörk",
    "nermörkare": "nermörk",
    "nermörkares": "nermörk",
    "nermörkas": "nermörk",
    "nermörkast": "nermörk",
    "nermörkaste": "nermörk",
    "nermörkastes": "nermörk",
    "nermörkasts": "nermörk",
    "nermörke": "nermörk",
    "nermörkes": "nermörk",
    "nermörks": "nermörk",
    "nermörkt": "nermörk",
    "nermörkts": "nermörk",
    "nerringda": "nerringd",
    "nerringdare": "nerringd",
    "nerringdares": "nerringd",
    "nerringdas": "nerringd",
    "nerringdast": "nerringd",
    "nerringdaste": "nerringd",
    "nerringdastes": "nerringd",
    "nerringdasts": "nerringd",
    "nerringde": "nerringd",
    "nerringdes": "nerringd",
    "nerringds": "nerringd",
    "nerringt": "nerringd",
    "nerringts": "nerringd",
    "nerrust": "nerrusta",
    "nerrustad": "nerrusta",
    "nerrustade": "nerrusta",
    "nerrustades": "nerrusta",
    "nerrustads": "nerrusta",
    "nerrustande": "nerrusta",
    "nerrustanden": "nerrustande",
    "nerrustandena": "nerrustande",
    "nerrustandenas": "nerrustande",
    "nerrustandens": "nerrustande",
    "nerrustandes": "nerrustande",
    "nerrustandet": "nerrustande",
    "nerrustandets": "nerrustande",
    "nerrustar": "nerrusta",
    "nerrustas": "nerrusta",
    "nerrustat": "nerrusta",
    "nerrustats": "nerrusta",
    "nerrustningar": "nerrustning",
    "nerrustningarna": "nerrustning",
    "nerrustningarnas": "nerrustning",
    "nerrustningars": "nerrustning",
    "nerrustningen": "nerrustning",
    "nerrustningens": "nerrustning",
    "nerrustnings": "nerrustning",
    "nerräkningar": "nerräkning",
    "nerräkningarna": "nerräkning",
    "nerräkningarnas": "nerräkning",
    "nerräkningars": "nerräkning",
    "nerräkningen": "nerräkning",
    "nerräkningens": "nerräkning",
    "nerräknings": "nerräkning",
    "nersalt": "nersalta",
    "nersaltad": "nersalta",
    "nersaltade": "nersalta",
    "nersaltades": "nersalta",
    "nersaltads": "nersalta",
    "nersaltande": "nersalta",
    "nersaltanden": "nersaltande",
    "nersaltandena": "nersaltande",
    "nersaltandenas": "nersaltande",
    "nersaltandens": "nersaltande",
    "nersaltandes": "nersaltande",
    "nersaltandet": "nersaltande",
    "nersaltandets": "nersaltande",
    "nersaltar": "nersalta",
    "nersaltas": "nersalta",
    "nersaltat": "nersalta",
    "nersaltats": "nersalta",
    "nersatt": "nersätta",
    "nersatta": "nersätta",
    "nersattare": "nersatt",
    "nersattares": "nersatt",
    "nersattas": "nersätta",
    "nersattast": "nersatt",
    "nersattaste": "nersatt",
    "nersattastes": "nersatt",
    "nersattasts": "nersatt",
    "nersatte": "nersätta",
    "nersattes": "nersätta",
    "nersatts": "nersätta",
    "nerskrev": "nerskriva",
    "nerskrevs": "nerskriva",
    "nerskriv": "nerskriva",
    "nerskrivande": "nerskriva",
    "nerskrivanden": "nerskrivande",
    "nerskrivandena": "nerskrivande",
    "nerskrivandenas": "nerskrivande",
    "nerskrivandens": "nerskrivande",
    "nerskrivandes": "nerskrivande",
    "nerskrivandet": "nerskrivande",
    "nerskrivandets": "nerskrivande",
    "nerskrivas": "nerskriva",
    "nerskrive": "nerskriva",
    "nerskriven": "nerskriva",
    "nerskrivens": "nerskriva",
    "nerskriver": "nerskriva",
    "nerskrives": "nerskriva",
    "nerskrivet": "nerskriva",
    "nerskrivets": "nerskriva",
    "nerskrivit": "nerskriva",
    "nerskrivits": "nerskriva",
    "nerskrivna": "nerskriva",
    "nerskrivnas": "nerskriva",
    "nerskrivne": "nerskriva",
    "nerskrivnes": "nerskriva",
    "nerskrivs": "nerskriva",
    "nerskällda": "nerskälld",
    "nerskälldare": "nerskälld",
    "nerskälldares": "nerskälld",
    "nerskälldas": "nerskälld",
    "nerskälldast": "nerskälld",
    "nerskälldaste": "nerskälld",
    "nerskälldastes": "nerskälld",
    "nerskälldasts": "nerskälld",
    "nerskällde": "nerskälld",
    "nerskälldes": "nerskälld",
    "nerskällds": "nerskälld",
    "nerskällt": "nerskälld",
    "nerskällts": "nerskälld",
    "nerskärningar": "nerskärning",
    "nerskärningarna": "nerskärning",
    "nerskärningarnas": "nerskärning",
    "nerskärningars": "nerskärning",
    "nerskärningen": "nerskärning",
    "nerskärningens": "nerskärning",
    "nerskärnings": "nerskärning",
    "nerslagen": "nerslag",
    "nerslagens": "nerslagen",
    "nerslaget": "nerslagen",
    "nerslagets": "nerslagen",
    "nerslagit": "nerslå",
    "nerslagits": "nerslå",
    "nerslagna": "nerslagen",
    "nerslagnare": "nerslagen",
    "nerslagnares": "nerslagen",
    "nerslagnas": "nerslagen",
    "nerslagnast": "nerslagen",
    "nerslagnaste": "nerslagen",
    "nerslagnastes": "nerslagen",
    "nerslagnasts": "nerslagen",
    "nerslagne": "nerslagen",
    "nerslagnes": "nerslagen",
    "nerslags": "nerslag",
    "nerslagskratern": "nerslagskrater",
    "nerslagskraterns": "nerslagskrater",
    "nerslagskraters": "nerslagskrater",
    "nerslagskratrar": "nerslagskrater",
    "nerslagskratrarna": "nerslagskrater",
    "nerslagskratrarnas": "nerslagskrater",
    "nerslagskratrars": "nerslagskrater",
    "nerslagsplatsen": "nerslagsplats",
    "nerslagsplatsens": "nerslagsplats",
    "nerslagsplatser": "nerslagsplats",
    "nerslagsplatserna": "nerslagsplats",
    "nerslagsplatsernas": "nerslagsplats",
    "nerslagsplatsers": "nerslagsplats",
    "nerslagsteorien": "nerslagsteori",
    "nerslagsteoriens": "nerslagsteori",
    "nerslagsteorier": "nerslagsteori",
    "nerslagsteorierna": "nerslagsteori",
    "nerslagsteoriernas": "nerslagsteori",
    "nerslagsteoriers": "nerslagsteori",
    "nerslagsteorin": "nerslagsteori",
    "nerslagsteorins": "nerslagsteori",
    "nerslagsteoris": "nerslagsteori",
    "nerslaktningar": "nerslaktning",
    "nerslaktningarna": "nerslaktning",
    "nerslaktningarnas": "nerslaktning",
    "nerslaktningars": "nerslaktning",
    "nerslaktningen": "nerslaktning",
    "nerslaktningens": "nerslaktning",
    "nerslaktnings": "nerslaktning",
    "nerslitens": "nersliten",
    "nerslitet": "nersliten",
    "nerslitets": "nersliten",
    "nerslitna": "nersliten",
    "nerslitnare": "nersliten",
    "nerslitnares": "nersliten",
    "nerslitnas": "nersliten",
    "nerslitnast": "nersliten",
    "nerslitnaste": "nersliten",
    "nerslitnastes": "nersliten",
    "nerslitnasts": "nersliten",
    "nerslitne": "nersliten",
    "nerslitnes": "nersliten",
    "nerslog": "nerslå",
    "nersloge": "nerslå",
    "nersloges": "nerslå",
    "nerslogs": "nerslå",
    "nersläppen": "nersläpp",
    "nersläppens": "nersläpp",
    "nersläppet": "nersläpp",
    "nersläppets": "nersläpp",
    "nersläpps": "nersläpp",
    "nerslående": "nerslå",
    "nerslåenden": "nerslående",
    "nerslåendena": "nerslående",
    "nerslåendenas": "nerslående",
    "nerslåendens": "nerslående",
    "nerslåendes": "nerslående",
    "nerslåendet": "nerslående",
    "nerslåendets": "nerslående",
    "nerslår": "nerslå",
    "nerslås": "nerslå",
    "nersmorda": "nersmord",
    "nersmordare": "nersmord",
    "nersmordares": "nersmord",
    "nersmordas": "nersmord",
    "nersmordast": "nersmord",
    "nersmordaste": "nersmord",
    "nersmordastes": "nersmord",
    "nersmordasts": "nersmord",
    "nersmorde": "nersmord",
    "nersmordes": "nersmord",
    "nersmords": "nersmord",
    "nersmort": "nersmord",
    "nersmorts": "nersmord",
    "nersmutsar": "nersmutsare",
    "nersmutsaren": "nersmutsare",
    "nersmutsarens": "nersmutsare",
    "nersmutsares": "nersmutsare",
    "nersmutsarna": "nersmutsare",
    "nersmutsarnas": "nersmutsare",
    "nerspillda": "nerspilld",
    "nerspilldare": "nerspilld",
    "nerspilldares": "nerspilld",
    "nerspilldas": "nerspilld",
    "nerspilldast": "nerspilld",
    "nerspilldaste": "nerspilld",
    "nerspilldastes": "nerspilld",
    "nerspilldasts": "nerspilld",
    "nerspillde": "nerspilld",
    "nerspilldes": "nerspilld",
    "nerspillds": "nerspilld",
    "nerspillt": "nerspilld",
    "nerspillts": "nerspilld",
    "nerstrykningar": "nerstrykning",
    "nerstrykningarna": "nerstrykning",
    "nerstrykningarnas": "nerstrykning",
    "nerstrykningars": "nerstrykning",
    "nerstrykningen": "nerstrykning",
    "nerstrykningens": "nerstrykning",
    "nerstryknings": "nerstrykning",
    "nerstråken": "nerstråk",
    "nerstråkens": "nerstråk",
    "nerstråket": "nerstråk",
    "nerstråkets": "nerstråk",
    "nerstråks": "nerstråk",
    "nerstämda": "nerstämd",
    "nerstämdare": "nerstämd",
    "nerstämdares": "nerstämd",
    "nerstämdas": "nerstämd",
    "nerstämdast": "nerstämd",
    "nerstämdaste": "nerstämd",
    "nerstämdastes": "nerstämd",
    "nerstämdasts": "nerstämd",
    "nerstämde": "nerstämd",
    "nerstämdes": "nerstämd",
    "nerstämds": "nerstämd",
    "nerstämt": "nerstämd",
    "nerstämts": "nerstämd",
    "nersupens": "nersupen",
    "nersupet": "nersupen",
    "nersupets": "nersupen",
    "nersupna": "nersupen",
    "nersupnare": "nersupen",
    "nersupnares": "nersupen",
    "nersupnas": "nersupen",
    "nersupnast": "nersupen",
    "nersupnaste": "nersupen",
    "nersupnastes": "nersupen",
    "nersupnasts": "nersupen",
    "nersupne": "nersupen",
    "nersupnes": "nersupen",
    "nersuttens": "nersutten",
    "nersuttet": "nersutten",
    "nersuttets": "nersutten",
    "nersuttna": "nersutten",
    "nersuttnare": "nersutten",
    "nersuttnares": "nersutten",
    "nersuttnas": "nersutten",
    "nersuttnast": "nersutten",
    "nersuttnaste": "nersutten",
    "nersuttnastes": "nersutten",
    "nersuttnasts": "nersutten",
    "nersuttne": "nersutten",
    "nersuttnes": "nersutten",
    "nersvärtningar": "nersvärtning",
    "nersvärtningarna": "nersvärtning",
    "nersvärtningarnas": "nersvärtning",
    "nersvärtningars": "nersvärtning",
    "nersvärtningen": "nersvärtning",
    "nersvärtningens": "nersvärtning",
    "nersvärtnings": "nersvärtning",
    "nersänk": "nersänka",
    "nersänkande": "nersänka",
    "nersänkanden": "nersänkande",
    "nersänkandena": "nersänkande",
    "nersänkandenas": "nersänkande",
    "nersänkandens": "nersänkande",
    "nersänkandes": "nersänkande",
    "nersänkandet": "nersänkande",
    "nersänkandets": "nersänkande",
    "nersänkas": "nersänka",
    "nersänker": "nersänka",
    "nersänkes": "nersänka",
    "nersänks": "nersänka",
    "nersänkt": "nersänka",
    "nersänkta": "nersänka",
    "nersänktas": "nersänka",
    "nersänkte": "nersänka",
    "nersänktes": "nersänka",
    "nersänkts": "nersänka",
    "nersätt": "nersätta",
    "nersättande": "nersätta",
    "nersättanden": "nersättande",
    "nersättandena": "nersättande",
    "nersättandenas": "nersättande",
    "nersättandens": "nersättande",
    "nersättandes": "nersättande",
    "nersättandet": "nersättande",
    "nersättandets": "nersättande",
    "nersättas": "nersätta",
    "nersätter": "nersätta",
    "nersättes": "nersätta",
    "nersättningar": "nersättning",
    "nersättningarna": "nersättning",
    "nersättningarnas": "nersättning",
    "nersättningars": "nersättning",
    "nersättningen": "nersättning",
    "nersättningens": "nersättning",
    "nersättnings": "nersättning",
    "nersättningsbevisen": "nersättningsbevis",
    "nersättningsbevisens": "nersättningsbevis",
    "nersättningsbeviset": "nersättningsbevis",
    "nersättningsbevisets": "nersättningsbevis",
    "nersätts": "nersätta",
    "nersölade": "nersölad",
    "nersölades": "nersölad",
    "nersölads": "nersölad",
    "nersölat": "nersölad",
    "nersölats": "nersölad",
    "nertagningar": "nertagning",
    "nertagningarna": "nertagning",
    "nertagningarnas": "nertagning",
    "nertagningars": "nertagning",
    "nertagningen": "nertagning",
    "nertagningens": "nertagning",
    "nertagnings": "nertagning",
    "nerteckn": "nerteckna",
    "nertecknad": "nerteckna",
    "nertecknade": "nerteckna",
    "nertecknades": "nerteckna",
    "nertecknads": "nerteckna",
    "nertecknande": "nerteckna",
    "nertecknanden": "nertecknande",
    "nertecknandena": "nertecknande",
    "nertecknandenas": "nertecknande",
    "nertecknandens": "nertecknande",
    "nertecknandes": "nertecknande",
    "nertecknandet": "nertecknande",
    "nertecknandets": "nertecknande",
    "nertecknar": "nerteckna",
    "nertecknas": "nerteckna",
    "nertecknat": "nerteckna",
    "nertecknats": "nerteckna",
    "nertiden": "nertid",
    "nertidens": "nertid",
    "nertids": "nertid",
    "nertoningar": "nertoning",
    "nertoningarna": "nertoning",
    "nertoningarnas": "nertoning",
    "nertoningars": "nertoning",
    "nertoningen": "nertoning",
    "nertoningens": "nertoning",
    "nertonings": "nertoning",
    "nertrampade": "nertrampad",
    "nertrampades": "nertrampad",
    "nertrampads": "nertrampad",
    "nertrampat": "nertrampad",
    "nertrampats": "nertrampad",
    "nertransformerad": "nertransformera",
    "nertransformerade": "nertransformera",
    "nertransformerades": "nertransformera",
    "nertransformerads": "nertransformera",
    "nertransformerande": "nertransformera",
    "nertransformeranden": "nertransformerande",
    "nertransformerandena": "nertransformerande",
    "nertransformerandenas": "nertransformerande",
    "nertransformerandens": "nertransformerande",
    "nertransformerandes": "nertransformerande",
    "nertransformerandet": "nertransformerande",
    "nertransformerandets": "nertransformerande",
    "nertransformerar": "nertransformera",
    "nertransformeras": "nertransformera",
    "nertransformerat": "nertransformera",
    "nertransformerats": "nertransformera",
    "nertransformerbara": "nertransformerbar",
    "nertransformerbarare": "nertransformerbar",
    "nertransformerbarares": "nertransformerbar",
    "nertransformerbaras": "nertransformerbar",
    "nertransformerbarast": "nertransformerbar",
    "nertransformerbaraste": "nertransformerbar",
    "nertransformerbarastes": "nertransformerbar",
    "nertransformerbarasts": "nertransformerbar",
    "nertransformerbare": "nertransformerbar",
    "nertransformerbares": "nertransformerbar",
    "nertransformerbarheten": "nertransformerbarhet",
    "nertransformerbarhetens": "nertransformerbarhet",
    "nertransformerbarhets": "nertransformerbarhet",
    "nertransformerbars": "nertransformerbar",
    "nertransformerbart": "nertransformerbar",
    "nertransformerbarts": "nertransformerbar",
    "nertransformeringar": "nertransformering",
    "nertransformeringarna": "nertransformering",
    "nertransformeringarnas": "nertransformering",
    "nertransformeringars": "nertransformering",
    "nertransformeringen": "nertransformering",
    "nertransformeringens": "nertransformering",
    "nertransformerings": "nertransformering",
    "nertransponerad": "nertransponera",
    "nertransponerade": "nertransponera",
    "nertransponerades": "nertransponera",
    "nertransponerads": "nertransponera",
    "nertransponerande": "nertransponera",
    "nertransponeranden": "nertransponerande",
    "nertransponerandena": "nertransponerande",
    "nertransponerandenas": "nertransponerande",
    "nertransponerandens": "nertransponerande",
    "nertransponerandes": "nertransponerande",
    "nertransponerandet": "nertransponerande",
    "nertransponerandets": "nertransponerande",
    "nertransponerar": "nertransponera",
    "nertransponeras": "nertransponera",
    "nertransponerat": "nertransponera",
    "nertransponerats": "nertransponera",
    "nertransponerbara": "nertransponerbar",
    "nertransponerbarare": "nertransponerbar",
    "nertransponerbarares": "nertransponerbar",
    "nertransponerbaras": "nertransponerbar",
    "nertransponerbarast": "nertransponerbar",
    "nertransponerbaraste": "nertransponerbar",
    "nertransponerbarastes": "nertransponerbar",
    "nertransponerbarasts": "nertransponerbar",
    "nertransponerbare": "nertransponerbar",
    "nertransponerbares": "nertransponerbar",
    "nertransponerbarheten": "nertransponerbarhet",
    "nertransponerbarhetens": "nertransponerbarhet",
    "nertransponerbarhets": "nertransponerbarhet",
    "nertransponerbars": "nertransponerbar",
    "nertransponerbart": "nertransponerbar",
    "nertransponerbarts": "nertransponerbar",
    "nertransponeringar": "nertransponering",
    "nertransponeringarna": "nertransponering",
    "nertransponeringarnas": "nertransponering",
    "nertransponeringars": "nertransponering",
    "nertransponeringen": "nertransponering",
    "nertransponeringens": "nertransponering",
    "nertransponerings": "nertransponering",
    "nertrapp": "nertrappa",
    "nertrappad": "nertrappa",
    "nertrappade": "nertrappa",
    "nertrappades": "nertrappa",
    "nertrappads": "nertrappa",
    "nertrappande": "nertrappa",
    "nertrappanden": "nertrappande",
    "nertrappandena": "nertrappande",
    "nertrappandenas": "nertrappande",
    "nertrappandens": "nertrappande",
    "nertrappandes": "nertrappande",
    "nertrappandet": "nertrappande",
    "nertrappandets": "nertrappande",
    "nertrappar": "nertrappa",
    "nertrappas": "nertrappa",
    "nertrappat": "nertrappa",
    "nertrappats": "nertrappa",
    "nertrappningar": "nertrappning",
    "nertrappningarna": "nertrappning",
    "nertrappningarnas": "nertrappning",
    "nertrappningars": "nertrappning",
    "nertrappningen": "nertrappning",
    "nertrappningens": "nertrappning",
    "nertrappnings": "nertrappning",
    "nertryckta": "nertryckt",
    "nertrycktare": "nertryckt",
    "nertrycktares": "nertryckt",
    "nertrycktas": "nertryckt",
    "nertrycktast": "nertryckt",
    "nertrycktaste": "nertryckt",
    "nertrycktastes": "nertryckt",
    "nertrycktasts": "nertryckt",
    "nertryckte": "nertryckt",
    "nertrycktes": "nertryckt",
    "nertryckts": "nertryckt",
    "nertsbisamen": "nertsbisam",
    "nertsbisamens": "nertsbisam",
    "nertsbisams": "nertsbisam",
    "nertsen": "nerts",
    "nertsens": "nerts",
    "nertzbisamen": "nertzbisam",
    "nertzbisamens": "nertzbisam",
    "nertzbisams": "nertzbisam",
    "nertzen": "nertz",
    "nertzens": "nertz",
    "nervaktiviteten": "nervaktivitet",
    "nervaktivitetens": "nervaktivitet",
    "nervaktiviteter": "nervaktivitet",
    "nervaktiviteterna": "nervaktivitet",
    "nervaktiviteternas": "nervaktivitet",
    "nervaktiviteters": "nervaktivitet",
    "nervaktivitets": "nervaktivitet",
    "nervattacken": "nervattack",
    "nervattackens": "nervattack",
    "nervattacker": "nervattack",
    "nervattackerna": "nervattack",
    "nervattackernas": "nervattack",
    "nervattackers": "nervattack",
    "nervattacks": "nervattack",
    "nervbanan": "nervbana",
    "nervbanans": "nervbana",
    "nervbanas": "nervbana",
    "nervbane": "nervbana",
    "nervbanor": "nervbana",
    "nervbanorna": "nervbana",
    "nervbanornas": "nervbana",
    "nervbanors": "nervbana",
    "nervcellen": "nervcell",
    "nervcellens": "nervcell",
    "nervceller": "nervcell",
    "nervcellerna": "nervcell",
    "nervcellernas": "nervcell",
    "nervcellers": "nervcell",
    "nervcells": "nervcell",
    "nervcellsgruppen": "nervcellsgrupp",
    "nervcellsgruppens": "nervcellsgrupp",
    "nervcellsgrupper": "nervcellsgrupp",
    "nervcellsgrupperna": "nervcellsgrupp",
    "nervcellsgruppernas": "nervcellsgrupp",
    "nervcellsgruppers": "nervcellsgrupp",
    "nervcellsgrupps": "nervcellsgrupp",
    "nervchocken": "nervchock",
    "nervchockens": "nervchock",
    "nervchocker": "nervchock",
    "nervchockerna": "nervchock",
    "nervchockernas": "nervchock",
    "nervchockers": "nervchock",
    "nervchocks": "nervchock",
    "nervdropparna": "nervdroppar",
    "nervdropparnas": "nervdroppar",
    "nervdroppars": "nervdroppar",
    "nervdropps": "nervdroppar",
    "nerven": "nerv",
    "nervens": "nerv",
    "nerver": "nerv",
    "nerverna": "nerv",
    "nervernas": "nerv",
    "nervers": "nerv",
    "nervevade": "nervevad",
    "nervevades": "nervevad",
    "nervevads": "nervevad",
    "nervevat": "nervevad",
    "nervevats": "nervevad",
    "nervfebern": "nervfeber",
    "nervfeberns": "nervfeber",
    "nervfebers": "nervfeber",
    "nervförbindelsen": "nervförbindelse",
    "nervförbindelsens": "nervförbindelse",
    "nervförbindelser": "nervförbindelse",
    "nervförbindelserna": "nervförbindelse",
    "nervförbindelsernas": "nervförbindelse",
    "nervförbindelsers": "nervförbindelse",
    "nervförbindelses": "nervförbindelse",
    "nervgasen": "nervgas",
    "nervgasens": "nervgas",
    "nervgaser": "nervgas",
    "nervgaserna": "nervgas",
    "nervgasernas": "nervgas",
    "nervgasers": "nervgas",
    "nervgifter": "nervgift",
    "nervgifterna": "nervgift",
    "nervgifternas": "nervgift",
    "nervgifters": "nervgift",
    "nervgiftet": "nervgift",
    "nervgiftets": "nervgift",
    "nervgifts": "nervgift",
    "nerviga": "nervig",
    "nervigare": "nervig",
    "nervigares": "nervig",
    "nervigas": "nervig",
    "nervigast": "nervig",
    "nervigaste": "nervig",
    "nervigastes": "nervig",
    "nervigasts": "nervig",
    "nervige": "nervig",
    "nerviges": "nervig",
    "nervigheten": "nervighet",
    "nervighetens": "nervighet",
    "nervighets": "nervighet",
    "nervigs": "nervig",
    "nervigt": "nervig",
    "nervigts": "nervig",
    "nervimpulsen": "nervimpuls",
    "nervimpulsens": "nervimpuls",
    "nervimpulser": "nervimpuls",
    "nervimpulserna": "nervimpuls",
    "nervimpulsernas": "nervimpuls",
    "nervimpulsers": "nervimpuls",
    "nervklena": "nervklen",
    "nervklenare": "nervklen",
    "nervklenares": "nervklen",
    "nervklenas": "nervklen",
    "nervklenast": "nervklen",
    "nervklenaste": "nervklen",
    "nervklenastes": "nervklen",
    "nervklenasts": "nervklen",
    "nervklene": "nervklen",
    "nervklenes": "nervklen",
    "nervklens": "nervklen",
    "nervklent": "nervklen",
    "nervklents": "nervklen",
    "nervknipp": "nervknippe",
    "nervknippen": "nervknippe",
    "nervknippena": "nervknippe",
    "nervknippenas": "nervknippe",
    "nervknippens": "nervknippe",
    "nervknippes": "nervknippe",
    "nervknippet": "nervknippe",
    "nervknippets": "nervknippe",
    "nervknipps": "nervknippe",
    "nervknutar": "nervknut",
    "nervknutarna": "nervknut",
    "nervknutarnas": "nervknut",
    "nervknutars": "nervknut",
    "nervknuten": "nervknut",
    "nervknutens": "nervknut",
    "nervknuts": "nervknut",
    "nervkollapsen": "nervkollaps",
    "nervkollapsens": "nervkollaps",
    "nervkollapser": "nervkollaps",
    "nervkollapserna": "nervkollaps",
    "nervkollapsernas": "nervkollaps",
    "nervkollapsers": "nervkollaps",
    "nervkrigen": "nervkrig",
    "nervkrigens": "nervkrig",
    "nervkriget": "nervkrig",
    "nervkrigets": "nervkrig",
    "nervkrigs": "nervkrig",
    "nervmedicinen": "nervmedicin",
    "nervmedicinens": "nervmedicin",
    "nervmediciner": "nervmedicin",
    "nervmedicinerna": "nervmedicin",
    "nervmedicinernas": "nervmedicin",
    "nervmediciners": "nervmedicin",
    "nervmedicins": "nervmedicin",
    "nervositeten": "nervositet",
    "nervositetens": "nervositet",
    "nervositeter": "nervositet",
    "nervositeterna": "nervositet",
    "nervositeternas": "nervositet",
    "nervositeters": "nervositet",
    "nervositets": "nervositet",
    "nervpressen": "nervpress",
    "nervpressens": "nervpress",
    "nervretningar": "nervretning",
    "nervretningarna": "nervretning",
    "nervretningarnas": "nervretning",
    "nervretningars": "nervretning",
    "nervretningen": "nervretning",
    "nervretningens": "nervretning",
    "nervretnings": "nervretning",
    "nervryckningar": "nervryckning",
    "nervryckningarna": "nervryckning",
    "nervryckningarnas": "nervryckning",
    "nervryckningars": "nervryckning",
    "nervryckningen": "nervryckning",
    "nervryckningens": "nervryckning",
    "nervrycknings": "nervryckning",
    "nervs": "nerv",
    "nervsammanbrotten": "nervsammanbrott",
    "nervsammanbrottens": "nervsammanbrott",
    "nervsammanbrottet": "nervsammanbrott",
    "nervsammanbrottets": "nervsammanbrott",
    "nervsammanbrotts": "nervsammanbrott",
    "nervsignalen": "nervsignal",
    "nervsignalens": "nervsignal",
    "nervsignaler": "nervsignal",
    "nervsignalerna": "nervsignal",
    "nervsignalernas": "nervsignal",
    "nervsignalers": "nervsignal",
    "nervsignalmönsterna": "nervsignalmönster",
    "nervsignalmönsternas": "nervsignalmönster",
    "nervsignalmönsters": "nervsignalmönster",
    "nervsignalmönstren": "nervsignalmönster",
    "nervsignalmönstrens": "nervsignalmönster",
    "nervsignalmönstret": "nervsignalmönster",
    "nervsignalmönstrets": "nervsignalmönster",
    "nervsignals": "nervsignal",
    "nervsjukdomar": "nervsjukdom",
    "nervsjukdomarna": "nervsjukdom",
    "nervsjukdomarnas": "nervsjukdom",
    "nervsjukdomars": "nervsjukdom",
    "nervsjukdomen": "nervsjukdom",
    "nervsjukdomens": "nervsjukdom",
    "nervsjukdoms": "nervsjukdom",
    "nervskadan": "nervskada",
    "nervskadans": "nervskada",
    "nervskadas": "nervskada",
    "nervskade": "nervskada",
    "nervskador": "nervskada",
    "nervskadorna": "nervskada",
    "nervskadornas": "nervskada",
    "nervskadors": "nervskada",
    "nervsmärt": "nervsmärta",
    "nervsmärtan": "nervsmärta",
    "nervsmärtans": "nervsmärta",
    "nervsmärtas": "nervsmärta",
    "nervsmärte": "nervsmärta",
    "nervsmärtor": "nervsmärta",
    "nervsmärtorna": "nervsmärta",
    "nervsmärtornas": "nervsmärta",
    "nervsmärtors": "nervsmärta",
    "nervsmärts": "nervsmärta",
    "nervstumpar": "nervstump",
    "nervstumparna": "nervstump",
    "nervstumparnas": "nervstump",
    "nervstumpars": "nervstump",
    "nervstumpen": "nervstump",
    "nervstumpens": "nervstump",
    "nervstumps": "nervstump",
    "nervsystemen": "nervsystem",
    "nervsystemens": "nervsystem",
    "nervsystemet": "nervsystem",
    "nervsystemets": "nervsystem",
    "nervsystems": "nervsystem",
    "nervtrådar": "nervtråd",
    "nervtrådarna": "nervtråd",
    "nervtrådarnas": "nervtråd",
    "nervtrådars": "nervtråd",
    "nervtråden": "nervtråd",
    "nervtrådens": "nervtråd",
    "nervtråds": "nervtråd",
    "nervvraken": "nervvrak",
    "nervvrakens": "nervvrak",
    "nervvraket": "nervvrak",
    "nervvrakets": "nervvrak",
    "nervvraks": "nervvrak",
    "nervänd": "nervända",
    "nervändan": "nervända",
    "nervändans": "nervända",
    "nervändar": "nervände",
    "nervändarna": "nervände",
    "nervändarnas": "nervände",
    "nervändars": "nervände",
    "nervändas": "nervända",
    "nervände": "nervända",
    "nervänden": "nervände",
    "nervändens": "nervände",
    "nervändes": "nervände",
    "nervändor": "nervända",
    "nervändorna": "nervända",
    "nervändornas": "nervända",
    "nervändors": "nervända",
    "nervänds": "nervända",
    "nervärderad": "nervärdera",
    "nervärderade": "nervärdera",
    "nervärderades": "nervärdera",
    "nervärderads": "nervärdera",
    "nervärderande": "nervärdera",
    "nervärderanden": "nervärderande",
    "nervärderandena": "nervärderande",
    "nervärderandenas": "nervärderande",
    "nervärderandens": "nervärderande",
    "nervärderandes": "nervärderande",
    "nervärderandet": "nervärderande",
    "nervärderandets": "nervärderande",
    "nervärderar": "nervärdera",
    "nervärderas": "nervärdera",
    "nervärderat": "nervärdera",
    "nervärderats": "nervärdera",
    "nervärderbara": "nervärderbar",
    "nervärderbarare": "nervärderbar",
    "nervärderbarares": "nervärderbar",
    "nervärderbaras": "nervärderbar",
    "nervärderbarast": "nervärderbar",
    "nervärderbaraste": "nervärderbar",
    "nervärderbarastes": "nervärderbar",
    "nervärderbarasts": "nervärderbar",
    "nervärderbare": "nervärderbar",
    "nervärderbares": "nervärderbar",
    "nervärderbarheten": "nervärderbarhet",
    "nervärderbarhetens": "nervärderbarhet",
    "nervärderbarhets": "nervärderbarhet",
    "nervärderbars": "nervärderbar",
    "nervärderbart": "nervärderbar",
    "nervärderbarts": "nervärderbar",
    "nervärderingar": "nervärdering",
    "nervärderingarna": "nervärdering",
    "nervärderingarnas": "nervärdering",
    "nervärderingars": "nervärdering",
    "nervärderingen": "nervärdering",
    "nervärderingens": "nervärdering",
    "nervärderings": "nervärdering",
    "nervösa": "nervös",
    "nervösare": "nervös",
    "nervösares": "nervös",
    "nervösas": "nervös",
    "nervösast": "nervös",
    "nervösaste": "nervös",
    "nervösastes": "nervös",
    "nervösasts": "nervös",
    "nervöse": "nervös",
    "nervöses": "nervös",
    "nervöst": "nervös",
    "nervösts": "nervös",
    "nerzbisamen": "nerzbisam",
    "nerzbisamens": "nerzbisam",
    "nerzbisams": "nerzbisam",
    "nerzen": "nerz",
    "nerzens": "nerz",
    "nerärvda": "nerärvd",
    "nerärvdare": "nerärvd",
    "nerärvdares": "nerärvd",
    "nerärvdas": "nerärvd",
    "nerärvdast": "nerärvd",
    "nerärvdaste": "nerärvd",
    "nerärvdastes": "nerärvd",
    "nerärvdasts": "nerärvd",
    "nerärvde": "nerärvd",
    "nerärvdes": "nerärvd",
    "nerärvds": "nerärvd",
    "nerärvt": "nerärvd",
    "nerärvts": "nerärvd",
    "neråtgåendes": "neråtgående",
    "neråtgåendet": "neråtgående",
    "neråtgåendets": "neråtgående",
    "neråtgången": "neråtgång",
    "neråtgångens": "neråtgång",
    "neråtgångs": "neråtgång",
    "nesan": "nesa",
    "nesans": "nesa",
    "nesas": "nesa",
    "nesliga": "neslig",
    "nesligare": "neslig",
    "nesligares": "neslig",
    "nesligas": "neslig",
    "nesligast": "neslig",
    "nesligaste": "neslig",
    "nesligastes": "neslig",
    "nesligasts": "neslig",
    "neslige": "neslig",
    "nesliges": "neslig",
    "nesligheten": "neslighet",
    "neslighetens": "neslighet",
    "nesligheter": "neslighet",
    "nesligheterna": "neslighet",
    "nesligheternas": "neslighet",
    "nesligheters": "neslighet",
    "neslighets": "neslighet",
    "nesligs": "neslig",
    "nesligt": "neslig",
    "nesligts": "neslig",
    "nessosdräkten": "nessosdräkt",
    "nessosdräktens": "nessosdräkt",
    "nessosdräkts": "nessosdräkt",
    "nessusdräkten": "nessusdräkt",
    "nessusdräktens": "nessusdräkt",
    "nessusdräkts": "nessusdräkt",
    "nestorianen": "nestorian",
    "nestorianens": "nestorian",
    "nestorianer": "nestorian",
    "nestorianerna": "nestorian",
    "nestorianernas": "nestorian",
    "nestorianers": "nestorian",
    "nestorianismen": "nestorianism",
    "nestorianismens": "nestorianism",
    "nestorianismer": "nestorianism",
    "nestorianismerna": "nestorianism",
    "nestorianismernas": "nestorianism",
    "nestorianismers": "nestorianism",
    "nestorianisms": "nestorianism",
    "nestorians": "nestorian",
    "nestorianska": "nestoriansk",
    "nestorianskare": "nestoriansk",
    "nestorianskares": "nestoriansk",
    "nestorianskas": "nestoriansk",
    "nestorianskast": "nestoriansk",
    "nestorianskaste": "nestoriansk",
    "nestorianskastes": "nestoriansk",
    "nestorianskasts": "nestoriansk",
    "nestorianske": "nestoriansk",
    "nestorianskes": "nestoriansk",
    "nestoriansks": "nestoriansk",
    "nestorianskt": "nestoriansk",
    "nestorianskts": "nestoriansk",
    "nestorn": "nestor",
    "nestorns": "nestor",
    "nestors": "nestor",
    "net": "n",
    "nets": "n",
    "nettoförmögenheten": "nettoförmögenhet",
    "nettoförmögenhetens": "nettoförmögenhet",
    "nettoförmögenheter": "nettoförmögenhet",
    "nettoförmögenheterna": "nettoförmögenhet",
    "nettoförmögenheternas": "nettoförmögenhet",
    "nettoförmögenheters": "nettoförmögenhet",
    "nettoförmögenhets": "nettoförmögenhet",
    "nettoinkomsten": "nettoinkomst",
    "nettoinkomstens": "nettoinkomst",
    "nettoinkomster": "nettoinkomst",
    "nettoinkomsterna": "nettoinkomst",
    "nettoinkomsternas": "nettoinkomst",
    "nettoinkomsters": "nettoinkomst",
    "nettoinkomsts": "nettoinkomst",
    "nettolönen": "nettolön",
    "nettolönens": "nettolön",
    "nettolöner": "nettolön",
    "nettolönerna": "nettolön",
    "nettolönernas": "nettolön",
    "nettolöners": "nettolön",
    "nettolöns": "nettolön",
    "netton": "netto",
    "nettona": "netto",
    "nettonas": "netto",
    "nettons": "netto",
    "nettoprisen": "nettopris",
    "nettoprisens": "nettopris",
    "nettopriser": "nettopris",
    "nettopriserna": "nettopris",
    "nettoprisernas": "nettopris",
    "nettoprisers": "nettopris",
    "nettopriset": "nettopris",
    "nettoprisets": "nettopris",
    "nettoregistertonnen": "nettoregisterton",
    "nettoregistertonnens": "nettoregisterton",
    "nettoregistertonnet": "nettoregisterton",
    "nettoregistertonnets": "nettoregisterton",
    "nettoregistertons": "nettoregisterton",
    "nettos": "netto",
    "nettoskulden": "nettoskuld",
    "nettoskuldens": "nettoskuld",
    "nettoskulder": "nettoskuld",
    "nettoskulderna": "nettoskuld",
    "nettoskuldernas": "nettoskuld",
    "nettoskulders": "nettoskuld",
    "nettoskulds": "nettoskuld",
    "nettosparanden": "nettosparande",
    "nettosparandena": "nettosparande",
    "nettosparandenas": "nettosparande",
    "nettosparandens": "nettosparande",
    "nettosparandes": "nettosparande",
    "nettosparandet": "nettosparande",
    "nettosparandets": "nettosparande",
    "nettostudietiden": "nettostudietid",
    "nettostudietidens": "nettostudietid",
    "nettostudietider": "nettostudietid",
    "nettostudietiderna": "nettostudietid",
    "nettostudietidernas": "nettostudietid",
    "nettostudietiders": "nettostudietid",
    "nettostudietids": "nettostudietid",
    "nettot": "netto",
    "nettotonnages": "nettotonnage",
    "nettotonnaget": "nettotonnage",
    "nettotonnagets": "nettotonnage",
    "nettots": "netto",
    "nettovikten": "nettovikt",
    "nettoviktens": "nettovikt",
    "nettovikts": "nettovikt",
    "nettovinsten": "nettovinst",
    "nettovinstens": "nettovinst",
    "nettovinster": "nettovinst",
    "nettovinsterna": "nettovinst",
    "nettovinsternas": "nettovinst",
    "nettovinsters": "nettovinst",
    "nettovinsts": "nettovinst",
    "neuralgien": "neuralgi",
    "neuralgiens": "neuralgi",
    "neuralgin": "neuralgi",
    "neuralgins": "neuralgi",
    "neuralgis": "neuralgi",
    "neuralgiska": "neuralgisk",
    "neuralgiskare": "neuralgisk",
    "neuralgiskares": "neuralgisk",
    "neuralgiskas": "neuralgisk",
    "neuralgiskast": "neuralgisk",
    "neuralgiskaste": "neuralgisk",
    "neuralgiskastes": "neuralgisk",
    "neuralgiskasts": "neuralgisk",
    "neuralgiske": "neuralgisk",
    "neuralgiskes": "neuralgisk",
    "neuralgisks": "neuralgisk",
    "neuralgiskt": "neuralgisk",
    "neuralgiskts": "neuralgisk",
    "neurastenien": "neurasteni",
    "neurasteniens": "neurasteni",
    "neurastenin": "neurasteni",
    "neurastenins": "neurasteni",
    "neurastenis": "neurasteni",
    "neuriten": "neurit",
    "neuritens": "neurit",
    "neuriter": "neurit",
    "neuriterna": "neurit",
    "neuriternas": "neurit",
    "neuriters": "neurit",
    "neurits": "neurit",
    "neurofysiologen": "neurofysiolog",
    "neurofysiologens": "neurofysiolog",
    "neurofysiologer": "neurofysiolog",
    "neurofysiologerna": "neurofysiolog",
    "neurofysiologernas": "neurofysiolog",
    "neurofysiologers": "neurofysiolog",
    "neurofysiologien": "neurofysiologi",
    "neurofysiologiens": "neurofysiologi",
    "neurofysiologin": "neurofysiologi",
    "neurofysiologins": "neurofysiologi",
    "neurofysiologis": "neurofysiologi",
    "neurofysiologs": "neurofysiolog",
    "neurografien": "neurografi",
    "neurografiens": "neurografi",
    "neurografin": "neurografi",
    "neurografins": "neurografi",
    "neurografis": "neurografi",
    "neuroleptikan": "neuroleptika",
    "neuroleptikana": "neuroleptika",
    "neuroleptikanas": "neuroleptika",
    "neuroleptikans": "neuroleptika",
    "neuroleptikas": "neuroleptika",
    "neuroleptikat": "neuroleptika",
    "neuroleptikats": "neuroleptika",
    "neurologen": "neurolog",
    "neurologens": "neurolog",
    "neurologer": "neurolog",
    "neurologerna": "neurolog",
    "neurologernas": "neurolog",
    "neurologers": "neurolog",
    "neurologien": "neurologi",
    "neurologiens": "neurologi",
    "neurologin": "neurologi",
    "neurologins": "neurologi",
    "neurologis": "neurologi",
    "neurologiska": "neurologisk",
    "neurologiskare": "neurologisk",
    "neurologiskares": "neurologisk",
    "neurologiskas": "neurologisk",
    "neurologiskast": "neurologisk",
    "neurologiskaste": "neurologisk",
    "neurologiskastes": "neurologisk",
    "neurologiskasts": "neurologisk",
    "neurologiske": "neurologisk",
    "neurologiskes": "neurologisk",
    "neurologisks": "neurologisk",
    "neurologiskt": "neurologisk",
    "neurologiskts": "neurologisk",
    "neurologs": "neurolog",
    "neuromen": "neurom",
    "neuromens": "neurom",
    "neuromer": "neurom",
    "neuromerna": "neurom",
    "neuromernas": "neurom",
    "neuromers": "neurom",
    "neuromet": "neurom",
    "neuromets": "neurom",
    "neuroms": "neurom",
    "neuronen": "neuron",
    "neuronens": "neuron",
    "neuroner": "neuron",
    "neuronerna": "neuron",
    "neuronernas": "neuron",
    "neuroners": "neuron",
    "neuronet": "neuron",
    "neuronets": "neuron",
    "neurons": "neuron",
    "neuropaten": "neuropat",
    "neuropatens": "neuropat",
    "neuropater": "neuropat",
    "neuropaterna": "neuropat",
    "neuropaternas": "neuropat",
    "neuropaters": "neuropat",
    "neuropatien": "neuropati",
    "neuropatiens": "neuropati",
    "neuropatin": "neuropati",
    "neuropatins": "neuropati",
    "neuropatis": "neuropati",
    "neuropats": "neuropat",
    "neurosedynet": "neurosedyn",
    "neurosedynets": "neurosedyn",
    "neurosedyns": "neurosedyn",
    "neurosen": "neuros",
    "neurosens": "neuros",
    "neuroser": "neuros",
    "neuroserna": "neuros",
    "neurosernas": "neuros",
    "neurosers": "neuros",
    "neurotikern": "neurotiker",
    "neurotikerna": "neurotiker",
    "neurotikernas": "neurotiker",
    "neurotikerns": "neurotiker",
    "neurotikers": "neurotiker",
    "neurotiska": "neurotisk",
    "neurotiskare": "neurotisk",
    "neurotiskares": "neurotisk",
    "neurotiskas": "neurotisk",
    "neurotiskast": "neurotisk",
    "neurotiskaste": "neurotisk",
    "neurotiskastes": "neurotisk",
    "neurotiskasts": "neurotisk",
    "neurotiske": "neurotisk",
    "neurotiskes": "neurotisk",
    "neurotisks": "neurotisk",
    "neurotiskt": "neurotisk",
    "neurotiskts": "neurotisk",
    "neutra": "neutrum",
    "neutrala": "neutral",
    "neutralare": "neutral",
    "neutralares": "neutral",
    "neutralas": "neutral",
    "neutralast": "neutral",
    "neutralaste": "neutral",
    "neutralastes": "neutral",
    "neutralasts": "neutral",
    "neutrale": "neutral",
    "neutrales": "neutral",
    "neutralisationen": "neutralisation",
    "neutralisationens": "neutralisation",
    "neutralisationer": "neutralisation",
    "neutralisationerna": "neutralisation",
    "neutralisationernas": "neutralisation",
    "neutralisationers": "neutralisation",
    "neutralisations": "neutralisation",
    "neutraliserad": "neutralisera",
    "neutraliserade": "neutralisera",
    "neutraliserades": "neutralisera",
    "neutraliserads": "neutralisera",
    "neutraliserande": "neutralisera",
    "neutraliseranden": "neutraliserande",
    "neutraliserandena": "neutraliserande",
    "neutraliserandenas": "neutraliserande",
    "neutraliserandens": "neutraliserande",
    "neutraliserandes": "neutraliserande",
    "neutraliserandet": "neutraliserande",
    "neutraliserandets": "neutraliserande",
    "neutraliserar": "neutralisera",
    "neutraliseras": "neutralisera",
    "neutraliserat": "neutralisera",
    "neutraliserats": "neutralisera",
    "neutraliserbara": "neutraliserbar",
    "neutraliserbarare": "neutraliserbar",
    "neutraliserbarares": "neutraliserbar",
    "neutraliserbaras": "neutraliserbar",
    "neutraliserbarast": "neutraliserbar",
    "neutraliserbaraste": "neutraliserbar",
    "neutraliserbarastes": "neutraliserbar",
    "neutraliserbarasts": "neutraliserbar",
    "neutraliserbare": "neutraliserbar",
    "neutraliserbares": "neutraliserbar",
    "neutraliserbarheten": "neutraliserbarhet",
    "neutraliserbarhetens": "neutraliserbarhet",
    "neutraliserbarhets": "neutraliserbarhet",
    "neutraliserbars": "neutraliserbar",
    "neutraliserbart": "neutraliserbar",
    "neutraliserbarts": "neutraliserbar",
    "neutraliseringar": "neutralisering",
    "neutraliseringarna": "neutralisering",
    "neutraliseringarnas": "neutralisering",
    "neutraliseringars": "neutralisering",
    "neutraliseringen": "neutralisering",
    "neutraliseringens": "neutralisering",
    "neutraliserings": "neutralisering",
    "neutralismen": "neutralism",
    "neutralismens": "neutralism",
    "neutralismer": "neutralism",
    "neutralismerna": "neutralism",
    "neutralismernas": "neutralism",
    "neutralismers": "neutralism",
    "neutralisms": "neutralism",
    "neutralisten": "neutralist",
    "neutralistens": "neutralist",
    "neutralister": "neutralist",
    "neutralisterna": "neutralist",
    "neutralisternas": "neutralist",
    "neutralisters": "neutralist",
    "neutralistiska": "neutralistisk",
    "neutralistiskare": "neutralistisk",
    "neutralistiskares": "neutralistisk",
    "neutralistiskas": "neutralistisk",
    "neutralistiskast": "neutralistisk",
    "neutralistiskaste": "neutralistisk",
    "neutralistiskastes": "neutralistisk",
    "neutralistiskasts": "neutralistisk",
    "neutralistiske": "neutralistisk",
    "neutralistiskes": "neutralistisk",
    "neutralistisks": "neutralistisk",
    "neutralistiskt": "neutralistisk",
    "neutralistiskts": "neutralistisk",
    "neutralists": "neutralist",
    "neutraliteten": "neutralitet",
    "neutralitetens": "neutralitet",
    "neutraliteter": "neutralitet",
    "neutraliteterna": "neutralitet",
    "neutraliteternas": "neutralitet",
    "neutraliteters": "neutralitet",
    "neutralitets": "neutralitet",
    "neutrallägen": "neutralläge",
    "neutrallägena": "neutralläge",
    "neutrallägenas": "neutralläge",
    "neutrallägens": "neutralläge",
    "neutralläges": "neutralläge",
    "neutralläget": "neutralläge",
    "neutrallägets": "neutralläge",
    "neutrals": "neutral",
    "neutralt": "neutral",
    "neutralts": "neutral",
    "neutrana": "neutrum",
    "neutranas": "neutrum",
    "neutras": "neutrum",
    "neutrena": "neutrum",
    "neutrenas": "neutrum",
    "neutrer": "neutrum",
    "neutrers": "neutrum",
    "neutret": "neutrum",
    "neutrets": "neutrum",
    "neutriner": "neutrino",
    "neutrinerna": "neutrino",
    "neutrinernas": "neutrino",
    "neutriners": "neutrino",
    "neutrinofäll": "neutrinofälla",
    "neutrinofällan": "neutrinofälla",
    "neutrinofällans": "neutrinofälla",
    "neutrinofällas": "neutrinofälla",
    "neutrinofälle": "neutrinofälla",
    "neutrinofällor": "neutrinofälla",
    "neutrinofällorna": "neutrinofälla",
    "neutrinofällornas": "neutrinofälla",
    "neutrinofällors": "neutrinofälla",
    "neutrinofälls": "neutrinofälla",
    "neutrinoförtätningar": "neutrinoförtätning",
    "neutrinoförtätningarna": "neutrinoförtätning",
    "neutrinoförtätningarnas": "neutrinoförtätning",
    "neutrinoförtätningars": "neutrinoförtätning",
    "neutrinoförtätningen": "neutrinoförtätning",
    "neutrinoförtätningens": "neutrinoförtätning",
    "neutrinoförtätnings": "neutrinoförtätning",
    "neutrinohaven": "neutrinohav",
    "neutrinohavens": "neutrinohav",
    "neutrinohavet": "neutrinohav",
    "neutrinohavets": "neutrinohav",
    "neutrinohavs": "neutrinohav",
    "neutrinomodellen": "neutrinomodell",
    "neutrinomodellens": "neutrinomodell",
    "neutrinomodeller": "neutrinomodell",
    "neutrinomodellerna": "neutrinomodell",
    "neutrinomodellernas": "neutrinomodell",
    "neutrinomodellers": "neutrinomodell",
    "neutrinomodells": "neutrinomodell",
    "neutrinon": "neutrino",
    "neutrinons": "neutrino",
    "neutrinorna": "neutrinor",
    "neutrinornas": "neutrinor",
    "neutrinors": "neutrinor",
    "neutrinos": "neutrino",
    "neutrinosarna": "neutrino",
    "neutrinosarnas": "neutrino",
    "neutronbomben": "neutronbomb",
    "neutronbombens": "neutronbomb",
    "neutronbomber": "neutronbomb",
    "neutronbomberna": "neutronbomb",
    "neutronbombernas": "neutronbomb",
    "neutronbombers": "neutronbomb",
    "neutronbombs": "neutronbomb",
    "neutronen": "neutron",
    "neutronens": "neutron",
    "neutroner": "neutron",
    "neutronerna": "neutron",
    "neutronernas": "neutron",
    "neutroners": "neutron",
    "neutrons": "neutron",
    "neutronstjärnan": "neutronstjärna",
    "neutronstjärnans": "neutronstjärna",
    "neutronstjärnas": "neutronstjärna",
    "neutronstjärne": "neutronstjärna",
    "neutronstjärnor": "neutronstjärna",
    "neutronstjärnorna": "neutronstjärna",
    "neutronstjärnornas": "neutronstjärna",
    "neutronstjärnors": "neutronstjärna",
    "neutronstrålningar": "neutronstrålning",
    "neutronstrålningarna": "neutronstrålning",
    "neutronstrålningarnas": "neutronstrålning",
    "neutronstrålningars": "neutronstrålning",
    "neutronstrålningen": "neutronstrålning",
    "neutronstrålningens": "neutronstrålning",
    "neutronstrålnings": "neutronstrålning",
    "neutrumen": "neutrum",
    "neutrumens": "neutrum",
    "neutrumet": "neutrum",
    "neutrumets": "neutrum",
    "neutrums": "neutrum",
    "nevöer": "nevö",
    "nevöerna": "nevö",
    "nevöernas": "nevö",
    "nevöers": "nevö",
    "nevön": "nevö",
    "nevöns": "nevö",
    "nevös": "nevö",
    "newfoundlandshundar": "newfoundlandshund",
    "newfoundlandshundarna": "newfoundlandshund",
    "newfoundlandshundarnas": "newfoundlandshund",
    "newfoundlandshundars": "newfoundlandshund",
    "newfoundlandshunden": "newfoundlandshund",
    "newfoundlandshundens": "newfoundlandshund",
    "newfoundlandshunds": "newfoundlandshund",
    "newfoundländar": "newfoundländare",
    "newfoundländaren": "newfoundländare",
    "newfoundländarens": "newfoundländare",
    "newfoundländares": "newfoundländare",
    "newfoundländarna": "newfoundländare",
    "newfoundländarnas": "newfoundländare",
    "newfoundländska": "newfoundländsk",
    "newfoundländskare": "newfoundländsk",
    "newfoundländskares": "newfoundländsk",
    "newfoundländskas": "newfoundländsk",
    "newfoundländskast": "newfoundländsk",
    "newfoundländskaste": "newfoundländsk",
    "newfoundländskastes": "newfoundländsk",
    "newfoundländskasts": "newfoundländsk",
    "newfoundländske": "newfoundländsk",
    "newfoundländskes": "newfoundländsk",
    "newfoundländsks": "newfoundländsk",
    "newfoundländskt": "newfoundländsk",
    "newfoundländskts": "newfoundländsk",
    "newtonen": "newton",
    "newtonens": "newton",
    "newtonmetern": "newtonmeter",
    "newtonmeterna": "newtonmeter",
    "newtonmeternas": "newtonmeter",
    "newtonmeterns": "newtonmeter",
    "newtonmeters": "newtonmeter",
    "newtonmetrar": "newtonmeter",
    "newtonmetrarna": "newtonmeter",
    "newtonmetrarnas": "newtonmeter",
    "newtonmetrars": "newtonmeter",
    "ng-ljuden": "ng-ljud",
    "ng-ljudens": "ng-ljud",
    "ng-ljudet": "ng-ljud",
    "ng-ljudets": "ng-ljud",
    "ng-ljuds": "ng-ljud",
    "ni": "nia",
    "niad": "nia",
    "niade": "nia",
    "niades": "nia",
    "niads": "nia",
    "nian": "nia",
    "niande": "nia",
    "nianden": "niande",
    "niandena": "niande",
    "niandenas": "niande",
    "niandens": "niande",
    "niandes": "niande",
    "niandet": "niande",
    "niandets": "niande",
    "nians": "nia",
    "niar": "nia",
    "nias": "nia",
    "niat": "nia",
    "niats": "nia",
    "nicaraguanen": "nicaraguan",
    "nicaraguanens": "nicaraguan",
    "nicaraguaner": "nicaraguan",
    "nicaraguanerna": "nicaraguan",
    "nicaraguanernas": "nicaraguan",
    "nicaraguaners": "nicaraguan",
    "nicaraguans": "nicaraguan",
    "nicaraguanska": "nicaraguansk",
    "nicaraguanskan": "nicaraguanska",
    "nicaraguanskans": "nicaraguanska",
    "nicaraguanskare": "nicaraguansk",
    "nicaraguanskares": "nicaraguansk",
    "nicaraguanskas": "nicaraguanska",
    "nicaraguanskast": "nicaraguansk",
    "nicaraguanskaste": "nicaraguansk",
    "nicaraguanskastes": "nicaraguansk",
    "nicaraguanskasts": "nicaraguansk",
    "nicaraguanske": "nicaraguanska",
    "nicaraguanskes": "nicaraguansk",
    "nicaraguanskor": "nicaraguanska",
    "nicaraguanskorna": "nicaraguanska",
    "nicaraguanskornas": "nicaraguanska",
    "nicaraguanskors": "nicaraguanska",
    "nicaraguansks": "nicaraguansk",
    "nicaraguanskt": "nicaraguansk",
    "nicaraguanskts": "nicaraguansk",
    "nickad": "nicka",
    "nickade": "nicka",
    "nickades": "nicka",
    "nickads": "nicka",
    "nickande": "nicka",
    "nickanden": "nickande",
    "nickandena": "nickande",
    "nickandenas": "nickande",
    "nickandens": "nickande",
    "nickandes": "nickande",
    "nickandet": "nickande",
    "nickandets": "nickande",
    "nickar": "nicka",
    "nickarna": "nick",
    "nickarnas": "nick",
    "nickars": "nick",
    "nickas": "nicka",
    "nickat": "nicka",
    "nickats": "nicka",
    "nickedock": "nickedocka",
    "nickedockan": "nickedocka",
    "nickedockans": "nickedocka",
    "nickedockas": "nickedocka",
    "nickedocke": "nickedocka",
    "nickedockor": "nickedocka",
    "nickedockorna": "nickedocka",
    "nickedockornas": "nickedocka",
    "nickedockors": "nickedocka",
    "nickedocks": "nickedocka",
    "nickelkromstålet": "nickelkromstål",
    "nickelkromstålets": "nickelkromstål",
    "nickelkromståls": "nickelkromstål",
    "nickeln": "nickel",
    "nickelns": "nickel",
    "nickels": "nickel",
    "nickelstålet": "nickelstål",
    "nickelstålets": "nickelstål",
    "nickelståls": "nickelstål",
    "nicken": "nick",
    "nickens": "nick",
    "nickhakar": "nickhake",
    "nickhakarna": "nickhake",
    "nickhakarnas": "nickhake",
    "nickhakars": "nickhake",
    "nickhaken": "nickhake",
    "nickhakens": "nickhake",
    "nickhakes": "nickhake",
    "nicklet": "nickel",
    "nicklets": "nickel",
    "nickningar": "nickning",
    "nickningarna": "nickning",
    "nickningarnas": "nickning",
    "nickningars": "nickning",
    "nickningen": "nickning",
    "nickningens": "nickning",
    "nicknings": "nickning",
    "nickpumpar": "nickpump",
    "nickpumparna": "nickpump",
    "nickpumparnas": "nickpump",
    "nickpumpars": "nickpump",
    "nickpumpen": "nickpump",
    "nickpumpens": "nickpump",
    "nickpumps": "nickpump",
    "nicks": "nick",
    "nidationen": "nidation",
    "nidationens": "nidation",
    "nidationer": "nidation",
    "nidationerna": "nidation",
    "nidationernas": "nidation",
    "nidationers": "nidation",
    "nidations": "nidation",
    "nidbilden": "nidbild",
    "nidbildens": "nidbild",
    "nidbilder": "nidbild",
    "nidbilderna": "nidbild",
    "nidbildernas": "nidbild",
    "nidbilders": "nidbild",
    "nidbilds": "nidbild",
    "niddikten": "niddikt",
    "niddiktens": "niddikt",
    "niddikter": "niddikt",
    "niddikterna": "niddikt",
    "niddikternas": "niddikt",
    "niddikters": "niddikt",
    "niddikts": "niddikt",
    "nidingar": "niding",
    "nidingarna": "niding",
    "nidingarnas": "niding",
    "nidingars": "niding",
    "nidingen": "niding",
    "nidingens": "niding",
    "nidings": "niding",
    "nidingsdåden": "nidingsdåd",
    "nidingsdådens": "nidingsdåd",
    "nidingsdådet": "nidingsdåd",
    "nidingsdådets": "nidingsdåd",
    "nidingsdåds": "nidingsdåd",
    "nidingsverken": "nidingsverk",
    "nidingsverkens": "nidingsverk",
    "nidingsverket": "nidingsverk",
    "nidingsverkets": "nidingsverk",
    "nidingsverks": "nidingsverk",
    "nidska": "nidsk",
    "nidskare": "nidsk",
    "nidskares": "nidsk",
    "nidskas": "nidsk",
    "nidskast": "nidsk",
    "nidskaste": "nidsk",
    "nidskastes": "nidsk",
    "nidskasts": "nidsk",
    "nidske": "nidsk",
    "nidskes": "nidsk",
    "nidskheten": "nidskhet",
    "nidskhetens": "nidskhet",
    "nidskhets": "nidskhet",
    "nidskriften": "nidskrift",
    "nidskriftens": "nidskrift",
    "nidskrifter": "nidskrift",
    "nidskrifterna": "nidskrift",
    "nidskrifternas": "nidskrift",
    "nidskrifters": "nidskrift",
    "nidskrifts": "nidskrift",
    "nidsks": "nidsk",
    "nidskt": "nidsk",
    "nidskts": "nidsk",
    "nidstänger": "nidstång",
    "nidstängerna": "nidstång",
    "nidstängernas": "nidstång",
    "nidstängers": "nidstång",
    "nidstången": "nidstång",
    "nidstångens": "nidstång",
    "nidstångs": "nidstång",
    "nidvis": "nidvisa",
    "nidvisan": "nidvisa",
    "nidvisans": "nidvisa",
    "nidvisas": "nidvisa",
    "nidvise": "nidvisa",
    "nidvisor": "nidvisa",
    "nidvisorna": "nidvisa",
    "nidvisornas": "nidvisa",
    "nidvisors": "nidvisa",
    "niecen": "niece",
    "niecens": "niece",
    "niecer": "niece",
    "niecerna": "niece",
    "niecernas": "niece",
    "niecers": "niece",
    "nieces": "niece",
    "nieller": "niello",
    "niellerad": "niellera",
    "niellerade": "niellera",
    "niellerades": "niellera",
    "niellerads": "niellera",
    "niellerande": "niellera",
    "nielleranden": "niellerande",
    "niellerandena": "niellerande",
    "niellerandenas": "niellerande",
    "niellerandens": "niellerande",
    "niellerandes": "niellerande",
    "niellerandet": "niellerande",
    "niellerandets": "niellerande",
    "niellerar": "niellera",
    "nielleras": "niellera",
    "niellerat": "niellera",
    "niellerats": "niellera",
    "niellerbara": "niellerbar",
    "niellerbarare": "niellerbar",
    "niellerbarares": "niellerbar",
    "niellerbaras": "niellerbar",
    "niellerbarast": "niellerbar",
    "niellerbaraste": "niellerbar",
    "niellerbarastes": "niellerbar",
    "niellerbarasts": "niellerbar",
    "niellerbare": "niellerbar",
    "niellerbares": "niellerbar",
    "niellerbarheten": "niellerbarhet",
    "niellerbarhetens": "niellerbarhet",
    "niellerbarhets": "niellerbarhet",
    "niellerbars": "niellerbar",
    "niellerbart": "niellerbar",
    "niellerbarts": "niellerbar",
    "nielleringar": "niellering",
    "nielleringarna": "niellering",
    "nielleringarnas": "niellering",
    "nielleringars": "niellering",
    "nielleringen": "niellering",
    "nielleringens": "niellering",
    "niellerings": "niellering",
    "niellerna": "niello",
    "niellernas": "niello",
    "niellers": "niello",
    "niellon": "niello",
    "niellons": "niello",
    "niellos": "niello",
    "nies": "nie",
    "niesnårets": "niesnåret",
    "nig": "niga",
    "nigande": "niga",
    "niganden": "nigande",
    "nigandena": "nigande",
    "nigandenas": "nigande",
    "nigandens": "nigande",
    "nigandes": "nigande",
    "nigandet": "nigande",
    "nigandets": "nigande",
    "nigas": "niga",
    "nige": "niga",
    "niger": "niga",
    "nigerern": "nigerer",
    "nigererna": "nigerer",
    "nigerernas": "nigerer",
    "nigererns": "nigerer",
    "nigerers": "nigerer",
    "nigerianen": "nigerian",
    "nigerianens": "nigerian",
    "nigerianer": "nigerian",
    "nigerianerna": "nigerian",
    "nigerianernas": "nigerian",
    "nigerianers": "nigerian",
    "nigerians": "nigerian",
    "nigerianska": "nigeriansk",
    "nigerianskan": "nigerianska",
    "nigerianskans": "nigerianska",
    "nigerianskare": "nigeriansk",
    "nigerianskares": "nigeriansk",
    "nigerianskas": "nigerianska",
    "nigerianskast": "nigeriansk",
    "nigerianskaste": "nigeriansk",
    "nigerianskastes": "nigeriansk",
    "nigerianskasts": "nigeriansk",
    "nigerianske": "nigerianska",
    "nigerianskes": "nigeriansk",
    "nigerianskor": "nigerianska",
    "nigerianskorna": "nigerianska",
    "nigerianskornas": "nigerianska",
    "nigerianskors": "nigerianska",
    "nigeriansks": "nigeriansk",
    "nigerianskt": "nigeriansk",
    "nigerianskts": "nigeriansk",
    "nigeriska": "nigerisk",
    "nigeriskan": "nigeriska",
    "nigeriskans": "nigeriska",
    "nigeriskare": "nigerisk",
    "nigeriskares": "nigerisk",
    "nigeriskas": "nigeriska",
    "nigeriskast": "nigerisk",
    "nigeriskaste": "nigerisk",
    "nigeriskastes": "nigerisk",
    "nigeriskasts": "nigerisk",
    "nigeriske": "nigeriska",
    "nigeriskes": "nigerisk",
    "nigeriskor": "nigeriska",
    "nigeriskorna": "nigeriska",
    "nigeriskornas": "nigeriska",
    "nigeriskors": "nigeriska",
    "nigerisks": "nigerisk",
    "nigeriskt": "nigerisk",
    "nigeriskts": "nigerisk",
    "niges": "niga",
    "niggern": "nigger",
    "niggerns": "nigger",
    "niggers": "nigger",
    "niggrer": "nigger",
    "niggrerna": "nigger",
    "niggrernas": "nigger",
    "niggrers": "nigger",
    "nigit": "niga",
    "nigits": "niga",
    "nigningar": "nigning",
    "nigningarna": "nigning",
    "nigningarnas": "nigning",
    "nigningars": "nigning",
    "nigningen": "nigning",
    "nigningens": "nigning",
    "nignings": "nigning",
    "nigs": "niga",
    "nihilismen": "nihilism",
    "nihilismens": "nihilism",
    "nihilismer": "nihilism",
    "nihilismerna": "nihilism",
    "nihilismernas": "nihilism",
    "nihilismers": "nihilism",
    "nihilisms": "nihilism",
    "nihilisten": "nihilist",
    "nihilistens": "nihilist",
    "nihilister": "nihilist",
    "nihilisterna": "nihilist",
    "nihilisternas": "nihilist",
    "nihilisters": "nihilist",
    "nihilistiska": "nihilistisk",
    "nihilistiskare": "nihilistisk",
    "nihilistiskares": "nihilistisk",
    "nihilistiskas": "nihilistisk",
    "nihilistiskast": "nihilistisk",
    "nihilistiskaste": "nihilistisk",
    "nihilistiskastes": "nihilistisk",
    "nihilistiskasts": "nihilistisk",
    "nihilistiske": "nihilistisk",
    "nihilistiskes": "nihilistisk",
    "nihilistisks": "nihilistisk",
    "nihilistiskt": "nihilistisk",
    "nihilistiskts": "nihilistisk",
    "nihilists": "nihilist",
    "nikotinen": "nikotin",
    "nikotinens": "nikotin",
    "nikotinet": "nikotin",
    "nikotinets": "nikotin",
    "nikotingula": "nikotingul",
    "nikotingulare": "nikotingul",
    "nikotingulares": "nikotingul",
    "nikotingulas": "nikotingul",
    "nikotingulast": "nikotingul",
    "nikotingulaste": "nikotingul",
    "nikotingulastes": "nikotingul",
    "nikotingulasts": "nikotingul",
    "nikotingule": "nikotingul",
    "nikotingules": "nikotingul",
    "nikotinguls": "nikotingul",
    "nikotingult": "nikotingul",
    "nikotingults": "nikotingul",
    "nikotinismen": "nikotinism",
    "nikotinismens": "nikotinism",
    "nikotinismer": "nikotinism",
    "nikotinismerna": "nikotinism",
    "nikotinismernas": "nikotinism",
    "nikotinismers": "nikotinism",
    "nikotinisms": "nikotinism",
    "nikotinisten": "nikotinist",
    "nikotinistens": "nikotinist",
    "nikotinister": "nikotinist",
    "nikotinisterna": "nikotinist",
    "nikotinisternas": "nikotinist",
    "nikotinisters": "nikotinist",
    "nikotinists": "nikotinist",
    "nikotins": "nikotin",
    "nikten": "nikt",
    "niktens": "nikt",
    "niktet": "nikt",
    "niktets": "nikt",
    "nikts": "nikt",
    "nimbusen": "nimbus",
    "nimbusens": "nimbus",
    "nimrodar": "nimrod",
    "nimrodarna": "nimrod",
    "nimrodarnas": "nimrod",
    "nimrodars": "nimrod",
    "nimroden": "nimrod",
    "nimrodens": "nimrod",
    "nimrods": "nimrod",
    "nioben": "niob",
    "niobens": "niob",
    "niobs": "niob",
    "niodagarsturnéer": "niodagarsturné",
    "niodagarsturnéerna": "niodagarsturné",
    "niodagarsturnéernas": "niodagarsturné",
    "niodagarsturnéers": "niodagarsturné",
    "niodagarsturnén": "niodagarsturné",
    "niodagarsturnéns": "niodagarsturné",
    "niodagarsturnés": "niodagarsturné",
    "niodubben": "niodubbel",
    "niodubbens": "niodubbel",
    "niodubbet": "niodubbel",
    "niodubbets": "niodubbel",
    "niodubbna": "niodubbel",
    "niodubbnas": "niodubbel",
    "niodubbne": "niodubbel",
    "niodubbnes": "niodubbel",
    "niofaldiga": "niofaldig",
    "niofaldigas": "niofaldig",
    "niofaldige": "niofaldig",
    "niofaldiges": "niofaldig",
    "niofaldigs": "niofaldig",
    "niofaldigt": "niofaldig",
    "niofaldigts": "niofaldig",
    "niohålsbanan": "niohålsbana",
    "niohålsbanans": "niohålsbana",
    "niohålsbanas": "niohålsbana",
    "niohålsbane": "niohålsbana",
    "niohålsbanor": "niohålsbana",
    "niohålsbanorna": "niohålsbana",
    "niohålsbanornas": "niohålsbana",
    "niohålsbanors": "niohålsbana",
    "nionde": "nio",
    "niondedelar": "niondedel",
    "niondedelarna": "niondedel",
    "niondedelarnas": "niondedel",
    "niondedelars": "niondedel",
    "niondedelen": "niondedel",
    "niondedelens": "niondedel",
    "niondedels": "niondedel",
    "niondelar": "niondel",
    "niondelarna": "niondel",
    "niondelarnas": "niondel",
    "niondelars": "niondel",
    "niondelen": "niondel",
    "niondelens": "niondel",
    "niondels": "niondel",
    "niondes": "nio",
    "nior": "nia",
    "niorna": "nia",
    "niornas": "nia",
    "niors": "nia",
    "nios": "nio",
    "niosnårets": "niosnåret",
    "niotillhållarlåsen": "niotillhållarlås",
    "niotillhållarlåsens": "niotillhållarlås",
    "niotillhållarlåset": "niotillhållarlås",
    "niotillhållarlåsets": "niotillhållarlås",
    "niotumsspikar": "niotumsspik",
    "niotumsspikarna": "niotumsspik",
    "niotumsspikarnas": "niotumsspik",
    "niotumsspikars": "niotumsspik",
    "niotumsspiken": "niotumsspik",
    "niotumsspikens": "niotumsspik",
    "niotumsspiks": "niotumsspik",
    "nioåriga": "nioårig",
    "nioårigas": "nioårig",
    "nioårige": "nioårig",
    "nioåriges": "nioårig",
    "nioårigs": "nioårig",
    "nioårigt": "nioårig",
    "nioårigts": "nioårig",
    "nioåringar": "nioåring",
    "nioåringarna": "nioåring",
    "nioåringarnas": "nioåring",
    "nioåringars": "nioåring",
    "nioåringen": "nioåring",
    "nioåringens": "nioåring",
    "nioårings": "nioåring",
    "nip": "nipa",
    "nipan": "nipa",
    "nipans": "nipa",
    "nipas": "nipa",
    "nipbranten": "nipbrant",
    "nipbrantens": "nipbrant",
    "nipbranter": "nipbrant",
    "nipbranterna": "nipbrant",
    "nipbranternas": "nipbrant",
    "nipbranters": "nipbrant",
    "nipbrants": "nipbrant",
    "nipe": "nipa",
    "nipfloden": "nipflod",
    "nipflodens": "nipflod",
    "nipfloder": "nipflod",
    "nipfloderna": "nipflod",
    "nipflodernas": "nipflod",
    "nipfloders": "nipflod",
    "nipflods": "nipflod",
    "nipiga": "nipig",
    "nipigare": "nipig",
    "nipigares": "nipig",
    "nipigas": "nipig",
    "nipigast": "nipig",
    "nipigaste": "nipig",
    "nipigastes": "nipig",
    "nipigasts": "nipig",
    "nipige": "nipig",
    "nipiges": "nipig",
    "nipigs": "nipig",
    "nipigt": "nipig",
    "nipigts": "nipig",
    "nipor": "nipa",
    "niporna": "nipa",
    "nipornas": "nipa",
    "nipors": "nipa",
    "nippeln": "nippel",
    "nippelns": "nippel",
    "nippels": "nippel",
    "nipperna": "nipper",
    "nippernas": "nipper",
    "nippers": "nipper",
    "nippertipp": "nippertippa",
    "nippertippan": "nippertippa",
    "nippertippans": "nippertippa",
    "nippertippas": "nippertippa",
    "nippertippe": "nippertippa",
    "nippertippor": "nippertippa",
    "nippertipporna": "nippertippa",
    "nippertippornas": "nippertippa",
    "nippertippors": "nippertippa",
    "nippertipps": "nippertippa",
    "nipplar": "nippel",
    "nipplarna": "nippel",
    "nipplarnas": "nippel",
    "nipplars": "nippel",
    "nipprans": "nippran",
    "nippriga": "nipprig",
    "nipprigare": "nipprig",
    "nipprigares": "nipprig",
    "nipprigas": "nipprig",
    "nipprigast": "nipprig",
    "nipprigaste": "nipprig",
    "nipprigastes": "nipprig",
    "nipprigasts": "nipprig",
    "nipprige": "nipprig",
    "nippriges": "nipprig",
    "nipprigheten": "nipprighet",
    "nipprighetens": "nipprighet",
    "nipprighets": "nipprighet",
    "nipprigs": "nipprig",
    "nipprigt": "nipprig",
    "nipprigts": "nipprig",
    "nips": "nipa",
    "nirvanas": "nirvana",
    "nirvanat": "nirvana",
    "nirvanats": "nirvana",
    "nischade": "nischad",
    "nischades": "nischad",
    "nischads": "nischad",
    "nischat": "nischad",
    "nischats": "nischad",
    "nischen": "nisch",
    "nischens": "nisch",
    "nischer": "nisch",
    "nischerna": "nisch",
    "nischernas": "nisch",
    "nischers": "nisch",
    "nischs": "nisch",
    "nissan": "nissa",
    "nissans": "nissa",
    "nissarna": "nisse",
    "nissars": "nisse",
    "nissas": "nissa",
    "nisseflick": "nisseflicka",
    "nisseflickan": "nisseflicka",
    "nisseflickans": "nisseflicka",
    "nisseflickas": "nisseflicka",
    "nisseflicke": "nisseflicka",
    "nisseflickor": "nisseflicka",
    "nisseflickorna": "nisseflicka",
    "nisseflickornas": "nisseflicka",
    "nisseflickors": "nisseflicka",
    "nisseflicks": "nisseflicka",
    "nissen": "nisse",
    "nissens": "nisse",
    "nisses": "nisse",
    "nissor": "nissa",
    "nissorna": "nissa",
    "nissornas": "nissa",
    "nissors": "nissa",
    "nissögas": "nissöga",
    "nissögat": "nissöga",
    "nissögats": "nissöga",
    "nissögon": "nissöga",
    "nissögonen": "nissöga",
    "nissögonens": "nissöga",
    "nissögons": "nissöga",
    "nit": "nita",
    "nitad": "nita",
    "nitade": "nita",
    "nitades": "nita",
    "nitads": "nita",
    "nitande": "nita",
    "nitanden": "nitande",
    "nitandena": "nitande",
    "nitandenas": "nitande",
    "nitandens": "nitande",
    "nitandes": "nitande",
    "nitandet": "nitande",
    "nitandets": "nitande",
    "nitar": "nita",
    "nitarna": "nit",
    "nitarnas": "nit",
    "nitars": "nit",
    "nitas": "nita",
    "nitat": "nita",
    "nitats": "nita",
    "nitbrick": "nitbricka",
    "nitbrickan": "nitbricka",
    "nitbrickans": "nitbricka",
    "nitbrickas": "nitbricka",
    "nitbricke": "nitbricka",
    "nitbrickor": "nitbricka",
    "nitbrickorna": "nitbricka",
    "nitbrickornas": "nitbricka",
    "nitbrickors": "nitbricka",
    "nitbricks": "nitbricka",
    "niten": "nit",
    "nitens": "nit",
    "niter": "nit",
    "niterna": "nit",
    "niternas": "nit",
    "niters": "nit",
    "nitet": "nit",
    "nitets": "nit",
    "nitförbanden": "nitförband",
    "nitförbandens": "nitförband",
    "nitförbandet": "nitförband",
    "nitförbandets": "nitförband",
    "nitförbands": "nitförband",
    "nithuvuden": "nithuvud",
    "nithuvudena": "nithuvud",
    "nithuvudenas": "nithuvud",
    "nithuvudens": "nithuvud",
    "nithuvudet": "nithuvud",
    "nithuvudets": "nithuvud",
    "nithuvuds": "nithuvud",
    "nitida": "nitid",
    "nitidare": "nitid",
    "nitidares": "nitid",
    "nitidas": "nitid",
    "nitidast": "nitid",
    "nitidaste": "nitid",
    "nitidastes": "nitid",
    "nitidasts": "nitid",
    "nitide": "nitid",
    "nitides": "nitid",
    "nitids": "nitid",
    "nitiska": "nitisk",
    "nitiskare": "nitisk",
    "nitiskares": "nitisk",
    "nitiskas": "nitisk",
    "nitiskast": "nitisk",
    "nitiskaste": "nitisk",
    "nitiskastes": "nitisk",
    "nitiskasts": "nitisk",
    "nitiske": "nitisk",
    "nitiskes": "nitisk",
    "nitisks": "nitisk",
    "nitiskt": "nitisk",
    "nitiskts": "nitisk",
    "nitlotten": "nitlott",
    "nitlottens": "nitlott",
    "nitlotter": "nitlott",
    "nitlotterna": "nitlott",
    "nitlotternas": "nitlott",
    "nitlotters": "nitlott",
    "nitlotts": "nitlott",
    "nitnageln": "nitnagel",
    "nitnagelns": "nitnagel",
    "nitnagels": "nitnagel",
    "nitnaglar": "nitnagel",
    "nitnaglarna": "nitnagel",
    "nitnaglarnas": "nitnagel",
    "nitnaglars": "nitnagel",
    "nitratbakterien": "nitratbakterie",
    "nitratbakteriens": "nitratbakterie",
    "nitratbakterier": "nitratbakterie",
    "nitratbakterierna": "nitratbakterie",
    "nitratbakteriernas": "nitratbakterie",
    "nitratbakteriers": "nitratbakterie",
    "nitratbakteries": "nitratbakterie",
    "nitraten": "nitrat",
    "nitratens": "nitrat",
    "nitrater": "nitrat",
    "nitraterna": "nitrat",
    "nitraternas": "nitrat",
    "nitraters": "nitrat",
    "nitratet": "nitrat",
    "nitratets": "nitrat",
    "nitrats": "nitrat",
    "nitrerad": "nitrera",
    "nitrerade": "nitrera",
    "nitrerades": "nitrera",
    "nitrerads": "nitrera",
    "nitrerande": "nitrera",
    "nitreranden": "nitrerande",
    "nitrerandena": "nitrerande",
    "nitrerandenas": "nitrerande",
    "nitrerandens": "nitrerande",
    "nitrerandes": "nitrerande",
    "nitrerandet": "nitrerande",
    "nitrerandets": "nitrerande",
    "nitrerar": "nitrera",
    "nitreras": "nitrera",
    "nitrerat": "nitrera",
    "nitrerats": "nitrera",
    "nitrerbara": "nitrerbar",
    "nitrerbarare": "nitrerbar",
    "nitrerbarares": "nitrerbar",
    "nitrerbaras": "nitrerbar",
    "nitrerbarast": "nitrerbar",
    "nitrerbaraste": "nitrerbar",
    "nitrerbarastes": "nitrerbar",
    "nitrerbarasts": "nitrerbar",
    "nitrerbare": "nitrerbar",
    "nitrerbares": "nitrerbar",
    "nitrerbarheten": "nitrerbarhet",
    "nitrerbarhetens": "nitrerbarhet",
    "nitrerbarhets": "nitrerbarhet",
    "nitrerbars": "nitrerbar",
    "nitrerbart": "nitrerbar",
    "nitrerbarts": "nitrerbar",
    "nitreringar": "nitrering",
    "nitreringarna": "nitrering",
    "nitreringarnas": "nitrering",
    "nitreringars": "nitrering",
    "nitreringen": "nitrering",
    "nitreringens": "nitrering",
    "nitrerings": "nitrering",
    "nitrerstålet": "nitrerstål",
    "nitrerstålets": "nitrerstål",
    "nitrerståls": "nitrerstål",
    "nitritbakterien": "nitritbakterie",
    "nitritbakteriens": "nitritbakterie",
    "nitritbakterier": "nitritbakterie",
    "nitritbakterierna": "nitritbakterie",
    "nitritbakteriernas": "nitritbakterie",
    "nitritbakteriers": "nitritbakterie",
    "nitritbakteries": "nitritbakterie",
    "nitriten": "nitrit",
    "nitritens": "nitrit",
    "nitriter": "nitrit",
    "nitriterna": "nitrit",
    "nitriternas": "nitrit",
    "nitriters": "nitrit",
    "nitritet": "nitrit",
    "nitritets": "nitrit",
    "nitrits": "nitrit",
    "nitrocellulosan": "nitrocellulosa",
    "nitrocellulosans": "nitrocellulosa",
    "nitrocellulosas": "nitrocellulosa",
    "nitroföreningar": "nitroförening",
    "nitroföreningarna": "nitroförening",
    "nitroföreningarnas": "nitroförening",
    "nitroföreningars": "nitroförening",
    "nitroföreningen": "nitroförening",
    "nitroföreningens": "nitroförening",
    "nitroförenings": "nitroförening",
    "nitrogenet": "nitrogen",
    "nitrogenets": "nitrogen",
    "nitrogens": "nitrogen",
    "nitroglycerinen": "nitroglycerin",
    "nitroglycerinens": "nitroglycerin",
    "nitroglyceriner": "nitroglycerin",
    "nitroglycerinerna": "nitroglycerin",
    "nitroglycerinernas": "nitroglycerin",
    "nitroglyceriners": "nitroglycerin",
    "nitroglycerinet": "nitroglycerin",
    "nitroglycerinets": "nitroglycerin",
    "nitroglycerins": "nitroglycerin",
    "nitrogruppen": "nitrogrupp",
    "nitrogruppens": "nitrogrupp",
    "nitrogrupper": "nitrogrupp",
    "nitrogrupperna": "nitrogrupp",
    "nitrogruppernas": "nitrogrupp",
    "nitrogruppers": "nitrogrupp",
    "nitrogrupps": "nitrogrupp",
    "nitroliten": "nitrolit",
    "nitrolitens": "nitrolit",
    "nitrolits": "nitrolit",
    "nitrösa": "nitrös",
    "nitrösare": "nitrös",
    "nitrösares": "nitrös",
    "nitrösas": "nitrös",
    "nitrösast": "nitrös",
    "nitrösaste": "nitrös",
    "nitrösastes": "nitrös",
    "nitrösasts": "nitrös",
    "nitröse": "nitrös",
    "nitröses": "nitrös",
    "nitröst": "nitrös",
    "nitrösts": "nitrös",
    "nits": "nit",
    "nitskall": "nitskalle",
    "nitskallar": "nitskalle",
    "nitskallarna": "nitskalle",
    "nitskallarnas": "nitskalle",
    "nitskallars": "nitskalle",
    "nitskallen": "nitskalle",
    "nitskallens": "nitskalle",
    "nitskalles": "nitskalle",
    "nitskalls": "nitskalle",
    "nitstampar": "nitstamp",
    "nitstamparna": "nitstamp",
    "nitstamparnas": "nitstamp",
    "nitstampars": "nitstamp",
    "nitstampen": "nitstamp",
    "nitstampens": "nitstamp",
    "nitstamps": "nitstamp",
    "nitstansar": "nitstans",
    "nitstansarna": "nitstans",
    "nitstansarnas": "nitstans",
    "nitstansars": "nitstans",
    "nitstansen": "nitstans",
    "nitstansens": "nitstans",
    "nittifems": "nittifem",
    "nittiofemoktaniga": "nittiofemoktanig",
    "nittiofemoktanigare": "nittiofemoktanig",
    "nittiofemoktanigares": "nittiofemoktanig",
    "nittiofemoktanigas": "nittiofemoktanig",
    "nittiofemoktanigast": "nittiofemoktanig",
    "nittiofemoktanigaste": "nittiofemoktanig",
    "nittiofemoktanigastes": "nittiofemoktanig",
    "nittiofemoktanigasts": "nittiofemoktanig",
    "nittiofemoktanige": "nittiofemoktanig",
    "nittiofemoktaniges": "nittiofemoktanig",
    "nittiofemoktanigs": "nittiofemoktanig",
    "nittiofemoktanigt": "nittiofemoktanig",
    "nittiofemoktanigts": "nittiofemoktanig",
    "nittiofems": "nittiofem",
    "nittiofemte": "nittiofem",
    "nittiofemtes": "nittiofem",
    "nittionde": "nittio",
    "nittiondes": "nittio",
    "nittios": "nittio",
    "nittiosexprocentiga": "nittiosexprocentig",
    "nittiosexprocentigare": "nittiosexprocentig",
    "nittiosexprocentigares": "nittiosexprocentig",
    "nittiosexprocentigas": "nittiosexprocentig",
    "nittiosexprocentigast": "nittiosexprocentig",
    "nittiosexprocentigaste": "nittiosexprocentig",
    "nittiosexprocentigastes": "nittiosexprocentig",
    "nittiosexprocentigasts": "nittiosexprocentig",
    "nittiosexprocentige": "nittiosexprocentig",
    "nittiosexprocentiges": "nittiosexprocentig",
    "nittiosexprocentigs": "nittiosexprocentig",
    "nittiosexprocentigt": "nittiosexprocentig",
    "nittiosexprocentigts": "nittiosexprocentig",
    "nittiotalet": "nittiotal",
    "nittiotalets": "nittiotal",
    "nittiotalismen": "nittiotalism",
    "nittiotalismens": "nittiotalism",
    "nittiotalismer": "nittiotalism",
    "nittiotalismerna": "nittiotalism",
    "nittiotalismernas": "nittiotalism",
    "nittiotalismers": "nittiotalism",
    "nittiotalisms": "nittiotalism",
    "nittiotalisten": "nittiotalist",
    "nittiotalistens": "nittiotalist",
    "nittiotalister": "nittiotalist",
    "nittiotalisterna": "nittiotalist",
    "nittiotalisternas": "nittiotalist",
    "nittiotalisters": "nittiotalist",
    "nittiotalistiska": "nittiotalistisk",
    "nittiotalistiskas": "nittiotalistisk",
    "nittiotalistiske": "nittiotalistisk",
    "nittiotalistiskes": "nittiotalistisk",
    "nittiotalistisks": "nittiotalistisk",
    "nittiotalistiskt": "nittiotalistisk",
    "nittiotalistiskts": "nittiotalistisk",
    "nittiotalists": "nittiotalist",
    "nittiotals": "nittiotal",
    "nittis": "nitti",
    "nittisexprocentiga": "nittisexprocentig",
    "nittisexprocentigare": "nittisexprocentig",
    "nittisexprocentigares": "nittisexprocentig",
    "nittisexprocentigas": "nittisexprocentig",
    "nittisexprocentigast": "nittisexprocentig",
    "nittisexprocentigaste": "nittisexprocentig",
    "nittisexprocentigastes": "nittisexprocentig",
    "nittisexprocentigasts": "nittisexprocentig",
    "nittisexprocentige": "nittisexprocentig",
    "nittisexprocentiges": "nittisexprocentig",
    "nittisexprocentigs": "nittisexprocentig",
    "nittisexprocentigt": "nittisexprocentig",
    "nittisexprocentigts": "nittisexprocentig",
    "nittitalet": "nittital",
    "nittitalets": "nittital",
    "nittitalismen": "nittitalism",
    "nittitalismens": "nittitalism",
    "nittitalismer": "nittitalism",
    "nittitalismerna": "nittitalism",
    "nittitalismernas": "nittitalism",
    "nittitalismers": "nittitalism",
    "nittitalisms": "nittitalism",
    "nittitalisten": "nittitalist",
    "nittitalistens": "nittitalist",
    "nittitalister": "nittitalist",
    "nittitalisterna": "nittitalist",
    "nittitalisternas": "nittitalist",
    "nittitalisters": "nittitalist",
    "nittitalists": "nittitalist",
    "nittitals": "nittital",
    "nittonde": "nitton",
    "nittondes": "nitton",
    "nittonhundrafemtiotalet": "nittonhundrafemtiotal",
    "nittonhundrafemtiotalets": "nittonhundrafemtiotal",
    "nittonhundrafemtiotals": "nittonhundrafemtiotal",
    "nittonhundrafyrtiotalet": "nittonhundrafyrtiotal",
    "nittonhundrafyrtiotalets": "nittonhundrafyrtiotal",
    "nittonhundrafyrtiotals": "nittonhundrafyrtiotal",
    "nittonhundranittiotalet": "nittonhundranittiotal",
    "nittonhundranittiotalets": "nittonhundranittiotal",
    "nittonhundranittiotals": "nittonhundranittiotal",
    "nittonhundrasextiotalet": "nittonhundrasextiotal",
    "nittonhundrasextiotalets": "nittonhundrasextiotal",
    "nittonhundrasextiotals": "nittonhundrasextiotal",
    "nittonhundrasjuttiotalet": "nittonhundrasjuttiotal",
    "nittonhundrasjuttiotalets": "nittonhundrasjuttiotal",
    "nittonhundrasjuttiotals": "nittonhundrasjuttiotal",
    "nittonhundratalet": "nittonhundratal",
    "nittonhundratalets": "nittonhundratal",
    "nittonhundratals": "nittonhundratal",
    "nittonhundratiotalet": "nittonhundratiotal",
    "nittonhundratiotalets": "nittonhundratiotal",
    "nittonhundratiotals": "nittonhundratiotal",
    "nittonhundratjugotalet": "nittonhundratjugotal",
    "nittonhundratjugotalets": "nittonhundratjugotal",
    "nittonhundratjugotals": "nittonhundratjugotal",
    "nittonhundratrettiotalet": "nittonhundratrettiotal",
    "nittonhundratrettiotalets": "nittonhundratrettiotal",
    "nittonhundratrettiotals": "nittonhundratrettiotal",
    "nittonhundraåttiotalet": "nittonhundraåttiotal",
    "nittonhundraåttiotalets": "nittonhundraåttiotal",
    "nittonhundraåttiotals": "nittonhundraåttiotal",
    "nittons": "nitton",
    "nittonsnårets": "nittonsnåret",
    "nittonåriga": "nittonårig",
    "nittonårigas": "nittonårig",
    "nittonårige": "nittonårig",
    "nittonåriges": "nittonårig",
    "nittonårigs": "nittonårig",
    "nittonårigt": "nittonårig",
    "nittonårigts": "nittonårig",
    "nittonåringar": "nittonåring",
    "nittonåringarna": "nittonåring",
    "nittonåringarnas": "nittonåring",
    "nittonåringars": "nittonåring",
    "nittonåringen": "nittonåring",
    "nittonåringens": "nittonåring",
    "nittonårings": "nittonåring",
    "nitälskade": "nitälska",
    "nitälskades": "nitälska",
    "nitälskande": "nitälska",
    "nitälskanden": "nitälskande",
    "nitälskandena": "nitälskande",
    "nitälskandenas": "nitälskande",
    "nitälskandens": "nitälskande",
    "nitälskandes": "nitälskande",
    "nitälskandet": "nitälskande",
    "nitälskandets": "nitälskande",
    "nitälskans": "nitälskan",
    "nitälskar": "nitälska",
    "nitälskas": "nitälska",
    "nitälskat": "nitälska",
    "nitälskats": "nitälska",
    "niuern": "niuer",
    "niuerna": "niuer",
    "niuernas": "niuer",
    "niuerns": "niuer",
    "niuers": "niuer",
    "niuiskan": "niuiska",
    "niuiskans": "niuiska",
    "niuiskas": "niuiska",
    "niuiske": "niuiska",
    "niuiskor": "niuiska",
    "niuiskorna": "niuiska",
    "niuiskornas": "niuiska",
    "niuiskors": "niuiska",
    "nivationen": "nivation",
    "nivationens": "nivation",
    "nivationer": "nivation",
    "nivationerna": "nivation",
    "nivationernas": "nivation",
    "nivationers": "nivation",
    "nivations": "nivation",
    "nivellerad": "nivellera",
    "nivellerade": "nivellera",
    "nivellerades": "nivellera",
    "nivellerads": "nivellera",
    "nivellerande": "nivellera",
    "nivelleranden": "nivellerande",
    "nivellerandena": "nivellerande",
    "nivellerandenas": "nivellerande",
    "nivellerandens": "nivellerande",
    "nivellerandes": "nivellerande",
    "nivellerandet": "nivellerande",
    "nivellerandets": "nivellerande",
    "nivellerar": "nivellera",
    "nivelleras": "nivellera",
    "nivellerat": "nivellera",
    "nivellerats": "nivellera",
    "nivellerbara": "nivellerbar",
    "nivellerbarare": "nivellerbar",
    "nivellerbarares": "nivellerbar",
    "nivellerbaras": "nivellerbar",
    "nivellerbarast": "nivellerbar",
    "nivellerbaraste": "nivellerbar",
    "nivellerbarastes": "nivellerbar",
    "nivellerbarasts": "nivellerbar",
    "nivellerbare": "nivellerbar",
    "nivellerbares": "nivellerbar",
    "nivellerbarheten": "nivellerbarhet",
    "nivellerbarhetens": "nivellerbarhet",
    "nivellerbarhets": "nivellerbarhet",
    "nivellerbars": "nivellerbar",
    "nivellerbart": "nivellerbar",
    "nivellerbarts": "nivellerbar",
    "nivelleringar": "nivellering",
    "nivelleringarna": "nivellering",
    "nivelleringarnas": "nivellering",
    "nivelleringars": "nivellering",
    "nivelleringen": "nivellering",
    "nivelleringens": "nivellering",
    "nivellerings": "nivellering",
    "nivåer": "nivå",
    "nivåerna": "nivå",
    "nivåernas": "nivå",
    "nivåers": "nivå",
    "nivågrupperad": "nivågruppera",
    "nivågrupperade": "nivågruppera",
    "nivågrupperades": "nivågruppera",
    "nivågrupperads": "nivågruppera",
    "nivågrupperande": "nivågruppera",
    "nivågrupperanden": "nivågrupperande",
    "nivågrupperandena": "nivågrupperande",
    "nivågrupperandenas": "nivågrupperande",
    "nivågrupperandens": "nivågrupperande",
    "nivågrupperandes": "nivågrupperande",
    "nivågrupperandet": "nivågrupperande",
    "nivågrupperandets": "nivågrupperande",
    "nivågrupperar": "nivågruppera",
    "nivågrupperas": "nivågruppera",
    "nivågrupperat": "nivågruppera",
    "nivågrupperats": "nivågruppera",
    "nivågrupperbara": "nivågrupperbar",
    "nivågrupperbarare": "nivågrupperbar",
    "nivågrupperbarares": "nivågrupperbar",
    "nivågrupperbaras": "nivågrupperbar",
    "nivågrupperbarast": "nivågrupperbar",
    "nivågrupperbaraste": "nivågrupperbar",
    "nivågrupperbarastes": "nivågrupperbar",
    "nivågrupperbarasts": "nivågrupperbar",
    "nivågrupperbare": "nivågrupperbar",
    "nivågrupperbares": "nivågrupperbar",
    "nivågrupperbarheten": "nivågrupperbarhet",
    "nivågrupperbarhetens": "nivågrupperbarhet",
    "nivågrupperbarhets": "nivågrupperbarhet",
    "nivågrupperbars": "nivågrupperbar",
    "nivågrupperbart": "nivågrupperbar",
    "nivågrupperbarts": "nivågrupperbar",
    "nivågrupperingar": "nivågruppering",
    "nivågrupperingarna": "nivågruppering",
    "nivågrupperingarnas": "nivågruppering",
    "nivågrupperingars": "nivågruppering",
    "nivågrupperingen": "nivågruppering",
    "nivågrupperingens": "nivågruppering",
    "nivågrupperings": "nivågruppering",
    "nivåkart": "nivåkarta",
    "nivåkartan": "nivåkarta",
    "nivåkartans": "nivåkarta",
    "nivåkartas": "nivåkarta",
    "nivåkarte": "nivåkarta",
    "nivåkartor": "nivåkarta",
    "nivåkartorna": "nivåkarta",
    "nivåkartornas": "nivåkarta",
    "nivåkartors": "nivåkarta",
    "nivåkarts": "nivåkarta",
    "nivåkurv": "nivåkurva",
    "nivåkurvan": "nivåkurva",
    "nivåkurvans": "nivåkurva",
    "nivåkurvas": "nivåkurva",
    "nivåkurve": "nivåkurva",
    "nivåkurvor": "nivåkurva",
    "nivåkurvorna": "nivåkurva",
    "nivåkurvornas": "nivåkurva",
    "nivåkurvors": "nivåkurva",
    "nivåkurvs": "nivåkurva",
    "nivån": "nivå",
    "nivåns": "nivå",
    "nivås": "nivå",
    "nivåskillnaden": "nivåskillnad",
    "nivåskillnadens": "nivåskillnad",
    "nivåskillnader": "nivåskillnad",
    "nivåskillnaderna": "nivåskillnad",
    "nivåskillnadernas": "nivåskillnad",
    "nivåskillnaders": "nivåskillnad",
    "nivåskillnads": "nivåskillnad",
    "nivåytan": "nivåyta",
    "nivåytans": "nivåyta",
    "nivåytas": "nivåyta",
    "nivåyte": "nivåyta",
    "nivåytor": "nivåyta",
    "nivåytorna": "nivåyta",
    "nivåytornas": "nivåyta",
    "nivåytors": "nivåyta",
    "njugga": "njugg",
    "njuggare": "njugg",
    "njuggares": "njugg",
    "njuggas": "njugg",
    "njuggast": "njugg",
    "njuggaste": "njugg",
    "njuggastes": "njugg",
    "njuggasts": "njugg",
    "njugge": "njugg",
    "njugges": "njugg",
    "njuggheten": "njugghet",
    "njugghetens": "njugghet",
    "njugghets": "njugghet",
    "njugghänta": "njugghänt",
    "njugghäntare": "njugghänt",
    "njugghäntares": "njugghänt",
    "njugghäntas": "njugghänt",
    "njugghäntast": "njugghänt",
    "njugghäntaste": "njugghänt",
    "njugghäntastes": "njugghänt",
    "njugghäntasts": "njugghänt",
    "njugghänte": "njugghänt",
    "njugghäntes": "njugghänt",
    "njugghäntheten": "njugghänthet",
    "njugghänthetens": "njugghänthet",
    "njugghänthets": "njugghänthet",
    "njugghänts": "njugghänt",
    "njuggs": "njugg",
    "njuggt": "njugg",
    "njuggts": "njugg",
    "njur": "njure",
    "njurar": "njure",
    "njurarna": "njure",
    "njurarnas": "njure",
    "njurars": "njure",
    "njurbäckenen": "njurbäcken",
    "njurbäckenens": "njurbäcken",
    "njurbäckenet": "njurbäcken",
    "njurbäckenets": "njurbäcken",
    "njurbäckens": "njurbäcken",
    "njurbälten": "njurbälte",
    "njurbältena": "njurbälte",
    "njurbältenas": "njurbälte",
    "njurbältens": "njurbälte",
    "njurbältes": "njurbälte",
    "njurbältet": "njurbälte",
    "njurbältets": "njurbälte",
    "njuren": "njure",
    "njurens": "njure",
    "njures": "njure",
    "njurs": "njure",
    "njurskadan": "njurskada",
    "njurskadans": "njurskada",
    "njurskadas": "njurskada",
    "njurskade": "njurskada",
    "njurskador": "njurskada",
    "njurskadorna": "njurskada",
    "njurskadornas": "njurskada",
    "njurskadors": "njurskada",
    "njurstenar": "njursten",
    "njurstenarna": "njursten",
    "njurstenarnas": "njursten",
    "njurstenars": "njursten",
    "njurstenen": "njursten",
    "njurstenens": "njursten",
    "njurstens": "njursten",
    "njurtalgen": "njurtalg",
    "njurtalgens": "njurtalg",
    "njurtalgs": "njurtalg",
    "njurtransplantationen": "njurtransplantation",
    "njurtransplantationens": "njurtransplantation",
    "njurtransplantationer": "njurtransplantation",
    "njurtransplantationerna": "njurtransplantation",
    "njurtransplantationernas": "njurtransplantation",
    "njurtransplantationers": "njurtransplantation",
    "njurtransplantations": "njurtransplantation",
    "njut": "njuta",
    "njutande": "njuta",
    "njutanden": "njutande",
    "njutandena": "njutande",
    "njutandenas": "njutande",
    "njutandens": "njutande",
    "njutandes": "njutande",
    "njutandet": "njutande",
    "njutandets": "njutande",
    "njutas": "njuta",
    "njutbara": "njutbar",
    "njutbarare": "njutbar",
    "njutbarares": "njutbar",
    "njutbaras": "njutbar",
    "njutbarast": "njutbar",
    "njutbaraste": "njutbar",
    "njutbarastes": "njutbar",
    "njutbarasts": "njutbar",
    "njutbare": "njutbar",
    "njutbares": "njutbar",
    "njutbarheten": "njutbarhet",
    "njutbarhetens": "njutbarhet",
    "njutbarhets": "njutbarhet",
    "njutbars": "njutbar",
    "njutbart": "njutbar",
    "njutbarts": "njutbar",
    "njute": "njuta",
    "njuten": "njuta",
    "njutens": "njuta",
    "njuter": "njuta",
    "njutes": "njuta",
    "njutet": "njuta",
    "njutets": "njuta",
    "njutit": "njuta",
    "njutits": "njuta",
    "njutna": "njuta",
    "njutnas": "njuta",
    "njutne": "njuta",
    "njutnes": "njuta",
    "njutningar": "njutning",
    "njutningarna": "njutning",
    "njutningarnas": "njutning",
    "njutningars": "njutning",
    "njutningen": "njutning",
    "njutningens": "njutning",
    "njutnings": "njutning",
    "njutningsfilosofien": "njutningsfilosofi",
    "njutningsfilosofiens": "njutningsfilosofi",
    "njutningsfilosofin": "njutningsfilosofi",
    "njutningsfilosofins": "njutningsfilosofi",
    "njutningsfilosofis": "njutningsfilosofi",
    "njutningslystens": "njutningslysten",
    "njutningslystet": "njutningslysten",
    "njutningslystets": "njutningslysten",
    "njutningslystna": "njutningslysten",
    "njutningslystnaden": "njutningslystnad",
    "njutningslystnadens": "njutningslystnad",
    "njutningslystnader": "njutningslystnad",
    "njutningslystnaderna": "njutningslystnad",
    "njutningslystnadernas": "njutningslystnad",
    "njutningslystnaders": "njutningslystnad",
    "njutningslystnads": "njutningslystnad",
    "njutningslystnare": "njutningslysten",
    "njutningslystnares": "njutningslysten",
    "njutningslystnas": "njutningslysten",
    "njutningslystnast": "njutningslysten",
    "njutningslystnaste": "njutningslysten",
    "njutningslystnastes": "njutningslysten",
    "njutningslystnasts": "njutningslysten",
    "njutningslystne": "njutningslysten",
    "njutningslystnes": "njutningslysten",
    "njutningsmedels": "njutningsmedel",
    "njutningsmedlen": "njutningsmedel",
    "njutningsmedlens": "njutningsmedel",
    "njutningsmedlet": "njutningsmedel",
    "njutningsmedlets": "njutningsmedel",
    "njutningsmänniskan": "njutningsmänniska",
    "njutningsmänniskans": "njutningsmänniska",
    "njutningsmänniskas": "njutningsmänniska",
    "njutningsmännisko": "njutningsmänniska",
    "njutningsmänniskor": "njutningsmänniska",
    "njutningsmänniskorna": "njutningsmänniska",
    "njutningsmänniskornas": "njutningsmänniska",
    "njutningsmänniskors": "njutningsmänniska",
    "njutningsmässiga": "njutningsmässig",
    "njutningsmässigare": "njutningsmässig",
    "njutningsmässigares": "njutningsmässig",
    "njutningsmässigas": "njutningsmässig",
    "njutningsmässigast": "njutningsmässig",
    "njutningsmässigaste": "njutningsmässig",
    "njutningsmässigastes": "njutningsmässig",
    "njutningsmässigasts": "njutningsmässig",
    "njutningsmässige": "njutningsmässig",
    "njutningsmässiges": "njutningsmässig",
    "njutningsmässigs": "njutningsmässig",
    "njutningsmässigt": "njutningsmässig",
    "njutningsmässigts": "njutningsmässig",
    "njuts": "njuta",
    "njöt": "njuta",
    "njöte": "njuta",
    "njötes": "njuta",
    "njöts": "njuta",
    "noanamnen": "noanamn",
    "noanamnens": "noanamn",
    "noanamnet": "noanamn",
    "noanamnets": "noanamn",
    "noanamns": "noanamn",
    "noaorden": "noaord",
    "noaordens": "noaord",
    "noaordet": "noaord",
    "noaordets": "noaord",
    "noaords": "noaord",
    "noas": "noa",
    "nobb": "nobba",
    "nobbad": "nobba",
    "nobbade": "nobba",
    "nobbades": "nobba",
    "nobbads": "nobba",
    "nobbande": "nobba",
    "nobbanden": "nobbande",
    "nobbandena": "nobbande",
    "nobbandenas": "nobbande",
    "nobbandens": "nobbande",
    "nobbandes": "nobbande",
    "nobbandet": "nobbande",
    "nobbandets": "nobbande",
    "nobbar": "nobba",
    "nobbarna": "nobb",
    "nobbarnas": "nobb",
    "nobbars": "nobb",
    "nobbas": "nobba",
    "nobbat": "nobba",
    "nobbats": "nobba",
    "nobben": "nobb",
    "nobbens": "nobb",
    "nobbs": "nobb",
    "nobeliet": "nobelium",
    "nobeliets": "nobelium",
    "nobeliumet": "nobelium",
    "nobeliumets": "nobelium",
    "nobeliums": "nobelium",
    "nobelprisen": "nobelpris",
    "nobelprisens": "nobelpris",
    "nobelpriser": "nobelpris",
    "nobelpriserna": "nobelpris",
    "nobelprisernas": "nobelpris",
    "nobelprisers": "nobelpris",
    "nobelpriset": "nobelpris",
    "nobelprisets": "nobelpris",
    "nobelpristagar": "nobelpristagare",
    "nobelpristagaren": "nobelpristagare",
    "nobelpristagarens": "nobelpristagare",
    "nobelpristagares": "nobelpristagare",
    "nobelpristagarna": "nobelpristagare",
    "nobelpristagarnas": "nobelpristagare",
    "nobelt": "nobel",
    "nobelts": "nobel",
    "nobiliserad": "nobilisera",
    "nobiliserade": "nobilisera",
    "nobiliserades": "nobilisera",
    "nobiliserads": "nobilisera",
    "nobiliserande": "nobilisera",
    "nobiliseranden": "nobiliserande",
    "nobiliserandena": "nobiliserande",
    "nobiliserandenas": "nobiliserande",
    "nobiliserandens": "nobiliserande",
    "nobiliserandes": "nobiliserande",
    "nobiliserandet": "nobiliserande",
    "nobiliserandets": "nobiliserande",
    "nobiliserar": "nobilisera",
    "nobiliseras": "nobilisera",
    "nobiliserat": "nobilisera",
    "nobiliserats": "nobilisera",
    "nobiliserbara": "nobiliserbar",
    "nobiliserbarare": "nobiliserbar",
    "nobiliserbarares": "nobiliserbar",
    "nobiliserbaras": "nobiliserbar",
    "nobiliserbarast": "nobiliserbar",
    "nobiliserbaraste": "nobiliserbar",
    "nobiliserbarastes": "nobiliserbar",
    "nobiliserbarasts": "nobiliserbar",
    "nobiliserbare": "nobiliserbar",
    "nobiliserbares": "nobiliserbar",
    "nobiliserbarheten": "nobiliserbarhet",
    "nobiliserbarhetens": "nobiliserbarhet",
    "nobiliserbarhets": "nobiliserbarhet",
    "nobiliserbars": "nobiliserbar",
    "nobiliserbart": "nobiliserbar",
    "nobiliserbarts": "nobiliserbar",
    "nobiliseringar": "nobilisering",
    "nobiliseringarna": "nobilisering",
    "nobiliseringarnas": "nobilisering",
    "nobiliseringars": "nobilisering",
    "nobiliseringen": "nobilisering",
    "nobiliseringens": "nobilisering",
    "nobiliserings": "nobilisering",
    "nobla": "nobel",
    "noblare": "nobel",
    "noblares": "nobel",
    "noblas": "nobel",
    "noblast": "nobel",
    "noblaste": "nobel",
    "noblastes": "nobel",
    "noblasts": "nobel",
    "noble": "nobel",
    "nobles": "nobel",
    "noblessen": "nobless",
    "noblessens": "nobless",
    "nock": "nocka",
    "nockad": "nocka",
    "nockade": "nocka",
    "nockades": "nocka",
    "nockads": "nocka",
    "nockande": "nocka",
    "nockanden": "nockande",
    "nockandena": "nockande",
    "nockandenas": "nockande",
    "nockandens": "nockande",
    "nockandes": "nockande",
    "nockandet": "nockande",
    "nockandets": "nockande",
    "nockar": "nocka",
    "nockarna": "nock",
    "nockarnas": "nock",
    "nockars": "nock",
    "nockas": "nocka",
    "nockat": "nocka",
    "nockats": "nocka",
    "nocken": "nock",
    "nockens": "nock",
    "nockouten": "nockout",
    "nockoutens": "nockout",
    "nockouter": "nockout",
    "nockouterna": "nockout",
    "nockouternas": "nockout",
    "nockouters": "nockout",
    "nockouts": "nockout",
    "nocks": "nock",
    "nocturnen": "nocturne",
    "nocturnens": "nocturne",
    "nocturner": "nocturne",
    "nocturnerna": "nocturne",
    "nocturnernas": "nocturne",
    "nocturners": "nocturne",
    "nocturnes": "nocturne",
    "noden": "nod",
    "nodens": "nod",
    "noder": "nod",
    "noderna": "nod",
    "nodernas": "nod",
    "noders": "nod",
    "nods": "nod",
    "noggranna": "noggrann",
    "noggrannare": "noggrann",
    "noggrannares": "noggrann",
    "noggrannas": "noggrann",
    "noggrannast": "noggrann",
    "noggrannaste": "noggrann",
    "noggrannastes": "noggrann",
    "noggrannasts": "noggrann",
    "noggranne": "noggrann",
    "noggrannes": "noggrann",
    "noggrannheten": "noggrannhet",
    "noggrannhetens": "noggrannhet",
    "noggrannheter": "noggrannhet",
    "noggrannheterna": "noggrannhet",
    "noggrannheternas": "noggrannhet",
    "noggrannheters": "noggrannhet",
    "noggrannhets": "noggrannhet",
    "noggranns": "noggrann",
    "noggrant": "noggrann",
    "noggrants": "noggrann",
    "nogräknade": "nogräknad",
    "nogräknades": "nogräknad",
    "nogräknads": "nogräknad",
    "nogräknat": "nogräknad",
    "nogräknats": "nogräknad",
    "noj": "noja",
    "nojan": "noja",
    "nojans": "noja",
    "nojas": "noja",
    "noje": "noja",
    "nojor": "noja",
    "nojorna": "noja",
    "nojornas": "noja",
    "nojors": "noja",
    "nojs": "noja",
    "nojsade": "nojsa",
    "nojsades": "nojsa",
    "nojsande": "nojsa",
    "nojsanden": "nojsande",
    "nojsandena": "nojsande",
    "nojsandenas": "nojsande",
    "nojsandens": "nojsande",
    "nojsandes": "nojsande",
    "nojsandet": "nojsande",
    "nojsandets": "nojsande",
    "nojsar": "nojsa",
    "nojsas": "nojsa",
    "nojsat": "nojsa",
    "nojsats": "nojsa",
    "nojset": "nojs",
    "nojsets": "nojs",
    "nokturnen": "nokturn",
    "nokturnens": "nokturn",
    "nokturner": "nokturn",
    "nokturnerna": "nokturn",
    "nokturnernas": "nokturn",
    "nokturners": "nokturn",
    "nokturns": "nokturn",
    "noll": "nolla",
    "nollad": "nolla",
    "nollade": "nolla",
    "nollades": "nolla",
    "nollads": "nolla",
    "nollan": "nolla",
    "nollande": "nolla",
    "nollanden": "nollande",
    "nollandena": "nollande",
    "nollandenas": "nollande",
    "nollandens": "nollande",
    "nollandes": "nollande",
    "nollandet": "nollande",
    "nollandets": "nollande",
    "nollans": "nolla",
    "nollar": "nolla",
    "nollas": "nolla",
    "nollat": "nolla",
    "nollats": "nolla",
    "nollcirkeln": "nollcirkel",
    "nollcirkelns": "nollcirkel",
    "nollcirkels": "nollcirkel",
    "nollcirklar": "nollcirkel",
    "nollcirklarna": "nollcirkel",
    "nollcirklarnas": "nollcirkel",
    "nollcirklars": "nollcirkel",
    "nolle": "nolla",
    "nolledningar": "nolledning",
    "nolledningarna": "nolledning",
    "nolledningarnas": "nolledning",
    "nolledningars": "nolledning",
    "nolledningen": "nolledning",
    "nolledningens": "nolledning",
    "nollednings": "nolledning",
    "nollkorrekturen": "nollkorrektur",
    "nollkorrekturens": "nollkorrektur",
    "nollkorrekturet": "nollkorrektur",
    "nollkorrekturets": "nollkorrektur",
    "nollkorrekturs": "nollkorrektur",
    "nollmeridianen": "nollmeridian",
    "nollmeridianens": "nollmeridian",
    "nollmeridians": "nollmeridian",
    "nollningar": "nollning",
    "nollningarna": "nollning",
    "nollningarnas": "nollning",
    "nollningars": "nollning",
    "nollningen": "nollning",
    "nollningens": "nollning",
    "nollnings": "nollning",
    "nollnoll-talet": "nollnoll-tal",
    "nollnoll-talets": "nollnoll-tal",
    "nollnoll-tals": "nollnoll-tal",
    "nollnolltalet": "nollnolltal",
    "nollnolltalets": "nollnolltal",
    "nollnolltals": "nollnolltal",
    "nollor": "nolla",
    "nollorna": "nolla",
    "nollornas": "nolla",
    "nollors": "nolla",
    "nollplanen": "nollplan",
    "nollplanens": "nollplan",
    "nollplanet": "nollplan",
    "nollplanets": "nollplan",
    "nollplans": "nollplan",
    "nollpunkten": "nollpunkt",
    "nollpunktens": "nollpunkt",
    "nollpunkter": "nollpunkt",
    "nollpunkterna": "nollpunkt",
    "nollpunkternas": "nollpunkt",
    "nollpunkters": "nollpunkt",
    "nollpunkts": "nollpunkt",
    "nolls": "nolla",
    "nollspanten": "nollspant",
    "nollspantens": "nollspant",
    "nollspantet": "nollspant",
    "nollspantets": "nollspant",
    "nollspants": "nollspant",
    "nollspänningar": "nollspänning",
    "nollspänningarna": "nollspänning",
    "nollspänningarnas": "nollspänning",
    "nollspänningars": "nollspänning",
    "nollspänningen": "nollspänning",
    "nollspänningens": "nollspänning",
    "nollspännings": "nollspänning",
    "nollställ": "nollställa",
    "nollställande": "nollställa",
    "nollställanden": "nollställande",
    "nollställandena": "nollställande",
    "nollställandenas": "nollställande",
    "nollställandens": "nollställande",
    "nollställandes": "nollställande",
    "nollställandet": "nollställande",
    "nollställandets": "nollställande",
    "nollställas": "nollställa",
    "nollställd": "nollställa",
    "nollställda": "nollställa",
    "nollställdas": "nollställa",
    "nollställde": "nollställa",
    "nollställdes": "nollställa",
    "nollställds": "nollställa",
    "nollställen": "nollställe",
    "nollställena": "nollställe",
    "nollställenas": "nollställe",
    "nollställens": "nollställe",
    "nollställer": "nollställa",
    "nollställes": "nollställe",
    "nollstället": "nollställe",
    "nollställets": "nollställe",
    "nollställs": "nollställa",
    "nollställt": "nollställa",
    "nollställts": "nollställa",
    "nolltax": "nolltaxa",
    "nolltaxan": "nolltaxa",
    "nolltaxans": "nolltaxa",
    "nolltaxas": "nolltaxa",
    "nolltaxe": "nolltaxa",
    "nolltaxerade": "nolltaxera",
    "nolltaxerades": "nolltaxera",
    "nolltaxerande": "nolltaxera",
    "nolltaxeranden": "nolltaxerande",
    "nolltaxerandena": "nolltaxerande",
    "nolltaxerandenas": "nolltaxerande",
    "nolltaxerandens": "nolltaxerande",
    "nolltaxerandes": "nolltaxerande",
    "nolltaxerandet": "nolltaxerande",
    "nolltaxerandets": "nolltaxerande",
    "nolltaxerar": "nolltaxerare",
    "nolltaxeraren": "nolltaxerare",
    "nolltaxerarens": "nolltaxerare",
    "nolltaxerares": "nolltaxerare",
    "nolltaxerarna": "nolltaxerare",
    "nolltaxerarnas": "nolltaxerare",
    "nolltaxeras": "nolltaxera",
    "nolltaxerat": "nolltaxera",
    "nolltaxerats": "nolltaxera",
    "nolltaxeringar": "nolltaxering",
    "nolltaxeringarna": "nolltaxering",
    "nolltaxeringarnas": "nolltaxering",
    "nolltaxeringars": "nolltaxering",
    "nolltaxeringen": "nolltaxering",
    "nolltaxeringens": "nolltaxering",
    "nolltaxerings": "nolltaxering",
    "nolltaxor": "nolltaxa",
    "nolltaxorna": "nolltaxa",
    "nolltaxornas": "nolltaxa",
    "nolltaxors": "nolltaxa",
    "nollte": "noll",
    "nolltes": "noll",
    "nolltillväxten": "nolltillväxt",
    "nolltillväxtens": "nolltillväxt",
    "nolltillväxts": "nolltillväxt",
    "nolltoleransen": "nolltolerans",
    "nolltoleransens": "nolltolerans",
    "nollutsläppen": "nollutsläpp",
    "nollutsläppens": "nollutsläpp",
    "nollutsläppet": "nollutsläpp",
    "nollutsläppets": "nollutsläpp",
    "nollutsläpps": "nollutsläpp",
    "nollägen": "nolläge",
    "nollägena": "nolläge",
    "nollägenas": "nolläge",
    "nollägens": "nolläge",
    "nolläges": "nolläge",
    "nolläget": "nolläge",
    "nollägets": "nolläge",
    "noltiga": "noltig",
    "noltigare": "noltig",
    "noltigares": "noltig",
    "noltigas": "noltig",
    "noltigast": "noltig",
    "noltigaste": "noltig",
    "noltigastes": "noltig",
    "noltigasts": "noltig",
    "noltige": "noltig",
    "noltiges": "noltig",
    "noltigheten": "noltighet",
    "noltighetens": "noltighet",
    "noltighets": "noltighet",
    "noltigs": "noltig",
    "noltigt": "noltig",
    "noltigts": "noltig",
    "nomaden": "nomad",
    "nomadens": "nomad",
    "nomader": "nomad",
    "nomaderna": "nomad",
    "nomadernas": "nomad",
    "nomaders": "nomad",
    "nomadfamiljen": "nomadfamilj",
    "nomadfamiljens": "nomadfamilj",
    "nomadfamiljer": "nomadfamilj",
    "nomadfamiljerna": "nomadfamilj",
    "nomadfamiljernas": "nomadfamilj",
    "nomadfamiljers": "nomadfamilj",
    "nomadfamiljs": "nomadfamilj",
    "nomadfolken": "nomadfolk",
    "nomadfolkens": "nomadfolk",
    "nomadfolket": "nomadfolk",
    "nomadfolkets": "nomadfolk",
    "nomadfolks": "nomadfolk",
    "nomadiserade": "nomadisera",
    "nomadiserades": "nomadisera",
    "nomadiserande": "nomadisera",
    "nomadiseranden": "nomadiserande",
    "nomadiserandena": "nomadiserande",
    "nomadiserandenas": "nomadiserande",
    "nomadiserandens": "nomadiserande",
    "nomadiserandes": "nomadiserande",
    "nomadiserandet": "nomadiserande",
    "nomadiserandets": "nomadiserande",
    "nomadiserar": "nomadisera",
    "nomadiseras": "nomadisera",
    "nomadiserat": "nomadisera",
    "nomadiserats": "nomadisera",
    "nomadiseringar": "nomadisering",
    "nomadiseringarna": "nomadisering",
    "nomadiseringarnas": "nomadisering",
    "nomadiseringars": "nomadisering",
    "nomadiseringen": "nomadisering",
    "nomadiseringens": "nomadisering",
    "nomadiserings": "nomadisering",
    "nomadiska": "nomadisk",
    "nomadiskare": "nomadisk",
    "nomadiskares": "nomadisk",
    "nomadiskas": "nomadisk",
    "nomadiskast": "nomadisk",
    "nomadiskaste": "nomadisk",
    "nomadiskastes": "nomadisk",
    "nomadiskasts": "nomadisk",
    "nomadiske": "nomadisk",
    "nomadiskes": "nomadisk",
    "nomadisks": "nomadisk",
    "nomadiskt": "nomadisk",
    "nomadiskts": "nomadisk",
    "nomadlivet": "nomadliv",
    "nomadlivets": "nomadliv",
    "nomadlivs": "nomadliv",
    "nomads": "nomad",
    "nomadskolan": "nomadskola",
    "nomadskolans": "nomadskola",
    "nomadskolas": "nomadskola",
    "nomadskole": "nomadskola",
    "nomadskolor": "nomadskola",
    "nomadskolorna": "nomadskola",
    "nomadskolornas": "nomadskola",
    "nomadskolors": "nomadskola",
    "nomadsystemen": "nomadsystem",
    "nomadsystemens": "nomadsystem",
    "nomadsystemet": "nomadsystem",
    "nomadsystemets": "nomadsystem",
    "nomadsystems": "nomadsystem",
    "nomenen": "nomen",
    "nomenens": "nomen",
    "nomenet": "nomen",
    "nomenets": "nomen",
    "nomenklaturen": "nomenklatur",
    "nomenklaturens": "nomenklatur",
    "nomenklaturer": "nomenklatur",
    "nomenklaturerna": "nomenklatur",
    "nomenklaturernas": "nomenklatur",
    "nomenklaturers": "nomenklatur",
    "nomenklaturs": "nomenklatur",
    "nomens": "nomen",
    "nomina": "nomen",
    "nominala": "nominal",
    "nominalare": "nominal",
    "nominalares": "nominal",
    "nominalas": "nominal",
    "nominalast": "nominal",
    "nominalaste": "nominal",
    "nominalastes": "nominal",
    "nominalasts": "nominal",
    "nominale": "nominal",
    "nominales": "nominal",
    "nominalismen": "nominalism",
    "nominalismens": "nominalism",
    "nominalismer": "nominalism",
    "nominalismerna": "nominalism",
    "nominalismernas": "nominalism",
    "nominalismers": "nominalism",
    "nominalisms": "nominalism",
    "nominalisten": "nominalist",
    "nominalistens": "nominalist",
    "nominalister": "nominalist",
    "nominalisterna": "nominalist",
    "nominalisternas": "nominalist",
    "nominalisters": "nominalist",
    "nominalistiska": "nominalistisk",
    "nominalistiskare": "nominalistisk",
    "nominalistiskares": "nominalistisk",
    "nominalistiskas": "nominalistisk",
    "nominalistiskast": "nominalistisk",
    "nominalistiskaste": "nominalistisk",
    "nominalistiskastes": "nominalistisk",
    "nominalistiskasts": "nominalistisk",
    "nominalistiske": "nominalistisk",
    "nominalistiskes": "nominalistisk",
    "nominalistisks": "nominalistisk",
    "nominalistiskt": "nominalistisk",
    "nominalistiskts": "nominalistisk",
    "nominalists": "nominalist",
    "nominalkatalogen": "nominalkatalog",
    "nominalkatalogens": "nominalkatalog",
    "nominalkataloger": "nominalkatalog",
    "nominalkatalogerna": "nominalkatalog",
    "nominalkatalogernas": "nominalkatalog",
    "nominalkatalogers": "nominalkatalog",
    "nominalkatalogs": "nominalkatalog",
    "nominallönen": "nominallön",
    "nominallönens": "nominallön",
    "nominallöner": "nominallön",
    "nominallönerna": "nominallön",
    "nominallönernas": "nominallön",
    "nominallöners": "nominallön",
    "nominallöns": "nominallön",
    "nominals": "nominal",
    "nominalt": "nominal",
    "nominalts": "nominal",
    "nominalvärden": "nominalvärde",
    "nominalvärdena": "nominalvärde",
    "nominalvärdenas": "nominalvärde",
    "nominalvärdens": "nominalvärde",
    "nominalvärdes": "nominalvärde",
    "nominalvärdet": "nominalvärde",
    "nominalvärdets": "nominalvärde",
    "nominas": "nomen",
    "nominativen": "nominativ",
    "nominativens": "nominativ",
    "nominativer": "nominativ",
    "nominativerna": "nominativ",
    "nominativernas": "nominativ",
    "nominativers": "nominativ",
    "nominativs": "nominativ",
    "nominativsubjekten": "nominativsubjekt",
    "nominativsubjektens": "nominativsubjekt",
    "nominativsubjektet": "nominativsubjekt",
    "nominativsubjektets": "nominativsubjekt",
    "nominativsubjekts": "nominativsubjekt",
    "nominella": "nominell",
    "nominellare": "nominell",
    "nominellares": "nominell",
    "nominellas": "nominell",
    "nominellast": "nominell",
    "nominellaste": "nominell",
    "nominellastes": "nominell",
    "nominellasts": "nominell",
    "nominelle": "nominell",
    "nominelles": "nominell",
    "nominells": "nominell",
    "nominellt": "nominell",
    "nominellts": "nominell",
    "nominerad": "nominera",
    "nominerade": "nominera",
    "nominerades": "nominera",
    "nominerads": "nominera",
    "nominerande": "nominera",
    "nomineranden": "nominerande",
    "nominerandena": "nominerande",
    "nominerandenas": "nominerande",
    "nominerandens": "nominerande",
    "nominerandes": "nominerande",
    "nominerandet": "nominerande",
    "nominerandets": "nominerande",
    "nominerar": "nominera",
    "nomineras": "nominera",
    "nominerat": "nominera",
    "nominerats": "nominera",
    "nominerbara": "nominerbar",
    "nominerbarare": "nominerbar",
    "nominerbarares": "nominerbar",
    "nominerbaras": "nominerbar",
    "nominerbarast": "nominerbar",
    "nominerbaraste": "nominerbar",
    "nominerbarastes": "nominerbar",
    "nominerbarasts": "nominerbar",
    "nominerbare": "nominerbar",
    "nominerbares": "nominerbar",
    "nominerbarheten": "nominerbarhet",
    "nominerbarhetens": "nominerbarhet",
    "nominerbarhets": "nominerbarhet",
    "nominerbars": "nominerbar",
    "nominerbart": "nominerbar",
    "nominerbarts": "nominerbar",
    "nomineringar": "nominering",
    "nomineringarna": "nominering",
    "nomineringarnas": "nominering",
    "nomineringars": "nominering",
    "nomineringen": "nominering",
    "nomineringens": "nominering",
    "nominerings": "nominering",
    "nomografien": "nomografi",
    "nomografiens": "nomografi",
    "nomografin": "nomografi",
    "nomografins": "nomografi",
    "nomografis": "nomografi",
    "nomogrammen": "nomogram",
    "nomogrammens": "nomogram",
    "nomogrammet": "nomogram",
    "nomogrammets": "nomogram",
    "nomograms": "nomogram",
    "non": "nona",
    "nonaggressionen": "nonaggression",
    "nonaggressionens": "nonaggression",
    "nonaggressioner": "nonaggression",
    "nonaggressionerna": "nonaggression",
    "nonaggressionernas": "nonaggression",
    "nonaggressioners": "nonaggression",
    "nonaggressions": "nonaggression",
    "nonaggressionsfördragen": "nonaggressionsfördrag",
    "nonaggressionsfördragens": "nonaggressionsfördrag",
    "nonaggressionsfördraget": "nonaggressionsfördrag",
    "nonaggressionsfördragets": "nonaggressionsfördrag",
    "nonaggressionsfördrags": "nonaggressionsfördrag",
    "nonan": "nona",
    "nonans": "nona",
    "nonas": "nona",
    "nonchalansen": "nonchalans",
    "nonchalansens": "nonchalans",
    "nonchalanta": "nonchalant",
    "nonchalantare": "nonchalant",
    "nonchalantares": "nonchalant",
    "nonchalantas": "nonchalant",
    "nonchalantast": "nonchalant",
    "nonchalantaste": "nonchalant",
    "nonchalantastes": "nonchalant",
    "nonchalantasts": "nonchalant",
    "nonchalante": "nonchalant",
    "nonchalantes": "nonchalant",
    "nonchalants": "nonchalant",
    "nonchalerad": "nonchalera",
    "nonchalerade": "nonchalera",
    "nonchalerades": "nonchalera",
    "nonchalerads": "nonchalera",
    "nonchalerande": "nonchalera",
    "nonchaleranden": "nonchalerande",
    "nonchalerandena": "nonchalerande",
    "nonchalerandenas": "nonchalerande",
    "nonchalerandens": "nonchalerande",
    "nonchalerandes": "nonchalerande",
    "nonchalerandet": "nonchalerande",
    "nonchalerandets": "nonchalerande",
    "nonchalerar": "nonchalera",
    "nonchaleras": "nonchalera",
    "nonchalerat": "nonchalera",
    "nonchalerats": "nonchalera",
    "nonchalerbara": "nonchalerbar",
    "nonchalerbarare": "nonchalerbar",
    "nonchalerbarares": "nonchalerbar",
    "nonchalerbaras": "nonchalerbar",
    "nonchalerbarast": "nonchalerbar",
    "nonchalerbaraste": "nonchalerbar",
    "nonchalerbarastes": "nonchalerbar",
    "nonchalerbarasts": "nonchalerbar",
    "nonchalerbare": "nonchalerbar",
    "nonchalerbares": "nonchalerbar",
    "nonchalerbarheten": "nonchalerbarhet",
    "nonchalerbarhetens": "nonchalerbarhet",
    "nonchalerbarhets": "nonchalerbarhet",
    "nonchalerbars": "nonchalerbar",
    "nonchalerbart": "nonchalerbar",
    "nonchalerbarts": "nonchalerbar",
    "nonchaleringar": "nonchalering",
    "nonchaleringarna": "nonchalering",
    "nonchaleringarnas": "nonchalering",
    "nonchaleringars": "nonchalering",
    "nonchaleringen": "nonchalering",
    "nonchaleringens": "nonchalering",
    "nonchalerings": "nonchalering",
    "none": "nona",
    "nonfigurativa": "nonfigurativ",
    "nonfigurativare": "nonfigurativ",
    "nonfigurativares": "nonfigurativ",
    "nonfigurativas": "nonfigurativ",
    "nonfigurativast": "nonfigurativ",
    "nonfigurativaste": "nonfigurativ",
    "nonfigurativastes": "nonfigurativ",
    "nonfigurativasts": "nonfigurativ",
    "nonfigurative": "nonfigurativ",
    "nonfiguratives": "nonfigurativ",
    "nonfigurativs": "nonfigurativ",
    "nonfigurativt": "nonfigurativ",
    "nonfigurativts": "nonfigurativ",
    "nonien": "nonie",
    "noniens": "nonie",
    "nonier": "nonie",
    "nonierna": "nonie",
    "noniernas": "nonie",
    "noniers": "nonie",
    "nonies": "nonie",
    "noninterventionen": "nonintervention",
    "noninterventionens": "nonintervention",
    "noninterventioner": "nonintervention",
    "noninterventionerna": "nonintervention",
    "noninterventionernas": "nonintervention",
    "noninterventioners": "nonintervention",
    "noninterventions": "nonintervention",
    "nonkombattanten": "nonkombattant",
    "nonkombattantens": "nonkombattant",
    "nonkombattanter": "nonkombattant",
    "nonkombattanterna": "nonkombattant",
    "nonkombattanternas": "nonkombattant",
    "nonkombattanters": "nonkombattant",
    "nonkombattants": "nonkombattant",
    "nonkonformismen": "nonkonformism",
    "nonkonformismens": "nonkonformism",
    "nonkonformismer": "nonkonformism",
    "nonkonformismerna": "nonkonformism",
    "nonkonformismernas": "nonkonformism",
    "nonkonformismers": "nonkonformism",
    "nonkonformisms": "nonkonformism",
    "nonkonformisten": "nonkonformist",
    "nonkonformistens": "nonkonformist",
    "nonkonformister": "nonkonformist",
    "nonkonformisterna": "nonkonformist",
    "nonkonformisternas": "nonkonformist",
    "nonkonformisters": "nonkonformist",
    "nonkonformistiska": "nonkonformistisk",
    "nonkonformistiskas": "nonkonformistisk",
    "nonkonformistiske": "nonkonformistisk",
    "nonkonformistiskes": "nonkonformistisk",
    "nonkonformistisks": "nonkonformistisk",
    "nonkonformistiskt": "nonkonformistisk",
    "nonkonformistiskts": "nonkonformistisk",
    "nonkonformists": "nonkonformist",
    "nonor": "nona",
    "nonorna": "nona",
    "nonornas": "nona",
    "nonors": "nona",
    "nonpareilen": "nonpareil",
    "nonpareilens": "nonpareil",
    "nonpareillen": "nonpareille",
    "nonpareillens": "nonpareille",
    "nonpareilles": "nonpareille",
    "nonpareils": "nonpareil",
    "nons": "nona",
    "nonsensen": "nonsens",
    "nonsensens": "nonsens",
    "nonsenset": "nonsens",
    "nonsensets": "nonsens",
    "nonsensversen": "nonsensvers",
    "nonsensversens": "nonsensvers",
    "nonsensverser": "nonsensvers",
    "nonsensverserna": "nonsensvers",
    "nonsensversernas": "nonsensvers",
    "nonsensversers": "nonsensvers",
    "nonstopflygen": "nonstopflyg",
    "nonstopflygens": "nonstopflyg",
    "nonstopflyget": "nonstopflyg",
    "nonstopflygets": "nonstopflyg",
    "nonstopflygs": "nonstopflyg",
    "nopp": "noppa",
    "noppad": "noppa",
    "noppade": "noppa",
    "noppades": "noppa",
    "noppads": "noppa",
    "noppan": "noppa",
    "noppande": "noppa",
    "noppanden": "noppande",
    "noppandena": "noppande",
    "noppandenas": "noppande",
    "noppandens": "noppande",
    "noppandes": "noppande",
    "noppandet": "noppande",
    "noppandets": "noppande",
    "noppans": "noppa",
    "noppar": "noppa",
    "nopparna": "nopp",
    "nopparnas": "nopp",
    "noppars": "nopp",
    "noppas": "noppa",
    "noppat": "noppa",
    "noppats": "noppa",
    "noppe": "noppa",
    "noppen": "nopp",
    "noppens": "nopp",
    "noppiga": "noppig",
    "noppigare": "noppig",
    "noppigares": "noppig",
    "noppigas": "noppig",
    "noppigast": "noppig",
    "noppigaste": "noppig",
    "noppigastes": "noppig",
    "noppigasts": "noppig",
    "noppige": "noppig",
    "noppiges": "noppig",
    "noppigheten": "noppighet",
    "noppighetens": "noppighet",
    "noppighets": "noppighet",
    "noppigs": "noppig",
    "noppigt": "noppig",
    "noppigts": "noppig",
    "noppor": "noppa",
    "nopporna": "noppa",
    "noppornas": "noppa",
    "noppors": "noppa",
    "noppr": "noppra",
    "noppran": "noppra",
    "nopprans": "noppra",
    "noppras": "noppra",
    "noppre": "noppra",
    "noppriga": "nopprig",
    "nopprigare": "nopprig",
    "nopprigares": "nopprig",
    "nopprigas": "nopprig",
    "nopprigast": "nopprig",
    "nopprigaste": "nopprig",
    "nopprigastes": "nopprig",
    "nopprigasts": "nopprig",
    "nopprige": "nopprig",
    "noppriges": "nopprig",
    "nopprigs": "nopprig",
    "nopprigt": "nopprig",
    "nopprigts": "nopprig",
    "noppror": "noppra",
    "nopprorna": "noppra",
    "nopprornas": "noppra",
    "nopprors": "noppra",
    "nopprs": "noppra",
    "nopps": "noppa",
    "noradrenalinen": "noradrenalin",
    "noradrenalinens": "noradrenalin",
    "noradrenaliner": "noradrenalin",
    "noradrenalinerna": "noradrenalin",
    "noradrenalinernas": "noradrenalin",
    "noradrenaliners": "noradrenalin",
    "noradrenalinet": "noradrenalin",
    "noradrenalinets": "noradrenalin",
    "noradrenalins": "noradrenalin",
    "nord-sydliga": "nord-sydlig",
    "nord-sydligare": "nord-sydlig",
    "nord-sydligares": "nord-sydlig",
    "nord-sydligas": "nord-sydlig",
    "nord-sydligast": "nord-sydlig",
    "nord-sydligaste": "nord-sydlig",
    "nord-sydligastes": "nord-sydlig",
    "nord-sydligasts": "nord-sydlig",
    "nord-sydlige": "nord-sydlig",
    "nord-sydliges": "nord-sydlig",
    "nord-sydligs": "nord-sydlig",
    "nord-sydligt": "nord-sydlig",
    "nord-sydligts": "nord-sydlig",
    "nordafrikanska": "nordafrikansk",
    "nordafrikanskare": "nordafrikansk",
    "nordafrikanskares": "nordafrikansk",
    "nordafrikanskas": "nordafrikansk",
    "nordafrikanskast": "nordafrikansk",
    "nordafrikanskaste": "nordafrikansk",
    "nordafrikanskastes": "nordafrikansk",
    "nordafrikanskasts": "nordafrikansk",
    "nordafrikanske": "nordafrikansk",
    "nordafrikanskes": "nordafrikansk",
    "nordafrikansks": "nordafrikansk",
    "nordafrikanskt": "nordafrikansk",
    "nordafrikanskts": "nordafrikansk",
    "nordamerikanen": "nordamerikan",
    "nordamerikanens": "nordamerikan",
    "nordamerikaner": "nordamerikan",
    "nordamerikanerna": "nordamerikan",
    "nordamerikanernas": "nordamerikan",
    "nordamerikaners": "nordamerikan",
    "nordamerikans": "nordamerikan",
    "nordamerikanska": "nordamerikansk",
    "nordamerikanskare": "nordamerikansk",
    "nordamerikanskares": "nordamerikansk",
    "nordamerikanskas": "nordamerikansk",
    "nordamerikanskast": "nordamerikansk",
    "nordamerikanskaste": "nordamerikansk",
    "nordamerikanskastes": "nordamerikansk",
    "nordamerikanskasts": "nordamerikansk",
    "nordamerikanske": "nordamerikansk",
    "nordamerikanskes": "nordamerikansk",
    "nordamerikansks": "nordamerikansk",
    "nordamerikanskt": "nordamerikansk",
    "nordamerikanskts": "nordamerikansk",
    "nordanlanden": "nordanland",
    "nordanlandens": "nordanland",
    "nordanlandet": "nordanland",
    "nordanlandets": "nordanland",
    "nordanlands": "nordanland",
    "nordans": "nordan",
    "nordanskogs": "nordanskog",
    "nordanvindar": "nordanvind",
    "nordanvindarna": "nordanvind",
    "nordanvindarnas": "nordanvind",
    "nordanvindars": "nordanvind",
    "nordanvinden": "nordanvind",
    "nordanvindens": "nordanvind",
    "nordanvinds": "nordanvind",
    "nordbon": "nordbo",
    "nordbons": "nordbo",
    "nordbor": "nordbo",
    "nordborna": "nordbo",
    "nordbornas": "nordbo",
    "nordbors": "nordbo",
    "nordbos": "nordbo",
    "norden": "nord",
    "nordens": "nord",
    "nordgränsen": "nordgräns",
    "nordgränsens": "nordgräns",
    "nordgränser": "nordgräns",
    "nordgränserna": "nordgräns",
    "nordgränsernas": "nordgräns",
    "nordgränsers": "nordgräns",
    "nordiska": "nordisk",
    "nordiskare": "nordisk",
    "nordiskares": "nordisk",
    "nordiskas": "nordisk",
    "nordiskast": "nordisk",
    "nordiskaste": "nordisk",
    "nordiskastes": "nordisk",
    "nordiskasts": "nordisk",
    "nordiske": "nordisk",
    "nordiskes": "nordisk",
    "nordisks": "nordisk",
    "nordiskt": "nordisk",
    "nordiskts": "nordisk",
    "nordismen": "nordism",
    "nordismens": "nordism",
    "nordismer": "nordism",
    "nordismerna": "nordism",
    "nordismernas": "nordism",
    "nordismers": "nordism",
    "nordisms": "nordism",
    "nordisten": "nordist",
    "nordistens": "nordist",
    "nordister": "nordist",
    "nordisterna": "nordist",
    "nordisternas": "nordist",
    "nordisters": "nordist",
    "nordistiska": "nordistisk",
    "nordistiskas": "nordistisk",
    "nordistiske": "nordistisk",
    "nordistiskes": "nordistisk",
    "nordistisks": "nordistisk",
    "nordistiskt": "nordistisk",
    "nordistiskts": "nordistisk",
    "nordists": "nordist",
    "nordjemeniten": "nordjemenit",
    "nordjemenitens": "nordjemenit",
    "nordjemeniter": "nordjemenit",
    "nordjemeniterna": "nordjemenit",
    "nordjemeniternas": "nordjemenit",
    "nordjemeniters": "nordjemenit",
    "nordjemenits": "nordjemenit",
    "nordkoreanen": "nordkorean",
    "nordkoreanens": "nordkorean",
    "nordkoreaner": "nordkorean",
    "nordkoreanerna": "nordkorean",
    "nordkoreanernas": "nordkorean",
    "nordkoreaners": "nordkorean",
    "nordkoreans": "nordkorean",
    "nordkoreanska": "nordkoreansk",
    "nordkoreanskan": "nordkoreanska",
    "nordkoreanskans": "nordkoreanska",
    "nordkoreanskare": "nordkoreansk",
    "nordkoreanskares": "nordkoreansk",
    "nordkoreanskas": "nordkoreanska",
    "nordkoreanskast": "nordkoreansk",
    "nordkoreanskaste": "nordkoreansk",
    "nordkoreanskastes": "nordkoreansk",
    "nordkoreanskasts": "nordkoreansk",
    "nordkoreanske": "nordkoreanska",
    "nordkoreanskes": "nordkoreansk",
    "nordkoreanskor": "nordkoreanska",
    "nordkoreanskorna": "nordkoreanska",
    "nordkoreanskornas": "nordkoreanska",
    "nordkoreanskors": "nordkoreanska",
    "nordkoreansks": "nordkoreansk",
    "nordkoreanskt": "nordkoreansk",
    "nordkoreanskts": "nordkoreansk",
    "nordliga": "nordlig",
    "nordligare": "nordlig",
    "nordligares": "nordlig",
    "nordligas": "nordlig",
    "nordligast": "nordlig",
    "nordligaste": "nordlig",
    "nordligastes": "nordlig",
    "nordligasts": "nordlig",
    "nordlige": "nordlig",
    "nordliges": "nordlig",
    "nordligs": "nordlig",
    "nordligt": "nordlig",
    "nordligts": "nordlig",
    "nordmannen": "nordman",
    "nordmannens": "nordman",
    "nordmans": "nordman",
    "nordmän": "nordman",
    "nordmännen": "nordman",
    "nordmännens": "nordman",
    "nordmäns": "nordman",
    "nordosten": "nordost",
    "nordostens": "nordost",
    "nordostpassagen": "nordostpassage",
    "nordostpassagens": "nordostpassage",
    "nordostpassages": "nordostpassage",
    "nordosts": "nordost",
    "nordpolen": "nordpol",
    "nordpolens": "nordpol",
    "nordpoler": "nordpol",
    "nordpolerna": "nordpol",
    "nordpolernas": "nordpol",
    "nordpolers": "nordpol",
    "nordpols": "nordpol",
    "nords": "nord",
    "nordsidan": "nordsida",
    "nordsidans": "nordsida",
    "nordsidas": "nordsida",
    "nordside": "nordsida",
    "nordsides": "nordsida",
    "nordsidor": "nordsida",
    "nordsidorna": "nordsida",
    "nordsidornas": "nordsida",
    "nordsidors": "nordsida",
    "nordsjöfarten": "nordsjöfart",
    "nordsjöfartens": "nordsjöfart",
    "nordsjöfarts": "nordsjöfart",
    "nordsluttningar": "nordsluttning",
    "nordsluttningarna": "nordsluttning",
    "nordsluttningarnas": "nordsluttning",
    "nordsluttningars": "nordsluttning",
    "nordsluttningen": "nordsluttning",
    "nordsluttningens": "nordsluttning",
    "nordsluttnings": "nordsluttning",
    "nordstjärneordens": "nordstjärneorden",
    "nordstjärneordnar": "nordstjärneorden",
    "nordstjärneordnarna": "nordstjärneorden",
    "nordstjärneordnarnas": "nordstjärneorden",
    "nordstjärneordnars": "nordstjärneorden",
    "nordstjärneordnen": "nordstjärneorden",
    "nordstjärneordnens": "nordstjärneorden",
    "nordsvenskar": "nordsvensk",
    "nordsvenskarna": "nordsvensk",
    "nordsvenskarnas": "nordsvensk",
    "nordsvenskars": "nordsvensk",
    "nordsvensken": "nordsvensk",
    "nordsvenskens": "nordsvensk",
    "nordsvensks": "nordsvensk",
    "nordtyska": "nordtysk",
    "nordtyskare": "nordtysk",
    "nordtyskares": "nordtysk",
    "nordtyskas": "nordtysk",
    "nordtyskast": "nordtysk",
    "nordtyskaste": "nordtysk",
    "nordtyskastes": "nordtysk",
    "nordtyskasts": "nordtysk",
    "nordtyske": "nordtysk",
    "nordtyskes": "nordtysk",
    "nordtysks": "nordtysk",
    "nordtyskt": "nordtysk",
    "nordtyskts": "nordtysk",
    "nordvietnamesiska": "nordvietnamesisk",
    "nordvietnamesiskare": "nordvietnamesisk",
    "nordvietnamesiskares": "nordvietnamesisk",
    "nordvietnamesiskas": "nordvietnamesisk",
    "nordvietnamesiskast": "nordvietnamesisk",
    "nordvietnamesiskaste": "nordvietnamesisk",
    "nordvietnamesiskastes": "nordvietnamesisk",
    "nordvietnamesiskasts": "nordvietnamesisk",
    "nordvietnamesiske": "nordvietnamesisk",
    "nordvietnamesiskes": "nordvietnamesisk",
    "nordvietnamesisks": "nordvietnamesisk",
    "nordvietnamesiskt": "nordvietnamesisk",
    "nordvietnamesiskts": "nordvietnamesisk",
    "nordvästen": "nordväst",
    "nordvästens": "nordväst",
    "nordvästs": "nordväst",
    "nordyemeniten": "nordyemenit",
    "nordyemenitens": "nordyemenit",
    "nordyemeniter": "nordyemenit",
    "nordyemeniterna": "nordyemenit",
    "nordyemeniternas": "nordyemenit",
    "nordyemeniters": "nordyemenit",
    "nordyemenits": "nordyemenit",
    "nordösten": "nordöst",
    "nordöstens": "nordöst",
    "nordösts": "nordöst",
    "noren": "nor",
    "norens": "nor",
    "norepinefrinen": "norepinefrin",
    "norepinefrinens": "norepinefrin",
    "norepinefriner": "norepinefrin",
    "norepinefrinerna": "norepinefrin",
    "norepinefrinernas": "norepinefrin",
    "norepinefriners": "norepinefrin",
    "norepinefrinet": "norepinefrin",
    "norepinefrinets": "norepinefrin",
    "norepinefrins": "norepinefrin",
    "noret": "nor",
    "norets": "nor",
    "normala": "normal",
    "normalare": "normal",
    "normalares": "normal",
    "normalas": "normal",
    "normalast": "normal",
    "normalaste": "normal",
    "normalastes": "normal",
    "normalasts": "normal",
    "normalbegåvade": "normalbegåvad",
    "normalbegåvades": "normalbegåvad",
    "normalbegåvads": "normalbegåvad",
    "normalbegåvat": "normalbegåvad",
    "normalbegåvats": "normalbegåvad",
    "normalbilden": "normalbild",
    "normalbildens": "normalbild",
    "normalbilder": "normalbild",
    "normalbilderna": "normalbild",
    "normalbildernas": "normalbild",
    "normalbilders": "normalbild",
    "normalbilds": "normalbild",
    "normalblyga": "normalblyg",
    "normalblygas": "normalblyg",
    "normalblyge": "normalblyg",
    "normalblyges": "normalblyg",
    "normalblygheten": "normalblyghet",
    "normalblyghetens": "normalblyghet",
    "normalblyghets": "normalblyghet",
    "normalblygs": "normalblyg",
    "normalblygt": "normalblyg",
    "normalblygts": "normalblyg",
    "normale": "normal",
    "normalen": "normal",
    "normalens": "normal",
    "normaler": "normal",
    "normalerna": "normal",
    "normalernas": "normal",
    "normalers": "normal",
    "normales": "normal",
    "normalfilmen": "normalfilm",
    "normalfilmens": "normalfilm",
    "normalfilmer": "normalfilm",
    "normalfilmerna": "normalfilm",
    "normalfilmernas": "normalfilm",
    "normalfilmers": "normalfilm",
    "normalfilms": "normalfilm",
    "normalfärgen": "normalfärg",
    "normalfärgens": "normalfärg",
    "normalfärger": "normalfärg",
    "normalfärgerna": "normalfärg",
    "normalfärgernas": "normalfärg",
    "normalfärgers": "normalfärg",
    "normalfärgs": "normalfärg",
    "normalfördelningar": "normalfördelning",
    "normalfördelningarna": "normalfördelning",
    "normalfördelningarnas": "normalfördelning",
    "normalfördelningars": "normalfördelning",
    "normalfördelningen": "normalfördelning",
    "normalfördelningens": "normalfördelning",
    "normalfördelnings": "normalfördelning",
    "normalgårdar": "normalgård",
    "normalgårdarna": "normalgård",
    "normalgårdarnas": "normalgård",
    "normalgårdars": "normalgård",
    "normalgården": "normalgård",
    "normalgårdens": "normalgård",
    "normalgårds": "normalgård",
    "normaliserad": "normalisera",
    "normaliserade": "normalisera",
    "normaliserades": "normalisera",
    "normaliserads": "normalisera",
    "normaliserande": "normalisera",
    "normaliseranden": "normaliserande",
    "normaliserandena": "normaliserande",
    "normaliserandenas": "normaliserande",
    "normaliserandens": "normaliserande",
    "normaliserandes": "normaliserande",
    "normaliserandet": "normaliserande",
    "normaliserandets": "normaliserande",
    "normaliserar": "normalisera",
    "normaliseras": "normalisera",
    "normaliserat": "normalisera",
    "normaliserats": "normalisera",
    "normaliserbara": "normaliserbar",
    "normaliserbarare": "normaliserbar",
    "normaliserbarares": "normaliserbar",
    "normaliserbaras": "normaliserbar",
    "normaliserbarast": "normaliserbar",
    "normaliserbaraste": "normaliserbar",
    "normaliserbarastes": "normaliserbar",
    "normaliserbarasts": "normaliserbar",
    "normaliserbare": "normaliserbar",
    "normaliserbares": "normaliserbar",
    "normaliserbarheten": "normaliserbarhet",
    "normaliserbarhetens": "normaliserbarhet",
    "normaliserbarhets": "normaliserbarhet",
    "normaliserbars": "normaliserbar",
    "normaliserbart": "normaliserbar",
    "normaliserbarts": "normaliserbar",
    "normaliseringar": "normalisering",
    "normaliseringarna": "normalisering",
    "normaliseringarnas": "normalisering",
    "normaliseringars": "normalisering",
    "normaliseringen": "normalisering",
    "normaliseringens": "normalisering",
    "normaliserings": "normalisering",
    "normaliseringsvågen": "normaliseringsvåg",
    "normaliseringsvågens": "normaliseringsvåg",
    "normaliseringsvågor": "normaliseringsvåg",
    "normaliseringsvågorna": "normaliseringsvåg",
    "normaliseringsvågornas": "normaliseringsvåg",
    "normaliseringsvågors": "normaliseringsvåg",
    "normaliseringsvågs": "normaliseringsvåg",
    "normaliteten": "normalitet",
    "normalitetens": "normalitet",
    "normaliteter": "normalitet",
    "normaliteterna": "normalitet",
    "normaliteternas": "normalitet",
    "normaliteters": "normalitet",
    "normalitets": "normalitet",
    "normalkraften": "normalkraft",
    "normalkraftens": "normalkraft",
    "normalkrafts": "normalkraft",
    "normalmånaden": "normalmånad",
    "normalmånadens": "normalmånad",
    "normalmånader": "normalmånad",
    "normalmånaderna": "normalmånad",
    "normalmånadernas": "normalmånad",
    "normalmånaders": "normalmånad",
    "normalmånads": "normalmånad",
    "normalmåtten": "normalmått",
    "normalmåttens": "normalmått",
    "normalmåttet": "normalmått",
    "normalmåttets": "normalmått",
    "normalmåtts": "normalmått",
    "normalobjektiven": "normalobjektiv",
    "normalobjektivens": "normalobjektiv",
    "normalobjektivet": "normalobjektiv",
    "normalobjektivets": "normalobjektiv",
    "normalobjektivs": "normalobjektiv",
    "normalpotentialen": "normalpotential",
    "normalpotentialens": "normalpotential",
    "normalpotentials": "normalpotential",
    "normalprosan": "normalprosa",
    "normalprosans": "normalprosa",
    "normalprosas": "normalprosa",
    "normals": "normal",
    "normalskolekompetensen": "normalskolekompetens",
    "normalskolekompetensens": "normalskolekompetens",
    "normalspåriga": "normalspårig",
    "normalspårigare": "normalspårig",
    "normalspårigares": "normalspårig",
    "normalspårigas": "normalspårig",
    "normalspårigast": "normalspårig",
    "normalspårigaste": "normalspårig",
    "normalspårigastes": "normalspårig",
    "normalspårigasts": "normalspårig",
    "normalspårige": "normalspårig",
    "normalspåriges": "normalspårig",
    "normalspårigs": "normalspårig",
    "normalspårigt": "normalspårig",
    "normalspårigts": "normalspårig",
    "normalstora": "normalstor",
    "normalstoras": "normalstor",
    "normalstore": "normalstor",
    "normalstores": "normalstor",
    "normalstors": "normalstor",
    "normalstort": "normalstor",
    "normalstorts": "normalstor",
    "normalstudietiden": "normalstudietid",
    "normalstudietidens": "normalstudietid",
    "normalstudietider": "normalstudietid",
    "normalstudietiderna": "normalstudietid",
    "normalstudietidernas": "normalstudietid",
    "normalstudietiders": "normalstudietid",
    "normalstudietids": "normalstudietid",
    "normalt": "normal",
    "normaltiden": "normaltid",
    "normaltidens": "normaltid",
    "normaltider": "normaltid",
    "normaltiderna": "normaltid",
    "normaltidernas": "normaltid",
    "normaltiders": "normaltid",
    "normaltids": "normaltid",
    "normaltillstånden": "normaltillstånd",
    "normaltillståndens": "normaltillstånd",
    "normaltillståndet": "normaltillstånd",
    "normaltillståndets": "normaltillstånd",
    "normaltillstånds": "normaltillstånd",
    "normaltonen": "normalton",
    "normaltonens": "normalton",
    "normaltoner": "normalton",
    "normaltonerna": "normalton",
    "normaltonernas": "normalton",
    "normaltoners": "normalton",
    "normaltons": "normalton",
    "normaltrycket": "normaltryck",
    "normaltryckets": "normaltryck",
    "normaltrycks": "normaltryck",
    "normalts": "normal",
    "normanden": "normand",
    "normandens": "normand",
    "normander": "normand",
    "normanderna": "normand",
    "normandernas": "normand",
    "normanders": "normand",
    "normandiska": "normandisk",
    "normandiskare": "normandisk",
    "normandiskares": "normandisk",
    "normandiskas": "normandisk",
    "normandiskast": "normandisk",
    "normandiskaste": "normandisk",
    "normandiskastes": "normandisk",
    "normandiskasts": "normandisk",
    "normandiske": "normandisk",
    "normandiskes": "normandisk",
    "normandisks": "normandisk",
    "normandiskt": "normandisk",
    "normandiskts": "normandisk",
    "normands": "normand",
    "normativa": "normativ",
    "normativare": "normativ",
    "normativares": "normativ",
    "normativas": "normativ",
    "normativast": "normativ",
    "normativaste": "normativ",
    "normativastes": "normativ",
    "normativasts": "normativ",
    "normative": "normativ",
    "normatives": "normativ",
    "normativs": "normativ",
    "normativt": "normativ",
    "normativts": "normativ",
    "normen": "norm",
    "normens": "norm",
    "normer": "norm",
    "normerad": "normera",
    "normerade": "normera",
    "normerades": "normera",
    "normerads": "normera",
    "normerande": "normera",
    "normeranden": "normerande",
    "normerandena": "normerande",
    "normerandenas": "normerande",
    "normerandens": "normerande",
    "normerandes": "normerande",
    "normerandet": "normerande",
    "normerandets": "normerande",
    "normerar": "normera",
    "normeras": "normera",
    "normerat": "normera",
    "normerats": "normera",
    "normerbara": "normerbar",
    "normerbarare": "normerbar",
    "normerbarares": "normerbar",
    "normerbaras": "normerbar",
    "normerbarast": "normerbar",
    "normerbaraste": "normerbar",
    "normerbarastes": "normerbar",
    "normerbarasts": "normerbar",
    "normerbare": "normerbar",
    "normerbares": "normerbar",
    "normerbarheten": "normerbarhet",
    "normerbarhetens": "normerbarhet",
    "normerbarhets": "normerbarhet",
    "normerbars": "normerbar",
    "normerbart": "normerbar",
    "normerbarts": "normerbar",
    "normeringar": "normering",
    "normeringarna": "normering",
    "normeringarnas": "normering",
    "normeringars": "normering",
    "normeringen": "normering",
    "normeringens": "normering",
    "normerings": "normering",
    "normerna": "norm",
    "normernas": "norm",
    "normers": "norm",
    "normlösa": "normlös",
    "normlösare": "normlös",
    "normlösares": "normlös",
    "normlösas": "normlös",
    "normlösast": "normlös",
    "normlösaste": "normlös",
    "normlösastes": "normlös",
    "normlösasts": "normlös",
    "normlöse": "normlös",
    "normlöses": "normlös",
    "normlösheten": "normlöshet",
    "normlöshetens": "normlöshet",
    "normlösheter": "normlöshet",
    "normlösheterna": "normlöshet",
    "normlösheternas": "normlöshet",
    "normlösheters": "normlöshet",
    "normlöshets": "normlöshet",
    "normlöst": "normlös",
    "normlösts": "normlös",
    "norms": "norm",
    "normsystemen": "normsystem",
    "normsystemens": "normsystem",
    "normsystemet": "normsystem",
    "normsystemets": "normsystem",
    "normsystems": "normsystem",
    "norn": "norna",
    "nornan": "norna",
    "nornans": "norna",
    "nornas": "norna",
    "norne": "norna",
    "nornor": "norna",
    "nornorna": "norna",
    "nornornas": "norna",
    "nornors": "norna",
    "norns": "norna",
    "norp": "norpa",
    "norpad": "norpa",
    "norpade": "norpa",
    "norpades": "norpa",
    "norpads": "norpa",
    "norpande": "norpa",
    "norpanden": "norpande",
    "norpandena": "norpande",
    "norpandenas": "norpande",
    "norpandens": "norpande",
    "norpandes": "norpande",
    "norpandet": "norpande",
    "norpandets": "norpande",
    "norpar": "norpa",
    "norpas": "norpa",
    "norpat": "norpa",
    "norpats": "norpa",
    "norrbagg": "norrbagge",
    "norrbaggar": "norrbagge",
    "norrbaggarna": "norrbagge",
    "norrbaggarnas": "norrbagge",
    "norrbaggars": "norrbagge",
    "norrbaggen": "norrbagge",
    "norrbaggens": "norrbagge",
    "norrbagges": "norrbagge",
    "norrbaggs": "norrbagge",
    "norrbottningar": "norrbottning",
    "norrbottningarna": "norrbottning",
    "norrbottningarnas": "norrbottning",
    "norrbottningars": "norrbottning",
    "norrbottningen": "norrbottning",
    "norrbottningens": "norrbottning",
    "norrbottnings": "norrbottning",
    "norrbottnisk": "norrbottniska",
    "norrbottniska": "norrbottnisk",
    "norrbottniskan": "norrbottniska",
    "norrbottniskans": "norrbottniska",
    "norrbottniskare": "norrbottnisk",
    "norrbottniskares": "norrbottnisk",
    "norrbottniskas": "norrbottniska",
    "norrbottniskast": "norrbottnisk",
    "norrbottniskaste": "norrbottnisk",
    "norrbottniskastes": "norrbottnisk",
    "norrbottniskasts": "norrbottnisk",
    "norrbottniske": "norrbottniska",
    "norrbottniskes": "norrbottnisk",
    "norrbottniskor": "norrbottniska",
    "norrbottniskorna": "norrbottniska",
    "norrbottniskornas": "norrbottniska",
    "norrbottniskors": "norrbottniska",
    "norrbottnisks": "norrbottnisk",
    "norrbottniskt": "norrbottnisk",
    "norrbottniskts": "norrbottnisk",
    "norrgökar": "norrgök",
    "norrgökarna": "norrgök",
    "norrgökarnas": "norrgök",
    "norrgökars": "norrgök",
    "norrgöken": "norrgök",
    "norrgökens": "norrgök",
    "norrgöks": "norrgök",
    "norrhimlens": "norrhimlen",
    "norrkvintar": "norrkvint",
    "norrkvintarna": "norrkvint",
    "norrkvintarnas": "norrkvint",
    "norrkvintars": "norrkvint",
    "norrkvinten": "norrkvint",
    "norrkvintens": "norrkvint",
    "norrkvints": "norrkvint",
    "norrköpingsnäs": "norrköpingsnäsa",
    "norrköpingsnäsan": "norrköpingsnäsa",
    "norrköpingsnäsans": "norrköpingsnäsa",
    "norrköpingsnäsas": "norrköpingsnäsa",
    "norrköpingsnäse": "norrköpingsnäsa",
    "norrköpingsnäsor": "norrköpingsnäsa",
    "norrköpingsnäsorna": "norrköpingsnäsa",
    "norrköpingsnäsornas": "norrköpingsnäsa",
    "norrköpingsnäsors": "norrköpingsnäsa",
    "norrlandshästar": "norrlandshäst",
    "norrlandshästarna": "norrlandshäst",
    "norrlandshästarnas": "norrlandshäst",
    "norrlandshästars": "norrlandshäst",
    "norrlandshästen": "norrlandshäst",
    "norrlandshästens": "norrlandshäst",
    "norrlandshästs": "norrlandshäst",
    "norrlandsälvar": "norrlandsälv",
    "norrlandsälvarna": "norrlandsälv",
    "norrlandsälvarnas": "norrlandsälv",
    "norrlandsälvars": "norrlandsälv",
    "norrlandsälven": "norrlandsälv",
    "norrlandsälvens": "norrlandsälv",
    "norrlandsälvs": "norrlandsälv",
    "norrländsk": "norrländska",
    "norrländska": "norrländsk",
    "norrländskan": "norrländska",
    "norrländskans": "norrländska",
    "norrländskare": "norrländsk",
    "norrländskares": "norrländsk",
    "norrländskas": "norrländska",
    "norrländskast": "norrländsk",
    "norrländskaste": "norrländsk",
    "norrländskastes": "norrländsk",
    "norrländskasts": "norrländsk",
    "norrländske": "norrländska",
    "norrländskes": "norrländsk",
    "norrländskor": "norrländska",
    "norrländskorna": "norrländska",
    "norrländskornas": "norrländska",
    "norrländskors": "norrländska",
    "norrländsks": "norrländsk",
    "norrländskt": "norrländsk",
    "norrländskts": "norrländsk",
    "norrlänningar": "norrlänning",
    "norrlänningarna": "norrlänning",
    "norrlänningarnas": "norrlänning",
    "norrlänningars": "norrlänning",
    "norrlänningen": "norrlänning",
    "norrlänningens": "norrlänning",
    "norrlännings": "norrlänning",
    "norrmannen": "norrman",
    "norrmannens": "norrman",
    "norrmans": "norrman",
    "norrmän": "norrman",
    "norrmännen": "norrman",
    "norrmännens": "norrman",
    "norrmäns": "norrman",
    "norrs": "norr",
    "norrsidan": "norrsida",
    "norrsidans": "norrsida",
    "norrsidas": "norrsida",
    "norrside": "norrsida",
    "norrsides": "norrsida",
    "norrsidor": "norrsida",
    "norrsidorna": "norrsida",
    "norrsidornas": "norrsida",
    "norrsidors": "norrsida",
    "norrskenet": "norrsken",
    "norrskenets": "norrsken",
    "norrskens": "norrsken",
    "norrskensupplevelsen": "norrskensupplevelse",
    "norrskensupplevelsens": "norrskensupplevelse",
    "norrskensupplevelser": "norrskensupplevelse",
    "norrskensupplevelserna": "norrskensupplevelse",
    "norrskensupplevelsernas": "norrskensupplevelse",
    "norrskensupplevelsers": "norrskensupplevelse",
    "norrskensupplevelses": "norrskensupplevelse",
    "norröna": "norrön",
    "norrönare": "norrön",
    "norrönares": "norrön",
    "norrönas": "norrön",
    "norrönast": "norrön",
    "norrönaste": "norrön",
    "norrönastes": "norrön",
    "norrönasts": "norrön",
    "norröne": "norrön",
    "norrönes": "norrön",
    "norröns": "norrön",
    "norrönt": "norrön",
    "norrönts": "norrön",
    "nors": "nor",
    "norsar": "nors",
    "norsarna": "nors",
    "norsarnas": "nors",
    "norsars": "nors",
    "norsen": "nors",
    "norsens": "nors",
    "norsk": "norska",
    "norska": "norsk",
    "norskan": "norska",
    "norskans": "norska",
    "norskare": "norsk",
    "norskares": "norsk",
    "norskas": "norska",
    "norskast": "norsk",
    "norskaste": "norsk",
    "norskastes": "norsk",
    "norskasts": "norsk",
    "norske": "norska",
    "norskes": "norsk",
    "norskheten": "norskhet",
    "norskhetens": "norskhet",
    "norskhets": "norskhet",
    "norskor": "norska",
    "norskorna": "norska",
    "norskornas": "norska",
    "norskors": "norska",
    "norsks": "norsk",
    "norskt": "norsk",
    "norsktillverkade": "norsktillverkad",
    "norsktillverkades": "norsktillverkad",
    "norsktillverkads": "norsktillverkad",
    "norsktillverkat": "norsktillverkad",
    "norsktillverkats": "norsktillverkad",
    "norskts": "norsk",
    "norvagismen": "norvagism",
    "norvagismens": "norvagism",
    "norvagismer": "norvagism",
    "norvagismerna": "norvagism",
    "norvagismernas": "norvagism",
    "norvagismers": "norvagism",
    "norvagisms": "norvagism",
    "nos": "nosa",
    "nosade": "nosa",
    "nosades": "nosa",
    "nosande": "nosa",
    "nosanden": "nosande",
    "nosandena": "nosande",
    "nosandenas": "nosande",
    "nosandens": "nosande",
    "nosandes": "nosande",
    "nosandet": "nosande",
    "nosandets": "nosande",
    "nosar": "nosa",
    "nosarna": "nos",
    "nosarnas": "nos",
    "nosars": "nos",
    "nosas": "nosa",
    "nosat": "nosa",
    "nosats": "nosa",
    "nosen": "nos",
    "nosens": "nos",
    "nosgrim": "nosgrimma",
    "nosgrimman": "nosgrimma",
    "nosgrimmans": "nosgrimma",
    "nosgrimmas": "nosgrimma",
    "nosgrimme": "nosgrimma",
    "nosgrimmor": "nosgrimma",
    "nosgrimmorna": "nosgrimma",
    "nosgrimmornas": "nosgrimma",
    "nosgrimmors": "nosgrimma",
    "nosgrims": "nosgrimma",
    "noshjulen": "noshjul",
    "noshjulens": "noshjul",
    "noshjulet": "noshjul",
    "noshjulets": "noshjul",
    "noshjuls": "noshjul",
    "noshörningar": "noshörning",
    "noshörningarna": "noshörning",
    "noshörningarnas": "noshörning",
    "noshörningars": "noshörning",
    "noshörningen": "noshörning",
    "noshörningens": "noshörning",
    "noshörnings": "noshörning",
    "noshörningsbebisar": "noshörningsbebis",
    "noshörningsbebisarna": "noshörningsbebis",
    "noshörningsbebisarnas": "noshörningsbebis",
    "noshörningsbebisars": "noshörningsbebis",
    "noshörningsbebisen": "noshörningsbebis",
    "noshörningsbebisens": "noshörningsbebis",
    "noshörningskalvar": "noshörningskalv",
    "noshörningskalvarna": "noshörningskalv",
    "noshörningskalvarnas": "noshörningskalv",
    "noshörningskalvars": "noshörningskalv",
    "noshörningskalven": "noshörningskalv",
    "noshörningskalvens": "noshörningskalv",
    "noshörningskalvs": "noshörningskalv",
    "noshörningsungar": "noshörningsunge",
    "noshörningsungarna": "noshörningsunge",
    "noshörningsungarnas": "noshörningsunge",
    "noshörningsungars": "noshörningsunge",
    "noshörningsungen": "noshörningsunge",
    "noshörningsungens": "noshörningsunge",
    "noshörningsunges": "noshörningsunge",
    "nosiga": "nosig",
    "nosigare": "nosig",
    "nosigares": "nosig",
    "nosigas": "nosig",
    "nosigast": "nosig",
    "nosigaste": "nosig",
    "nosigastes": "nosig",
    "nosigasts": "nosig",
    "nosige": "nosig",
    "nosiges": "nosig",
    "nosigheten": "nosighet",
    "nosighetens": "nosighet",
    "nosigheter": "nosighet",
    "nosigheterna": "nosighet",
    "nosigheternas": "nosighet",
    "nosigheters": "nosighet",
    "nosighets": "nosighet",
    "nosigs": "nosig",
    "nosigt": "nosig",
    "nosigts": "nosig",
    "noskiga": "noskig",
    "noskigare": "noskig",
    "noskigares": "noskig",
    "noskigas": "noskig",
    "noskigast": "noskig",
    "noskigaste": "noskig",
    "noskigastes": "noskig",
    "noskigasts": "noskig",
    "noskige": "noskig",
    "noskiges": "noskig",
    "noskigheten": "noskighet",
    "noskighetens": "noskighet",
    "noskigheter": "noskighet",
    "noskigheterna": "noskighet",
    "noskigheternas": "noskighet",
    "noskigheters": "noskighet",
    "noskighets": "noskighet",
    "noskigs": "noskig",
    "noskigt": "noskig",
    "noskigts": "noskig",
    "noskonen": "noskon",
    "noskonens": "noskon",
    "noskoner": "noskon",
    "noskonerna": "noskon",
    "noskonernas": "noskon",
    "noskoners": "noskon",
    "noskons": "noskon",
    "noskorgar": "noskorg",
    "noskorgarna": "noskorg",
    "noskorgarnas": "noskorg",
    "noskorgars": "noskorg",
    "noskorgen": "noskorg",
    "noskorgens": "noskorg",
    "noskorgs": "noskorg",
    "noslängden": "noslängd",
    "noslängdens": "noslängd",
    "noslängder": "noslängd",
    "noslängderna": "noslängd",
    "noslängdernas": "noslängd",
    "noslängders": "noslängd",
    "noslängds": "noslängd",
    "nosregionen": "nosregion",
    "nosregionens": "nosregion",
    "nosregioner": "nosregion",
    "nosregionerna": "nosregion",
    "nosregionernas": "nosregion",
    "nosregioners": "nosregion",
    "nosregions": "nosregion",
    "nosringar": "nosring",
    "nosringarna": "nosring",
    "nosringarnas": "nosring",
    "nosringars": "nosring",
    "nosringen": "nosring",
    "nosringens": "nosring",
    "nosrings": "nosring",
    "nosseroten": "nosserot",
    "nosserotens": "nosserot",
    "nosserots": "nosserot",
    "nosspetsar": "nosspets",
    "nosspetsarna": "nosspets",
    "nosspetsarnas": "nosspets",
    "nosspetsars": "nosspets",
    "nosspetsen": "nosspets",
    "nosspetsens": "nosspets",
    "nostalgien": "nostalgi",
    "nostalgiens": "nostalgi",
    "nostalgier": "nostalgi",
    "nostalgierna": "nostalgi",
    "nostalgiernas": "nostalgi",
    "nostalgiers": "nostalgi",
    "nostalgikern": "nostalgiker",
    "nostalgikerna": "nostalgiker",
    "nostalgikernas": "nostalgiker",
    "nostalgikerns": "nostalgiker",
    "nostalgikers": "nostalgiker",
    "nostalgin": "nostalgi",
    "nostalgins": "nostalgi",
    "nostalgipjäsen": "nostalgipjäs",
    "nostalgipjäsens": "nostalgipjäs",
    "nostalgipjäser": "nostalgipjäs",
    "nostalgipjäserna": "nostalgipjäs",
    "nostalgipjäsernas": "nostalgipjäs",
    "nostalgipjäsers": "nostalgipjäs",
    "nostalgis": "nostalgi",
    "nostalgiska": "nostalgisk",
    "nostalgiskare": "nostalgisk",
    "nostalgiskares": "nostalgisk",
    "nostalgiskas": "nostalgisk",
    "nostalgiskast": "nostalgisk",
    "nostalgiskaste": "nostalgisk",
    "nostalgiskastes": "nostalgisk",
    "nostalgiskasts": "nostalgisk",
    "nostalgiske": "nostalgisk",
    "nostalgiskes": "nostalgisk",
    "nostalgisks": "nostalgisk",
    "nostalgiskt": "nostalgisk",
    "nostalgiskts": "nostalgisk",
    "notabels": "notabel",
    "notabelt": "notabel",
    "notabelts": "notabel",
    "notabiliteten": "notabilitet",
    "notabilitetens": "notabilitet",
    "notabiliteter": "notabilitet",
    "notabiliteterna": "notabilitet",
    "notabiliteternas": "notabilitet",
    "notabiliteters": "notabilitet",
    "notabilitets": "notabilitet",
    "notabla": "notabel",
    "notablare": "notabel",
    "notablares": "notabel",
    "notablas": "notabel",
    "notablast": "notabel",
    "notablaste": "notabel",
    "notablastes": "notabel",
    "notablasts": "notabel",
    "notable": "notabel",
    "notables": "notabel",
    "notad": "nota",
    "notade": "nota",
    "notades": "nota",
    "notads": "nota",
    "notan": "nota",
    "notande": "nota",
    "notanden": "notande",
    "notandena": "notande",
    "notandenas": "notande",
    "notandens": "notande",
    "notandes": "notande",
    "notandet": "notande",
    "notandets": "notande",
    "notans": "nota",
    "notar": "nota",
    "notariatavdelningar": "notariatavdelning",
    "notariatavdelningarna": "notariatavdelning",
    "notariatavdelningarnas": "notariatavdelning",
    "notariatavdelningars": "notariatavdelning",
    "notariatavdelningen": "notariatavdelning",
    "notariatavdelningens": "notariatavdelning",
    "notariatavdelnings": "notariatavdelning",
    "notariaten": "notariat",
    "notariatens": "notariat",
    "notariatet": "notariat",
    "notariatets": "notariat",
    "notariats": "notariat",
    "notarien": "notarie",
    "notariens": "notarie",
    "notarier": "notarie",
    "notarierna": "notarie",
    "notariernas": "notarie",
    "notariers": "notarie",
    "notaries": "notarie",
    "notarna": "not",
    "notarnas": "not",
    "notars": "not",
    "notas": "nota",
    "notat": "nota",
    "notationen": "notation",
    "notationens": "notation",
    "notationer": "notation",
    "notationerna": "notation",
    "notationernas": "notation",
    "notationers": "notation",
    "notations": "notation",
    "notats": "nota",
    "notbladen": "notblad",
    "notbladens": "notblad",
    "notbladet": "notblad",
    "notbladets": "notblad",
    "notblads": "notblad",
    "notdragningar": "notdragning",
    "notdragningarna": "notdragning",
    "notdragningarnas": "notdragning",
    "notdragningars": "notdragning",
    "notdragningen": "notdragning",
    "notdragningens": "notdragning",
    "notdragnings": "notdragning",
    "notdräkten": "notdräkt",
    "notdräktens": "notdräkt",
    "notdräkter": "notdräkt",
    "notdräkterna": "notdräkt",
    "notdräkternas": "notdräkt",
    "notdräkters": "notdräkt",
    "notdräkts": "notdräkt",
    "note": "nota",
    "noten": "not",
    "notens": "not",
    "noter": "not",
    "noterad": "notera",
    "noterade": "notera",
    "noterades": "notera",
    "noterads": "notera",
    "noterande": "notera",
    "noteranden": "noterande",
    "noterandena": "noterande",
    "noterandenas": "noterande",
    "noterandens": "noterande",
    "noterandes": "noterande",
    "noterandet": "noterande",
    "noterandets": "noterande",
    "noterar": "notera",
    "noteras": "notera",
    "noterat": "notera",
    "noterats": "notera",
    "noterbara": "noterbar",
    "noterbarare": "noterbar",
    "noterbarares": "noterbar",
    "noterbaras": "noterbar",
    "noterbarast": "noterbar",
    "noterbaraste": "noterbar",
    "noterbarastes": "noterbar",
    "noterbarasts": "noterbar",
    "noterbare": "noterbar",
    "noterbares": "noterbar",
    "noterbarheten": "noterbarhet",
    "noterbarhetens": "noterbarhet",
    "noterbarhets": "noterbarhet",
    "noterbars": "noterbar",
    "noterbart": "noterbar",
    "noterbarts": "noterbar",
    "noteringar": "notering",
    "noteringarna": "notering",
    "noteringarnas": "notering",
    "noteringars": "notering",
    "noteringen": "notering",
    "noteringens": "notering",
    "noterings": "notering",
    "noterna": "not",
    "noternas": "not",
    "noters": "not",
    "notesblocken": "notesblock",
    "notesblockens": "notesblock",
    "notesblocket": "notesblock",
    "notesblockets": "notesblock",
    "notesblocks": "notesblock",
    "notfasta": "notfast",
    "notfastare": "notfast",
    "notfastares": "notfast",
    "notfastas": "notfast",
    "notfastast": "notfast",
    "notfastaste": "notfast",
    "notfastastes": "notfast",
    "notfastasts": "notfast",
    "notfaste": "notfast",
    "notfastes": "notfast",
    "notfasts": "notfast",
    "notificerad": "notificera",
    "notificerade": "notificera",
    "notificerades": "notificera",
    "notificerads": "notificera",
    "notificerande": "notificera",
    "notificeranden": "notificerande",
    "notificerandena": "notificerande",
    "notificerandenas": "notificerande",
    "notificerandens": "notificerande",
    "notificerandes": "notificerande",
    "notificerandet": "notificerande",
    "notificerandets": "notificerande",
    "notificerar": "notificera",
    "notificeras": "notificera",
    "notificerat": "notificera",
    "notificerats": "notificera",
    "notificerbara": "notificerbar",
    "notificerbarare": "notificerbar",
    "notificerbarares": "notificerbar",
    "notificerbaras": "notificerbar",
    "notificerbarast": "notificerbar",
    "notificerbaraste": "notificerbar",
    "notificerbarastes": "notificerbar",
    "notificerbarasts": "notificerbar",
    "notificerbare": "notificerbar",
    "notificerbares": "notificerbar",
    "notificerbarheten": "notificerbarhet",
    "notificerbarhetens": "notificerbarhet",
    "notificerbarhets": "notificerbarhet",
    "notificerbars": "notificerbar",
    "notificerbart": "notificerbar",
    "notificerbarts": "notificerbar",
    "notificeringar": "notificering",
    "notificeringarna": "notificering",
    "notificeringarnas": "notificering",
    "notificeringars": "notificering",
    "notificeringen": "notificering",
    "notificeringens": "notificering",
    "notificerings": "notificering",
    "notifierad": "notifiera",
    "notifierade": "notifiera",
    "notifierades": "notifiera",
    "notifierads": "notifiera",
    "notifierande": "notifiera",
    "notifieranden": "notifierande",
    "notifierandena": "notifierande",
    "notifierandenas": "notifierande",
    "notifierandens": "notifierande",
    "notifierandes": "notifierande",
    "notifierandet": "notifierande",
    "notifierandets": "notifierande",
    "notifierar": "notifiera",
    "notifieras": "notifiera",
    "notifierat": "notifiera",
    "notifierats": "notifiera",
    "notifierbara": "notifierbar",
    "notifierbarare": "notifierbar",
    "notifierbarares": "notifierbar",
    "notifierbaras": "notifierbar",
    "notifierbarast": "notifierbar",
    "notifierbaraste": "notifierbar",
    "notifierbarastes": "notifierbar",
    "notifierbarasts": "notifierbar",
    "notifierbare": "notifierbar",
    "notifierbares": "notifierbar",
    "notifierbarheten": "notifierbarhet",
    "notifierbarhetens": "notifierbarhet",
    "notifierbarhets": "notifierbarhet",
    "notifierbars": "notifierbar",
    "notifierbart": "notifierbar",
    "notifierbarts": "notifierbar",
    "notifieringar": "notifiering",
    "notifieringarna": "notifiering",
    "notifieringarnas": "notifiering",
    "notifieringars": "notifiering",
    "notifieringen": "notifiering",
    "notifieringens": "notifiering",
    "notifierings": "notifiering",
    "notifikationen": "notifikation",
    "notifikationens": "notifikation",
    "notifikationer": "notifikation",
    "notifikationerna": "notifikation",
    "notifikationernas": "notifikation",
    "notifikationers": "notifikation",
    "notifikations": "notifikation",
    "notisen": "notis",
    "notisens": "notis",
    "notiser": "notis",
    "notiserad": "notisera",
    "notiserade": "notisera",
    "notiserades": "notisera",
    "notiserads": "notisera",
    "notiserande": "notisera",
    "notiseranden": "notiserande",
    "notiserandena": "notiserande",
    "notiserandenas": "notiserande",
    "notiserandens": "notiserande",
    "notiserandes": "notiserande",
    "notiserandet": "notiserande",
    "notiserandets": "notiserande",
    "notiserar": "notisera",
    "notiseras": "notisera",
    "notiserat": "notisera",
    "notiserats": "notisera",
    "notiserbara": "notiserbar",
    "notiserbarare": "notiserbar",
    "notiserbarares": "notiserbar",
    "notiserbaras": "notiserbar",
    "notiserbarast": "notiserbar",
    "notiserbaraste": "notiserbar",
    "notiserbarastes": "notiserbar",
    "notiserbarasts": "notiserbar",
    "notiserbare": "notiserbar",
    "notiserbares": "notiserbar",
    "notiserbarheten": "notiserbarhet",
    "notiserbarhetens": "notiserbarhet",
    "notiserbarhets": "notiserbarhet",
    "notiserbars": "notiserbar",
    "notiserbart": "notiserbar",
    "notiserbarts": "notiserbar",
    "notiseringar": "notisering",
    "notiseringarna": "notisering",
    "notiseringarnas": "notisering",
    "notiseringars": "notisering",
    "notiseringen": "notisering",
    "notiseringens": "notisering",
    "notiserings": "notisering",
    "notiserna": "notis",
    "notisernas": "notis",
    "notisers": "notis",
    "notlagen": "notlag",
    "notlagens": "notlag",
    "notlaget": "notlag",
    "notlagets": "notlag",
    "notlags": "notlag",
    "notlinjen": "notlinje",
    "notlinjens": "notlinje",
    "notlinjer": "notlinje",
    "notlinjerna": "notlinje",
    "notlinjernas": "notlinje",
    "notlinjers": "notlinje",
    "notlinjes": "notlinje",
    "notor": "nota",
    "notorieteten": "notorietet",
    "notorietetens": "notorietet",
    "notorieteter": "notorietet",
    "notorieteterna": "notorietet",
    "notorieteternas": "notorietet",
    "notorieteters": "notorietet",
    "notorietets": "notorietet",
    "notoriska": "notorisk",
    "notoriskare": "notorisk",
    "notoriskares": "notorisk",
    "notoriskas": "notorisk",
    "notoriskast": "notorisk",
    "notoriskaste": "notorisk",
    "notoriskastes": "notorisk",
    "notoriskasts": "notorisk",
    "notoriske": "notorisk",
    "notoriskes": "notorisk",
    "notorisks": "notorisk",
    "notoriskt": "notorisk",
    "notoriskts": "notorisk",
    "notorna": "nota",
    "notornas": "nota",
    "notors": "nota",
    "nototenioiden": "nototenioid",
    "nototenioidens": "nototenioid",
    "nototenioider": "nototenioid",
    "nototenioiderna": "nototenioid",
    "nototenioidernas": "nototenioid",
    "nototenioiders": "nototenioid",
    "nototenioids": "nototenioid",
    "notpapperen": "notpapper",
    "notpapperens": "notpapper",
    "notpapperet": "notpapper",
    "notpapperets": "notpapper",
    "notpapperna": "notpapper",
    "notpappernas": "notpapper",
    "notpappers": "notpapper",
    "notpappren": "notpapper",
    "notpapprens": "notpapper",
    "notpappret": "notpapper",
    "notpapprets": "notpapper",
    "notplanen": "notplan",
    "notplanens": "notplan",
    "notplanet": "notplan",
    "notplanets": "notplan",
    "notplans": "notplan",
    "notraden": "notrad",
    "notradens": "notrad",
    "notrader": "notrad",
    "notraderna": "notrad",
    "notradernas": "notrad",
    "notraders": "notrad",
    "notrads": "notrad",
    "nots": "not",
    "notsiffer": "notsiffra",
    "notsiffran": "notsiffra",
    "notsiffrans": "notsiffra",
    "notsiffras": "notsiffra",
    "notsiffre": "notsiffra",
    "notsiffror": "notsiffra",
    "notsiffrorna": "notsiffra",
    "notsiffrornas": "notsiffra",
    "notsiffrors": "notsiffra",
    "notskriften": "notskrift",
    "notskriftens": "notskrift",
    "notskrifts": "notskrift",
    "notskriftsteckens": "notskriftstecken",
    "notskriftstecknen": "notskriftstecken",
    "notskriftstecknens": "notskriftstecken",
    "notskriftstecknet": "notskriftstecken",
    "notskriftstecknets": "notskriftstecken",
    "notställen": "notställ",
    "notställens": "notställ",
    "notstället": "notställ",
    "notställets": "notställ",
    "notställs": "notställ",
    "notstålen": "notstål",
    "notstålens": "notstål",
    "notstålet": "notstål",
    "notstålets": "notstål",
    "notståls": "notstål",
    "notsäkerheten": "notsäkerhet",
    "notsäkerhetens": "notsäkerhet",
    "notsäkerhets": "notsäkerhet",
    "notsäkers": "notsäker",
    "notsäkert": "notsäker",
    "notsäkerts": "notsäker",
    "notsäkra": "notsäker",
    "notsäkrare": "notsäker",
    "notsäkrares": "notsäker",
    "notsäkras": "notsäker",
    "notsäkrast": "notsäker",
    "notsäkraste": "notsäker",
    "notsäkrastes": "notsäker",
    "notsäkrasts": "notsäker",
    "notsäkre": "notsäker",
    "notsäkres": "notsäker",
    "notvarpen": "notvarp",
    "notvarpens": "notvarp",
    "notvarpet": "notvarp",
    "notvarpets": "notvarp",
    "notvarps": "notvarp",
    "notvändar": "notvändare",
    "notvändaren": "notvändare",
    "notvändarens": "notvändare",
    "notvändares": "notvändare",
    "notvändarna": "notvändare",
    "notvändarnas": "notvändare",
    "notväxlingar": "notväxling",
    "notväxlingarna": "notväxling",
    "notväxlingarnas": "notväxling",
    "notväxlingars": "notväxling",
    "notväxlingen": "notväxling",
    "notväxlingens": "notväxling",
    "notväxlings": "notväxling",
    "nougaten": "nougat",
    "nougatens": "nougat",
    "nougater": "nougat",
    "nougaterna": "nougat",
    "nougaternas": "nougat",
    "nougaters": "nougat",
    "nougats": "nougat",
    "novan": "nova",
    "novans": "nova",
    "novantika": "novantik",
    "novantikare": "novantik",
    "novantikares": "novantik",
    "novantikas": "novantik",
    "novantikast": "novantik",
    "novantikaste": "novantik",
    "novantikastes": "novantik",
    "novantikasts": "novantik",
    "novantike": "novantik",
    "novantikes": "novantik",
    "novantiks": "novantik",
    "novantikt": "novantik",
    "novantikts": "novantik",
    "novas": "nova",
    "novationen": "novation",
    "novationens": "novation",
    "novationer": "novation",
    "novationerna": "novation",
    "novationernas": "novation",
    "novationers": "novation",
    "novations": "novation",
    "novautbrotten": "novautbrott",
    "novautbrottens": "novautbrott",
    "novautbrottet": "novautbrott",
    "novautbrottets": "novautbrott",
    "novautbrotts": "novautbrott",
    "novellen": "novell",
    "novellens": "novell",
    "noveller": "novell",
    "novellerna": "novell",
    "novellernas": "novell",
    "novellers": "novell",
    "novelletten": "novellett",
    "novellettens": "novellett",
    "novelletter": "novellett",
    "novelletterna": "novellett",
    "novelletternas": "novellett",
    "novelletters": "novellett",
    "novelletts": "novellett",
    "novellisten": "novellist",
    "novellistens": "novellist",
    "novellister": "novellist",
    "novellisterna": "novellist",
    "novellisternas": "novellist",
    "novellisters": "novellist",
    "novellistiken": "novellistik",
    "novellistikens": "novellistik",
    "novellistiks": "novellistik",
    "novellistiska": "novellistisk",
    "novellistiskare": "novellistisk",
    "novellistiskares": "novellistisk",
    "novellistiskas": "novellistisk",
    "novellistiskast": "novellistisk",
    "novellistiskaste": "novellistisk",
    "novellistiskastes": "novellistisk",
    "novellistiskasts": "novellistisk",
    "novellistiske": "novellistisk",
    "novellistiskes": "novellistisk",
    "novellistisks": "novellistisk",
    "novellistiskt": "novellistisk",
    "novellistiskts": "novellistisk",
    "novellists": "novellist",
    "novells": "novell",
    "novellsamlingar": "novellsamling",
    "novellsamlingarna": "novellsamling",
    "novellsamlingarnas": "novellsamling",
    "novellsamlingars": "novellsamling",
    "novellsamlingen": "novellsamling",
    "novellsamlingens": "novellsamling",
    "novellsamlings": "novellsamling",
    "novemberkvällar": "novemberkväll",
    "novemberkvällarna": "novemberkväll",
    "novemberkvällarnas": "novemberkväll",
    "novemberkvällars": "novemberkväll",
    "novemberkvällen": "novemberkväll",
    "novemberkvällens": "novemberkväll",
    "novemberkvälls": "novemberkväll",
    "novembermörkers": "novembermörker",
    "novembermörkret": "novembermörker",
    "novembermörkrets": "novembermörker",
    "novembers": "november",
    "novemberskymningen": "novemberskymning",
    "novemberskymningens": "novemberskymning",
    "novemberskymnings": "novemberskymning",
    "novisen": "novis",
    "novisens": "novis",
    "noviser": "novis",
    "noviserna": "novis",
    "novisernas": "novis",
    "novisers": "novis",
    "noviteten": "novitet",
    "novitetens": "novitet",
    "noviteter": "novitet",
    "noviteterna": "novitet",
    "noviteternas": "novitet",
    "noviteters": "novitet",
    "novitets": "novitet",
    "novitiaten": "novitiat",
    "novitiatens": "novitiat",
    "novitiatet": "novitiat",
    "novitiatets": "novitiat",
    "novitiats": "novitiat",
    "novor": "nova",
    "novorna": "nova",
    "novornas": "nova",
    "novors": "nova",
    "nubb": "nubbe",
    "nubbad": "nubba",
    "nubbade": "nubba",
    "nubbades": "nubba",
    "nubbads": "nubba",
    "nubbande": "nubba",
    "nubbanden": "nubbande",
    "nubbandena": "nubbande",
    "nubbandenas": "nubbande",
    "nubbandens": "nubbande",
    "nubbandes": "nubbande",
    "nubbandet": "nubbande",
    "nubbandets": "nubbande",
    "nubbar": "nubbe",
    "nubbarna": "nubbe",
    "nubbarnas": "nubbe",
    "nubbars": "nubbe",
    "nubbas": "nubba",
    "nubbat": "nubba",
    "nubbats": "nubba",
    "nubben": "nubbe",
    "nubbens": "nubbe",
    "nubbes": "nubbe",
    "nubbevis": "nubbevisa",
    "nubbevisan": "nubbevisa",
    "nubbevisans": "nubbevisa",
    "nubbevisas": "nubbevisa",
    "nubbevise": "nubbevisa",
    "nubbevisor": "nubbevisa",
    "nubbevisorna": "nubbevisa",
    "nubbevisornas": "nubbevisa",
    "nubbevisors": "nubbevisa",
    "nubbs": "nubbe",
    "nubbstenen": "nubbsten",
    "nubbstenens": "nubbsten",
    "nubbstens": "nubbsten",
    "nubiern": "nubier",
    "nubierna": "nubier",
    "nubiernas": "nubier",
    "nubierns": "nubier",
    "nubiers": "nubier",
    "nubiska": "nubisk",
    "nubiskare": "nubisk",
    "nubiskares": "nubisk",
    "nubiskas": "nubisk",
    "nubiskast": "nubisk",
    "nubiskaste": "nubisk",
    "nubiskastes": "nubisk",
    "nubiskasts": "nubisk",
    "nubiske": "nubisk",
    "nubiskes": "nubisk",
    "nubisks": "nubisk",
    "nubiskt": "nubisk",
    "nubiskts": "nubisk",
    "nuck": "nucka",
    "nuckan": "nucka",
    "nuckans": "nucka",
    "nuckas": "nucka",
    "nucke": "nucka",
    "nuckiga": "nuckig",
    "nuckigare": "nuckig",
    "nuckigares": "nuckig",
    "nuckigas": "nuckig",
    "nuckigast": "nuckig",
    "nuckigaste": "nuckig",
    "nuckigastes": "nuckig",
    "nuckigasts": "nuckig",
    "nuckige": "nuckig",
    "nuckiges": "nuckig",
    "nuckigheten": "nuckighet",
    "nuckighetens": "nuckighet",
    "nuckighets": "nuckighet",
    "nuckigs": "nuckig",
    "nuckigt": "nuckig",
    "nuckigts": "nuckig",
    "nuckor": "nucka",
    "nuckorna": "nucka",
    "nuckornas": "nucka",
    "nuckors": "nucka",
    "nucks": "nucka",
    "nudd": "nudda",
    "nuddad": "nudda",
    "nuddade": "nudda",
    "nuddades": "nudda",
    "nuddads": "nudda",
    "nuddande": "nudda",
    "nuddanden": "nuddande",
    "nuddandena": "nuddande",
    "nuddandenas": "nuddande",
    "nuddandens": "nuddande",
    "nuddandes": "nuddande",
    "nuddandet": "nuddande",
    "nuddandets": "nuddande",
    "nuddar": "nudda",
    "nuddas": "nudda",
    "nuddat": "nudda",
    "nuddats": "nudda",
    "nudeln": "nudel",
    "nudelns": "nudel",
    "nudels": "nudel",
    "nudelwokar": "nudelwok",
    "nudelwokarna": "nudelwok",
    "nudelwokarnas": "nudelwok",
    "nudelwokars": "nudelwok",
    "nudelwoken": "nudelwok",
    "nudelwokens": "nudelwok",
    "nudelwoks": "nudelwok",
    "nudismen": "nudism",
    "nudismens": "nudism",
    "nudismer": "nudism",
    "nudismerna": "nudism",
    "nudismernas": "nudism",
    "nudismers": "nudism",
    "nudisms": "nudism",
    "nudisten": "nudist",
    "nudistens": "nudist",
    "nudister": "nudist",
    "nudisterna": "nudist",
    "nudisternas": "nudist",
    "nudisters": "nudist",
    "nudistiska": "nudistisk",
    "nudistiskare": "nudistisk",
    "nudistiskares": "nudistisk",
    "nudistiskas": "nudistisk",
    "nudistiskast": "nudistisk",
    "nudistiskaste": "nudistisk",
    "nudistiskastes": "nudistisk",
    "nudistiskasts": "nudistisk",
    "nudistiske": "nudistisk",
    "nudistiskes": "nudistisk",
    "nudistisks": "nudistisk",
    "nudistiskt": "nudistisk",
    "nudistiskts": "nudistisk",
    "nudists": "nudist",
    "nuditeten": "nuditet",
    "nuditetens": "nuditet",
    "nuditeter": "nuditet",
    "nuditeterna": "nuditet",
    "nuditeternas": "nuditet",
    "nuditeters": "nuditet",
    "nuditets": "nuditet",
    "nudlar": "nudel",
    "nudlarna": "nudel",
    "nudlarnas": "nudel",
    "nudlars": "nudel",
    "nuffr": "nuffra",
    "nuffran": "nuffra",
    "nuffrans": "nuffra",
    "nuffras": "nuffra",
    "nuffre": "nuffra",
    "nuffror": "nuffra",
    "nuffrorna": "nuffra",
    "nuffrornas": "nuffra",
    "nuffrors": "nuffra",
    "nuffrs": "nuffra",
    "nugaten": "nugat",
    "nugatens": "nugat",
    "nugater": "nugat",
    "nugaterna": "nugat",
    "nugaternas": "nugat",
    "nugaters": "nugat",
    "nugats": "nugat",
    "nukleiden": "nukleid",
    "nukleidens": "nukleid",
    "nukleider": "nukleid",
    "nukleiderna": "nukleid",
    "nukleidernas": "nukleid",
    "nukleiders": "nukleid",
    "nukleids": "nukleid",
    "nukleinen": "nuklein",
    "nukleinens": "nuklein",
    "nukleiner": "nuklein",
    "nukleinerna": "nuklein",
    "nukleinernas": "nuklein",
    "nukleiners": "nuklein",
    "nukleinet": "nuklein",
    "nukleinets": "nuklein",
    "nukleins": "nuklein",
    "nukleinsyran": "nukleinsyra",
    "nukleinsyrans": "nukleinsyra",
    "nukleinsyras": "nukleinsyra",
    "nukleinsyre": "nukleinsyra",
    "nukleinsyror": "nukleinsyra",
    "nukleinsyrorna": "nukleinsyra",
    "nukleinsyrornas": "nukleinsyra",
    "nukleinsyrors": "nukleinsyra",
    "nukleonen": "nukleon",
    "nukleonens": "nukleon",
    "nukleoner": "nukleon",
    "nukleonerna": "nukleon",
    "nukleonernas": "nukleon",
    "nukleoners": "nukleon",
    "nukleons": "nukleon",
    "nukleontalen": "nukleontal",
    "nukleontalens": "nukleontal",
    "nukleontalet": "nukleontal",
    "nukleontalets": "nukleontal",
    "nukleontals": "nukleontal",
    "nukleotiden": "nukleotid",
    "nukleotidens": "nukleotid",
    "nukleotider": "nukleotid",
    "nukleotiderna": "nukleotid",
    "nukleotidernas": "nukleotid",
    "nukleotiders": "nukleotid",
    "nukleotids": "nukleotid",
    "nukleära": "nukleär",
    "nukleärare": "nukleär",
    "nukleärares": "nukleär",
    "nukleäras": "nukleär",
    "nukleärast": "nukleär",
    "nukleäraste": "nukleär",
    "nukleärastes": "nukleär",
    "nukleärasts": "nukleär",
    "nukleäre": "nukleär",
    "nukleäres": "nukleär",
    "nukleärs": "nukleär",
    "nukleärt": "nukleär",
    "nukleärts": "nukleär",
    "nukliden": "nuklid",
    "nuklidens": "nuklid",
    "nuklider": "nuklid",
    "nukliderna": "nuklid",
    "nuklidernas": "nuklid",
    "nukliders": "nuklid",
    "nuklids": "nuklid",
    "nulliteten": "nullitet",
    "nullitetens": "nullitet",
    "nulliteter": "nullitet",
    "nulliteterna": "nullitet",
    "nulliteternas": "nullitet",
    "nulliteters": "nullitet",
    "nullitets": "nullitet",
    "nuläges": "nuläge",
    "nuläget": "nuläge",
    "nulägets": "nuläge",
    "numens": "numen",
    "numeriska": "numerisk",
    "numeriskare": "numerisk",
    "numeriskares": "numerisk",
    "numeriskas": "numerisk",
    "numeriskast": "numerisk",
    "numeriskaste": "numerisk",
    "numeriskastes": "numerisk",
    "numeriskasts": "numerisk",
    "numeriske": "numerisk",
    "numeriskes": "numerisk",
    "numerisks": "numerisk",
    "numeriskt": "numerisk",
    "numeriskts": "numerisk",
    "numersen": "numerus",
    "numersens": "numerus",
    "numerset": "numerus",
    "numersets": "numerus",
    "numerusen": "numerus",
    "numerusens": "numerus",
    "numeruset": "numerus",
    "numerusets": "numerus",
    "numerära": "numerär",
    "numerärare": "numerär",
    "numerärares": "numerär",
    "numeräras": "numerär",
    "numerärast": "numerär",
    "numeräraste": "numerär",
    "numerärastes": "numerär",
    "numerärasts": "numerär",
    "numeräre": "numerär",
    "numerären": "numerär",
    "numerärens": "numerär",
    "numerärer": "numerär",
    "numerärerna": "numerär",
    "numerärernas": "numerär",
    "numerärers": "numerär",
    "numeräres": "numerär",
    "numerärs": "numerär",
    "numerärt": "numerär",
    "numerärts": "numerär",
    "numinösa": "numinös",
    "numinösare": "numinös",
    "numinösares": "numinös",
    "numinösas": "numinös",
    "numinösast": "numinös",
    "numinösaste": "numinös",
    "numinösastes": "numinös",
    "numinösasts": "numinös",
    "numinöse": "numinös",
    "numinöses": "numinös",
    "numinöst": "numinös",
    "numinösts": "numinös",
    "numismatiken": "numismatik",
    "numismatikens": "numismatik",
    "numismatikern": "numismatiker",
    "numismatikerna": "numismatiker",
    "numismatikernas": "numismatiker",
    "numismatikerns": "numismatiker",
    "numismatikers": "numismatiker",
    "numismatiks": "numismatik",
    "numismatiska": "numismatisk",
    "numismatiskare": "numismatisk",
    "numismatiskares": "numismatisk",
    "numismatiskas": "numismatisk",
    "numismatiskast": "numismatisk",
    "numismatiskaste": "numismatisk",
    "numismatiskastes": "numismatisk",
    "numismatiskasts": "numismatisk",
    "numismatiske": "numismatisk",
    "numismatiskes": "numismatisk",
    "numismatisks": "numismatisk",
    "numismatiskt": "numismatisk",
    "numismatiskts": "numismatisk",
    "nummens": "nummen",
    "nummerbrick": "nummerbricka",
    "nummerbrickan": "nummerbricka",
    "nummerbrickans": "nummerbricka",
    "nummerbrickas": "nummerbricka",
    "nummerbricke": "nummerbricka",
    "nummerbrickor": "nummerbricka",
    "nummerbrickorna": "nummerbricka",
    "nummerbrickornas": "nummerbricka",
    "nummerbrickors": "nummerbricka",
    "nummerbricks": "nummerbricka",
    "nummerbyråer": "nummerbyrå",
    "nummerbyråerna": "nummerbyrå",
    "nummerbyråernas": "nummerbyrå",
    "nummerbyråers": "nummerbyrå",
    "nummerbyrån": "nummerbyrå",
    "nummerbyråns": "nummerbyrå",
    "nummerbyrås": "nummerbyrå",
    "nummerflick": "nummerflicka",
    "nummerflickan": "nummerflicka",
    "nummerflickans": "nummerflicka",
    "nummerflickas": "nummerflicka",
    "nummerflicke": "nummerflicka",
    "nummerflickor": "nummerflicka",
    "nummerflickorna": "nummerflicka",
    "nummerflickornas": "nummerflicka",
    "nummerflickors": "nummerflicka",
    "nummerflicks": "nummerflicka",
    "nummerhästar": "nummerhäst",
    "nummerhästarna": "nummerhäst",
    "nummerhästarnas": "nummerhäst",
    "nummerhästars": "nummerhäst",
    "nummerhästen": "nummerhäst",
    "nummerhästens": "nummerhäst",
    "nummerhästs": "nummerhäst",
    "nummerkarlar": "nummerkarl",
    "nummerkarlarna": "nummerkarl",
    "nummerkarlarnas": "nummerkarl",
    "nummerkarlars": "nummerkarl",
    "nummerkarlen": "nummerkarl",
    "nummerkarlens": "nummerkarl",
    "nummerkarls": "nummerkarl",
    "nummerna": "nummer",
    "nummernas": "nummer",
    "nummerplåtar": "nummerplåt",
    "nummerplåtarna": "nummerplåt",
    "nummerplåtarnas": "nummerplåt",
    "nummerplåtars": "nummerplåt",
    "nummerplåten": "nummerplåt",
    "nummerplåtens": "nummerplåt",
    "nummerplåts": "nummerplåt",
    "nummerrevyer": "nummerrevy",
    "nummerrevyerna": "nummerrevy",
    "nummerrevyernas": "nummerrevy",
    "nummerrevyers": "nummerrevy",
    "nummerrevyn": "nummerrevy",
    "nummerrevyns": "nummerrevy",
    "nummerrevys": "nummerrevy",
    "nummers": "nummer",
    "nummerskivan": "nummerskiva",
    "nummerskivans": "nummerskiva",
    "nummerskivas": "nummerskiva",
    "nummerskive": "nummerskiva",
    "nummerskivor": "nummerskiva",
    "nummerskivorna": "nummerskiva",
    "nummerskivornas": "nummerskiva",
    "nummerskivors": "nummerskiva",
    "nummerskyltar": "nummerskylt",
    "nummerskyltarna": "nummerskylt",
    "nummerskyltarnas": "nummerskylt",
    "nummerskyltars": "nummerskylt",
    "nummerskylten": "nummerskylt",
    "nummerskyltens": "nummerskylt",
    "nummerskylts": "nummerskylt",
    "nummerskyltsbelysningar": "nummerskyltsbelysning",
    "nummerskyltsbelysningarna": "nummerskyltsbelysning",
    "nummerskyltsbelysningarnas": "nummerskyltsbelysning",
    "nummerskyltsbelysningars": "nummerskyltsbelysning",
    "nummerskyltsbelysningen": "nummerskyltsbelysning",
    "nummerskyltsbelysningens": "nummerskyltsbelysning",
    "nummerskyltsbelysnings": "nummerskyltsbelysning",
    "nummet": "nummen",
    "nummets": "nummen",
    "numna": "nummen",
    "numnare": "nummen",
    "numnares": "nummen",
    "numnas": "nummen",
    "numnast": "nummen",
    "numnaste": "nummen",
    "numnastes": "nummen",
    "numnasts": "nummen",
    "numne": "nummen",
    "numnes": "nummen",
    "numren": "nummer",
    "numrens": "nummer",
    "numrerad": "numrera",
    "numrerade": "numrera",
    "numrerades": "numrera",
    "numrerads": "numrera",
    "numrerande": "numrera",
    "numreranden": "numrerande",
    "numrerandena": "numrerande",
    "numrerandenas": "numrerande",
    "numrerandens": "numrerande",
    "numrerandes": "numrerande",
    "numrerandet": "numrerande",
    "numrerandets": "numrerande",
    "numrerar": "numrera",
    "numreras": "numrera",
    "numrerat": "numrera",
    "numrerats": "numrera",
    "numrerbara": "numrerbar",
    "numrerbarare": "numrerbar",
    "numrerbarares": "numrerbar",
    "numrerbaras": "numrerbar",
    "numrerbarast": "numrerbar",
    "numrerbaraste": "numrerbar",
    "numrerbarastes": "numrerbar",
    "numrerbarasts": "numrerbar",
    "numrerbare": "numrerbar",
    "numrerbares": "numrerbar",
    "numrerbarheten": "numrerbarhet",
    "numrerbarhetens": "numrerbarhet",
    "numrerbarhets": "numrerbarhet",
    "numrerbars": "numrerbar",
    "numrerbart": "numrerbar",
    "numrerbarts": "numrerbar",
    "numreringar": "numrering",
    "numreringarna": "numrering",
    "numreringarnas": "numrering",
    "numreringars": "numrering",
    "numreringen": "numrering",
    "numreringens": "numrering",
    "numrerings": "numrering",
    "numret": "nummer",
    "numrets": "nummer",
    "numros": "numro",
    "nun": "nuna",
    "nunan": "nuna",
    "nunans": "nuna",
    "nunas": "nuna",
    "nunatacken": "nunatack",
    "nunatackens": "nunatack",
    "nunatacker": "nunatack",
    "nunatackerna": "nunatack",
    "nunatackernas": "nunatack",
    "nunatackers": "nunatack",
    "nunatacks": "nunatack",
    "nunataken": "nunatak",
    "nunatakens": "nunatak",
    "nunataker": "nunatak",
    "nunatakerna": "nunatak",
    "nunatakernas": "nunatak",
    "nunatakers": "nunatak",
    "nunataks": "nunatak",
    "nune": "nuna",
    "nunn": "nunna",
    "nunnan": "nunna",
    "nunnans": "nunna",
    "nunnas": "nunna",
    "nunne": "nunna",
    "nunnedoken": "nunnedok",
    "nunnedokens": "nunnedok",
    "nunnedoket": "nunnedok",
    "nunnedokets": "nunnedok",
    "nunnedoks": "nunnedok",
    "nunneörten": "nunneört",
    "nunneörtens": "nunneört",
    "nunneörter": "nunneört",
    "nunneörterna": "nunneört",
    "nunneörternas": "nunneört",
    "nunneörters": "nunneört",
    "nunneörts": "nunneört",
    "nunnor": "nunna",
    "nunnorna": "nunna",
    "nunnornas": "nunna",
    "nunnors": "nunna",
    "nunns": "nunna",
    "nunor": "nuna",
    "nunorna": "nuna",
    "nunornas": "nuna",
    "nunors": "nuna",
    "nuns": "nuna",
    "nuntiaturen": "nuntiatur",
    "nuntiaturens": "nuntiatur",
    "nuntiaturer": "nuntiatur",
    "nuntiaturerna": "nuntiatur",
    "nuntiaturernas": "nuntiatur",
    "nuntiaturers": "nuntiatur",
    "nuntiaturs": "nuntiatur",
    "nuntien": "nuntie",
    "nuntiens": "nuntie",
    "nuntier": "nuntie",
    "nuntierna": "nuntie",
    "nuntiernas": "nuntie",
    "nuntiers": "nuntie",
    "nunties": "nuntie",
    "nupen": "nypa",
    "nupens": "nypa",
    "nupet": "nypa",
    "nupets": "nypa",
    "nupit": "nypa",
    "nupits": "nypa",
    "nupna": "nypa",
    "nupnas": "nypa",
    "nupne": "nypa",
    "nupnes": "nypa",
    "nusit": "nysa",
    "nusits": "nysa",
    "nuspråkliga": "nuspråklig",
    "nuspråkligare": "nuspråklig",
    "nuspråkligares": "nuspråklig",
    "nuspråkligas": "nuspråklig",
    "nuspråkligast": "nuspråklig",
    "nuspråkligaste": "nuspråklig",
    "nuspråkligastes": "nuspråklig",
    "nuspråkligasts": "nuspråklig",
    "nuspråklige": "nuspråklig",
    "nuspråkliges": "nuspråklig",
    "nuspråkligheten": "nuspråklighet",
    "nuspråklighetens": "nuspråklighet",
    "nuspråkligheter": "nuspråklighet",
    "nuspråkligheterna": "nuspråklighet",
    "nuspråkligheternas": "nuspråklighet",
    "nuspråkligheters": "nuspråklighet",
    "nuspråklighets": "nuspråklighet",
    "nuspråkligs": "nuspråklig",
    "nuspråkligt": "nuspråklig",
    "nuspråkligts": "nuspråklig",
    "nusvensk": "nusvenska",
    "nusvenska": "nusvensk",
    "nusvenskan": "nusvenska",
    "nusvenskans": "nusvenska",
    "nusvenskare": "nusvensk",
    "nusvenskares": "nusvensk",
    "nusvenskas": "nusvenska",
    "nusvenskast": "nusvensk",
    "nusvenskaste": "nusvensk",
    "nusvenskastes": "nusvensk",
    "nusvenskasts": "nusvensk",
    "nusvenske": "nusvensk",
    "nusvenskes": "nusvensk",
    "nusvensks": "nusvensk",
    "nusvenskt": "nusvensk",
    "nusvenskts": "nusvensk",
    "nutiden": "nutid",
    "nutidens": "nutid",
    "nutids": "nutid",
    "nutidsfixerade": "nutidsfixerad",
    "nutidsfixerades": "nutidsfixerad",
    "nutidsfixerads": "nutidsfixerad",
    "nutidsfixerat": "nutidsfixerad",
    "nutidsfixerats": "nutidsfixerad",
    "nutidshistorian": "nutidshistoria",
    "nutidshistorians": "nutidshistoria",
    "nutidshistorias": "nutidshistoria",
    "nutidshistorien": "nutidshistoria",
    "nutidshistoriens": "nutidshistoria",
    "nutidshistorier": "nutidshistoria",
    "nutidshistorierna": "nutidshistoria",
    "nutidshistoriernas": "nutidshistoria",
    "nutidshistoriers": "nutidshistoria",
    "nutidsorienterade": "nutidsorienterad",
    "nutidsorienterades": "nutidsorienterad",
    "nutidsorienterads": "nutidsorienterad",
    "nutidsorienterat": "nutidsorienterad",
    "nutidsorienterats": "nutidsorienterad",
    "nutidsorienteringar": "nutidsorientering",
    "nutidsorienteringarna": "nutidsorientering",
    "nutidsorienteringarnas": "nutidsorientering",
    "nutidsorienteringars": "nutidsorientering",
    "nutidsorienteringen": "nutidsorientering",
    "nutidsorienteringens": "nutidsorientering",
    "nutidsorienterings": "nutidsorientering",
    "nutidstesten": "nutidstest",
    "nutidstestens": "nutidstest",
    "nutidstester": "nutidstest",
    "nutidstesterna": "nutidstest",
    "nutidstesternas": "nutidstest",
    "nutidstesters": "nutidstest",
    "nutidstestet": "nutidstest",
    "nutidstestets": "nutidstest",
    "nutidstests": "nutidstest",
    "nutrian": "nutria",
    "nutrians": "nutria",
    "nutrias": "nutria",
    "nutritionen": "nutrition",
    "nutritionens": "nutrition",
    "nutritioner": "nutrition",
    "nutritionerna": "nutrition",
    "nutritionernas": "nutrition",
    "nutritioners": "nutrition",
    "nutritions": "nutrition",
    "nutritionsorganen": "nutritionsorgan",
    "nutritionsorganens": "nutritionsorgan",
    "nutritionsorganet": "nutritionsorgan",
    "nutritionsorganets": "nutritionsorgan",
    "nutritionsorgans": "nutritionsorgan",
    "nutritiva": "nutritiv",
    "nutritivare": "nutritiv",
    "nutritivares": "nutritiv",
    "nutritivas": "nutritiv",
    "nutritivast": "nutritiv",
    "nutritivaste": "nutritiv",
    "nutritivastes": "nutritiv",
    "nutritivasts": "nutritiv",
    "nutritive": "nutritiv",
    "nutritives": "nutritiv",
    "nutritivs": "nutritiv",
    "nutritivt": "nutritiv",
    "nutritivts": "nutritiv",
    "nuviga": "nuvig",
    "nuvigare": "nuvig",
    "nuvigares": "nuvig",
    "nuvigas": "nuvig",
    "nuvigast": "nuvig",
    "nuvigaste": "nuvig",
    "nuvigastes": "nuvig",
    "nuvigasts": "nuvig",
    "nuvige": "nuvig",
    "nuviges": "nuvig",
    "nuvigs": "nuvig",
    "nuvigt": "nuvig",
    "nuvigts": "nuvig",
    "nya": "ny",
    "nyagnade": "nyagnad",
    "nyagnades": "nyagnad",
    "nyagnads": "nyagnad",
    "nyagnat": "nyagnad",
    "nyagnats": "nyagnad",
    "nyanla": "nyanlägga",
    "nyanlade": "nyanlägga",
    "nyanlades": "nyanlägga",
    "nyanlagd": "nyanlägga",
    "nyanlagda": "nyanlägga",
    "nyanlagdas": "nyanlägga",
    "nyanlagde": "nyanlägga",
    "nyanlagdes": "nyanlägga",
    "nyanlagds": "nyanlägga",
    "nyanlagt": "nyanlägga",
    "nyanlagts": "nyanlägga",
    "nyanlas": "nyanlägga",
    "nyanlägg": "nyanlägga",
    "nyanläggande": "nyanlägga",
    "nyanlägganden": "nyanläggande",
    "nyanläggandena": "nyanläggande",
    "nyanläggandenas": "nyanläggande",
    "nyanläggandens": "nyanläggande",
    "nyanläggandes": "nyanläggande",
    "nyanläggandet": "nyanläggande",
    "nyanläggandets": "nyanläggande",
    "nyanläggas": "nyanlägga",
    "nyanlägger": "nyanlägga",
    "nyanlägges": "nyanlägga",
    "nyanläggningar": "nyanläggning",
    "nyanläggningarna": "nyanläggning",
    "nyanläggningarnas": "nyanläggning",
    "nyanläggningars": "nyanläggning",
    "nyanläggningen": "nyanläggning",
    "nyanläggningens": "nyanläggning",
    "nyanläggnings": "nyanläggning",
    "nyanläggs": "nyanlägga",
    "nyansen": "nyans",
    "nyansens": "nyans",
    "nyanser": "nyans",
    "nyanserad": "nyansera",
    "nyanserade": "nyanserad",
    "nyanserades": "nyanserad",
    "nyanserads": "nyanserad",
    "nyanserande": "nyansera",
    "nyanseranden": "nyanserande",
    "nyanserandena": "nyanserande",
    "nyanserandenas": "nyanserande",
    "nyanserandens": "nyanserande",
    "nyanserandes": "nyanserande",
    "nyanserandet": "nyanserande",
    "nyanserandets": "nyanserande",
    "nyanserar": "nyansera",
    "nyanseras": "nyansera",
    "nyanserat": "nyanserad",
    "nyanserats": "nyanserad",
    "nyanserbara": "nyanserbar",
    "nyanserbarare": "nyanserbar",
    "nyanserbarares": "nyanserbar",
    "nyanserbaras": "nyanserbar",
    "nyanserbarast": "nyanserbar",
    "nyanserbaraste": "nyanserbar",
    "nyanserbarastes": "nyanserbar",
    "nyanserbarasts": "nyanserbar",
    "nyanserbare": "nyanserbar",
    "nyanserbares": "nyanserbar",
    "nyanserbarheten": "nyanserbarhet",
    "nyanserbarhetens": "nyanserbarhet",
    "nyanserbarhets": "nyanserbarhet",
    "nyanserbars": "nyanserbar",
    "nyanserbart": "nyanserbar",
    "nyanserbarts": "nyanserbar",
    "nyanseringar": "nyansering",
    "nyanseringarna": "nyansering",
    "nyanseringarnas": "nyansering",
    "nyanseringars": "nyansering",
    "nyanseringen": "nyansering",
    "nyanseringens": "nyansering",
    "nyanserings": "nyansering",
    "nyanseringsteckens": "nyanseringstecken",
    "nyanseringstecknen": "nyanseringstecken",
    "nyanseringstecknens": "nyanseringstecken",
    "nyanseringstecknet": "nyanseringstecken",
    "nyanseringstecknets": "nyanseringstecken",
    "nyanserna": "nyans",
    "nyansernas": "nyans",
    "nyansers": "nyans",
    "nyanskaffningar": "nyanskaffning",
    "nyanskaffningarna": "nyanskaffning",
    "nyanskaffningarnas": "nyanskaffning",
    "nyanskaffningars": "nyanskaffning",
    "nyanskaffningen": "nyanskaffning",
    "nyanskaffningens": "nyanskaffning",
    "nyanskaffnings": "nyanskaffning",
    "nyanställ": "nyanställa",
    "nyanställande": "nyanställa",
    "nyanställanden": "nyanställande",
    "nyanställandena": "nyanställande",
    "nyanställandenas": "nyanställande",
    "nyanställandens": "nyanställande",
    "nyanställandes": "nyanställande",
    "nyanställandet": "nyanställande",
    "nyanställandets": "nyanställande",
    "nyanställas": "nyanställa",
    "nyanställd": "nyanställa",
    "nyanställda": "nyanställa",
    "nyanställdas": "nyanställa",
    "nyanställde": "nyanställa",
    "nyanställdes": "nyanställa",
    "nyanställds": "nyanställa",
    "nyanställer": "nyanställa",
    "nyanställes": "nyanställa",
    "nyanställs": "nyanställa",
    "nyanställt": "nyanställa",
    "nyanställts": "nyanställa",
    "nyantika": "nyantik",
    "nyantikare": "nyantik",
    "nyantikares": "nyantik",
    "nyantikas": "nyantik",
    "nyantikast": "nyantik",
    "nyantikaste": "nyantik",
    "nyantikastes": "nyantik",
    "nyantikasts": "nyantik",
    "nyantike": "nyantik",
    "nyantiken": "nyantik",
    "nyantikens": "nyantik",
    "nyantikes": "nyantik",
    "nyantiks": "nyantik",
    "nyantikt": "nyantik",
    "nyantikts": "nyantik",
    "nyare": "ny",
    "nyares": "ny",
    "nyas": "ny",
    "nyast": "ny",
    "nyaste": "ny",
    "nyastes": "ny",
    "nyasts": "ny",
    "nybakade": "nybakad",
    "nybakades": "nybakad",
    "nybakads": "nybakad",
    "nybakat": "nybakad",
    "nybakats": "nybakad",
    "nybearbetningar": "nybearbetning",
    "nybearbetningarna": "nybearbetning",
    "nybearbetningarnas": "nybearbetning",
    "nybearbetningars": "nybearbetning",
    "nybearbetningen": "nybearbetning",
    "nybearbetningens": "nybearbetning",
    "nybearbetnings": "nybearbetning",
    "nybildade": "nybildad",
    "nybildades": "nybildad",
    "nybildads": "nybildad",
    "nybildat": "nybildad",
    "nybildats": "nybildad",
    "nybildningar": "nybildning",
    "nybildningarna": "nybildning",
    "nybildningarnas": "nybildning",
    "nybildningars": "nybildning",
    "nybildningen": "nybildning",
    "nybildningens": "nybildning",
    "nybildnings": "nybildning",
    "nyblivens": "nybliven",
    "nyblivet": "nybliven",
    "nyblivets": "nybliven",
    "nyblivna": "nybliven",
    "nyblivnare": "nybliven",
    "nyblivnares": "nybliven",
    "nyblivnas": "nybliven",
    "nyblivnast": "nybliven",
    "nyblivnaste": "nybliven",
    "nyblivnastes": "nybliven",
    "nyblivnasts": "nybliven",
    "nyblivne": "nybliven",
    "nyblivnes": "nybliven",
    "nybrutens": "nybruten",
    "nybrutet": "nybruten",
    "nybrutets": "nybruten",
    "nybrutna": "nybruten",
    "nybrutnare": "nybruten",
    "nybrutnares": "nybruten",
    "nybrutnas": "nybruten",
    "nybrutnast": "nybruten",
    "nybrutnaste": "nybruten",
    "nybrutnastes": "nybruten",
    "nybrutnasts": "nybruten",
    "nybrutne": "nybruten",
    "nybrutnes": "nybruten",
    "nyburens": "nyburen",
    "nyburet": "nyburen",
    "nyburets": "nyburen",
    "nyburna": "nyburen",
    "nyburnare": "nyburen",
    "nyburnares": "nyburen",
    "nyburnas": "nyburen",
    "nyburnast": "nyburen",
    "nyburnaste": "nyburen",
    "nyburnastes": "nyburen",
    "nyburnasts": "nyburen",
    "nyburne": "nyburen",
    "nyburnes": "nyburen",
    "nybyggar": "nybyggare",
    "nybyggaren": "nybyggare",
    "nybyggarens": "nybyggare",
    "nybyggares": "nybyggare",
    "nybyggarna": "nybyggare",
    "nybyggarnas": "nybyggare",
    "nybyggda": "nybyggd",
    "nybyggdare": "nybyggd",
    "nybyggdares": "nybyggd",
    "nybyggdas": "nybyggd",
    "nybyggdast": "nybyggd",
    "nybyggdaste": "nybyggd",
    "nybyggdastes": "nybyggd",
    "nybyggdasts": "nybyggd",
    "nybyggde": "nybyggd",
    "nybyggdes": "nybyggd",
    "nybyggds": "nybyggd",
    "nybyggen": "nybygge",
    "nybyggena": "nybygge",
    "nybyggenas": "nybygge",
    "nybyggens": "nybygge",
    "nybygges": "nybygge",
    "nybygget": "nybygge",
    "nybyggets": "nybygge",
    "nybyggnaden": "nybyggnad",
    "nybyggnadens": "nybyggnad",
    "nybyggnader": "nybyggnad",
    "nybyggnaderna": "nybyggnad",
    "nybyggnadernas": "nybyggnad",
    "nybyggnaders": "nybyggnad",
    "nybyggnads": "nybyggnad",
    "nybyggt": "nybyggd",
    "nybyggts": "nybyggd",
    "nybörjar": "nybörjare",
    "nybörjarboken": "nybörjarbok",
    "nybörjarbokens": "nybörjarbok",
    "nybörjarboks": "nybörjarbok",
    "nybörjarbåg": "nybörjarbåge",
    "nybörjarbågar": "nybörjarbåge",
    "nybörjarbågarna": "nybörjarbåge",
    "nybörjarbågarnas": "nybörjarbåge",
    "nybörjarbågars": "nybörjarbåge",
    "nybörjarbågen": "nybörjarbåge",
    "nybörjarbågens": "nybörjarbåge",
    "nybörjarbåges": "nybörjarbåge",
    "nybörjarbågs": "nybörjarbåge",
    "nybörjarböcker": "nybörjarbok",
    "nybörjarböckerna": "nybörjarbok",
    "nybörjarböckernas": "nybörjarbok",
    "nybörjarböckers": "nybörjarbok",
    "nybörjaren": "nybörjare",
    "nybörjarens": "nybörjare",
    "nybörjares": "nybörjare",
    "nybörjarna": "nybörjare",
    "nybörjarnas": "nybörjare",
    "nybörjarseten": "nybörjarset",
    "nybörjarsetens": "nybörjarset",
    "nybörjarsetet": "nybörjarset",
    "nybörjarsetets": "nybörjarset",
    "nybörjarsets": "nybörjarset",
    "nyckelaxen": "nyckelax",
    "nyckelaxens": "nyckelax",
    "nyckelaxet": "nyckelax",
    "nyckelaxets": "nyckelax",
    "nyckelbarnen": "nyckelbarn",
    "nyckelbarnens": "nyckelbarn",
    "nyckelbarnet": "nyckelbarn",
    "nyckelbarnets": "nyckelbarn",
    "nyckelbarns": "nyckelbarn",
    "nyckelbenen": "nyckelben",
    "nyckelbenens": "nyckelben",
    "nyckelbenet": "nyckelben",
    "nyckelbenets": "nyckelben",
    "nyckelbens": "nyckelben",
    "nyckelblomsterna": "nyckelblomster",
    "nyckelblomsternas": "nyckelblomster",
    "nyckelblomsters": "nyckelblomster",
    "nyckelblomstren": "nyckelblomster",
    "nyckelblomstrens": "nyckelblomster",
    "nyckelblomstret": "nyckelblomster",
    "nyckelblomstrets": "nyckelblomster",
    "nyckelfunktionen": "nyckelfunktion",
    "nyckelfunktionens": "nyckelfunktion",
    "nyckelfunktioner": "nyckelfunktion",
    "nyckelfunktionerna": "nyckelfunktion",
    "nyckelfunktionernas": "nyckelfunktion",
    "nyckelfunktioners": "nyckelfunktion",
    "nyckelfunktions": "nyckelfunktion",
    "nyckelfärdiga": "nyckelfärdig",
    "nyckelfärdigare": "nyckelfärdig",
    "nyckelfärdigares": "nyckelfärdig",
    "nyckelfärdigas": "nyckelfärdig",
    "nyckelfärdigast": "nyckelfärdig",
    "nyckelfärdigaste": "nyckelfärdig",
    "nyckelfärdigastes": "nyckelfärdig",
    "nyckelfärdigasts": "nyckelfärdig",
    "nyckelfärdige": "nyckelfärdig",
    "nyckelfärdiges": "nyckelfärdig",
    "nyckelfärdigs": "nyckelfärdig",
    "nyckelfärdigt": "nyckelfärdig",
    "nyckelfärdigts": "nyckelfärdig",
    "nyckelharp": "nyckelharpa",
    "nyckelharpan": "nyckelharpa",
    "nyckelharpans": "nyckelharpa",
    "nyckelharpas": "nyckelharpa",
    "nyckelharpe": "nyckelharpa",
    "nyckelharpor": "nyckelharpa",
    "nyckelharporna": "nyckelharpa",
    "nyckelharpornas": "nyckelharpa",
    "nyckelharpors": "nyckelharpa",
    "nyckelharps": "nyckelharpa",
    "nyckelhålen": "nyckelhål",
    "nyckelhålens": "nyckelhål",
    "nyckelhålet": "nyckelhål",
    "nyckelhålets": "nyckelhål",
    "nyckelhåls": "nyckelhål",
    "nyckelindustrien": "nyckelindustri",
    "nyckelindustriens": "nyckelindustri",
    "nyckelindustrier": "nyckelindustri",
    "nyckelindustrierna": "nyckelindustri",
    "nyckelindustriernas": "nyckelindustri",
    "nyckelindustriers": "nyckelindustri",
    "nyckelindustrin": "nyckelindustri",
    "nyckelindustrins": "nyckelindustri",
    "nyckelindustris": "nyckelindustri",
    "nyckelinslagen": "nyckelinslag",
    "nyckelinslagens": "nyckelinslag",
    "nyckelinslaget": "nyckelinslag",
    "nyckelinslagets": "nyckelinslag",
    "nyckelinslags": "nyckelinslag",
    "nyckelknipp": "nyckelknippa",
    "nyckelknippan": "nyckelknippa",
    "nyckelknippans": "nyckelknippa",
    "nyckelknippas": "nyckelknippa",
    "nyckelknippe": "nyckelknippa",
    "nyckelknippor": "nyckelknippa",
    "nyckelknipporna": "nyckelknippa",
    "nyckelknippornas": "nyckelknippa",
    "nyckelknippors": "nyckelknippa",
    "nyckelknipps": "nyckelknippa",
    "nyckelkorten": "nyckelkort",
    "nyckelkortens": "nyckelkort",
    "nyckelkortet": "nyckelkort",
    "nyckelkortets": "nyckelkort",
    "nyckelkorts": "nyckelkort",
    "nyckelmannen": "nyckelman",
    "nyckelmannens": "nyckelman",
    "nyckelmans": "nyckelman",
    "nyckelmän": "nyckelman",
    "nyckelmännen": "nyckelman",
    "nyckelmännens": "nyckelman",
    "nyckelmäns": "nyckelman",
    "nyckeln": "nyckel",
    "nyckelns": "nyckel",
    "nyckelorden": "nyckelord",
    "nyckelordens": "nyckelord",
    "nyckelordet": "nyckelord",
    "nyckelordets": "nyckelord",
    "nyckelords": "nyckelord",
    "nyckelpersonen": "nyckelperson",
    "nyckelpersonens": "nyckelperson",
    "nyckelpersoner": "nyckelperson",
    "nyckelpersonerna": "nyckelperson",
    "nyckelpersonernas": "nyckelperson",
    "nyckelpersoners": "nyckelperson",
    "nyckelpersons": "nyckelperson",
    "nyckelpig": "nyckelpiga",
    "nyckelpigan": "nyckelpiga",
    "nyckelpigans": "nyckelpiga",
    "nyckelpigas": "nyckelpiga",
    "nyckelpige": "nyckelpiga",
    "nyckelpigor": "nyckelpiga",
    "nyckelpigorna": "nyckelpiga",
    "nyckelpigornas": "nyckelpiga",
    "nyckelpigors": "nyckelpiga",
    "nyckelpigs": "nyckelpiga",
    "nyckelpositionen": "nyckelposition",
    "nyckelpositionens": "nyckelposition",
    "nyckelpositioner": "nyckelposition",
    "nyckelpositionerna": "nyckelposition",
    "nyckelpositionernas": "nyckelposition",
    "nyckelpositioners": "nyckelposition",
    "nyckelpositions": "nyckelposition",
    "nyckelretningar": "nyckelretning",
    "nyckelretningarna": "nyckelretning",
    "nyckelretningarnas": "nyckelretning",
    "nyckelretningars": "nyckelretning",
    "nyckelretningen": "nyckelretning",
    "nyckelretningens": "nyckelretning",
    "nyckelretnings": "nyckelretning",
    "nyckelrollen": "nyckelroll",
    "nyckelrollens": "nyckelroll",
    "nyckelroller": "nyckelroll",
    "nyckelrollerna": "nyckelroll",
    "nyckelrollernas": "nyckelroll",
    "nyckelrollers": "nyckelroll",
    "nyckelrolls": "nyckelroll",
    "nyckelromanen": "nyckelroman",
    "nyckelromanens": "nyckelroman",
    "nyckelromaner": "nyckelroman",
    "nyckelromanerna": "nyckelroman",
    "nyckelromanernas": "nyckelroman",
    "nyckelromaners": "nyckelroman",
    "nyckelromans": "nyckelroman",
    "nyckels": "nyckel",
    "nyckelskåpen": "nyckelskåp",
    "nyckelskåpens": "nyckelskåp",
    "nyckelskåpet": "nyckelskåp",
    "nyckelskåpets": "nyckelskåp",
    "nyckelskåps": "nyckelskåp",
    "nyckelstenar": "nyckelsten",
    "nyckelstenarna": "nyckelsten",
    "nyckelstenarnas": "nyckelsten",
    "nyckelstenars": "nyckelsten",
    "nyckelstenen": "nyckelsten",
    "nyckelstenens": "nyckelsten",
    "nyckelstens": "nyckelsten",
    "nyckelämnen": "nyckelämne",
    "nyckelämnena": "nyckelämne",
    "nyckelämnenas": "nyckelämne",
    "nyckelämnens": "nyckelämne",
    "nyckelämnes": "nyckelämne",
    "nyckelämnet": "nyckelämne",
    "nyckelämnets": "nyckelämne",
    "nycken": "nyck",
    "nyckens": "nyck",
    "nycker": "nyck",
    "nyckerna": "nyck",
    "nyckernas": "nyck",
    "nyckers": "nyck",
    "nyckfulla": "nyckfull",
    "nyckfullare": "nyckfull",
    "nyckfullares": "nyckfull",
    "nyckfullas": "nyckfull",
    "nyckfullast": "nyckfull",
    "nyckfullaste": "nyckfull",
    "nyckfullastes": "nyckfull",
    "nyckfullasts": "nyckfull",
    "nyckfulle": "nyckfull",
    "nyckfulles": "nyckfull",
    "nyckfullheten": "nyckfullhet",
    "nyckfullhetens": "nyckfullhet",
    "nyckfullheter": "nyckfullhet",
    "nyckfullheterna": "nyckfullhet",
    "nyckfullheternas": "nyckfullhet",
    "nyckfullheters": "nyckfullhet",
    "nyckfullhets": "nyckfullhet",
    "nyckfulls": "nyckfull",
    "nyckfullt": "nyckfull",
    "nyckfullts": "nyckfull",
    "nycklar": "nyckel",
    "nycklarna": "nyckel",
    "nycklarnas": "nyckel",
    "nycklars": "nyckel",
    "nycks": "nyck",
    "nydan": "nydana",
    "nydanad": "nydana",
    "nydanade": "nydana",
    "nydanades": "nydana",
    "nydanads": "nydana",
    "nydanande": "nydana",
    "nydananden": "nydanande",
    "nydanandena": "nydanande",
    "nydanandenas": "nydanande",
    "nydanandens": "nydanande",
    "nydanandes": "nydanande",
    "nydanandet": "nydanande",
    "nydanandets": "nydanande",
    "nydanar": "nydanare",
    "nydanaren": "nydanare",
    "nydanarens": "nydanare",
    "nydanares": "nydanare",
    "nydanarna": "nydanare",
    "nydanarnas": "nydanare",
    "nydanas": "nydana",
    "nydanat": "nydana",
    "nydanats": "nydana",
    "nydaningar": "nydaning",
    "nydaningarna": "nydaning",
    "nydaningarnas": "nydaning",
    "nydaningars": "nydaning",
    "nydaningen": "nydaning",
    "nydaningens": "nydaning",
    "nydanings": "nydaning",
    "nyduschade": "nyduschad",
    "nyduschades": "nyduschad",
    "nyduschads": "nyduschad",
    "nyduschat": "nyduschad",
    "nyduschats": "nyduschad",
    "nye": "ny",
    "nyemissionen": "nyemission",
    "nyemissionens": "nyemission",
    "nyemissioner": "nyemission",
    "nyemissionerna": "nyemission",
    "nyemissionernas": "nyemission",
    "nyemissioners": "nyemission",
    "nyemissions": "nyemission",
    "nyemitterad": "nyemittera",
    "nyemitterade": "nyemittera",
    "nyemitterades": "nyemittera",
    "nyemitterads": "nyemittera",
    "nyemitterande": "nyemittera",
    "nyemitteranden": "nyemitterande",
    "nyemitterandena": "nyemitterande",
    "nyemitterandenas": "nyemitterande",
    "nyemitterandens": "nyemitterande",
    "nyemitterandes": "nyemitterande",
    "nyemitterandet": "nyemitterande",
    "nyemitterandets": "nyemitterande",
    "nyemitterar": "nyemittera",
    "nyemitteras": "nyemittera",
    "nyemitterat": "nyemittera",
    "nyemitterats": "nyemittera",
    "nyemitterbara": "nyemitterbar",
    "nyemitterbarare": "nyemitterbar",
    "nyemitterbarares": "nyemitterbar",
    "nyemitterbaras": "nyemitterbar",
    "nyemitterbarast": "nyemitterbar",
    "nyemitterbaraste": "nyemitterbar",
    "nyemitterbarastes": "nyemitterbar",
    "nyemitterbarasts": "nyemitterbar",
    "nyemitterbare": "nyemitterbar",
    "nyemitterbares": "nyemitterbar",
    "nyemitterbarheten": "nyemitterbarhet",
    "nyemitterbarhetens": "nyemitterbarhet",
    "nyemitterbarhets": "nyemitterbarhet",
    "nyemitterbars": "nyemitterbar",
    "nyemitterbart": "nyemitterbar",
    "nyemitterbarts": "nyemitterbar",
    "nyemitteringar": "nyemittering",
    "nyemitteringarna": "nyemittering",
    "nyemitteringarnas": "nyemittering",
    "nyemitteringars": "nyemittering",
    "nyemitteringen": "nyemittering",
    "nyemitteringens": "nyemittering",
    "nyemitterings": "nyemittering",
    "nyen": "ny",
    "nyenkels": "nyenkel",
    "nyenkelt": "nyenkel",
    "nyenkelts": "nyenkel",
    "nyenkla": "nyenkel",
    "nyenklare": "nyenkel",
    "nyenklares": "nyenkel",
    "nyenklas": "nyenkel",
    "nyenklast": "nyenkel",
    "nyenklaste": "nyenkel",
    "nyenklastes": "nyenkel",
    "nyenklasts": "nyenkel",
    "nyenkle": "nyenkel",
    "nyenkles": "nyenkel",
    "nyens": "ny",
    "nyes": "ny",
    "nyet": "ny",
    "nyetablerad": "nyetablera",
    "nyetablerade": "nyetablera",
    "nyetablerades": "nyetablera",
    "nyetablerads": "nyetablera",
    "nyetablerande": "nyetablera",
    "nyetableranden": "nyetablerande",
    "nyetablerandena": "nyetablerande",
    "nyetablerandenas": "nyetablerande",
    "nyetablerandens": "nyetablerande",
    "nyetablerandes": "nyetablerande",
    "nyetablerandet": "nyetablerande",
    "nyetablerandets": "nyetablerande",
    "nyetablerar": "nyetablera",
    "nyetableras": "nyetablera",
    "nyetablerat": "nyetablera",
    "nyetablerats": "nyetablera",
    "nyetablerbara": "nyetablerbar",
    "nyetablerbarare": "nyetablerbar",
    "nyetablerbarares": "nyetablerbar",
    "nyetablerbaras": "nyetablerbar",
    "nyetablerbarast": "nyetablerbar",
    "nyetablerbaraste": "nyetablerbar",
    "nyetablerbarastes": "nyetablerbar",
    "nyetablerbarasts": "nyetablerbar",
    "nyetablerbare": "nyetablerbar",
    "nyetablerbares": "nyetablerbar",
    "nyetablerbarheten": "nyetablerbarhet",
    "nyetablerbarhetens": "nyetablerbarhet",
    "nyetablerbarhets": "nyetablerbarhet",
    "nyetablerbars": "nyetablerbar",
    "nyetablerbart": "nyetablerbar",
    "nyetablerbarts": "nyetablerbar",
    "nyetableringar": "nyetablering",
    "nyetableringarna": "nyetablering",
    "nyetableringarnas": "nyetablering",
    "nyetableringars": "nyetablering",
    "nyetableringen": "nyetablering",
    "nyetableringens": "nyetablering",
    "nyetablerings": "nyetablering",
    "nyets": "ny",
    "nyexaminerade": "nyexaminerad",
    "nyexaminerades": "nyexaminerad",
    "nyexaminerads": "nyexaminerad",
    "nyexaminerat": "nyexaminerad",
    "nyexaminerats": "nyexaminerad",
    "nyfallens": "nyfallen",
    "nyfallet": "nyfallen",
    "nyfallets": "nyfallen",
    "nyfallna": "nyfallen",
    "nyfallnare": "nyfallen",
    "nyfallnares": "nyfallen",
    "nyfallnas": "nyfallen",
    "nyfallnast": "nyfallen",
    "nyfallnaste": "nyfallen",
    "nyfallnastes": "nyfallen",
    "nyfallnasts": "nyfallen",
    "nyfallne": "nyfallen",
    "nyfallnes": "nyfallen",
    "nyfascismen": "nyfascism",
    "nyfascismens": "nyfascism",
    "nyfascismer": "nyfascism",
    "nyfascismerna": "nyfascism",
    "nyfascismernas": "nyfascism",
    "nyfascismers": "nyfascism",
    "nyfascisms": "nyfascism",
    "nyfascistiska": "nyfascistisk",
    "nyfascistiskas": "nyfascistisk",
    "nyfascistiske": "nyfascistisk",
    "nyfascistiskes": "nyfascistisk",
    "nyfascistisks": "nyfascistisk",
    "nyfascistiskt": "nyfascistisk",
    "nyfascistiskts": "nyfascistisk",
    "nyfikenheten": "nyfikenhet",
    "nyfikenhetens": "nyfikenhet",
    "nyfikenheter": "nyfikenhet",
    "nyfikenheterna": "nyfikenhet",
    "nyfikenheternas": "nyfikenhet",
    "nyfikenheters": "nyfikenhet",
    "nyfikenhets": "nyfikenhet",
    "nyfikens": "nyfiken",
    "nyfiket": "nyfiken",
    "nyfikets": "nyfiken",
    "nyfikna": "nyfiken",
    "nyfiknare": "nyfiken",
    "nyfiknares": "nyfiken",
    "nyfiknas": "nyfiken",
    "nyfiknast": "nyfiken",
    "nyfiknaste": "nyfiken",
    "nyfiknastes": "nyfiken",
    "nyfiknasts": "nyfiken",
    "nyfikne": "nyfiken",
    "nyfiknes": "nyfiken",
    "nyfriserade": "nyfriserad",
    "nyfriserades": "nyfriserad",
    "nyfriserads": "nyfriserad",
    "nyfriserat": "nyfriserad",
    "nyfriserats": "nyfriserad",
    "nyfödda": "nyfödd",
    "nyföddare": "nyfödd",
    "nyföddares": "nyfödd",
    "nyföddas": "nyfödd",
    "nyföddast": "nyfödd",
    "nyföddaste": "nyfödd",
    "nyföddastes": "nyfödd",
    "nyföddasts": "nyfödd",
    "nyfödde": "nyfödd",
    "nyföddes": "nyfödd",
    "nyfödds": "nyfödd",
    "nyförvärvade": "nyförvärvad",
    "nyförvärvades": "nyförvärvad",
    "nyförvärvads": "nyförvärvad",
    "nyförvärvat": "nyförvärvad",
    "nyförvärvats": "nyförvärvad",
    "nyförvärven": "nyförvärv",
    "nyförvärvens": "nyförvärv",
    "nyförvärvet": "nyförvärv",
    "nyförvärvets": "nyförvärv",
    "nyförvärvs": "nyförvärv",
    "nyfött": "nyfödd",
    "nyfötts": "nyfödd",
    "nygamla": "nygammal",
    "nygamlas": "nygammal",
    "nygamle": "nygammal",
    "nygamles": "nygammal",
    "nygammals": "nygammal",
    "nygammalt": "nygammal",
    "nygammalts": "nygammal",
    "nygifta": "nygift",
    "nygiftare": "nygift",
    "nygiftares": "nygift",
    "nygiftas": "nygift",
    "nygiftast": "nygift",
    "nygiftaste": "nygift",
    "nygiftastes": "nygift",
    "nygiftasts": "nygift",
    "nygifte": "nygift",
    "nygiftes": "nygift",
    "nygifts": "nygift",
    "nygotiken": "nygotik",
    "nygotikens": "nygotik",
    "nygotiks": "nygotik",
    "nygraden": "nygrad",
    "nygradens": "nygrad",
    "nygrader": "nygrad",
    "nygraderna": "nygrad",
    "nygradernas": "nygrad",
    "nygraders": "nygrad",
    "nygrads": "nygrad",
    "nygrekisk": "nygrekiska",
    "nygrekiskan": "nygrekiska",
    "nygrekiskans": "nygrekiska",
    "nygrekiskas": "nygrekiska",
    "nygrundade": "nygrundad",
    "nygrundades": "nygrundad",
    "nygrundads": "nygrundad",
    "nygrundat": "nygrundad",
    "nygrundats": "nygrundad",
    "nygräddade": "nygräddad",
    "nygräddades": "nygräddad",
    "nygräddads": "nygräddad",
    "nygräddat": "nygräddad",
    "nygräddats": "nygräddad",
    "nygångens": "nygången",
    "nygånget": "nygången",
    "nygångets": "nygången",
    "nygångna": "nygången",
    "nygångnare": "nygången",
    "nygångnares": "nygången",
    "nygångnas": "nygången",
    "nygångnast": "nygången",
    "nygångnaste": "nygången",
    "nygångnastes": "nygången",
    "nygångnasts": "nygången",
    "nygångne": "nygången",
    "nygångnes": "nygången",
    "nyheten": "nyhet",
    "nyhetens": "nyhet",
    "nyheter": "nyhet",
    "nyheterna": "nyhet",
    "nyheternas": "nyhet",
    "nyheters": "nyhet",
    "nyhetiseringar": "nyhetisering",
    "nyhetiseringarna": "nyhetisering",
    "nyhetiseringarnas": "nyhetisering",
    "nyhetiseringars": "nyhetisering",
    "nyhetiseringen": "nyhetisering",
    "nyhetiseringens": "nyhetisering",
    "nyhetiserings": "nyhetisering",
    "nyhets": "nyhet",
    "nyhetsankar": "nyhetsankare",
    "nyhetsankaren": "nyhetsankare",
    "nyhetsankarens": "nyhetsankare",
    "nyhetsankares": "nyhetsankare",
    "nyhetsankaret": "nyhetsankare",
    "nyhetsankarets": "nyhetsankare",
    "nyhetsankarna": "nyhetsankare",
    "nyhetsankarnas": "nyhetsankare",
    "nyhetsbevakningar": "nyhetsbevakning",
    "nyhetsbevakningarna": "nyhetsbevakning",
    "nyhetsbevakningarnas": "nyhetsbevakning",
    "nyhetsbevakningars": "nyhetsbevakning",
    "nyhetsbevakningen": "nyhetsbevakning",
    "nyhetsbevakningens": "nyhetsbevakning",
    "nyhetsbevaknings": "nyhetsbevakning",
    "nyhetsbyråer": "nyhetsbyrå",
    "nyhetsbyråerna": "nyhetsbyrå",
    "nyhetsbyråernas": "nyhetsbyrå",
    "nyhetsbyråers": "nyhetsbyrå",
    "nyhetsbyrån": "nyhetsbyrå",
    "nyhetsbyråns": "nyhetsbyrå",
    "nyhetsbyrås": "nyhetsbyrå",
    "nyhetsförmedlingar": "nyhetsförmedling",
    "nyhetsförmedlingarna": "nyhetsförmedling",
    "nyhetsförmedlingarnas": "nyhetsförmedling",
    "nyhetsförmedlingars": "nyhetsförmedling",
    "nyhetsförmedlingen": "nyhetsförmedling",
    "nyhetsförmedlingens": "nyhetsförmedling",
    "nyhetsförmedlings": "nyhetsförmedling",
    "nyhetsmässiga": "nyhetsmässig",
    "nyhetsmässigare": "nyhetsmässig",
    "nyhetsmässigares": "nyhetsmässig",
    "nyhetsmässigas": "nyhetsmässig",
    "nyhetsmässigast": "nyhetsmässig",
    "nyhetsmässigaste": "nyhetsmässig",
    "nyhetsmässigastes": "nyhetsmässig",
    "nyhetsmässigasts": "nyhetsmässig",
    "nyhetsmässige": "nyhetsmässig",
    "nyhetsmässiges": "nyhetsmässig",
    "nyhetsmässigs": "nyhetsmässig",
    "nyhetsmässigt": "nyhetsmässig",
    "nyhetsmässigts": "nyhetsmässig",
    "nyhetsportalen": "nyhetsportal",
    "nyhetsportalens": "nyhetsportal",
    "nyhetsportaler": "nyhetsportal",
    "nyhetsportalerna": "nyhetsportal",
    "nyhetsportalernas": "nyhetsportal",
    "nyhetsportalers": "nyhetsportal",
    "nyhetsportals": "nyhetsportal",
    "nyhetsprogramen": "nyhetsprogram",
    "nyhetsprogramens": "nyhetsprogram",
    "nyhetsprogramet": "nyhetsprogram",
    "nyhetsprogramets": "nyhetsprogram",
    "nyhetsprograms": "nyhetsprogram",
    "nyhetsredaktionen": "nyhetsredaktion",
    "nyhetsredaktionens": "nyhetsredaktion",
    "nyhetsredaktioner": "nyhetsredaktion",
    "nyhetsredaktionerna": "nyhetsredaktion",
    "nyhetsredaktionernas": "nyhetsredaktion",
    "nyhetsredaktioners": "nyhetsredaktion",
    "nyhetsredaktions": "nyhetsredaktion",
    "nyhetsreportern": "nyhetsreporter",
    "nyhetsreporterns": "nyhetsreporter",
    "nyhetsreporters": "nyhetsreporter",
    "nyhetsreportrar": "nyhetsreporter",
    "nyhetsreportrarna": "nyhetsreporter",
    "nyhetsreportrarnas": "nyhetsreporter",
    "nyhetsreportrars": "nyhetsreporter",
    "nyhetssöken": "nyhetssök",
    "nyhetssökens": "nyhetssök",
    "nyhetssöket": "nyhetssök",
    "nyhetssökets": "nyhetssök",
    "nyhetssöks": "nyhetssök",
    "nyhetstelegrammen": "nyhetstelegram",
    "nyhetstelegrammens": "nyhetstelegram",
    "nyhetstelegrammet": "nyhetstelegram",
    "nyhetstelegrammets": "nyhetstelegram",
    "nyhetstelegrams": "nyhetstelegram",
    "nyhetstesten": "nyhetstest",
    "nyhetstestens": "nyhetstest",
    "nyhetstester": "nyhetstest",
    "nyhetstesterna": "nyhetstest",
    "nyhetstesternas": "nyhetstest",
    "nyhetstesters": "nyhetstest",
    "nyhetstestet": "nyhetstest",
    "nyhetstestets": "nyhetstest",
    "nyhetstests": "nyhetstest",
    "nyhetsuppläsar": "nyhetsuppläsare",
    "nyhetsuppläsaren": "nyhetsuppläsare",
    "nyhetsuppläsarens": "nyhetsuppläsare",
    "nyhetsuppläsares": "nyhetsuppläsare",
    "nyhetsuppläsarna": "nyhetsuppläsare",
    "nyhetsuppläsarnas": "nyhetsuppläsare",
    "nyhetsvärderingar": "nyhetsvärdering",
    "nyhetsvärderingarna": "nyhetsvärdering",
    "nyhetsvärderingarnas": "nyhetsvärdering",
    "nyhetsvärderingars": "nyhetsvärdering",
    "nyhetsvärderingen": "nyhetsvärdering",
    "nyhetsvärderingens": "nyhetsvärdering",
    "nyhetsvärderings": "nyhetsvärdering",
    "nyhetsvärdes": "nyhetsvärde",
    "nyhetsvärdet": "nyhetsvärde",
    "nyhetsvärdets": "nyhetsvärde",
    "nyhumanismen": "nyhumanism",
    "nyhumanismens": "nyhumanism",
    "nyhumanismer": "nyhumanism",
    "nyhumanismerna": "nyhumanism",
    "nyhumanismernas": "nyhumanism",
    "nyhumanismers": "nyhumanism",
    "nyhumanisms": "nyhumanism",
    "nyingar": "nying",
    "nyingarna": "nying",
    "nyingarnas": "nying",
    "nyingars": "nying",
    "nyingen": "nying",
    "nyingens": "nying",
    "nyings": "nying",
    "nyingsbras": "nyingsbrasa",
    "nyingsbrasan": "nyingsbrasa",
    "nyingsbrasans": "nyingsbrasa",
    "nyingsbrasas": "nyingsbrasa",
    "nyingsbrase": "nyingsbrasa",
    "nyingsbrasor": "nyingsbrasa",
    "nyingsbrasorna": "nyingsbrasa",
    "nyingsbrasornas": "nyingsbrasa",
    "nyingsbrasors": "nyingsbrasa",
    "nyinköpta": "nyinköpt",
    "nyinköptare": "nyinköpt",
    "nyinköptares": "nyinköpt",
    "nyinköptas": "nyinköpt",
    "nyinköptast": "nyinköpt",
    "nyinköptaste": "nyinköpt",
    "nyinköptastes": "nyinköpt",
    "nyinköptasts": "nyinköpt",
    "nyinköpte": "nyinköpt",
    "nyinköptes": "nyinköpt",
    "nyinköpts": "nyinköpt",
    "nyinredda": "nyinredd",
    "nyinreddare": "nyinredd",
    "nyinreddares": "nyinredd",
    "nyinreddas": "nyinredd",
    "nyinreddast": "nyinredd",
    "nyinreddaste": "nyinredd",
    "nyinreddastes": "nyinredd",
    "nyinreddasts": "nyinredd",
    "nyinredde": "nyinredd",
    "nyinreddes": "nyinredd",
    "nyinredds": "nyinredd",
    "nyinrett": "nyinredd",
    "nyinretts": "nyinredd",
    "nyinrättade": "nyinrättad",
    "nyinrättades": "nyinrättad",
    "nyinrättads": "nyinrättad",
    "nyinrättat": "nyinrättad",
    "nyinrättats": "nyinrättad",
    "nyinskaffade": "nyinskaffad",
    "nyinskaffades": "nyinskaffad",
    "nyinskaffads": "nyinskaffad",
    "nyinskaffat": "nyinskaffad",
    "nyinskaffats": "nyinskaffad",
    "nyintagningar": "nyintagning",
    "nyintagningarna": "nyintagning",
    "nyintagningarnas": "nyintagning",
    "nyintagningars": "nyintagning",
    "nyintagningen": "nyintagning",
    "nyintagningens": "nyintagning",
    "nyintagnings": "nyintagning",
    "nyinvesterad": "nyinvestera",
    "nyinvesterade": "nyinvestera",
    "nyinvesterades": "nyinvestera",
    "nyinvesterads": "nyinvestera",
    "nyinvesterande": "nyinvestera",
    "nyinvesteranden": "nyinvesterande",
    "nyinvesterandena": "nyinvesterande",
    "nyinvesterandenas": "nyinvesterande",
    "nyinvesterandens": "nyinvesterande",
    "nyinvesterandes": "nyinvesterande",
    "nyinvesterandet": "nyinvesterande",
    "nyinvesterandets": "nyinvesterande",
    "nyinvesterar": "nyinvestera",
    "nyinvesteras": "nyinvestera",
    "nyinvesterat": "nyinvestera",
    "nyinvesterats": "nyinvestera",
    "nyinvesterbara": "nyinvesterbar",
    "nyinvesterbarare": "nyinvesterbar",
    "nyinvesterbarares": "nyinvesterbar",
    "nyinvesterbaras": "nyinvesterbar",
    "nyinvesterbarast": "nyinvesterbar",
    "nyinvesterbaraste": "nyinvesterbar",
    "nyinvesterbarastes": "nyinvesterbar",
    "nyinvesterbarasts": "nyinvesterbar",
    "nyinvesterbare": "nyinvesterbar",
    "nyinvesterbares": "nyinvesterbar",
    "nyinvesterbarheten": "nyinvesterbarhet",
    "nyinvesterbarhetens": "nyinvesterbarhet",
    "nyinvesterbarhets": "nyinvesterbarhet",
    "nyinvesterbars": "nyinvesterbar",
    "nyinvesterbart": "nyinvesterbar",
    "nyinvesterbarts": "nyinvesterbar",
    "nyinvesteringar": "nyinvestering",
    "nyinvesteringarna": "nyinvestering",
    "nyinvesteringarnas": "nyinvestering",
    "nyinvesteringars": "nyinvestering",
    "nyinvesteringen": "nyinvestering",
    "nyinvesteringens": "nyinvestering",
    "nyinvesterings": "nyinvestering",
    "nyklassicismen": "nyklassicism",
    "nyklassicismens": "nyklassicism",
    "nyklassicismer": "nyklassicism",
    "nyklassicismerna": "nyklassicism",
    "nyklassicismernas": "nyklassicism",
    "nyklassicismers": "nyklassicism",
    "nyklassicisms": "nyklassicism",
    "nyklassicistiska": "nyklassicistisk",
    "nyklassicistiskare": "nyklassicistisk",
    "nyklassicistiskares": "nyklassicistisk",
    "nyklassicistiskas": "nyklassicistisk",
    "nyklassicistiskast": "nyklassicistisk",
    "nyklassicistiskaste": "nyklassicistisk",
    "nyklassicistiskastes": "nyklassicistisk",
    "nyklassicistiskasts": "nyklassicistisk",
    "nyklassicistiske": "nyklassicistisk",
    "nyklassicistiskes": "nyklassicistisk",
    "nyklassicistisks": "nyklassicistisk",
    "nyklassicistiskt": "nyklassicistisk",
    "nyklassicistiskts": "nyklassicistisk",
    "nyklassikern": "nyklassiker",
    "nyklassikerna": "nyklassiker",
    "nyklassikernas": "nyklassiker",
    "nyklassikerns": "nyklassiker",
    "nyklassikers": "nyklassiker",
    "nyklassiska": "nyklassisk",
    "nyklassiskare": "nyklassisk",
    "nyklassiskares": "nyklassisk",
    "nyklassiskas": "nyklassisk",
    "nyklassiskast": "nyklassisk",
    "nyklassiskaste": "nyklassisk",
    "nyklassiskastes": "nyklassisk",
    "nyklassiskasts": "nyklassisk",
    "nyklassiske": "nyklassisk",
    "nyklassiskes": "nyklassisk",
    "nyklassisks": "nyklassisk",
    "nyklassiskt": "nyklassisk",
    "nyklassiskts": "nyklassisk",
    "nyklippta": "nyklippt",
    "nyklipptas": "nyklippt",
    "nyklippte": "nyklippt",
    "nyklipptes": "nyklippt",
    "nyklippts": "nyklippt",
    "nykolonialismen": "nykolonialism",
    "nykolonialismens": "nykolonialism",
    "nykolonialismer": "nykolonialism",
    "nykolonialismerna": "nykolonialism",
    "nykolonialismernas": "nykolonialism",
    "nykolonialismers": "nykolonialism",
    "nykolonialisms": "nykolonialism",
    "nykolonialistiska": "nykolonialistisk",
    "nykolonialistiskas": "nykolonialistisk",
    "nykolonialistiske": "nykolonialistisk",
    "nykolonialistiskes": "nykolonialistisk",
    "nykolonialistisks": "nykolonialistisk",
    "nykolonialistiskt": "nykolonialistisk",
    "nykolonialistiskts": "nykolonialistisk",
    "nykolonisationen": "nykolonisation",
    "nykolonisationens": "nykolonisation",
    "nykolonisationer": "nykolonisation",
    "nykolonisationerna": "nykolonisation",
    "nykolonisationernas": "nykolonisation",
    "nykolonisationers": "nykolonisation",
    "nykolonisations": "nykolonisation",
    "nykomlingar": "nykomling",
    "nykomlingarna": "nykomling",
    "nykomlingarnas": "nykomling",
    "nykomlingars": "nykomling",
    "nykomlingen": "nykomling",
    "nykomlingens": "nykomling",
    "nykomlings": "nykomling",
    "nykterheten": "nykterhet",
    "nykterhetens": "nykterhet",
    "nykterheter": "nykterhet",
    "nykterheterna": "nykterhet",
    "nykterheternas": "nykterhet",
    "nykterheters": "nykterhet",
    "nykterhets": "nykterhet",
    "nykterhetsföreningar": "nykterhetsförening",
    "nykterhetsföreningarna": "nykterhetsförening",
    "nykterhetsföreningarnas": "nykterhetsförening",
    "nykterhetsföreningars": "nykterhetsförening",
    "nykterhetsföreningen": "nykterhetsförening",
    "nykterhetsföreningens": "nykterhetsförening",
    "nykterhetsförenings": "nykterhetsförening",
    "nykterhetsnämnden": "nykterhetsnämnd",
    "nykterhetsnämndens": "nykterhetsnämnd",
    "nykterhetsnämnder": "nykterhetsnämnd",
    "nykterhetsnämnderna": "nykterhetsnämnd",
    "nykterhetsnämndernas": "nykterhetsnämnd",
    "nykterhetsnämnders": "nykterhetsnämnd",
    "nykterhetsnämnds": "nykterhetsnämnd",
    "nykterhetsrörelsen": "nykterhetsrörelse",
    "nykterhetsrörelsens": "nykterhetsrörelse",
    "nykterhetsrörelser": "nykterhetsrörelse",
    "nykterhetsrörelserna": "nykterhetsrörelse",
    "nykterhetsrörelsernas": "nykterhetsrörelse",
    "nykterhetsrörelsers": "nykterhetsrörelse",
    "nykterhetsrörelses": "nykterhetsrörelse",
    "nykterhetsvården": "nykterhetsvård",
    "nykterhetsvårdens": "nykterhetsvård",
    "nykterhetsvårds": "nykterhetsvård",
    "nykterismen": "nykterism",
    "nykterismens": "nykterism",
    "nykterismer": "nykterism",
    "nykterismerna": "nykterism",
    "nykterismernas": "nykterism",
    "nykterismers": "nykterism",
    "nykterisms": "nykterism",
    "nykteristen": "nykterist",
    "nykteristens": "nykterist",
    "nykterister": "nykterist",
    "nykteristerna": "nykterist",
    "nykteristernas": "nykterist",
    "nykteristers": "nykterist",
    "nykteristiska": "nykteristisk",
    "nykteristiskas": "nykteristisk",
    "nykteristiske": "nykteristisk",
    "nykteristiskes": "nykteristisk",
    "nykteristisks": "nykteristisk",
    "nykteristiskt": "nykteristisk",
    "nykteristiskts": "nykteristisk",
    "nykterists": "nykterist",
    "nykters": "nykter",
    "nyktert": "nykter",
    "nykterts": "nykter",
    "nyktofobien": "nyktofobi",
    "nyktofobiens": "nyktofobi",
    "nyktofobin": "nyktofobi",
    "nyktofobins": "nyktofobi",
    "nyktofobis": "nyktofobi",
    "nyktra": "nykter",
    "nyktrare": "nykter",
    "nyktrares": "nykter",
    "nyktras": "nykter",
    "nyktrast": "nykter",
    "nyktraste": "nykter",
    "nyktrastes": "nykter",
    "nyktrasts": "nykter",
    "nyktre": "nykter",
    "nyktres": "nykter",
    "nylagade": "nylagad",
    "nylagades": "nylagad",
    "nylagads": "nylagad",
    "nylagat": "nylagad",
    "nylagats": "nylagad",
    "nylagda": "nylagd",
    "nylagdare": "nylagd",
    "nylagdares": "nylagd",
    "nylagdas": "nylagd",
    "nylagdast": "nylagd",
    "nylagdaste": "nylagd",
    "nylagdastes": "nylagd",
    "nylagdasts": "nylagd",
    "nylagde": "nylagd",
    "nylagdes": "nylagd",
    "nylagds": "nylagd",
    "nylagt": "nylagd",
    "nylagts": "nylagd",
    "nylatinet": "nylatin",
    "nylatinets": "nylatin",
    "nylatins": "nylatin",
    "nyliberala": "nyliberal",
    "nyliberalare": "nyliberal",
    "nyliberalares": "nyliberal",
    "nyliberalas": "nyliberal",
    "nyliberalast": "nyliberal",
    "nyliberalaste": "nyliberal",
    "nyliberalastes": "nyliberal",
    "nyliberalasts": "nyliberal",
    "nyliberale": "nyliberal",
    "nyliberales": "nyliberal",
    "nyliberalismen": "nyliberalism",
    "nyliberalismens": "nyliberalism",
    "nyliberalisms": "nyliberalism",
    "nyliberalistiska": "nyliberalistisk",
    "nyliberalistiskas": "nyliberalistisk",
    "nyliberalistiske": "nyliberalistisk",
    "nyliberalistiskes": "nyliberalistisk",
    "nyliberalistisks": "nyliberalistisk",
    "nyliberalistiskt": "nyliberalistisk",
    "nyliberalistiskts": "nyliberalistisk",
    "nyliberals": "nyliberal",
    "nyliberalt": "nyliberal",
    "nyliberalts": "nyliberal",
    "nyllen": "nylle",
    "nyllena": "nylle",
    "nyllenas": "nylle",
    "nyllens": "nylle",
    "nylles": "nylle",
    "nyllet": "nylle",
    "nyllets": "nylle",
    "nylonen": "nylon",
    "nylonens": "nylon",
    "nylonet": "nylon",
    "nylonets": "nylon",
    "nylonhjulen": "nylonhjul",
    "nylonhjulens": "nylonhjul",
    "nylonhjulet": "nylonhjul",
    "nylonhjulets": "nylonhjul",
    "nylonhjuls": "nylonhjul",
    "nylons": "nylon",
    "nylonskjort": "nylonskjorta",
    "nylonskjortan": "nylonskjorta",
    "nylonskjortans": "nylonskjorta",
    "nylonskjortas": "nylonskjorta",
    "nylonskjorte": "nylonskjorta",
    "nylonskjortor": "nylonskjorta",
    "nylonskjortorna": "nylonskjorta",
    "nylonskjortornas": "nylonskjorta",
    "nylonskjortors": "nylonskjorta",
    "nylonskjorts": "nylonskjorta",
    "nylonsnör": "nylonsnöre",
    "nylonsnören": "nylonsnöre",
    "nylonsnörena": "nylonsnöre",
    "nylonsnörenas": "nylonsnöre",
    "nylonsnörens": "nylonsnöre",
    "nylonsnöres": "nylonsnöre",
    "nylonsnöret": "nylonsnöre",
    "nylonsnörets": "nylonsnöre",
    "nylonsnörs": "nylonsnöre",
    "nylonstrump": "nylonstrumpa",
    "nylonstrumpan": "nylonstrumpa",
    "nylonstrumpans": "nylonstrumpa",
    "nylonstrumpas": "nylonstrumpa",
    "nylonstrumpe": "nylonstrumpa",
    "nylonstrumpor": "nylonstrumpa",
    "nylonstrumporna": "nylonstrumpa",
    "nylonstrumpornas": "nylonstrumpa",
    "nylonstrumpors": "nylonstrumpa",
    "nylonstrumps": "nylonstrumpa",
    "nylonsträngar": "nylonsträng",
    "nylonsträngarna": "nylonsträng",
    "nylonsträngarnas": "nylonsträng",
    "nylonsträngars": "nylonsträng",
    "nylonsträngen": "nylonsträng",
    "nylonsträngens": "nylonsträng",
    "nylonsträngs": "nylonsträng",
    "nylonutsidan": "nylonutsida",
    "nylonutsidans": "nylonutsida",
    "nylonutsidas": "nylonutsida",
    "nylonutside": "nylonutsida",
    "nylonutsides": "nylonutsida",
    "nylonutsidor": "nylonutsida",
    "nylonutsidorna": "nylonutsida",
    "nylonutsidornas": "nylonutsida",
    "nylonutsidors": "nylonutsida",
    "nyländsk": "nyländska",
    "nyländska": "nyländsk",
    "nyländskan": "nyländska",
    "nyländskans": "nyländska",
    "nyländskare": "nyländsk",
    "nyländskares": "nyländsk",
    "nyländskas": "nyländska",
    "nyländskast": "nyländsk",
    "nyländskaste": "nyländsk",
    "nyländskastes": "nyländsk",
    "nyländskasts": "nyländsk",
    "nyländske": "nyländska",
    "nyländskes": "nyländsk",
    "nyländskor": "nyländska",
    "nyländskorna": "nyländska",
    "nyländskornas": "nyländska",
    "nyländskors": "nyländska",
    "nyländsks": "nyländsk",
    "nyländskt": "nyländsk",
    "nyländskts": "nyländsk",
    "nylänningar": "nylänning",
    "nylänningarna": "nylänning",
    "nylänningarnas": "nylänning",
    "nylänningars": "nylänning",
    "nylänningen": "nylänning",
    "nylänningens": "nylänning",
    "nylännings": "nylänning",
    "nyläsningar": "nyläsning",
    "nyläsningarna": "nyläsning",
    "nyläsningarnas": "nyläsning",
    "nyläsningars": "nyläsning",
    "nyläsningen": "nyläsning",
    "nyläsningens": "nyläsning",
    "nyläsnings": "nyläsning",
    "nylövade": "nylövad",
    "nylövades": "nylövad",
    "nylövads": "nylövad",
    "nylövat": "nylövad",
    "nylövats": "nylövad",
    "nymfen": "nymf",
    "nymfens": "nymf",
    "nymfer": "nymf",
    "nymferna": "nymf",
    "nymfernas": "nymf",
    "nymfers": "nymf",
    "nymfomanen": "nymfoman",
    "nymfomanens": "nymfoman",
    "nymfomaner": "nymfoman",
    "nymfomanerna": "nymfoman",
    "nymfomanernas": "nymfoman",
    "nymfomaners": "nymfoman",
    "nymfomanien": "nymfomani",
    "nymfomaniens": "nymfomani",
    "nymfomanin": "nymfomani",
    "nymfomanins": "nymfomani",
    "nymfomanis": "nymfomani",
    "nymfomans": "nymfoman",
    "nymfs": "nymf",
    "nymobiliserade": "nymobiliserad",
    "nymobiliserades": "nymobiliserad",
    "nymobiliserads": "nymobiliserad",
    "nymobiliserat": "nymobiliserad",
    "nymobiliserats": "nymobiliserad",
    "nymodiga": "nymodig",
    "nymodigare": "nymodig",
    "nymodigares": "nymodig",
    "nymodigas": "nymodig",
    "nymodigast": "nymodig",
    "nymodigaste": "nymodig",
    "nymodigastes": "nymodig",
    "nymodigasts": "nymodig",
    "nymodige": "nymodig",
    "nymodiges": "nymodig",
    "nymodigheten": "nymodighet",
    "nymodighetens": "nymodighet",
    "nymodigheter": "nymodighet",
    "nymodigheterna": "nymodighet",
    "nymodigheternas": "nymodighet",
    "nymodigheters": "nymodighet",
    "nymodighets": "nymodighet",
    "nymodigs": "nymodig",
    "nymodigt": "nymodig",
    "nymodigts": "nymodig",
    "nymorgnade": "nymorgnad",
    "nymorgnades": "nymorgnad",
    "nymorgnads": "nymorgnad",
    "nymorgnat": "nymorgnad",
    "nymorgnats": "nymorgnad",
    "nymornade": "nymornad",
    "nymornades": "nymornad",
    "nymornads": "nymornad",
    "nymornat": "nymornad",
    "nymornats": "nymornad",
    "nymånen": "nymåne",
    "nymånens": "nymåne",
    "nymånes": "nymåne",
    "nyn": "ny",
    "nyna": "ny",
    "nynas": "ny",
    "nynazismen": "nynazism",
    "nynazismens": "nynazism",
    "nynazismer": "nynazism",
    "nynazismerna": "nynazism",
    "nynazismernas": "nynazism",
    "nynazismers": "nynazism",
    "nynazisms": "nynazism",
    "nynazisten": "nynazist",
    "nynazistens": "nynazist",
    "nynazister": "nynazist",
    "nynazisterna": "nynazist",
    "nynazisternas": "nynazist",
    "nynazisters": "nynazist",
    "nynazistiska": "nynazistisk",
    "nynazistiskas": "nynazistisk",
    "nynazistiske": "nynazistisk",
    "nynazistiskes": "nynazistisk",
    "nynazistisks": "nynazistisk",
    "nynazistiskt": "nynazistisk",
    "nynazistiskts": "nynazistisk",
    "nynazists": "nynazist",
    "nynn": "nynna",
    "nynnad": "nynna",
    "nynnade": "nynna",
    "nynnades": "nynna",
    "nynnads": "nynna",
    "nynnande": "nynna",
    "nynnanden": "nynnande",
    "nynnandena": "nynnande",
    "nynnandenas": "nynnande",
    "nynnandens": "nynnande",
    "nynnandes": "nynnande",
    "nynnandet": "nynnande",
    "nynnandets": "nynnande",
    "nynnar": "nynna",
    "nynnas": "nynna",
    "nynnat": "nynna",
    "nynnats": "nynna",
    "nynorsk": "nynorska",
    "nynorska": "nynorsk",
    "nynorskan": "nynorska",
    "nynorskans": "nynorska",
    "nynorskare": "nynorsk",
    "nynorskares": "nynorsk",
    "nynorskas": "nynorska",
    "nynorskast": "nynorsk",
    "nynorskaste": "nynorsk",
    "nynorskastes": "nynorsk",
    "nynorskasts": "nynorsk",
    "nynorske": "nynorsk",
    "nynorskes": "nynorsk",
    "nynorsks": "nynorsk",
    "nynorskt": "nynorsk",
    "nynorskts": "nynorsk",
    "nyns": "ny",
    "nyodlingar": "nyodling",
    "nyodlingarna": "nyodling",
    "nyodlingarnas": "nyodling",
    "nyodlingars": "nyodling",
    "nyodlingen": "nyodling",
    "nyodlingens": "nyodling",
    "nyodlings": "nyodling",
    "nyorden": "nyord",
    "nyordens": "nyord",
    "nyordet": "nyord",
    "nyordets": "nyord",
    "nyordningar": "nyordning",
    "nyordningarna": "nyordning",
    "nyordningarnas": "nyordning",
    "nyordningars": "nyordning",
    "nyordningen": "nyordning",
    "nyordningens": "nyordning",
    "nyordnings": "nyordning",
    "nyords": "nyord",
    "nyorienteringar": "nyorientering",
    "nyorienteringarna": "nyorientering",
    "nyorienteringarnas": "nyorientering",
    "nyorienteringars": "nyorientering",
    "nyorienteringen": "nyorientering",
    "nyorienteringens": "nyorientering",
    "nyorienterings": "nyorientering",
    "nyp": "nypa",
    "nypan": "nypa",
    "nypande": "nypa",
    "nypanden": "nypande",
    "nypandena": "nypande",
    "nypandenas": "nypande",
    "nypandens": "nypande",
    "nypandes": "nypande",
    "nypandet": "nypande",
    "nypandets": "nypande",
    "nypans": "nypa",
    "nypas": "nypa",
    "nype": "nypa",
    "nypen": "nyp",
    "nypens": "nyp",
    "nyper": "nypa",
    "nypes": "nypa",
    "nypet": "nyp",
    "nypets": "nyp",
    "nyplanterad": "nyplantera",
    "nyplanterade": "nyplantera",
    "nyplanterades": "nyplantera",
    "nyplanterads": "nyplantera",
    "nyplanterande": "nyplantera",
    "nyplanteranden": "nyplanterande",
    "nyplanterandena": "nyplanterande",
    "nyplanterandenas": "nyplanterande",
    "nyplanterandens": "nyplanterande",
    "nyplanterandes": "nyplanterande",
    "nyplanterandet": "nyplanterande",
    "nyplanterandets": "nyplanterande",
    "nyplanterar": "nyplantera",
    "nyplanteras": "nyplantera",
    "nyplanterat": "nyplantera",
    "nyplanterats": "nyplantera",
    "nyplanterbara": "nyplanterbar",
    "nyplanterbarare": "nyplanterbar",
    "nyplanterbarares": "nyplanterbar",
    "nyplanterbaras": "nyplanterbar",
    "nyplanterbarast": "nyplanterbar",
    "nyplanterbaraste": "nyplanterbar",
    "nyplanterbarastes": "nyplanterbar",
    "nyplanterbarasts": "nyplanterbar",
    "nyplanterbare": "nyplanterbar",
    "nyplanterbares": "nyplanterbar",
    "nyplanterbarheten": "nyplanterbarhet",
    "nyplanterbarhetens": "nyplanterbarhet",
    "nyplanterbarhets": "nyplanterbarhet",
    "nyplanterbars": "nyplanterbar",
    "nyplanterbart": "nyplanterbar",
    "nyplanterbarts": "nyplanterbar",
    "nyplanteringar": "nyplantering",
    "nyplanteringarna": "nyplantering",
    "nyplanteringarnas": "nyplantering",
    "nyplanteringars": "nyplantering",
    "nyplanteringen": "nyplantering",
    "nyplanteringens": "nyplantering",
    "nyplanterings": "nyplantering",
    "nyplatonismen": "nyplatonism",
    "nyplatonismens": "nyplatonism",
    "nyplatonismer": "nyplatonism",
    "nyplatonismerna": "nyplatonism",
    "nyplatonismernas": "nyplatonism",
    "nyplatonismers": "nyplatonism",
    "nyplatonisms": "nyplatonism",
    "nyplatonistiska": "nyplatonistisk",
    "nyplatonistiskas": "nyplatonistisk",
    "nyplatonistiske": "nyplatonistisk",
    "nyplatonistiskes": "nyplatonistisk",
    "nyplatonistisks": "nyplatonistisk",
    "nyplatonistiskt": "nyplatonistisk",
    "nyplatonistiskts": "nyplatonistisk",
    "nyplatonska": "nyplatonsk",
    "nyplatonskare": "nyplatonsk",
    "nyplatonskares": "nyplatonsk",
    "nyplatonskas": "nyplatonsk",
    "nyplatonskast": "nyplatonsk",
    "nyplatonskaste": "nyplatonsk",
    "nyplatonskastes": "nyplatonsk",
    "nyplatonskasts": "nyplatonsk",
    "nyplatonske": "nyplatonsk",
    "nyplatonskes": "nyplatonsk",
    "nyplatonsks": "nyplatonsk",
    "nyplatonskt": "nyplatonsk",
    "nyplatonskts": "nyplatonsk",
    "nypolerade": "nypolerad",
    "nypolerades": "nypolerad",
    "nypolerads": "nypolerad",
    "nypolerat": "nypolerad",
    "nypolerats": "nypolerad",
    "nyponen": "nypon",
    "nyponens": "nypon",
    "nyponet": "nypon",
    "nyponets": "nypon",
    "nyponrosen": "nyponros",
    "nyponrosens": "nyponros",
    "nyponrosor": "nyponros",
    "nyponrosorna": "nyponros",
    "nyponrosornas": "nyponros",
    "nyponrosors": "nyponros",
    "nypons": "nypon",
    "nyponsoppan": "nyponsoppa",
    "nyponsoppans": "nyponsoppa",
    "nyponsoppas": "nyponsoppa",
    "nyponteet": "nyponte",
    "nyponteets": "nyponte",
    "nypontes": "nyponte",
    "nypontet": "nyponte",
    "nypontets": "nyponte",
    "nypor": "nypa",
    "nyporna": "nypa",
    "nypornas": "nypa",
    "nypors": "nypa",
    "nypremiären": "nypremiär",
    "nypremiärens": "nypremiär",
    "nypremiärer": "nypremiär",
    "nypremiärerna": "nypremiär",
    "nypremiärernas": "nypremiär",
    "nypremiärers": "nypremiär",
    "nypremiärs": "nypremiär",
    "nypressade": "nypressad",
    "nypressades": "nypressad",
    "nypressads": "nypressad",
    "nypressat": "nypressad",
    "nypressats": "nypressad",
    "nyproduktionen": "nyproduktion",
    "nyproduktionens": "nyproduktion",
    "nyproduktioner": "nyproduktion",
    "nyproduktionerna": "nyproduktion",
    "nyproduktionernas": "nyproduktion",
    "nyproduktioners": "nyproduktion",
    "nyproduktions": "nyproduktion",
    "nyps": "nypa",
    "nypt": "nypa",
    "nypta": "nypa",
    "nyptas": "nypa",
    "nypte": "nypa",
    "nyptes": "nypa",
    "nypts": "nypa",
    "nyrealismen": "nyrealism",
    "nyrealismens": "nyrealism",
    "nyrealismer": "nyrealism",
    "nyrealismerna": "nyrealism",
    "nyrealismernas": "nyrealism",
    "nyrealismers": "nyrealism",
    "nyrealisms": "nyrealism",
    "nyrealistiska": "nyrealistisk",
    "nyrealistiskas": "nyrealistisk",
    "nyrealistiske": "nyrealistisk",
    "nyrealistiskes": "nyrealistisk",
    "nyrealistisks": "nyrealistisk",
    "nyrealistiskt": "nyrealistisk",
    "nyrealistiskts": "nyrealistisk",
    "nyrekryteringar": "nyrekrytering",
    "nyrekryteringarna": "nyrekrytering",
    "nyrekryteringarnas": "nyrekrytering",
    "nyrekryteringars": "nyrekrytering",
    "nyrekryteringen": "nyrekrytering",
    "nyrekryteringens": "nyrekrytering",
    "nyrekryterings": "nyrekrytering",
    "nyrika": "nyrik",
    "nyrikare": "nyrik",
    "nyrikares": "nyrik",
    "nyrikas": "nyrik",
    "nyrikast": "nyrik",
    "nyrikaste": "nyrik",
    "nyrikastes": "nyrik",
    "nyrikasts": "nyrik",
    "nyrike": "nyrik",
    "nyrikes": "nyrik",
    "nyrikheten": "nyrikhet",
    "nyrikhetens": "nyrikhet",
    "nyrikhets": "nyrikhet",
    "nyriks": "nyrik",
    "nyrikt": "nyrik",
    "nyrikts": "nyrik",
    "nyrokokon": "nyrokoko",
    "nyrokokons": "nyrokoko",
    "nyrokokos": "nyrokoko",
    "nyromantiken": "nyromantik",
    "nyromantikens": "nyromantik",
    "nyromantiks": "nyromantik",
    "nys": "nysa",
    "nysande": "nysa",
    "nysandes": "nysande",
    "nysandet": "nysande",
    "nysandets": "nysande",
    "nysas": "nysa",
    "nysattacken": "nysattack",
    "nysattackens": "nysattack",
    "nysattacker": "nysattack",
    "nysattackerna": "nysattack",
    "nysattackernas": "nysattack",
    "nysattackers": "nysattack",
    "nysattacks": "nysattack",
    "nyse": "nysa",
    "nyser": "nysa",
    "nyses": "nysa",
    "nyset": "nys",
    "nysets": "nys",
    "nysilvers": "nysilver",
    "nysilvret": "nysilver",
    "nysilvrets": "nysilver",
    "nysit": "nysa",
    "nysits": "nysa",
    "nyskap": "nyskapa",
    "nyskapad": "nyskapa",
    "nyskapade": "nyskapa",
    "nyskapades": "nyskapa",
    "nyskapads": "nyskapa",
    "nyskapande": "nyskapa",
    "nyskapandes": "nyskapande",
    "nyskapandet": "nyskapande",
    "nyskapandets": "nyskapande",
    "nyskapar": "nyskapare",
    "nyskaparen": "nyskapare",
    "nyskaparens": "nyskapare",
    "nyskapares": "nyskapare",
    "nyskaparna": "nyskapare",
    "nyskaparnas": "nyskapare",
    "nyskapas": "nyskapa",
    "nyskapat": "nyskapa",
    "nyskapats": "nyskapa",
    "nyskapelsen": "nyskapelse",
    "nyskapelsens": "nyskapelse",
    "nyskapelser": "nyskapelse",
    "nyskapelserna": "nyskapelse",
    "nyskapelsernas": "nyskapelse",
    "nyskapelsers": "nyskapelse",
    "nyskapelses": "nyskapelse",
    "nyskotten": "nyskott",
    "nyskottens": "nyskott",
    "nyskottet": "nyskott",
    "nyskottets": "nyskott",
    "nyskotts": "nyskott",
    "nyslipade": "nyslipad",
    "nyslipades": "nyslipad",
    "nyslipads": "nyslipad",
    "nyslipat": "nyslipad",
    "nyslipats": "nyslipad",
    "nysningar": "nysning",
    "nysningarna": "nysning",
    "nysningarnas": "nysning",
    "nysningars": "nysning",
    "nysningen": "nysning",
    "nysningens": "nysning",
    "nysnings": "nysning",
    "nysnön": "nysnö",
    "nysnöns": "nysnö",
    "nysnös": "nysnö",
    "nyspulvers": "nyspulver",
    "nyspulvret": "nyspulver",
    "nyspulvrets": "nyspulver",
    "nyssbemäldas": "nyssbemälda",
    "nyssbemälde": "nyssbemälda",
    "nyssbemäldes": "nyssbemälda",
    "nyssbemältas": "nyssbemälta",
    "nyssbemälte": "nyssbemälta",
    "nyssbemältes": "nyssbemälta",
    "nyssberördas": "nyssberörda",
    "nyssberörde": "nyssberörda",
    "nyssberördes": "nyssberörda",
    "nyssnämndas": "nyssnämnda",
    "nyssnämnde": "nyssnämnda",
    "nyssnämndes": "nyssnämnda",
    "nyst": "nysta",
    "nystad": "nysta",
    "nystade": "nysta",
    "nystades": "nysta",
    "nystads": "nysta",
    "nystande": "nysta",
    "nystanden": "nystande",
    "nystandena": "nystande",
    "nystandenas": "nystande",
    "nystandens": "nystande",
    "nystandes": "nystande",
    "nystandet": "nystande",
    "nystandets": "nystande",
    "nystanen": "nystan",
    "nystanens": "nystan",
    "nystanet": "nystan",
    "nystanets": "nystan",
    "nystans": "nystan",
    "nystar": "nysta",
    "nystartade": "nystartad",
    "nystartades": "nystartad",
    "nystartads": "nystartad",
    "nystartat": "nystartad",
    "nystartats": "nystartad",
    "nystarten": "nystart",
    "nystartens": "nystart",
    "nystarter": "nystart",
    "nystarterna": "nystart",
    "nystarternas": "nystart",
    "nystarters": "nystart",
    "nystarts": "nystart",
    "nystas": "nysta",
    "nystat": "nysta",
    "nystats": "nysta",
    "nystavar": "nystavare",
    "nystavaren": "nystavare",
    "nystavarens": "nystavare",
    "nystavares": "nystavare",
    "nystavarna": "nystavare",
    "nystavarnas": "nystavare",
    "nystavningar": "nystavning",
    "nystavningarna": "nystavning",
    "nystavningarnas": "nystavning",
    "nystavningars": "nystavning",
    "nystavningen": "nystavning",
    "nystavningens": "nystavning",
    "nystavnings": "nystavning",
    "nyste": "nysa",
    "nystes": "nysa",
    "nystkron": "nystkrona",
    "nystkronan": "nystkrona",
    "nystkronans": "nystkrona",
    "nystkronas": "nystkrona",
    "nystkrone": "nystkrona",
    "nystkronor": "nystkrona",
    "nystkronorna": "nystkrona",
    "nystkronornas": "nystkrona",
    "nystkronors": "nystkrona",
    "nystkrons": "nystkrona",
    "nystpinn": "nystpinne",
    "nystpinnar": "nystpinne",
    "nystpinnarna": "nystpinne",
    "nystpinnarnas": "nystpinne",
    "nystpinnars": "nystpinne",
    "nystpinnen": "nystpinne",
    "nystpinnens": "nystpinne",
    "nystpinnes": "nystpinne",
    "nystpinns": "nystpinne",
    "nysts": "nysa",
    "nyststjärnan": "nyststjärna",
    "nyststjärnans": "nyststjärna",
    "nyststjärnas": "nyststjärna",
    "nyststjärne": "nyststjärna",
    "nyststjärnor": "nyststjärna",
    "nyststjärnorna": "nyststjärna",
    "nyststjärnornas": "nyststjärna",
    "nyststjärnors": "nyststjärna",
    "nystvind": "nystvinda",
    "nystvindan": "nystvinda",
    "nystvindans": "nystvinda",
    "nystvindas": "nystvinda",
    "nystvinde": "nystvinda",
    "nystvindor": "nystvinda",
    "nystvindorna": "nystvinda",
    "nystvindornas": "nystvinda",
    "nystvindors": "nystvinda",
    "nystvinds": "nystvinda",
    "nystädade": "nystädad",
    "nystädades": "nystädad",
    "nystädads": "nystädad",
    "nystädat": "nystädad",
    "nystädats": "nystädad",
    "nysvensk": "nysvenska",
    "nysvenska": "nysvensk",
    "nysvenskan": "nysvenska",
    "nysvenskans": "nysvenska",
    "nysvenskare": "nysvensk",
    "nysvenskares": "nysvensk",
    "nysvenskas": "nysvenska",
    "nysvenskast": "nysvensk",
    "nysvenskaste": "nysvensk",
    "nysvenskastes": "nysvensk",
    "nysvenskasts": "nysvensk",
    "nysvenske": "nysvensk",
    "nysvenskes": "nysvensk",
    "nysvensks": "nysvensk",
    "nysvenskt": "nysvensk",
    "nysvenskts": "nysvensk",
    "nysörten": "nysört",
    "nysörtens": "nysört",
    "nysörter": "nysört",
    "nysörterna": "nysört",
    "nysörternas": "nysört",
    "nysörters": "nysört",
    "nysörts": "nysört",
    "nyt": "ny",
    "nyteckn": "nyteckna",
    "nytecknad": "nyteckna",
    "nytecknade": "nyteckna",
    "nytecknades": "nyteckna",
    "nytecknads": "nyteckna",
    "nytecknande": "nyteckna",
    "nytecknanden": "nytecknande",
    "nytecknandena": "nytecknande",
    "nytecknandenas": "nytecknande",
    "nytecknandens": "nytecknande",
    "nytecknandes": "nytecknande",
    "nytecknandet": "nytecknande",
    "nytecknandets": "nytecknande",
    "nytecknar": "nyteckna",
    "nytecknas": "nyteckna",
    "nytecknat": "nyteckna",
    "nytecknats": "nyteckna",
    "nyters": "nyter",
    "nytert": "nyter",
    "nyterts": "nyter",
    "nytestamentliga": "nytestamentlig",
    "nytestamentligare": "nytestamentlig",
    "nytestamentligares": "nytestamentlig",
    "nytestamentligas": "nytestamentlig",
    "nytestamentligast": "nytestamentlig",
    "nytestamentligaste": "nytestamentlig",
    "nytestamentligastes": "nytestamentlig",
    "nytestamentligasts": "nytestamentlig",
    "nytestamentlige": "nytestamentlig",
    "nytestamentliges": "nytestamentlig",
    "nytestamentligheten": "nytestamentlighet",
    "nytestamentlighetens": "nytestamentlighet",
    "nytestamentlighets": "nytestamentlighet",
    "nytestamentligs": "nytestamentlig",
    "nytestamentligt": "nytestamentlig",
    "nytestamentligts": "nytestamentlig",
    "nytillkommens": "nytillkommen",
    "nytillkommet": "nytillkommen",
    "nytillkommets": "nytillkommen",
    "nytillkomna": "nytillkommen",
    "nytillkomnare": "nytillkommen",
    "nytillkomnares": "nytillkommen",
    "nytillkomnas": "nytillkommen",
    "nytillkomnast": "nytillkommen",
    "nytillkomnaste": "nytillkommen",
    "nytillkomnastes": "nytillkommen",
    "nytillkomnasts": "nytillkommen",
    "nytillkomne": "nytillkommen",
    "nytillkomnes": "nytillkommen",
    "nytillskotten": "nytillskott",
    "nytillskottens": "nytillskott",
    "nytillskottet": "nytillskott",
    "nytillskottets": "nytillskott",
    "nytillskotts": "nytillskott",
    "nytra": "nyter",
    "nytrare": "nyter",
    "nytrares": "nyter",
    "nytras": "nyter",
    "nytrast": "nyter",
    "nytraste": "nyter",
    "nytrastes": "nyter",
    "nytrasts": "nyter",
    "nytre": "nyter",
    "nytres": "nyter",
    "nytrycken": "nytryck",
    "nytryckens": "nytryck",
    "nytrycket": "nytryck",
    "nytryckets": "nytryck",
    "nytrycks": "nytryck",
    "nyts": "ny",
    "nytt": "nytta",
    "nyttade": "nytta",
    "nyttades": "nytta",
    "nyttan": "nytta",
    "nyttande": "nytta",
    "nyttanden": "nyttande",
    "nyttandena": "nyttande",
    "nyttandenas": "nyttande",
    "nyttandens": "nyttande",
    "nyttandes": "nyttande",
    "nyttandet": "nyttande",
    "nyttandets": "nyttande",
    "nyttans": "nytta",
    "nyttar": "nytta",
    "nyttas": "nytta",
    "nyttat": "nytta",
    "nyttats": "nytta",
    "nytte": "nytta",
    "nyttiga": "nyttig",
    "nyttigare": "nyttig",
    "nyttigares": "nyttig",
    "nyttigas": "nyttig",
    "nyttigast": "nyttig",
    "nyttigaste": "nyttig",
    "nyttigastes": "nyttig",
    "nyttigasts": "nyttig",
    "nyttige": "nyttig",
    "nyttiges": "nyttig",
    "nyttiggjord": "nyttiggöra",
    "nyttiggjorda": "nyttiggöra",
    "nyttiggjordas": "nyttiggöra",
    "nyttiggjorde": "nyttiggöra",
    "nyttiggjordes": "nyttiggöra",
    "nyttiggjords": "nyttiggöra",
    "nyttiggjort": "nyttiggöra",
    "nyttiggjorts": "nyttiggöra",
    "nyttiggör": "nyttiggöra",
    "nyttiggörande": "nyttiggöra",
    "nyttiggöranden": "nyttiggörande",
    "nyttiggörandena": "nyttiggörande",
    "nyttiggörandenas": "nyttiggörande",
    "nyttiggörandens": "nyttiggörande",
    "nyttiggörandes": "nyttiggörande",
    "nyttiggörandet": "nyttiggörande",
    "nyttiggörandets": "nyttiggörande",
    "nyttiggöras": "nyttiggöra",
    "nyttiggöres": "nyttiggöra",
    "nyttiggörs": "nyttiggöra",
    "nyttigheten": "nyttighet",
    "nyttighetens": "nyttighet",
    "nyttigheter": "nyttighet",
    "nyttigheterna": "nyttighet",
    "nyttigheternas": "nyttighet",
    "nyttigheters": "nyttighet",
    "nyttighets": "nyttighet",
    "nyttighetsmoralen": "nyttighetsmoral",
    "nyttighetsmoralens": "nyttighetsmoral",
    "nyttighetsmorals": "nyttighetsmoral",
    "nyttigs": "nyttig",
    "nyttigt": "nyttig",
    "nyttigts": "nyttig",
    "nyttjad": "nyttja",
    "nyttjade": "nyttja",
    "nyttjades": "nyttja",
    "nyttjads": "nyttja",
    "nyttjande": "nyttja",
    "nyttjandefrekvensen": "nyttjandefrekvens",
    "nyttjandefrekvensens": "nyttjandefrekvens",
    "nyttjandefrekvenser": "nyttjandefrekvens",
    "nyttjandefrekvenserna": "nyttjandefrekvens",
    "nyttjandefrekvensernas": "nyttjandefrekvens",
    "nyttjandefrekvensers": "nyttjandefrekvens",
    "nyttjanden": "nyttjande",
    "nyttjandena": "nyttjande",
    "nyttjandenas": "nyttjande",
    "nyttjandens": "nyttjande",
    "nyttjanderätten": "nyttjanderätt",
    "nyttjanderättens": "nyttjanderätt",
    "nyttjanderätts": "nyttjanderätt",
    "nyttjandes": "nyttjande",
    "nyttjandet": "nyttjande",
    "nyttjandets": "nyttjande",
    "nyttjar": "nyttjare",
    "nyttjaren": "nyttjare",
    "nyttjarens": "nyttjare",
    "nyttjares": "nyttjare",
    "nyttjarna": "nyttjare",
    "nyttjarnas": "nyttjare",
    "nyttjas": "nyttja",
    "nyttjat": "nyttja",
    "nyttjats": "nyttja",
    "nytto": "nytta",
    "nyttobetonade": "nyttobetonad",
    "nyttobetonades": "nyttobetonad",
    "nyttobetonads": "nyttobetonad",
    "nyttobetonat": "nyttobetonad",
    "nyttobetonats": "nyttobetonad",
    "nyttoföremålen": "nyttoföremål",
    "nyttoföremålens": "nyttoföremål",
    "nyttoföremålet": "nyttoföremål",
    "nyttoföremålets": "nyttoföremål",
    "nyttoföremåls": "nyttoföremål",
    "nyttokonsten": "nyttokonst",
    "nyttokonstens": "nyttokonst",
    "nyttokonsts": "nyttokonst",
    "nyttomoralen": "nyttomoral",
    "nyttomoralens": "nyttomoral",
    "nyttomorals": "nyttomoral",
    "nyttor": "nytta",
    "nyttorna": "nytta",
    "nyttornas": "nytta",
    "nyttors": "nytta",
    "nyttosynpunkten": "nyttosynpunkt",
    "nyttosynpunktens": "nyttosynpunkt",
    "nyttosynpunkter": "nyttosynpunkt",
    "nyttosynpunkterna": "nyttosynpunkt",
    "nyttosynpunkternas": "nyttosynpunkt",
    "nyttosynpunkters": "nyttosynpunkt",
    "nyttosynpunkts": "nyttosynpunkt",
    "nyttotrafiken": "nyttotrafik",
    "nyttotrafikens": "nyttotrafik",
    "nyttotrafiks": "nyttotrafik",
    "nyttoväxten": "nyttoväxt",
    "nyttoväxtens": "nyttoväxt",
    "nyttoväxter": "nyttoväxt",
    "nyttoväxterna": "nyttoväxt",
    "nyttoväxternas": "nyttoväxt",
    "nyttoväxters": "nyttoväxt",
    "nyttoväxts": "nyttoväxt",
    "nytts": "nytta",
    "nytända": "nytänd",
    "nytändare": "nytänd",
    "nytändares": "nytänd",
    "nytändas": "nytänd",
    "nytändast": "nytänd",
    "nytändaste": "nytänd",
    "nytändastes": "nytänd",
    "nytändasts": "nytänd",
    "nytände": "nytänd",
    "nytändes": "nytänd",
    "nytändningar": "nytändning",
    "nytändningarna": "nytändning",
    "nytändningarnas": "nytändning",
    "nytändningars": "nytändning",
    "nytändningen": "nytändning",
    "nytändningens": "nytändning",
    "nytändnings": "nytändning",
    "nytänds": "nytänd",
    "nytänkandes": "nytänkande",
    "nytänkandet": "nytänkande",
    "nytänkandets": "nytänkande",
    "nytänkar": "nytänkare",
    "nytänkaren": "nytänkare",
    "nytänkarens": "nytänkare",
    "nytänkares": "nytänkare",
    "nytänkarna": "nytänkare",
    "nytänkarnas": "nytänkare",
    "nytänt": "nytänd",
    "nytänts": "nytänd",
    "nyuppförda": "nyuppförd",
    "nyuppfördare": "nyuppförd",
    "nyuppfördares": "nyuppförd",
    "nyuppfördas": "nyuppförd",
    "nyuppfördast": "nyuppförd",
    "nyuppfördaste": "nyuppförd",
    "nyuppfördastes": "nyuppförd",
    "nyuppfördasts": "nyuppförd",
    "nyuppförde": "nyuppförd",
    "nyuppfördes": "nyuppförd",
    "nyuppförds": "nyuppförd",
    "nyuppfört": "nyuppförd",
    "nyuppförts": "nyuppförd",
    "nyuppsättningar": "nyuppsättning",
    "nyuppsättningarna": "nyuppsättning",
    "nyuppsättningarnas": "nyuppsättning",
    "nyuppsättningars": "nyuppsättning",
    "nyuppsättningen": "nyuppsättning",
    "nyuppsättningens": "nyuppsättning",
    "nyuppsättnings": "nyuppsättning",
    "nyupptäckta": "nyupptäckt",
    "nyupptäcktare": "nyupptäckt",
    "nyupptäcktares": "nyupptäckt",
    "nyupptäcktas": "nyupptäckt",
    "nyupptäcktast": "nyupptäckt",
    "nyupptäcktaste": "nyupptäckt",
    "nyupptäcktastes": "nyupptäckt",
    "nyupptäcktasts": "nyupptäckt",
    "nyupptäckte": "nyupptäckt",
    "nyupptäcktes": "nyupptäckt",
    "nyupptäckts": "nyupptäckt",
    "nyutexaminerade": "nyutexaminerad",
    "nyutexaminerades": "nyutexaminerad",
    "nyutexaminerads": "nyutexaminerad",
    "nyutexaminerat": "nyutexaminerad",
    "nyutexaminerats": "nyutexaminerad",
    "nyutgåvan": "nyutgåva",
    "nyutgåvans": "nyutgåva",
    "nyutgåvas": "nyutgåva",
    "nyutgåve": "nyutgåva",
    "nyutgåvo": "nyutgåva",
    "nyutgåvor": "nyutgåva",
    "nyutgåvorna": "nyutgåva",
    "nyutgåvornas": "nyutgåva",
    "nyutgåvors": "nyutgåva",
    "nyutkommens": "nyutkommen",
    "nyutkommet": "nyutkommen",
    "nyutkommets": "nyutkommen",
    "nyutkomna": "nyutkommen",
    "nyutkomnare": "nyutkommen",
    "nyutkomnares": "nyutkommen",
    "nyutkomnas": "nyutkommen",
    "nyutkomnast": "nyutkommen",
    "nyutkomnaste": "nyutkommen",
    "nyutkomnastes": "nyutkommen",
    "nyutkomnasts": "nyutkommen",
    "nyutkomne": "nyutkommen",
    "nyutkomnes": "nyutkommen",
    "nyutslagens": "nyutslagen",
    "nyutslaget": "nyutslagen",
    "nyutslagets": "nyutslagen",
    "nyutslagna": "nyutslagen",
    "nyutslagnare": "nyutslagen",
    "nyutslagnares": "nyutslagen",
    "nyutslagnas": "nyutslagen",
    "nyutslagnast": "nyutslagen",
    "nyutslagnaste": "nyutslagen",
    "nyutslagnastes": "nyutslagen",
    "nyutslagnasts": "nyutslagen",
    "nyutslagne": "nyutslagen",
    "nyutslagnes": "nyutslagen",
    "nyutsprungens": "nyutsprungen",
    "nyutsprunget": "nyutsprungen",
    "nyutsprungets": "nyutsprungen",
    "nyutsprungna": "nyutsprungen",
    "nyutsprungnare": "nyutsprungen",
    "nyutsprungnares": "nyutsprungen",
    "nyutsprungnas": "nyutsprungen",
    "nyutsprungnast": "nyutsprungen",
    "nyutsprungnaste": "nyutsprungen",
    "nyutsprungnastes": "nyutsprungen",
    "nyutsprungnasts": "nyutsprungen",
    "nyutsprungne": "nyutsprungen",
    "nyutsprungnes": "nyutsprungen",
    "nyvalda": "nyvald",
    "nyvaldare": "nyvald",
    "nyvaldares": "nyvald",
    "nyvaldas": "nyvald",
    "nyvaldast": "nyvald",
    "nyvaldaste": "nyvald",
    "nyvaldastes": "nyvald",
    "nyvaldasts": "nyvald",
    "nyvalde": "nyvald",
    "nyvaldes": "nyvald",
    "nyvalds": "nyvald",
    "nyvalen": "nyval",
    "nyvalens": "nyval",
    "nyvalet": "nyval",
    "nyvalets": "nyval",
    "nyvals": "nyval",
    "nyvalt": "nyvald",
    "nyvalts": "nyvald",
    "nyvordens": "nyvorden",
    "nyvordet": "nyvorden",
    "nyvordets": "nyvorden",
    "nyvordna": "nyvorden",
    "nyvordnare": "nyvorden",
    "nyvordnares": "nyvorden",
    "nyvordnas": "nyvorden",
    "nyvordnast": "nyvorden",
    "nyvordnaste": "nyvorden",
    "nyvordnastes": "nyvorden",
    "nyvordnasts": "nyvorden",
    "nyvordne": "nyvorden",
    "nyvordnes": "nyvorden",
    "nyvunna": "nyvunnen",
    "nyvunnare": "nyvunnen",
    "nyvunnares": "nyvunnen",
    "nyvunnas": "nyvunnen",
    "nyvunnast": "nyvunnen",
    "nyvunnaste": "nyvunnen",
    "nyvunnastes": "nyvunnen",
    "nyvunnasts": "nyvunnen",
    "nyvunne": "nyvunnen",
    "nyvunnens": "nyvunnen",
    "nyvunnes": "nyvunnen",
    "nyvunnet": "nyvunnen",
    "nyvunnets": "nyvunnen",
    "nyvälles": "nyvälle",
    "nyvället": "nyvälle",
    "nyvällets": "nyvälle",
    "nyvärden": "nyvärde",
    "nyvärdena": "nyvärde",
    "nyvärdenas": "nyvärde",
    "nyvärdens": "nyvärde",
    "nyvärdes": "nyvärde",
    "nyvärdet": "nyvärde",
    "nyvärdets": "nyvärde",
    "nyvässade": "nyvässad",
    "nyvässades": "nyvässad",
    "nyvässads": "nyvässad",
    "nyvässat": "nyvässad",
    "nyvässats": "nyvässad",
    "nyzeeländar": "nyzeeländare",
    "nyzeeländaren": "nyzeeländare",
    "nyzeeländarens": "nyzeeländare",
    "nyzeeländares": "nyzeeländare",
    "nyzeeländarna": "nyzeeländare",
    "nyzeeländarnas": "nyzeeländare",
    "nyzeeländska": "nyzeeländsk",
    "nyzeeländskan": "nyzeeländska",
    "nyzeeländskans": "nyzeeländska",
    "nyzeeländskare": "nyzeeländsk",
    "nyzeeländskares": "nyzeeländsk",
    "nyzeeländskas": "nyzeeländska",
    "nyzeeländskast": "nyzeeländsk",
    "nyzeeländskaste": "nyzeeländsk",
    "nyzeeländskastes": "nyzeeländsk",
    "nyzeeländskasts": "nyzeeländsk",
    "nyzeeländske": "nyzeeländska",
    "nyzeeländskes": "nyzeeländsk",
    "nyzeeländskor": "nyzeeländska",
    "nyzeeländskorna": "nyzeeländska",
    "nyzeeländskornas": "nyzeeländska",
    "nyzeeländskors": "nyzeeländska",
    "nyzeeländsks": "nyzeeländsk",
    "nyzeeländskt": "nyzeeländsk",
    "nyzeeländskts": "nyzeeländsk",
    "nyzeelänningar": "nyzeelänning",
    "nyzeelänningarna": "nyzeelänning",
    "nyzeelänningarnas": "nyzeelänning",
    "nyzeelänningars": "nyzeelänning",
    "nyzeelänningen": "nyzeelänning",
    "nyzeelänningens": "nyzeelänning",
    "nyzeelännings": "nyzeelänning",
    "nyåren": "nyår",
    "nyårens": "nyår",
    "nyåret": "nyår",
    "nyårets": "nyår",
    "nyårs": "nyår",
    "nyårsaftnar": "nyårsafton",
    "nyårsaftnarna": "nyårsafton",
    "nyårsaftnarnas": "nyårsafton",
    "nyårsaftnars": "nyårsafton",
    "nyårsaftonen": "nyårsafton",
    "nyårsaftonens": "nyårsafton",
    "nyårsaftons": "nyårsafton",
    "nyårsbönen": "nyårsbön",
    "nyårsbönens": "nyårsbön",
    "nyårsböner": "nyårsbön",
    "nyårsbönerna": "nyårsbön",
    "nyårsbönernas": "nyårsbön",
    "nyårsböners": "nyårsbön",
    "nyårsböns": "nyårsbön",
    "nyårsdagar": "nyårsdag",
    "nyårsdagarna": "nyårsdag",
    "nyårsdagarnas": "nyårsdag",
    "nyårsdagars": "nyårsdag",
    "nyårsdagen": "nyårsdag",
    "nyårsdagens": "nyårsdag",
    "nyårsdags": "nyårsdag",
    "nyårsfesten": "nyårsfest",
    "nyårsfestens": "nyårsfest",
    "nyårsfester": "nyårsfest",
    "nyårsfesterna": "nyårsfest",
    "nyårsfesternas": "nyårsfest",
    "nyårsfesters": "nyårsfest",
    "nyårsfests": "nyårsfest",
    "nyårslöften": "nyårslöfte",
    "nyårslöftena": "nyårslöfte",
    "nyårslöftenas": "nyårslöfte",
    "nyårslöftens": "nyårslöfte",
    "nyårslöftes": "nyårslöfte",
    "nyårslöftet": "nyårslöfte",
    "nyårslöftets": "nyårslöfte",
    "nyårsnatn": "nyårsnatt",
    "nyårsnatns": "nyårsnatt",
    "nyårsnatten": "nyårsnatt",
    "nyårsnattens": "nyårsnatt",
    "nyårsnatts": "nyårsnatt",
    "nyårsnätter": "nyårsnatt",
    "nyårsnätterna": "nyårsnatt",
    "nyårsnätternas": "nyårsnatt",
    "nyårsnätters": "nyårsnatt",
    "nyårsvak": "nyårsvaka",
    "nyårsvakan": "nyårsvaka",
    "nyårsvakans": "nyårsvaka",
    "nyårsvakas": "nyårsvaka",
    "nyårsvake": "nyårsvaka",
    "nyårsvakor": "nyårsvaka",
    "nyårsvakorna": "nyårsvaka",
    "nyårsvakornas": "nyårsvaka",
    "nyårsvakors": "nyårsvaka",
    "nyårsvaks": "nyårsvaka",
    "näbb": "näbba",
    "näbbades": "näbbas",
    "näbban": "näbba",
    "näbbans": "näbba",
    "näbbar": "näbb",
    "näbbarna": "näbb",
    "näbbarnas": "näbb",
    "näbbars": "näbb",
    "näbbas": "näbba",
    "näbbats": "näbbas",
    "näbbdjuren": "näbbdjur",
    "näbbdjurens": "näbbdjur",
    "näbbdjuret": "näbbdjur",
    "näbbdjurets": "näbbdjur",
    "näbbdjurs": "näbbdjur",
    "näbbe": "näbba",
    "näbben": "näbb",
    "näbbens": "näbb",
    "näbbet": "näbb",
    "näbbets": "näbb",
    "näbbgädd": "näbbgädda",
    "näbbgäddan": "näbbgädda",
    "näbbgäddans": "näbbgädda",
    "näbbgäddas": "näbbgädda",
    "näbbgädde": "näbbgädda",
    "näbbgäddor": "näbbgädda",
    "näbbgäddorna": "näbbgädda",
    "näbbgäddornas": "näbbgädda",
    "näbbgäddors": "näbbgädda",
    "näbbgädds": "näbbgädda",
    "näbbiga": "näbbig",
    "näbbigare": "näbbig",
    "näbbigares": "näbbig",
    "näbbigas": "näbbig",
    "näbbigast": "näbbig",
    "näbbigaste": "näbbig",
    "näbbigastes": "näbbig",
    "näbbigasts": "näbbig",
    "näbbige": "näbbig",
    "näbbiges": "näbbig",
    "näbbigheten": "näbbighet",
    "näbbighetens": "näbbighet",
    "näbbighets": "näbbighet",
    "näbbigs": "näbbig",
    "näbbigt": "näbbig",
    "näbbigts": "näbbig",
    "näbbknölar": "näbbknöl",
    "näbbknölarna": "näbbknöl",
    "näbbknölarnas": "näbbknöl",
    "näbbknölars": "näbbknöl",
    "näbbknölen": "näbbknöl",
    "näbbknölens": "näbbknöl",
    "näbbknöls": "näbbknöl",
    "näbbmusen": "näbbmus",
    "näbbmusens": "näbbmus",
    "näbbmöss": "näbbmus",
    "näbbmössen": "näbbmus",
    "näbbmössens": "näbbmus",
    "näbbor": "näbba",
    "näbborna": "näbba",
    "näbbornas": "näbba",
    "näbbors": "näbba",
    "näbbs": "näbba",
    "näbbskon": "näbbsko",
    "näbbskons": "näbbsko",
    "näbbskor": "näbbsko",
    "näbbskorna": "näbbsko",
    "näbbskornas": "näbbsko",
    "näbbskors": "näbbsko",
    "näbbskos": "näbbsko",
    "näbbvalar": "näbbval",
    "näbbvalarna": "näbbval",
    "näbbvalarnas": "näbbval",
    "näbbvalars": "näbbval",
    "näbbvalen": "näbbval",
    "näbbvalens": "näbbval",
    "näbbvals": "näbbval",
    "näck": "näcka",
    "näckade": "näcka",
    "näckades": "näcka",
    "näckande": "näcka",
    "näckandes": "näcka",
    "näckar": "näcka",
    "näckas": "näcka",
    "näckat": "näcka",
    "näckats": "näcka",
    "näcken": "näck",
    "näckens": "näck",
    "näckrosbladen": "näckrosblad",
    "näckrosbladens": "näckrosblad",
    "näckrosbladet": "näckrosblad",
    "näckrosbladets": "näckrosblad",
    "näckrosblads": "näckrosblad",
    "näckrosen": "näckros",
    "näckrosens": "näckros",
    "näckrosor": "näckros",
    "näckrosorna": "näckros",
    "näckrosornas": "näckros",
    "näckrosors": "näckros",
    "näckrosroten": "näckrosrot",
    "näckrosrotens": "näckrosrot",
    "näckrosrots": "näckrosrot",
    "näckrosrötter": "näckrosrot",
    "näckrosrötterna": "näckrosrot",
    "näckrosrötternas": "näckrosrot",
    "näckrosrötters": "näckrosrot",
    "näcks": "näck",
    "näktergalar": "näktergal",
    "näktergalarna": "näktergal",
    "näktergalarnas": "näktergal",
    "näktergalars": "näktergal",
    "näktergalen": "näktergal",
    "näktergalens": "näktergal",
    "näktergals": "näktergal",
    "näktergalsslagen": "näktergalsslag",
    "näktergalsslagens": "näktergalsslag",
    "näktergalsslaget": "näktergalsslag",
    "näktergalsslagets": "näktergalsslag",
    "näktergalsslags": "näktergalsslag",
    "nämn": "nämna",
    "nämnande": "nämna",
    "nämnanden": "nämnande",
    "nämnandena": "nämnande",
    "nämnandenas": "nämnande",
    "nämnandens": "nämnande",
    "nämnandes": "nämnande",
    "nämnandet": "nämnande",
    "nämnandets": "nämnande",
    "nämnar": "nämnare",
    "nämnaren": "nämnare",
    "nämnarens": "nämnare",
    "nämnares": "nämnare",
    "nämnarna": "nämnare",
    "nämnarnas": "nämnare",
    "nämnas": "nämna",
    "nämnbara": "nämnbar",
    "nämnbarare": "nämnbar",
    "nämnbarares": "nämnbar",
    "nämnbaras": "nämnbar",
    "nämnbarast": "nämnbar",
    "nämnbaraste": "nämnbar",
    "nämnbarastes": "nämnbar",
    "nämnbarasts": "nämnbar",
    "nämnbare": "nämnbar",
    "nämnbares": "nämnbar",
    "nämnbarheten": "nämnbarhet",
    "nämnbarhetens": "nämnbarhet",
    "nämnbarhets": "nämnbarhet",
    "nämnbars": "nämnbar",
    "nämnbart": "nämnbar",
    "nämnbarts": "nämnbar",
    "nämnd": "nämna",
    "nämnda": "nämna",
    "nämndas": "nämna",
    "nämnde": "nämnd",
    "nämndemannen": "nämndeman",
    "nämndemannens": "nämndeman",
    "nämndemans": "nämndeman",
    "nämndemän": "nämndeman",
    "nämndemännen": "nämndeman",
    "nämndemännens": "nämndeman",
    "nämndemäns": "nämndeman",
    "nämnden": "nämnd",
    "nämndens": "nämnd",
    "nämnder": "nämnd",
    "nämnderna": "nämnd",
    "nämndernas": "nämnd",
    "nämnders": "nämnd",
    "nämndes": "nämna",
    "nämnds": "nämnd",
    "nämner": "nämna",
    "nämnes": "nämna",
    "nämns": "nämna",
    "nämnt": "nämna",
    "nämnts": "nämna",
    "nämnvärda": "nämnvärd",
    "nämnvärdare": "nämnvärd",
    "nämnvärdares": "nämnvärd",
    "nämnvärdas": "nämnvärd",
    "nämnvärdast": "nämnvärd",
    "nämnvärdaste": "nämnvärd",
    "nämnvärdastes": "nämnvärd",
    "nämnvärdasts": "nämnvärd",
    "nämnvärde": "nämnvärd",
    "nämnvärdes": "nämnvärd",
    "nämnvärdheten": "nämnvärdhet",
    "nämnvärdhetens": "nämnvärdhet",
    "nämnvärdhets": "nämnvärdhet",
    "nämnvärds": "nämnvärd",
    "nämnvärt": "nämnvärd",
    "nämnvärts": "nämnvärd",
    "nändes": "nännas",
    "nänns": "nännas",
    "nänts": "nännas",
    "näpenheten": "näpenhet",
    "näpenhetens": "näpenhet",
    "näpenheter": "näpenhet",
    "näpenheterna": "näpenhet",
    "näpenheternas": "näpenhet",
    "näpenheters": "näpenhet",
    "näpenhets": "näpenhet",
    "näpens": "näpen",
    "näpet": "näpen",
    "näpets": "näpen",
    "näpna": "näpen",
    "näpnare": "näpen",
    "näpnares": "näpen",
    "näpnas": "näpen",
    "näpnast": "näpen",
    "näpnaste": "näpen",
    "näpnastes": "näpen",
    "näpnasts": "näpen",
    "näpne": "näpen",
    "näpnes": "näpen",
    "näps": "näpsa",
    "näpsande": "näpsa",
    "näpsanden": "näpsande",
    "näpsandena": "näpsande",
    "näpsandenas": "näpsande",
    "näpsandens": "näpsande",
    "näpsandes": "näpsande",
    "näpsandet": "näpsande",
    "näpsandets": "näpsande",
    "näpsas": "näpsa",
    "näpser": "näpsa",
    "näpses": "näpsa",
    "näpst": "näpsa",
    "näpsta": "näpsa",
    "näpstas": "näpsa",
    "näpste": "näpsa",
    "näpsten": "näpst",
    "näpstens": "näpst",
    "näpstes": "näpsa",
    "näpsts": "näpst",
    "när": "nära",
    "närande": "nära",
    "näranden": "närande",
    "närandena": "närande",
    "närandenas": "närande",
    "närandens": "närande",
    "närandes": "närande",
    "närandet": "närande",
    "närandets": "närande",
    "näras": "nära",
    "närbelägens": "närbelägen",
    "närbeläget": "närbelägen",
    "närbelägets": "närbelägen",
    "närbelägna": "närbelägen",
    "närbelägnare": "närbelägen",
    "närbelägnares": "närbelägen",
    "närbelägnas": "närbelägen",
    "närbelägnast": "närbelägen",
    "närbelägnaste": "närbelägen",
    "närbelägnastes": "närbelägen",
    "närbelägnasts": "närbelägen",
    "närbelägne": "närbelägen",
    "närbelägnes": "närbelägen",
    "närbesläktade": "närbesläktad",
    "närbesläktades": "närbesläktad",
    "närbesläktads": "närbesläktad",
    "närbesläktat": "närbesläktad",
    "närbesläktats": "närbesläktad",
    "närbilden": "närbild",
    "närbildens": "närbild",
    "närbilder": "närbild",
    "närbilderna": "närbild",
    "närbildernas": "närbild",
    "närbilders": "närbild",
    "närbilds": "närbild",
    "närbutiken": "närbutik",
    "närbutikens": "närbutik",
    "närbutiker": "närbutik",
    "närbutikerna": "närbutik",
    "närbutikernas": "närbutik",
    "närbutikers": "närbutik",
    "närbutiks": "närbutik",
    "närd": "nära",
    "närda": "nära",
    "närdas": "nära",
    "närde": "nära",
    "närdemokratien": "närdemokrati",
    "närdemokratiens": "närdemokrati",
    "närdemokratin": "närdemokrati",
    "närdemokratins": "närdemokrati",
    "närdemokratis": "närdemokrati",
    "närdes": "nära",
    "närds": "nära",
    "näre": "nära",
    "näres": "nära",
    "närförsvaret": "närförsvar",
    "närförsvarets": "närförsvar",
    "närförsvars": "närförsvar",
    "närgångenheten": "närgångenhet",
    "närgångenhetens": "närgångenhet",
    "närgångenheter": "närgångenhet",
    "närgångenheterna": "närgångenhet",
    "närgångenheternas": "närgångenhet",
    "närgångenheters": "närgångenhet",
    "närgångenhets": "närgångenhet",
    "närgångens": "närgången",
    "närgånget": "närgången",
    "närgångets": "närgången",
    "närgångna": "närgången",
    "närgångnare": "närgången",
    "närgångnares": "närgången",
    "närgångnas": "närgången",
    "närgångnast": "närgången",
    "närgångnaste": "närgången",
    "närgångnastes": "närgången",
    "närgångnasts": "närgången",
    "närgångne": "närgången",
    "närgångnes": "närgången",
    "närheten": "närhet",
    "närhetens": "närhet",
    "närheter": "närhet",
    "närheterna": "närhet",
    "närheternas": "närhet",
    "närheters": "närhet",
    "närhets": "närhet",
    "näriga": "närig",
    "närigare": "närig",
    "närigares": "närig",
    "närigas": "närig",
    "närigast": "närig",
    "närigaste": "närig",
    "närigastes": "närig",
    "närigasts": "närig",
    "närige": "närig",
    "näriges": "närig",
    "närigs": "närig",
    "närigt": "närig",
    "närigts": "närig",
    "näringar": "näring",
    "näringarna": "näring",
    "näringarnas": "näring",
    "näringars": "näring",
    "näringen": "näring",
    "näringens": "näring",
    "närings": "näring",
    "näringsbristen": "näringsbrist",
    "näringsbristens": "näringsbrist",
    "näringsbrister": "näringsbrist",
    "näringsbristerna": "näringsbrist",
    "näringsbristernas": "näringsbrist",
    "näringsbristers": "näringsbrist",
    "näringsbrists": "näringsbrist",
    "näringsfattiga": "näringsfattig",
    "näringsfattigare": "näringsfattig",
    "näringsfattigares": "näringsfattig",
    "näringsfattigas": "näringsfattig",
    "näringsfattigast": "näringsfattig",
    "näringsfattigaste": "näringsfattig",
    "näringsfattigastes": "näringsfattig",
    "näringsfattigasts": "näringsfattig",
    "näringsfattige": "näringsfattig",
    "näringsfattiges": "näringsfattig",
    "näringsfattigs": "näringsfattig",
    "näringsfattigt": "näringsfattig",
    "näringsfattigts": "näringsfattig",
    "näringsfliten": "näringsflit",
    "näringsflitens": "näringsflit",
    "näringsflits": "näringsflit",
    "näringsfriheten": "näringsfrihet",
    "näringsfrihetens": "näringsfrihet",
    "näringsfriheter": "näringsfrihet",
    "näringsfriheterna": "näringsfrihet",
    "näringsfriheternas": "näringsfrihet",
    "näringsfriheters": "näringsfrihet",
    "näringsfrihets": "näringsfrihet",
    "näringsfrihetsombudsmannen": "näringsfrihetsombudsman",
    "näringsfrihetsombudsmannens": "näringsfrihetsombudsman",
    "näringsfrihetsombudsmans": "näringsfrihetsombudsman",
    "näringsfrihetsombudsmän": "näringsfrihetsombudsman",
    "näringsfrihetsombudsmännen": "näringsfrihetsombudsman",
    "näringsfrihetsombudsmännens": "näringsfrihetsombudsman",
    "näringsfrihetsombudsmäns": "näringsfrihetsombudsman",
    "näringsfysiologien": "näringsfysiologi",
    "näringsfysiologiens": "näringsfysiologi",
    "näringsfysiologin": "näringsfysiologi",
    "näringsfysiologins": "näringsfysiologi",
    "näringsfysiologis": "näringsfysiologi",
    "näringsfysiologiska": "näringsfysiologisk",
    "näringsfysiologiskare": "näringsfysiologisk",
    "näringsfysiologiskares": "näringsfysiologisk",
    "näringsfysiologiskas": "näringsfysiologisk",
    "näringsfysiologiskast": "näringsfysiologisk",
    "näringsfysiologiskaste": "näringsfysiologisk",
    "näringsfysiologiskastes": "näringsfysiologisk",
    "näringsfysiologiskasts": "näringsfysiologisk",
    "näringsfysiologiske": "näringsfysiologisk",
    "näringsfysiologiskes": "näringsfysiologisk",
    "näringsfysiologisks": "näringsfysiologisk",
    "näringsfysiologiskt": "näringsfysiologisk",
    "näringsfysiologiskts": "näringsfysiologisk",
    "näringsfången": "näringsfång",
    "näringsfångens": "näringsfång",
    "näringsfånget": "näringsfång",
    "näringsfångets": "näringsfång",
    "näringsfångs": "näringsfång",
    "näringsgeografien": "näringsgeografi",
    "näringsgeografiens": "näringsgeografi",
    "näringsgeografin": "näringsgeografi",
    "näringsgeografins": "näringsgeografi",
    "näringsgeografis": "näringsgeografi",
    "näringsgrenar": "näringsgren",
    "näringsgrenarna": "näringsgren",
    "näringsgrenarnas": "näringsgren",
    "näringsgrenars": "näringsgren",
    "näringsgrenen": "näringsgren",
    "näringsgrenens": "näringsgren",
    "näringsgrens": "näringsgren",
    "näringsidkar": "näringsidkare",
    "näringsidkaren": "näringsidkare",
    "näringsidkarens": "näringsidkare",
    "näringsidkares": "näringsidkare",
    "näringsidkarna": "näringsidkare",
    "näringsidkarnas": "näringsidkare",
    "näringskedjan": "näringskedja",
    "näringskedjans": "näringskedja",
    "näringskedjas": "näringskedja",
    "näringskedje": "näringskedja",
    "näringskedjor": "näringskedja",
    "näringskedjorna": "näringskedja",
    "näringskedjornas": "näringskedja",
    "näringskedjors": "näringskedja",
    "näringskäll": "näringskälla",
    "näringskällan": "näringskälla",
    "näringskällans": "näringskälla",
    "näringskällas": "näringskälla",
    "näringskälle": "näringskälla",
    "näringskällor": "näringskälla",
    "näringskällorna": "näringskälla",
    "näringskällornas": "näringskälla",
    "näringskällors": "näringskälla",
    "näringskälls": "näringskälla",
    "näringslivet": "näringsliv",
    "näringslivets": "näringsliv",
    "näringslivs": "näringsliv",
    "näringslivskonsulten": "näringslivskonsult",
    "näringslivskonsultens": "näringslivskonsult",
    "näringslivskonsulter": "näringslivskonsult",
    "näringslivskonsulterna": "näringslivskonsult",
    "näringslivskonsulternas": "näringslivskonsult",
    "näringslivskonsulters": "näringslivskonsult",
    "näringslivskonsults": "näringslivskonsult",
    "näringslivsledar": "näringslivsledare",
    "näringslivsledaren": "näringslivsledare",
    "näringslivsledarens": "näringslivsledare",
    "näringslivsledares": "näringslivsledare",
    "näringslivsledarna": "näringslivsledare",
    "näringslivsledarnas": "näringslivsledare",
    "näringslivsmässiga": "näringslivsmässig",
    "näringslivsmässigare": "näringslivsmässig",
    "näringslivsmässigares": "näringslivsmässig",
    "näringslivsmässigas": "näringslivsmässig",
    "näringslivsmässigast": "näringslivsmässig",
    "näringslivsmässigaste": "näringslivsmässig",
    "näringslivsmässigastes": "näringslivsmässig",
    "näringslivsmässigasts": "näringslivsmässig",
    "näringslivsmässige": "näringslivsmässig",
    "näringslivsmässiges": "näringslivsmässig",
    "näringslivsmässigs": "näringslivsmässig",
    "näringslivsmässigt": "näringslivsmässig",
    "näringslivsmässigts": "näringslivsmässig",
    "näringslivspolitiken": "näringslivspolitik",
    "näringslivspolitikens": "näringslivspolitik",
    "näringslivspolitiks": "näringslivspolitik",
    "näringslivspolitiska": "näringslivspolitisk",
    "näringslivspolitiskas": "näringslivspolitisk",
    "näringslivspolitiske": "näringslivspolitisk",
    "näringslivspolitiskes": "näringslivspolitisk",
    "näringslivspolitisks": "näringslivspolitisk",
    "näringslivspolitiskt": "näringslivspolitisk",
    "näringslivspolitiskts": "näringslivspolitisk",
    "näringslivstoppar": "näringslivstopp",
    "näringslivstopparna": "näringslivstopp",
    "näringslivstopparnas": "näringslivstopp",
    "näringslivstoppars": "näringslivstopp",
    "näringslivstoppen": "näringslivstopp",
    "näringslivstoppens": "näringslivstopp",
    "näringslivstopps": "näringslivstopp",
    "näringslösningar": "näringslösning",
    "näringslösningarna": "näringslösning",
    "näringslösningarnas": "näringslösning",
    "näringslösningars": "näringslösning",
    "näringslösningen": "näringslösning",
    "näringslösningens": "näringslösning",
    "näringslösnings": "näringslösning",
    "näringsministern": "näringsminister",
    "näringsministerns": "näringsminister",
    "näringsministers": "näringsminister",
    "näringsministrar": "näringsminister",
    "näringsministrarna": "näringsminister",
    "näringsministrarnas": "näringsminister",
    "näringsministrars": "näringsminister",
    "näringsmässiga": "näringsmässig",
    "näringsmässigare": "näringsmässig",
    "näringsmässigares": "näringsmässig",
    "näringsmässigas": "näringsmässig",
    "näringsmässigast": "näringsmässig",
    "näringsmässigaste": "näringsmässig",
    "näringsmässigastes": "näringsmässig",
    "näringsmässigasts": "näringsmässig",
    "näringsmässige": "näringsmässig",
    "näringsmässiges": "näringsmässig",
    "näringsmässigs": "näringsmässig",
    "näringsmässigt": "näringsmässig",
    "näringsmässigts": "näringsmässig",
    "näringspolitiken": "näringspolitik",
    "näringspolitikens": "näringspolitik",
    "näringspolitiks": "näringspolitik",
    "näringspolitiska": "näringspolitisk",
    "näringspolitiskas": "näringspolitisk",
    "näringspolitiske": "näringspolitisk",
    "näringspolitiskes": "näringspolitisk",
    "näringspolitisks": "näringspolitisk",
    "näringspolitiskt": "näringspolitisk",
    "näringspolitiskts": "näringspolitisk",
    "näringsprocessen": "näringsprocess",
    "näringsprocessens": "näringsprocess",
    "näringsprocesser": "näringsprocess",
    "näringsprocesserna": "näringsprocess",
    "näringsprocessernas": "näringsprocess",
    "näringsprocessers": "näringsprocess",
    "näringsrika": "näringsrik",
    "näringsrikare": "näringsrik",
    "näringsrikares": "näringsrik",
    "näringsrikas": "näringsrik",
    "näringsrikast": "näringsrik",
    "näringsrikaste": "näringsrik",
    "näringsrikastes": "näringsrik",
    "näringsrikasts": "näringsrik",
    "näringsrike": "näringsrik",
    "näringsrikes": "näringsrik",
    "näringsrikheten": "näringsrikhet",
    "näringsrikhetens": "näringsrikhet",
    "näringsrikhets": "näringsrikhet",
    "näringsriks": "näringsrik",
    "näringsrikt": "näringsrik",
    "näringsrikts": "näringsrik",
    "näringssalter": "näringssalt",
    "näringssalterna": "näringssalt",
    "näringssalternas": "näringssalt",
    "näringssalters": "näringssalt",
    "näringssaltet": "näringssalt",
    "näringssaltets": "näringssalt",
    "näringssalts": "näringssalt",
    "näringsställen": "näringsställe",
    "näringsställena": "näringsställe",
    "näringsställenas": "näringsställe",
    "näringsställens": "näringsställe",
    "näringsställes": "näringsställe",
    "näringsstället": "näringsställe",
    "näringsställets": "näringsställe",
    "näringsvärden": "näringsvärde",
    "näringsvärdena": "näringsvärde",
    "näringsvärdenas": "näringsvärde",
    "näringsvärdens": "näringsvärde",
    "näringsvärdes": "näringsvärde",
    "näringsvärdet": "näringsvärde",
    "näringsvärdets": "näringsvärde",
    "näringsämnen": "näringsämne",
    "näringsämnena": "näringsämne",
    "näringsämnenas": "näringsämne",
    "näringsämnens": "näringsämne",
    "näringsämnes": "näringsämne",
    "näringsämnet": "näringsämne",
    "näringsämnets": "näringsämne",
    "närkampen": "närkamp",
    "närkampens": "närkamp",
    "närkamper": "närkamp",
    "närkamperna": "närkamp",
    "närkampernas": "närkamp",
    "närkampers": "närkamp",
    "närkamps": "närkamp",
    "närkingar": "närking",
    "närkingarna": "närking",
    "närkingarnas": "närking",
    "närkingars": "närking",
    "närkingen": "närking",
    "närkingens": "närking",
    "närkings": "närking",
    "närkingsk": "närkingska",
    "närkingska": "närkingsk",
    "närkingskan": "närkingska",
    "närkingskans": "närkingska",
    "närkingskare": "närkingsk",
    "närkingskares": "närkingsk",
    "närkingskas": "närkingska",
    "närkingskast": "närkingsk",
    "närkingskaste": "närkingsk",
    "närkingskastes": "närkingsk",
    "närkingskasts": "närkingsk",
    "närkingske": "närkingska",
    "närkingskes": "närkingsk",
    "närkingskor": "närkingska",
    "närkingskorna": "närkingska",
    "närkingskornas": "närkingska",
    "närkingskors": "närkingska",
    "närkingsks": "närkingsk",
    "närkingskt": "närkingsk",
    "närkingskts": "närkingsk",
    "närkontakten": "närkontakt",
    "närkontaktens": "närkontakt",
    "närkontakts": "närkontakt",
    "närlagda": "närlagd",
    "närlagdare": "närlagd",
    "närlagdares": "närlagd",
    "närlagdas": "närlagd",
    "närlagdast": "närlagd",
    "närlagdaste": "närlagd",
    "närlagdastes": "närlagd",
    "närlagdasts": "närlagd",
    "närlagde": "närlagd",
    "närlagdes": "närlagd",
    "närlagds": "närlagd",
    "närlagt": "närlagd",
    "närlagts": "närlagd",
    "närmad": "närma",
    "närmade": "närma",
    "närmades": "närma",
    "närmads": "närma",
    "närmande": "närma",
    "närmanden": "närmande",
    "närmandena": "närmande",
    "närmandenas": "närmande",
    "närmandens": "närmande",
    "närmandes": "närmande",
    "närmandet": "närmande",
    "närmandets": "närmande",
    "närmar": "närma",
    "närmare": "nära",
    "närmares": "nära",
    "närmas": "närma",
    "närmast": "nära",
    "närmasta": "nära",
    "närmastas": "nära",
    "närmaste": "nära",
    "närmastes": "nära",
    "närmasts": "nära",
    "närmat": "närma",
    "närmats": "närma",
    "närme": "närma",
    "närmevärden": "närmevärde",
    "närmevärdena": "närmevärde",
    "närmevärdenas": "närmevärde",
    "närmevärdens": "närmevärde",
    "närmevärdes": "närmevärde",
    "närmevärdet": "närmevärde",
    "närmevärdets": "närmevärde",
    "närmiljöer": "närmiljö",
    "närmiljöerna": "närmiljö",
    "närmiljöernas": "närmiljö",
    "närmiljöers": "närmiljö",
    "närmiljön": "närmiljö",
    "närmiljöns": "närmiljö",
    "närmiljös": "närmiljö",
    "närminnes": "närminne",
    "närminnet": "närminne",
    "närminnets": "närminne",
    "närmre": "nära",
    "närmres": "nära",
    "närmst": "nära",
    "närmsta": "nära",
    "närmstas": "nära",
    "närmste": "nära",
    "närmstes": "nära",
    "närmsts": "nära",
    "närområden": "närområde",
    "närområdena": "närområde",
    "närområdenas": "närområde",
    "närområdens": "närområde",
    "närområdes": "närområde",
    "närområdet": "närområde",
    "närområdets": "närområde",
    "närpassagen": "närpassage",
    "närpassagens": "närpassage",
    "närpassager": "närpassage",
    "närpassagerna": "närpassage",
    "närpassagernas": "närpassage",
    "närpassagers": "närpassage",
    "närpassages": "närpassage",
    "närpunkten": "närpunkt",
    "närpunktens": "närpunkt",
    "närpunkter": "närpunkt",
    "närpunkterna": "närpunkt",
    "närpunkternas": "närpunkt",
    "närpunkters": "närpunkt",
    "närpunkts": "närpunkt",
    "närradion": "närradio",
    "närradions": "närradio",
    "närradios": "närradio",
    "närs": "nära",
    "närsalter": "närsalt",
    "närsalterna": "närsalt",
    "närsalternas": "närsalt",
    "närsalters": "närsalt",
    "närsaltet": "närsalt",
    "närsaltets": "närsalt",
    "närsalts": "närsalt",
    "närsamhällen": "närsamhälle",
    "närsamhällena": "närsamhälle",
    "närsamhällenas": "närsamhälle",
    "närsamhällens": "närsamhälle",
    "närsamhälles": "närsamhälle",
    "närsamhället": "närsamhälle",
    "närsamhällets": "närsamhälle",
    "närsamhälls": "närsamhälle",
    "närskylda": "närskyld",
    "närskyldare": "närskyld",
    "närskyldares": "närskyld",
    "närskyldas": "närskyld",
    "närskyldast": "närskyld",
    "närskyldaste": "närskyld",
    "närskyldastes": "närskyld",
    "närskyldasts": "närskyld",
    "närskylde": "närskyld",
    "närskyldes": "närskyld",
    "närskylds": "närskyld",
    "närskylt": "närskyld",
    "närskylts": "närskyld",
    "närslut": "närsluta",
    "närslutande": "närsluta",
    "närslutanden": "närslutande",
    "närslutandena": "närslutande",
    "närslutandenas": "närslutande",
    "närslutandens": "närslutande",
    "närslutandes": "närslutande",
    "närslutandet": "närslutande",
    "närslutandets": "närslutande",
    "närslutas": "närsluta",
    "närslute": "närsluta",
    "närsluten": "närsluta",
    "närslutens": "närsluta",
    "närsluter": "närsluta",
    "närslutes": "närsluta",
    "närslutet": "närsluta",
    "närslutets": "närsluta",
    "närslutit": "närsluta",
    "närslutits": "närsluta",
    "närslutna": "närsluta",
    "närslutnas": "närsluta",
    "närslutne": "närsluta",
    "närslutnes": "närsluta",
    "närsluts": "närsluta",
    "närslöt": "närsluta",
    "närslöte": "närsluta",
    "närslötes": "närsluta",
    "närslöts": "närsluta",
    "närspaningar": "närspaning",
    "närspaningarna": "närspaning",
    "närspaningarnas": "närspaning",
    "närspaningars": "närspaning",
    "närspaningen": "närspaning",
    "närspaningens": "närspaning",
    "närspanings": "närspaning",
    "närstriden": "närstrid",
    "närstridens": "närstrid",
    "närstrider": "närstrid",
    "närstriderna": "närstrid",
    "närstridernas": "närstrid",
    "närstriders": "närstrid",
    "närstrids": "närstrid",
    "närstudie": "närstudium",
    "närstudier": "närstudium",
    "närstudierna": "närstudium",
    "närstudiernas": "närstudium",
    "närstudiers": "närstudium",
    "närstudiet": "närstudium",
    "närstudiets": "närstudium",
    "närstudiums": "närstudium",
    "närsynta": "närsynt",
    "närsyntare": "närsynt",
    "närsyntares": "närsynt",
    "närsyntas": "närsynt",
    "närsyntast": "närsynt",
    "närsyntaste": "närsynt",
    "närsyntastes": "närsynt",
    "närsyntasts": "närsynt",
    "närsynte": "närsynt",
    "närsyntes": "närsynt",
    "närsyntheten": "närsynthet",
    "närsynthetens": "närsynthet",
    "närsyntheter": "närsynthet",
    "närsyntheterna": "närsynthet",
    "närsyntheternas": "närsynthet",
    "närsyntheters": "närsynthet",
    "närsynthets": "närsynthet",
    "närsynts": "närsynt",
    "närt": "nära",
    "närts": "nära",
    "närvar": "närvara",
    "närvarade": "närvara",
    "närvarades": "närvara",
    "närvarande": "närvara",
    "närvaranden": "närvarande",
    "närvarandena": "närvarande",
    "närvarandenas": "närvarande",
    "närvarandens": "närvarande",
    "närvarandes": "närvarande",
    "närvarandet": "närvarande",
    "närvarandets": "närvarande",
    "närvarar": "närvara",
    "närvaras": "närvara",
    "närvarat": "närvara",
    "närvarats": "närvara",
    "närvarelsen": "närvarelse",
    "närvarelsens": "närvarelse",
    "närvarelses": "närvarelse",
    "närvarit": "närvara",
    "närvarits": "närvara",
    "närvaron": "närvaro",
    "närvarons": "närvaro",
    "närvarorapporteringen": "närvarorapportering",
    "närvarorapporteringens": "närvarorapportering",
    "närvarorapporterings": "närvarorapportering",
    "närvaros": "närvaro",
    "näs": "näsa",
    "näsan": "näsa",
    "näsandningar": "näsandning",
    "näsandningarna": "näsandning",
    "näsandningarnas": "näsandning",
    "näsandningars": "näsandning",
    "näsandningen": "näsandning",
    "näsandningens": "näsandning",
    "näsandnings": "näsandning",
    "näsans": "näsa",
    "näsas": "näsa",
    "näsavtrycken": "näsavtryck",
    "näsavtryckens": "näsavtryck",
    "näsavtrycket": "näsavtryck",
    "näsavtryckets": "näsavtryck",
    "näsavtrycks": "näsavtryck",
    "näsbenen": "näsben",
    "näsbenens": "näsben",
    "näsbenet": "näsben",
    "näsbenets": "näsben",
    "näsbens": "näsben",
    "näsblodet": "näsblod",
    "näsblodets": "näsblod",
    "näsblods": "näsblod",
    "näsborr": "näsborre",
    "näsborrar": "näsborre",
    "näsborrarna": "näsborre",
    "näsborrarnas": "näsborre",
    "näsborrars": "näsborre",
    "näsborren": "näsborre",
    "näsborrens": "näsborre",
    "näsborres": "näsborre",
    "näsborrs": "näsborre",
    "näsbrosken": "näsbrosk",
    "näsbroskens": "näsbrosk",
    "näsbrosket": "näsbrosk",
    "näsbroskets": "näsbrosk",
    "näsbrosks": "näsbrosk",
    "näsbränn": "näsbränna",
    "näsbrännan": "näsbränna",
    "näsbrännans": "näsbränna",
    "näsbrännas": "näsbränna",
    "näsbränne": "näsbränna",
    "näsbrännor": "näsbränna",
    "näsbrännorna": "näsbränna",
    "näsbrännornas": "näsbränna",
    "näsbrännors": "näsbränna",
    "näsbränns": "näsbränna",
    "näsdukar": "näsduk",
    "näsdukarna": "näsduk",
    "näsdukarnas": "näsduk",
    "näsdukars": "näsduk",
    "näsduken": "näsduk",
    "näsdukens": "näsduk",
    "näsduks": "näsduk",
    "näse": "näsa",
    "näsen": "näs",
    "näsens": "näs",
    "näset": "näs",
    "näsets": "näs",
    "näsgångar": "näsgång",
    "näsgångarna": "näsgång",
    "näsgångarnas": "näsgång",
    "näsgångars": "näsgång",
    "näsgången": "näsgång",
    "näsgångens": "näsgång",
    "näsgångs": "näsgång",
    "näshål": "näshåla",
    "näshålan": "näshåla",
    "näshålans": "näshåla",
    "näshålas": "näshåla",
    "näshåle": "näshåla",
    "näshålor": "näshåla",
    "näshålorna": "näshåla",
    "näshålornas": "näshåla",
    "näshålors": "näshåla",
    "näshåls": "näshåla",
    "näskatarren": "näskatarr",
    "näskatarrens": "näskatarr",
    "näskatarrer": "näskatarr",
    "näskatarrerna": "näskatarr",
    "näskatarrernas": "näskatarr",
    "näskatarrers": "näskatarr",
    "näskatarrs": "näskatarr",
    "näsknäppar": "näsknäpp",
    "näsknäpparna": "näsknäpp",
    "näsknäpparnas": "näsknäpp",
    "näsknäppars": "näsknäpp",
    "näsknäppen": "näsknäpp",
    "näsknäppens": "näsknäpp",
    "näsknäpps": "näsknäpp",
    "näsljuden": "näsljud",
    "näsljudens": "näsljud",
    "näsljudet": "näsljud",
    "näsljudets": "näsljud",
    "näsljuds": "näsljud",
    "näsor": "näsa",
    "näsorna": "näsa",
    "näsornas": "näsa",
    "näsors": "näsa",
    "näsprydnaden": "näsprydnad",
    "näsprydnadens": "näsprydnad",
    "näsprydnader": "näsprydnad",
    "näsprydnaderna": "näsprydnad",
    "näsprydnadernas": "näsprydnad",
    "näsprydnaders": "näsprydnad",
    "näsprydnads": "näsprydnad",
    "näspärl": "näspärla",
    "näspärlan": "näspärla",
    "näspärlans": "näspärla",
    "näspärlas": "näspärla",
    "näspärle": "näspärla",
    "näspärlor": "näspärla",
    "näspärlorna": "näspärla",
    "näspärlornas": "näspärla",
    "näspärlors": "näspärla",
    "näspärls": "näspärla",
    "näsringar": "näsring",
    "näsringarna": "näsring",
    "näsringarnas": "näsring",
    "näsringars": "näsring",
    "näsringen": "näsring",
    "näsringens": "näsring",
    "näsrings": "näsring",
    "näsroten": "näsrot",
    "näsrotens": "näsrot",
    "näsrots": "näsrot",
    "näsryggar": "näsrygg",
    "näsryggarna": "näsrygg",
    "näsryggarnas": "näsrygg",
    "näsryggars": "näsrygg",
    "näsryggen": "näsrygg",
    "näsryggens": "näsrygg",
    "näsryggs": "näsrygg",
    "näsrötter": "näsrot",
    "näsrötterna": "näsrot",
    "näsrötternas": "näsrot",
    "näsrötters": "näsrot",
    "nässel": "nässla",
    "nässelcellen": "nässelcell",
    "nässelcellens": "nässelcell",
    "nässelceller": "nässelcell",
    "nässelcellerna": "nässelcell",
    "nässelcellernas": "nässelcell",
    "nässelcellers": "nässelcell",
    "nässelcells": "nässelcell",
    "nässeldjuren": "nässeldjur",
    "nässeldjurens": "nässeldjur",
    "nässeldjuret": "nässeldjur",
    "nässeldjurets": "nässeldjur",
    "nässeldjurs": "nässeldjur",
    "nässelfebern": "nässelfeber",
    "nässelfeberns": "nässelfeber",
    "nässelfebers": "nässelfeber",
    "nässelfibern": "nässelfiber",
    "nässelfiberns": "nässelfiber",
    "nässelfibers": "nässelfiber",
    "nässelfibrer": "nässelfiber",
    "nässelfibrerna": "nässelfiber",
    "nässelfibrernas": "nässelfiber",
    "nässelfibrers": "nässelfiber",
    "nässelfjärilar": "nässelfjäril",
    "nässelfjärilarna": "nässelfjäril",
    "nässelfjärilarnas": "nässelfjäril",
    "nässelfjärilars": "nässelfjäril",
    "nässelfjärilen": "nässelfjäril",
    "nässelfjärilens": "nässelfjäril",
    "nässelfjäriln": "nässelfjäril",
    "nässelfjärilns": "nässelfjäril",
    "nässelfjärils": "nässelfjäril",
    "nässelkålen": "nässelkål",
    "nässelkålens": "nässelkål",
    "nässelkåls": "nässelkål",
    "nässelsoppan": "nässelsoppa",
    "nässelsoppans": "nässelsoppa",
    "nässelsoppas": "nässelsoppa",
    "nässelsoppe": "nässelsoppa",
    "nässelsoppor": "nässelsoppa",
    "nässelsopporna": "nässelsoppa",
    "nässelsoppornas": "nässelsoppa",
    "nässelsoppors": "nässelsoppa",
    "nässlan": "nässla",
    "nässlans": "nässla",
    "nässlas": "nässla",
    "nässle": "nässla",
    "nässlor": "nässla",
    "nässlorna": "nässla",
    "nässlornas": "nässla",
    "nässlors": "nässla",
    "nässpetsar": "nässpets",
    "nässpetsarna": "nässpets",
    "nässpetsarnas": "nässpets",
    "nässpetsars": "nässpets",
    "nässpetsen": "nässpets",
    "nässpetsens": "nässpets",
    "nässprayen": "nässpray",
    "nässprayens": "nässpray",
    "nässprayer": "nässpray",
    "nässprayerna": "nässpray",
    "nässprayernas": "nässpray",
    "nässprayers": "nässpray",
    "nässprays": "nässpray",
    "nässprejen": "nässprej",
    "nässprejens": "nässprej",
    "nässprejer": "nässprej",
    "nässprejerna": "nässprej",
    "nässprejernas": "nässprej",
    "nässprejers": "nässprej",
    "nässprejs": "nässprej",
    "näst": "näste",
    "nästad": "nästa",
    "nästade": "nästa",
    "nästades": "nästa",
    "nästads": "nästa",
    "nästande": "nästa",
    "nästanden": "nästande",
    "nästandena": "nästande",
    "nästandenas": "nästande",
    "nästandens": "nästande",
    "nästandes": "nästande",
    "nästandet": "nästande",
    "nästandets": "nästande",
    "nästar": "nästa",
    "nästas": "nästa",
    "nästat": "nästa",
    "nästats": "nästa",
    "näste": "nästa",
    "nästen": "näste",
    "nästena": "näste",
    "nästenas": "näste",
    "nästens": "näste",
    "nästes": "näste",
    "nästet": "näste",
    "nästets": "näste",
    "nästippar": "nästipp",
    "nästipparna": "nästipp",
    "nästipparnas": "nästipp",
    "nästippars": "nästipp",
    "nästippen": "nästipp",
    "nästippens": "nästipp",
    "nästipps": "nästipp",
    "nästkusinen": "nästkusin",
    "nästkusinens": "nästkusin",
    "nästkusiner": "nästkusin",
    "nästkusinerna": "nästkusin",
    "nästkusinernas": "nästkusin",
    "nästkusiners": "nästkusin",
    "nästkusins": "nästkusin",
    "nästlidens": "nästliden",
    "nästlidet": "nästliden",
    "nästlidets": "nästliden",
    "nästlidna": "nästliden",
    "nästlidnare": "nästliden",
    "nästlidnares": "nästliden",
    "nästlidnas": "nästliden",
    "nästlidnast": "nästliden",
    "nästlidnaste": "nästliden",
    "nästlidnastes": "nästliden",
    "nästlidnasts": "nästliden",
    "nästlidne": "nästliden",
    "nästlidnes": "nästliden",
    "nästonen": "näston",
    "nästonens": "näston",
    "nästons": "näston",
    "nästs": "näst",
    "nästungar": "nästunge",
    "nästungarna": "nästunge",
    "nästungarnas": "nästunge",
    "nästungars": "nästunge",
    "nästungen": "nästunge",
    "nästungens": "nästunge",
    "nästunges": "nästunge",
    "nästäggen": "nästägg",
    "nästäggens": "nästägg",
    "nästägget": "nästägg",
    "nästäggets": "nästägg",
    "nästäggs": "nästägg",
    "nästäppan": "nästäppa",
    "nästäppans": "nästäppa",
    "nästäppas": "nästäppa",
    "näsving": "näsvinge",
    "näsvingar": "näsvinge",
    "näsvingarna": "näsvinge",
    "näsvingarnas": "näsvinge",
    "näsvingars": "näsvinge",
    "näsvingen": "näsvinge",
    "näsvingens": "näsvinge",
    "näsvinges": "näsvinge",
    "näsvings": "näsvinge",
    "näsvisa": "näsvis",
    "näsvisare": "näsvis",
    "näsvisares": "näsvis",
    "näsvisas": "näsvis",
    "näsvisast": "näsvis",
    "näsvisaste": "näsvis",
    "näsvisastes": "näsvis",
    "näsvisasts": "näsvis",
    "näsvise": "näsvis",
    "näsvises": "näsvis",
    "näsvisheten": "näsvishet",
    "näsvishetens": "näsvishet",
    "näsvishets": "näsvishet",
    "näsvist": "näsvis",
    "näsvists": "näsvis",
    "nätad": "näta",
    "nätade": "näta",
    "nätades": "näta",
    "nätads": "näta",
    "nätande": "näta",
    "nätanden": "nätande",
    "nätandena": "nätande",
    "nätandenas": "nätande",
    "nätandens": "nätande",
    "nätandes": "nätande",
    "nätandet": "nätande",
    "nätandets": "nätande",
    "nätanslutens": "nätansluten",
    "nätanslutet": "nätansluten",
    "nätanslutets": "nätansluten",
    "nätanslutna": "nätansluten",
    "nätanslutnare": "nätansluten",
    "nätanslutnares": "nätansluten",
    "nätanslutnas": "nätansluten",
    "nätanslutnast": "nätansluten",
    "nätanslutnaste": "nätansluten",
    "nätanslutnastes": "nätansluten",
    "nätanslutnasts": "nätansluten",
    "nätanslutne": "nätansluten",
    "nätanslutnes": "nätansluten",
    "nätanvändandes": "nätanvändande",
    "nätanvändandet": "nätanvändande",
    "nätanvändandets": "nätanvändande",
    "nätar": "näta",
    "nätartikeln": "nätartikel",
    "nätartikelns": "nätartikel",
    "nätartikels": "nätartikel",
    "nätartiklar": "nätartikel",
    "nätartiklarna": "nätartikel",
    "nätartiklarnas": "nätartikel",
    "nätartiklars": "nätartikel",
    "nätas": "näta",
    "nätat": "näta",
    "nätats": "näta",
    "nätattacken": "nätattack",
    "nätattackens": "nätattack",
    "nätattacker": "nätattack",
    "nätattackerna": "nätattack",
    "nätattackernas": "nätattack",
    "nätattackers": "nätattack",
    "nätattacks": "nätattack",
    "nätbedrägerier": "nätbedrägeri",
    "nätbedrägerierna": "nätbedrägeri",
    "nätbedrägeriernas": "nätbedrägeri",
    "nätbedrägeriers": "nätbedrägeri",
    "nätbedrägeriet": "nätbedrägeri",
    "nätbedrägeriets": "nätbedrägeri",
    "nätbedrägeris": "nätbedrägeri",
    "nätbedrägerit": "nätbedrägeri",
    "nätbedrägerits": "nätbedrägeri",
    "nätbluffar": "nätbluff",
    "nätbluffarna": "nätbluff",
    "nätbluffarnas": "nätbluff",
    "nätbluffars": "nätbluff",
    "nätbluffen": "nätbluff",
    "nätbluffens": "nätbluff",
    "nätbluffs": "nätbluff",
    "nätbokningar": "nätbokning",
    "nätbokningarna": "nätbokning",
    "nätbokningarnas": "nätbokning",
    "nätbokningars": "nätbokning",
    "nätbokningen": "nätbokning",
    "nätbokningens": "nätbokning",
    "nätboknings": "nätbokning",
    "nätbollar": "nätboll",
    "nätbollarna": "nätboll",
    "nätbollarnas": "nätboll",
    "nätbollars": "nätboll",
    "nätbollen": "nätboll",
    "nätbollens": "nätboll",
    "nätbolls": "nätboll",
    "nätburar": "nätbur",
    "nätburarna": "nätbur",
    "nätburarnas": "nätbur",
    "nätburars": "nätbur",
    "nätburen": "nätbur",
    "nätburens": "nätbur",
    "nätburs": "nätbur",
    "nätcensuren": "nätcensur",
    "nätcensurens": "nätcensur",
    "nätcensurs": "nätcensur",
    "nätdriften": "nätdrift",
    "nätdriftens": "nätdrift",
    "nätdrifts": "nätdrift",
    "nätdrogen": "nätdrog",
    "nätdrogens": "nätdrog",
    "nätdroger": "nätdrog",
    "nätdrogerna": "nätdrog",
    "nätdrogernas": "nätdrog",
    "nätdrogers": "nätdrog",
    "nätdrogs": "nätdrog",
    "nätdörrar": "nätdörr",
    "nätdörrarna": "nätdörr",
    "nätdörrarnas": "nätdörr",
    "nätdörrars": "nätdörr",
    "nätdörren": "nätdörr",
    "nätdörrens": "nätdörr",
    "nätdörrs": "nätdörr",
    "näten": "nät",
    "nätens": "nät",
    "nätet": "nät",
    "nätets": "nät",
    "nätfiskes": "nätfiske",
    "nätfisket": "nätfiske",
    "nätfiskets": "nätfiske",
    "nätformiga": "nätformig",
    "nätformigare": "nätformig",
    "nätformigares": "nätformig",
    "nätformigas": "nätformig",
    "nätformigast": "nätformig",
    "nätformigaste": "nätformig",
    "nätformigastes": "nätformig",
    "nätformigasts": "nätformig",
    "nätformige": "nätformig",
    "nätformiges": "nätformig",
    "nätformigheten": "nätformighet",
    "nätformighetens": "nätformighet",
    "nätformighets": "nätformighet",
    "nätformigs": "nätformig",
    "nätformigt": "nätformig",
    "nätformigts": "nätformig",
    "nätfönsterna": "nätfönster",
    "nätfönsternas": "nätfönster",
    "nätfönsters": "nätfönster",
    "nätfönstren": "nätfönster",
    "nätfönstrens": "nätfönster",
    "nätfönstret": "nätfönster",
    "nätfönstrets": "nätfönster",
    "nätguruer": "nätguru",
    "nätguruerna": "nätguru",
    "nätguruernas": "nätguru",
    "nätguruers": "nätguru",
    "nätgurun": "nätguru",
    "nätguruns": "nätguru",
    "nätgurus": "nätguru",
    "nätgurusarna": "nätguru",
    "nätgurusarnas": "nätguru",
    "näthandeln": "näthandel",
    "näthandelns": "näthandel",
    "näthandels": "näthandel",
    "näthandl": "näthandla",
    "näthandlade": "näthandla",
    "näthandlades": "näthandla",
    "näthandlande": "näthandla",
    "näthandlanden": "näthandlande",
    "näthandlandena": "näthandlande",
    "näthandlandenas": "näthandlande",
    "näthandlandens": "näthandlande",
    "näthandlandes": "näthandlande",
    "näthandlandet": "näthandlande",
    "näthandlandets": "näthandlande",
    "näthandlar": "näthandla",
    "näthandlas": "näthandla",
    "näthandlat": "näthandla",
    "näthandlats": "näthandla",
    "näthatet": "näthat",
    "näthatets": "näthat",
    "näthats": "näthat",
    "näthinnan": "näthinna",
    "näthinnans": "näthinna",
    "näthinnas": "näthinna",
    "näthinne": "näthinna",
    "näthinneavlossningen": "näthinneavlossning",
    "näthinneavlossningens": "näthinneavlossning",
    "näthinneavlossnings": "näthinneavlossning",
    "näthinnor": "näthinna",
    "näthinnorna": "näthinna",
    "näthinnornas": "näthinna",
    "näthinnors": "näthinna",
    "nätkampanjen": "nätkampanj",
    "nätkampanjens": "nätkampanj",
    "nätkampanjer": "nätkampanj",
    "nätkampanjerna": "nätkampanj",
    "nätkampanjernas": "nätkampanj",
    "nätkampanjers": "nätkampanj",
    "nätkampanjs": "nätkampanj",
    "nätmag": "nätmage",
    "nätmagar": "nätmage",
    "nätmagarna": "nätmage",
    "nätmagarnas": "nätmage",
    "nätmagars": "nätmage",
    "nätmagen": "nätmage",
    "nätmagens": "nätmage",
    "nätmages": "nätmage",
    "nätmags": "nätmage",
    "nätmask": "nätmaska",
    "nätmaskan": "nätmaska",
    "nätmaskans": "nätmaska",
    "nätmaskas": "nätmaska",
    "nätmaske": "nätmaska",
    "nätmaskor": "nätmaska",
    "nätmaskorna": "nätmaska",
    "nätmaskornas": "nätmaska",
    "nätmaskors": "nätmaska",
    "nätmelonen": "nätmelon",
    "nätmelonens": "nätmelon",
    "nätmeloner": "nätmelon",
    "nätmelonerna": "nätmelon",
    "nätmelonernas": "nätmelon",
    "nätmeloners": "nätmelon",
    "nätmelons": "nätmelon",
    "nätporren": "nätporr",
    "nätporrens": "nätporr",
    "nätporrs": "nätporr",
    "nätrullar": "nätrullare",
    "nätrullaren": "nätrullare",
    "nätrullarens": "nätrullare",
    "nätrullares": "nätrullare",
    "nätrullarna": "nätrullare",
    "nätrullarnas": "nätrullare",
    "näts": "nät",
    "nätsaxar": "nätsax",
    "nätsaxarna": "nätsax",
    "nätsaxarnas": "nätsax",
    "nätsaxars": "nätsax",
    "nätsaxen": "nätsax",
    "nätsaxens": "nätsax",
    "nätspelet": "nätspel",
    "nätspelets": "nätspel",
    "nätspels": "nätspel",
    "nätspänningar": "nätspänning",
    "nätspänningarna": "nätspänning",
    "nätspänningarnas": "nätspänning",
    "nätspänningars": "nätspänning",
    "nätspänningen": "nätspänning",
    "nätspänningens": "nätspänning",
    "nätspännings": "nätspänning",
    "nätstrump": "nätstrumpa",
    "nätstrumpan": "nätstrumpa",
    "nätstrumpans": "nätstrumpa",
    "nätstrumpas": "nätstrumpa",
    "nätstrumpe": "nätstrumpa",
    "nätstrumpor": "nätstrumpa",
    "nätstrumporna": "nätstrumpa",
    "nätstrumpornas": "nätstrumpa",
    "nätstrumpors": "nätstrumpa",
    "nätstrumps": "nätstrumpa",
    "nätta": "nätt",
    "nättare": "nätt",
    "nättares": "nätt",
    "nättas": "nätt",
    "nättast": "nätt",
    "nättaste": "nätt",
    "nättastes": "nätt",
    "nättasts": "nätt",
    "nätte": "nätt",
    "nätteldukar": "nättelduk",
    "nätteldukarna": "nättelduk",
    "nätteldukarnas": "nättelduk",
    "nätteldukars": "nättelduk",
    "nättelduken": "nättelduk",
    "nätteldukens": "nättelduk",
    "nättelduks": "nättelduk",
    "nätter": "natt",
    "nätterna": "natt",
    "nätternas": "natt",
    "nätters": "natt",
    "nättes": "nätt",
    "nättheten": "nätthet",
    "nätthetens": "nätthet",
    "nätthets": "nätthet",
    "nättidningar": "nättidning",
    "nättidningarna": "nättidning",
    "nättidningarnas": "nättidning",
    "nättidningars": "nättidning",
    "nättidningen": "nättidning",
    "nättidningens": "nättidning",
    "nättidnings": "nättidning",
    "nättingar": "nätting",
    "nättingarna": "nätting",
    "nättingarnas": "nätting",
    "nättingars": "nätting",
    "nättingen": "nätting",
    "nättingens": "nätting",
    "nättings": "nätting",
    "nättröj": "nättröja",
    "nättröjan": "nättröja",
    "nättröjans": "nättröja",
    "nättröjas": "nättröja",
    "nättröje": "nättröja",
    "nättröjor": "nättröja",
    "nättröjorna": "nättröja",
    "nättröjornas": "nättröja",
    "nättröjors": "nättröja",
    "nättröjs": "nättröja",
    "nätts": "nätt",
    "nätuppslagsverken": "nätuppslagsverk",
    "nätuppslagsverkens": "nätuppslagsverk",
    "nätuppslagsverket": "nätuppslagsverk",
    "nätuppslagsverkets": "nätuppslagsverk",
    "nätuppslagsverks": "nätuppslagsverk",
    "nätvana": "nätvan",
    "nätvanan": "nätvana",
    "nätvanans": "nätvana",
    "nätvanare": "nätvan",
    "nätvanares": "nätvan",
    "nätvanas": "nätvana",
    "nätvanast": "nätvan",
    "nätvanaste": "nätvan",
    "nätvanastes": "nätvan",
    "nätvanasts": "nätvan",
    "nätvane": "nätvana",
    "nätvanes": "nätvan",
    "nätvanor": "nätvana",
    "nätvanorna": "nätvana",
    "nätvanornas": "nätvana",
    "nätvanors": "nätvana",
    "nätvans": "nätvan",
    "nätvant": "nätvan",
    "nätvants": "nätvan",
    "nätverken": "nätverk",
    "nätverkens": "nätverk",
    "nätverket": "nätverk",
    "nätverkets": "nätverk",
    "nätverks": "nätverk",
    "nätving": "nätvinge",
    "nätvingar": "nätvinge",
    "nätvingarna": "nätvinge",
    "nätvingarnas": "nätvinge",
    "nätvingars": "nätvinge",
    "nätvingen": "nätvinge",
    "nätvingens": "nätvinge",
    "nätvinges": "nätvinge",
    "nätvings": "nätvinge",
    "näv": "näve",
    "nävan": "näva",
    "nävans": "näva",
    "nävar": "näve",
    "nävarna": "näve",
    "nävarnas": "näve",
    "nävars": "näve",
    "nävas": "näva",
    "näve": "näva",
    "näven": "näve",
    "nävens": "näve",
    "näverbehållar": "näverbehållare",
    "näverbehållaren": "näverbehållare",
    "näverbehållarens": "näverbehållare",
    "näverbehållares": "näverbehållare",
    "näverbehållarna": "näverbehållare",
    "näverbehållarnas": "näverbehållare",
    "näverflaken": "näverflak",
    "näverflakens": "näverflak",
    "näverflaket": "näverflak",
    "näverflakets": "näverflak",
    "näverflaks": "näverflak",
    "näverkontar": "näverkont",
    "näverkontarna": "näverkont",
    "näverkontarnas": "näverkont",
    "näverkontars": "näverkont",
    "näverkonten": "näverkont",
    "näverkontens": "näverkont",
    "näverkonter": "näverkont",
    "näverkonterna": "näverkont",
    "näverkonternas": "näverkont",
    "näverkonters": "näverkont",
    "näverkonts": "näverkont",
    "näverkorgar": "näverkorg",
    "näverkorgarna": "näverkorg",
    "näverkorgarnas": "näverkorg",
    "näverkorgars": "näverkorg",
    "näverkorgen": "näverkorg",
    "näverkorgens": "näverkorg",
    "näverkorgs": "näverkorg",
    "näverlurar": "näverlur",
    "näverlurarna": "näverlur",
    "näverlurarnas": "näverlur",
    "näverlurars": "näverlur",
    "näverluren": "näverlur",
    "näverlurens": "näverlur",
    "näverlurs": "näverlur",
    "nävern": "näver",
    "näverns": "näver",
    "nävers": "näver",
    "näversömmar": "näversöm",
    "näversömmarna": "näversöm",
    "näversömmarnas": "näversöm",
    "näversömmars": "näversöm",
    "näversömmen": "näversöm",
    "näversömmens": "näversöm",
    "näversöms": "näversöm",
    "näves": "näve",
    "nävgröten": "nävgröt",
    "nävgrötens": "nävgröt",
    "nävgröts": "nävgröt",
    "nävkampen": "nävkamp",
    "nävkampens": "nävkamp",
    "nävkamper": "nävkamp",
    "nävkamperna": "nävkamp",
    "nävkampernas": "nävkamp",
    "nävkampers": "nävkamp",
    "nävkamps": "nävkamp",
    "nävor": "näva",
    "nävorna": "näva",
    "nävornas": "näva",
    "nävors": "näva",
    "nävrar": "näver",
    "nävrarna": "näver",
    "nävrarnas": "näver",
    "nävrars": "näver",
    "nävrätten": "nävrätt",
    "nävrättens": "nävrätt",
    "nävrätts": "nävrätt",
    "nävs": "näve",
    "nådad": "nåda",
    "nådade": "nåda",
    "nådades": "nåda",
    "nådads": "nåda",
    "nådande": "nåda",
    "nådanden": "nådande",
    "nådandena": "nådande",
    "nådandenas": "nådande",
    "nådandens": "nådande",
    "nådandes": "nådande",
    "nådandet": "nådande",
    "nådandets": "nådande",
    "nådar": "nåda",
    "nådarna": "nåd",
    "nådarnas": "nåd",
    "nådars": "nåd",
    "nådas": "nåda",
    "nådaskotten": "nådaskott",
    "nådaskottens": "nådaskott",
    "nådaskottet": "nådaskott",
    "nådaskottets": "nådaskott",
    "nådaskotts": "nådaskott",
    "nådastötar": "nådastöt",
    "nådastötarna": "nådastöt",
    "nådastötarnas": "nådastöt",
    "nådastötars": "nådastöt",
    "nådastöten": "nådastöt",
    "nådastötens": "nådastöt",
    "nådastöts": "nådastöt",
    "nådat": "nåda",
    "nådatiden": "nådatid",
    "nådatidens": "nådatid",
    "nådatids": "nådatid",
    "nådats": "nåda",
    "nådavalen": "nådaval",
    "nådavalens": "nådaval",
    "nådavalet": "nådaval",
    "nådavalets": "nådaval",
    "nådavals": "nådaval",
    "nådd": "nå",
    "nådda": "nå",
    "nåddas": "nå",
    "nådde": "nå",
    "nåddes": "nå",
    "nådds": "nå",
    "nådeansökans": "nådeansökan",
    "nådeansökningar": "nådeansökning",
    "nådeansökningarna": "nådeansökning",
    "nådeansökningarnas": "nådeansökning",
    "nådeansökningars": "nådeansökning",
    "nådeansökningen": "nådeansökning",
    "nådeansökningens": "nådeansökning",
    "nådeansöknings": "nådeansökning",
    "nådebevisen": "nådebevis",
    "nådebevisens": "nådebevis",
    "nådebeviset": "nådebevis",
    "nådebevisets": "nådebevis",
    "nådeborden": "nådebord",
    "nådebordens": "nådebord",
    "nådebordet": "nådebord",
    "nådebordets": "nådebord",
    "nådebords": "nådebord",
    "nådebrödet": "nådebröd",
    "nådebrödets": "nådebröd",
    "nådebröds": "nådebröd",
    "nådegåvan": "nådegåva",
    "nådegåvans": "nådegåva",
    "nådegåvas": "nådegåva",
    "nådegåve": "nådegåva",
    "nådegåvo": "nådegåva",
    "nådegåvor": "nådegåva",
    "nådegåvorna": "nådegåva",
    "nådegåvornas": "nådegåva",
    "nådegåvors": "nådegåva",
    "nådehjonen": "nådehjon",
    "nådehjonens": "nådehjon",
    "nådehjonet": "nådehjon",
    "nådehjonets": "nådehjon",
    "nådehjons": "nådehjon",
    "nådeliga": "nådelig",
    "nådeligare": "nådelig",
    "nådeligares": "nådelig",
    "nådeligas": "nådelig",
    "nådeligast": "nådelig",
    "nådeligaste": "nådelig",
    "nådeligastes": "nådelig",
    "nådeligasts": "nådelig",
    "nådelige": "nådelig",
    "nådeliges": "nådelig",
    "nådeligheten": "nådelighet",
    "nådelighetens": "nådelighet",
    "nådelighets": "nådelighet",
    "nådeligs": "nådelig",
    "nådeligt": "nådelig",
    "nådeligts": "nådelig",
    "nådemedels": "nådemedel",
    "nådemedlen": "nådemedel",
    "nådemedlens": "nådemedel",
    "nådemedlet": "nådemedel",
    "nådemedlets": "nådemedel",
    "nåden": "nåd",
    "nådens": "nåd",
    "nådes": "nåde",
    "nådevedermälen": "nådevedermäle",
    "nådevedermälena": "nådevedermäle",
    "nådevedermälenas": "nådevedermäle",
    "nådevedermälens": "nådevedermäle",
    "nådevedermäles": "nådevedermäle",
    "nådevedermälet": "nådevedermäle",
    "nådevedermälets": "nådevedermäle",
    "nådiga": "nådig",
    "nådigare": "nådig",
    "nådigares": "nådig",
    "nådigas": "nådig",
    "nådigast": "nådig",
    "nådigaste": "nådig",
    "nådigastes": "nådig",
    "nådigasts": "nådig",
    "nådige": "nådig",
    "nådiges": "nådig",
    "nådigs": "nådig",
    "nådigt": "nådig",
    "nådigts": "nådig",
    "nåds": "nåd",
    "nådåren": "nådår",
    "nådårens": "nådår",
    "nådåret": "nådår",
    "nådårets": "nådår",
    "nådårs": "nådår",
    "nående": "nå",
    "nåenden": "nående",
    "nåendena": "nående",
    "nåendenas": "nående",
    "nåendens": "nående",
    "nåendes": "nående",
    "nåendet": "nående",
    "nåendets": "nående",
    "någadera": "någondera",
    "någaderas": "någondera",
    "någonderas": "någondera",
    "någons": "någon",
    "någontings": "någonting",
    "något": "någon",
    "någotdera": "någondera",
    "någotderas": "någondera",
    "någots": "någon",
    "några": "någon",
    "någras": "någon",
    "nålad": "nåla",
    "nålade": "nåla",
    "nålades": "nåla",
    "nålads": "nåla",
    "nålande": "nåla",
    "nålanden": "nålande",
    "nålandena": "nålande",
    "nålandenas": "nålande",
    "nålandens": "nålande",
    "nålandes": "nålande",
    "nålandet": "nålande",
    "nålandets": "nålande",
    "nålar": "nåla",
    "nålarna": "nål",
    "nålarnas": "nål",
    "nålars": "nål",
    "nålas": "nåla",
    "nålat": "nåla",
    "nålats": "nåla",
    "nålbreven": "nålbrev",
    "nålbrevens": "nålbrev",
    "nålbrevet": "nålbrev",
    "nålbrevets": "nålbrev",
    "nålbrevs": "nålbrev",
    "nåldyn": "nåldyna",
    "nåldynan": "nåldyna",
    "nåldynans": "nåldyna",
    "nåldynas": "nåldyna",
    "nåldyne": "nåldyna",
    "nåldynor": "nåldyna",
    "nåldynorna": "nåldyna",
    "nåldynornas": "nåldyna",
    "nåldynors": "nåldyna",
    "nåldyns": "nåldyna",
    "nålen": "nål",
    "nålens": "nål",
    "nålfilar": "nålfil",
    "nålfilarna": "nålfil",
    "nålfilarnas": "nålfil",
    "nålfilars": "nålfil",
    "nålfilen": "nålfil",
    "nålfilens": "nålfil",
    "nålfils": "nålfil",
    "nålfiltmatt": "nålfiltmatta",
    "nålfiltmattan": "nålfiltmatta",
    "nålfiltmattans": "nålfiltmatta",
    "nålfiltmattas": "nålfiltmatta",
    "nålfiltmatte": "nålfiltmatta",
    "nålfiltmattor": "nålfiltmatta",
    "nålfiltmattorna": "nålfiltmatta",
    "nålfiltmattornas": "nålfiltmatta",
    "nålfiltmattors": "nålfiltmatta",
    "nålfiltmatts": "nålfiltmatta",
    "nålfiltsmatt": "nålfiltsmatta",
    "nålfiltsmattan": "nålfiltsmatta",
    "nålfiltsmattans": "nålfiltsmatta",
    "nålfiltsmattas": "nålfiltsmatta",
    "nålfiltsmatte": "nålfiltsmatta",
    "nålfiltsmattor": "nålfiltsmatta",
    "nålfiltsmattorna": "nålfiltsmatta",
    "nålfiltsmattornas": "nålfiltsmatta",
    "nålfiltsmattors": "nålfiltsmatta",
    "nålfiltsmatts": "nålfiltsmatta",
    "nålfina": "nålfin",
    "nålfinare": "nålfin",
    "nålfinares": "nålfin",
    "nålfinas": "nålfin",
    "nålfinast": "nålfin",
    "nålfinaste": "nålfin",
    "nålfinastes": "nålfin",
    "nålfinasts": "nålfin",
    "nålfine": "nålfin",
    "nålfines": "nålfin",
    "nålfins": "nålfin",
    "nålfint": "nålfin",
    "nålfints": "nålfin",
    "nålkorten": "nålkort",
    "nålkortens": "nålkort",
    "nålkortet": "nålkort",
    "nålkortets": "nålkort",
    "nålkorts": "nålkort",
    "nålmikrofonen": "nålmikrofon",
    "nålmikrofonens": "nålmikrofon",
    "nålmikrofoner": "nålmikrofon",
    "nålmikrofonerna": "nålmikrofon",
    "nålmikrofonernas": "nålmikrofon",
    "nålmikrofoners": "nålmikrofon",
    "nålmikrofons": "nålmikrofon",
    "nålpengar": "nålpeng",
    "nålpengarna": "nålpeng",
    "nålpengarnas": "nålpeng",
    "nålpengars": "nålpeng",
    "nålpengen": "nålpeng",
    "nålpengens": "nålpeng",
    "nålpengs": "nålpeng",
    "nåls": "nål",
    "nålspetsar": "nålspets",
    "nålspetsarna": "nålspets",
    "nålspetsarnas": "nålspets",
    "nålspetsars": "nålspets",
    "nålspetsen": "nålspets",
    "nålspetsens": "nålspets",
    "nålsticken": "nålstick",
    "nålstickens": "nålstick",
    "nålsticket": "nålstick",
    "nålstickets": "nålstick",
    "nålsticks": "nålstick",
    "nålsticksangreppen": "nålsticksangrepp",
    "nålsticksangreppens": "nålsticksangrepp",
    "nålsticksangreppet": "nålsticksangrepp",
    "nålsticksangreppets": "nålsticksangrepp",
    "nålsticksangrepps": "nålsticksangrepp",
    "nålstingen": "nålsting",
    "nålstingens": "nålsting",
    "nålstinget": "nålsting",
    "nålstingets": "nålsting",
    "nålstings": "nålsting",
    "nålstygnen": "nålstygn",
    "nålstygnens": "nålstygn",
    "nålstygnet": "nålstygn",
    "nålstygnets": "nålstygn",
    "nålstygns": "nålstygn",
    "nålstyngen": "nålstyng",
    "nålstyngens": "nålstyng",
    "nålstynget": "nålstyng",
    "nålstyngets": "nålstyng",
    "nålstyngs": "nålstyng",
    "nålsögas": "nålsöga",
    "nålsögat": "nålsöga",
    "nålsögats": "nålsöga",
    "nålsögon": "nålsöga",
    "nålsögonen": "nålsöga",
    "nålsögonens": "nålsöga",
    "nålsögons": "nålsöga",
    "nålventilen": "nålventil",
    "nålventilens": "nålventil",
    "nålventiler": "nålventil",
    "nålventilerna": "nålventil",
    "nålventilernas": "nålventil",
    "nålventilers": "nålventil",
    "nålventils": "nålventil",
    "nån": "någon",
    "nåns": "någon",
    "nåntings": "nånting",
    "når": "nå",
    "nås": "nå",
    "nåt": "någon",
    "nåtad": "nåta",
    "nåtade": "nåta",
    "nåtades": "nåta",
    "nåtads": "nåta",
    "nåtande": "nåta",
    "nåtanden": "nåtande",
    "nåtandena": "nåtande",
    "nåtandenas": "nåtande",
    "nåtandens": "nåtande",
    "nåtandes": "nåtande",
    "nåtandet": "nåtande",
    "nåtandets": "nåtande",
    "nåtar": "nåta",
    "nåtarna": "nåt",
    "nåtarnas": "nåt",
    "nåtars": "nåt",
    "nåtas": "nåta",
    "nåtat": "nåta",
    "nåtats": "nåta",
    "nåtel": "nåtla",
    "nåten": "nåt",
    "nåtens": "nåt",
    "nåtlad": "nåtla",
    "nåtlade": "nåtla",
    "nåtlades": "nåtla",
    "nåtlads": "nåtla",
    "nåtlande": "nåtla",
    "nåtlanden": "nåtlande",
    "nåtlandena": "nåtlande",
    "nåtlandenas": "nåtlande",
    "nåtlandens": "nåtlande",
    "nåtlandes": "nåtlande",
    "nåtlandet": "nåtlande",
    "nåtlandets": "nåtlande",
    "nåtlar": "nåtla",
    "nåtlas": "nåtla",
    "nåtlat": "nåtla",
    "nåtlats": "nåtla",
    "nåts": "nåt",
    "nåtstålen": "nåtstål",
    "nåtstålens": "nåtstål",
    "nåtstålet": "nåtstål",
    "nåtstålets": "nåtstål",
    "nåtståls": "nåtstål",
    "nått": "nå",
    "nåtts": "nå",
    "nödanropen": "nödanrop",
    "nödanropens": "nödanrop",
    "nödanropet": "nödanrop",
    "nödanropets": "nödanrop",
    "nödanrops": "nödanrop",
    "nödbedda": "nödbedd",
    "nödbeddare": "nödbedd",
    "nödbeddares": "nödbedd",
    "nödbeddas": "nödbedd",
    "nödbeddast": "nödbedd",
    "nödbeddaste": "nödbedd",
    "nödbeddastes": "nödbedd",
    "nödbeddasts": "nödbedd",
    "nödbedde": "nödbedd",
    "nödbeddes": "nödbedd",
    "nödbeddheten": "nödbeddhet",
    "nödbeddhetens": "nödbeddhet",
    "nödbeddhets": "nödbeddhet",
    "nödbedds": "nödbedd",
    "nödbett": "nödbedd",
    "nödbetts": "nödbedd",
    "nödbjudens": "nödbjuden",
    "nödbjudet": "nödbjuden",
    "nödbjudets": "nödbjuden",
    "nödbjudna": "nödbjuden",
    "nödbjudnare": "nödbjuden",
    "nödbjudnares": "nödbjuden",
    "nödbjudnas": "nödbjuden",
    "nödbjudnast": "nödbjuden",
    "nödbjudnaste": "nödbjuden",
    "nödbjudnastes": "nödbjuden",
    "nödbjudnasts": "nödbjuden",
    "nödbjudne": "nödbjuden",
    "nödbjudnes": "nödbjuden",
    "nödbromsad": "nödbromsa",
    "nödbromsade": "nödbromsa",
    "nödbromsades": "nödbromsa",
    "nödbromsads": "nödbromsa",
    "nödbromsande": "nödbromsa",
    "nödbromsanden": "nödbromsande",
    "nödbromsandena": "nödbromsande",
    "nödbromsandenas": "nödbromsande",
    "nödbromsandens": "nödbromsande",
    "nödbromsandes": "nödbromsande",
    "nödbromsandet": "nödbromsande",
    "nödbromsandets": "nödbromsande",
    "nödbromsar": "nödbromsa",
    "nödbromsarna": "nödbroms",
    "nödbromsarnas": "nödbroms",
    "nödbromsars": "nödbroms",
    "nödbromsas": "nödbromsa",
    "nödbromsat": "nödbromsa",
    "nödbromsats": "nödbromsa",
    "nödbromsen": "nödbroms",
    "nödbromsens": "nödbroms",
    "nödda": "nödd",
    "nöddare": "nödd",
    "nöddares": "nödd",
    "nöddas": "nödd",
    "nöddast": "nödd",
    "nöddaste": "nödd",
    "nöddastes": "nödd",
    "nöddasts": "nödd",
    "nödde": "nödd",
    "nöddes": "nödd",
    "nöddheten": "nöddhet",
    "nöddhetens": "nöddhet",
    "nöddhets": "nöddhet",
    "nöddopen": "nöddop",
    "nöddopens": "nöddop",
    "nöddopet": "nöddop",
    "nöddopets": "nöddop",
    "nöddops": "nöddop",
    "nödds": "nödd",
    "nöden": "nöd",
    "nödens": "nöd",
    "nödfallen": "nödfall",
    "nödfallens": "nödfall",
    "nödfallet": "nödfall",
    "nödfallets": "nödfall",
    "nödfalls": "nödfall",
    "nödflaggen": "nödflagg",
    "nödflaggens": "nödflagg",
    "nödflaggs": "nödflagg",
    "nödgad": "nödga",
    "nödgade": "nödga",
    "nödgades": "nödgas",
    "nödgads": "nödga",
    "nödgande": "nödga",
    "nödganden": "nödgande",
    "nödgandena": "nödgande",
    "nödgandenas": "nödgande",
    "nödgandens": "nödgande",
    "nödgandes": "nödgande",
    "nödgandet": "nödgande",
    "nödgandets": "nödgande",
    "nödgar": "nödga",
    "nödgas": "nödga",
    "nödgat": "nödga",
    "nödgats": "nödgas",
    "nödhamnar": "nödhamn",
    "nödhamnarna": "nödhamn",
    "nödhamnarnas": "nödhamn",
    "nödhamnars": "nödhamn",
    "nödhamnen": "nödhamn",
    "nödhamnens": "nödhamn",
    "nödhamns": "nödhamn",
    "nödhjälpen": "nödhjälp",
    "nödhjälpens": "nödhjälp",
    "nödhjälps": "nödhjälp",
    "nödiga": "nödig",
    "nödigare": "nödig",
    "nödigares": "nödig",
    "nödigas": "nödig",
    "nödigast": "nödig",
    "nödigaste": "nödig",
    "nödigastes": "nödig",
    "nödigasts": "nödig",
    "nödige": "nödig",
    "nödiges": "nödig",
    "nödigs": "nödig",
    "nödigt": "nödig",
    "nödigts": "nödig",
    "nödlandad": "nödlanda",
    "nödlandade": "nödlanda",
    "nödlandades": "nödlanda",
    "nödlandads": "nödlanda",
    "nödlandande": "nödlanda",
    "nödlandanden": "nödlandande",
    "nödlandandena": "nödlandande",
    "nödlandandenas": "nödlandande",
    "nödlandandens": "nödlandande",
    "nödlandandes": "nödlandande",
    "nödlandandet": "nödlandande",
    "nödlandandets": "nödlandande",
    "nödlandar": "nödlanda",
    "nödlandas": "nödlanda",
    "nödlandat": "nödlanda",
    "nödlandats": "nödlanda",
    "nödlandningar": "nödlandning",
    "nödlandningarna": "nödlandning",
    "nödlandningarnas": "nödlandning",
    "nödlandningars": "nödlandning",
    "nödlandningen": "nödlandning",
    "nödlandningens": "nödlandning",
    "nödlandnings": "nödlandning",
    "nödlägen": "nödläge",
    "nödlägena": "nödläge",
    "nödlägenas": "nödläge",
    "nödlägens": "nödläge",
    "nödläges": "nödläge",
    "nödläget": "nödläge",
    "nödlägets": "nödläge",
    "nödlögnen": "nödlögn",
    "nödlögnens": "nödlögn",
    "nödlögner": "nödlögn",
    "nödlögnerna": "nödlögn",
    "nödlögnernas": "nödlögn",
    "nödlögners": "nödlögn",
    "nödlögns": "nödlögn",
    "nödlösningar": "nödlösning",
    "nödlösningarna": "nödlösning",
    "nödlösningarnas": "nödlösning",
    "nödlösningars": "nödlösning",
    "nödlösningen": "nödlösning",
    "nödlösningens": "nödlösning",
    "nödlösnings": "nödlösning",
    "nödmynten": "nödmynt",
    "nödmyntens": "nödmynt",
    "nödmyntet": "nödmynt",
    "nödmyntets": "nödmynt",
    "nödmynts": "nödmynt",
    "nödprovianten": "nödproviant",
    "nödproviantens": "nödproviant",
    "nödproviants": "nödproviant",
    "nödraketen": "nödraket",
    "nödraketens": "nödraket",
    "nödraketer": "nödraket",
    "nödraketerna": "nödraket",
    "nödraketernas": "nödraket",
    "nödraketers": "nödraket",
    "nödrakets": "nödraket",
    "nödrimmen": "nödrim",
    "nödrimmens": "nödrim",
    "nödrimmet": "nödrim",
    "nödrimmets": "nödrim",
    "nödrims": "nödrim",
    "nödropen": "nödrop",
    "nödropens": "nödrop",
    "nödropet": "nödrop",
    "nödropets": "nödrop",
    "nödrops": "nödrop",
    "nödrätten": "nödrätt",
    "nödrättens": "nödrätt",
    "nödrätts": "nödrätt",
    "nöds": "nöd",
    "nödsakad": "nödsaka",
    "nödsakade": "nödsakad",
    "nödsakades": "nödsakas",
    "nödsakads": "nödsakad",
    "nödsakande": "nödsaka",
    "nödsakanden": "nödsakande",
    "nödsakandena": "nödsakande",
    "nödsakandenas": "nödsakande",
    "nödsakandens": "nödsakande",
    "nödsakandes": "nödsakande",
    "nödsakandet": "nödsakande",
    "nödsakandets": "nödsakande",
    "nödsakar": "nödsaka",
    "nödsakas": "nödsaka",
    "nödsakat": "nödsakad",
    "nödsakats": "nödsakas",
    "nödsignalen": "nödsignal",
    "nödsignalens": "nödsignal",
    "nödsignaler": "nödsignal",
    "nödsignalerade": "nödsignalera",
    "nödsignalerades": "nödsignalera",
    "nödsignalerande": "nödsignalera",
    "nödsignaleranden": "nödsignalerande",
    "nödsignalerandena": "nödsignalerande",
    "nödsignalerandenas": "nödsignalerande",
    "nödsignalerandens": "nödsignalerande",
    "nödsignalerandes": "nödsignalerande",
    "nödsignalerandet": "nödsignalerande",
    "nödsignalerandets": "nödsignalerande",
    "nödsignalerar": "nödsignalera",
    "nödsignaleras": "nödsignalera",
    "nödsignalerat": "nödsignalera",
    "nödsignalerats": "nödsignalera",
    "nödsignaleringar": "nödsignalering",
    "nödsignaleringarna": "nödsignalering",
    "nödsignaleringarnas": "nödsignalering",
    "nödsignaleringars": "nödsignalering",
    "nödsignaleringen": "nödsignalering",
    "nödsignaleringens": "nödsignalering",
    "nödsignalerings": "nödsignalering",
    "nödsignalerna": "nödsignal",
    "nödsignalernas": "nödsignal",
    "nödsignalers": "nödsignal",
    "nödsignals": "nödsignal",
    "nödsituationen": "nödsituation",
    "nödsituationens": "nödsituation",
    "nödsituationer": "nödsituation",
    "nödsituationerna": "nödsituation",
    "nödsituationernas": "nödsituation",
    "nödsituationers": "nödsituation",
    "nödsituations": "nödsituation",
    "nödsituationslamp": "nödsituationslampa",
    "nödsituationslampan": "nödsituationslampa",
    "nödsituationslampans": "nödsituationslampa",
    "nödsituationslampas": "nödsituationslampa",
    "nödsituationslampe": "nödsituationslampa",
    "nödsituationslampor": "nödsituationslampa",
    "nödsituationslamporna": "nödsituationslampa",
    "nödsituationslampornas": "nödsituationslampa",
    "nödsituationslampors": "nödsituationslampa",
    "nödsituationslamps": "nödsituationslampa",
    "nödslakten": "nödslakt",
    "nödslaktens": "nödslakt",
    "nödslakts": "nödslakt",
    "nödstoppad": "nödstoppa",
    "nödstoppade": "nödstoppa",
    "nödstoppades": "nödstoppa",
    "nödstoppads": "nödstoppa",
    "nödstoppande": "nödstoppa",
    "nödstoppanden": "nödstoppande",
    "nödstoppandena": "nödstoppande",
    "nödstoppandenas": "nödstoppande",
    "nödstoppandens": "nödstoppande",
    "nödstoppandes": "nödstoppande",
    "nödstoppandet": "nödstoppande",
    "nödstoppandets": "nödstoppande",
    "nödstoppar": "nödstoppa",
    "nödstoppas": "nödstoppa",
    "nödstoppat": "nödstoppa",
    "nödstoppats": "nödstoppa",
    "nödstoppen": "nödstopp",
    "nödstoppens": "nödstopp",
    "nödstoppet": "nödstopp",
    "nödstoppets": "nödstopp",
    "nödstopps": "nödstopp",
    "nödställda": "nödställd",
    "nödställdare": "nödställd",
    "nödställdares": "nödställd",
    "nödställdas": "nödställd",
    "nödställdast": "nödställd",
    "nödställdaste": "nödställd",
    "nödställdastes": "nödställd",
    "nödställdasts": "nödställd",
    "nödställde": "nödställd",
    "nödställdes": "nödställd",
    "nödställdheten": "nödställdhet",
    "nödställdhetens": "nödställdhet",
    "nödställdhets": "nödställdhet",
    "nödställds": "nödställd",
    "nödställt": "nödställd",
    "nödställts": "nödställd",
    "nödtorften": "nödtorft",
    "nödtorftens": "nödtorft",
    "nödtorftiga": "nödtorftig",
    "nödtorftigare": "nödtorftig",
    "nödtorftigares": "nödtorftig",
    "nödtorftigas": "nödtorftig",
    "nödtorftigast": "nödtorftig",
    "nödtorftigaste": "nödtorftig",
    "nödtorftigastes": "nödtorftig",
    "nödtorftigasts": "nödtorftig",
    "nödtorftige": "nödtorftig",
    "nödtorftiges": "nödtorftig",
    "nödtorftigheten": "nödtorftighet",
    "nödtorftighetens": "nödtorftighet",
    "nödtorftigheter": "nödtorftighet",
    "nödtorftigheterna": "nödtorftighet",
    "nödtorftigheternas": "nödtorftighet",
    "nödtorftigheters": "nödtorftighet",
    "nödtorftighets": "nödtorftighet",
    "nödtorftigs": "nödtorftig",
    "nödtorftigt": "nödtorftig",
    "nödtorftigts": "nödtorftig",
    "nödtorfts": "nödtorft",
    "nödtvungens": "nödtvungen",
    "nödtvunget": "nödtvungen",
    "nödtvungets": "nödtvungen",
    "nödtvungna": "nödtvungen",
    "nödtvungnare": "nödtvungen",
    "nödtvungnares": "nödtvungen",
    "nödtvungnas": "nödtvungen",
    "nödtvungnast": "nödtvungen",
    "nödtvungnaste": "nödtvungen",
    "nödtvungnastes": "nödtvungen",
    "nödtvungnasts": "nödtvungen",
    "nödtvungne": "nödtvungen",
    "nödtvungnes": "nödtvungen",
    "nödtvånget": "nödtvång",
    "nödtvångets": "nödtvång",
    "nödtvångs": "nödtvång",
    "nödutgångar": "nödutgång",
    "nödutgångarna": "nödutgång",
    "nödutgångarnas": "nödutgång",
    "nödutgångars": "nödutgång",
    "nödutgången": "nödutgång",
    "nödutgångens": "nödutgång",
    "nödutgångs": "nödutgång",
    "nödvuxens": "nödvuxen",
    "nödvuxet": "nödvuxen",
    "nödvuxets": "nödvuxen",
    "nödvuxna": "nödvuxen",
    "nödvuxnare": "nödvuxen",
    "nödvuxnares": "nödvuxen",
    "nödvuxnas": "nödvuxen",
    "nödvuxnast": "nödvuxen",
    "nödvuxnaste": "nödvuxen",
    "nödvuxnastes": "nödvuxen",
    "nödvuxnasts": "nödvuxen",
    "nödvuxne": "nödvuxen",
    "nödvuxnes": "nödvuxen",
    "nödvändiga": "nödvändig",
    "nödvändigare": "nödvändig",
    "nödvändigares": "nödvändig",
    "nödvändigas": "nödvändig",
    "nödvändigast": "nödvändig",
    "nödvändigaste": "nödvändig",
    "nödvändigastes": "nödvändig",
    "nödvändigasts": "nödvändig",
    "nödvändige": "nödvändig",
    "nödvändiges": "nödvändig",
    "nödvändigheten": "nödvändighet",
    "nödvändighetens": "nödvändighet",
    "nödvändigheter": "nödvändighet",
    "nödvändigheterna": "nödvändighet",
    "nödvändigheternas": "nödvändighet",
    "nödvändigheters": "nödvändighet",
    "nödvändighets": "nödvändighet",
    "nödvändighetsartikeln": "nödvändighetsartikel",
    "nödvändighetsartikelns": "nödvändighetsartikel",
    "nödvändighetsartikels": "nödvändighetsartikel",
    "nödvändighetsartiklar": "nödvändighetsartikel",
    "nödvändighetsartiklarna": "nödvändighetsartikel",
    "nödvändighetsartiklarnas": "nödvändighetsartikel",
    "nödvändighetsartiklars": "nödvändighetsartikel",
    "nödvändighetsvar": "nödvändighetsvara",
    "nödvändighetsvaran": "nödvändighetsvara",
    "nödvändighetsvarans": "nödvändighetsvara",
    "nödvändighetsvaras": "nödvändighetsvara",
    "nödvändighetsvare": "nödvändighetsvara",
    "nödvändighetsvaror": "nödvändighetsvara",
    "nödvändighetsvarorna": "nödvändighetsvara",
    "nödvändighetsvarornas": "nödvändighetsvara",
    "nödvändighetsvarors": "nödvändighetsvara",
    "nödvändighetsvars": "nödvändighetsvara",
    "nödvändigs": "nödvändig",
    "nödvändigt": "nödvändig",
    "nödvändigts": "nödvändig",
    "nödvärns": "nödvärn",
    "nödåren": "nödår",
    "nödårens": "nödår",
    "nödåret": "nödår",
    "nödårets": "nödår",
    "nödårs": "nödår",
    "nödöppnad": "nödöppna",
    "nödöppnade": "nödöppna",
    "nödöppnades": "nödöppna",
    "nödöppnads": "nödöppna",
    "nödöppnande": "nödöppna",
    "nödöppnanden": "nödöppnande",
    "nödöppnandena": "nödöppnande",
    "nödöppnandenas": "nödöppnande",
    "nödöppnandens": "nödöppnande",
    "nödöppnandes": "nödöppnande",
    "nödöppnandet": "nödöppnande",
    "nödöppnandets": "nödöppnande",
    "nödöppnar": "nödöppna",
    "nödöppnas": "nödöppna",
    "nödöppnat": "nödöppna",
    "nödöppnats": "nödöppna",
    "nöjaktiga": "nöjaktig",
    "nöjaktigare": "nöjaktig",
    "nöjaktigares": "nöjaktig",
    "nöjaktigas": "nöjaktig",
    "nöjaktigast": "nöjaktig",
    "nöjaktigaste": "nöjaktig",
    "nöjaktigastes": "nöjaktig",
    "nöjaktigasts": "nöjaktig",
    "nöjaktige": "nöjaktig",
    "nöjaktiges": "nöjaktig",
    "nöjaktigheten": "nöjaktighet",
    "nöjaktighetens": "nöjaktighet",
    "nöjaktighets": "nöjaktighet",
    "nöjaktigs": "nöjaktig",
    "nöjaktigt": "nöjaktig",
    "nöjaktigts": "nöjaktig",
    "nöjda": "nöjd",
    "nöjdare": "nöjd",
    "nöjdares": "nöjd",
    "nöjdas": "nöjd",
    "nöjdast": "nöjd",
    "nöjdaste": "nöjd",
    "nöjdastes": "nöjd",
    "nöjdasts": "nöjd",
    "nöjde": "nöjd",
    "nöjdes": "nöjd",
    "nöjdförklaringar": "nöjdförklaring",
    "nöjdförklaringarna": "nöjdförklaring",
    "nöjdförklaringarnas": "nöjdförklaring",
    "nöjdförklaringars": "nöjdförklaring",
    "nöjdförklaringen": "nöjdförklaring",
    "nöjdförklaringens": "nöjdförklaring",
    "nöjdförklarings": "nöjdförklaring",
    "nöjdheten": "nöjdhet",
    "nöjdhetens": "nöjdhet",
    "nöjdhets": "nöjdhet",
    "nöjds": "nöjd",
    "nöjen": "nöje",
    "nöjena": "nöje",
    "nöjenas": "nöje",
    "nöjens": "nöje",
    "nöjes": "nöje",
    "nöjesbegären": "nöjesbegär",
    "nöjesbegärens": "nöjesbegär",
    "nöjesbegäret": "nöjesbegär",
    "nöjesbegärets": "nöjesbegär",
    "nöjesbegärs": "nöjesbegär",
    "nöjesbranschen": "nöjesbransch",
    "nöjesbranschens": "nöjesbransch",
    "nöjesbranschs": "nöjesbransch",
    "nöjesbåtar": "nöjesbåt",
    "nöjesbåtarna": "nöjesbåt",
    "nöjesbåtarnas": "nöjesbåt",
    "nöjesbåtars": "nöjesbåt",
    "nöjesbåten": "nöjesbåt",
    "nöjesbåtens": "nöjesbåt",
    "nöjesbåts": "nöjesbåt",
    "nöjesdistrikten": "nöjesdistrikt",
    "nöjesdistriktens": "nöjesdistrikt",
    "nöjesdistriktet": "nöjesdistrikt",
    "nöjesdistriktets": "nöjesdistrikt",
    "nöjesdistrikts": "nöjesdistrikt",
    "nöjesetablissemangen": "nöjesetablissemang",
    "nöjesetablissemangens": "nöjesetablissemang",
    "nöjesetablissemanget": "nöjesetablissemang",
    "nöjesetablissemangets": "nöjesetablissemang",
    "nöjesetablissemangs": "nöjesetablissemang",
    "nöjesfiskar": "nöjesfiskare",
    "nöjesfiskaren": "nöjesfiskare",
    "nöjesfiskarens": "nöjesfiskare",
    "nöjesfiskares": "nöjesfiskare",
    "nöjesfiskarna": "nöjesfiskare",
    "nöjesfiskarnas": "nöjesfiskare",
    "nöjesfiskes": "nöjesfiske",
    "nöjesfisket": "nöjesfiske",
    "nöjesfiskets": "nöjesfiske",
    "nöjesfälten": "nöjesfält",
    "nöjesfältens": "nöjesfält",
    "nöjesfältet": "nöjesfält",
    "nöjesfältets": "nöjesfält",
    "nöjesfälts": "nöjesfält",
    "nöjeshallar": "nöjeshall",
    "nöjeshallarna": "nöjeshall",
    "nöjeshallarnas": "nöjeshall",
    "nöjeshallars": "nöjeshall",
    "nöjeshallen": "nöjeshall",
    "nöjeshallens": "nöjeshall",
    "nöjeshalls": "nöjeshall",
    "nöjeskörningar": "nöjeskörning",
    "nöjeskörningarna": "nöjeskörning",
    "nöjeskörningarnas": "nöjeskörning",
    "nöjeskörningars": "nöjeskörning",
    "nöjeskörningen": "nöjeskörning",
    "nöjeskörningens": "nöjeskörning",
    "nöjeskörnings": "nöjeskörning",
    "nöjeslivet": "nöjesliv",
    "nöjeslivets": "nöjesliv",
    "nöjeslivs": "nöjesliv",
    "nöjeslokalen": "nöjeslokal",
    "nöjeslokalens": "nöjeslokal",
    "nöjeslokaler": "nöjeslokal",
    "nöjeslokalerna": "nöjeslokal",
    "nöjeslokalernas": "nöjeslokal",
    "nöjeslokalers": "nöjeslokal",
    "nöjeslokals": "nöjeslokal",
    "nöjeslystens": "nöjeslysten",
    "nöjeslystet": "nöjeslysten",
    "nöjeslystets": "nöjeslysten",
    "nöjeslystna": "nöjeslysten",
    "nöjeslystnare": "nöjeslysten",
    "nöjeslystnares": "nöjeslysten",
    "nöjeslystnas": "nöjeslysten",
    "nöjeslystnast": "nöjeslysten",
    "nöjeslystnaste": "nöjeslysten",
    "nöjeslystnastes": "nöjeslysten",
    "nöjeslystnasts": "nöjeslysten",
    "nöjeslystne": "nöjeslysten",
    "nöjeslystnes": "nöjeslysten",
    "nöjesmaskinen": "nöjesmaskin",
    "nöjesmaskinens": "nöjesmaskin",
    "nöjesmaskiner": "nöjesmaskin",
    "nöjesmaskinerna": "nöjesmaskin",
    "nöjesmaskinernas": "nöjesmaskin",
    "nöjesmaskiners": "nöjesmaskin",
    "nöjesmaskins": "nöjesmaskin",
    "nöjespalatsen": "nöjespalats",
    "nöjespalatsens": "nöjespalats",
    "nöjespalatset": "nöjespalats",
    "nöjespalatsets": "nöjespalats",
    "nöjespappan": "nöjespappa",
    "nöjespappans": "nöjespappa",
    "nöjespappas": "nöjespappa",
    "nöjespappe": "nöjespappa",
    "nöjespappor": "nöjespappa",
    "nöjespapporna": "nöjespappa",
    "nöjespappornas": "nöjespappa",
    "nöjespappors": "nöjespappa",
    "nöjesparken": "nöjespark",
    "nöjesparkens": "nöjespark",
    "nöjesparker": "nöjespark",
    "nöjesparkerna": "nöjespark",
    "nöjesparkernas": "nöjespark",
    "nöjesparkers": "nöjespark",
    "nöjesparks": "nöjespark",
    "nöjesprogrammen": "nöjesprogram",
    "nöjesprogrammens": "nöjesprogram",
    "nöjesprogrammet": "nöjesprogram",
    "nöjesprogrammets": "nöjesprogram",
    "nöjesprograms": "nöjesprogram",
    "nöjesresan": "nöjesresa",
    "nöjesresans": "nöjesresa",
    "nöjesresas": "nöjesresa",
    "nöjesrese": "nöjesresa",
    "nöjesresor": "nöjesresa",
    "nöjesresorna": "nöjesresa",
    "nöjesresornas": "nöjesresa",
    "nöjesresors": "nöjesresa",
    "nöjesturen": "nöjestur",
    "nöjesturens": "nöjestur",
    "nöjesturer": "nöjestur",
    "nöjesturerna": "nöjestur",
    "nöjesturernas": "nöjestur",
    "nöjesturers": "nöjestur",
    "nöjesturs": "nöjestur",
    "nöjet": "nöje",
    "nöjets": "nöje",
    "nöjs": "nöjas",
    "nöjsamheten": "nöjsamhet",
    "nöjsamhetens": "nöjsamhet",
    "nöjsamhets": "nöjsamhet",
    "nöjsamma": "nöjsam",
    "nöjsammare": "nöjsam",
    "nöjsammares": "nöjsam",
    "nöjsammas": "nöjsam",
    "nöjsammast": "nöjsam",
    "nöjsammaste": "nöjsam",
    "nöjsammastes": "nöjsam",
    "nöjsammasts": "nöjsam",
    "nöjsamme": "nöjsam",
    "nöjsammes": "nöjsam",
    "nöjsams": "nöjsam",
    "nöjsamt": "nöjsam",
    "nöjsamts": "nöjsam",
    "nöjt": "nöjd",
    "nöjts": "nöjd",
    "nöp": "nypa",
    "nöpe": "nypa",
    "nöpes": "nypa",
    "nöps": "nypa",
    "nördar": "nörd",
    "nördarna": "nörd",
    "nördarnas": "nörd",
    "nördars": "nörd",
    "nörden": "nörd",
    "nördens": "nörd",
    "nörderier": "nörderi",
    "nörderierna": "nörderi",
    "nörderiernas": "nörderi",
    "nörderiers": "nörderi",
    "nörderiet": "nörderi",
    "nörderiets": "nörderi",
    "nörderis": "nörderi",
    "nörderit": "nörderi",
    "nörderits": "nörderi",
    "nördiga": "nördig",
    "nördigare": "nördig",
    "nördigares": "nördig",
    "nördigas": "nördig",
    "nördigast": "nördig",
    "nördigaste": "nördig",
    "nördigastes": "nördig",
    "nördigasts": "nördig",
    "nördige": "nördig",
    "nördiges": "nördig",
    "nördigheten": "nördighet",
    "nördighetens": "nördighet",
    "nördighets": "nördighet",
    "nördigs": "nördig",
    "nördigt": "nördig",
    "nördigts": "nördig",
    "nörds": "nörd",
    "nös": "nysa",
    "nöse": "nysa",
    "nöses": "nysa",
    "nöt": "nöta",
    "nötande": "nöta",
    "nötanden": "nötande",
    "nötandena": "nötande",
    "nötandenas": "nötande",
    "nötandens": "nötande",
    "nötandes": "nötande",
    "nötandet": "nötande",
    "nötandets": "nötande",
    "nötas": "nöta",
    "nötbarheten": "nötbarhet",
    "nötbarhetens": "nötbarhet",
    "nötbarheter": "nötbarhet",
    "nötbarheterna": "nötbarhet",
    "nötbarheternas": "nötbarhet",
    "nötbarheters": "nötbarhet",
    "nötbarhets": "nötbarhet",
    "nötboskapen": "nötboskap",
    "nötboskapens": "nötboskap",
    "nötboskaps": "nötboskap",
    "nötbruna": "nötbrun",
    "nötbrunare": "nötbrun",
    "nötbrunares": "nötbrun",
    "nötbrunas": "nötbrun",
    "nötbrunast": "nötbrun",
    "nötbrunaste": "nötbrun",
    "nötbrunastes": "nötbrun",
    "nötbrunasts": "nötbrun",
    "nötbrune": "nötbrun",
    "nötbrunes": "nötbrun",
    "nötbruns": "nötbrun",
    "nötbrunt": "nötbrun",
    "nötbrunts": "nötbrun",
    "nötchokladen": "nötchoklad",
    "nötchokladens": "nötchoklad",
    "nötchoklads": "nötchoklad",
    "nöten": "nöt",
    "nötens": "nöt",
    "nöter": "nöta",
    "nötes": "nöta",
    "nötet": "nöt",
    "nötets": "nöt",
    "nötfnaset": "nötfnas",
    "nötfnasets": "nötfnas",
    "nötfrukten": "nötfrukt",
    "nötfruktens": "nötfrukt",
    "nötfrukter": "nötfrukt",
    "nötfrukterna": "nötfrukt",
    "nötfrukternas": "nötfrukt",
    "nötfrukters": "nötfrukt",
    "nötfrukts": "nötfrukt",
    "nöthåret": "nöthår",
    "nöthårets": "nöthår",
    "nöthårs": "nöthår",
    "nötknäckar": "nötknäckare",
    "nötknäckaren": "nötknäckare",
    "nötknäckarens": "nötknäckare",
    "nötknäckares": "nötknäckare",
    "nötknäckarna": "nötknäckare",
    "nötknäckarnas": "nötknäckare",
    "nötknäppar": "nötknäppare",
    "nötknäpparansikten": "nötknäpparansikte",
    "nötknäpparansiktena": "nötknäpparansikte",
    "nötknäpparansiktenas": "nötknäpparansikte",
    "nötknäpparansiktens": "nötknäpparansikte",
    "nötknäpparansiktes": "nötknäpparansikte",
    "nötknäpparansiktet": "nötknäpparansikte",
    "nötknäpparansiktets": "nötknäpparansikte",
    "nötknäpparansikts": "nötknäpparansikte",
    "nötknäpparen": "nötknäppare",
    "nötknäpparens": "nötknäppare",
    "nötknäppares": "nötknäppare",
    "nötknäpparna": "nötknäppare",
    "nötknäpparnas": "nötknäppare",
    "nötkreaturen": "nötkreatur",
    "nötkreaturens": "nötkreatur",
    "nötkreaturet": "nötkreatur",
    "nötkreaturets": "nötkreatur",
    "nötkreaturs": "nötkreatur",
    "nötkreatursdriften": "nötkreatursdrift",
    "nötkreatursdriftens": "nötkreatursdrift",
    "nötkreatursdrifts": "nötkreatursdrift",
    "nötkråk": "nötkråka",
    "nötkråkan": "nötkråka",
    "nötkråkans": "nötkråka",
    "nötkråkas": "nötkråka",
    "nötkråke": "nötkråka",
    "nötkråkor": "nötkråka",
    "nötkråkorna": "nötkråka",
    "nötkråkornas": "nötkråka",
    "nötkråkors": "nötkråka",
    "nötkråks": "nötkråka",
    "nötkärn": "nötkärna",
    "nötkärnan": "nötkärna",
    "nötkärnans": "nötkärna",
    "nötkärnas": "nötkärna",
    "nötkärne": "nötkärna",
    "nötkärnor": "nötkärna",
    "nötkärnorna": "nötkärna",
    "nötkärnornas": "nötkärna",
    "nötkärnors": "nötkärna",
    "nötkärns": "nötkärna",
    "nötköttet": "nötkött",
    "nötköttets": "nötkött",
    "nötkötts": "nötkött",
    "nötmassan": "nötmassa",
    "nötmassans": "nötmassa",
    "nötmassas": "nötmassa",
    "nötmasse": "nötmassa",
    "nötmassor": "nötmassa",
    "nötmassorna": "nötmassa",
    "nötmassornas": "nötmassa",
    "nötmassors": "nötmassa",
    "nötningar": "nötning",
    "nötningarna": "nötning",
    "nötningarnas": "nötning",
    "nötningars": "nötning",
    "nötningen": "nötning",
    "nötningens": "nötning",
    "nötnings": "nötning",
    "nötningsbeständiga": "nötningsbeständig",
    "nötningsbeständigare": "nötningsbeständig",
    "nötningsbeständigares": "nötningsbeständig",
    "nötningsbeständigas": "nötningsbeständig",
    "nötningsbeständigast": "nötningsbeständig",
    "nötningsbeständigaste": "nötningsbeständig",
    "nötningsbeständigastes": "nötningsbeständig",
    "nötningsbeständigasts": "nötningsbeständig",
    "nötningsbeständige": "nötningsbeständig",
    "nötningsbeständiges": "nötningsbeständig",
    "nötningsbeständigheten": "nötningsbeständighet",
    "nötningsbeständighetens": "nötningsbeständighet",
    "nötningsbeständighets": "nötningsbeständighet",
    "nötningsbeständigs": "nötningsbeständig",
    "nötningsbeständigt": "nötningsbeständig",
    "nötningsbeständigts": "nötningsbeständig",
    "nötningsresistansen": "nötningsresistans",
    "nötningsresistansens": "nötningsresistans",
    "nötningsresistenta": "nötningsresistent",
    "nötningsresistentare": "nötningsresistent",
    "nötningsresistentares": "nötningsresistent",
    "nötningsresistentas": "nötningsresistent",
    "nötningsresistentast": "nötningsresistent",
    "nötningsresistentaste": "nötningsresistent",
    "nötningsresistentastes": "nötningsresistent",
    "nötningsresistentasts": "nötningsresistent",
    "nötningsresistente": "nötningsresistent",
    "nötningsresistentes": "nötningsresistent",
    "nötningsresistents": "nötningsresistent",
    "nötningsresistentt": "nötningsresistent",
    "nötningsresistentts": "nötningsresistent",
    "nötoljan": "nötolja",
    "nötoljans": "nötolja",
    "nötoljas": "nötolja",
    "nötolje": "nötolja",
    "nöts": "nöta",
    "nötskalen": "nötskal",
    "nötskalens": "nötskal",
    "nötskalet": "nötskal",
    "nötskalets": "nötskal",
    "nötskals": "nötskal",
    "nötskrik": "nötskrika",
    "nötskrikan": "nötskrika",
    "nötskrikans": "nötskrika",
    "nötskrikas": "nötskrika",
    "nötskrike": "nötskrika",
    "nötskrikor": "nötskrika",
    "nötskrikorna": "nötskrika",
    "nötskrikornas": "nötskrika",
    "nötskrikors": "nötskrika",
    "nötskriks": "nötskrika",
    "nötstyngen": "nötstyng",
    "nötstyngens": "nötstyng",
    "nötstynget": "nötstyng",
    "nötstyngets": "nötstyng",
    "nötstyngs": "nötstyng",
    "nött": "nöta",
    "nötta": "nöta",
    "nöttas": "nöta",
    "nötte": "nöta",
    "nötter": "nöt",
    "nötterna": "nöt",
    "nötternas": "nöt",
    "nötters": "nöt",
    "nöttes": "nöta",
    "nötts": "nöta",
    "nötviveln": "nötvivel",
    "nötvivelns": "nötvivel",
    "nötvivels": "nötvivel",
    "nötvivlar": "nötvivel",
    "nötvivlarna": "nötvivel",
    "nötvivlarnas": "nötvivel",
    "nötvivlars": "nötvivel",
    "nötväck": "nötväcka",
    "nötväckan": "nötväcka",
    "nötväckans": "nötväcka",
    "nötväckas": "nötväcka",
    "nötväcke": "nötväcka",
    "nötväckor": "nötväcka",
    "nötväckorna": "nötväcka",
    "nötväckornas": "nötväcka",
    "nötväckors": "nötväcka",
    "nötväcks": "nötväcka",
    "o-en": "o",
    "o-ens": "o",
    "o-et": "o",
    "o-ets": "o",
    "o-n": "o",
    "o-na": "o",
    "o-nas": "o",
    "o-ns": "o",
    "o-t": "o",
    "o-ts": "o",
    "o:en": "o",
    "o:ens": "o",
    "o:et": "o",
    "o:ets": "o",
    "o:n": "o",
    "o:na": "o",
    "o:nas": "o",
    "o:ns": "o",
    "o:s": "o",
    "o:t": "o",
    "o:ts": "o",
    "oabbrevierade": "oabbrevierad",
    "oabbrevierades": "oabbrevierad",
    "oabbrevierads": "oabbrevierad",
    "oabbrevierat": "oabbrevierad",
    "oabbrevierats": "oabbrevierad",
    "oabbrevierbara": "oabbrevierbar",
    "oabbrevierbarare": "oabbrevierbar",
    "oabbrevierbarares": "oabbrevierbar",
    "oabbrevierbaras": "oabbrevierbar",
    "oabbrevierbarast": "oabbrevierbar",
    "oabbrevierbaraste": "oabbrevierbar",
    "oabbrevierbarastes": "oabbrevierbar",
    "oabbrevierbarasts": "oabbrevierbar",
    "oabbrevierbare": "oabbrevierbar",
    "oabbrevierbares": "oabbrevierbar",
    "oabbrevierbarheten": "oabbrevierbarhet",
    "oabbrevierbarhetens": "oabbrevierbarhet",
    "oabbrevierbarhets": "oabbrevierbarhet",
    "oabbrevierbars": "oabbrevierbar",
    "oabbrevierbart": "oabbrevierbar",
    "oabbrevierbarts": "oabbrevierbar",
    "oabdikerade": "oabdikerad",
    "oabdikerades": "oabdikerad",
    "oabdikerads": "oabdikerad",
    "oabdikerat": "oabdikerad",
    "oabdikerats": "oabdikerad",
    "oabdikerbara": "oabdikerbar",
    "oabdikerbarare": "oabdikerbar",
    "oabdikerbarares": "oabdikerbar",
    "oabdikerbaras": "oabdikerbar",
    "oabdikerbarast": "oabdikerbar",
    "oabdikerbaraste": "oabdikerbar",
    "oabdikerbarastes": "oabdikerbar",
    "oabdikerbarasts": "oabdikerbar",
    "oabdikerbare": "oabdikerbar",
    "oabdikerbares": "oabdikerbar",
    "oabdikerbarheten": "oabdikerbarhet",
    "oabdikerbarhetens": "oabdikerbarhet",
    "oabdikerbarhets": "oabdikerbarhet",
    "oabdikerbars": "oabdikerbar",
    "oabdikerbart": "oabdikerbar",
    "oabdikerbarts": "oabdikerbar",
    "oabonnerade": "oabonnerad",
    "oabonnerades": "oabonnerad",
    "oabonnerads": "oabonnerad",
    "oabonnerat": "oabonnerad",
    "oabonnerats": "oabonnerad",
    "oabonnerbara": "oabonnerbar",
    "oabonnerbarare": "oabonnerbar",
    "oabonnerbarares": "oabonnerbar",
    "oabonnerbaras": "oabonnerbar",
    "oabonnerbarast": "oabonnerbar",
    "oabonnerbaraste": "oabonnerbar",
    "oabonnerbarastes": "oabonnerbar",
    "oabonnerbarasts": "oabonnerbar",
    "oabonnerbare": "oabonnerbar",
    "oabonnerbares": "oabonnerbar",
    "oabonnerbarheten": "oabonnerbarhet",
    "oabonnerbarhetens": "oabonnerbarhet",
    "oabonnerbarhets": "oabonnerbarhet",
    "oabonnerbars": "oabonnerbar",
    "oabonnerbart": "oabonnerbar",
    "oabonnerbarts": "oabonnerbar",
    "oaborterade": "oaborterad",
    "oaborterades": "oaborterad",
    "oaborterads": "oaborterad",
    "oaborterat": "oaborterad",
    "oaborterats": "oaborterad",
    "oaborterbara": "oaborterbar",
    "oaborterbarare": "oaborterbar",
    "oaborterbarares": "oaborterbar",
    "oaborterbaras": "oaborterbar",
    "oaborterbarast": "oaborterbar",
    "oaborterbaraste": "oaborterbar",
    "oaborterbarastes": "oaborterbar",
    "oaborterbarasts": "oaborterbar",
    "oaborterbare": "oaborterbar",
    "oaborterbares": "oaborterbar",
    "oaborterbarheten": "oaborterbarhet",
    "oaborterbarhetens": "oaborterbarhet",
    "oaborterbarhets": "oaborterbarhet",
    "oaborterbars": "oaborterbar",
    "oaborterbart": "oaborterbar",
    "oaborterbarts": "oaborterbar",
    "oabraderade": "oabraderad",
    "oabraderades": "oabraderad",
    "oabraderads": "oabraderad",
    "oabraderat": "oabraderad",
    "oabraderats": "oabraderad",
    "oabraderbara": "oabraderbar",
    "oabraderbarare": "oabraderbar",
    "oabraderbarares": "oabraderbar",
    "oabraderbaras": "oabraderbar",
    "oabraderbarast": "oabraderbar",
    "oabraderbaraste": "oabraderbar",
    "oabraderbarastes": "oabraderbar",
    "oabraderbarasts": "oabraderbar",
    "oabraderbare": "oabraderbar",
    "oabraderbares": "oabraderbar",
    "oabraderbarheten": "oabraderbarhet",
    "oabraderbarhetens": "oabraderbarhet",
    "oabraderbarhets": "oabraderbarhet",
    "oabraderbars": "oabraderbar",
    "oabraderbart": "oabraderbar",
    "oabraderbarts": "oabraderbar",
    "oabsolverade": "oabsolverad",
    "oabsolverades": "oabsolverad",
    "oabsolverads": "oabsolverad",
    "oabsolverat": "oabsolverad",
    "oabsolverats": "oabsolverad",
    "oabsolverbara": "oabsolverbar",
    "oabsolverbarare": "oabsolverbar",
    "oabsolverbarares": "oabsolverbar",
    "oabsolverbaras": "oabsolverbar",
    "oabsolverbarast": "oabsolverbar",
    "oabsolverbaraste": "oabsolverbar",
    "oabsolverbarastes": "oabsolverbar",
    "oabsolverbarasts": "oabsolverbar",
    "oabsolverbare": "oabsolverbar",
    "oabsolverbares": "oabsolverbar",
    "oabsolverbarheten": "oabsolverbarhet",
    "oabsolverbarhetens": "oabsolverbarhet",
    "oabsolverbarhets": "oabsolverbarhet",
    "oabsolverbars": "oabsolverbar",
    "oabsolverbart": "oabsolverbar",
    "oabsolverbarts": "oabsolverbar",
    "oabsorberade": "oabsorberad",
    "oabsorberades": "oabsorberad",
    "oabsorberads": "oabsorberad",
    "oabsorberat": "oabsorberad",
    "oabsorberats": "oabsorberad",
    "oabsorberbara": "oabsorberbar",
    "oabsorberbarare": "oabsorberbar",
    "oabsorberbarares": "oabsorberbar",
    "oabsorberbaras": "oabsorberbar",
    "oabsorberbarast": "oabsorberbar",
    "oabsorberbaraste": "oabsorberbar",
    "oabsorberbarastes": "oabsorberbar",
    "oabsorberbarasts": "oabsorberbar",
    "oabsorberbare": "oabsorberbar",
    "oabsorberbares": "oabsorberbar",
    "oabsorberbarheten": "oabsorberbarhet",
    "oabsorberbarhetens": "oabsorberbarhet",
    "oabsorberbarhets": "oabsorberbarhet",
    "oabsorberbars": "oabsorberbar",
    "oabsorberbart": "oabsorberbar",
    "oabsorberbarts": "oabsorberbar",
    "oabstraherade": "oabstraherad",
    "oabstraherades": "oabstraherad",
    "oabstraherads": "oabstraherad",
    "oabstraherat": "oabstraherad",
    "oabstraherats": "oabstraherad",
    "oabstraherbara": "oabstraherbar",
    "oabstraherbarare": "oabstraherbar",
    "oabstraherbarares": "oabstraherbar",
    "oabstraherbaras": "oabstraherbar",
    "oabstraherbarast": "oabstraherbar",
    "oabstraherbaraste": "oabstraherbar",
    "oabstraherbarastes": "oabstraherbar",
    "oabstraherbarasts": "oabstraherbar",
    "oabstraherbare": "oabstraherbar",
    "oabstraherbares": "oabstraherbar",
    "oabstraherbarheten": "oabstraherbarhet",
    "oabstraherbarhetens": "oabstraherbarhet",
    "oabstraherbarhets": "oabstraherbarhet",
    "oabstraherbars": "oabstraherbar",
    "oabstraherbart": "oabstraherbar",
    "oabstraherbarts": "oabstraherbar",
    "oaccederade": "oaccederad",
    "oaccederades": "oaccederad",
    "oaccederads": "oaccederad",
    "oaccederat": "oaccederad",
    "oaccederats": "oaccederad",
    "oaccederbara": "oaccederbar",
    "oaccederbarare": "oaccederbar",
    "oaccederbarares": "oaccederbar",
    "oaccederbaras": "oaccederbar",
    "oaccederbarast": "oaccederbar",
    "oaccederbaraste": "oaccederbar",
    "oaccederbarastes": "oaccederbar",
    "oaccederbarasts": "oaccederbar",
    "oaccederbare": "oaccederbar",
    "oaccederbares": "oaccederbar",
    "oaccederbarheten": "oaccederbarhet",
    "oaccederbarhetens": "oaccederbarhet",
    "oaccederbarhets": "oaccederbarhet",
    "oaccederbars": "oaccederbar",
    "oaccederbart": "oaccederbar",
    "oaccederbarts": "oaccederbar",
    "oaccelererade": "oaccelererad",
    "oaccelererades": "oaccelererad",
    "oaccelererads": "oaccelererad",
    "oaccelererat": "oaccelererad",
    "oaccelererats": "oaccelererad",
    "oaccelererbara": "oaccelererbar",
    "oaccelererbarare": "oaccelererbar",
    "oaccelererbarares": "oaccelererbar",
    "oaccelererbaras": "oaccelererbar",
    "oaccelererbarast": "oaccelererbar",
    "oaccelererbaraste": "oaccelererbar",
    "oaccelererbarastes": "oaccelererbar",
    "oaccelererbarasts": "oaccelererbar",
    "oaccelererbare": "oaccelererbar",
    "oaccelererbares": "oaccelererbar",
    "oaccelererbarheten": "oaccelererbarhet",
    "oaccelererbarhetens": "oaccelererbarhet",
    "oaccelererbarhets": "oaccelererbarhet",
    "oaccelererbars": "oaccelererbar",
    "oaccelererbart": "oaccelererbar",
    "oaccelererbarts": "oaccelererbar",
    "oaccentuerade": "oaccentuerad",
    "oaccentuerades": "oaccentuerad",
    "oaccentuerads": "oaccentuerad",
    "oaccentuerat": "oaccentuerad",
    "oaccentuerats": "oaccentuerad",
    "oaccentuerbara": "oaccentuerbar",
    "oaccentuerbarare": "oaccentuerbar",
    "oaccentuerbarares": "oaccentuerbar",
    "oaccentuerbaras": "oaccentuerbar",
    "oaccentuerbarast": "oaccentuerbar",
    "oaccentuerbaraste": "oaccentuerbar",
    "oaccentuerbarastes": "oaccentuerbar",
    "oaccentuerbarasts": "oaccentuerbar",
    "oaccentuerbare": "oaccentuerbar",
    "oaccentuerbares": "oaccentuerbar",
    "oaccentuerbarheten": "oaccentuerbarhet",
    "oaccentuerbarhetens": "oaccentuerbarhet",
    "oaccentuerbarhets": "oaccentuerbarhet",
    "oaccentuerbars": "oaccentuerbar",
    "oaccentuerbart": "oaccentuerbar",
    "oaccentuerbarts": "oaccentuerbar",
    "oacceptabels": "oacceptabel",
    "oacceptabelt": "oacceptabel",
    "oacceptabelts": "oacceptabel",
    "oacceptabla": "oacceptabel",
    "oacceptablare": "oacceptabel",
    "oacceptablares": "oacceptabel",
    "oacceptablas": "oacceptabel",
    "oacceptablast": "oacceptabel",
    "oacceptablaste": "oacceptabel",
    "oacceptablastes": "oacceptabel",
    "oacceptablasts": "oacceptabel",
    "oacceptable": "oacceptabel",
    "oacceptables": "oacceptabel",
    "oaccepterade": "oaccepterad",
    "oaccepterades": "oaccepterad",
    "oaccepterads": "oaccepterad",
    "oaccepterat": "oaccepterad",
    "oaccepterats": "oaccepterad",
    "oaccepterbara": "oaccepterbar",
    "oaccepterbarare": "oaccepterbar",
    "oaccepterbarares": "oaccepterbar",
    "oaccepterbaras": "oaccepterbar",
    "oaccepterbarast": "oaccepterbar",
    "oaccepterbaraste": "oaccepterbar",
    "oaccepterbarastes": "oaccepterbar",
    "oaccepterbarasts": "oaccepterbar",
    "oaccepterbare": "oaccepterbar",
    "oaccepterbares": "oaccepterbar",
    "oaccepterbarheten": "oaccepterbarhet",
    "oaccepterbarhetens": "oaccepterbarhet",
    "oaccepterbarhets": "oaccepterbarhet",
    "oaccepterbars": "oaccepterbar",
    "oaccepterbart": "oaccepterbar",
    "oaccepterbarts": "oaccepterbar",
    "oacklimatiserade": "oacklimatiserad",
    "oacklimatiserades": "oacklimatiserad",
    "oacklimatiserads": "oacklimatiserad",
    "oacklimatiserat": "oacklimatiserad",
    "oacklimatiserats": "oacklimatiserad",
    "oacklimatiserbara": "oacklimatiserbar",
    "oacklimatiserbarare": "oacklimatiserbar",
    "oacklimatiserbarares": "oacklimatiserbar",
    "oacklimatiserbaras": "oacklimatiserbar",
    "oacklimatiserbarast": "oacklimatiserbar",
    "oacklimatiserbaraste": "oacklimatiserbar",
    "oacklimatiserbarastes": "oacklimatiserbar",
    "oacklimatiserbarasts": "oacklimatiserbar",
    "oacklimatiserbare": "oacklimatiserbar",
    "oacklimatiserbares": "oacklimatiserbar",
    "oacklimatiserbarheten": "oacklimatiserbarhet",
    "oacklimatiserbarhetens": "oacklimatiserbarhet",
    "oacklimatiserbarhets": "oacklimatiserbarhet",
    "oacklimatiserbars": "oacklimatiserbar",
    "oacklimatiserbart": "oacklimatiserbar",
    "oacklimatiserbarts": "oacklimatiserbar",
    "oackommoderade": "oackommoderad",
    "oackommoderades": "oackommoderad",
    "oackommoderads": "oackommoderad",
    "oackommoderat": "oackommoderad",
    "oackommoderats": "oackommoderad",
    "oackommoderbara": "oackommoderbar",
    "oackommoderbarare": "oackommoderbar",
    "oackommoderbarares": "oackommoderbar",
    "oackommoderbaras": "oackommoderbar",
    "oackommoderbarast": "oackommoderbar",
    "oackommoderbaraste": "oackommoderbar",
    "oackommoderbarastes": "oackommoderbar",
    "oackommoderbarasts": "oackommoderbar",
    "oackommoderbare": "oackommoderbar",
    "oackommoderbares": "oackommoderbar",
    "oackommoderbarheten": "oackommoderbarhet",
    "oackommoderbarhetens": "oackommoderbarhet",
    "oackommoderbarhets": "oackommoderbarhet",
    "oackommoderbars": "oackommoderbar",
    "oackommoderbart": "oackommoderbar",
    "oackommoderbarts": "oackommoderbar",
    "oackompanjerade": "oackompanjerad",
    "oackompanjerades": "oackompanjerad",
    "oackompanjerads": "oackompanjerad",
    "oackompanjerat": "oackompanjerad",
    "oackompanjerats": "oackompanjerad",
    "oackompanjerbara": "oackompanjerbar",
    "oackompanjerbarare": "oackompanjerbar",
    "oackompanjerbarares": "oackompanjerbar",
    "oackompanjerbaras": "oackompanjerbar",
    "oackompanjerbarast": "oackompanjerbar",
    "oackompanjerbaraste": "oackompanjerbar",
    "oackompanjerbarastes": "oackompanjerbar",
    "oackompanjerbarasts": "oackompanjerbar",
    "oackompanjerbare": "oackompanjerbar",
    "oackompanjerbares": "oackompanjerbar",
    "oackompanjerbarheten": "oackompanjerbarhet",
    "oackompanjerbarhetens": "oackompanjerbarhet",
    "oackompanjerbarhets": "oackompanjerbarhet",
    "oackompanjerbars": "oackompanjerbar",
    "oackompanjerbart": "oackompanjerbar",
    "oackompanjerbarts": "oackompanjerbar",
    "oackorderade": "oackorderad",
    "oackorderades": "oackorderad",
    "oackorderads": "oackorderad",
    "oackorderat": "oackorderad",
    "oackorderats": "oackorderad",
    "oackorderbara": "oackorderbar",
    "oackorderbarare": "oackorderbar",
    "oackorderbarares": "oackorderbar",
    "oackorderbaras": "oackorderbar",
    "oackorderbarast": "oackorderbar",
    "oackorderbaraste": "oackorderbar",
    "oackorderbarastes": "oackorderbar",
    "oackorderbarasts": "oackorderbar",
    "oackorderbare": "oackorderbar",
    "oackorderbares": "oackorderbar",
    "oackorderbarheten": "oackorderbarhet",
    "oackorderbarhetens": "oackorderbarhet",
    "oackorderbarhets": "oackorderbarhet",
    "oackorderbars": "oackorderbar",
    "oackorderbart": "oackorderbar",
    "oackorderbarts": "oackorderbar",
    "oackrediterade": "oackrediterad",
    "oackrediterades": "oackrediterad",
    "oackrediterads": "oackrediterad",
    "oackrediterat": "oackrediterad",
    "oackrediterats": "oackrediterad",
    "oackrediterbara": "oackrediterbar",
    "oackrediterbarare": "oackrediterbar",
    "oackrediterbarares": "oackrediterbar",
    "oackrediterbaras": "oackrediterbar",
    "oackrediterbarast": "oackrediterbar",
    "oackrediterbaraste": "oackrediterbar",
    "oackrediterbarastes": "oackrediterbar",
    "oackrediterbarasts": "oackrediterbar",
    "oackrediterbare": "oackrediterbar",
    "oackrediterbares": "oackrediterbar",
    "oackrediterbarheten": "oackrediterbarhet",
    "oackrediterbarhetens": "oackrediterbarhet",
    "oackrediterbarhets": "oackrediterbarhet",
    "oackrediterbars": "oackrediterbar",
    "oackrediterbart": "oackrediterbar",
    "oackrediterbarts": "oackrediterbar",
    "oackumulerade": "oackumulerad",
    "oackumulerades": "oackumulerad",
    "oackumulerads": "oackumulerad",
    "oackumulerat": "oackumulerad",
    "oackumulerats": "oackumulerad",
    "oackumulerbara": "oackumulerbar",
    "oackumulerbarare": "oackumulerbar",
    "oackumulerbarares": "oackumulerbar",
    "oackumulerbaras": "oackumulerbar",
    "oackumulerbarast": "oackumulerbar",
    "oackumulerbaraste": "oackumulerbar",
    "oackumulerbarastes": "oackumulerbar",
    "oackumulerbarasts": "oackumulerbar",
    "oackumulerbare": "oackumulerbar",
    "oackumulerbares": "oackumulerbar",
    "oackumulerbarheten": "oackumulerbarhet",
    "oackumulerbarhetens": "oackumulerbarhet",
    "oackumulerbarhets": "oackumulerbarhet",
    "oackumulerbars": "oackumulerbar",
    "oackumulerbart": "oackumulerbar",
    "oackumulerbarts": "oackumulerbar",
    "oackvirerade": "oackvirerad",
    "oackvirerades": "oackvirerad",
    "oackvirerads": "oackvirerad",
    "oackvirerat": "oackvirerad",
    "oackvirerats": "oackvirerad",
    "oackvirerbara": "oackvirerbar",
    "oackvirerbarare": "oackvirerbar",
    "oackvirerbarares": "oackvirerbar",
    "oackvirerbaras": "oackvirerbar",
    "oackvirerbarast": "oackvirerbar",
    "oackvirerbaraste": "oackvirerbar",
    "oackvirerbarastes": "oackvirerbar",
    "oackvirerbarasts": "oackvirerbar",
    "oackvirerbare": "oackvirerbar",
    "oackvirerbares": "oackvirerbar",
    "oackvirerbarheten": "oackvirerbarhet",
    "oackvirerbarhetens": "oackvirerbarhet",
    "oackvirerbarhets": "oackvirerbarhet",
    "oackvirerbars": "oackvirerbar",
    "oackvirerbart": "oackvirerbar",
    "oackvirerbarts": "oackvirerbar",
    "oadapterade": "oadapterad",
    "oadapterades": "oadapterad",
    "oadapterads": "oadapterad",
    "oadapterat": "oadapterad",
    "oadapterats": "oadapterad",
    "oadapterbara": "oadapterbar",
    "oadapterbarare": "oadapterbar",
    "oadapterbarares": "oadapterbar",
    "oadapterbaras": "oadapterbar",
    "oadapterbarast": "oadapterbar",
    "oadapterbaraste": "oadapterbar",
    "oadapterbarastes": "oadapterbar",
    "oadapterbarasts": "oadapterbar",
    "oadapterbare": "oadapterbar",
    "oadapterbares": "oadapterbar",
    "oadapterbarheten": "oadapterbarhet",
    "oadapterbarhetens": "oadapterbarhet",
    "oadapterbarhets": "oadapterbarhet",
    "oadapterbars": "oadapterbar",
    "oadapterbart": "oadapterbar",
    "oadapterbarts": "oadapterbar",
    "oadderade": "oadderad",
    "oadderades": "oadderad",
    "oadderads": "oadderad",
    "oadderat": "oadderad",
    "oadderats": "oadderad",
    "oadderbara": "oadderbar",
    "oadderbarare": "oadderbar",
    "oadderbarares": "oadderbar",
    "oadderbaras": "oadderbar",
    "oadderbarast": "oadderbar",
    "oadderbaraste": "oadderbar",
    "oadderbarastes": "oadderbar",
    "oadderbarasts": "oadderbar",
    "oadderbare": "oadderbar",
    "oadderbares": "oadderbar",
    "oadderbarheten": "oadderbarhet",
    "oadderbarhetens": "oadderbarhet",
    "oadderbarhets": "oadderbarhet",
    "oadderbars": "oadderbar",
    "oadderbart": "oadderbar",
    "oadderbarts": "oadderbar",
    "oadjungerade": "oadjungerad",
    "oadjungerades": "oadjungerad",
    "oadjungerads": "oadjungerad",
    "oadjungerat": "oadjungerad",
    "oadjungerats": "oadjungerad",
    "oadjungerbara": "oadjungerbar",
    "oadjungerbarare": "oadjungerbar",
    "oadjungerbarares": "oadjungerbar",
    "oadjungerbaras": "oadjungerbar",
    "oadjungerbarast": "oadjungerbar",
    "oadjungerbaraste": "oadjungerbar",
    "oadjungerbarastes": "oadjungerbar",
    "oadjungerbarasts": "oadjungerbar",
    "oadjungerbare": "oadjungerbar",
    "oadjungerbares": "oadjungerbar",
    "oadjungerbarheten": "oadjungerbarhet",
    "oadjungerbarhetens": "oadjungerbarhet",
    "oadjungerbarhets": "oadjungerbarhet",
    "oadjungerbars": "oadjungerbar",
    "oadjungerbart": "oadjungerbar",
    "oadjungerbarts": "oadjungerbar",
    "oadlade": "oadlad",
    "oadlades": "oadlad",
    "oadlads": "oadlad",
    "oadlat": "oadlad",
    "oadlats": "oadlad",
    "oadministrerade": "oadministrerad",
    "oadministrerades": "oadministrerad",
    "oadministrerads": "oadministrerad",
    "oadministrerat": "oadministrerad",
    "oadministrerats": "oadministrerad",
    "oadministrerbara": "oadministrerbar",
    "oadministrerbarare": "oadministrerbar",
    "oadministrerbarares": "oadministrerbar",
    "oadministrerbaras": "oadministrerbar",
    "oadministrerbarast": "oadministrerbar",
    "oadministrerbaraste": "oadministrerbar",
    "oadministrerbarastes": "oadministrerbar",
    "oadministrerbarasts": "oadministrerbar",
    "oadministrerbare": "oadministrerbar",
    "oadministrerbares": "oadministrerbar",
    "oadministrerbarheten": "oadministrerbarhet",
    "oadministrerbarhetens": "oadministrerbarhet",
    "oadministrerbarhets": "oadministrerbarhet",
    "oadministrerbars": "oadministrerbar",
    "oadministrerbart": "oadministrerbar",
    "oadministrerbarts": "oadministrerbar",
    "oadopterade": "oadopterad",
    "oadopterades": "oadopterad",
    "oadopterads": "oadopterad",
    "oadopterat": "oadopterad",
    "oadopterats": "oadopterad",
    "oadopterbara": "oadopterbar",
    "oadopterbarare": "oadopterbar",
    "oadopterbarares": "oadopterbar",
    "oadopterbaras": "oadopterbar",
    "oadopterbarast": "oadopterbar",
    "oadopterbaraste": "oadopterbar",
    "oadopterbarastes": "oadopterbar",
    "oadopterbarasts": "oadopterbar",
    "oadopterbare": "oadopterbar",
    "oadopterbares": "oadopterbar",
    "oadopterbarheten": "oadopterbarhet",
    "oadopterbarhetens": "oadopterbarhet",
    "oadopterbarhets": "oadopterbarhet",
    "oadopterbars": "oadopterbar",
    "oadopterbart": "oadopterbar",
    "oadopterbarts": "oadopterbar",
    "oadresserade": "oadresserad",
    "oadresserades": "oadresserad",
    "oadresserads": "oadresserad",
    "oadresserat": "oadresserad",
    "oadresserats": "oadresserad",
    "oadresserbara": "oadresserbar",
    "oadresserbarare": "oadresserbar",
    "oadresserbarares": "oadresserbar",
    "oadresserbaras": "oadresserbar",
    "oadresserbarast": "oadresserbar",
    "oadresserbaraste": "oadresserbar",
    "oadresserbarastes": "oadresserbar",
    "oadresserbarasts": "oadresserbar",
    "oadresserbare": "oadresserbar",
    "oadresserbares": "oadresserbar",
    "oadresserbarheten": "oadresserbarhet",
    "oadresserbarhetens": "oadresserbarhet",
    "oadresserbarhets": "oadresserbarhet",
    "oadresserbars": "oadresserbar",
    "oadresserbart": "oadresserbar",
    "oadresserbarts": "oadresserbar",
    "oadsorberade": "oadsorberad",
    "oadsorberades": "oadsorberad",
    "oadsorberads": "oadsorberad",
    "oadsorberat": "oadsorberad",
    "oadsorberats": "oadsorberad",
    "oadsorberbara": "oadsorberbar",
    "oadsorberbarare": "oadsorberbar",
    "oadsorberbarares": "oadsorberbar",
    "oadsorberbaras": "oadsorberbar",
    "oadsorberbarast": "oadsorberbar",
    "oadsorberbaraste": "oadsorberbar",
    "oadsorberbarastes": "oadsorberbar",
    "oadsorberbarasts": "oadsorberbar",
    "oadsorberbare": "oadsorberbar",
    "oadsorberbares": "oadsorberbar",
    "oadsorberbarheten": "oadsorberbarhet",
    "oadsorberbarhetens": "oadsorberbarhet",
    "oadsorberbarhets": "oadsorberbarhet",
    "oadsorberbars": "oadsorberbar",
    "oadsorberbart": "oadsorberbar",
    "oadsorberbarts": "oadsorberbar",
    "oaducerade": "oaducerad",
    "oaducerades": "oaducerad",
    "oaducerads": "oaducerad",
    "oaducerat": "oaducerad",
    "oaducerats": "oaducerad",
    "oaducerbara": "oaducerbar",
    "oaducerbarare": "oaducerbar",
    "oaducerbarares": "oaducerbar",
    "oaducerbaras": "oaducerbar",
    "oaducerbarast": "oaducerbar",
    "oaducerbaraste": "oaducerbar",
    "oaducerbarastes": "oaducerbar",
    "oaducerbarasts": "oaducerbar",
    "oaducerbare": "oaducerbar",
    "oaducerbares": "oaducerbar",
    "oaducerbarheten": "oaducerbarhet",
    "oaducerbarhetens": "oaducerbarhet",
    "oaducerbarhets": "oaducerbarhet",
    "oaducerbars": "oaducerbar",
    "oaducerbart": "oaducerbar",
    "oaducerbarts": "oaducerbar",
    "oadvocerade": "oadvocerad",
    "oadvocerades": "oadvocerad",
    "oadvocerads": "oadvocerad",
    "oadvocerat": "oadvocerad",
    "oadvocerats": "oadvocerad",
    "oadvocerbara": "oadvocerbar",
    "oadvocerbarare": "oadvocerbar",
    "oadvocerbarares": "oadvocerbar",
    "oadvocerbaras": "oadvocerbar",
    "oadvocerbarast": "oadvocerbar",
    "oadvocerbaraste": "oadvocerbar",
    "oadvocerbarastes": "oadvocerbar",
    "oadvocerbarasts": "oadvocerbar",
    "oadvocerbare": "oadvocerbar",
    "oadvocerbares": "oadvocerbar",
    "oadvocerbarheten": "oadvocerbarhet",
    "oadvocerbarhetens": "oadvocerbarhet",
    "oadvocerbarhets": "oadvocerbarhet",
    "oadvocerbars": "oadvocerbar",
    "oadvocerbart": "oadvocerbar",
    "oadvocerbarts": "oadvocerbar",
    "oafficierade": "oafficierad",
    "oafficierades": "oafficierad",
    "oafficierads": "oafficierad",
    "oafficierat": "oafficierad",
    "oafficierats": "oafficierad",
    "oafficierbara": "oafficierbar",
    "oafficierbarare": "oafficierbar",
    "oafficierbarares": "oafficierbar",
    "oafficierbaras": "oafficierbar",
    "oafficierbarast": "oafficierbar",
    "oafficierbaraste": "oafficierbar",
    "oafficierbarastes": "oafficierbar",
    "oafficierbarasts": "oafficierbar",
    "oafficierbare": "oafficierbar",
    "oafficierbares": "oafficierbar",
    "oafficierbarheten": "oafficierbarhet",
    "oafficierbarhetens": "oafficierbarhet",
    "oafficierbarhets": "oafficierbarhet",
    "oafficierbars": "oafficierbar",
    "oafficierbart": "oafficierbar",
    "oafficierbarts": "oafficierbar",
    "oaffinerade": "oaffinerad",
    "oaffinerades": "oaffinerad",
    "oaffinerads": "oaffinerad",
    "oaffinerat": "oaffinerad",
    "oaffinerats": "oaffinerad",
    "oaffinerbara": "oaffinerbar",
    "oaffinerbarare": "oaffinerbar",
    "oaffinerbarares": "oaffinerbar",
    "oaffinerbaras": "oaffinerbar",
    "oaffinerbarast": "oaffinerbar",
    "oaffinerbaraste": "oaffinerbar",
    "oaffinerbarastes": "oaffinerbar",
    "oaffinerbarasts": "oaffinerbar",
    "oaffinerbare": "oaffinerbar",
    "oaffinerbares": "oaffinerbar",
    "oaffinerbarheten": "oaffinerbarhet",
    "oaffinerbarhetens": "oaffinerbarhet",
    "oaffinerbarhets": "oaffinerbarhet",
    "oaffinerbars": "oaffinerbar",
    "oaffinerbart": "oaffinerbar",
    "oaffinerbarts": "oaffinerbar",
    "oaffischerade": "oaffischerad",
    "oaffischerades": "oaffischerad",
    "oaffischerads": "oaffischerad",
    "oaffischerat": "oaffischerad",
    "oaffischerats": "oaffischerad",
    "oaffischerbara": "oaffischerbar",
    "oaffischerbarare": "oaffischerbar",
    "oaffischerbarares": "oaffischerbar",
    "oaffischerbaras": "oaffischerbar",
    "oaffischerbarast": "oaffischerbar",
    "oaffischerbaraste": "oaffischerbar",
    "oaffischerbarastes": "oaffischerbar",
    "oaffischerbarasts": "oaffischerbar",
    "oaffischerbare": "oaffischerbar",
    "oaffischerbares": "oaffischerbar",
    "oaffischerbarheten": "oaffischerbarhet",
    "oaffischerbarhetens": "oaffischerbarhet",
    "oaffischerbarhets": "oaffischerbarhet",
    "oaffischerbars": "oaffischerbar",
    "oaffischerbart": "oaffischerbar",
    "oaffischerbarts": "oaffischerbar",
    "oafrikaniserade": "oafrikaniserad",
    "oafrikaniserades": "oafrikaniserad",
    "oafrikaniserads": "oafrikaniserad",
    "oafrikaniserat": "oafrikaniserad",
    "oafrikaniserats": "oafrikaniserad",
    "oafrikaniserbara": "oafrikaniserbar",
    "oafrikaniserbarare": "oafrikaniserbar",
    "oafrikaniserbarares": "oafrikaniserbar",
    "oafrikaniserbaras": "oafrikaniserbar",
    "oafrikaniserbarast": "oafrikaniserbar",
    "oafrikaniserbaraste": "oafrikaniserbar",
    "oafrikaniserbarastes": "oafrikaniserbar",
    "oafrikaniserbarasts": "oafrikaniserbar",
    "oafrikaniserbare": "oafrikaniserbar",
    "oafrikaniserbares": "oafrikaniserbar",
    "oafrikaniserbarheten": "oafrikaniserbarhet",
    "oafrikaniserbarhetens": "oafrikaniserbarhet",
    "oafrikaniserbarhets": "oafrikaniserbarhet",
    "oafrikaniserbars": "oafrikaniserbar",
    "oafrikaniserbart": "oafrikaniserbar",
    "oafrikaniserbarts": "oafrikaniserbar",
    "oagade": "oagad",
    "oagades": "oagad",
    "oagads": "oagad",
    "oagat": "oagad",
    "oagats": "oagad",
    "oagerade": "oagerad",
    "oagerades": "oagerad",
    "oagerads": "oagerad",
    "oagerat": "oagerad",
    "oagerats": "oagerad",
    "oagerbara": "oagerbar",
    "oagerbarare": "oagerbar",
    "oagerbarares": "oagerbar",
    "oagerbaras": "oagerbar",
    "oagerbarast": "oagerbar",
    "oagerbaraste": "oagerbar",
    "oagerbarastes": "oagerbar",
    "oagerbarasts": "oagerbar",
    "oagerbare": "oagerbar",
    "oagerbares": "oagerbar",
    "oagerbarheten": "oagerbarhet",
    "oagerbarhetens": "oagerbarhet",
    "oagerbarhets": "oagerbarhet",
    "oagerbars": "oagerbar",
    "oagerbart": "oagerbar",
    "oagerbarts": "oagerbar",
    "oagglomererade": "oagglomererad",
    "oagglomererades": "oagglomererad",
    "oagglomererads": "oagglomererad",
    "oagglomererat": "oagglomererad",
    "oagglomererats": "oagglomererad",
    "oagglomererbara": "oagglomererbar",
    "oagglomererbarare": "oagglomererbar",
    "oagglomererbarares": "oagglomererbar",
    "oagglomererbaras": "oagglomererbar",
    "oagglomererbarast": "oagglomererbar",
    "oagglomererbaraste": "oagglomererbar",
    "oagglomererbarastes": "oagglomererbar",
    "oagglomererbarasts": "oagglomererbar",
    "oagglomererbare": "oagglomererbar",
    "oagglomererbares": "oagglomererbar",
    "oagglomererbarheten": "oagglomererbarhet",
    "oagglomererbarhetens": "oagglomererbarhet",
    "oagglomererbarhets": "oagglomererbarhet",
    "oagglomererbars": "oagglomererbar",
    "oagglomererbart": "oagglomererbar",
    "oagglomererbarts": "oagglomererbar",
    "oagglutinerade": "oagglutinerad",
    "oagglutinerades": "oagglutinerad",
    "oagglutinerads": "oagglutinerad",
    "oagglutinerat": "oagglutinerad",
    "oagglutinerats": "oagglutinerad",
    "oagglutinerbara": "oagglutinerbar",
    "oagglutinerbarare": "oagglutinerbar",
    "oagglutinerbarares": "oagglutinerbar",
    "oagglutinerbaras": "oagglutinerbar",
    "oagglutinerbarast": "oagglutinerbar",
    "oagglutinerbaraste": "oagglutinerbar",
    "oagglutinerbarastes": "oagglutinerbar",
    "oagglutinerbarasts": "oagglutinerbar",
    "oagglutinerbare": "oagglutinerbar",
    "oagglutinerbares": "oagglutinerbar",
    "oagglutinerbarheten": "oagglutinerbarhet",
    "oagglutinerbarhetens": "oagglutinerbarhet",
    "oagglutinerbarhets": "oagglutinerbarhet",
    "oagglutinerbars": "oagglutinerbar",
    "oagglutinerbart": "oagglutinerbar",
    "oagglutinerbarts": "oagglutinerbar",
    "oagiterade": "oagiterad",
    "oagiterades": "oagiterad",
    "oagiterads": "oagiterad",
    "oagiterat": "oagiterad",
    "oagiterats": "oagiterad",
    "oagiterbara": "oagiterbar",
    "oagiterbarare": "oagiterbar",
    "oagiterbarares": "oagiterbar",
    "oagiterbaras": "oagiterbar",
    "oagiterbarast": "oagiterbar",
    "oagiterbaraste": "oagiterbar",
    "oagiterbarastes": "oagiterbar",
    "oagiterbarasts": "oagiterbar",
    "oagiterbare": "oagiterbar",
    "oagiterbares": "oagiterbar",
    "oagiterbarheten": "oagiterbarhet",
    "oagiterbarhetens": "oagiterbarhet",
    "oagiterbarhets": "oagiterbarhet",
    "oagiterbars": "oagiterbar",
    "oagiterbart": "oagiterbar",
    "oagiterbarts": "oagiterbar",
    "oagnade": "oagnad",
    "oagnades": "oagnad",
    "oagnads": "oagnad",
    "oagnat": "oagnad",
    "oagnats": "oagnad",
    "oajournerade": "oajournerad",
    "oajournerades": "oajournerad",
    "oajournerads": "oajournerad",
    "oajournerat": "oajournerad",
    "oajournerats": "oajournerad",
    "oajournerbara": "oajournerbar",
    "oajournerbarare": "oajournerbar",
    "oajournerbarares": "oajournerbar",
    "oajournerbaras": "oajournerbar",
    "oajournerbarast": "oajournerbar",
    "oajournerbaraste": "oajournerbar",
    "oajournerbarastes": "oajournerbar",
    "oajournerbarasts": "oajournerbar",
    "oajournerbare": "oajournerbar",
    "oajournerbares": "oajournerbar",
    "oajournerbarheten": "oajournerbarhet",
    "oajournerbarhetens": "oajournerbarhet",
    "oajournerbarhets": "oajournerbarhet",
    "oajournerbars": "oajournerbar",
    "oajournerbart": "oajournerbar",
    "oajournerbarts": "oajournerbar",
    "oaktade": "oaktad",
    "oaktades": "oaktad",
    "oaktads": "oaktad",
    "oaktat": "oaktad",
    "oaktats": "oaktad",
    "oaktiverade": "oaktiverad",
    "oaktiverades": "oaktiverad",
    "oaktiverads": "oaktiverad",
    "oaktiverat": "oaktiverad",
    "oaktiverats": "oaktiverad",
    "oaktiverbara": "oaktiverbar",
    "oaktiverbarare": "oaktiverbar",
    "oaktiverbarares": "oaktiverbar",
    "oaktiverbaras": "oaktiverbar",
    "oaktiverbarast": "oaktiverbar",
    "oaktiverbaraste": "oaktiverbar",
    "oaktiverbarastes": "oaktiverbar",
    "oaktiverbarasts": "oaktiverbar",
    "oaktiverbare": "oaktiverbar",
    "oaktiverbares": "oaktiverbar",
    "oaktiverbarheten": "oaktiverbarhet",
    "oaktiverbarhetens": "oaktiverbarhet",
    "oaktiverbarhets": "oaktiverbarhet",
    "oaktiverbars": "oaktiverbar",
    "oaktiverbart": "oaktiverbar",
    "oaktiverbarts": "oaktiverbar",
    "oaktsamheten": "oaktsamhet",
    "oaktsamhetens": "oaktsamhet",
    "oaktsamheter": "oaktsamhet",
    "oaktsamheterna": "oaktsamhet",
    "oaktsamheternas": "oaktsamhet",
    "oaktsamheters": "oaktsamhet",
    "oaktsamhets": "oaktsamhet",
    "oaktsamhetsbrotten": "oaktsamhetsbrott",
    "oaktsamhetsbrottens": "oaktsamhetsbrott",
    "oaktsamhetsbrottet": "oaktsamhetsbrott",
    "oaktsamhetsbrottets": "oaktsamhetsbrott",
    "oaktsamhetsbrotts": "oaktsamhetsbrott",
    "oaktsamma": "oaktsam",
    "oaktsammare": "oaktsam",
    "oaktsammares": "oaktsam",
    "oaktsammas": "oaktsam",
    "oaktsammast": "oaktsam",
    "oaktsammaste": "oaktsam",
    "oaktsammastes": "oaktsam",
    "oaktsammasts": "oaktsam",
    "oaktsamme": "oaktsam",
    "oaktsammes": "oaktsam",
    "oaktsams": "oaktsam",
    "oaktsamt": "oaktsam",
    "oaktsamts": "oaktsam",
    "oaktualiserade": "oaktualiserad",
    "oaktualiserades": "oaktualiserad",
    "oaktualiserads": "oaktualiserad",
    "oaktualiserat": "oaktualiserad",
    "oaktualiserats": "oaktualiserad",
    "oaktualiserbara": "oaktualiserbar",
    "oaktualiserbarare": "oaktualiserbar",
    "oaktualiserbarares": "oaktualiserbar",
    "oaktualiserbaras": "oaktualiserbar",
    "oaktualiserbarast": "oaktualiserbar",
    "oaktualiserbaraste": "oaktualiserbar",
    "oaktualiserbarastes": "oaktualiserbar",
    "oaktualiserbarasts": "oaktualiserbar",
    "oaktualiserbare": "oaktualiserbar",
    "oaktualiserbares": "oaktualiserbar",
    "oaktualiserbarheten": "oaktualiserbarhet",
    "oaktualiserbarhetens": "oaktualiserbarhet",
    "oaktualiserbarhets": "oaktualiserbarhet",
    "oaktualiserbars": "oaktualiserbar",
    "oaktualiserbart": "oaktualiserbar",
    "oaktualiserbarts": "oaktualiserbar",
    "oalarmerade": "oalarmerad",
    "oalarmerades": "oalarmerad",
    "oalarmerads": "oalarmerad",
    "oalarmerat": "oalarmerad",
    "oalarmerats": "oalarmerad",
    "oalarmerbara": "oalarmerbar",
    "oalarmerbarare": "oalarmerbar",
    "oalarmerbarares": "oalarmerbar",
    "oalarmerbaras": "oalarmerbar",
    "oalarmerbarast": "oalarmerbar",
    "oalarmerbaraste": "oalarmerbar",
    "oalarmerbarastes": "oalarmerbar",
    "oalarmerbarasts": "oalarmerbar",
    "oalarmerbare": "oalarmerbar",
    "oalarmerbares": "oalarmerbar",
    "oalarmerbarheten": "oalarmerbarhet",
    "oalarmerbarhetens": "oalarmerbarhet",
    "oalarmerbarhets": "oalarmerbarhet",
    "oalarmerbars": "oalarmerbar",
    "oalarmerbart": "oalarmerbar",
    "oalarmerbarts": "oalarmerbar",
    "oalfabetiserade": "oalfabetiserad",
    "oalfabetiserades": "oalfabetiserad",
    "oalfabetiserads": "oalfabetiserad",
    "oalfabetiserat": "oalfabetiserad",
    "oalfabetiserats": "oalfabetiserad",
    "oalfabetiserbara": "oalfabetiserbar",
    "oalfabetiserbarare": "oalfabetiserbar",
    "oalfabetiserbarares": "oalfabetiserbar",
    "oalfabetiserbaras": "oalfabetiserbar",
    "oalfabetiserbarast": "oalfabetiserbar",
    "oalfabetiserbaraste": "oalfabetiserbar",
    "oalfabetiserbarastes": "oalfabetiserbar",
    "oalfabetiserbarasts": "oalfabetiserbar",
    "oalfabetiserbare": "oalfabetiserbar",
    "oalfabetiserbares": "oalfabetiserbar",
    "oalfabetiserbarheten": "oalfabetiserbarhet",
    "oalfabetiserbarhetens": "oalfabetiserbarhet",
    "oalfabetiserbarhets": "oalfabetiserbarhet",
    "oalfabetiserbars": "oalfabetiserbar",
    "oalfabetiserbart": "oalfabetiserbar",
    "oalfabetiserbarts": "oalfabetiserbar",
    "oalienerade": "oalienerad",
    "oalienerades": "oalienerad",
    "oalienerads": "oalienerad",
    "oalienerat": "oalienerad",
    "oalienerats": "oalienerad",
    "oalienerbara": "oalienerbar",
    "oalienerbarare": "oalienerbar",
    "oalienerbarares": "oalienerbar",
    "oalienerbaras": "oalienerbar",
    "oalienerbarast": "oalienerbar",
    "oalienerbaraste": "oalienerbar",
    "oalienerbarastes": "oalienerbar",
    "oalienerbarasts": "oalienerbar",
    "oalienerbare": "oalienerbar",
    "oalienerbares": "oalienerbar",
    "oalienerbarheten": "oalienerbarhet",
    "oalienerbarhetens": "oalienerbarhet",
    "oalienerbarhets": "oalienerbarhet",
    "oalienerbars": "oalienerbar",
    "oalienerbart": "oalienerbar",
    "oalienerbarts": "oalienerbar",
    "oallegoriserade": "oallegoriserad",
    "oallegoriserades": "oallegoriserad",
    "oallegoriserads": "oallegoriserad",
    "oallegoriserat": "oallegoriserad",
    "oallegoriserats": "oallegoriserad",
    "oallegoriserbara": "oallegoriserbar",
    "oallegoriserbarare": "oallegoriserbar",
    "oallegoriserbarares": "oallegoriserbar",
    "oallegoriserbaras": "oallegoriserbar",
    "oallegoriserbarast": "oallegoriserbar",
    "oallegoriserbaraste": "oallegoriserbar",
    "oallegoriserbarastes": "oallegoriserbar",
    "oallegoriserbarasts": "oallegoriserbar",
    "oallegoriserbare": "oallegoriserbar",
    "oallegoriserbares": "oallegoriserbar",
    "oallegoriserbarheten": "oallegoriserbarhet",
    "oallegoriserbarhetens": "oallegoriserbarhet",
    "oallegoriserbarhets": "oallegoriserbarhet",
    "oallegoriserbars": "oallegoriserbar",
    "oallegoriserbart": "oallegoriserbar",
    "oallegoriserbarts": "oallegoriserbar",
    "oallierade": "oallierad",
    "oallierades": "oallierad",
    "oallierads": "oallierad",
    "oallierat": "oallierad",
    "oallierats": "oallierad",
    "oallierbara": "oallierbar",
    "oallierbarare": "oallierbar",
    "oallierbarares": "oallierbar",
    "oallierbaras": "oallierbar",
    "oallierbarast": "oallierbar",
    "oallierbaraste": "oallierbar",
    "oallierbarastes": "oallierbar",
    "oallierbarasts": "oallierbar",
    "oallierbare": "oallierbar",
    "oallierbares": "oallierbar",
    "oallierbarheten": "oallierbarhet",
    "oallierbarhetens": "oallierbarhet",
    "oallierbarhets": "oallierbarhet",
    "oallierbars": "oallierbar",
    "oallierbart": "oallierbar",
    "oallierbarts": "oallierbar",
    "oallittererade": "oallittererad",
    "oallittererades": "oallittererad",
    "oallittererads": "oallittererad",
    "oallittererat": "oallittererad",
    "oallittererats": "oallittererad",
    "oallittererbara": "oallittererbar",
    "oallittererbarare": "oallittererbar",
    "oallittererbarares": "oallittererbar",
    "oallittererbaras": "oallittererbar",
    "oallittererbarast": "oallittererbar",
    "oallittererbaraste": "oallittererbar",
    "oallittererbarastes": "oallittererbar",
    "oallittererbarasts": "oallittererbar",
    "oallittererbare": "oallittererbar",
    "oallittererbares": "oallittererbar",
    "oallittererbarheten": "oallittererbarhet",
    "oallittererbarhetens": "oallittererbarhet",
    "oallittererbarhets": "oallittererbarhet",
    "oallittererbars": "oallittererbar",
    "oallittererbart": "oallittererbar",
    "oallittererbarts": "oallittererbar",
    "oallmänbildade": "oallmänbildad",
    "oallmänbildades": "oallmänbildad",
    "oallmänbildads": "oallmänbildad",
    "oallmänbildat": "oallmänbildad",
    "oallmänbildats": "oallmänbildad",
    "oallokerade": "oallokerad",
    "oallokerades": "oallokerad",
    "oallokerads": "oallokerad",
    "oallokerat": "oallokerad",
    "oallokerats": "oallokerad",
    "oallokerbara": "oallokerbar",
    "oallokerbarare": "oallokerbar",
    "oallokerbarares": "oallokerbar",
    "oallokerbaras": "oallokerbar",
    "oallokerbarast": "oallokerbar",
    "oallokerbaraste": "oallokerbar",
    "oallokerbarastes": "oallokerbar",
    "oallokerbarasts": "oallokerbar",
    "oallokerbare": "oallokerbar",
    "oallokerbares": "oallokerbar",
    "oallokerbarheten": "oallokerbarhet",
    "oallokerbarhetens": "oallokerbarhet",
    "oallokerbarhets": "oallokerbarhet",
    "oallokerbars": "oallokerbar",
    "oallokerbart": "oallokerbar",
    "oallokerbarts": "oallokerbar",
    "oalluderade": "oalluderad",
    "oalluderades": "oalluderad",
    "oalluderads": "oalluderad",
    "oalluderat": "oalluderad",
    "oalluderats": "oalluderad",
    "oalluderbara": "oalluderbar",
    "oalluderbarare": "oalluderbar",
    "oalluderbarares": "oalluderbar",
    "oalluderbaras": "oalluderbar",
    "oalluderbarast": "oalluderbar",
    "oalluderbaraste": "oalluderbar",
    "oalluderbarastes": "oalluderbar",
    "oalluderbarasts": "oalluderbar",
    "oalluderbare": "oalluderbar",
    "oalluderbares": "oalluderbar",
    "oalluderbarheten": "oalluderbarhet",
    "oalluderbarhetens": "oalluderbarhet",
    "oalluderbarhets": "oalluderbarhet",
    "oalluderbars": "oalluderbar",
    "oalluderbart": "oalluderbar",
    "oalluderbarts": "oalluderbar",
    "oalstrade": "oalstrad",
    "oalstrades": "oalstrad",
    "oalstrads": "oalstrad",
    "oalstrat": "oalstrad",
    "oalstrats": "oalstrad",
    "oalternerade": "oalternerad",
    "oalternerades": "oalternerad",
    "oalternerads": "oalternerad",
    "oalternerat": "oalternerad",
    "oalternerats": "oalternerad",
    "oalternerbara": "oalternerbar",
    "oalternerbarare": "oalternerbar",
    "oalternerbarares": "oalternerbar",
    "oalternerbaras": "oalternerbar",
    "oalternerbarast": "oalternerbar",
    "oalternerbaraste": "oalternerbar",
    "oalternerbarastes": "oalternerbar",
    "oalternerbarasts": "oalternerbar",
    "oalternerbare": "oalternerbar",
    "oalternerbares": "oalternerbar",
    "oalternerbarheten": "oalternerbarhet",
    "oalternerbarhetens": "oalternerbarhet",
    "oalternerbarhets": "oalternerbarhet",
    "oalternerbars": "oalternerbar",
    "oalternerbart": "oalternerbar",
    "oalternerbarts": "oalternerbar",
    "oaluminerade": "oaluminerad",
    "oaluminerades": "oaluminerad",
    "oaluminerads": "oaluminerad",
    "oaluminerat": "oaluminerad",
    "oaluminerats": "oaluminerad",
    "oaluminerbara": "oaluminerbar",
    "oaluminerbarare": "oaluminerbar",
    "oaluminerbarares": "oaluminerbar",
    "oaluminerbaras": "oaluminerbar",
    "oaluminerbarast": "oaluminerbar",
    "oaluminerbaraste": "oaluminerbar",
    "oaluminerbarastes": "oaluminerbar",
    "oaluminerbarasts": "oaluminerbar",
    "oaluminerbare": "oaluminerbar",
    "oaluminerbares": "oaluminerbar",
    "oaluminerbarheten": "oaluminerbarhet",
    "oaluminerbarhetens": "oaluminerbarhet",
    "oaluminerbarhets": "oaluminerbarhet",
    "oaluminerbars": "oaluminerbar",
    "oaluminerbart": "oaluminerbar",
    "oaluminerbarts": "oaluminerbar",
    "oamalgamerade": "oamalgamerad",
    "oamalgamerades": "oamalgamerad",
    "oamalgamerads": "oamalgamerad",
    "oamalgamerat": "oamalgamerad",
    "oamalgamerats": "oamalgamerad",
    "oamalgamerbara": "oamalgamerbar",
    "oamalgamerbarare": "oamalgamerbar",
    "oamalgamerbarares": "oamalgamerbar",
    "oamalgamerbaras": "oamalgamerbar",
    "oamalgamerbarast": "oamalgamerbar",
    "oamalgamerbaraste": "oamalgamerbar",
    "oamalgamerbarastes": "oamalgamerbar",
    "oamalgamerbarasts": "oamalgamerbar",
    "oamalgamerbare": "oamalgamerbar",
    "oamalgamerbares": "oamalgamerbar",
    "oamalgamerbarheten": "oamalgamerbarhet",
    "oamalgamerbarhetens": "oamalgamerbarhet",
    "oamalgamerbarhets": "oamalgamerbarhet",
    "oamalgamerbars": "oamalgamerbar",
    "oamalgamerbart": "oamalgamerbar",
    "oamalgamerbarts": "oamalgamerbar",
    "oambulerade": "oambulerad",
    "oambulerades": "oambulerad",
    "oambulerads": "oambulerad",
    "oambulerat": "oambulerad",
    "oambulerats": "oambulerad",
    "oambulerbara": "oambulerbar",
    "oambulerbarare": "oambulerbar",
    "oambulerbarares": "oambulerbar",
    "oambulerbaras": "oambulerbar",
    "oambulerbarast": "oambulerbar",
    "oambulerbaraste": "oambulerbar",
    "oambulerbarastes": "oambulerbar",
    "oambulerbarasts": "oambulerbar",
    "oambulerbare": "oambulerbar",
    "oambulerbares": "oambulerbar",
    "oambulerbarheten": "oambulerbarhet",
    "oambulerbarhetens": "oambulerbarhet",
    "oambulerbarhets": "oambulerbarhet",
    "oambulerbars": "oambulerbar",
    "oambulerbart": "oambulerbar",
    "oambulerbarts": "oambulerbar",
    "oamerikaniserade": "oamerikaniserad",
    "oamerikaniserades": "oamerikaniserad",
    "oamerikaniserads": "oamerikaniserad",
    "oamerikaniserat": "oamerikaniserad",
    "oamerikaniserats": "oamerikaniserad",
    "oamerikaniserbara": "oamerikaniserbar",
    "oamerikaniserbarare": "oamerikaniserbar",
    "oamerikaniserbarares": "oamerikaniserbar",
    "oamerikaniserbaras": "oamerikaniserbar",
    "oamerikaniserbarast": "oamerikaniserbar",
    "oamerikaniserbaraste": "oamerikaniserbar",
    "oamerikaniserbarastes": "oamerikaniserbar",
    "oamerikaniserbarasts": "oamerikaniserbar",
    "oamerikaniserbare": "oamerikaniserbar",
    "oamerikaniserbares": "oamerikaniserbar",
    "oamerikaniserbarheten": "oamerikaniserbarhet",
    "oamerikaniserbarhetens": "oamerikaniserbarhet",
    "oamerikaniserbarhets": "oamerikaniserbarhet",
    "oamerikaniserbars": "oamerikaniserbar",
    "oamerikaniserbart": "oamerikaniserbar",
    "oamerikaniserbarts": "oamerikaniserbar",
    "oamerikanska": "oamerikansk",
    "oamerikanskare": "oamerikansk",
    "oamerikanskares": "oamerikansk",
    "oamerikanskas": "oamerikansk",
    "oamerikanskast": "oamerikansk",
    "oamerikanskaste": "oamerikansk",
    "oamerikanskastes": "oamerikansk",
    "oamerikanskasts": "oamerikansk",
    "oamerikanske": "oamerikansk",
    "oamerikanskes": "oamerikansk",
    "oamerikansks": "oamerikansk",
    "oamerikanskt": "oamerikansk",
    "oamerikanskts": "oamerikansk",
    "oammade": "oammad",
    "oammades": "oammad",
    "oammads": "oammad",
    "oammat": "oammad",
    "oammats": "oammad",
    "oamorterade": "oamorterad",
    "oamorterades": "oamorterad",
    "oamorterads": "oamorterad",
    "oamorterat": "oamorterad",
    "oamorterats": "oamorterad",
    "oamorterbara": "oamorterbar",
    "oamorterbarare": "oamorterbar",
    "oamorterbarares": "oamorterbar",
    "oamorterbaras": "oamorterbar",
    "oamorterbarast": "oamorterbar",
    "oamorterbaraste": "oamorterbar",
    "oamorterbarastes": "oamorterbar",
    "oamorterbarasts": "oamorterbar",
    "oamorterbare": "oamorterbar",
    "oamorterbares": "oamorterbar",
    "oamorterbarheten": "oamorterbarhet",
    "oamorterbarhetens": "oamorterbarhet",
    "oamorterbarhets": "oamorterbarhet",
    "oamorterbars": "oamorterbar",
    "oamorterbart": "oamorterbar",
    "oamorterbarts": "oamorterbar",
    "oamplifierade": "oamplifierad",
    "oamplifierades": "oamplifierad",
    "oamplifierads": "oamplifierad",
    "oamplifierat": "oamplifierad",
    "oamplifierats": "oamplifierad",
    "oamplifierbara": "oamplifierbar",
    "oamplifierbarare": "oamplifierbar",
    "oamplifierbarares": "oamplifierbar",
    "oamplifierbaras": "oamplifierbar",
    "oamplifierbarast": "oamplifierbar",
    "oamplifierbaraste": "oamplifierbar",
    "oamplifierbarastes": "oamplifierbar",
    "oamplifierbarasts": "oamplifierbar",
    "oamplifierbare": "oamplifierbar",
    "oamplifierbares": "oamplifierbar",
    "oamplifierbarheten": "oamplifierbarhet",
    "oamplifierbarhetens": "oamplifierbarhet",
    "oamplifierbarhets": "oamplifierbarhet",
    "oamplifierbars": "oamplifierbar",
    "oamplifierbart": "oamplifierbar",
    "oamplifierbarts": "oamplifierbar",
    "oamputerade": "oamputerad",
    "oamputerades": "oamputerad",
    "oamputerads": "oamputerad",
    "oamputerat": "oamputerad",
    "oamputerats": "oamputerad",
    "oamputerbara": "oamputerbar",
    "oamputerbarare": "oamputerbar",
    "oamputerbarares": "oamputerbar",
    "oamputerbaras": "oamputerbar",
    "oamputerbarast": "oamputerbar",
    "oamputerbaraste": "oamputerbar",
    "oamputerbarastes": "oamputerbar",
    "oamputerbarasts": "oamputerbar",
    "oamputerbare": "oamputerbar",
    "oamputerbares": "oamputerbar",
    "oamputerbarheten": "oamputerbarhet",
    "oamputerbarhetens": "oamputerbarhet",
    "oamputerbarhets": "oamputerbarhet",
    "oamputerbars": "oamputerbar",
    "oamputerbart": "oamputerbar",
    "oamputerbarts": "oamputerbar",
    "oanade": "oanad",
    "oanades": "oanad",
    "oanads": "oanad",
    "oanalyserade": "oanalyserad",
    "oanalyserades": "oanalyserad",
    "oanalyserads": "oanalyserad",
    "oanalyserat": "oanalyserad",
    "oanalyserats": "oanalyserad",
    "oanalyserbara": "oanalyserbar",
    "oanalyserbarare": "oanalyserbar",
    "oanalyserbarares": "oanalyserbar",
    "oanalyserbaras": "oanalyserbar",
    "oanalyserbarast": "oanalyserbar",
    "oanalyserbaraste": "oanalyserbar",
    "oanalyserbarastes": "oanalyserbar",
    "oanalyserbarasts": "oanalyserbar",
    "oanalyserbare": "oanalyserbar",
    "oanalyserbares": "oanalyserbar",
    "oanalyserbarheten": "oanalyserbarhet",
    "oanalyserbarhetens": "oanalyserbarhet",
    "oanalyserbarhets": "oanalyserbarhet",
    "oanalyserbars": "oanalyserbar",
    "oanalyserbart": "oanalyserbar",
    "oanalyserbarts": "oanalyserbar",
    "oanammade": "oanammad",
    "oanammades": "oanammad",
    "oanammads": "oanammad",
    "oanammat": "oanammad",
    "oanammats": "oanammad",
    "oanat": "oanad",
    "oanats": "oanad",
    "oanbefallde": "oanbefalld",
    "oanbefalldes": "oanbefalld",
    "oanbefallds": "oanbefalld",
    "oanbefallt": "oanbefalld",
    "oanbefallts": "oanbefalld",
    "oandliga": "oandlig",
    "oandligare": "oandlig",
    "oandligares": "oandlig",
    "oandligas": "oandlig",
    "oandligast": "oandlig",
    "oandligaste": "oandlig",
    "oandligastes": "oandlig",
    "oandligasts": "oandlig",
    "oandlige": "oandlig",
    "oandliges": "oandlig",
    "oandligheten": "oandlighet",
    "oandlighetens": "oandlighet",
    "oandlighets": "oandlighet",
    "oandligs": "oandlig",
    "oandligt": "oandlig",
    "oandligts": "oandlig",
    "oanfrätta": "oanfrätt",
    "oanfrättare": "oanfrätt",
    "oanfrättares": "oanfrätt",
    "oanfrättas": "oanfrätt",
    "oanfrättast": "oanfrätt",
    "oanfrättaste": "oanfrätt",
    "oanfrättastes": "oanfrätt",
    "oanfrättasts": "oanfrätt",
    "oanfrätte": "oanfrätt",
    "oanfrättes": "oanfrätt",
    "oanfrättheten": "oanfrätthet",
    "oanfrätthetens": "oanfrätthet",
    "oanfrätthets": "oanfrätthet",
    "oanfrätts": "oanfrätt",
    "oanfäktade": "oanfäktad",
    "oanfäktades": "oanfäktad",
    "oanfäktads": "oanfäktad",
    "oanfäktat": "oanfäktad",
    "oanfäktats": "oanfäktad",
    "oanförde": "oanförd",
    "oanfördes": "oanförd",
    "oanförds": "oanförd",
    "oanfört": "oanförd",
    "oanförts": "oanförd",
    "oangenäma": "oangenäm",
    "oangenämare": "oangenäm",
    "oangenämares": "oangenäm",
    "oangenämas": "oangenäm",
    "oangenämast": "oangenäm",
    "oangenämaste": "oangenäm",
    "oangenämastes": "oangenäm",
    "oangenämasts": "oangenäm",
    "oangenäme": "oangenäm",
    "oangenämes": "oangenäm",
    "oangenämheten": "oangenämhet",
    "oangenämhetens": "oangenämhet",
    "oangenämhets": "oangenämhet",
    "oangenäms": "oangenäm",
    "oangenämt": "oangenäm",
    "oangenämts": "oangenäm",
    "oanglade": "oanglad",
    "oanglades": "oanglad",
    "oanglads": "oanglad",
    "oanglat": "oanglad",
    "oanglats": "oanglad",
    "oangliserade": "oangliserad",
    "oangliserades": "oangliserad",
    "oangliserads": "oangliserad",
    "oangliserat": "oangliserad",
    "oangliserats": "oangliserad",
    "oangliserbara": "oangliserbar",
    "oangliserbarare": "oangliserbar",
    "oangliserbarares": "oangliserbar",
    "oangliserbaras": "oangliserbar",
    "oangliserbarast": "oangliserbar",
    "oangliserbaraste": "oangliserbar",
    "oangliserbarastes": "oangliserbar",
    "oangliserbarasts": "oangliserbar",
    "oangliserbare": "oangliserbar",
    "oangliserbares": "oangliserbar",
    "oangliserbarheten": "oangliserbarhet",
    "oangliserbarhetens": "oangliserbarhet",
    "oangliserbarhets": "oangliserbarhet",
    "oangliserbars": "oangliserbar",
    "oangliserbart": "oangliserbar",
    "oangliserbarts": "oangliserbar",
    "oangripbara": "oangripbar",
    "oangripbarare": "oangripbar",
    "oangripbarares": "oangripbar",
    "oangripbaras": "oangripbar",
    "oangripbarast": "oangripbar",
    "oangripbaraste": "oangripbar",
    "oangripbarastes": "oangripbar",
    "oangripbarasts": "oangripbar",
    "oangripbare": "oangripbar",
    "oangripbares": "oangripbar",
    "oangripbarheten": "oangripbarhet",
    "oangripbarhetens": "oangripbarhet",
    "oangripbarhets": "oangripbarhet",
    "oangripbars": "oangripbar",
    "oangripbart": "oangripbar",
    "oangripbarts": "oangripbar",
    "oangripliga": "oangriplig",
    "oangripligare": "oangriplig",
    "oangripligares": "oangriplig",
    "oangripligas": "oangriplig",
    "oangripligast": "oangriplig",
    "oangripligaste": "oangriplig",
    "oangripligastes": "oangriplig",
    "oangripligasts": "oangriplig",
    "oangriplige": "oangriplig",
    "oangripliges": "oangriplig",
    "oangripligheten": "oangriplighet",
    "oangriplighetens": "oangriplighet",
    "oangriplighets": "oangriplighet",
    "oangripligs": "oangriplig",
    "oangripligt": "oangriplig",
    "oangripligts": "oangriplig",
    "oanhopade": "oanhopad",
    "oanhopades": "oanhopad",
    "oanhopads": "oanhopad",
    "oanhopat": "oanhopad",
    "oanhopats": "oanhopad",
    "oanimerade": "oanimerad",
    "oanimerades": "oanimerad",
    "oanimerads": "oanimerad",
    "oanimerat": "oanimerad",
    "oanimerats": "oanimerad",
    "oanimerbara": "oanimerbar",
    "oanimerbarare": "oanimerbar",
    "oanimerbarares": "oanimerbar",
    "oanimerbaras": "oanimerbar",
    "oanimerbarast": "oanimerbar",
    "oanimerbaraste": "oanimerbar",
    "oanimerbarastes": "oanimerbar",
    "oanimerbarasts": "oanimerbar",
    "oanimerbare": "oanimerbar",
    "oanimerbares": "oanimerbar",
    "oanimerbarheten": "oanimerbarhet",
    "oanimerbarhetens": "oanimerbarhet",
    "oanimerbarhets": "oanimerbarhet",
    "oanimerbars": "oanimerbar",
    "oanimerbart": "oanimerbar",
    "oanimerbarts": "oanimerbar",
    "oanklagade": "oanklagad",
    "oanklagades": "oanklagad",
    "oanklagads": "oanklagad",
    "oanklagat": "oanklagad",
    "oanklagats": "oanklagad",
    "oankrade": "oankrad",
    "oankrades": "oankrad",
    "oankrads": "oankrad",
    "oankrat": "oankrad",
    "oankrats": "oankrad",
    "oanlitade": "oanlitad",
    "oanlitades": "oanlitad",
    "oanlitads": "oanlitad",
    "oanlitat": "oanlitad",
    "oanlitats": "oanlitad",
    "oanlände": "oanländ",
    "oanländes": "oanländ",
    "oanländs": "oanländ",
    "oanlänt": "oanländ",
    "oanlänts": "oanländ",
    "oanlöpta": "oanlöpt",
    "oanlöptas": "oanlöpt",
    "oanlöpte": "oanlöpt",
    "oanlöptes": "oanlöpt",
    "oanlöpts": "oanlöpt",
    "oanmanade": "oanmanad",
    "oanmanades": "oanmanad",
    "oanmanads": "oanmanad",
    "oanmanat": "oanmanad",
    "oanmanats": "oanmanad",
    "oanmodade": "oanmodad",
    "oanmodades": "oanmodad",
    "oanmodads": "oanmodad",
    "oanmodat": "oanmodad",
    "oanmodats": "oanmodad",
    "oanmälda": "oanmäld",
    "oanmäldare": "oanmäld",
    "oanmäldares": "oanmäld",
    "oanmäldas": "oanmäld",
    "oanmäldast": "oanmäld",
    "oanmäldaste": "oanmäld",
    "oanmäldastes": "oanmäld",
    "oanmäldasts": "oanmäld",
    "oanmälde": "oanmäld",
    "oanmäldes": "oanmäld",
    "oanmälds": "oanmäld",
    "oanmält": "oanmäld",
    "oanmälts": "oanmäld",
    "oanmärkta": "oanmärkt",
    "oanmärktare": "oanmärkt",
    "oanmärktares": "oanmärkt",
    "oanmärktas": "oanmärkt",
    "oanmärktast": "oanmärkt",
    "oanmärktaste": "oanmärkt",
    "oanmärktastes": "oanmärkt",
    "oanmärktasts": "oanmärkt",
    "oanmärkte": "oanmärkt",
    "oanmärktes": "oanmärkt",
    "oanmärkts": "oanmärkt",
    "oannekterade": "oannekterad",
    "oannekterades": "oannekterad",
    "oannekterads": "oannekterad",
    "oannekterat": "oannekterad",
    "oannekterats": "oannekterad",
    "oannekterbara": "oannekterbar",
    "oannekterbarare": "oannekterbar",
    "oannekterbarares": "oannekterbar",
    "oannekterbaras": "oannekterbar",
    "oannekterbarast": "oannekterbar",
    "oannekterbaraste": "oannekterbar",
    "oannekterbarastes": "oannekterbar",
    "oannekterbarasts": "oannekterbar",
    "oannekterbare": "oannekterbar",
    "oannekterbares": "oannekterbar",
    "oannekterbarheten": "oannekterbarhet",
    "oannekterbarhetens": "oannekterbarhet",
    "oannekterbarhets": "oannekterbarhet",
    "oannekterbars": "oannekterbar",
    "oannekterbart": "oannekterbar",
    "oannekterbarts": "oannekterbar",
    "oannihilerade": "oannihilerad",
    "oannihilerades": "oannihilerad",
    "oannihilerads": "oannihilerad",
    "oannihilerat": "oannihilerad",
    "oannihilerats": "oannihilerad",
    "oannihilerbara": "oannihilerbar",
    "oannihilerbarare": "oannihilerbar",
    "oannihilerbarares": "oannihilerbar",
    "oannihilerbaras": "oannihilerbar",
    "oannihilerbarast": "oannihilerbar",
    "oannihilerbaraste": "oannihilerbar",
    "oannihilerbarastes": "oannihilerbar",
    "oannihilerbarasts": "oannihilerbar",
    "oannihilerbare": "oannihilerbar",
    "oannihilerbares": "oannihilerbar",
    "oannihilerbarheten": "oannihilerbarhet",
    "oannihilerbarhetens": "oannihilerbarhet",
    "oannihilerbarhets": "oannihilerbarhet",
    "oannihilerbars": "oannihilerbar",
    "oannihilerbart": "oannihilerbar",
    "oannihilerbarts": "oannihilerbar",
    "oannonserade": "oannonserad",
    "oannonserades": "oannonserad",
    "oannonserads": "oannonserad",
    "oannonserat": "oannonserad",
    "oannonserats": "oannonserad",
    "oannonserbara": "oannonserbar",
    "oannonserbarare": "oannonserbar",
    "oannonserbarares": "oannonserbar",
    "oannonserbaras": "oannonserbar",
    "oannonserbarast": "oannonserbar",
    "oannonserbaraste": "oannonserbar",
    "oannonserbarastes": "oannonserbar",
    "oannonserbarasts": "oannonserbar",
    "oannonserbare": "oannonserbar",
    "oannonserbares": "oannonserbar",
    "oannonserbarheten": "oannonserbarhet",
    "oannonserbarhetens": "oannonserbarhet",
    "oannonserbarhets": "oannonserbarhet",
    "oannonserbars": "oannonserbar",
    "oannonserbart": "oannonserbar",
    "oannonserbarts": "oannonserbar",
    "oannoterade": "oannoterad",
    "oannoterades": "oannoterad",
    "oannoterads": "oannoterad",
    "oannoterat": "oannoterad",
    "oannoterats": "oannoterad",
    "oannoterbara": "oannoterbar",
    "oannoterbarare": "oannoterbar",
    "oannoterbarares": "oannoterbar",
    "oannoterbaras": "oannoterbar",
    "oannoterbarast": "oannoterbar",
    "oannoterbaraste": "oannoterbar",
    "oannoterbarastes": "oannoterbar",
    "oannoterbarasts": "oannoterbar",
    "oannoterbare": "oannoterbar",
    "oannoterbares": "oannoterbar",
    "oannoterbarheten": "oannoterbarhet",
    "oannoterbarhetens": "oannoterbarhet",
    "oannoterbarhets": "oannoterbarhet",
    "oannoterbars": "oannoterbar",
    "oannoterbart": "oannoterbar",
    "oannoterbarts": "oannoterbar",
    "oannullerade": "oannullerad",
    "oannullerades": "oannullerad",
    "oannullerads": "oannullerad",
    "oannullerat": "oannullerad",
    "oannullerats": "oannullerad",
    "oannullerbara": "oannullerbar",
    "oannullerbarare": "oannullerbar",
    "oannullerbarares": "oannullerbar",
    "oannullerbaras": "oannullerbar",
    "oannullerbarast": "oannullerbar",
    "oannullerbaraste": "oannullerbar",
    "oannullerbarastes": "oannullerbar",
    "oannullerbarasts": "oannullerbar",
    "oannullerbare": "oannullerbar",
    "oannullerbares": "oannullerbar",
    "oannullerbarheten": "oannullerbarhet",
    "oannullerbarhetens": "oannullerbarhet",
    "oannullerbarhets": "oannullerbarhet",
    "oannullerbars": "oannullerbar",
    "oannullerbart": "oannullerbar",
    "oannullerbarts": "oannullerbar",
    "oanodiserade": "oanodiserad",
    "oanodiserades": "oanodiserad",
    "oanodiserads": "oanodiserad",
    "oanodiserat": "oanodiserad",
    "oanodiserats": "oanodiserad",
    "oanodiserbara": "oanodiserbar",
    "oanodiserbarare": "oanodiserbar",
    "oanodiserbarares": "oanodiserbar",
    "oanodiserbaras": "oanodiserbar",
    "oanodiserbarast": "oanodiserbar",
    "oanodiserbaraste": "oanodiserbar",
    "oanodiserbarastes": "oanodiserbar",
    "oanodiserbarasts": "oanodiserbar",
    "oanodiserbare": "oanodiserbar",
    "oanodiserbares": "oanodiserbar",
    "oanodiserbarheten": "oanodiserbarhet",
    "oanodiserbarhetens": "oanodiserbarhet",
    "oanodiserbarhets": "oanodiserbarhet",
    "oanodiserbars": "oanodiserbar",
    "oanodiserbart": "oanodiserbar",
    "oanodiserbarts": "oanodiserbar",
    "oanonymiserade": "oanonymiserad",
    "oanonymiserades": "oanonymiserad",
    "oanonymiserads": "oanonymiserad",
    "oanonymiserat": "oanonymiserad",
    "oanonymiserats": "oanonymiserad",
    "oanonymiserbara": "oanonymiserbar",
    "oanonymiserbarare": "oanonymiserbar",
    "oanonymiserbarares": "oanonymiserbar",
    "oanonymiserbaras": "oanonymiserbar",
    "oanonymiserbarast": "oanonymiserbar",
    "oanonymiserbaraste": "oanonymiserbar",
    "oanonymiserbarastes": "oanonymiserbar",
    "oanonymiserbarasts": "oanonymiserbar",
    "oanonymiserbare": "oanonymiserbar",
    "oanonymiserbares": "oanonymiserbar",
    "oanonymiserbarheten": "oanonymiserbarhet",
    "oanonymiserbarhetens": "oanonymiserbarhet",
    "oanonymiserbarhets": "oanonymiserbarhet",
    "oanonymiserbars": "oanonymiserbar",
    "oanonymiserbart": "oanonymiserbar",
    "oanonymiserbarts": "oanonymiserbar",
    "oanordnade": "oanordnad",
    "oanordnades": "oanordnad",
    "oanordnads": "oanordnad",
    "oanordnat": "oanordnad",
    "oanordnats": "oanordnad",
    "oanpassade": "oanpassad",
    "oanpassades": "oanpassad",
    "oanpassads": "oanpassad",
    "oanpassat": "oanpassad",
    "oanpassats": "oanpassad",
    "oanrikade": "oanrikad",
    "oanrikades": "oanrikad",
    "oanrikads": "oanrikad",
    "oanrikat": "oanrikad",
    "oanrikats": "oanrikad",
    "oanropade": "oanropad",
    "oanropades": "oanropad",
    "oanropads": "oanropad",
    "oanropat": "oanropad",
    "oanropats": "oanropad",
    "oanrättade": "oanrättad",
    "oanrättades": "oanrättad",
    "oanrättads": "oanrättad",
    "oanrättat": "oanrättad",
    "oanrättats": "oanrättad",
    "oansade": "oansad",
    "oansades": "oansad",
    "oansads": "oansad",
    "oansamlade": "oansamlad",
    "oansamlades": "oansamlad",
    "oansamlads": "oansamlad",
    "oansamlat": "oansamlad",
    "oansamlats": "oansamlad",
    "oansat": "oansad",
    "oansats": "oansad",
    "oansenliga": "oansenlig",
    "oansenligare": "oansenlig",
    "oansenligares": "oansenlig",
    "oansenligas": "oansenlig",
    "oansenligast": "oansenlig",
    "oansenligaste": "oansenlig",
    "oansenligastes": "oansenlig",
    "oansenligasts": "oansenlig",
    "oansenlige": "oansenlig",
    "oansenliges": "oansenlig",
    "oansenligheten": "oansenlighet",
    "oansenlighetens": "oansenlighet",
    "oansenlighets": "oansenlighet",
    "oansenligs": "oansenlig",
    "oansenligt": "oansenlig",
    "oansenligts": "oansenlig",
    "oanskaffade": "oanskaffad",
    "oanskaffades": "oanskaffad",
    "oanskaffads": "oanskaffad",
    "oanskaffat": "oanskaffad",
    "oanskaffats": "oanskaffad",
    "oanspelade": "oanspelad",
    "oanspelades": "oanspelad",
    "oanspelads": "oanspelad",
    "oanspelat": "oanspelad",
    "oanspelats": "oanspelad",
    "oanstiftade": "oanstiftad",
    "oanstiftades": "oanstiftad",
    "oanstiftads": "oanstiftad",
    "oanstiftat": "oanstiftad",
    "oanstiftats": "oanstiftad",
    "oanstormade": "oanstormad",
    "oanstormades": "oanstormad",
    "oanstormads": "oanstormad",
    "oanstormat": "oanstormad",
    "oanstormats": "oanstormad",
    "oansträngde": "oansträngd",
    "oansträngdes": "oansträngd",
    "oansträngds": "oansträngd",
    "oansträngt": "oansträngd",
    "oansträngts": "oansträngd",
    "oanställde": "oanställd",
    "oanställdes": "oanställd",
    "oanställds": "oanställd",
    "oanställt": "oanställd",
    "oanställts": "oanställd",
    "oanständiga": "oanständig",
    "oanständigare": "oanständig",
    "oanständigares": "oanständig",
    "oanständigas": "oanständig",
    "oanständigast": "oanständig",
    "oanständigaste": "oanständig",
    "oanständigastes": "oanständig",
    "oanständigasts": "oanständig",
    "oanständige": "oanständig",
    "oanständiges": "oanständig",
    "oanständigheten": "oanständighet",
    "oanständighetens": "oanständighet",
    "oanständigheter": "oanständighet",
    "oanständigheterna": "oanständighet",
    "oanständigheternas": "oanständighet",
    "oanständigheters": "oanständighet",
    "oanständighets": "oanständighet",
    "oanständigs": "oanständig",
    "oanständigt": "oanständig",
    "oanständigts": "oanständig",
    "oansvariga": "oansvarig",
    "oansvarigare": "oansvarig",
    "oansvarigares": "oansvarig",
    "oansvarigas": "oansvarig",
    "oansvarigast": "oansvarig",
    "oansvarigaste": "oansvarig",
    "oansvarigastes": "oansvarig",
    "oansvarigasts": "oansvarig",
    "oansvarige": "oansvarig",
    "oansvariges": "oansvarig",
    "oansvarigheten": "oansvarighet",
    "oansvarighetens": "oansvarighet",
    "oansvarighets": "oansvarighet",
    "oansvarigs": "oansvarig",
    "oansvarigt": "oansvarig",
    "oansvarigts": "oansvarig",
    "oansvällde": "oansvälld",
    "oansvälldes": "oansvälld",
    "oansvällds": "oansvälld",
    "oansvällt": "oansvälld",
    "oansvällts": "oansvälld",
    "oansökta": "oansökt",
    "oansöktas": "oansökt",
    "oansökte": "oansökt",
    "oansöktes": "oansökt",
    "oansökts": "oansökt",
    "oantagbara": "oantagbar",
    "oantagbarare": "oantagbar",
    "oantagbarares": "oantagbar",
    "oantagbaras": "oantagbar",
    "oantagbarast": "oantagbar",
    "oantagbaraste": "oantagbar",
    "oantagbarastes": "oantagbar",
    "oantagbarasts": "oantagbar",
    "oantagbare": "oantagbar",
    "oantagbares": "oantagbar",
    "oantagbarheten": "oantagbarhet",
    "oantagbarhetens": "oantagbarhet",
    "oantagbarhets": "oantagbarhet",
    "oantagbars": "oantagbar",
    "oantagbart": "oantagbar",
    "oantagbarts": "oantagbar",
    "oantagliga": "oantaglig",
    "oantagligare": "oantaglig",
    "oantagligares": "oantaglig",
    "oantagligas": "oantaglig",
    "oantagligast": "oantaglig",
    "oantagligaste": "oantaglig",
    "oantagligastes": "oantaglig",
    "oantagligasts": "oantaglig",
    "oantaglige": "oantaglig",
    "oantagliges": "oantaglig",
    "oantagligheten": "oantaglighet",
    "oantaglighetens": "oantaglighet",
    "oantaglighets": "oantaglighet",
    "oantagligs": "oantaglig",
    "oantagligt": "oantaglig",
    "oantagligts": "oantaglig",
    "oantastade": "oantastad",
    "oantastades": "oantastad",
    "oantastads": "oantastad",
    "oantastat": "oantastad",
    "oantastats": "oantastad",
    "oantastliga": "oantastlig",
    "oantastligare": "oantastlig",
    "oantastligares": "oantastlig",
    "oantastligas": "oantastlig",
    "oantastligast": "oantastlig",
    "oantastligaste": "oantastlig",
    "oantastligastes": "oantastlig",
    "oantastligasts": "oantastlig",
    "oantastlige": "oantastlig",
    "oantastliges": "oantastlig",
    "oantastligheten": "oantastlighet",
    "oantastlighetens": "oantastlighet",
    "oantastlighets": "oantastlighet",
    "oantastligs": "oantastlig",
    "oantastligt": "oantastlig",
    "oantastligts": "oantastlig",
    "oanteciperade": "oanteciperad",
    "oanteciperades": "oanteciperad",
    "oanteciperads": "oanteciperad",
    "oanteciperat": "oanteciperad",
    "oanteciperats": "oanteciperad",
    "oanteciperbara": "oanteciperbar",
    "oanteciperbarare": "oanteciperbar",
    "oanteciperbarares": "oanteciperbar",
    "oanteciperbaras": "oanteciperbar",
    "oanteciperbarast": "oanteciperbar",
    "oanteciperbaraste": "oanteciperbar",
    "oanteciperbarastes": "oanteciperbar",
    "oanteciperbarasts": "oanteciperbar",
    "oanteciperbare": "oanteciperbar",
    "oanteciperbares": "oanteciperbar",
    "oanteciperbarheten": "oanteciperbarhet",
    "oanteciperbarhetens": "oanteciperbarhet",
    "oanteciperbarhets": "oanteciperbarhet",
    "oanteciperbars": "oanteciperbar",
    "oanteciperbart": "oanteciperbar",
    "oanteciperbarts": "oanteciperbar",
    "oantecknade": "oantecknad",
    "oantecknades": "oantecknad",
    "oantecknads": "oantecknad",
    "oantecknat": "oantecknad",
    "oantecknats": "oantecknad",
    "oantedaterade": "oantedaterad",
    "oantedaterades": "oantedaterad",
    "oantedaterads": "oantedaterad",
    "oantedaterat": "oantedaterad",
    "oantedaterats": "oantedaterad",
    "oantedaterbara": "oantedaterbar",
    "oantedaterbarare": "oantedaterbar",
    "oantedaterbarares": "oantedaterbar",
    "oantedaterbaras": "oantedaterbar",
    "oantedaterbarast": "oantedaterbar",
    "oantedaterbaraste": "oantedaterbar",
    "oantedaterbarastes": "oantedaterbar",
    "oantedaterbarasts": "oantedaterbar",
    "oantedaterbare": "oantedaterbar",
    "oantedaterbares": "oantedaterbar",
    "oantedaterbarheten": "oantedaterbarhet",
    "oantedaterbarhetens": "oantedaterbarhet",
    "oantedaterbarhets": "oantedaterbarhet",
    "oantedaterbars": "oantedaterbar",
    "oantedaterbart": "oantedaterbar",
    "oantedaterbarts": "oantedaterbar",
    "oantichambrerade": "oantichambrerad",
    "oantichambrerades": "oantichambrerad",
    "oantichambrerads": "oantichambrerad",
    "oantichambrerat": "oantichambrerad",
    "oantichambrerats": "oantichambrerad",
    "oantichambrerbara": "oantichambrerbar",
    "oantichambrerbarare": "oantichambrerbar",
    "oantichambrerbarares": "oantichambrerbar",
    "oantichambrerbaras": "oantichambrerbar",
    "oantichambrerbarast": "oantichambrerbar",
    "oantichambrerbaraste": "oantichambrerbar",
    "oantichambrerbarastes": "oantichambrerbar",
    "oantichambrerbarasts": "oantichambrerbar",
    "oantichambrerbare": "oantichambrerbar",
    "oantichambrerbares": "oantichambrerbar",
    "oantichambrerbarheten": "oantichambrerbarhet",
    "oantichambrerbarhetens": "oantichambrerbarhet",
    "oantichambrerbarhets": "oantichambrerbarhet",
    "oantichambrerbars": "oantichambrerbar",
    "oantichambrerbart": "oantichambrerbar",
    "oantichambrerbarts": "oantichambrerbar",
    "oantikiserade": "oantikiserad",
    "oantikiserades": "oantikiserad",
    "oantikiserads": "oantikiserad",
    "oantikiserat": "oantikiserad",
    "oantikiserats": "oantikiserad",
    "oantikiserbara": "oantikiserbar",
    "oantikiserbarare": "oantikiserbar",
    "oantikiserbarares": "oantikiserbar",
    "oantikiserbaras": "oantikiserbar",
    "oantikiserbarast": "oantikiserbar",
    "oantikiserbaraste": "oantikiserbar",
    "oantikiserbarastes": "oantikiserbar",
    "oantikiserbarasts": "oantikiserbar",
    "oantikiserbare": "oantikiserbar",
    "oantikiserbares": "oantikiserbar",
    "oantikiserbarheten": "oantikiserbarhet",
    "oantikiserbarhetens": "oantikiserbarhet",
    "oantikiserbarhets": "oantikiserbarhet",
    "oantikiserbars": "oantikiserbar",
    "oantikiserbart": "oantikiserbar",
    "oantikiserbarts": "oantikiserbar",
    "oanträffade": "oanträffad",
    "oanträffades": "oanträffad",
    "oanträffads": "oanträffad",
    "oanträffat": "oanträffad",
    "oanträffats": "oanträffad",
    "oanträffbara": "oanträffbar",
    "oanträffbarare": "oanträffbar",
    "oanträffbarares": "oanträffbar",
    "oanträffbaras": "oanträffbar",
    "oanträffbarast": "oanträffbar",
    "oanträffbaraste": "oanträffbar",
    "oanträffbarastes": "oanträffbar",
    "oanträffbarasts": "oanträffbar",
    "oanträffbare": "oanträffbar",
    "oanträffbares": "oanträffbar",
    "oanträffbarheten": "oanträffbarhet",
    "oanträffbarhetens": "oanträffbarhet",
    "oanträffbarhets": "oanträffbarhet",
    "oanträffbars": "oanträffbar",
    "oanträffbart": "oanträffbar",
    "oanträffbarts": "oanträffbar",
    "oantvardade": "oantvardad",
    "oantvardades": "oantvardad",
    "oantvardads": "oantvardad",
    "oantvardat": "oantvardad",
    "oantvardats": "oantvardad",
    "oantände": "oantänd",
    "oantändes": "oantänd",
    "oantänds": "oantänd",
    "oantänt": "oantänd",
    "oantänts": "oantänd",
    "oantågade": "oantågad",
    "oantågades": "oantågad",
    "oantågads": "oantågad",
    "oantågat": "oantågad",
    "oantågats": "oantågad",
    "oanvisade": "oanvisad",
    "oanvisades": "oanvisad",
    "oanvisads": "oanvisad",
    "oanvisat": "oanvisad",
    "oanvisats": "oanvisad",
    "oanvända": "oanvänd",
    "oanvändare": "oanvänd",
    "oanvändares": "oanvänd",
    "oanvändas": "oanvänd",
    "oanvändast": "oanvänd",
    "oanvändaste": "oanvänd",
    "oanvändastes": "oanvänd",
    "oanvändasts": "oanvänd",
    "oanvändbara": "oanvändbar",
    "oanvändbarare": "oanvändbar",
    "oanvändbarares": "oanvändbar",
    "oanvändbaras": "oanvändbar",
    "oanvändbarast": "oanvändbar",
    "oanvändbaraste": "oanvändbar",
    "oanvändbarastes": "oanvändbar",
    "oanvändbarasts": "oanvändbar",
    "oanvändbare": "oanvändbar",
    "oanvändbares": "oanvändbar",
    "oanvändbarheten": "oanvändbarhet",
    "oanvändbarhetens": "oanvändbarhet",
    "oanvändbarhets": "oanvändbarhet",
    "oanvändbars": "oanvändbar",
    "oanvändbart": "oanvändbar",
    "oanvändbarts": "oanvändbar",
    "oanvände": "oanvänd",
    "oanvändes": "oanvänd",
    "oanvänds": "oanvänd",
    "oanvänt": "oanvänd",
    "oanvänts": "oanvänd",
    "oapostroferade": "oapostroferad",
    "oapostroferades": "oapostroferad",
    "oapostroferads": "oapostroferad",
    "oapostroferat": "oapostroferad",
    "oapostroferats": "oapostroferad",
    "oapostroferbara": "oapostroferbar",
    "oapostroferbarare": "oapostroferbar",
    "oapostroferbarares": "oapostroferbar",
    "oapostroferbaras": "oapostroferbar",
    "oapostroferbarast": "oapostroferbar",
    "oapostroferbaraste": "oapostroferbar",
    "oapostroferbarastes": "oapostroferbar",
    "oapostroferbarasts": "oapostroferbar",
    "oapostroferbare": "oapostroferbar",
    "oapostroferbares": "oapostroferbar",
    "oapostroferbarheten": "oapostroferbarhet",
    "oapostroferbarhetens": "oapostroferbarhet",
    "oapostroferbarhets": "oapostroferbarhet",
    "oapostroferbars": "oapostroferbar",
    "oapostroferbart": "oapostroferbar",
    "oapostroferbarts": "oapostroferbar",
    "oappellerade": "oappellerad",
    "oappellerades": "oappellerad",
    "oappellerads": "oappellerad",
    "oappellerat": "oappellerad",
    "oappellerats": "oappellerad",
    "oappellerbara": "oappellerbar",
    "oappellerbarare": "oappellerbar",
    "oappellerbarares": "oappellerbar",
    "oappellerbaras": "oappellerbar",
    "oappellerbarast": "oappellerbar",
    "oappellerbaraste": "oappellerbar",
    "oappellerbarastes": "oappellerbar",
    "oappellerbarasts": "oappellerbar",
    "oappellerbare": "oappellerbar",
    "oappellerbares": "oappellerbar",
    "oappellerbarheten": "oappellerbarhet",
    "oappellerbarhetens": "oappellerbarhet",
    "oappellerbarhets": "oappellerbarhet",
    "oappellerbars": "oappellerbar",
    "oappellerbart": "oappellerbar",
    "oappellerbarts": "oappellerbar",
    "oapplicerade": "oapplicerad",
    "oapplicerades": "oapplicerad",
    "oapplicerads": "oapplicerad",
    "oapplicerat": "oapplicerad",
    "oapplicerats": "oapplicerad",
    "oapplicerbara": "oapplicerbar",
    "oapplicerbarare": "oapplicerbar",
    "oapplicerbarares": "oapplicerbar",
    "oapplicerbaras": "oapplicerbar",
    "oapplicerbarast": "oapplicerbar",
    "oapplicerbaraste": "oapplicerbar",
    "oapplicerbarastes": "oapplicerbar",
    "oapplicerbarasts": "oapplicerbar",
    "oapplicerbare": "oapplicerbar",
    "oapplicerbares": "oapplicerbar",
    "oapplicerbarheten": "oapplicerbarhet",
    "oapplicerbarhetens": "oapplicerbarhet",
    "oapplicerbarhets": "oapplicerbarhet",
    "oapplicerbars": "oapplicerbar",
    "oapplicerbart": "oapplicerbar",
    "oapplicerbarts": "oapplicerbar",
    "oapplåderade": "oapplåderad",
    "oapplåderades": "oapplåderad",
    "oapplåderads": "oapplåderad",
    "oapplåderat": "oapplåderad",
    "oapplåderats": "oapplåderad",
    "oapplåderbara": "oapplåderbar",
    "oapplåderbarare": "oapplåderbar",
    "oapplåderbarares": "oapplåderbar",
    "oapplåderbaras": "oapplåderbar",
    "oapplåderbarast": "oapplåderbar",
    "oapplåderbaraste": "oapplåderbar",
    "oapplåderbarastes": "oapplåderbar",
    "oapplåderbarasts": "oapplåderbar",
    "oapplåderbare": "oapplåderbar",
    "oapplåderbares": "oapplåderbar",
    "oapplåderbarheten": "oapplåderbarhet",
    "oapplåderbarhetens": "oapplåderbarhet",
    "oapplåderbarhets": "oapplåderbarhet",
    "oapplåderbars": "oapplåderbar",
    "oapplåderbart": "oapplåderbar",
    "oapplåderbarts": "oapplåderbar",
    "oapporterade": "oapporterad",
    "oapporterades": "oapporterad",
    "oapporterads": "oapporterad",
    "oapporterat": "oapporterad",
    "oapporterats": "oapporterad",
    "oapporterbara": "oapporterbar",
    "oapporterbarare": "oapporterbar",
    "oapporterbarares": "oapporterbar",
    "oapporterbaras": "oapporterbar",
    "oapporterbarast": "oapporterbar",
    "oapporterbaraste": "oapporterbar",
    "oapporterbarastes": "oapporterbar",
    "oapporterbarasts": "oapporterbar",
    "oapporterbare": "oapporterbar",
    "oapporterbares": "oapporterbar",
    "oapporterbarheten": "oapporterbarhet",
    "oapporterbarhetens": "oapporterbarhet",
    "oapporterbarhets": "oapporterbarhet",
    "oapporterbars": "oapporterbar",
    "oapporterbart": "oapporterbar",
    "oapporterbarts": "oapporterbar",
    "oapprecierade": "oapprecierad",
    "oapprecierades": "oapprecierad",
    "oapprecierads": "oapprecierad",
    "oapprecierat": "oapprecierad",
    "oapprecierats": "oapprecierad",
    "oapprecierbara": "oapprecierbar",
    "oapprecierbarare": "oapprecierbar",
    "oapprecierbarares": "oapprecierbar",
    "oapprecierbaras": "oapprecierbar",
    "oapprecierbarast": "oapprecierbar",
    "oapprecierbaraste": "oapprecierbar",
    "oapprecierbarastes": "oapprecierbar",
    "oapprecierbarasts": "oapprecierbar",
    "oapprecierbare": "oapprecierbar",
    "oapprecierbares": "oapprecierbar",
    "oapprecierbarheten": "oapprecierbarhet",
    "oapprecierbarhetens": "oapprecierbarhet",
    "oapprecierbarhets": "oapprecierbarhet",
    "oapprecierbars": "oapprecierbar",
    "oapprecierbart": "oapprecierbar",
    "oapprecierbarts": "oapprecierbar",
    "oappreterade": "oappreterad",
    "oappreterades": "oappreterad",
    "oappreterads": "oappreterad",
    "oappreterat": "oappreterad",
    "oappreterats": "oappreterad",
    "oappreterbara": "oappreterbar",
    "oappreterbarare": "oappreterbar",
    "oappreterbarares": "oappreterbar",
    "oappreterbaras": "oappreterbar",
    "oappreterbarast": "oappreterbar",
    "oappreterbaraste": "oappreterbar",
    "oappreterbarastes": "oappreterbar",
    "oappreterbarasts": "oappreterbar",
    "oappreterbare": "oappreterbar",
    "oappreterbares": "oappreterbar",
    "oappreterbarheten": "oappreterbarhet",
    "oappreterbarhetens": "oappreterbarhet",
    "oappreterbarhets": "oappreterbarhet",
    "oappreterbars": "oappreterbar",
    "oappreterbart": "oappreterbar",
    "oappreterbarts": "oappreterbar",
    "oapprocherade": "oapprocherad",
    "oapprocherades": "oapprocherad",
    "oapprocherads": "oapprocherad",
    "oapprocherat": "oapprocherad",
    "oapprocherats": "oapprocherad",
    "oapprocherbara": "oapprocherbar",
    "oapprocherbarare": "oapprocherbar",
    "oapprocherbarares": "oapprocherbar",
    "oapprocherbaras": "oapprocherbar",
    "oapprocherbarast": "oapprocherbar",
    "oapprocherbaraste": "oapprocherbar",
    "oapprocherbarastes": "oapprocherbar",
    "oapprocherbarasts": "oapprocherbar",
    "oapprocherbare": "oapprocherbar",
    "oapprocherbares": "oapprocherbar",
    "oapprocherbarheten": "oapprocherbarhet",
    "oapprocherbarhetens": "oapprocherbarhet",
    "oapprocherbarhets": "oapprocherbarhet",
    "oapprocherbars": "oapprocherbar",
    "oapprocherbart": "oapprocherbar",
    "oapprocherbarts": "oapprocherbar",
    "oapproximerade": "oapproximerad",
    "oapproximerades": "oapproximerad",
    "oapproximerads": "oapproximerad",
    "oapproximerat": "oapproximerad",
    "oapproximerats": "oapproximerad",
    "oapproximerbara": "oapproximerbar",
    "oapproximerbarare": "oapproximerbar",
    "oapproximerbarares": "oapproximerbar",
    "oapproximerbaras": "oapproximerbar",
    "oapproximerbarast": "oapproximerbar",
    "oapproximerbaraste": "oapproximerbar",
    "oapproximerbarastes": "oapproximerbar",
    "oapproximerbarasts": "oapproximerbar",
    "oapproximerbare": "oapproximerbar",
    "oapproximerbares": "oapproximerbar",
    "oapproximerbarheten": "oapproximerbarhet",
    "oapproximerbarhetens": "oapproximerbarhet",
    "oapproximerbarhets": "oapproximerbarhet",
    "oapproximerbars": "oapproximerbar",
    "oapproximerbart": "oapproximerbar",
    "oapproximerbarts": "oapproximerbar",
    "oapterade": "oapterad",
    "oapterades": "oapterad",
    "oapterads": "oapterad",
    "oapterat": "oapterad",
    "oapterats": "oapterad",
    "oapterbara": "oapterbar",
    "oapterbarare": "oapterbar",
    "oapterbarares": "oapterbar",
    "oapterbaras": "oapterbar",
    "oapterbarast": "oapterbar",
    "oapterbaraste": "oapterbar",
    "oapterbarastes": "oapterbar",
    "oapterbarasts": "oapterbar",
    "oapterbare": "oapterbar",
    "oapterbares": "oapterbar",
    "oapterbarheten": "oapterbarhet",
    "oapterbarhetens": "oapterbarhet",
    "oapterbarhets": "oapterbarhet",
    "oapterbars": "oapterbar",
    "oapterbart": "oapterbar",
    "oapterbarts": "oapterbar",
    "oaptitliga": "oaptitlig",
    "oaptitligare": "oaptitlig",
    "oaptitligares": "oaptitlig",
    "oaptitligas": "oaptitlig",
    "oaptitligast": "oaptitlig",
    "oaptitligaste": "oaptitlig",
    "oaptitligastes": "oaptitlig",
    "oaptitligasts": "oaptitlig",
    "oaptitlige": "oaptitlig",
    "oaptitliges": "oaptitlig",
    "oaptitligheten": "oaptitlighet",
    "oaptitlighetens": "oaptitlighet",
    "oaptitlighets": "oaptitlighet",
    "oaptitligs": "oaptitlig",
    "oaptitligt": "oaptitlig",
    "oaptitligts": "oaptitlig",
    "oarbetade": "oarbetad",
    "oarbetades": "oarbetad",
    "oarbetads": "oarbetad",
    "oarbetat": "oarbetad",
    "oarbetats": "oarbetad",
    "oargumenterade": "oargumenterad",
    "oargumenterades": "oargumenterad",
    "oargumenterads": "oargumenterad",
    "oargumenterat": "oargumenterad",
    "oargumenterats": "oargumenterad",
    "oargumenterbara": "oargumenterbar",
    "oargumenterbarare": "oargumenterbar",
    "oargumenterbarares": "oargumenterbar",
    "oargumenterbaras": "oargumenterbar",
    "oargumenterbarast": "oargumenterbar",
    "oargumenterbaraste": "oargumenterbar",
    "oargumenterbarastes": "oargumenterbar",
    "oargumenterbarasts": "oargumenterbar",
    "oargumenterbare": "oargumenterbar",
    "oargumenterbares": "oargumenterbar",
    "oargumenterbarheten": "oargumenterbarhet",
    "oargumenterbarhetens": "oargumenterbarhet",
    "oargumenterbarhets": "oargumenterbarhet",
    "oargumenterbars": "oargumenterbar",
    "oargumenterbart": "oargumenterbar",
    "oargumenterbarts": "oargumenterbar",
    "oarkaiserade": "oarkaiserad",
    "oarkaiserades": "oarkaiserad",
    "oarkaiserads": "oarkaiserad",
    "oarkaiserat": "oarkaiserad",
    "oarkaiserats": "oarkaiserad",
    "oarkaiserbara": "oarkaiserbar",
    "oarkaiserbarare": "oarkaiserbar",
    "oarkaiserbarares": "oarkaiserbar",
    "oarkaiserbaras": "oarkaiserbar",
    "oarkaiserbarast": "oarkaiserbar",
    "oarkaiserbaraste": "oarkaiserbar",
    "oarkaiserbarastes": "oarkaiserbar",
    "oarkaiserbarasts": "oarkaiserbar",
    "oarkaiserbare": "oarkaiserbar",
    "oarkaiserbares": "oarkaiserbar",
    "oarkaiserbarheten": "oarkaiserbarhet",
    "oarkaiserbarhetens": "oarkaiserbarhet",
    "oarkaiserbarhets": "oarkaiserbarhet",
    "oarkaiserbars": "oarkaiserbar",
    "oarkaiserbart": "oarkaiserbar",
    "oarkaiserbarts": "oarkaiserbar",
    "oarkebuserade": "oarkebuserad",
    "oarkebuserades": "oarkebuserad",
    "oarkebuserads": "oarkebuserad",
    "oarkebuserat": "oarkebuserad",
    "oarkebuserats": "oarkebuserad",
    "oarkebuserbara": "oarkebuserbar",
    "oarkebuserbarare": "oarkebuserbar",
    "oarkebuserbarares": "oarkebuserbar",
    "oarkebuserbaras": "oarkebuserbar",
    "oarkebuserbarast": "oarkebuserbar",
    "oarkebuserbaraste": "oarkebuserbar",
    "oarkebuserbarastes": "oarkebuserbar",
    "oarkebuserbarasts": "oarkebuserbar",
    "oarkebuserbare": "oarkebuserbar",
    "oarkebuserbares": "oarkebuserbar",
    "oarkebuserbarheten": "oarkebuserbarhet",
    "oarkebuserbarhetens": "oarkebuserbarhet",
    "oarkebuserbarhets": "oarkebuserbarhet",
    "oarkebuserbars": "oarkebuserbar",
    "oarkebuserbart": "oarkebuserbar",
    "oarkebuserbarts": "oarkebuserbar",
    "oarkiverade": "oarkiverad",
    "oarkiverades": "oarkiverad",
    "oarkiverads": "oarkiverad",
    "oarkiverat": "oarkiverad",
    "oarkiverats": "oarkiverad",
    "oarkiverbara": "oarkiverbar",
    "oarkiverbarare": "oarkiverbar",
    "oarkiverbarares": "oarkiverbar",
    "oarkiverbaras": "oarkiverbar",
    "oarkiverbarast": "oarkiverbar",
    "oarkiverbaraste": "oarkiverbar",
    "oarkiverbarastes": "oarkiverbar",
    "oarkiverbarasts": "oarkiverbar",
    "oarkiverbare": "oarkiverbar",
    "oarkiverbares": "oarkiverbar",
    "oarkiverbarheten": "oarkiverbarhet",
    "oarkiverbarhetens": "oarkiverbarhet",
    "oarkiverbarhets": "oarkiverbarhet",
    "oarkiverbars": "oarkiverbar",
    "oarkiverbart": "oarkiverbar",
    "oarkiverbarts": "oarkiverbar",
    "oarmerade": "oarmerad",
    "oarmerades": "oarmerad",
    "oarmerads": "oarmerad",
    "oarmerat": "oarmerad",
    "oarmerats": "oarmerad",
    "oarmerbara": "oarmerbar",
    "oarmerbarare": "oarmerbar",
    "oarmerbarares": "oarmerbar",
    "oarmerbaras": "oarmerbar",
    "oarmerbarast": "oarmerbar",
    "oarmerbaraste": "oarmerbar",
    "oarmerbarastes": "oarmerbar",
    "oarmerbarasts": "oarmerbar",
    "oarmerbare": "oarmerbar",
    "oarmerbares": "oarmerbar",
    "oarmerbarheten": "oarmerbarhet",
    "oarmerbarhetens": "oarmerbarhet",
    "oarmerbarhets": "oarmerbarhet",
    "oarmerbars": "oarmerbar",
    "oarmerbart": "oarmerbar",
    "oarmerbarts": "oarmerbar",
    "oarrangerade": "oarrangerad",
    "oarrangerades": "oarrangerad",
    "oarrangerads": "oarrangerad",
    "oarrangerat": "oarrangerad",
    "oarrangerats": "oarrangerad",
    "oarrangerbara": "oarrangerbar",
    "oarrangerbarare": "oarrangerbar",
    "oarrangerbarares": "oarrangerbar",
    "oarrangerbaras": "oarrangerbar",
    "oarrangerbarast": "oarrangerbar",
    "oarrangerbaraste": "oarrangerbar",
    "oarrangerbarastes": "oarrangerbar",
    "oarrangerbarasts": "oarrangerbar",
    "oarrangerbare": "oarrangerbar",
    "oarrangerbares": "oarrangerbar",
    "oarrangerbarheten": "oarrangerbarhet",
    "oarrangerbarhetens": "oarrangerbarhet",
    "oarrangerbarhets": "oarrangerbarhet",
    "oarrangerbars": "oarrangerbar",
    "oarrangerbart": "oarrangerbar",
    "oarrangerbarts": "oarrangerbar",
    "oarrenderade": "oarrenderad",
    "oarrenderades": "oarrenderad",
    "oarrenderads": "oarrenderad",
    "oarrenderat": "oarrenderad",
    "oarrenderats": "oarrenderad",
    "oarrenderbara": "oarrenderbar",
    "oarrenderbarare": "oarrenderbar",
    "oarrenderbarares": "oarrenderbar",
    "oarrenderbaras": "oarrenderbar",
    "oarrenderbarast": "oarrenderbar",
    "oarrenderbaraste": "oarrenderbar",
    "oarrenderbarastes": "oarrenderbar",
    "oarrenderbarasts": "oarrenderbar",
    "oarrenderbare": "oarrenderbar",
    "oarrenderbares": "oarrenderbar",
    "oarrenderbarheten": "oarrenderbarhet",
    "oarrenderbarhetens": "oarrenderbarhet",
    "oarrenderbarhets": "oarrenderbarhet",
    "oarrenderbars": "oarrenderbar",
    "oarrenderbart": "oarrenderbar",
    "oarrenderbarts": "oarrenderbar",
    "oarresterade": "oarresterad",
    "oarresterades": "oarresterad",
    "oarresterads": "oarresterad",
    "oarresterat": "oarresterad",
    "oarresterats": "oarresterad",
    "oarresterbara": "oarresterbar",
    "oarresterbarare": "oarresterbar",
    "oarresterbarares": "oarresterbar",
    "oarresterbaras": "oarresterbar",
    "oarresterbarast": "oarresterbar",
    "oarresterbaraste": "oarresterbar",
    "oarresterbarastes": "oarresterbar",
    "oarresterbarasts": "oarresterbar",
    "oarresterbare": "oarresterbar",
    "oarresterbares": "oarresterbar",
    "oarresterbarheten": "oarresterbarhet",
    "oarresterbarhetens": "oarresterbarhet",
    "oarresterbarhets": "oarresterbarhet",
    "oarresterbars": "oarresterbar",
    "oarresterbart": "oarresterbar",
    "oarresterbarts": "oarresterbar",
    "oarronderade": "oarronderad",
    "oarronderades": "oarronderad",
    "oarronderads": "oarronderad",
    "oarronderat": "oarronderad",
    "oarronderats": "oarronderad",
    "oarronderbara": "oarronderbar",
    "oarronderbarare": "oarronderbar",
    "oarronderbarares": "oarronderbar",
    "oarronderbaras": "oarronderbar",
    "oarronderbarast": "oarronderbar",
    "oarronderbaraste": "oarronderbar",
    "oarronderbarastes": "oarronderbar",
    "oarronderbarasts": "oarronderbar",
    "oarronderbare": "oarronderbar",
    "oarronderbares": "oarronderbar",
    "oarronderbarheten": "oarronderbarhet",
    "oarronderbarhetens": "oarronderbarhet",
    "oarronderbarhets": "oarronderbarhet",
    "oarronderbars": "oarronderbar",
    "oarronderbart": "oarronderbar",
    "oarronderbarts": "oarronderbar",
    "oarten": "oart",
    "oartens": "oart",
    "oarter": "oart",
    "oarterna": "oart",
    "oarternas": "oart",
    "oarters": "oart",
    "oartiga": "oartig",
    "oartigare": "oartig",
    "oartigares": "oartig",
    "oartigas": "oartig",
    "oartigast": "oartig",
    "oartigaste": "oartig",
    "oartigastes": "oartig",
    "oartigasts": "oartig",
    "oartige": "oartig",
    "oartiges": "oartig",
    "oartigheten": "oartighet",
    "oartighetens": "oartighet",
    "oartigheter": "oartighet",
    "oartigheterna": "oartighet",
    "oartigheternas": "oartighet",
    "oartigheters": "oartighet",
    "oartighets": "oartighet",
    "oartigs": "oartig",
    "oartigt": "oartig",
    "oartigts": "oartig",
    "oartikulerade": "oartikulerad",
    "oartikulerades": "oartikulerad",
    "oartikulerads": "oartikulerad",
    "oartikulerat": "oartikulerad",
    "oartikulerats": "oartikulerad",
    "oartikulerbara": "oartikulerbar",
    "oartikulerbarare": "oartikulerbar",
    "oartikulerbarares": "oartikulerbar",
    "oartikulerbaras": "oartikulerbar",
    "oartikulerbarast": "oartikulerbar",
    "oartikulerbaraste": "oartikulerbar",
    "oartikulerbarastes": "oartikulerbar",
    "oartikulerbarasts": "oartikulerbar",
    "oartikulerbare": "oartikulerbar",
    "oartikulerbares": "oartikulerbar",
    "oartikulerbarheten": "oartikulerbarhet",
    "oartikulerbarhetens": "oartikulerbarhet",
    "oartikulerbarhets": "oartikulerbarhet",
    "oartikulerbars": "oartikulerbar",
    "oartikulerbart": "oartikulerbar",
    "oartikulerbarts": "oartikulerbar",
    "oarts": "oart",
    "oarvoderade": "oarvoderad",
    "oarvoderades": "oarvoderad",
    "oarvoderads": "oarvoderad",
    "oarvoderat": "oarvoderad",
    "oarvoderats": "oarvoderad",
    "oarvoderbara": "oarvoderbar",
    "oarvoderbarare": "oarvoderbar",
    "oarvoderbarares": "oarvoderbar",
    "oarvoderbaras": "oarvoderbar",
    "oarvoderbarast": "oarvoderbar",
    "oarvoderbaraste": "oarvoderbar",
    "oarvoderbarastes": "oarvoderbar",
    "oarvoderbarasts": "oarvoderbar",
    "oarvoderbare": "oarvoderbar",
    "oarvoderbares": "oarvoderbar",
    "oarvoderbarheten": "oarvoderbarhet",
    "oarvoderbarhetens": "oarvoderbarhet",
    "oarvoderbarhets": "oarvoderbarhet",
    "oarvoderbars": "oarvoderbar",
    "oarvoderbart": "oarvoderbar",
    "oarvoderbarts": "oarvoderbar",
    "oasen": "oas",
    "oasens": "oas",
    "oaser": "oas",
    "oaserna": "oas",
    "oasernas": "oas",
    "oasers": "oas",
    "oasfalterade": "oasfalterad",
    "oasfalterades": "oasfalterad",
    "oasfalterads": "oasfalterad",
    "oasfalterat": "oasfalterad",
    "oasfalterats": "oasfalterad",
    "oasfalterbara": "oasfalterbar",
    "oasfalterbarare": "oasfalterbar",
    "oasfalterbarares": "oasfalterbar",
    "oasfalterbaras": "oasfalterbar",
    "oasfalterbarast": "oasfalterbar",
    "oasfalterbaraste": "oasfalterbar",
    "oasfalterbarastes": "oasfalterbar",
    "oasfalterbarasts": "oasfalterbar",
    "oasfalterbare": "oasfalterbar",
    "oasfalterbares": "oasfalterbar",
    "oasfalterbarheten": "oasfalterbarhet",
    "oasfalterbarhetens": "oasfalterbarhet",
    "oasfalterbarhets": "oasfalterbarhet",
    "oasfalterbars": "oasfalterbar",
    "oasfalterbart": "oasfalterbar",
    "oasfalterbarts": "oasfalterbar",
    "oaskade": "oaskad",
    "oaskades": "oaskad",
    "oaskads": "oaskad",
    "oaskat": "oaskad",
    "oaskats": "oaskad",
    "oaspirerade": "oaspirerad",
    "oaspirerades": "oaspirerad",
    "oaspirerads": "oaspirerad",
    "oaspirerat": "oaspirerad",
    "oaspirerats": "oaspirerad",
    "oaspirerbara": "oaspirerbar",
    "oaspirerbarare": "oaspirerbar",
    "oaspirerbarares": "oaspirerbar",
    "oaspirerbaras": "oaspirerbar",
    "oaspirerbarast": "oaspirerbar",
    "oaspirerbaraste": "oaspirerbar",
    "oaspirerbarastes": "oaspirerbar",
    "oaspirerbarasts": "oaspirerbar",
    "oaspirerbare": "oaspirerbar",
    "oaspirerbares": "oaspirerbar",
    "oaspirerbarheten": "oaspirerbarhet",
    "oaspirerbarhetens": "oaspirerbarhet",
    "oaspirerbarhets": "oaspirerbarhet",
    "oaspirerbars": "oaspirerbar",
    "oaspirerbart": "oaspirerbar",
    "oaspirerbarts": "oaspirerbar",
    "oassignerade": "oassignerad",
    "oassignerades": "oassignerad",
    "oassignerads": "oassignerad",
    "oassignerat": "oassignerad",
    "oassignerats": "oassignerad",
    "oassignerbara": "oassignerbar",
    "oassignerbarare": "oassignerbar",
    "oassignerbarares": "oassignerbar",
    "oassignerbaras": "oassignerbar",
    "oassignerbarast": "oassignerbar",
    "oassignerbaraste": "oassignerbar",
    "oassignerbarastes": "oassignerbar",
    "oassignerbarasts": "oassignerbar",
    "oassignerbare": "oassignerbar",
    "oassignerbares": "oassignerbar",
    "oassignerbarheten": "oassignerbarhet",
    "oassignerbarhetens": "oassignerbarhet",
    "oassignerbarhets": "oassignerbarhet",
    "oassignerbars": "oassignerbar",
    "oassignerbart": "oassignerbar",
    "oassignerbarts": "oassignerbar",
    "oassimilerade": "oassimilerad",
    "oassimilerades": "oassimilerad",
    "oassimilerads": "oassimilerad",
    "oassimilerat": "oassimilerad",
    "oassimilerats": "oassimilerad",
    "oassimilerbara": "oassimilerbar",
    "oassimilerbarare": "oassimilerbar",
    "oassimilerbarares": "oassimilerbar",
    "oassimilerbaras": "oassimilerbar",
    "oassimilerbarast": "oassimilerbar",
    "oassimilerbaraste": "oassimilerbar",
    "oassimilerbarastes": "oassimilerbar",
    "oassimilerbarasts": "oassimilerbar",
    "oassimilerbare": "oassimilerbar",
    "oassimilerbares": "oassimilerbar",
    "oassimilerbarheten": "oassimilerbarhet",
    "oassimilerbarhetens": "oassimilerbarhet",
    "oassimilerbarhets": "oassimilerbarhet",
    "oassimilerbars": "oassimilerbar",
    "oassimilerbart": "oassimilerbar",
    "oassimilerbarts": "oassimilerbar",
    "oassisterade": "oassisterad",
    "oassisterades": "oassisterad",
    "oassisterads": "oassisterad",
    "oassisterat": "oassisterad",
    "oassisterats": "oassisterad",
    "oassisterbara": "oassisterbar",
    "oassisterbarare": "oassisterbar",
    "oassisterbarares": "oassisterbar",
    "oassisterbaras": "oassisterbar",
    "oassisterbarast": "oassisterbar",
    "oassisterbaraste": "oassisterbar",
    "oassisterbarastes": "oassisterbar",
    "oassisterbarasts": "oassisterbar",
    "oassisterbare": "oassisterbar",
    "oassisterbares": "oassisterbar",
    "oassisterbarheten": "oassisterbarhet",
    "oassisterbarhetens": "oassisterbarhet",
    "oassisterbarhets": "oassisterbarhet",
    "oassisterbars": "oassisterbar",
    "oassisterbart": "oassisterbar",
    "oassisterbarts": "oassisterbar",
    "oassocierade": "oassocierad",
    "oassocierades": "oassocierad",
    "oassocierads": "oassocierad",
    "oassocierat": "oassocierad",
    "oassocierats": "oassocierad",
    "oassocierbara": "oassocierbar",
    "oassocierbarare": "oassocierbar",
    "oassocierbarares": "oassocierbar",
    "oassocierbaras": "oassocierbar",
    "oassocierbarast": "oassocierbar",
    "oassocierbaraste": "oassocierbar",
    "oassocierbarastes": "oassocierbar",
    "oassocierbarasts": "oassocierbar",
    "oassocierbare": "oassocierbar",
    "oassocierbares": "oassocierbar",
    "oassocierbarheten": "oassocierbarhet",
    "oassocierbarhetens": "oassocierbarhet",
    "oassocierbarhets": "oassocierbarhet",
    "oassocierbars": "oassocierbar",
    "oassocierbart": "oassocierbar",
    "oassocierbarts": "oassocierbar",
    "oassurerade": "oassurerad",
    "oassurerades": "oassurerad",
    "oassurerads": "oassurerad",
    "oassurerat": "oassurerad",
    "oassurerats": "oassurerad",
    "oassurerbara": "oassurerbar",
    "oassurerbarare": "oassurerbar",
    "oassurerbarares": "oassurerbar",
    "oassurerbaras": "oassurerbar",
    "oassurerbarast": "oassurerbar",
    "oassurerbaraste": "oassurerbar",
    "oassurerbarastes": "oassurerbar",
    "oassurerbarasts": "oassurerbar",
    "oassurerbare": "oassurerbar",
    "oassurerbares": "oassurerbar",
    "oassurerbarheten": "oassurerbarhet",
    "oassurerbarhetens": "oassurerbarhet",
    "oassurerbarhets": "oassurerbarhet",
    "oassurerbars": "oassurerbar",
    "oassurerbart": "oassurerbar",
    "oassurerbarts": "oassurerbar",
    "oatrofierade": "oatrofierad",
    "oatrofierades": "oatrofierad",
    "oatrofierads": "oatrofierad",
    "oatrofierat": "oatrofierad",
    "oatrofierats": "oatrofierad",
    "oatrofierbara": "oatrofierbar",
    "oatrofierbarare": "oatrofierbar",
    "oatrofierbarares": "oatrofierbar",
    "oatrofierbaras": "oatrofierbar",
    "oatrofierbarast": "oatrofierbar",
    "oatrofierbaraste": "oatrofierbar",
    "oatrofierbarastes": "oatrofierbar",
    "oatrofierbarasts": "oatrofierbar",
    "oatrofierbare": "oatrofierbar",
    "oatrofierbares": "oatrofierbar",
    "oatrofierbarheten": "oatrofierbarhet",
    "oatrofierbarhetens": "oatrofierbarhet",
    "oatrofierbarhets": "oatrofierbarhet",
    "oatrofierbars": "oatrofierbar",
    "oatrofierbart": "oatrofierbar",
    "oatrofierbarts": "oatrofierbar",
    "oattackerade": "oattackerad",
    "oattackerades": "oattackerad",
    "oattackerads": "oattackerad",
    "oattackerat": "oattackerad",
    "oattackerats": "oattackerad",
    "oattackerbara": "oattackerbar",
    "oattackerbarare": "oattackerbar",
    "oattackerbarares": "oattackerbar",
    "oattackerbaras": "oattackerbar",
    "oattackerbarast": "oattackerbar",
    "oattackerbaraste": "oattackerbar",
    "oattackerbarastes": "oattackerbar",
    "oattackerbarasts": "oattackerbar",
    "oattackerbare": "oattackerbar",
    "oattackerbares": "oattackerbar",
    "oattackerbarheten": "oattackerbarhet",
    "oattackerbarhetens": "oattackerbarhet",
    "oattackerbarhets": "oattackerbarhet",
    "oattackerbars": "oattackerbar",
    "oattackerbart": "oattackerbar",
    "oattackerbarts": "oattackerbar",
    "oattesterade": "oattesterad",
    "oattesterades": "oattesterad",
    "oattesterads": "oattesterad",
    "oattesterat": "oattesterad",
    "oattesterats": "oattesterad",
    "oattesterbara": "oattesterbar",
    "oattesterbarare": "oattesterbar",
    "oattesterbarares": "oattesterbar",
    "oattesterbaras": "oattesterbar",
    "oattesterbarast": "oattesterbar",
    "oattesterbaraste": "oattesterbar",
    "oattesterbarastes": "oattesterbar",
    "oattesterbarasts": "oattesterbar",
    "oattesterbare": "oattesterbar",
    "oattesterbares": "oattesterbar",
    "oattesterbarheten": "oattesterbarhet",
    "oattesterbarhetens": "oattesterbarhet",
    "oattesterbarhets": "oattesterbarhet",
    "oattesterbars": "oattesterbar",
    "oattesterbart": "oattesterbar",
    "oattesterbarts": "oattesterbar",
    "oattraherade": "oattraherad",
    "oattraherades": "oattraherad",
    "oattraherads": "oattraherad",
    "oattraherat": "oattraherad",
    "oattraherats": "oattraherad",
    "oattraherbara": "oattraherbar",
    "oattraherbarare": "oattraherbar",
    "oattraherbarares": "oattraherbar",
    "oattraherbaras": "oattraherbar",
    "oattraherbarast": "oattraherbar",
    "oattraherbaraste": "oattraherbar",
    "oattraherbarastes": "oattraherbar",
    "oattraherbarasts": "oattraherbar",
    "oattraherbare": "oattraherbar",
    "oattraherbares": "oattraherbar",
    "oattraherbarheten": "oattraherbarhet",
    "oattraherbarhetens": "oattraherbarhet",
    "oattraherbarhets": "oattraherbarhet",
    "oattraherbars": "oattraherbar",
    "oattraherbart": "oattraherbar",
    "oattraherbarts": "oattraherbar",
    "oattrapperade": "oattrapperad",
    "oattrapperades": "oattrapperad",
    "oattrapperads": "oattrapperad",
    "oattrapperat": "oattrapperad",
    "oattrapperats": "oattrapperad",
    "oattrapperbara": "oattrapperbar",
    "oattrapperbarare": "oattrapperbar",
    "oattrapperbarares": "oattrapperbar",
    "oattrapperbaras": "oattrapperbar",
    "oattrapperbarast": "oattrapperbar",
    "oattrapperbaraste": "oattrapperbar",
    "oattrapperbarastes": "oattrapperbar",
    "oattrapperbarasts": "oattrapperbar",
    "oattrapperbare": "oattrapperbar",
    "oattrapperbares": "oattrapperbar",
    "oattrapperbarheten": "oattrapperbarhet",
    "oattrapperbarhetens": "oattrapperbarhet",
    "oattrapperbarhets": "oattrapperbarhet",
    "oattrapperbars": "oattrapperbar",
    "oattrapperbart": "oattrapperbar",
    "oattrapperbarts": "oattrapperbar",
    "oattribuerade": "oattribuerad",
    "oattribuerades": "oattribuerad",
    "oattribuerads": "oattribuerad",
    "oattribuerat": "oattribuerad",
    "oattribuerats": "oattribuerad",
    "oattribuerbara": "oattribuerbar",
    "oattribuerbarare": "oattribuerbar",
    "oattribuerbarares": "oattribuerbar",
    "oattribuerbaras": "oattribuerbar",
    "oattribuerbarast": "oattribuerbar",
    "oattribuerbaraste": "oattribuerbar",
    "oattribuerbarastes": "oattribuerbar",
    "oattribuerbarasts": "oattribuerbar",
    "oattribuerbare": "oattribuerbar",
    "oattribuerbares": "oattribuerbar",
    "oattribuerbarheten": "oattribuerbarhet",
    "oattribuerbarhetens": "oattribuerbarhet",
    "oattribuerbarhets": "oattribuerbarhet",
    "oattribuerbars": "oattribuerbar",
    "oattribuerbart": "oattribuerbar",
    "oattribuerbarts": "oattribuerbar",
    "oauktionerade": "oauktionerad",
    "oauktionerades": "oauktionerad",
    "oauktionerads": "oauktionerad",
    "oauktionerat": "oauktionerad",
    "oauktionerats": "oauktionerad",
    "oauktionerbara": "oauktionerbar",
    "oauktionerbarare": "oauktionerbar",
    "oauktionerbarares": "oauktionerbar",
    "oauktionerbaras": "oauktionerbar",
    "oauktionerbarast": "oauktionerbar",
    "oauktionerbaraste": "oauktionerbar",
    "oauktionerbarastes": "oauktionerbar",
    "oauktionerbarasts": "oauktionerbar",
    "oauktionerbare": "oauktionerbar",
    "oauktionerbares": "oauktionerbar",
    "oauktionerbarheten": "oauktionerbarhet",
    "oauktionerbarhetens": "oauktionerbarhet",
    "oauktionerbarhets": "oauktionerbarhet",
    "oauktionerbars": "oauktionerbar",
    "oauktionerbart": "oauktionerbar",
    "oauktionerbarts": "oauktionerbar",
    "oauktoriserade": "oauktoriserad",
    "oauktoriserades": "oauktoriserad",
    "oauktoriserads": "oauktoriserad",
    "oauktoriserat": "oauktoriserad",
    "oauktoriserats": "oauktoriserad",
    "oauktoriserbara": "oauktoriserbar",
    "oauktoriserbarare": "oauktoriserbar",
    "oauktoriserbarares": "oauktoriserbar",
    "oauktoriserbaras": "oauktoriserbar",
    "oauktoriserbarast": "oauktoriserbar",
    "oauktoriserbaraste": "oauktoriserbar",
    "oauktoriserbarastes": "oauktoriserbar",
    "oauktoriserbarasts": "oauktoriserbar",
    "oauktoriserbare": "oauktoriserbar",
    "oauktoriserbares": "oauktoriserbar",
    "oauktoriserbarheten": "oauktoriserbarhet",
    "oauktoriserbarhetens": "oauktoriserbarhet",
    "oauktoriserbarhets": "oauktoriserbarhet",
    "oauktoriserbars": "oauktoriserbar",
    "oauktoriserbart": "oauktoriserbar",
    "oauktoriserbarts": "oauktoriserbar",
    "oauskulterade": "oauskulterad",
    "oauskulterades": "oauskulterad",
    "oauskulterads": "oauskulterad",
    "oauskulterat": "oauskulterad",
    "oauskulterats": "oauskulterad",
    "oauskulterbara": "oauskulterbar",
    "oauskulterbarare": "oauskulterbar",
    "oauskulterbarares": "oauskulterbar",
    "oauskulterbaras": "oauskulterbar",
    "oauskulterbarast": "oauskulterbar",
    "oauskulterbaraste": "oauskulterbar",
    "oauskulterbarastes": "oauskulterbar",
    "oauskulterbarasts": "oauskulterbar",
    "oauskulterbare": "oauskulterbar",
    "oauskulterbares": "oauskulterbar",
    "oauskulterbarheten": "oauskulterbarhet",
    "oauskulterbarhetens": "oauskulterbarhet",
    "oauskulterbarhets": "oauskulterbarhet",
    "oauskulterbars": "oauskulterbar",
    "oauskulterbart": "oauskulterbar",
    "oauskulterbarts": "oauskulterbar",
    "oautenticerade": "oautenticerad",
    "oautenticerades": "oautenticerad",
    "oautenticerads": "oautenticerad",
    "oautenticerat": "oautenticerad",
    "oautenticerats": "oautenticerad",
    "oautenticerbara": "oautenticerbar",
    "oautenticerbarare": "oautenticerbar",
    "oautenticerbarares": "oautenticerbar",
    "oautenticerbaras": "oautenticerbar",
    "oautenticerbarast": "oautenticerbar",
    "oautenticerbaraste": "oautenticerbar",
    "oautenticerbarastes": "oautenticerbar",
    "oautenticerbarasts": "oautenticerbar",
    "oautenticerbare": "oautenticerbar",
    "oautenticerbares": "oautenticerbar",
    "oautenticerbarheten": "oautenticerbarhet",
    "oautenticerbarhetens": "oautenticerbarhet",
    "oautenticerbarhets": "oautenticerbarhet",
    "oautenticerbars": "oautenticerbar",
    "oautenticerbart": "oautenticerbar",
    "oautenticerbarts": "oautenticerbar",
    "oautentifierade": "oautentifierad",
    "oautentifierades": "oautentifierad",
    "oautentifierads": "oautentifierad",
    "oautentifierat": "oautentifierad",
    "oautentifierats": "oautentifierad",
    "oautentifierbara": "oautentifierbar",
    "oautentifierbarare": "oautentifierbar",
    "oautentifierbarares": "oautentifierbar",
    "oautentifierbaras": "oautentifierbar",
    "oautentifierbarast": "oautentifierbar",
    "oautentifierbaraste": "oautentifierbar",
    "oautentifierbarastes": "oautentifierbar",
    "oautentifierbarasts": "oautentifierbar",
    "oautentifierbare": "oautentifierbar",
    "oautentifierbares": "oautentifierbar",
    "oautentifierbarheten": "oautentifierbarhet",
    "oautentifierbarhetens": "oautentifierbarhet",
    "oautentifierbarhets": "oautentifierbarhet",
    "oautentifierbars": "oautentifierbar",
    "oautentifierbart": "oautentifierbar",
    "oautentifierbarts": "oautentifierbar",
    "oautentiserade": "oautentiserad",
    "oautentiserades": "oautentiserad",
    "oautentiserads": "oautentiserad",
    "oautentiserat": "oautentiserad",
    "oautentiserats": "oautentiserad",
    "oautentiserbara": "oautentiserbar",
    "oautentiserbarare": "oautentiserbar",
    "oautentiserbarares": "oautentiserbar",
    "oautentiserbaras": "oautentiserbar",
    "oautentiserbarast": "oautentiserbar",
    "oautentiserbaraste": "oautentiserbar",
    "oautentiserbarastes": "oautentiserbar",
    "oautentiserbarasts": "oautentiserbar",
    "oautentiserbare": "oautentiserbar",
    "oautentiserbares": "oautentiserbar",
    "oautentiserbarheten": "oautentiserbarhet",
    "oautentiserbarhetens": "oautentiserbarhet",
    "oautentiserbarhets": "oautentiserbarhet",
    "oautentiserbars": "oautentiserbar",
    "oautentiserbart": "oautentiserbar",
    "oautentiserbarts": "oautentiserbar",
    "oautomatiserade": "oautomatiserad",
    "oautomatiserades": "oautomatiserad",
    "oautomatiserads": "oautomatiserad",
    "oautomatiserat": "oautomatiserad",
    "oautomatiserats": "oautomatiserad",
    "oautomatiserbara": "oautomatiserbar",
    "oautomatiserbarare": "oautomatiserbar",
    "oautomatiserbarares": "oautomatiserbar",
    "oautomatiserbaras": "oautomatiserbar",
    "oautomatiserbarast": "oautomatiserbar",
    "oautomatiserbaraste": "oautomatiserbar",
    "oautomatiserbarastes": "oautomatiserbar",
    "oautomatiserbarasts": "oautomatiserbar",
    "oautomatiserbare": "oautomatiserbar",
    "oautomatiserbares": "oautomatiserbar",
    "oautomatiserbarheten": "oautomatiserbarhet",
    "oautomatiserbarhetens": "oautomatiserbarhet",
    "oautomatiserbarhets": "oautomatiserbarhet",
    "oautomatiserbars": "oautomatiserbar",
    "oautomatiserbart": "oautomatiserbar",
    "oautomatiserbarts": "oautomatiserbar",
    "oavade": "oavad",
    "oavades": "oavad",
    "oavads": "oavad",
    "oavancerade": "oavancerad",
    "oavancerades": "oavancerad",
    "oavancerads": "oavancerad",
    "oavancerat": "oavancerad",
    "oavancerats": "oavancerad",
    "oavancerbara": "oavancerbar",
    "oavancerbarare": "oavancerbar",
    "oavancerbarares": "oavancerbar",
    "oavancerbaras": "oavancerbar",
    "oavancerbarast": "oavancerbar",
    "oavancerbaraste": "oavancerbar",
    "oavancerbarastes": "oavancerbar",
    "oavancerbarasts": "oavancerbar",
    "oavancerbare": "oavancerbar",
    "oavancerbares": "oavancerbar",
    "oavancerbarheten": "oavancerbarhet",
    "oavancerbarhetens": "oavancerbarhet",
    "oavancerbarhets": "oavancerbarhet",
    "oavancerbars": "oavancerbar",
    "oavancerbart": "oavancerbar",
    "oavancerbarts": "oavancerbar",
    "oavannonserade": "oavannonserad",
    "oavannonserades": "oavannonserad",
    "oavannonserads": "oavannonserad",
    "oavannonserat": "oavannonserad",
    "oavannonserats": "oavannonserad",
    "oavannonserbara": "oavannonserbar",
    "oavannonserbarare": "oavannonserbar",
    "oavannonserbarares": "oavannonserbar",
    "oavannonserbaras": "oavannonserbar",
    "oavannonserbarast": "oavannonserbar",
    "oavannonserbaraste": "oavannonserbar",
    "oavannonserbarastes": "oavannonserbar",
    "oavannonserbarasts": "oavannonserbar",
    "oavannonserbare": "oavannonserbar",
    "oavannonserbares": "oavannonserbar",
    "oavannonserbarheten": "oavannonserbarhet",
    "oavannonserbarhetens": "oavannonserbarhet",
    "oavannonserbarhets": "oavannonserbarhet",
    "oavannonserbars": "oavannonserbar",
    "oavannonserbart": "oavannonserbar",
    "oavannonserbarts": "oavannonserbar",
    "oavat": "oavad",
    "oavats": "oavad",
    "oavbalkade": "oavbalkad",
    "oavbalkades": "oavbalkad",
    "oavbalkads": "oavbalkad",
    "oavbalkat": "oavbalkad",
    "oavbalkats": "oavbalkad",
    "oavbeställde": "oavbeställd",
    "oavbeställdes": "oavbeställd",
    "oavbeställds": "oavbeställd",
    "oavbeställt": "oavbeställd",
    "oavbeställts": "oavbeställd",
    "oavbetade": "oavbetad",
    "oavbetades": "oavbetad",
    "oavbetads": "oavbetad",
    "oavbetalade": "oavbetalad",
    "oavbetalades": "oavbetalad",
    "oavbetalads": "oavbetalad",
    "oavbetalat": "oavbetalad",
    "oavbetalats": "oavbetalad",
    "oavbetat": "oavbetad",
    "oavbetats": "oavbetad",
    "oavbildade": "oavbildad",
    "oavbildades": "oavbildad",
    "oavbildads": "oavbildad",
    "oavbildat": "oavbildad",
    "oavbildats": "oavbildad",
    "oavblåsta": "oavblåst",
    "oavblåstas": "oavblåst",
    "oavblåste": "oavblåst",
    "oavblåstes": "oavblåst",
    "oavblåsts": "oavblåst",
    "oavbrutens": "oavbruten",
    "oavbrutet": "oavbruten",
    "oavbrutets": "oavbruten",
    "oavbrutna": "oavbruten",
    "oavbrutnare": "oavbruten",
    "oavbrutnares": "oavbruten",
    "oavbrutnas": "oavbruten",
    "oavbrutnast": "oavbruten",
    "oavbrutnaste": "oavbruten",
    "oavbrutnastes": "oavbruten",
    "oavbrutnasts": "oavbruten",
    "oavbrutne": "oavbruten",
    "oavbrutnes": "oavbruten",
    "oavböjde": "oavböjd",
    "oavböjdes": "oavböjd",
    "oavböjds": "oavböjd",
    "oavböjt": "oavböjd",
    "oavböjts": "oavböjd",
    "oavbördade": "oavbördad",
    "oavbördades": "oavbördad",
    "oavbördads": "oavbördad",
    "oavbördat": "oavbördad",
    "oavbördats": "oavbördad",
    "oavdelade": "oavdelad",
    "oavdelades": "oavdelad",
    "oavdelads": "oavdelad",
    "oavdelat": "oavdelad",
    "oavdelats": "oavdelad",
    "oavdramatiserade": "oavdramatiserad",
    "oavdramatiserades": "oavdramatiserad",
    "oavdramatiserads": "oavdramatiserad",
    "oavdramatiserat": "oavdramatiserad",
    "oavdramatiserats": "oavdramatiserad",
    "oavdramatiserbara": "oavdramatiserbar",
    "oavdramatiserbarare": "oavdramatiserbar",
    "oavdramatiserbarares": "oavdramatiserbar",
    "oavdramatiserbaras": "oavdramatiserbar",
    "oavdramatiserbarast": "oavdramatiserbar",
    "oavdramatiserbaraste": "oavdramatiserbar",
    "oavdramatiserbarastes": "oavdramatiserbar",
    "oavdramatiserbarasts": "oavdramatiserbar",
    "oavdramatiserbare": "oavdramatiserbar",
    "oavdramatiserbares": "oavdramatiserbar",
    "oavdramatiserbarheten": "oavdramatiserbarhet",
    "oavdramatiserbarhetens": "oavdramatiserbarhet",
    "oavdramatiserbarhets": "oavdramatiserbarhet",
    "oavdramatiserbars": "oavdramatiserbar",
    "oavdramatiserbart": "oavdramatiserbar",
    "oavdramatiserbarts": "oavdramatiserbar",
    "oavdunstade": "oavdunstad",
    "oavdunstades": "oavdunstad",
    "oavdunstads": "oavdunstad",
    "oavdunstat": "oavdunstad",
    "oavdunstats": "oavdunstad",
    "oavdämde": "oavdämd",
    "oavdämdes": "oavdämd",
    "oavdämds": "oavdämd",
    "oavdämt": "oavdämd",
    "oavdämts": "oavdämd",
    "oavdömde": "oavdömd",
    "oavdömdes": "oavdömd",
    "oavdömds": "oavdömd",
    "oavdömt": "oavdömd",
    "oavdömts": "oavdömd",
    "oavfattade": "oavfattad",
    "oavfattades": "oavfattad",
    "oavfattads": "oavfattad",
    "oavfattat": "oavfattad",
    "oavfattats": "oavfattad",
    "oavfettade": "oavfettad",
    "oavfettades": "oavfettad",
    "oavfettads": "oavfettad",
    "oavfettat": "oavfettad",
    "oavfettats": "oavfettad",
    "oavflyttade": "oavflyttad",
    "oavflyttades": "oavflyttad",
    "oavflyttads": "oavflyttad",
    "oavflyttat": "oavflyttad",
    "oavflyttats": "oavflyttad",
    "oavfolkade": "oavfolkad",
    "oavfolkades": "oavfolkad",
    "oavfolkads": "oavfolkad",
    "oavfolkat": "oavfolkad",
    "oavfolkats": "oavfolkad",
    "oavfordrade": "oavfordrad",
    "oavfordrades": "oavfordrad",
    "oavfordrads": "oavfordrad",
    "oavfordrat": "oavfordrad",
    "oavfordrats": "oavfordrad",
    "oavfuktade": "oavfuktad",
    "oavfuktades": "oavfuktad",
    "oavfuktads": "oavfuktad",
    "oavfuktat": "oavfuktad",
    "oavfuktats": "oavfuktad",
    "oavfyrade": "oavfyrad",
    "oavfyrades": "oavfyrad",
    "oavfyrads": "oavfyrad",
    "oavfyrat": "oavfyrad",
    "oavfyrats": "oavfyrad",
    "oavfärdade": "oavfärdad",
    "oavfärdades": "oavfärdad",
    "oavfärdads": "oavfärdad",
    "oavfärdat": "oavfärdad",
    "oavfärdats": "oavfärdad",
    "oavförde": "oavförd",
    "oavfördes": "oavförd",
    "oavförds": "oavförd",
    "oavfört": "oavförd",
    "oavförts": "oavförd",
    "oavgiftade": "oavgiftad",
    "oavgiftades": "oavgiftad",
    "oavgiftads": "oavgiftad",
    "oavgiftat": "oavgiftad",
    "oavgiftats": "oavgiftad",
    "oavgjorda": "oavgjord",
    "oavgjordare": "oavgjord",
    "oavgjordares": "oavgjord",
    "oavgjordas": "oavgjord",
    "oavgjordast": "oavgjord",
    "oavgjordaste": "oavgjord",
    "oavgjordastes": "oavgjord",
    "oavgjordasts": "oavgjord",
    "oavgjorde": "oavgjord",
    "oavgjordes": "oavgjord",
    "oavgjords": "oavgjord",
    "oavgjort": "oavgjord",
    "oavgjorts": "oavgjord",
    "oavgränsade": "oavgränsad",
    "oavgränsades": "oavgränsad",
    "oavgränsads": "oavgränsad",
    "oavgränsat": "oavgränsad",
    "oavgränsats": "oavgränsad",
    "oavgudade": "oavgudad",
    "oavgudades": "oavgudad",
    "oavgudads": "oavgudad",
    "oavgudat": "oavgudad",
    "oavgudats": "oavgudad",
    "oavgärdade": "oavgärdad",
    "oavgärdades": "oavgärdad",
    "oavgärdads": "oavgärdad",
    "oavgärdat": "oavgärdad",
    "oavgärdats": "oavgärdad",
    "oavhandlade": "oavhandlad",
    "oavhandlades": "oavhandlad",
    "oavhandlads": "oavhandlad",
    "oavhandlat": "oavhandlad",
    "oavhandlats": "oavhandlad",
    "oavhjälpta": "oavhjälpt",
    "oavhjälptas": "oavhjälpt",
    "oavhjälpte": "oavhjälpt",
    "oavhjälptes": "oavhjälpt",
    "oavhjälpts": "oavhjälpt",
    "oavhysta": "oavhyst",
    "oavhystas": "oavhyst",
    "oavhyste": "oavhyst",
    "oavhystes": "oavhyst",
    "oavhysts": "oavhyst",
    "oavhämtade": "oavhämtad",
    "oavhämtades": "oavhämtad",
    "oavhämtads": "oavhämtad",
    "oavhämtat": "oavhämtad",
    "oavhämtats": "oavhämtad",
    "oavhängde": "oavhängd",
    "oavhängdes": "oavhängd",
    "oavhängds": "oavhängd",
    "oavhängiga": "oavhängig",
    "oavhängigare": "oavhängig",
    "oavhängigares": "oavhängig",
    "oavhängigas": "oavhängig",
    "oavhängigast": "oavhängig",
    "oavhängigaste": "oavhängig",
    "oavhängigastes": "oavhängig",
    "oavhängigasts": "oavhängig",
    "oavhängige": "oavhängig",
    "oavhängiges": "oavhängig",
    "oavhängigheten": "oavhängighet",
    "oavhängighetens": "oavhängighet",
    "oavhängigheter": "oavhängighet",
    "oavhängigheterna": "oavhängighet",
    "oavhängigheternas": "oavhängighet",
    "oavhängigheters": "oavhängighet",
    "oavhängighets": "oavhängighet",
    "oavhängigs": "oavhängig",
    "oavhängigt": "oavhängig",
    "oavhängigts": "oavhängig",
    "oavhängt": "oavhängd",
    "oavhängts": "oavhängd",
    "oavhärdade": "oavhärdad",
    "oavhärdades": "oavhärdad",
    "oavhärdads": "oavhärdad",
    "oavhärdat": "oavhärdad",
    "oavhärdats": "oavhärdad",
    "oavhörde": "oavhörd",
    "oavhördes": "oavhörd",
    "oavhörds": "oavhörd",
    "oavhört": "oavhörd",
    "oavhörts": "oavhörd",
    "oavhöstade": "oavhöstad",
    "oavhöstades": "oavhöstad",
    "oavhöstads": "oavhöstad",
    "oavhöstat": "oavhöstad",
    "oavhöstats": "oavhöstad",
    "oavisade": "oavisad",
    "oavisades": "oavisad",
    "oavisads": "oavisad",
    "oavisat": "oavisad",
    "oavisats": "oavisad",
    "oaviserade": "oaviserad",
    "oaviserades": "oaviserad",
    "oaviserads": "oaviserad",
    "oaviserat": "oaviserad",
    "oaviserats": "oaviserad",
    "oaviserbara": "oaviserbar",
    "oaviserbarare": "oaviserbar",
    "oaviserbarares": "oaviserbar",
    "oaviserbaras": "oaviserbar",
    "oaviserbarast": "oaviserbar",
    "oaviserbaraste": "oaviserbar",
    "oaviserbarastes": "oaviserbar",
    "oaviserbarasts": "oaviserbar",
    "oaviserbare": "oaviserbar",
    "oaviserbares": "oaviserbar",
    "oaviserbarheten": "oaviserbarhet",
    "oaviserbarhetens": "oaviserbarhet",
    "oaviserbarhets": "oaviserbarhet",
    "oaviserbars": "oaviserbar",
    "oaviserbart": "oaviserbar",
    "oaviserbarts": "oaviserbar",
    "oavjagade": "oavjagad",
    "oavjagades": "oavjagad",
    "oavjagads": "oavjagad",
    "oavjagat": "oavjagad",
    "oavjagats": "oavjagad",
    "oavjämnade": "oavjämnad",
    "oavjämnades": "oavjämnad",
    "oavjämnads": "oavjämnad",
    "oavjämnat": "oavjämnad",
    "oavjämnats": "oavjämnad",
    "oavkalkade": "oavkalkad",
    "oavkalkades": "oavkalkad",
    "oavkalkads": "oavkalkad",
    "oavkalkat": "oavkalkad",
    "oavkalkats": "oavkalkad",
    "oavklarade": "oavklarad",
    "oavklarades": "oavklarad",
    "oavklarads": "oavklarad",
    "oavklarat": "oavklarad",
    "oavklarats": "oavklarad",
    "oavklingade": "oavklingad",
    "oavklingades": "oavklingad",
    "oavklingads": "oavklingad",
    "oavklingat": "oavklingad",
    "oavklingats": "oavklingad",
    "oavknoppade": "oavknoppad",
    "oavknoppades": "oavknoppad",
    "oavknoppads": "oavknoppad",
    "oavknoppat": "oavknoppad",
    "oavknoppats": "oavknoppad",
    "oavkoloniserade": "oavkoloniserad",
    "oavkoloniserades": "oavkoloniserad",
    "oavkoloniserads": "oavkoloniserad",
    "oavkoloniserat": "oavkoloniserad",
    "oavkoloniserats": "oavkoloniserad",
    "oavkoloniserbara": "oavkoloniserbar",
    "oavkoloniserbarare": "oavkoloniserbar",
    "oavkoloniserbarares": "oavkoloniserbar",
    "oavkoloniserbaras": "oavkoloniserbar",
    "oavkoloniserbarast": "oavkoloniserbar",
    "oavkoloniserbaraste": "oavkoloniserbar",
    "oavkoloniserbarastes": "oavkoloniserbar",
    "oavkoloniserbarasts": "oavkoloniserbar",
    "oavkoloniserbare": "oavkoloniserbar",
    "oavkoloniserbares": "oavkoloniserbar",
    "oavkoloniserbarheten": "oavkoloniserbarhet",
    "oavkoloniserbarhetens": "oavkoloniserbarhet",
    "oavkoloniserbarhets": "oavkoloniserbarhet",
    "oavkoloniserbars": "oavkoloniserbar",
    "oavkoloniserbart": "oavkoloniserbar",
    "oavkoloniserbarts": "oavkoloniserbar",
    "oavkopplade": "oavkopplad",
    "oavkopplades": "oavkopplad",
    "oavkopplads": "oavkopplad",
    "oavkopplat": "oavkopplad",
    "oavkopplats": "oavkopplad",
    "oavkortade": "oavkortad",
    "oavkortades": "oavkortad",
    "oavkortads": "oavkortad",
    "oavkortat": "oavkortad",
    "oavkortats": "oavkortad",
    "oavkriminaliserade": "oavkriminaliserad",
    "oavkriminaliserades": "oavkriminaliserad",
    "oavkriminaliserads": "oavkriminaliserad",
    "oavkriminaliserat": "oavkriminaliserad",
    "oavkriminaliserats": "oavkriminaliserad",
    "oavkriminaliserbara": "oavkriminaliserbar",
    "oavkriminaliserbarare": "oavkriminaliserbar",
    "oavkriminaliserbarares": "oavkriminaliserbar",
    "oavkriminaliserbaras": "oavkriminaliserbar",
    "oavkriminaliserbarast": "oavkriminaliserbar",
    "oavkriminaliserbaraste": "oavkriminaliserbar",
    "oavkriminaliserbarastes": "oavkriminaliserbar",
    "oavkriminaliserbarasts": "oavkriminaliserbar",
    "oavkriminaliserbare": "oavkriminaliserbar",
    "oavkriminaliserbares": "oavkriminaliserbar",
    "oavkriminaliserbarheten": "oavkriminaliserbarhet",
    "oavkriminaliserbarhetens": "oavkriminaliserbarhet",
    "oavkriminaliserbarhets": "oavkriminaliserbarhet",
    "oavkriminaliserbars": "oavkriminaliserbar",
    "oavkriminaliserbart": "oavkriminaliserbar",
    "oavkriminaliserbarts": "oavkriminaliserbar",
    "oavkristnade": "oavkristnad",
    "oavkristnades": "oavkristnad",
    "oavkristnads": "oavkristnad",
    "oavkristnat": "oavkristnad",
    "oavkristnats": "oavkristnad",
    "oavkrävde": "oavkrävd",
    "oavkrävdes": "oavkrävd",
    "oavkrävds": "oavkrävd",
    "oavkrävt": "oavkrävd",
    "oavkrävts": "oavkrävd",
    "oavkunnade": "oavkunnad",
    "oavkunnades": "oavkunnad",
    "oavkunnads": "oavkunnad",
    "oavkunnat": "oavkunnad",
    "oavkunnats": "oavkunnad",
    "oavkylde": "oavkyld",
    "oavkyldes": "oavkyld",
    "oavkylds": "oavkyld",
    "oavkylt": "oavkyld",
    "oavkylts": "oavkyld",
    "oavkände": "oavkänd",
    "oavkändes": "oavkänd",
    "oavkänds": "oavkänd",
    "oavkänt": "oavkänd",
    "oavkänts": "oavkänd",
    "oavkönade": "oavkönad",
    "oavkönades": "oavkönad",
    "oavkönads": "oavkönad",
    "oavkönat": "oavkönad",
    "oavkönats": "oavkönad",
    "oavlade": "oavlad",
    "oavlades": "oavlad",
    "oavlads": "oavlad",
    "oavlagrade": "oavlagrad",
    "oavlagrades": "oavlagrad",
    "oavlagrads": "oavlagrad",
    "oavlagrat": "oavlagrad",
    "oavlagrats": "oavlagrad",
    "oavlastade": "oavlastad",
    "oavlastades": "oavlastad",
    "oavlastads": "oavlastad",
    "oavlastat": "oavlastad",
    "oavlastats": "oavlastad",
    "oavlat": "oavlad",
    "oavlats": "oavlad",
    "oavlivade": "oavlivad",
    "oavlivades": "oavlivad",
    "oavlivads": "oavlivad",
    "oavlivat": "oavlivad",
    "oavlivats": "oavlivad",
    "oavlockade": "oavlockad",
    "oavlockades": "oavlockad",
    "oavlockads": "oavlockad",
    "oavlockat": "oavlockad",
    "oavlockats": "oavlockad",
    "oavlossade": "oavlossad",
    "oavlossades": "oavlossad",
    "oavlossads": "oavlossad",
    "oavlossat": "oavlossad",
    "oavlossats": "oavlossad",
    "oavlusade": "oavlusad",
    "oavlusades": "oavlusad",
    "oavlusads": "oavlusad",
    "oavlusat": "oavlusad",
    "oavlusats": "oavlusad",
    "oavlyssnade": "oavlyssnad",
    "oavlyssnades": "oavlyssnad",
    "oavlyssnads": "oavlyssnad",
    "oavlyssnat": "oavlyssnad",
    "oavlyssnats": "oavlyssnad",
    "oavlysta": "oavlyst",
    "oavlystas": "oavlyst",
    "oavlyste": "oavlyst",
    "oavlystes": "oavlyst",
    "oavlysts": "oavlyst",
    "oavlägsnade": "oavlägsnad",
    "oavlägsnades": "oavlägsnad",
    "oavlägsnads": "oavlägsnad",
    "oavlägsnat": "oavlägsnad",
    "oavlägsnats": "oavlägsnad",
    "oavlämnade": "oavlämnad",
    "oavlämnades": "oavlämnad",
    "oavlämnads": "oavlämnad",
    "oavlämnat": "oavlämnad",
    "oavlämnats": "oavlämnad",
    "oavlänkade": "oavlänkad",
    "oavlänkades": "oavlänkad",
    "oavlänkads": "oavlänkad",
    "oavlänkat": "oavlänkad",
    "oavlänkats": "oavlänkad",
    "oavlåtliga": "oavlåtlig",
    "oavlåtligare": "oavlåtlig",
    "oavlåtligares": "oavlåtlig",
    "oavlåtligas": "oavlåtlig",
    "oavlåtligast": "oavlåtlig",
    "oavlåtligaste": "oavlåtlig",
    "oavlåtligastes": "oavlåtlig",
    "oavlåtligasts": "oavlåtlig",
    "oavlåtlige": "oavlåtlig",
    "oavlåtliges": "oavlåtlig",
    "oavlåtligheten": "oavlåtlighet",
    "oavlåtlighetens": "oavlåtlighet",
    "oavlåtlighets": "oavlåtlighet",
    "oavlåtligs": "oavlåtlig",
    "oavlåtligt": "oavlåtlig",
    "oavlåtligts": "oavlåtlig",
    "oavlönade": "oavlönad",
    "oavlönades": "oavlönad",
    "oavlönads": "oavlönad",
    "oavlönat": "oavlönad",
    "oavlönats": "oavlönad",
    "oavlöpta": "oavlöpt",
    "oavlöptas": "oavlöpt",
    "oavlöpte": "oavlöpt",
    "oavlöptes": "oavlöpt",
    "oavlöpts": "oavlöpt",
    "oavlösta": "oavlöst",
    "oavlöstas": "oavlöst",
    "oavlöste": "oavlöst",
    "oavlöstes": "oavlöst",
    "oavlösts": "oavlöst",
    "oavlövade": "oavlövad",
    "oavlövades": "oavlövad",
    "oavlövads": "oavlövad",
    "oavlövat": "oavlövad",
    "oavlövats": "oavlövad",
    "oavmagnetiserade": "oavmagnetiserad",
    "oavmagnetiserades": "oavmagnetiserad",
    "oavmagnetiserads": "oavmagnetiserad",
    "oavmagnetiserat": "oavmagnetiserad",
    "oavmagnetiserats": "oavmagnetiserad",
    "oavmagnetiserbara": "oavmagnetiserbar",
    "oavmagnetiserbarare": "oavmagnetiserbar",
    "oavmagnetiserbarares": "oavmagnetiserbar",
    "oavmagnetiserbaras": "oavmagnetiserbar",
    "oavmagnetiserbarast": "oavmagnetiserbar",
    "oavmagnetiserbaraste": "oavmagnetiserbar",
    "oavmagnetiserbarastes": "oavmagnetiserbar",
    "oavmagnetiserbarasts": "oavmagnetiserbar",
    "oavmagnetiserbare": "oavmagnetiserbar",
    "oavmagnetiserbares": "oavmagnetiserbar",
    "oavmagnetiserbarheten": "oavmagnetiserbarhet",
    "oavmagnetiserbarhetens": "oavmagnetiserbarhet",
    "oavmagnetiserbarhets": "oavmagnetiserbarhet",
    "oavmagnetiserbars": "oavmagnetiserbar",
    "oavmagnetiserbart": "oavmagnetiserbar",
    "oavmagnetiserbarts": "oavmagnetiserbar",
    "oavmaskade": "oavmaskad",
    "oavmaskades": "oavmaskad",
    "oavmaskads": "oavmaskad",
    "oavmaskat": "oavmaskad",
    "oavmaskats": "oavmaskad",
    "oavmastade": "oavmastad",
    "oavmastades": "oavmastad",
    "oavmastads": "oavmastad",
    "oavmastat": "oavmastad",
    "oavmastats": "oavmastad",
    "oavmattade": "oavmattad",
    "oavmattades": "oavmattad",
    "oavmattads": "oavmattad",
    "oavmattat": "oavmattad",
    "oavmattats": "oavmattad",
    "oavmätta": "oavmätt",
    "oavmättas": "oavmätt",
    "oavmätte": "oavmätt",
    "oavmättes": "oavmätt",
    "oavmättheten": "oavmätthet",
    "oavmätthetens": "oavmätthet",
    "oavmätthets": "oavmätthet",
    "oavmätts": "oavmätt",
    "oavnavlade": "oavnavlad",
    "oavnavlades": "oavnavlad",
    "oavnavlads": "oavnavlad",
    "oavnavlat": "oavnavlad",
    "oavnavlats": "oavnavlad",
    "oavnazifierade": "oavnazifierad",
    "oavnazifierades": "oavnazifierad",
    "oavnazifierads": "oavnazifierad",
    "oavnazifierat": "oavnazifierad",
    "oavnazifierats": "oavnazifierad",
    "oavnazifierbara": "oavnazifierbar",
    "oavnazifierbarare": "oavnazifierbar",
    "oavnazifierbarares": "oavnazifierbar",
    "oavnazifierbaras": "oavnazifierbar",
    "oavnazifierbarast": "oavnazifierbar",
    "oavnazifierbaraste": "oavnazifierbar",
    "oavnazifierbarastes": "oavnazifierbar",
    "oavnazifierbarasts": "oavnazifierbar",
    "oavnazifierbare": "oavnazifierbar",
    "oavnazifierbares": "oavnazifierbar",
    "oavnazifierbarheten": "oavnazifierbarhet",
    "oavnazifierbarhetens": "oavnazifierbarhet",
    "oavnazifierbarhets": "oavnazifierbarhet",
    "oavnazifierbars": "oavnazifierbar",
    "oavnazifierbart": "oavnazifierbar",
    "oavnazifierbarts": "oavnazifierbar",
    "oavpassade": "oavpassad",
    "oavpassades": "oavpassad",
    "oavpassads": "oavpassad",
    "oavpassat": "oavpassad",
    "oavpassats": "oavpassad",
    "oavpatrullerade": "oavpatrullerad",
    "oavpatrullerades": "oavpatrullerad",
    "oavpatrullerads": "oavpatrullerad",
    "oavpatrullerat": "oavpatrullerad",
    "oavpatrullerats": "oavpatrullerad",
    "oavpatrullerbara": "oavpatrullerbar",
    "oavpatrullerbarare": "oavpatrullerbar",
    "oavpatrullerbarares": "oavpatrullerbar",
    "oavpatrullerbaras": "oavpatrullerbar",
    "oavpatrullerbarast": "oavpatrullerbar",
    "oavpatrullerbaraste": "oavpatrullerbar",
    "oavpatrullerbarastes": "oavpatrullerbar",
    "oavpatrullerbarasts": "oavpatrullerbar",
    "oavpatrullerbare": "oavpatrullerbar",
    "oavpatrullerbares": "oavpatrullerbar",
    "oavpatrullerbarheten": "oavpatrullerbarhet",
    "oavpatrullerbarhetens": "oavpatrullerbarhet",
    "oavpatrullerbarhets": "oavpatrullerbarhet",
    "oavpatrullerbars": "oavpatrullerbar",
    "oavpatrullerbart": "oavpatrullerbar",
    "oavpatrullerbarts": "oavpatrullerbar",
    "oavplanade": "oavplanad",
    "oavplanades": "oavplanad",
    "oavplanads": "oavplanad",
    "oavplanat": "oavplanad",
    "oavplanats": "oavplanad",
    "oavpolitiserade": "oavpolitiserad",
    "oavpolitiserades": "oavpolitiserad",
    "oavpolitiserads": "oavpolitiserad",
    "oavpolitiserat": "oavpolitiserad",
    "oavpolitiserats": "oavpolitiserad",
    "oavpolitiserbara": "oavpolitiserbar",
    "oavpolitiserbarare": "oavpolitiserbar",
    "oavpolitiserbarares": "oavpolitiserbar",
    "oavpolitiserbaras": "oavpolitiserbar",
    "oavpolitiserbarast": "oavpolitiserbar",
    "oavpolitiserbaraste": "oavpolitiserbar",
    "oavpolitiserbarastes": "oavpolitiserbar",
    "oavpolitiserbarasts": "oavpolitiserbar",
    "oavpolitiserbare": "oavpolitiserbar",
    "oavpolitiserbares": "oavpolitiserbar",
    "oavpolitiserbarheten": "oavpolitiserbarhet",
    "oavpolitiserbarhetens": "oavpolitiserbarhet",
    "oavpolitiserbarhets": "oavpolitiserbarhet",
    "oavpolitiserbars": "oavpolitiserbar",
    "oavpolitiserbart": "oavpolitiserbar",
    "oavpolitiserbarts": "oavpolitiserbar",
    "oavpolletterade": "oavpolletterad",
    "oavpolletterades": "oavpolletterad",
    "oavpolletterads": "oavpolletterad",
    "oavpolletterat": "oavpolletterad",
    "oavpolletterats": "oavpolletterad",
    "oavpolletterbara": "oavpolletterbar",
    "oavpolletterbarare": "oavpolletterbar",
    "oavpolletterbarares": "oavpolletterbar",
    "oavpolletterbaras": "oavpolletterbar",
    "oavpolletterbarast": "oavpolletterbar",
    "oavpolletterbaraste": "oavpolletterbar",
    "oavpolletterbarastes": "oavpolletterbar",
    "oavpolletterbarasts": "oavpolletterbar",
    "oavpolletterbare": "oavpolletterbar",
    "oavpolletterbares": "oavpolletterbar",
    "oavpolletterbarheten": "oavpolletterbarhet",
    "oavpolletterbarhetens": "oavpolletterbarhet",
    "oavpolletterbarhets": "oavpolletterbarhet",
    "oavpolletterbars": "oavpolletterbar",
    "oavpolletterbart": "oavpolletterbar",
    "oavpolletterbarts": "oavpolletterbar",
    "oavporträtterade": "oavporträtterad",
    "oavporträtterades": "oavporträtterad",
    "oavporträtterads": "oavporträtterad",
    "oavporträtterat": "oavporträtterad",
    "oavporträtterats": "oavporträtterad",
    "oavporträtterbara": "oavporträtterbar",
    "oavporträtterbarare": "oavporträtterbar",
    "oavporträtterbarares": "oavporträtterbar",
    "oavporträtterbaras": "oavporträtterbar",
    "oavporträtterbarast": "oavporträtterbar",
    "oavporträtterbaraste": "oavporträtterbar",
    "oavporträtterbarastes": "oavporträtterbar",
    "oavporträtterbarasts": "oavporträtterbar",
    "oavporträtterbare": "oavporträtterbar",
    "oavporträtterbares": "oavporträtterbar",
    "oavporträtterbarheten": "oavporträtterbarhet",
    "oavporträtterbarhetens": "oavporträtterbarhet",
    "oavporträtterbarhets": "oavporträtterbarhet",
    "oavporträtterbars": "oavporträtterbar",
    "oavporträtterbart": "oavporträtterbar",
    "oavporträtterbarts": "oavporträtterbar",
    "oavpressade": "oavpressad",
    "oavpressades": "oavpressad",
    "oavpressads": "oavpressad",
    "oavpressat": "oavpressad",
    "oavpressats": "oavpressad",
    "oavreagerade": "oavreagerad",
    "oavreagerades": "oavreagerad",
    "oavreagerads": "oavreagerad",
    "oavreagerat": "oavreagerad",
    "oavreagerats": "oavreagerad",
    "oavreagerbara": "oavreagerbar",
    "oavreagerbarare": "oavreagerbar",
    "oavreagerbarares": "oavreagerbar",
    "oavreagerbaras": "oavreagerbar",
    "oavreagerbarast": "oavreagerbar",
    "oavreagerbaraste": "oavreagerbar",
    "oavreagerbarastes": "oavreagerbar",
    "oavreagerbarasts": "oavreagerbar",
    "oavreagerbare": "oavreagerbar",
    "oavreagerbares": "oavreagerbar",
    "oavreagerbarheten": "oavreagerbarhet",
    "oavreagerbarhetens": "oavreagerbarhet",
    "oavreagerbarhets": "oavreagerbarhet",
    "oavreagerbars": "oavreagerbar",
    "oavreagerbart": "oavreagerbar",
    "oavreagerbarts": "oavreagerbar",
    "oavregistrerade": "oavregistrerad",
    "oavregistrerades": "oavregistrerad",
    "oavregistrerads": "oavregistrerad",
    "oavregistrerat": "oavregistrerad",
    "oavregistrerats": "oavregistrerad",
    "oavregistrerbara": "oavregistrerbar",
    "oavregistrerbarare": "oavregistrerbar",
    "oavregistrerbarares": "oavregistrerbar",
    "oavregistrerbaras": "oavregistrerbar",
    "oavregistrerbarast": "oavregistrerbar",
    "oavregistrerbaraste": "oavregistrerbar",
    "oavregistrerbarastes": "oavregistrerbar",
    "oavregistrerbarasts": "oavregistrerbar",
    "oavregistrerbare": "oavregistrerbar",
    "oavregistrerbares": "oavregistrerbar",
    "oavregistrerbarheten": "oavregistrerbarhet",
    "oavregistrerbarhetens": "oavregistrerbarhet",
    "oavregistrerbarhets": "oavregistrerbarhet",
    "oavregistrerbars": "oavregistrerbar",
    "oavregistrerbart": "oavregistrerbar",
    "oavregistrerbarts": "oavregistrerbar",
    "oavreglerade": "oavreglerad",
    "oavreglerades": "oavreglerad",
    "oavreglerads": "oavreglerad",
    "oavreglerat": "oavreglerad",
    "oavreglerats": "oavreglerad",
    "oavreglerbara": "oavreglerbar",
    "oavreglerbarare": "oavreglerbar",
    "oavreglerbarares": "oavreglerbar",
    "oavreglerbaras": "oavreglerbar",
    "oavreglerbarast": "oavreglerbar",
    "oavreglerbaraste": "oavreglerbar",
    "oavreglerbarastes": "oavreglerbar",
    "oavreglerbarasts": "oavreglerbar",
    "oavreglerbare": "oavreglerbar",
    "oavreglerbares": "oavreglerbar",
    "oavreglerbarheten": "oavreglerbarhet",
    "oavreglerbarhetens": "oavreglerbarhet",
    "oavreglerbarhets": "oavreglerbarhet",
    "oavreglerbars": "oavreglerbar",
    "oavreglerbart": "oavreglerbar",
    "oavreglerbarts": "oavreglerbar",
    "oavresta": "oavrest",
    "oavrestas": "oavrest",
    "oavreste": "oavrest",
    "oavrestes": "oavrest",
    "oavrests": "oavrest",
    "oavromantiserade": "oavromantiserad",
    "oavromantiserades": "oavromantiserad",
    "oavromantiserads": "oavromantiserad",
    "oavromantiserat": "oavromantiserad",
    "oavromantiserats": "oavromantiserad",
    "oavromantiserbara": "oavromantiserbar",
    "oavromantiserbarare": "oavromantiserbar",
    "oavromantiserbarares": "oavromantiserbar",
    "oavromantiserbaras": "oavromantiserbar",
    "oavromantiserbarast": "oavromantiserbar",
    "oavromantiserbaraste": "oavromantiserbar",
    "oavromantiserbarastes": "oavromantiserbar",
    "oavromantiserbarasts": "oavromantiserbar",
    "oavromantiserbare": "oavromantiserbar",
    "oavromantiserbares": "oavromantiserbar",
    "oavromantiserbarheten": "oavromantiserbarhet",
    "oavromantiserbarhetens": "oavromantiserbarhet",
    "oavromantiserbarhets": "oavromantiserbarhet",
    "oavromantiserbars": "oavromantiserbar",
    "oavromantiserbart": "oavromantiserbar",
    "oavromantiserbarts": "oavromantiserbar",
    "oavrundade": "oavrundad",
    "oavrundades": "oavrundad",
    "oavrundads": "oavrundad",
    "oavrundat": "oavrundad",
    "oavrundats": "oavrundad",
    "oavrustade": "oavrustad",
    "oavrustades": "oavrustad",
    "oavrustads": "oavrustad",
    "oavrustat": "oavrustad",
    "oavrustats": "oavrustad",
    "oavräknade": "oavräknad",
    "oavräknades": "oavräknad",
    "oavräknads": "oavräknad",
    "oavräknat": "oavräknad",
    "oavräknats": "oavräknad",
    "oavrättade": "oavrättad",
    "oavrättades": "oavrättad",
    "oavrättads": "oavrättad",
    "oavrättat": "oavrättad",
    "oavrättats": "oavrättad",
    "oavsaltade": "oavsaltad",
    "oavsaltades": "oavsaltad",
    "oavsaltads": "oavsaltad",
    "oavsaltat": "oavsaltad",
    "oavsaltats": "oavsaltad",
    "oavsedda": "oavsedd",
    "oavseddare": "oavsedd",
    "oavseddares": "oavsedd",
    "oavseddas": "oavsedd",
    "oavseddast": "oavsedd",
    "oavseddaste": "oavsedd",
    "oavseddastes": "oavsedd",
    "oavseddasts": "oavsedd",
    "oavsedde": "oavsedd",
    "oavseddes": "oavsedd",
    "oavsedds": "oavsedd",
    "oavseglade": "oavseglad",
    "oavseglades": "oavseglad",
    "oavseglads": "oavseglad",
    "oavseglat": "oavseglad",
    "oavseglats": "oavseglad",
    "oavsett": "oavsedd",
    "oavsetts": "oavsedd",
    "oavsiktliga": "oavsiktlig",
    "oavsiktligare": "oavsiktlig",
    "oavsiktligares": "oavsiktlig",
    "oavsiktligas": "oavsiktlig",
    "oavsiktligast": "oavsiktlig",
    "oavsiktligaste": "oavsiktlig",
    "oavsiktligastes": "oavsiktlig",
    "oavsiktligasts": "oavsiktlig",
    "oavsiktlige": "oavsiktlig",
    "oavsiktliges": "oavsiktlig",
    "oavsiktligheten": "oavsiktlighet",
    "oavsiktlighetens": "oavsiktlighet",
    "oavsiktlighets": "oavsiktlighet",
    "oavsiktligs": "oavsiktlig",
    "oavsiktligt": "oavsiktlig",
    "oavsiktligts": "oavsiktlig",
    "oavskaffade": "oavskaffad",
    "oavskaffades": "oavskaffad",
    "oavskaffads": "oavskaffad",
    "oavskaffat": "oavskaffad",
    "oavskaffats": "oavskaffad",
    "oavskavde": "oavskavd",
    "oavskavdes": "oavskavd",
    "oavskavds": "oavskavd",
    "oavskavt": "oavskavd",
    "oavskavts": "oavskavd",
    "oavskedade": "oavskedad",
    "oavskedades": "oavskedad",
    "oavskedads": "oavskedad",
    "oavskedat": "oavskedad",
    "oavskedats": "oavskedad",
    "oavskräckta": "oavskräckt",
    "oavskräcktas": "oavskräckt",
    "oavskräckte": "oavskräckt",
    "oavskräcktes": "oavskräckt",
    "oavskräckts": "oavskräckt",
    "oavskärmade": "oavskärmad",
    "oavskärmades": "oavskärmad",
    "oavskärmads": "oavskärmad",
    "oavskärmat": "oavskärmad",
    "oavskärmats": "oavskärmad",
    "oavslipade": "oavslipad",
    "oavslipades": "oavslipad",
    "oavslipads": "oavslipad",
    "oavslipat": "oavslipad",
    "oavslipats": "oavslipad",
    "oavslutade": "oavslutad",
    "oavslutades": "oavslutad",
    "oavslutads": "oavslutad",
    "oavslutat": "oavslutad",
    "oavslutats": "oavslutad",
    "oavslöjade": "oavslöjad",
    "oavslöjades": "oavslöjad",
    "oavslöjads": "oavslöjad",
    "oavslöjat": "oavslöjad",
    "oavslöjats": "oavslöjad",
    "oavsmakade": "oavsmakad",
    "oavsmakades": "oavsmakad",
    "oavsmakads": "oavsmakad",
    "oavsmakat": "oavsmakad",
    "oavsmakats": "oavsmakad",
    "oavsmalnade": "oavsmalnad",
    "oavsmalnades": "oavsmalnad",
    "oavsmalnads": "oavsmalnad",
    "oavsmalnat": "oavsmalnad",
    "oavsmalnats": "oavsmalnad",
    "oavsnörde": "oavsnörd",
    "oavsnördes": "oavsnörd",
    "oavsnörds": "oavsnörd",
    "oavsnört": "oavsnörd",
    "oavsnörts": "oavsnörd",
    "oavsocialiserade": "oavsocialiserad",
    "oavsocialiserades": "oavsocialiserad",
    "oavsocialiserads": "oavsocialiserad",
    "oavsocialiserat": "oavsocialiserad",
    "oavsocialiserats": "oavsocialiserad",
    "oavsocialiserbara": "oavsocialiserbar",
    "oavsocialiserbarare": "oavsocialiserbar",
    "oavsocialiserbarares": "oavsocialiserbar",
    "oavsocialiserbaras": "oavsocialiserbar",
    "oavsocialiserbarast": "oavsocialiserbar",
    "oavsocialiserbaraste": "oavsocialiserbar",
    "oavsocialiserbarastes": "oavsocialiserbar",
    "oavsocialiserbarasts": "oavsocialiserbar",
    "oavsocialiserbare": "oavsocialiserbar",
    "oavsocialiserbares": "oavsocialiserbar",
    "oavsocialiserbarheten": "oavsocialiserbarhet",
    "oavsocialiserbarhetens": "oavsocialiserbarhet",
    "oavsocialiserbarhets": "oavsocialiserbarhet",
    "oavsocialiserbars": "oavsocialiserbar",
    "oavsocialiserbart": "oavsocialiserbar",
    "oavsocialiserbarts": "oavsocialiserbar",
    "oavsomnade": "oavsomnad",
    "oavsomnades": "oavsomnad",
    "oavsomnads": "oavsomnad",
    "oavsomnat": "oavsomnad",
    "oavsomnats": "oavsomnad",
    "oavspeglade": "oavspeglad",
    "oavspeglades": "oavspeglad",
    "oavspeglads": "oavspeglad",
    "oavspeglat": "oavspeglad",
    "oavspeglats": "oavspeglad",
    "oavspelade": "oavspelad",
    "oavspelades": "oavspelad",
    "oavspelads": "oavspelad",
    "oavspelat": "oavspelad",
    "oavspelats": "oavspelad",
    "oavspisade": "oavspisad",
    "oavspisades": "oavspisad",
    "oavspisads": "oavspisad",
    "oavspisat": "oavspisad",
    "oavspisats": "oavspisad",
    "oavspärrade": "oavspärrad",
    "oavspärrades": "oavspärrad",
    "oavspärrads": "oavspärrad",
    "oavspärrat": "oavspärrad",
    "oavspärrats": "oavspärrad",
    "oavstaliniserade": "oavstaliniserad",
    "oavstaliniserades": "oavstaliniserad",
    "oavstaliniserads": "oavstaliniserad",
    "oavstaliniserat": "oavstaliniserad",
    "oavstaliniserats": "oavstaliniserad",
    "oavstaliniserbara": "oavstaliniserbar",
    "oavstaliniserbarare": "oavstaliniserbar",
    "oavstaliniserbarares": "oavstaliniserbar",
    "oavstaliniserbaras": "oavstaliniserbar",
    "oavstaliniserbarast": "oavstaliniserbar",
    "oavstaliniserbaraste": "oavstaliniserbar",
    "oavstaliniserbarastes": "oavstaliniserbar",
    "oavstaliniserbarasts": "oavstaliniserbar",
    "oavstaliniserbare": "oavstaliniserbar",
    "oavstaliniserbares": "oavstaliniserbar",
    "oavstaliniserbarheten": "oavstaliniserbarhet",
    "oavstaliniserbarhetens": "oavstaliniserbarhet",
    "oavstaliniserbarhets": "oavstaliniserbarhet",
    "oavstaliniserbars": "oavstaliniserbar",
    "oavstaliniserbart": "oavstaliniserbar",
    "oavstaliniserbarts": "oavstaliniserbar",
    "oavstannade": "oavstannad",
    "oavstannades": "oavstannad",
    "oavstannads": "oavstannad",
    "oavstannat": "oavstannad",
    "oavstannats": "oavstannad",
    "oavstavade": "oavstavad",
    "oavstavades": "oavstavad",
    "oavstavads": "oavstavad",
    "oavstavat": "oavstavad",
    "oavstavats": "oavstavad",
    "oavstressade": "oavstressad",
    "oavstressades": "oavstressad",
    "oavstressads": "oavstressad",
    "oavstressat": "oavstressad",
    "oavstressats": "oavstressad",
    "oavstyckade": "oavstyckad",
    "oavstyckades": "oavstyckad",
    "oavstyckads": "oavstyckad",
    "oavstyckat": "oavstyckad",
    "oavstyckats": "oavstyckad",
    "oavstyrde": "oavstyrd",
    "oavstyrdes": "oavstyrd",
    "oavstyrds": "oavstyrd",
    "oavstyrkta": "oavstyrkt",
    "oavstyrktas": "oavstyrkt",
    "oavstyrkte": "oavstyrkt",
    "oavstyrktes": "oavstyrkt",
    "oavstyrkts": "oavstyrkt",
    "oavstyrt": "oavstyrd",
    "oavstyrts": "oavstyrd",
    "oavställde": "oavställd",
    "oavställdes": "oavställd",
    "oavställds": "oavställd",
    "oavställt": "oavställd",
    "oavställts": "oavställd",
    "oavstämde": "oavstämd",
    "oavstämdes": "oavstämd",
    "oavstämds": "oavstämd",
    "oavstämt": "oavstämd",
    "oavstämts": "oavstämd",
    "oavstörde": "oavstörd",
    "oavstördes": "oavstörd",
    "oavstörds": "oavstörd",
    "oavstört": "oavstörd",
    "oavstörts": "oavstörd",
    "oavstötta": "oavstött",
    "oavstöttas": "oavstött",
    "oavstötte": "oavstött",
    "oavstöttes": "oavstött",
    "oavstötts": "oavstött",
    "oavsvalnade": "oavsvalnad",
    "oavsvalnades": "oavsvalnad",
    "oavsvalnads": "oavsvalnad",
    "oavsvalnat": "oavsvalnad",
    "oavsvalnats": "oavsvalnad",
    "oavsvavlade": "oavsvavlad",
    "oavsvavlades": "oavsvavlad",
    "oavsvavlads": "oavsvavlad",
    "oavsvavlat": "oavsvavlad",
    "oavsvavlats": "oavsvavlad",
    "oavsynade": "oavsynad",
    "oavsynades": "oavsynad",
    "oavsynads": "oavsynad",
    "oavsynat": "oavsynad",
    "oavsynats": "oavsynad",
    "oavsände": "oavsänd",
    "oavsändes": "oavsänd",
    "oavsänds": "oavsänd",
    "oavsänt": "oavsänd",
    "oavsänts": "oavsänd",
    "oavsättliga": "oavsättlig",
    "oavsättligare": "oavsättlig",
    "oavsättligares": "oavsättlig",
    "oavsättligas": "oavsättlig",
    "oavsättligast": "oavsättlig",
    "oavsättligaste": "oavsättlig",
    "oavsättligastes": "oavsättlig",
    "oavsättligasts": "oavsättlig",
    "oavsättlige": "oavsättlig",
    "oavsättliges": "oavsättlig",
    "oavsättligheten": "oavsättlighet",
    "oavsättlighetens": "oavsättlighet",
    "oavsättlighets": "oavsättlighet",
    "oavsättligs": "oavsättlig",
    "oavsättligt": "oavsättlig",
    "oavsättligts": "oavsättlig",
    "oavsökta": "oavsökt",
    "oavsöktas": "oavsökt",
    "oavsökte": "oavsökt",
    "oavsöktes": "oavsökt",
    "oavsökts": "oavsökt",
    "oavsöndrade": "oavsöndrad",
    "oavsöndrades": "oavsöndrad",
    "oavsöndrads": "oavsöndrad",
    "oavsöndrat": "oavsöndrad",
    "oavsöndrats": "oavsöndrad",
    "oavtackade": "oavtackad",
    "oavtackades": "oavtackad",
    "oavtackads": "oavtackad",
    "oavtackat": "oavtackad",
    "oavtackats": "oavtackad",
    "oavtalade": "oavtalad",
    "oavtalades": "oavtalad",
    "oavtalads": "oavtalad",
    "oavtalat": "oavtalad",
    "oavtalats": "oavtalad",
    "oavtappade": "oavtappad",
    "oavtappades": "oavtappad",
    "oavtappads": "oavtappad",
    "oavtappat": "oavtappad",
    "oavtappats": "oavtappad",
    "oavtecknade": "oavtecknad",
    "oavtecknades": "oavtecknad",
    "oavtecknads": "oavtecknad",
    "oavtecknat": "oavtecknad",
    "oavtecknats": "oavtecknad",
    "oavtjänade": "oavtjänad",
    "oavtjänades": "oavtjänad",
    "oavtjänads": "oavtjänad",
    "oavtjänat": "oavtjänad",
    "oavtjänats": "oavtjänad",
    "oavtonade": "oavtonad",
    "oavtonades": "oavtonad",
    "oavtonads": "oavtonad",
    "oavtonat": "oavtonad",
    "oavtonats": "oavtonad",
    "oavtrappade": "oavtrappad",
    "oavtrappades": "oavtrappad",
    "oavtrappads": "oavtrappad",
    "oavtrappat": "oavtrappad",
    "oavtrappats": "oavtrappad",
    "oavtrubbade": "oavtrubbad",
    "oavtrubbades": "oavtrubbad",
    "oavtrubbads": "oavtrubbad",
    "oavtrubbat": "oavtrubbad",
    "oavtrubbats": "oavtrubbad",
    "oavtunnade": "oavtunnad",
    "oavtunnades": "oavtunnad",
    "oavtunnads": "oavtunnad",
    "oavtunnat": "oavtunnad",
    "oavtunnats": "oavtunnad",
    "oavtäckta": "oavtäckt",
    "oavtäcktas": "oavtäckt",
    "oavtäckte": "oavtäckt",
    "oavtäcktes": "oavtäckt",
    "oavtäckts": "oavtäckt",
    "oavtågade": "oavtågad",
    "oavtågades": "oavtågad",
    "oavtågads": "oavtågad",
    "oavtågat": "oavtågad",
    "oavtågats": "oavtågad",
    "oavvaktade": "oavvaktad",
    "oavvaktades": "oavvaktad",
    "oavvaktads": "oavvaktad",
    "oavvaktat": "oavvaktad",
    "oavvaktats": "oavvaktad",
    "oavvattnade": "oavvattnad",
    "oavvattnades": "oavvattnad",
    "oavvattnads": "oavvattnad",
    "oavvattnat": "oavvattnad",
    "oavvattnats": "oavvattnad",
    "oavvecklade": "oavvecklad",
    "oavvecklades": "oavvecklad",
    "oavvecklads": "oavvecklad",
    "oavvecklat": "oavvecklad",
    "oavvecklats": "oavvecklad",
    "oavverkade": "oavverkad",
    "oavverkades": "oavverkad",
    "oavverkads": "oavverkad",
    "oavverkat": "oavverkad",
    "oavverkats": "oavverkad",
    "oavvisade": "oavvisad",
    "oavvisades": "oavvisad",
    "oavvisads": "oavvisad",
    "oavvisat": "oavvisad",
    "oavvisats": "oavvisad",
    "oavvisbara": "oavvisbar",
    "oavvisbarare": "oavvisbar",
    "oavvisbarares": "oavvisbar",
    "oavvisbaras": "oavvisbar",
    "oavvisbarast": "oavvisbar",
    "oavvisbaraste": "oavvisbar",
    "oavvisbarastes": "oavvisbar",
    "oavvisbarasts": "oavvisbar",
    "oavvisbare": "oavvisbar",
    "oavvisbares": "oavvisbar",
    "oavvisbarheten": "oavvisbarhet",
    "oavvisbarhetens": "oavvisbarhet",
    "oavvisbarhets": "oavvisbarhet",
    "oavvisbars": "oavvisbar",
    "oavvisbart": "oavvisbar",
    "oavvisbarts": "oavvisbar",
    "oavvisliga": "oavvislig",
    "oavvisligare": "oavvislig",
    "oavvisligares": "oavvislig",
    "oavvisligas": "oavvislig",
    "oavvisligast": "oavvislig",
    "oavvisligaste": "oavvislig",
    "oavvisligastes": "oavvislig",
    "oavvisligasts": "oavvislig",
    "oavvislige": "oavvislig",
    "oavvisliges": "oavvislig",
    "oavvisligheten": "oavvislighet",
    "oavvislighetens": "oavvislighet",
    "oavvislighets": "oavvislighet",
    "oavvisligs": "oavvislig",
    "oavvisligt": "oavvislig",
    "oavvisligts": "oavvislig",
    "oavvitade": "oavvitad",
    "oavvitades": "oavvitad",
    "oavvitads": "oavvitad",
    "oavvitat": "oavvitad",
    "oavvitats": "oavvitad",
    "oavvittrade": "oavvittrad",
    "oavvittrades": "oavvittrad",
    "oavvittrads": "oavvittrad",
    "oavvittrat": "oavvittrad",
    "oavvittrats": "oavvittrad",
    "oavvägde": "oavvägd",
    "oavvägdes": "oavvägd",
    "oavvägds": "oavvägd",
    "oavvägt": "oavvägd",
    "oavvägts": "oavvägd",
    "oavvända": "oavvänd",
    "oavvändare": "oavvänd",
    "oavvändares": "oavvänd",
    "oavvändas": "oavvänd",
    "oavvändast": "oavvänd",
    "oavvändaste": "oavvänd",
    "oavvändastes": "oavvänd",
    "oavvändasts": "oavvänd",
    "oavvände": "oavvänd",
    "oavvändes": "oavvänd",
    "oavvänds": "oavvänd",
    "oavvänt": "oavvänd",
    "oavvänts": "oavvänd",
    "oavväpnade": "oavväpnad",
    "oavväpnades": "oavväpnad",
    "oavväpnads": "oavväpnad",
    "oavväpnat": "oavväpnad",
    "oavväpnats": "oavväpnad",
    "oavvärjde": "oavvärjd",
    "oavvärjdes": "oavvärjd",
    "oavvärjds": "oavvärjd",
    "oavvärjt": "oavvärjd",
    "oavvärjts": "oavvärjd",
    "oavytterliga": "oavytterlig",
    "oavytterligare": "oavytterlig",
    "oavytterligares": "oavytterlig",
    "oavytterligas": "oavytterlig",
    "oavytterligast": "oavytterlig",
    "oavytterligaste": "oavytterlig",
    "oavytterligastes": "oavytterlig",
    "oavytterligasts": "oavytterlig",
    "oavytterlige": "oavytterlig",
    "oavytterliges": "oavytterlig",
    "oavytterligheten": "oavytterlighet",
    "oavytterlighetens": "oavytterlighet",
    "oavytterlighets": "oavytterlighet",
    "oavytterligs": "oavytterlig",
    "oavytterligt": "oavytterlig",
    "oavytterligts": "oavytterlig",
    "oavyttrade": "oavyttrad",
    "oavyttrades": "oavyttrad",
    "oavyttrads": "oavyttrad",
    "oavyttrat": "oavyttrad",
    "oavyttrats": "oavyttrad",
    "oaxiomatiserade": "oaxiomatiserad",
    "oaxiomatiserades": "oaxiomatiserad",
    "oaxiomatiserads": "oaxiomatiserad",
    "oaxiomatiserat": "oaxiomatiserad",
    "oaxiomatiserats": "oaxiomatiserad",
    "oaxiomatiserbara": "oaxiomatiserbar",
    "oaxiomatiserbarare": "oaxiomatiserbar",
    "oaxiomatiserbarares": "oaxiomatiserbar",
    "oaxiomatiserbaras": "oaxiomatiserbar",
    "oaxiomatiserbarast": "oaxiomatiserbar",
    "oaxiomatiserbaraste": "oaxiomatiserbar",
    "oaxiomatiserbarastes": "oaxiomatiserbar",
    "oaxiomatiserbarasts": "oaxiomatiserbar",
    "oaxiomatiserbare": "oaxiomatiserbar",
    "oaxiomatiserbares": "oaxiomatiserbar",
    "oaxiomatiserbarheten": "oaxiomatiserbarhet",
    "oaxiomatiserbarhetens": "oaxiomatiserbarhet",
    "oaxiomatiserbarhets": "oaxiomatiserbarhet",
    "oaxiomatiserbars": "oaxiomatiserbar",
    "oaxiomatiserbart": "oaxiomatiserbar",
    "oaxiomatiserbarts": "oaxiomatiserbar",
    "oaxlade": "oaxlad",
    "oaxlades": "oaxlad",
    "oaxlads": "oaxlad",
    "oaxlat": "oaxlad",
    "oaxlats": "oaxlad",
    "obackade": "obackad",
    "obackades": "obackad",
    "obackads": "obackad",
    "obackat": "obackad",
    "obackats": "obackad",
    "obackupade": "obackupad",
    "obackupades": "obackupad",
    "obackupads": "obackupad",
    "obackupat": "obackupad",
    "obackupats": "obackupad",
    "obackuppade": "obackuppad",
    "obackuppades": "obackuppad",
    "obackuppads": "obackuppad",
    "obackuppat": "obackuppad",
    "obackuppats": "obackuppad",
    "obadade": "obadad",
    "obadades": "obadad",
    "obadads": "obadad",
    "obadat": "obadad",
    "obadats": "obadad",
    "obaddade": "obaddad",
    "obaddades": "obaddad",
    "obaddads": "obaddad",
    "obaddat": "obaddad",
    "obaddats": "obaddad",
    "obagatelliserade": "obagatelliserad",
    "obagatelliserades": "obagatelliserad",
    "obagatelliserads": "obagatelliserad",
    "obagatelliserat": "obagatelliserad",
    "obagatelliserats": "obagatelliserad",
    "obagatelliserbara": "obagatelliserbar",
    "obagatelliserbarare": "obagatelliserbar",
    "obagatelliserbarares": "obagatelliserbar",
    "obagatelliserbaras": "obagatelliserbar",
    "obagatelliserbarast": "obagatelliserbar",
    "obagatelliserbaraste": "obagatelliserbar",
    "obagatelliserbarastes": "obagatelliserbar",
    "obagatelliserbarasts": "obagatelliserbar",
    "obagatelliserbare": "obagatelliserbar",
    "obagatelliserbares": "obagatelliserbar",
    "obagatelliserbarheten": "obagatelliserbarhet",
    "obagatelliserbarhetens": "obagatelliserbarhet",
    "obagatelliserbarhets": "obagatelliserbarhet",
    "obagatelliserbars": "obagatelliserbar",
    "obagatelliserbart": "obagatelliserbar",
    "obagatelliserbarts": "obagatelliserbar",
    "obaissade": "obaissad",
    "obaissades": "obaissad",
    "obaissads": "obaissad",
    "obaissat": "obaissad",
    "obaissats": "obaissad",
    "obajsade": "obajsad",
    "obajsades": "obajsad",
    "obajsads": "obajsad",
    "obajsat": "obajsad",
    "obajsats": "obajsad",
    "obakade": "obakad",
    "obakades": "obakad",
    "obakads": "obakad",
    "obakat": "obakad",
    "obakats": "obakad",
    "obakdantade": "obakdantad",
    "obakdantades": "obakdantad",
    "obakdantads": "obakdantad",
    "obakdantat": "obakdantad",
    "obakdantats": "obakdantad",
    "obaktalade": "obaktalad",
    "obaktalades": "obaktalad",
    "obaktalads": "obaktalad",
    "obaktalat": "obaktalad",
    "obaktalats": "obaktalad",
    "obalade": "obalad",
    "obalades": "obalad",
    "obalads": "obalad",
    "obalansen": "obalans",
    "obalansens": "obalans",
    "obalanserade": "obalanserad",
    "obalanserades": "obalanserad",
    "obalanserads": "obalanserad",
    "obalanserat": "obalanserad",
    "obalanserats": "obalanserad",
    "obalanserbara": "obalanserbar",
    "obalanserbarare": "obalanserbar",
    "obalanserbarares": "obalanserbar",
    "obalanserbaras": "obalanserbar",
    "obalanserbarast": "obalanserbar",
    "obalanserbaraste": "obalanserbar",
    "obalanserbarastes": "obalanserbar",
    "obalanserbarasts": "obalanserbar",
    "obalanserbare": "obalanserbar",
    "obalanserbares": "obalanserbar",
    "obalanserbarheten": "obalanserbarhet",
    "obalanserbarhetens": "obalanserbarhet",
    "obalanserbarhets": "obalanserbarhet",
    "obalanserbars": "obalanserbar",
    "obalanserbart": "obalanserbar",
    "obalanserbarts": "obalanserbar",
    "obalat": "obalad",
    "obalats": "obalad",
    "oballoterade": "oballoterad",
    "oballoterades": "oballoterad",
    "oballoterads": "oballoterad",
    "oballoterat": "oballoterad",
    "oballoterats": "oballoterad",
    "oballoterbara": "oballoterbar",
    "oballoterbarare": "oballoterbar",
    "oballoterbarares": "oballoterbar",
    "oballoterbaras": "oballoterbar",
    "oballoterbarast": "oballoterbar",
    "oballoterbaraste": "oballoterbar",
    "oballoterbarastes": "oballoterbar",
    "oballoterbarasts": "oballoterbar",
    "oballoterbare": "oballoterbar",
    "oballoterbares": "oballoterbar",
    "oballoterbarheten": "oballoterbarhet",
    "oballoterbarhetens": "oballoterbarhet",
    "oballoterbarhets": "oballoterbarhet",
    "oballoterbars": "oballoterbar",
    "oballoterbart": "oballoterbar",
    "oballoterbarts": "oballoterbar",
    "obalsamerade": "obalsamerad",
    "obalsamerades": "obalsamerad",
    "obalsamerads": "obalsamerad",
    "obalsamerat": "obalsamerad",
    "obalsamerats": "obalsamerad",
    "obalsamerbara": "obalsamerbar",
    "obalsamerbarare": "obalsamerbar",
    "obalsamerbarares": "obalsamerbar",
    "obalsamerbaras": "obalsamerbar",
    "obalsamerbarast": "obalsamerbar",
    "obalsamerbaraste": "obalsamerbar",
    "obalsamerbarastes": "obalsamerbar",
    "obalsamerbarasts": "obalsamerbar",
    "obalsamerbare": "obalsamerbar",
    "obalsamerbares": "obalsamerbar",
    "obalsamerbarheten": "obalsamerbarhet",
    "obalsamerbarhetens": "obalsamerbarhet",
    "obalsamerbarhets": "obalsamerbarhet",
    "obalsamerbars": "obalsamerbar",
    "obalsamerbart": "obalsamerbar",
    "obalsamerbarts": "obalsamerbar",
    "obanade": "obanad",
    "obanades": "obanad",
    "obanads": "obanad",
    "obanaliserade": "obanaliserad",
    "obanaliserades": "obanaliserad",
    "obanaliserads": "obanaliserad",
    "obanaliserat": "obanaliserad",
    "obanaliserats": "obanaliserad",
    "obanaliserbara": "obanaliserbar",
    "obanaliserbarare": "obanaliserbar",
    "obanaliserbarares": "obanaliserbar",
    "obanaliserbaras": "obanaliserbar",
    "obanaliserbarast": "obanaliserbar",
    "obanaliserbaraste": "obanaliserbar",
    "obanaliserbarastes": "obanaliserbar",
    "obanaliserbarasts": "obanaliserbar",
    "obanaliserbare": "obanaliserbar",
    "obanaliserbares": "obanaliserbar",
    "obanaliserbarheten": "obanaliserbarhet",
    "obanaliserbarhetens": "obanaliserbarhet",
    "obanaliserbarhets": "obanaliserbarhet",
    "obanaliserbars": "obanaliserbar",
    "obanaliserbart": "obanaliserbar",
    "obanaliserbarts": "obanaliserbar",
    "obanat": "obanad",
    "obanats": "obanad",
    "obandade": "obandad",
    "obandades": "obandad",
    "obandads": "obandad",
    "obandat": "obandad",
    "obandats": "obandad",
    "obankade": "obankad",
    "obankades": "obankad",
    "obankads": "obankad",
    "obankat": "obankad",
    "obankats": "obankad",
    "obankrutterade": "obankrutterad",
    "obankrutterades": "obankrutterad",
    "obankrutterads": "obankrutterad",
    "obankrutterat": "obankrutterad",
    "obankrutterats": "obankrutterad",
    "obankrutterbara": "obankrutterbar",
    "obankrutterbarare": "obankrutterbar",
    "obankrutterbarares": "obankrutterbar",
    "obankrutterbaras": "obankrutterbar",
    "obankrutterbarast": "obankrutterbar",
    "obankrutterbaraste": "obankrutterbar",
    "obankrutterbarastes": "obankrutterbar",
    "obankrutterbarasts": "obankrutterbar",
    "obankrutterbare": "obankrutterbar",
    "obankrutterbares": "obankrutterbar",
    "obankrutterbarheten": "obankrutterbarhet",
    "obankrutterbarhetens": "obankrutterbarhet",
    "obankrutterbarhets": "obankrutterbarhet",
    "obankrutterbars": "obankrutterbar",
    "obankrutterbart": "obankrutterbar",
    "obankrutterbarts": "obankrutterbar",
    "obannade": "obannad",
    "obannades": "obannad",
    "obannads": "obannad",
    "obannat": "obannad",
    "obannats": "obannad",
    "obannlysta": "obannlyst",
    "obannlystas": "obannlyst",
    "obannlyste": "obannlyst",
    "obannlystes": "obannlyst",
    "obannlysts": "obannlyst",
    "obantade": "obantad",
    "obantades": "obantad",
    "obantads": "obantad",
    "obantat": "obantad",
    "obantats": "obantad",
    "obarkade": "obarkad",
    "obarkades": "obarkad",
    "obarkads": "obarkad",
    "obarkat": "obarkad",
    "obarkats": "obarkad",
    "obarlastade": "obarlastad",
    "obarlastades": "obarlastad",
    "obarlastads": "obarlastad",
    "obarlastat": "obarlastad",
    "obarlastats": "obarlastad",
    "obarmhärtiga": "obarmhärtig",
    "obarmhärtigare": "obarmhärtig",
    "obarmhärtigares": "obarmhärtig",
    "obarmhärtigas": "obarmhärtig",
    "obarmhärtigast": "obarmhärtig",
    "obarmhärtigaste": "obarmhärtig",
    "obarmhärtigastes": "obarmhärtig",
    "obarmhärtigasts": "obarmhärtig",
    "obarmhärtige": "obarmhärtig",
    "obarmhärtiges": "obarmhärtig",
    "obarmhärtigheten": "obarmhärtighet",
    "obarmhärtighetens": "obarmhärtighet",
    "obarmhärtighets": "obarmhärtighet",
    "obarmhärtigs": "obarmhärtig",
    "obarmhärtigt": "obarmhärtig",
    "obarmhärtigts": "obarmhärtig",
    "obarrade": "obarrad",
    "obarrades": "obarrad",
    "obarrads": "obarrad",
    "obarrat": "obarrad",
    "obarrats": "obarrad",
    "obarrikaderade": "obarrikaderad",
    "obarrikaderades": "obarrikaderad",
    "obarrikaderads": "obarrikaderad",
    "obarrikaderat": "obarrikaderad",
    "obarrikaderats": "obarrikaderad",
    "obarrikaderbara": "obarrikaderbar",
    "obarrikaderbarare": "obarrikaderbar",
    "obarrikaderbarares": "obarrikaderbar",
    "obarrikaderbaras": "obarrikaderbar",
    "obarrikaderbarast": "obarrikaderbar",
    "obarrikaderbaraste": "obarrikaderbar",
    "obarrikaderbarastes": "obarrikaderbar",
    "obarrikaderbarasts": "obarrikaderbar",
    "obarrikaderbare": "obarrikaderbar",
    "obarrikaderbares": "obarrikaderbar",
    "obarrikaderbarheten": "obarrikaderbarhet",
    "obarrikaderbarhetens": "obarrikaderbarhet",
    "obarrikaderbarhets": "obarrikaderbarhet",
    "obarrikaderbars": "obarrikaderbar",
    "obarrikaderbart": "obarrikaderbar",
    "obarrikaderbarts": "obarrikaderbar",
    "obaserade": "obaserad",
    "obaserades": "obaserad",
    "obaserads": "obaserad",
    "obaserat": "obaserad",
    "obaserats": "obaserad",
    "obaserbara": "obaserbar",
    "obaserbarare": "obaserbar",
    "obaserbarares": "obaserbar",
    "obaserbaras": "obaserbar",
    "obaserbarast": "obaserbar",
    "obaserbaraste": "obaserbar",
    "obaserbarastes": "obaserbar",
    "obaserbarasts": "obaserbar",
    "obaserbare": "obaserbar",
    "obaserbares": "obaserbar",
    "obaserbarheten": "obaserbarhet",
    "obaserbarhetens": "obaserbarhet",
    "obaserbarhets": "obaserbarhet",
    "obaserbars": "obaserbar",
    "obaserbart": "obaserbar",
    "obaserbarts": "obaserbar",
    "obastade": "obastad",
    "obastades": "obastad",
    "obastads": "obastad",
    "obastat": "obastad",
    "obastats": "obastad",
    "obaxade": "obaxad",
    "obaxades": "obaxad",
    "obaxads": "obaxad",
    "obaxat": "obaxad",
    "obaxats": "obaxad",
    "obducenten": "obducent",
    "obducentens": "obducent",
    "obducenter": "obducent",
    "obducenterna": "obducent",
    "obducenternas": "obducent",
    "obducenters": "obducent",
    "obducents": "obducent",
    "obducerad": "obducera",
    "obducerade": "obducera",
    "obducerades": "obducera",
    "obducerads": "obducera",
    "obducerande": "obducera",
    "obduceranden": "obducerande",
    "obducerandena": "obducerande",
    "obducerandenas": "obducerande",
    "obducerandens": "obducerande",
    "obducerandes": "obducerande",
    "obducerandet": "obducerande",
    "obducerandets": "obducerande",
    "obducerar": "obducera",
    "obduceras": "obducera",
    "obducerat": "obducera",
    "obducerats": "obducera",
    "obducerbara": "obducerbar",
    "obducerbarare": "obducerbar",
    "obducerbarares": "obducerbar",
    "obducerbaras": "obducerbar",
    "obducerbarast": "obducerbar",
    "obducerbaraste": "obducerbar",
    "obducerbarastes": "obducerbar",
    "obducerbarasts": "obducerbar",
    "obducerbare": "obducerbar",
    "obducerbares": "obducerbar",
    "obducerbarheten": "obducerbarhet",
    "obducerbarhetens": "obducerbarhet",
    "obducerbarhets": "obducerbarhet",
    "obducerbars": "obducerbar",
    "obducerbart": "obducerbar",
    "obducerbarts": "obducerbar",
    "obduceringar": "obducering",
    "obduceringarna": "obducering",
    "obduceringarnas": "obducering",
    "obduceringars": "obducering",
    "obduceringen": "obducering",
    "obduceringens": "obducering",
    "obducerings": "obducering",
    "obduktionen": "obduktion",
    "obduktionens": "obduktion",
    "obduktioner": "obduktion",
    "obduktionerna": "obduktion",
    "obduktionernas": "obduktion",
    "obduktioners": "obduktion",
    "obduktions": "obduktion",
    "obduktionsrapporten": "obduktionsrapport",
    "obduktionsrapportens": "obduktionsrapport",
    "obduktionsrapporter": "obduktionsrapport",
    "obduktionsrapporterna": "obduktionsrapport",
    "obduktionsrapporternas": "obduktionsrapport",
    "obduktionsrapporters": "obduktionsrapport",
    "obduktionsrapports": "obduktionsrapport",
    "obduktionsresultaten": "obduktionsresultat",
    "obduktionsresultatens": "obduktionsresultat",
    "obduktionsresultatet": "obduktionsresultat",
    "obduktionsresultatets": "obduktionsresultat",
    "obduktionsresultats": "obduktionsresultat",
    "obeaktade": "obeaktad",
    "obeaktades": "obeaktad",
    "obeaktads": "obeaktad",
    "obeaktat": "obeaktad",
    "obeaktats": "obeaktad",
    "obearbetade": "obearbetad",
    "obearbetades": "obearbetad",
    "obearbetads": "obearbetad",
    "obearbetat": "obearbetad",
    "obearbetats": "obearbetad",
    "obebodda": "obebodd",
    "obeboddare": "obebodd",
    "obeboddares": "obebodd",
    "obeboddas": "obebodd",
    "obeboddast": "obebodd",
    "obeboddaste": "obebodd",
    "obeboddastes": "obebodd",
    "obeboddasts": "obebodd",
    "obebodde": "obebodd",
    "obeboddes": "obebodd",
    "obebodds": "obebodd",
    "obeboeliga": "obeboelig",
    "obeboeligare": "obeboelig",
    "obeboeligares": "obeboelig",
    "obeboeligas": "obeboelig",
    "obeboeligast": "obeboelig",
    "obeboeligaste": "obeboelig",
    "obeboeligastes": "obeboelig",
    "obeboeligasts": "obeboelig",
    "obeboelige": "obeboelig",
    "obeboeliges": "obeboelig",
    "obeboeligheten": "obeboelighet",
    "obeboelighetens": "obeboelighet",
    "obeboelighets": "obeboelighet",
    "obeboeligs": "obeboelig",
    "obeboeligt": "obeboelig",
    "obeboeligts": "obeboelig",
    "obebott": "obebodd",
    "obebotts": "obebodd",
    "obebyggde": "obebyggd",
    "obebyggdes": "obebyggd",
    "obebyggds": "obebyggd",
    "obebyggt": "obebyggd",
    "obebyggts": "obebyggd",
    "obebådade": "obebådad",
    "obebådades": "obebådad",
    "obebådads": "obebådad",
    "obebådat": "obebådad",
    "obebådats": "obebådad",
    "obeckade": "obeckad",
    "obeckades": "obeckad",
    "obeckads": "obeckad",
    "obeckat": "obeckad",
    "obeckats": "obeckad",
    "obedarrade": "obedarrad",
    "obedarrades": "obedarrad",
    "obedarrads": "obedarrad",
    "obedarrat": "obedarrad",
    "obedarrats": "obedarrad",
    "obedda": "obedd",
    "obeddare": "obedd",
    "obeddares": "obedd",
    "obeddas": "obedd",
    "obeddast": "obedd",
    "obeddaste": "obedd",
    "obeddastes": "obedd",
    "obeddasts": "obedd",
    "obedde": "obedd",
    "obeddes": "obedd",
    "obedds": "obedd",
    "obedrövade": "obedrövad",
    "obedrövades": "obedrövad",
    "obedrövads": "obedrövad",
    "obedrövat": "obedrövad",
    "obedrövats": "obedrövad",
    "obedyrade": "obedyrad",
    "obedyrades": "obedyrad",
    "obedyrads": "obedyrad",
    "obedyrat": "obedyrad",
    "obedyrats": "obedyrad",
    "obedårade": "obedårad",
    "obedårades": "obedårad",
    "obedårads": "obedårad",
    "obedårat": "obedårad",
    "obedårats": "obedårad",
    "obedömde": "obedömd",
    "obedömdes": "obedömd",
    "obedömds": "obedömd",
    "obedömt": "obedömd",
    "obedömts": "obedömd",
    "obedövade": "obedövad",
    "obedövades": "obedövad",
    "obedövads": "obedövad",
    "obedövat": "obedövad",
    "obedövats": "obedövad",
    "obeedigade": "obeedigad",
    "obeedigades": "obeedigad",
    "obeedigads": "obeedigad",
    "obeedigat": "obeedigad",
    "obeedigats": "obeedigad",
    "obefallde": "obefalld",
    "obefalldes": "obefalld",
    "obefallds": "obefalld",
    "obefallt": "obefalld",
    "obefallts": "obefalld",
    "obefarade": "obefarad",
    "obefarades": "obefarad",
    "obefarads": "obefarad",
    "obefarat": "obefarad",
    "obefarats": "obefarad",
    "obefarens": "obefaren",
    "obefaret": "obefaren",
    "obefarets": "obefaren",
    "obefarna": "obefaren",
    "obefarnare": "obefaren",
    "obefarnares": "obefaren",
    "obefarnas": "obefaren",
    "obefarnast": "obefaren",
    "obefarnaste": "obefaren",
    "obefarnastes": "obefaren",
    "obefarnasts": "obefaren",
    "obefarne": "obefaren",
    "obefarnes": "obefaren",
    "obefintliga": "obefintlig",
    "obefintligare": "obefintlig",
    "obefintligares": "obefintlig",
    "obefintligas": "obefintlig",
    "obefintligast": "obefintlig",
    "obefintligaste": "obefintlig",
    "obefintligastes": "obefintlig",
    "obefintligasts": "obefintlig",
    "obefintlige": "obefintlig",
    "obefintliges": "obefintlig",
    "obefintligheten": "obefintlighet",
    "obefintlighetens": "obefintlighet",
    "obefintlighets": "obefintlighet",
    "obefintligs": "obefintlig",
    "obefintligt": "obefintlig",
    "obefintligts": "obefintlig",
    "obefläckade": "obefläckad",
    "obefläckades": "obefläckad",
    "obefläckads": "obefläckad",
    "obefläckat": "obefläckad",
    "obefläckats": "obefläckad",
    "obefogade": "obefogad",
    "obefogades": "obefogad",
    "obefogads": "obefogad",
    "obefogat": "obefogad",
    "obefogats": "obefogad",
    "obefolkade": "obefolkad",
    "obefolkades": "obefolkad",
    "obefolkads": "obefolkad",
    "obefolkat": "obefolkad",
    "obefolkats": "obefolkad",
    "obefordrade": "obefordrad",
    "obefordrades": "obefordrad",
    "obefordrads": "obefordrad",
    "obefordrat": "obefordrad",
    "obefordrats": "obefordrad",
    "obefraktade": "obefraktad",
    "obefraktades": "obefraktad",
    "obefraktads": "obefraktad",
    "obefraktat": "obefraktad",
    "obefraktats": "obefraktad",
    "obefriade": "obefriad",
    "obefriades": "obefriad",
    "obefriads": "obefriad",
    "obefriat": "obefriad",
    "obefriats": "obefriad",
    "obefruktade": "obefruktad",
    "obefruktades": "obefruktad",
    "obefruktads": "obefruktad",
    "obefruktat": "obefruktad",
    "obefruktats": "obefruktad",
    "obefryndade": "obefryndad",
    "obefryndades": "obefryndad",
    "obefryndads": "obefryndad",
    "obefryndat": "obefryndad",
    "obefryndats": "obefryndad",
    "obefrämjade": "obefrämjad",
    "obefrämjades": "obefrämjad",
    "obefrämjads": "obefrämjad",
    "obefrämjat": "obefrämjad",
    "obefrämjats": "obefrämjad",
    "obefullmäktigade": "obefullmäktigad",
    "obefullmäktigades": "obefullmäktigad",
    "obefullmäktigads": "obefullmäktigad",
    "obefullmäktigat": "obefullmäktigad",
    "obefullmäktigats": "obefullmäktigad",
    "obegabbade": "obegabbad",
    "obegabbades": "obegabbad",
    "obegabbads": "obegabbad",
    "obegabbat": "obegabbad",
    "obegabbats": "obegabbad",
    "obegagnade": "obegagnad",
    "obegagnades": "obegagnad",
    "obegagnads": "obegagnad",
    "obegagnat": "obegagnad",
    "obegagnats": "obegagnad",
    "obegapade": "obegapad",
    "obegapades": "obegapad",
    "obegapads": "obegapad",
    "obegapat": "obegapad",
    "obegapats": "obegapad",
    "obeglänsta": "obeglänst",
    "obeglänstas": "obeglänst",
    "obeglänste": "obeglänst",
    "obeglänstes": "obeglänst",
    "obeglänsts": "obeglänst",
    "obegripliga": "obegriplig",
    "obegripligare": "obegriplig",
    "obegripligares": "obegriplig",
    "obegripligas": "obegriplig",
    "obegripligast": "obegriplig",
    "obegripligaste": "obegriplig",
    "obegripligastes": "obegriplig",
    "obegripligasts": "obegriplig",
    "obegriplige": "obegriplig",
    "obegripliges": "obegriplig",
    "obegripligheten": "obegriplighet",
    "obegriplighetens": "obegriplighet",
    "obegripligheter": "obegriplighet",
    "obegripligheterna": "obegriplighet",
    "obegripligheternas": "obegriplighet",
    "obegripligheters": "obegriplighet",
    "obegriplighets": "obegriplighet",
    "obegripligs": "obegriplig",
    "obegripligt": "obegriplig",
    "obegripligts": "obegriplig",
    "obegrundade": "obegrundad",
    "obegrundades": "obegrundad",
    "obegrundads": "obegrundad",
    "obegrundat": "obegrundad",
    "obegrundats": "obegrundad",
    "obegränsade": "obegränsad",
    "obegränsades": "obegränsad",
    "obegränsads": "obegränsad",
    "obegränsat": "obegränsad",
    "obegränsats": "obegränsad",
    "obegärde": "obegärd",
    "obegärdes": "obegärd",
    "obegärds": "obegärd",
    "obegärt": "obegärd",
    "obegärts": "obegärd",
    "obegåvade": "obegåvad",
    "obegåvades": "obegåvad",
    "obegåvads": "obegåvad",
    "obegåvat": "obegåvad",
    "obegåvats": "obegåvad",
    "obehagen": "obehag",
    "obehagens": "obehag",
    "obehaget": "obehag",
    "obehagets": "obehag",
    "obehagliga": "obehaglig",
    "obehagligare": "obehaglig",
    "obehagligares": "obehaglig",
    "obehagligas": "obehaglig",
    "obehagligast": "obehaglig",
    "obehagligaste": "obehaglig",
    "obehagligastes": "obehaglig",
    "obehagligasts": "obehaglig",
    "obehaglige": "obehaglig",
    "obehagliges": "obehaglig",
    "obehagligheten": "obehaglighet",
    "obehaglighetens": "obehaglighet",
    "obehagligheter": "obehaglighet",
    "obehagligheterna": "obehaglighet",
    "obehagligheternas": "obehaglighet",
    "obehagligheters": "obehaglighet",
    "obehaglighets": "obehaglighet",
    "obehagligs": "obehaglig",
    "obehagligt": "obehaglig",
    "obehagligts": "obehaglig",
    "obehags": "obehag",
    "obehandlade": "obehandlad",
    "obehandlades": "obehandlad",
    "obehandlads": "obehandlad",
    "obehandlat": "obehandlad",
    "obehandlats": "obehandlad",
    "obehindrade": "obehindrad",
    "obehindrades": "obehindrad",
    "obehindrads": "obehindrad",
    "obehindrat": "obehindrad",
    "obehindrats": "obehindrad",
    "obehängde": "obehängd",
    "obehängdes": "obehängd",
    "obehängds": "obehängd",
    "obehängt": "obehängd",
    "obehängts": "obehängd",
    "obehärskade": "obehärskad",
    "obehärskades": "obehärskad",
    "obehärskads": "obehärskad",
    "obehärskat": "obehärskad",
    "obehärskats": "obehärskad",
    "obehöriga": "obehörig",
    "obehörigare": "obehörig",
    "obehörigares": "obehörig",
    "obehörigas": "obehörig",
    "obehörigast": "obehörig",
    "obehörigaste": "obehörig",
    "obehörigastes": "obehörig",
    "obehörigasts": "obehörig",
    "obehörige": "obehörig",
    "obehöriges": "obehörig",
    "obehörigheten": "obehörighet",
    "obehörighetens": "obehörighet",
    "obehörighets": "obehörighet",
    "obehörigs": "obehörig",
    "obehörigt": "obehörig",
    "obehörigts": "obehörig",
    "obehövde": "obehövd",
    "obehövdes": "obehövd",
    "obehövds": "obehövd",
    "obehövliga": "obehövlig",
    "obehövligare": "obehövlig",
    "obehövligares": "obehövlig",
    "obehövligas": "obehövlig",
    "obehövligast": "obehövlig",
    "obehövligaste": "obehövlig",
    "obehövligastes": "obehövlig",
    "obehövligasts": "obehövlig",
    "obehövlige": "obehövlig",
    "obehövliges": "obehövlig",
    "obehövligheten": "obehövlighet",
    "obehövlighetens": "obehövlighet",
    "obehövligheter": "obehövlighet",
    "obehövligheterna": "obehövlighet",
    "obehövligheternas": "obehövlighet",
    "obehövligheters": "obehövlighet",
    "obehövlighets": "obehövlighet",
    "obehövligs": "obehövlig",
    "obehövligt": "obehövlig",
    "obehövligts": "obehövlig",
    "obehövt": "obehövd",
    "obehövts": "obehövd",
    "obeivrade": "obeivrad",
    "obeivrades": "obeivrad",
    "obeivrads": "obeivrad",
    "obeivrat": "obeivrad",
    "obeivrats": "obeivrad",
    "obejakade": "obejakad",
    "obejakades": "obejakad",
    "obejakads": "obejakad",
    "obejakat": "obejakad",
    "obejakats": "obejakad",
    "obejublade": "obejublad",
    "obejublades": "obejublad",
    "obejublads": "obejublad",
    "obejublat": "obejublad",
    "obejublats": "obejublad",
    "obekajade": "obekajad",
    "obekajades": "obekajad",
    "obekajads": "obekajad",
    "obekajat": "obekajad",
    "obekajats": "obekajad",
    "obekanta": "obekant",
    "obekantare": "obekant",
    "obekantares": "obekant",
    "obekantas": "obekant",
    "obekantast": "obekant",
    "obekantaste": "obekant",
    "obekantastes": "obekant",
    "obekantasts": "obekant",
    "obekante": "obekant",
    "obekantes": "obekant",
    "obekants": "obekant",
    "obekikade": "obekikad",
    "obekikades": "obekikad",
    "obekikads": "obekikad",
    "obekikat": "obekikad",
    "obekikats": "obekikad",
    "obeklagade": "obeklagad",
    "obeklagades": "obeklagad",
    "obeklagads": "obeklagad",
    "obeklagat": "obeklagad",
    "obeklagats": "obeklagad",
    "obekostade": "obekostad",
    "obekostades": "obekostad",
    "obekostads": "obekostad",
    "obekostat": "obekostad",
    "obekostats": "obekostad",
    "obekransade": "obekransad",
    "obekransades": "obekransad",
    "obekransads": "obekransad",
    "obekransat": "obekransad",
    "obekransats": "obekransad",
    "obekrigade": "obekrigad",
    "obekrigades": "obekrigad",
    "obekrigads": "obekrigad",
    "obekrigat": "obekrigad",
    "obekrigats": "obekrigad",
    "obekräftade": "obekräftad",
    "obekräftades": "obekräftad",
    "obekräftads": "obekräftad",
    "obekräftat": "obekräftad",
    "obekräftats": "obekräftad",
    "obekrönta": "obekrönt",
    "obekröntas": "obekrönt",
    "obekrönte": "obekrönt",
    "obekröntes": "obekrönt",
    "obekrönts": "obekrönt",
    "obekväma": "obekväm",
    "obekvämare": "obekväm",
    "obekvämares": "obekväm",
    "obekvämas": "obekväm",
    "obekvämast": "obekväm",
    "obekvämaste": "obekväm",
    "obekvämastes": "obekväm",
    "obekvämasts": "obekväm",
    "obekväme": "obekväm",
    "obekvämes": "obekväm",
    "obekvämheten": "obekvämhet",
    "obekvämhetens": "obekvämhet",
    "obekvämheter": "obekvämhet",
    "obekvämheterna": "obekvämhet",
    "obekvämheternas": "obekvämhet",
    "obekvämheters": "obekvämhet",
    "obekvämhets": "obekvämhet",
    "obekväms": "obekväm",
    "obekvämt": "obekväm",
    "obekvämts": "obekväm",
    "obekymrade": "obekymrad",
    "obekymrades": "obekymrad",
    "obekymrads": "obekymrad",
    "obekymrat": "obekymrad",
    "obekymrats": "obekymrad",
    "obekämpade": "obekämpad",
    "obekämpades": "obekämpad",
    "obekämpads": "obekämpad",
    "obekämpat": "obekämpad",
    "obekämpats": "obekämpad",
    "obekände": "obekänd",
    "obekändes": "obekänd",
    "obekänds": "obekänd",
    "obekänt": "obekänd",
    "obekänts": "obekänd",
    "obelamrade": "obelamrad",
    "obelamrades": "obelamrad",
    "obelamrads": "obelamrad",
    "obelamrat": "obelamrad",
    "obelamrats": "obelamrad",
    "obelastade": "obelastad",
    "obelastades": "obelastad",
    "obelastads": "obelastad",
    "obelastat": "obelastad",
    "obelastats": "obelastad",
    "obeledsagade": "obeledsagad",
    "obeledsagades": "obeledsagad",
    "obeledsagads": "obeledsagad",
    "obeledsagat": "obeledsagad",
    "obeledsagats": "obeledsagad",
    "obelisken": "obelisk",
    "obeliskens": "obelisk",
    "obelisker": "obelisk",
    "obeliskerna": "obelisk",
    "obeliskernas": "obelisk",
    "obeliskers": "obelisk",
    "obelisks": "obelisk",
    "obelysta": "obelyst",
    "obelystas": "obelyst",
    "obelyste": "obelyst",
    "obelystes": "obelyst",
    "obelysts": "obelyst",
    "obelägrade": "obelägrad",
    "obelägrades": "obelägrad",
    "obelägrads": "obelägrad",
    "obelägrat": "obelägrad",
    "obelägrats": "obelägrad",
    "obelånade": "obelånad",
    "obelånades": "obelånad",
    "obelånads": "obelånad",
    "obelånat": "obelånad",
    "obelånats": "obelånad",
    "obelönade": "obelönad",
    "obelönades": "obelönad",
    "obelönads": "obelönad",
    "obelönat": "obelönad",
    "obelönats": "obelönad",
    "obemannade": "obemannad",
    "obemannades": "obemannad",
    "obemannads": "obemannad",
    "obemannat": "obemannad",
    "obemannats": "obemannad",
    "obemantlade": "obemantlad",
    "obemantlades": "obemantlad",
    "obemantlads": "obemantlad",
    "obemantlat": "obemantlad",
    "obemantlats": "obemantlad",
    "obemedlade": "obemedlad",
    "obemedlades": "obemedlad",
    "obemedlads": "obemedlad",
    "obemedlat": "obemedlad",
    "obemedlats": "obemedlad",
    "obemyndigade": "obemyndigad",
    "obemyndigades": "obemyndigad",
    "obemyndigads": "obemyndigad",
    "obemyndigat": "obemyndigad",
    "obemyndigats": "obemyndigad",
    "obemängde": "obemängd",
    "obemängdes": "obemängd",
    "obemängds": "obemängd",
    "obemängt": "obemängd",
    "obemängts": "obemängd",
    "obemärkta": "obemärkt",
    "obemärktare": "obemärkt",
    "obemärktares": "obemärkt",
    "obemärktas": "obemärkt",
    "obemärktast": "obemärkt",
    "obemärktaste": "obemärkt",
    "obemärktastes": "obemärkt",
    "obemärktasts": "obemärkt",
    "obemärkte": "obemärkt",
    "obemärktes": "obemärkt",
    "obemärktheten": "obemärkthet",
    "obemärkthetens": "obemärkthet",
    "obemärktheter": "obemärkthet",
    "obemärktheterna": "obemärkthet",
    "obemärktheternas": "obemärkthet",
    "obemärktheters": "obemärkthet",
    "obemärkthets": "obemärkthet",
    "obemärkts": "obemärkt",
    "obemästrade": "obemästrad",
    "obemästrades": "obemästrad",
    "obemästrads": "obemästrad",
    "obemästrat": "obemästrad",
    "obemästrats": "obemästrad",
    "obemötta": "obemött",
    "obemöttas": "obemött",
    "obemötte": "obemött",
    "obemöttes": "obemött",
    "obemötts": "obemött",
    "obenade": "obenad",
    "obenades": "obenad",
    "obenads": "obenad",
    "obenat": "obenad",
    "obenats": "obenad",
    "obenägens": "obenägen",
    "obenäget": "obenägen",
    "obenägets": "obenägen",
    "obenägna": "obenägen",
    "obenägnare": "obenägen",
    "obenägnares": "obenägen",
    "obenägnas": "obenägen",
    "obenägnast": "obenägen",
    "obenägnaste": "obenägen",
    "obenägnastes": "obenägen",
    "obenägnasts": "obenägen",
    "obenägne": "obenägen",
    "obenägnes": "obenägen",
    "obenämnde": "obenämnd",
    "obenämndes": "obenämnd",
    "obenämnds": "obenämnd",
    "obenämnt": "obenämnd",
    "obenämnts": "obenämnd",
    "obenådade": "obenådad",
    "obenådades": "obenådad",
    "obenådads": "obenådad",
    "obenådat": "obenådad",
    "obenådats": "obenådad",
    "obeordrade": "obeordrad",
    "obeordrades": "obeordrad",
    "obeordrads": "obeordrad",
    "obeordrat": "obeordrad",
    "obeordrats": "obeordrad",
    "obepansrade": "obepansrad",
    "obepansrades": "obepansrad",
    "obepansrads": "obepansrad",
    "obepansrat": "obepansrad",
    "obepansrats": "obepansrad",
    "obeprisade": "obeprisad",
    "obeprisades": "obeprisad",
    "obeprisads": "obeprisad",
    "obeprisat": "obeprisad",
    "obeprisats": "obeprisad",
    "obeprövade": "obeprövad",
    "obeprövades": "obeprövad",
    "obeprövads": "obeprövad",
    "obeprövat": "obeprövad",
    "obeprövats": "obeprövad",
    "obepudrade": "obepudrad",
    "obepudrades": "obepudrad",
    "obepudrads": "obepudrad",
    "obepudrat": "obepudrad",
    "obepudrats": "obepudrad",
    "oberikade": "oberikad",
    "oberikades": "oberikad",
    "oberikads": "oberikad",
    "oberikat": "oberikad",
    "oberikats": "oberikad",
    "oberiktigade": "oberiktigad",
    "oberiktigades": "oberiktigad",
    "oberiktigads": "oberiktigad",
    "oberiktigat": "oberiktigad",
    "oberiktigats": "oberiktigad",
    "oberoendes": "oberoende",
    "oberoendet": "oberoende",
    "oberoendets": "oberoende",
    "oberusade": "oberusad",
    "oberusades": "oberusad",
    "oberusads": "oberusad",
    "oberusat": "oberusad",
    "oberusats": "oberusad",
    "oberäknade": "oberäknad",
    "oberäknades": "oberäknad",
    "oberäknads": "oberäknad",
    "oberäknat": "oberäknad",
    "oberäknats": "oberäknad",
    "oberäkneliga": "oberäknelig",
    "oberäkneligare": "oberäknelig",
    "oberäkneligares": "oberäknelig",
    "oberäkneligas": "oberäknelig",
    "oberäkneligast": "oberäknelig",
    "oberäkneligaste": "oberäknelig",
    "oberäkneligastes": "oberäknelig",
    "oberäkneligasts": "oberäknelig",
    "oberäknelige": "oberäknelig",
    "oberäkneliges": "oberäknelig",
    "oberäkneligheten": "oberäknelighet",
    "oberäknelighetens": "oberäknelighet",
    "oberäknelighets": "oberäknelighet",
    "oberäkneligs": "oberäknelig",
    "oberäkneligt": "oberäknelig",
    "oberäkneligts": "oberäknelig",
    "oberättade": "oberättad",
    "oberättades": "oberättad",
    "oberättads": "oberättad",
    "oberättat": "oberättad",
    "oberättats": "oberättad",
    "oberättigade": "oberättigad",
    "oberättigades": "oberättigad",
    "oberättigads": "oberättigad",
    "oberättigat": "oberättigad",
    "oberättigats": "oberättigad",
    "oberömde": "oberömd",
    "oberömdes": "oberömd",
    "oberömdheten": "oberömdhet",
    "oberömdhetens": "oberömdhet",
    "oberömdhets": "oberömdhet",
    "oberömds": "oberömd",
    "oberömt": "oberömd",
    "oberömts": "oberömd",
    "oberörbara": "oberörbar",
    "oberörbarare": "oberörbar",
    "oberörbarares": "oberörbar",
    "oberörbaras": "oberörbar",
    "oberörbarast": "oberörbar",
    "oberörbaraste": "oberörbar",
    "oberörbarastes": "oberörbar",
    "oberörbarasts": "oberörbar",
    "oberörbare": "oberörbar",
    "oberörbares": "oberörbar",
    "oberörbarheten": "oberörbarhet",
    "oberörbarhetens": "oberörbarhet",
    "oberörbarhets": "oberörbarhet",
    "oberörbars": "oberörbar",
    "oberörbart": "oberörbar",
    "oberörbarts": "oberörbar",
    "oberörda": "oberörd",
    "oberördare": "oberörd",
    "oberördares": "oberörd",
    "oberördas": "oberörd",
    "oberördast": "oberörd",
    "oberördaste": "oberörd",
    "oberördastes": "oberörd",
    "oberördasts": "oberörd",
    "oberörde": "oberörd",
    "oberördes": "oberörd",
    "oberördheten": "oberördhet",
    "oberördhetens": "oberördhet",
    "oberördheter": "oberördhet",
    "oberördheterna": "oberördhet",
    "oberördheternas": "oberördhet",
    "oberördheters": "oberördhet",
    "oberördhets": "oberördhet",
    "oberörds": "oberörd",
    "oberört": "oberörd",
    "oberörts": "oberörd",
    "oberövade": "oberövad",
    "oberövades": "oberövad",
    "oberövads": "oberövad",
    "oberövat": "oberövad",
    "oberövats": "oberövad",
    "obesannade": "obesannad",
    "obesannades": "obesannad",
    "obesannads": "obesannad",
    "obesannat": "obesannad",
    "obesannats": "obesannad",
    "obesatta": "obesatt",
    "obesattare": "obesatt",
    "obesattares": "obesatt",
    "obesattas": "obesatt",
    "obesattast": "obesatt",
    "obesattaste": "obesatt",
    "obesattastes": "obesatt",
    "obesattasts": "obesatt",
    "obesatte": "obesatt",
    "obesattes": "obesatt",
    "obesattheten": "obesatthet",
    "obesatthetens": "obesatthet",
    "obesatthets": "obesatthet",
    "obesatts": "obesatt",
    "obesedda": "obesedd",
    "obeseddare": "obesedd",
    "obeseddares": "obesedd",
    "obeseddas": "obesedd",
    "obeseddast": "obesedd",
    "obeseddaste": "obesedd",
    "obeseddastes": "obesedd",
    "obeseddasts": "obesedd",
    "obesedde": "obesedd",
    "obeseddes": "obesedd",
    "obesedds": "obesedd",
    "obeseglade": "obeseglad",
    "obeseglades": "obeseglad",
    "obeseglads": "obeseglad",
    "obeseglat": "obeseglad",
    "obeseglats": "obeseglad",
    "obesegrade": "obesegrad",
    "obesegrades": "obesegrad",
    "obesegrads": "obesegrad",
    "obesegrat": "obesegrad",
    "obesegrats": "obesegrad",
    "obesett": "obesedd",
    "obesetts": "obesedd",
    "obesiktigade": "obesiktigad",
    "obesiktigades": "obesiktigad",
    "obesiktigads": "obesiktigad",
    "obesiktigat": "obesiktigad",
    "obesiktigats": "obesiktigad",
    "obesinnade": "obesinnad",
    "obesinnades": "obesinnad",
    "obesinnads": "obesinnad",
    "obesinnat": "obesinnad",
    "obesinnats": "obesinnad",
    "obesjälade": "obesjälad",
    "obesjälades": "obesjälad",
    "obesjälads": "obesjälad",
    "obesjälat": "obesjälad",
    "obesjälats": "obesjälad",
    "obeskattade": "obeskattad",
    "obeskattades": "obeskattad",
    "obeskattads": "obeskattad",
    "obeskattat": "obeskattad",
    "obeskattats": "obeskattad",
    "obeskickade": "obeskickad",
    "obeskickades": "obeskickad",
    "obeskickads": "obeskickad",
    "obeskickat": "obeskickad",
    "obeskickats": "obeskickad",
    "obeskrivbara": "obeskrivbar",
    "obeskrivbarare": "obeskrivbar",
    "obeskrivbarares": "obeskrivbar",
    "obeskrivbaras": "obeskrivbar",
    "obeskrivbarast": "obeskrivbar",
    "obeskrivbaraste": "obeskrivbar",
    "obeskrivbarastes": "obeskrivbar",
    "obeskrivbarasts": "obeskrivbar",
    "obeskrivbare": "obeskrivbar",
    "obeskrivbares": "obeskrivbar",
    "obeskrivbarheten": "obeskrivbarhet",
    "obeskrivbarhetens": "obeskrivbarhet",
    "obeskrivbarhets": "obeskrivbarhet",
    "obeskrivbars": "obeskrivbar",
    "obeskrivbart": "obeskrivbar",
    "obeskrivbarts": "obeskrivbar",
    "obeskrivliga": "obeskrivlig",
    "obeskrivligare": "obeskrivlig",
    "obeskrivligares": "obeskrivlig",
    "obeskrivligas": "obeskrivlig",
    "obeskrivligast": "obeskrivlig",
    "obeskrivligaste": "obeskrivlig",
    "obeskrivligastes": "obeskrivlig",
    "obeskrivligasts": "obeskrivlig",
    "obeskrivlige": "obeskrivlig",
    "obeskrivliges": "obeskrivlig",
    "obeskrivligheten": "obeskrivlighet",
    "obeskrivlighetens": "obeskrivlighet",
    "obeskrivlighets": "obeskrivlighet",
    "obeskrivligs": "obeskrivlig",
    "obeskrivligt": "obeskrivlig",
    "obeskrivligts": "obeskrivlig",
    "obeskuggade": "obeskuggad",
    "obeskuggades": "obeskuggad",
    "obeskuggads": "obeskuggad",
    "obeskuggat": "obeskuggad",
    "obeskuggats": "obeskuggad",
    "obeskurens": "obeskuren",
    "obeskuret": "obeskuren",
    "obeskurets": "obeskuren",
    "obeskurna": "obeskuren",
    "obeskurnare": "obeskuren",
    "obeskurnares": "obeskuren",
    "obeskurnas": "obeskuren",
    "obeskurnast": "obeskuren",
    "obeskurnaste": "obeskuren",
    "obeskurnastes": "obeskuren",
    "obeskurnasts": "obeskuren",
    "obeskurne": "obeskuren",
    "obeskurnes": "obeskuren",
    "obeskyddade": "obeskyddad",
    "obeskyddades": "obeskyddad",
    "obeskyddads": "obeskyddad",
    "obeskyddat": "obeskyddad",
    "obeskyddats": "obeskyddad",
    "obeskyllde": "obeskylld",
    "obeskylldes": "obeskylld",
    "obeskyllds": "obeskylld",
    "obeskyllt": "obeskylld",
    "obeskyllts": "obeskylld",
    "obeskärmade": "obeskärmad",
    "obeskärmades": "obeskärmad",
    "obeskärmads": "obeskärmad",
    "obeskärmat": "obeskärmad",
    "obeskärmats": "obeskärmad",
    "obeskådade": "obeskådad",
    "obeskådades": "obeskådad",
    "obeskådads": "obeskådad",
    "obeskådat": "obeskådad",
    "obeskådats": "obeskådad",
    "obeslutsamheten": "obeslutsamhet",
    "obeslutsamhetens": "obeslutsamhet",
    "obeslutsamheter": "obeslutsamhet",
    "obeslutsamheterna": "obeslutsamhet",
    "obeslutsamheternas": "obeslutsamhet",
    "obeslutsamheters": "obeslutsamhet",
    "obeslutsamhets": "obeslutsamhet",
    "obeslutsamma": "obeslutsam",
    "obeslutsammare": "obeslutsam",
    "obeslutsammares": "obeslutsam",
    "obeslutsammas": "obeslutsam",
    "obeslutsammast": "obeslutsam",
    "obeslutsammaste": "obeslutsam",
    "obeslutsammastes": "obeslutsam",
    "obeslutsammasts": "obeslutsam",
    "obeslutsamme": "obeslutsam",
    "obeslutsammes": "obeslutsam",
    "obeslutsams": "obeslutsam",
    "obeslutsamt": "obeslutsam",
    "obeslutsamts": "obeslutsam",
    "obesläktade": "obesläktad",
    "obesläktades": "obesläktad",
    "obesläktads": "obesläktad",
    "obesläktat": "obesläktad",
    "obesläktats": "obesläktad",
    "obeslöjade": "obeslöjad",
    "obeslöjades": "obeslöjad",
    "obeslöjads": "obeslöjad",
    "obeslöjat": "obeslöjad",
    "obeslöjats": "obeslöjad",
    "obesmittade": "obesmittad",
    "obesmittades": "obesmittad",
    "obesmittads": "obesmittad",
    "obesmittat": "obesmittad",
    "obesmittats": "obesmittad",
    "obesockrade": "obesockrad",
    "obesockrades": "obesockrad",
    "obesockrads": "obesockrad",
    "obesockrat": "obesockrad",
    "obesockrats": "obesockrad",
    "obesoldade": "obesoldad",
    "obesoldades": "obesoldad",
    "obesoldads": "obesoldad",
    "obesoldat": "obesoldad",
    "obesoldats": "obesoldad",
    "obespejade": "obespejad",
    "obespejades": "obespejad",
    "obespejads": "obespejad",
    "obespejat": "obespejad",
    "obespejats": "obespejad",
    "obespisade": "obespisad",
    "obespisades": "obespisad",
    "obespisads": "obespisad",
    "obespisat": "obespisad",
    "obespisats": "obespisad",
    "obespolade": "obespolad",
    "obespolades": "obespolad",
    "obespolads": "obespolad",
    "obespolat": "obespolad",
    "obespolats": "obespolad",
    "obespottade": "obespottad",
    "obespottades": "obespottad",
    "obespottads": "obespottad",
    "obespottat": "obespottad",
    "obespottats": "obespottad",
    "obesprutade": "obesprutad",
    "obesprutades": "obesprutad",
    "obesprutads": "obesprutad",
    "obesprutat": "obesprutad",
    "obesprutats": "obesprutad",
    "obestickliga": "obesticklig",
    "obestickligare": "obesticklig",
    "obestickligares": "obesticklig",
    "obestickligas": "obesticklig",
    "obestickligast": "obesticklig",
    "obestickligaste": "obesticklig",
    "obestickligastes": "obesticklig",
    "obestickligasts": "obesticklig",
    "obesticklige": "obesticklig",
    "obestickliges": "obesticklig",
    "obestickligheten": "obesticklighet",
    "obesticklighetens": "obesticklighet",
    "obesticklighets": "obesticklighet",
    "obestickligs": "obesticklig",
    "obestickligt": "obesticklig",
    "obestickligts": "obesticklig",
    "obestormade": "obestormad",
    "obestormades": "obestormad",
    "obestormads": "obestormad",
    "obestormat": "obestormad",
    "obestormats": "obestormad",
    "obestraffade": "obestraffad",
    "obestraffades": "obestraffad",
    "obestraffads": "obestraffad",
    "obestraffat": "obestraffad",
    "obestraffats": "obestraffad",
    "obestridda": "obestridd",
    "obestriddare": "obestridd",
    "obestriddares": "obestridd",
    "obestriddas": "obestridd",
    "obestriddast": "obestridd",
    "obestriddaste": "obestridd",
    "obestriddastes": "obestridd",
    "obestriddasts": "obestridd",
    "obestridde": "obestridd",
    "obestriddes": "obestridd",
    "obestridds": "obestridd",
    "obestridliga": "obestridlig",
    "obestridligare": "obestridlig",
    "obestridligares": "obestridlig",
    "obestridligas": "obestridlig",
    "obestridligast": "obestridlig",
    "obestridligaste": "obestridlig",
    "obestridligastes": "obestridlig",
    "obestridligasts": "obestridlig",
    "obestridlige": "obestridlig",
    "obestridliges": "obestridlig",
    "obestridligheten": "obestridlighet",
    "obestridlighetens": "obestridlighet",
    "obestridlighets": "obestridlighet",
    "obestridligs": "obestridlig",
    "obestridligt": "obestridlig",
    "obestridligts": "obestridlig",
    "obestritt": "obestridd",
    "obestritts": "obestridd",
    "obestrålade": "obestrålad",
    "obestrålades": "obestrålad",
    "obestrålads": "obestrålad",
    "obestrålat": "obestrålad",
    "obestrålats": "obestrålad",
    "obestyckade": "obestyckad",
    "obestyckades": "obestyckad",
    "obestyckads": "obestyckad",
    "obestyckat": "obestyckad",
    "obestyckats": "obestyckad",
    "obestyrkta": "obestyrkt",
    "obestyrktare": "obestyrkt",
    "obestyrktares": "obestyrkt",
    "obestyrktas": "obestyrkt",
    "obestyrktast": "obestyrkt",
    "obestyrktaste": "obestyrkt",
    "obestyrktastes": "obestyrkt",
    "obestyrktasts": "obestyrkt",
    "obestyrkte": "obestyrkt",
    "obestyrktes": "obestyrkt",
    "obestyrkts": "obestyrkt",
    "obeställbara": "obeställbar",
    "obeställbarare": "obeställbar",
    "obeställbarares": "obeställbar",
    "obeställbaras": "obeställbar",
    "obeställbarast": "obeställbar",
    "obeställbaraste": "obeställbar",
    "obeställbarastes": "obeställbar",
    "obeställbarasts": "obeställbar",
    "obeställbare": "obeställbar",
    "obeställbares": "obeställbar",
    "obeställbarheten": "obeställbarhet",
    "obeställbarhetens": "obeställbarhet",
    "obeställbarhets": "obeställbarhet",
    "obeställbars": "obeställbar",
    "obeställbart": "obeställbar",
    "obeställbarts": "obeställbar",
    "obeställde": "obeställd",
    "obeställdes": "obeställd",
    "obeställds": "obeställd",
    "obeställt": "obeställd",
    "obeställts": "obeställd",
    "obestämbara": "obestämbar",
    "obestämbarare": "obestämbar",
    "obestämbarares": "obestämbar",
    "obestämbaras": "obestämbar",
    "obestämbarast": "obestämbar",
    "obestämbaraste": "obestämbar",
    "obestämbarastes": "obestämbar",
    "obestämbarasts": "obestämbar",
    "obestämbare": "obestämbar",
    "obestämbares": "obestämbar",
    "obestämbarheten": "obestämbarhet",
    "obestämbarhetens": "obestämbarhet",
    "obestämbarheter": "obestämbarhet",
    "obestämbarheterna": "obestämbarhet",
    "obestämbarheternas": "obestämbarhet",
    "obestämbarheters": "obestämbarhet",
    "obestämbarhets": "obestämbarhet",
    "obestämbars": "obestämbar",
    "obestämbart": "obestämbar",
    "obestämbarts": "obestämbar",
    "obestämda": "obestämd",
    "obestämdare": "obestämd",
    "obestämdares": "obestämd",
    "obestämdas": "obestämd",
    "obestämdast": "obestämd",
    "obestämdaste": "obestämd",
    "obestämdastes": "obestämd",
    "obestämdasts": "obestämd",
    "obestämde": "obestämd",
    "obestämdes": "obestämd",
    "obestämdheten": "obestämdhet",
    "obestämdhetens": "obestämdhet",
    "obestämdheter": "obestämdhet",
    "obestämdheterna": "obestämdhet",
    "obestämdheternas": "obestämdhet",
    "obestämdheters": "obestämdhet",
    "obestämdhets": "obestämdhet",
    "obestämdhetsprincipen": "obestämdhetsprincip",
    "obestämdhetsprincipens": "obestämdhetsprincip",
    "obestämdhetsprinciper": "obestämdhetsprincip",
    "obestämdhetsprinciperna": "obestämdhetsprincip",
    "obestämdhetsprincipernas": "obestämdhetsprincip",
    "obestämdhetsprincipers": "obestämdhetsprincip",
    "obestämdhetsprincips": "obestämdhetsprincip",
    "obestämds": "obestämd",
    "obestämt": "obestämd",
    "obestämts": "obestämd",
    "obeständiga": "obeständig",
    "obeständigare": "obeständig",
    "obeständigares": "obeständig",
    "obeständigas": "obeständig",
    "obeständigast": "obeständig",
    "obeständigaste": "obeständig",
    "obeständigastes": "obeständig",
    "obeständigasts": "obeständig",
    "obeständige": "obeständig",
    "obeständiges": "obeständig",
    "obeständigheten": "obeständighet",
    "obeständighetens": "obeständighet",
    "obeständigheter": "obeständighet",
    "obeständigheterna": "obeständighet",
    "obeständigheternas": "obeständighet",
    "obeständigheters": "obeständighet",
    "obeständighets": "obeständighet",
    "obeständigs": "obeständig",
    "obeständigt": "obeständig",
    "obeständigts": "obeständig",
    "obestänkta": "obestänkt",
    "obestänktas": "obestänkt",
    "obestänkte": "obestänkt",
    "obestänktes": "obestänkt",
    "obestänkts": "obestänkt",
    "obesudlade": "obesudlad",
    "obesudlades": "obesudlad",
    "obesudlads": "obesudlad",
    "obesudlat": "obesudlad",
    "obesudlats": "obesudlad",
    "obesvarade": "obesvarad",
    "obesvarades": "obesvarad",
    "obesvarads": "obesvarad",
    "obesvarat": "obesvarad",
    "obesvarats": "obesvarad",
    "obesvärade": "obesvärad",
    "obesvärades": "obesvärad",
    "obesvärads": "obesvärad",
    "obesvärat": "obesvärad",
    "obesvärats": "obesvärad",
    "obesökta": "obesökt",
    "obesöktas": "obesökt",
    "obesökte": "obesökt",
    "obesöktes": "obesökt",
    "obesökts": "obesökt",
    "obesörjde": "obesörjd",
    "obesörjdes": "obesörjd",
    "obesörjds": "obesörjd",
    "obesörjt": "obesörjd",
    "obesörjts": "obesörjd",
    "obetade": "obetad",
    "obetades": "obetad",
    "obetads": "obetad",
    "obetagens": "obetagen",
    "obetaget": "obetagen",
    "obetagets": "obetagen",
    "obetagna": "obetagen",
    "obetagnare": "obetagen",
    "obetagnares": "obetagen",
    "obetagnas": "obetagen",
    "obetagnast": "obetagen",
    "obetagnaste": "obetagen",
    "obetagnastes": "obetagen",
    "obetagnasts": "obetagen",
    "obetagne": "obetagen",
    "obetagnes": "obetagen",
    "obetalbara": "obetalbar",
    "obetalbarare": "obetalbar",
    "obetalbarares": "obetalbar",
    "obetalbaras": "obetalbar",
    "obetalbarast": "obetalbar",
    "obetalbaraste": "obetalbar",
    "obetalbarastes": "obetalbar",
    "obetalbarasts": "obetalbar",
    "obetalbare": "obetalbar",
    "obetalbares": "obetalbar",
    "obetalbarheten": "obetalbarhet",
    "obetalbarhetens": "obetalbarhet",
    "obetalbarhets": "obetalbarhet",
    "obetalbars": "obetalbar",
    "obetalbart": "obetalbar",
    "obetalbarts": "obetalbar",
    "obetalda": "obetald",
    "obetaldare": "obetald",
    "obetaldares": "obetald",
    "obetaldas": "obetald",
    "obetaldast": "obetald",
    "obetaldaste": "obetald",
    "obetaldastes": "obetald",
    "obetaldasts": "obetald",
    "obetalde": "obetald",
    "obetaldes": "obetald",
    "obetalds": "obetald",
    "obetalt": "obetald",
    "obetalts": "obetald",
    "obetat": "obetad",
    "obetats": "obetad",
    "obetecknade": "obetecknad",
    "obetecknades": "obetecknad",
    "obetecknads": "obetecknad",
    "obetecknat": "obetecknad",
    "obetecknats": "obetecknad",
    "obetingade": "obetingad",
    "obetingades": "obetingad",
    "obetingads": "obetingad",
    "obetingat": "obetingad",
    "obetingats": "obetingad",
    "obetitlade": "obetitlad",
    "obetitlades": "obetitlad",
    "obetitlads": "obetitlad",
    "obetitlat": "obetitlad",
    "obetitlats": "obetitlad",
    "obetittade": "obetittad",
    "obetittades": "obetittad",
    "obetittads": "obetittad",
    "obetittat": "obetittad",
    "obetittats": "obetittad",
    "obetjänade": "obetjänad",
    "obetjänades": "obetjänad",
    "obetjänads": "obetjänad",
    "obetjänat": "obetjänad",
    "obetjänats": "obetjänad",
    "obetonade": "obetonad",
    "obetonades": "obetonad",
    "obetonads": "obetonad",
    "obetonat": "obetonad",
    "obetonats": "obetonad",
    "obetongerade": "obetongerad",
    "obetongerades": "obetongerad",
    "obetongerads": "obetongerad",
    "obetongerat": "obetongerad",
    "obetongerats": "obetongerad",
    "obetongerbara": "obetongerbar",
    "obetongerbarare": "obetongerbar",
    "obetongerbarares": "obetongerbar",
    "obetongerbaras": "obetongerbar",
    "obetongerbarast": "obetongerbar",
    "obetongerbaraste": "obetongerbar",
    "obetongerbarastes": "obetongerbar",
    "obetongerbarasts": "obetongerbar",
    "obetongerbare": "obetongerbar",
    "obetongerbares": "obetongerbar",
    "obetongerbarheten": "obetongerbarhet",
    "obetongerbarhetens": "obetongerbarhet",
    "obetongerbarhets": "obetongerbarhet",
    "obetongerbars": "obetongerbar",
    "obetongerbart": "obetongerbar",
    "obetongerbarts": "obetongerbar",
    "obetraktade": "obetraktad",
    "obetraktades": "obetraktad",
    "obetraktads": "obetraktad",
    "obetraktat": "obetraktad",
    "obetraktats": "obetraktad",
    "obetryckta": "obetryckt",
    "obetrycktas": "obetryckt",
    "obetryckte": "obetryckt",
    "obetrycktes": "obetryckt",
    "obetryckts": "obetryckt",
    "obetryggade": "obetryggad",
    "obetryggades": "obetryggad",
    "obetryggads": "obetryggad",
    "obetryggat": "obetryggad",
    "obetryggats": "obetryggad",
    "obeträffade": "obeträffad",
    "obeträffades": "obeträffad",
    "obeträffads": "obeträffad",
    "obeträffat": "obeträffad",
    "obeträffats": "obeträffad",
    "obetsade": "obetsad",
    "obetsades": "obetsad",
    "obetsads": "obetsad",
    "obetsat": "obetsad",
    "obetsats": "obetsad",
    "obetslade": "obetslad",
    "obetslades": "obetslad",
    "obetslads": "obetslad",
    "obetslat": "obetslad",
    "obetslats": "obetslad",
    "obett": "obedd",
    "obetts": "obedd",
    "obetungade": "obetungad",
    "obetungades": "obetungad",
    "obetungads": "obetungad",
    "obetungat": "obetungad",
    "obetungats": "obetungad",
    "obetvingliga": "obetvinglig",
    "obetvingligare": "obetvinglig",
    "obetvingligares": "obetvinglig",
    "obetvingligas": "obetvinglig",
    "obetvingligast": "obetvinglig",
    "obetvingligaste": "obetvinglig",
    "obetvingligastes": "obetvinglig",
    "obetvingligasts": "obetvinglig",
    "obetvinglige": "obetvinglig",
    "obetvingliges": "obetvinglig",
    "obetvingligheten": "obetvinglighet",
    "obetvinglighetens": "obetvinglighet",
    "obetvinglighets": "obetvinglighet",
    "obetvingligs": "obetvinglig",
    "obetvingligt": "obetvinglig",
    "obetvingligts": "obetvinglig",
    "obetvivlade": "obetvivlad",
    "obetvivlades": "obetvivlad",
    "obetvivlads": "obetvivlad",
    "obetvivlat": "obetvivlad",
    "obetvivlats": "obetvivlad",
    "obetydliga": "obetydlig",
    "obetydligare": "obetydlig",
    "obetydligares": "obetydlig",
    "obetydligas": "obetydlig",
    "obetydligast": "obetydlig",
    "obetydligaste": "obetydlig",
    "obetydligastes": "obetydlig",
    "obetydligasts": "obetydlig",
    "obetydlige": "obetydlig",
    "obetydliges": "obetydlig",
    "obetydligheten": "obetydlighet",
    "obetydlighetens": "obetydlighet",
    "obetydligheter": "obetydlighet",
    "obetydligheterna": "obetydlighet",
    "obetydligheternas": "obetydlighet",
    "obetydligheters": "obetydlighet",
    "obetydlighets": "obetydlighet",
    "obetydligs": "obetydlig",
    "obetydligt": "obetydlig",
    "obetydligts": "obetydlig",
    "obetygade": "obetygad",
    "obetygades": "obetygad",
    "obetygads": "obetygad",
    "obetygat": "obetygad",
    "obetygats": "obetygad",
    "obetäckta": "obetäckt",
    "obetäcktas": "obetäckt",
    "obetäckte": "obetäckt",
    "obetäcktes": "obetäckt",
    "obetäckts": "obetäckt",
    "obetänksamheten": "obetänksamhet",
    "obetänksamhetens": "obetänksamhet",
    "obetänksamhets": "obetänksamhet",
    "obetänksamma": "obetänksam",
    "obetänksammare": "obetänksam",
    "obetänksammares": "obetänksam",
    "obetänksammas": "obetänksam",
    "obetänksammast": "obetänksam",
    "obetänksammaste": "obetänksam",
    "obetänksammastes": "obetänksam",
    "obetänksammasts": "obetänksam",
    "obetänksamme": "obetänksam",
    "obetänksammes": "obetänksam",
    "obetänksams": "obetänksam",
    "obetänksamt": "obetänksam",
    "obetänksamts": "obetänksam",
    "obetänkta": "obetänkt",
    "obetänktare": "obetänkt",
    "obetänktares": "obetänkt",
    "obetänktas": "obetänkt",
    "obetänktast": "obetänkt",
    "obetänktaste": "obetänkt",
    "obetänktastes": "obetänkt",
    "obetänktasts": "obetänkt",
    "obetänkte": "obetänkt",
    "obetänktes": "obetänkt",
    "obetänktheten": "obetänkthet",
    "obetänkthetens": "obetänkthet",
    "obetänkthets": "obetänkthet",
    "obetänkts": "obetänkt",
    "obeundrade": "obeundrad",
    "obeundrades": "obeundrad",
    "obeundrads": "obeundrad",
    "obeundrat": "obeundrad",
    "obeundrats": "obeundrad",
    "obevakade": "obevakad",
    "obevakades": "obevakad",
    "obevakads": "obevakad",
    "obevakat": "obevakad",
    "obevakats": "obevakad",
    "obevandrade": "obevandrad",
    "obevandrades": "obevandrad",
    "obevandrads": "obevandrad",
    "obevandrat": "obevandrad",
    "obevandrats": "obevandrad",
    "obevarade": "obevarad",
    "obevarades": "obevarad",
    "obevarads": "obevarad",
    "obevarat": "obevarad",
    "obevarats": "obevarad",
    "obevattnade": "obevattnad",
    "obevattnades": "obevattnad",
    "obevattnads": "obevattnad",
    "obevattnat": "obevattnad",
    "obevattnats": "obevattnad",
    "obevekliga": "obeveklig",
    "obevekligare": "obeveklig",
    "obevekligares": "obeveklig",
    "obevekligas": "obeveklig",
    "obevekligast": "obeveklig",
    "obevekligaste": "obeveklig",
    "obevekligastes": "obeveklig",
    "obevekligasts": "obeveklig",
    "obeveklige": "obeveklig",
    "obevekliges": "obeveklig",
    "obevekligheten": "obeveklighet",
    "obeveklighetens": "obeveklighet",
    "obeveklighets": "obeveklighet",
    "obevekligs": "obeveklig",
    "obevekligt": "obeveklig",
    "obevekligts": "obeveklig",
    "obeviljade": "obeviljad",
    "obeviljades": "obeviljad",
    "obeviljads": "obeviljad",
    "obeviljat": "obeviljad",
    "obeviljats": "obeviljad",
    "obevisade": "obevisad",
    "obevisades": "obevisad",
    "obevisads": "obevisad",
    "obevisat": "obevisad",
    "obevisats": "obevisad",
    "obevistade": "obevistad",
    "obevistades": "obevistad",
    "obevistads": "obevistad",
    "obevistat": "obevistad",
    "obevistats": "obevistad",
    "obevittnade": "obevittnad",
    "obevittnades": "obevittnad",
    "obevittnads": "obevittnad",
    "obevittnat": "obevittnad",
    "obevittnats": "obevittnad",
    "obeväpnade": "obeväpnad",
    "obeväpnades": "obeväpnad",
    "obeväpnads": "obeväpnad",
    "obeväpnat": "obeväpnad",
    "obeväpnats": "obeväpnad",
    "obevärade": "obevärad",
    "obevärades": "obevärad",
    "obevärads": "obevärad",
    "obevärat": "obevärad",
    "obevärats": "obevärad",
    "obevärdigade": "obevärdigad",
    "obevärdigades": "obevärdigad",
    "obevärdigads": "obevärdigad",
    "obevärdigat": "obevärdigad",
    "obevärdigats": "obevärdigad",
    "obidade": "obidad",
    "obidades": "obidad",
    "obidads": "obidad",
    "obidat": "obidad",
    "obidats": "obidad",
    "obifogade": "obifogad",
    "obifogades": "obifogad",
    "obifogads": "obifogad",
    "obifogat": "obifogad",
    "obifogats": "obifogad",
    "obiktade": "obiktad",
    "obiktades": "obiktad",
    "obiktads": "obiktad",
    "obiktat": "obiktad",
    "obiktats": "obiktad",
    "obilade": "obilad",
    "obilades": "obilad",
    "obilads": "obilad",
    "obilat": "obilad",
    "obilats": "obilad",
    "obildade": "obildad",
    "obildades": "obildad",
    "obildads": "obildad",
    "obildat": "obildad",
    "obildats": "obildad",
    "obildbara": "obildbar",
    "obildbarare": "obildbar",
    "obildbarares": "obildbar",
    "obildbaras": "obildbar",
    "obildbarast": "obildbar",
    "obildbaraste": "obildbar",
    "obildbarastes": "obildbar",
    "obildbarasts": "obildbar",
    "obildbare": "obildbar",
    "obildbares": "obildbar",
    "obildbarheten": "obildbarhet",
    "obildbarhetens": "obildbarhet",
    "obildbarhets": "obildbarhet",
    "obildbars": "obildbar",
    "obildbart": "obildbar",
    "obildbarts": "obildbar",
    "obildningar": "obildning",
    "obildningarna": "obildning",
    "obildningarnas": "obildning",
    "obildningars": "obildning",
    "obildningen": "obildning",
    "obildningens": "obildning",
    "obildnings": "obildning",
    "obilliga": "obillig",
    "obilligare": "obillig",
    "obilligares": "obillig",
    "obilligas": "obillig",
    "obilligast": "obillig",
    "obilligaste": "obillig",
    "obilligastes": "obillig",
    "obilligasts": "obillig",
    "obillige": "obillig",
    "obilliges": "obillig",
    "obilligheten": "obillighet",
    "obillighetens": "obillighet",
    "obilligheter": "obillighet",
    "obilligheterna": "obillighet",
    "obilligheternas": "obillighet",
    "obilligheters": "obillighet",
    "obillighets": "obillighet",
    "obilligs": "obillig",
    "obilligt": "obillig",
    "obilligts": "obillig",
    "obiograferade": "obiograferad",
    "obiograferades": "obiograferad",
    "obiograferads": "obiograferad",
    "obiograferat": "obiograferad",
    "obiograferats": "obiograferad",
    "obiograferbara": "obiograferbar",
    "obiograferbarare": "obiograferbar",
    "obiograferbarares": "obiograferbar",
    "obiograferbaras": "obiograferbar",
    "obiograferbarast": "obiograferbar",
    "obiograferbaraste": "obiograferbar",
    "obiograferbarastes": "obiograferbar",
    "obiograferbarasts": "obiograferbar",
    "obiograferbare": "obiograferbar",
    "obiograferbares": "obiograferbar",
    "obiograferbarheten": "obiograferbarhet",
    "obiograferbarhetens": "obiograferbarhet",
    "obiograferbarhets": "obiograferbarhet",
    "obiograferbars": "obiograferbar",
    "obiograferbart": "obiograferbar",
    "obiograferbarts": "obiograferbar",
    "obisserade": "obisserad",
    "obisserades": "obisserad",
    "obisserads": "obisserad",
    "obisserat": "obisserad",
    "obisserats": "obisserad",
    "obisserbara": "obisserbar",
    "obisserbarare": "obisserbar",
    "obisserbarares": "obisserbar",
    "obisserbaras": "obisserbar",
    "obisserbarast": "obisserbar",
    "obisserbaraste": "obisserbar",
    "obisserbarastes": "obisserbar",
    "obisserbarasts": "obisserbar",
    "obisserbare": "obisserbar",
    "obisserbares": "obisserbar",
    "obisserbarheten": "obisserbarhet",
    "obisserbarhetens": "obisserbarhet",
    "obisserbarhets": "obisserbarhet",
    "obisserbars": "obisserbar",
    "obisserbart": "obisserbar",
    "obisserbarts": "obisserbar",
    "obisträckta": "obisträckt",
    "obisträcktas": "obisträckt",
    "obisträckte": "obisträckt",
    "obisträcktes": "obisträckt",
    "obisträckts": "obisträckt",
    "obitade": "obitad",
    "obitades": "obitad",
    "obitads": "obitad",
    "obitat": "obitad",
    "obitats": "obitad",
    "obivackerade": "obivackerad",
    "obivackerades": "obivackerad",
    "obivackerads": "obivackerad",
    "obivackerat": "obivackerad",
    "obivackerats": "obivackerad",
    "obivackerbara": "obivackerbar",
    "obivackerbarare": "obivackerbar",
    "obivackerbarares": "obivackerbar",
    "obivackerbaras": "obivackerbar",
    "obivackerbarast": "obivackerbar",
    "obivackerbaraste": "obivackerbar",
    "obivackerbarastes": "obivackerbar",
    "obivackerbarasts": "obivackerbar",
    "obivackerbare": "obivackerbar",
    "obivackerbares": "obivackerbar",
    "obivackerbarheten": "obivackerbarhet",
    "obivackerbarhetens": "obivackerbarhet",
    "obivackerbarhets": "obivackerbarhet",
    "obivackerbars": "obivackerbar",
    "obivackerbart": "obivackerbar",
    "obivackerbarts": "obivackerbar",
    "objekten": "objekt",
    "objektens": "objekt",
    "objektet": "objekt",
    "objektets": "objekt",
    "objektförlusten": "objektförlust",
    "objektförlustens": "objektförlust",
    "objektförlusts": "objektförlust",
    "objektglasen": "objektglas",
    "objektglasens": "objektglas",
    "objektglaset": "objektglas",
    "objektglasets": "objektglas",
    "objektiva": "objektiv",
    "objektivare": "objektiv",
    "objektivares": "objektiv",
    "objektivas": "objektiv",
    "objektivast": "objektiv",
    "objektivaste": "objektiv",
    "objektivastes": "objektiv",
    "objektivasts": "objektiv",
    "objektive": "objektiv",
    "objektiven": "objektiv",
    "objektivens": "objektiv",
    "objektiverad": "objektivera",
    "objektiverade": "objektivera",
    "objektiverades": "objektivera",
    "objektiverads": "objektivera",
    "objektiverande": "objektivera",
    "objektiveranden": "objektiverande",
    "objektiverandena": "objektiverande",
    "objektiverandenas": "objektiverande",
    "objektiverandens": "objektiverande",
    "objektiverandes": "objektiverande",
    "objektiverandet": "objektiverande",
    "objektiverandets": "objektiverande",
    "objektiverar": "objektivera",
    "objektiveras": "objektivera",
    "objektiverat": "objektivera",
    "objektiverats": "objektivera",
    "objektiverbara": "objektiverbar",
    "objektiverbarare": "objektiverbar",
    "objektiverbarares": "objektiverbar",
    "objektiverbaras": "objektiverbar",
    "objektiverbarast": "objektiverbar",
    "objektiverbaraste": "objektiverbar",
    "objektiverbarastes": "objektiverbar",
    "objektiverbarasts": "objektiverbar",
    "objektiverbare": "objektiverbar",
    "objektiverbares": "objektiverbar",
    "objektiverbarheten": "objektiverbarhet",
    "objektiverbarhetens": "objektiverbarhet",
    "objektiverbarhets": "objektiverbarhet",
    "objektiverbars": "objektiverbar",
    "objektiverbart": "objektiverbar",
    "objektiverbarts": "objektiverbar",
    "objektiveringar": "objektivering",
    "objektiveringarna": "objektivering",
    "objektiveringarnas": "objektivering",
    "objektiveringars": "objektivering",
    "objektiveringen": "objektivering",
    "objektiveringens": "objektivering",
    "objektiverings": "objektivering",
    "objektives": "objektiv",
    "objektivet": "objektiv",
    "objektivets": "objektiv",
    "objektivismen": "objektivism",
    "objektivismens": "objektivism",
    "objektivismer": "objektivism",
    "objektivismerna": "objektivism",
    "objektivismernas": "objektivism",
    "objektivismers": "objektivism",
    "objektivisms": "objektivism",
    "objektivistiska": "objektivistisk",
    "objektivistiskas": "objektivistisk",
    "objektivistiske": "objektivistisk",
    "objektivistiskes": "objektivistisk",
    "objektivistisks": "objektivistisk",
    "objektivistiskt": "objektivistisk",
    "objektivistiskts": "objektivistisk",
    "objektiviteten": "objektivitet",
    "objektivitetens": "objektivitet",
    "objektiviteter": "objektivitet",
    "objektiviteterna": "objektivitet",
    "objektiviteternas": "objektivitet",
    "objektiviteters": "objektivitet",
    "objektivitets": "objektivitet",
    "objektivs": "objektiv",
    "objektivt": "objektiv",
    "objektivts": "objektiv",
    "objekts": "objekt",
    "objektsformen": "objektsform",
    "objektsformens": "objektsform",
    "objektsformer": "objektsform",
    "objektsformerna": "objektsform",
    "objektsformernas": "objektsform",
    "objektsformers": "objektsform",
    "objektsforms": "objektsform",
    "objektskatten": "objektskatt",
    "objektskattens": "objektskatt",
    "objektskatter": "objektskatt",
    "objektskatterna": "objektskatt",
    "objektskatternas": "objektskatt",
    "objektskatters": "objektskatt",
    "objektskatts": "objektskatt",
    "objektspråken": "objektspråk",
    "objektspråkens": "objektspråk",
    "objektspråket": "objektspråk",
    "objektspråkets": "objektspråk",
    "objektspråks": "objektspråk",
    "objudens": "objuden",
    "objudet": "objuden",
    "objudets": "objuden",
    "objudna": "objuden",
    "objudnare": "objuden",
    "objudnares": "objuden",
    "objudnas": "objuden",
    "objudnast": "objuden",
    "objudnaste": "objuden",
    "objudnastes": "objuden",
    "objudnasts": "objuden",
    "objudne": "objuden",
    "objudnes": "objuden",
    "objussade": "objussad",
    "objussades": "objussad",
    "objussads": "objussad",
    "objussat": "objussad",
    "objussats": "objussad",
    "objörnade": "objörnad",
    "objörnades": "objörnad",
    "objörnads": "objörnad",
    "objörnat": "objörnad",
    "objörnats": "objörnad",
    "obladade": "obladad",
    "obladades": "obladad",
    "obladads": "obladad",
    "obladat": "obladad",
    "obladats": "obladad",
    "oblancherade": "oblancherad",
    "oblancherades": "oblancherad",
    "oblancherads": "oblancherad",
    "oblancherat": "oblancherad",
    "oblancherats": "oblancherad",
    "oblancherbara": "oblancherbar",
    "oblancherbarare": "oblancherbar",
    "oblancherbarares": "oblancherbar",
    "oblancherbaras": "oblancherbar",
    "oblancherbarast": "oblancherbar",
    "oblancherbaraste": "oblancherbar",
    "oblancherbarastes": "oblancherbar",
    "oblancherbarasts": "oblancherbar",
    "oblancherbare": "oblancherbar",
    "oblancherbares": "oblancherbar",
    "oblancherbarheten": "oblancherbarhet",
    "oblancherbarhetens": "oblancherbarhet",
    "oblancherbarhets": "oblancherbarhet",
    "oblancherbars": "oblancherbar",
    "oblancherbart": "oblancherbar",
    "oblancherbarts": "oblancherbar",
    "oblandade": "oblandad",
    "oblandades": "oblandad",
    "oblandads": "oblandad",
    "oblandat": "oblandad",
    "oblandats": "oblandad",
    "oblankade": "oblankad",
    "oblankades": "oblankad",
    "oblankads": "oblankad",
    "oblankat": "oblankad",
    "oblankats": "oblankad",
    "oblankpolerbara": "oblankpolerbar",
    "oblankpolerbarare": "oblankpolerbar",
    "oblankpolerbarares": "oblankpolerbar",
    "oblankpolerbaras": "oblankpolerbar",
    "oblankpolerbarast": "oblankpolerbar",
    "oblankpolerbaraste": "oblankpolerbar",
    "oblankpolerbarastes": "oblankpolerbar",
    "oblankpolerbarasts": "oblankpolerbar",
    "oblankpolerbare": "oblankpolerbar",
    "oblankpolerbares": "oblankpolerbar",
    "oblankpolerbarheten": "oblankpolerbarhet",
    "oblankpolerbarhetens": "oblankpolerbarhet",
    "oblankpolerbarhets": "oblankpolerbarhet",
    "oblankpolerbars": "oblankpolerbar",
    "oblankpolerbart": "oblankpolerbar",
    "oblankpolerbarts": "oblankpolerbar",
    "oblasten": "oblast",
    "oblastens": "oblast",
    "oblaster": "oblast",
    "oblasterna": "oblast",
    "oblasternas": "oblast",
    "oblasters": "oblast",
    "oblasts": "oblast",
    "oblaten": "oblat",
    "oblatens": "oblat",
    "oblater": "oblat",
    "oblaterna": "oblat",
    "oblaternas": "oblat",
    "oblaters": "oblat",
    "oblats": "oblat",
    "obleknade": "obleknad",
    "obleknades": "obleknad",
    "obleknads": "obleknad",
    "obleknat": "obleknad",
    "obleknats": "obleknad",
    "oblekta": "oblekt",
    "oblektare": "oblekt",
    "oblektares": "oblekt",
    "oblektas": "oblekt",
    "oblektast": "oblekt",
    "oblektaste": "oblekt",
    "oblektastes": "oblekt",
    "oblektasts": "oblekt",
    "oblekte": "oblekt",
    "oblektes": "oblekt",
    "oblekts": "oblekt",
    "oblesserade": "oblesserad",
    "oblesserades": "oblesserad",
    "oblesserads": "oblesserad",
    "oblesserat": "oblesserad",
    "oblesserats": "oblesserad",
    "oblesserbara": "oblesserbar",
    "oblesserbarare": "oblesserbar",
    "oblesserbarares": "oblesserbar",
    "oblesserbaras": "oblesserbar",
    "oblesserbarast": "oblesserbar",
    "oblesserbaraste": "oblesserbar",
    "oblesserbarastes": "oblesserbar",
    "oblesserbarasts": "oblesserbar",
    "oblesserbare": "oblesserbar",
    "oblesserbares": "oblesserbar",
    "oblesserbarheten": "oblesserbarhet",
    "oblesserbarhetens": "oblesserbarhet",
    "oblesserbarhets": "oblesserbarhet",
    "oblesserbars": "oblesserbar",
    "oblesserbart": "oblesserbar",
    "oblesserbarts": "oblesserbar",
    "oblida": "oblid",
    "oblidare": "oblid",
    "oblidares": "oblid",
    "oblidas": "oblid",
    "oblidast": "oblid",
    "oblidaste": "oblid",
    "oblidastes": "oblid",
    "oblidasts": "oblid",
    "oblide": "oblid",
    "oblides": "oblid",
    "oblidkade": "oblidkad",
    "oblidkades": "oblidkad",
    "oblidkads": "oblidkad",
    "oblidkat": "oblidkad",
    "oblidkats": "oblidkad",
    "oblidkeliga": "oblidkelig",
    "oblidkeligare": "oblidkelig",
    "oblidkeligares": "oblidkelig",
    "oblidkeligas": "oblidkelig",
    "oblidkeligast": "oblidkelig",
    "oblidkeligaste": "oblidkelig",
    "oblidkeligastes": "oblidkelig",
    "oblidkeligasts": "oblidkelig",
    "oblidkelige": "oblidkelig",
    "oblidkeliges": "oblidkelig",
    "oblidkeligheten": "oblidkelighet",
    "oblidkelighetens": "oblidkelighet",
    "oblidkelighets": "oblidkelighet",
    "oblidkeligs": "oblidkelig",
    "oblidkeligt": "oblidkelig",
    "oblidkeligts": "oblidkelig",
    "oblids": "oblid",
    "obligata": "obligat",
    "obligatare": "obligat",
    "obligatares": "obligat",
    "obligatas": "obligat",
    "obligatast": "obligat",
    "obligataste": "obligat",
    "obligatastes": "obligat",
    "obligatasts": "obligat",
    "obligate": "obligat",
    "obligaten": "obligat",
    "obligatens": "obligat",
    "obligater": "obligat",
    "obligaterna": "obligat",
    "obligaternas": "obligat",
    "obligaters": "obligat",
    "obligates": "obligat",
    "obligationen": "obligation",
    "obligationens": "obligation",
    "obligationer": "obligation",
    "obligationerna": "obligation",
    "obligationernas": "obligation",
    "obligationers": "obligation",
    "obligations": "obligation",
    "obligationslånen": "obligationslån",
    "obligationslånens": "obligationslån",
    "obligationslånet": "obligationslån",
    "obligationslånets": "obligationslån",
    "obligationslåns": "obligationslån",
    "obligatorie": "obligatorium",
    "obligatorier": "obligatorium",
    "obligatorierna": "obligatorium",
    "obligatoriernas": "obligatorium",
    "obligatoriers": "obligatorium",
    "obligatoriet": "obligatorium",
    "obligatoriets": "obligatorium",
    "obligatoriska": "obligatorisk",
    "obligatoriskare": "obligatorisk",
    "obligatoriskares": "obligatorisk",
    "obligatoriskas": "obligatorisk",
    "obligatoriskast": "obligatorisk",
    "obligatoriskaste": "obligatorisk",
    "obligatoriskastes": "obligatorisk",
    "obligatoriskasts": "obligatorisk",
    "obligatoriske": "obligatorisk",
    "obligatoriskes": "obligatorisk",
    "obligatorisks": "obligatorisk",
    "obligatoriskt": "obligatorisk",
    "obligatoriskts": "obligatorisk",
    "obligatoriums": "obligatorium",
    "obligats": "obligat",
    "obligerad": "obligera",
    "obligerade": "obligera",
    "obligerades": "obligera",
    "obligerads": "obligera",
    "obligerande": "obligera",
    "obligeranden": "obligerande",
    "obligerandena": "obligerande",
    "obligerandenas": "obligerande",
    "obligerandens": "obligerande",
    "obligerandes": "obligerande",
    "obligerandet": "obligerande",
    "obligerandets": "obligerande",
    "obligerar": "obligera",
    "obligeras": "obligera",
    "obligerat": "obligera",
    "obligerats": "obligera",
    "obligerbara": "obligerbar",
    "obligerbarare": "obligerbar",
    "obligerbarares": "obligerbar",
    "obligerbaras": "obligerbar",
    "obligerbarast": "obligerbar",
    "obligerbaraste": "obligerbar",
    "obligerbarastes": "obligerbar",
    "obligerbarasts": "obligerbar",
    "obligerbare": "obligerbar",
    "obligerbares": "obligerbar",
    "obligerbarheten": "obligerbarhet",
    "obligerbarhetens": "obligerbarhet",
    "obligerbarhets": "obligerbarhet",
    "obligerbars": "obligerbar",
    "obligerbart": "obligerbar",
    "obligerbarts": "obligerbar",
    "obligeringar": "obligering",
    "obligeringarna": "obligering",
    "obligeringarnas": "obligering",
    "obligeringars": "obligering",
    "obligeringen": "obligering",
    "obligeringens": "obligering",
    "obligerings": "obligering",
    "oblika": "oblik",
    "oblikare": "oblik",
    "oblikares": "oblik",
    "oblikas": "oblik",
    "oblikast": "oblik",
    "oblikaste": "oblik",
    "oblikastes": "oblik",
    "oblikasts": "oblik",
    "oblike": "oblik",
    "obliken": "oblik",
    "oblikens": "oblik",
    "obliker": "oblik",
    "oblikerna": "oblik",
    "oblikernas": "oblik",
    "oblikers": "oblik",
    "oblikes": "oblik",
    "oblikheten": "oblikhet",
    "oblikhetens": "oblikhet",
    "oblikhets": "oblikhet",
    "obliks": "oblik",
    "oblikt": "oblik",
    "oblikts": "oblik",
    "oblikviteten": "oblikvitet",
    "oblikvitetens": "oblikvitet",
    "oblikviteter": "oblikvitet",
    "oblikviteterna": "oblikvitet",
    "oblikviteternas": "oblikvitet",
    "oblikviteters": "oblikvitet",
    "oblikvitets": "oblikvitet",
    "oblinderade": "oblinderad",
    "oblinderades": "oblinderad",
    "oblinderads": "oblinderad",
    "oblinderat": "oblinderad",
    "oblinderats": "oblinderad",
    "oblinderbara": "oblinderbar",
    "oblinderbarare": "oblinderbar",
    "oblinderbarares": "oblinderbar",
    "oblinderbaras": "oblinderbar",
    "oblinderbarast": "oblinderbar",
    "oblinderbaraste": "oblinderbar",
    "oblinderbarastes": "oblinderbar",
    "oblinderbarasts": "oblinderbar",
    "oblinderbare": "oblinderbar",
    "oblinderbares": "oblinderbar",
    "oblinderbarheten": "oblinderbarhet",
    "oblinderbarhetens": "oblinderbarhet",
    "oblinderbarhets": "oblinderbarhet",
    "oblinderbars": "oblinderbar",
    "oblinderbart": "oblinderbar",
    "oblinderbarts": "oblinderbar",
    "oblitt": "oblid",
    "oblitts": "oblid",
    "oblockade": "oblockad",
    "oblockades": "oblockad",
    "oblockads": "oblockad",
    "oblockat": "oblockad",
    "oblockats": "oblockad",
    "oblockerade": "oblockerad",
    "oblockerades": "oblockerad",
    "oblockerads": "oblockerad",
    "oblockerat": "oblockerad",
    "oblockerats": "oblockerad",
    "oblockerbara": "oblockerbar",
    "oblockerbarare": "oblockerbar",
    "oblockerbarares": "oblockerbar",
    "oblockerbaras": "oblockerbar",
    "oblockerbarast": "oblockerbar",
    "oblockerbaraste": "oblockerbar",
    "oblockerbarastes": "oblockerbar",
    "oblockerbarasts": "oblockerbar",
    "oblockerbare": "oblockerbar",
    "oblockerbares": "oblockerbar",
    "oblockerbarheten": "oblockerbarhet",
    "oblockerbarhetens": "oblockerbarhet",
    "oblockerbarhets": "oblockerbarhet",
    "oblockerbars": "oblockerbar",
    "oblockerbart": "oblockerbar",
    "oblockerbarts": "oblockerbar",
    "oblodade": "oblodad",
    "oblodades": "oblodad",
    "oblodads": "oblodad",
    "oblodat": "oblodad",
    "oblodats": "oblodad",
    "oblodiga": "oblodig",
    "oblodigare": "oblodig",
    "oblodigares": "oblodig",
    "oblodigas": "oblodig",
    "oblodigast": "oblodig",
    "oblodigaste": "oblodig",
    "oblodigastes": "oblodig",
    "oblodigasts": "oblodig",
    "oblodige": "oblodig",
    "oblodiges": "oblodig",
    "oblodigheten": "oblodighet",
    "oblodighetens": "oblodighet",
    "oblodighets": "oblodighet",
    "oblodigs": "oblodig",
    "oblodigt": "oblodig",
    "oblodigts": "oblodig",
    "obloggade": "obloggad",
    "obloggades": "obloggad",
    "obloggads": "obloggad",
    "obloggat": "obloggad",
    "obloggats": "obloggad",
    "oblommograferade": "oblommograferad",
    "oblommograferades": "oblommograferad",
    "oblommograferads": "oblommograferad",
    "oblommograferat": "oblommograferad",
    "oblommograferats": "oblommograferad",
    "oblommograferbara": "oblommograferbar",
    "oblommograferbarare": "oblommograferbar",
    "oblommograferbarares": "oblommograferbar",
    "oblommograferbaras": "oblommograferbar",
    "oblommograferbarast": "oblommograferbar",
    "oblommograferbaraste": "oblommograferbar",
    "oblommograferbarastes": "oblommograferbar",
    "oblommograferbarasts": "oblommograferbar",
    "oblommograferbare": "oblommograferbar",
    "oblommograferbares": "oblommograferbar",
    "oblommograferbarheten": "oblommograferbarhet",
    "oblommograferbarhetens": "oblommograferbarhet",
    "oblommograferbarhets": "oblommograferbarhet",
    "oblommograferbars": "oblommograferbar",
    "oblommograferbart": "oblommograferbar",
    "oblommograferbarts": "oblommograferbar",
    "oblonderade": "oblonderad",
    "oblonderades": "oblonderad",
    "oblonderads": "oblonderad",
    "oblonderat": "oblonderad",
    "oblonderats": "oblonderad",
    "oblonderbara": "oblonderbar",
    "oblonderbarare": "oblonderbar",
    "oblonderbarares": "oblonderbar",
    "oblonderbaras": "oblonderbar",
    "oblonderbarast": "oblonderbar",
    "oblonderbaraste": "oblonderbar",
    "oblonderbarastes": "oblonderbar",
    "oblonderbarasts": "oblonderbar",
    "oblonderbare": "oblonderbar",
    "oblonderbares": "oblonderbar",
    "oblonderbarheten": "oblonderbarhet",
    "oblonderbarhetens": "oblonderbarhet",
    "oblonderbarhets": "oblonderbarhet",
    "oblonderbars": "oblonderbar",
    "oblonderbart": "oblonderbar",
    "oblonderbarts": "oblonderbar",
    "oblottade": "oblottad",
    "oblottades": "oblottad",
    "oblottads": "oblottad",
    "oblottat": "oblottad",
    "oblottats": "oblottad",
    "obluffade": "obluffad",
    "obluffades": "obluffad",
    "obluffads": "obluffad",
    "obluffat": "obluffad",
    "obluffats": "obluffad",
    "oblyade": "oblyad",
    "oblyades": "oblyad",
    "oblyads": "oblyad",
    "oblyat": "oblyad",
    "oblyats": "oblyad",
    "oblyga": "oblyg",
    "oblygare": "oblyg",
    "oblygares": "oblyg",
    "oblygas": "oblyg",
    "oblygast": "oblyg",
    "oblygaste": "oblyg",
    "oblygastes": "oblyg",
    "oblygasts": "oblyg",
    "oblyge": "oblyg",
    "oblyges": "oblyg",
    "oblygheten": "oblyghet",
    "oblyghetens": "oblyghet",
    "oblyghets": "oblyghet",
    "oblygs": "oblyg",
    "oblygt": "oblyg",
    "oblygts": "oblyg",
    "obläckade": "obläckad",
    "obläckades": "obläckad",
    "obläckads": "obläckad",
    "obläckat": "obläckad",
    "obläckats": "obläckad",
    "oblädade": "oblädad",
    "oblädades": "oblädad",
    "oblädads": "oblädad",
    "oblädat": "oblädad",
    "oblädats": "oblädad",
    "obläddrade": "obläddrad",
    "obläddrades": "obläddrad",
    "obläddrads": "obläddrad",
    "obläddrat": "obläddrad",
    "obläddrats": "obläddrad",
    "obländade": "obländad",
    "obländades": "obländad",
    "obländads": "obländad",
    "obländat": "obländad",
    "obländats": "obländad",
    "oblästade": "oblästad",
    "oblästades": "oblästad",
    "oblästads": "oblästad",
    "oblästat": "oblästad",
    "oblästats": "oblästad",
    "oblästrade": "oblästrad",
    "oblästrades": "oblästrad",
    "oblästrads": "oblästrad",
    "oblästrat": "oblästrad",
    "oblästrats": "oblästrad",
    "oblåsta": "oblåst",
    "oblåstas": "oblåst",
    "oblåste": "oblåst",
    "oblåstes": "oblåst",
    "oblåsts": "oblåst",
    "oblötta": "oblött",
    "oblöttas": "oblött",
    "oblötte": "oblött",
    "oblöttes": "oblött",
    "oblötts": "oblött",
    "oboaserade": "oboaserad",
    "oboaserades": "oboaserad",
    "oboaserads": "oboaserad",
    "oboaserat": "oboaserad",
    "oboaserats": "oboaserad",
    "oboaserbara": "oboaserbar",
    "oboaserbarare": "oboaserbar",
    "oboaserbarares": "oboaserbar",
    "oboaserbaras": "oboaserbar",
    "oboaserbarast": "oboaserbar",
    "oboaserbaraste": "oboaserbar",
    "oboaserbarastes": "oboaserbar",
    "oboaserbarasts": "oboaserbar",
    "oboaserbare": "oboaserbar",
    "oboaserbares": "oboaserbar",
    "oboaserbarheten": "oboaserbarhet",
    "oboaserbarhetens": "oboaserbarhet",
    "oboaserbarhets": "oboaserbarhet",
    "oboaserbars": "oboaserbar",
    "oboaserbart": "oboaserbar",
    "oboaserbarts": "oboaserbar",
    "obobbade": "obobbad",
    "obobbades": "obobbad",
    "obobbads": "obobbad",
    "obobbat": "obobbad",
    "obobbats": "obobbad",
    "obockade": "obockad",
    "obockades": "obockad",
    "obockads": "obockad",
    "obockat": "obockad",
    "obockats": "obockad",
    "oboen": "oboe",
    "oboens": "oboe",
    "oboer": "oboe",
    "oboerna": "oboe",
    "oboernas": "oboe",
    "oboers": "oboe",
    "oboes": "oboe",
    "obogserade": "obogserad",
    "obogserades": "obogserad",
    "obogserads": "obogserad",
    "obogserat": "obogserad",
    "obogserats": "obogserad",
    "obogserbara": "obogserbar",
    "obogserbarare": "obogserbar",
    "obogserbarares": "obogserbar",
    "obogserbaras": "obogserbar",
    "obogserbarast": "obogserbar",
    "obogserbaraste": "obogserbar",
    "obogserbarastes": "obogserbar",
    "obogserbarasts": "obogserbar",
    "obogserbare": "obogserbar",
    "obogserbares": "obogserbar",
    "obogserbarheten": "obogserbarhet",
    "obogserbarhetens": "obogserbarhet",
    "obogserbarhets": "obogserbarhet",
    "obogserbars": "obogserbar",
    "obogserbart": "obogserbar",
    "obogserbarts": "obogserbar",
    "obojkottade": "obojkottad",
    "obojkottades": "obojkottad",
    "obojkottads": "obojkottad",
    "obojkottat": "obojkottad",
    "obojkottats": "obojkottad",
    "obokade": "obokad",
    "obokades": "obokad",
    "obokads": "obokad",
    "obokat": "obokad",
    "obokats": "obokad",
    "obokförde": "obokförd",
    "obokfördes": "obokförd",
    "obokförds": "obokförd",
    "obokfört": "obokförd",
    "obokförts": "obokförd",
    "obokstaverade": "obokstaverad",
    "obokstaverades": "obokstaverad",
    "obokstaverads": "obokstaverad",
    "obokstaverat": "obokstaverad",
    "obokstaverats": "obokstaverad",
    "obokstaverbara": "obokstaverbar",
    "obokstaverbarare": "obokstaverbar",
    "obokstaverbarares": "obokstaverbar",
    "obokstaverbaras": "obokstaverbar",
    "obokstaverbarast": "obokstaverbar",
    "obokstaverbaraste": "obokstaverbar",
    "obokstaverbarastes": "obokstaverbar",
    "obokstaverbarasts": "obokstaverbar",
    "obokstaverbare": "obokstaverbar",
    "obokstaverbares": "obokstaverbar",
    "obokstaverbarheten": "obokstaverbarhet",
    "obokstaverbarhetens": "obokstaverbarhet",
    "obokstaverbarhets": "obokstaverbarhet",
    "obokstaverbars": "obokstaverbar",
    "obokstaverbart": "obokstaverbar",
    "obokstaverbarts": "obokstaverbar",
    "obolen": "obol",
    "obolens": "obol",
    "oboler": "obol",
    "obolerna": "obol",
    "obolernas": "obol",
    "obolers": "obol",
    "obollade": "obollad",
    "obollades": "obollad",
    "obollads": "obollad",
    "obollat": "obollad",
    "obollats": "obollad",
    "obols": "obol",
    "obombade": "obombad",
    "obombades": "obombad",
    "obombads": "obombad",
    "obombarderade": "obombarderad",
    "obombarderades": "obombarderad",
    "obombarderads": "obombarderad",
    "obombarderat": "obombarderad",
    "obombarderats": "obombarderad",
    "obombarderbara": "obombarderbar",
    "obombarderbarare": "obombarderbar",
    "obombarderbarares": "obombarderbar",
    "obombarderbaras": "obombarderbar",
    "obombarderbarast": "obombarderbar",
    "obombarderbaraste": "obombarderbar",
    "obombarderbarastes": "obombarderbar",
    "obombarderbarasts": "obombarderbar",
    "obombarderbare": "obombarderbar",
    "obombarderbares": "obombarderbar",
    "obombarderbarheten": "obombarderbarhet",
    "obombarderbarhetens": "obombarderbarhet",
    "obombarderbarhets": "obombarderbarhet",
    "obombarderbars": "obombarderbar",
    "obombarderbart": "obombarderbar",
    "obombarderbarts": "obombarderbar",
    "obombat": "obombad",
    "obombats": "obombad",
    "obommade": "obommad",
    "obommades": "obommad",
    "obommads": "obommad",
    "obommat": "obommad",
    "obommats": "obommad",
    "obonade": "obonad",
    "obonades": "obonad",
    "obonads": "obonad",
    "obonat": "obonad",
    "obonats": "obonad",
    "obongade": "obongad",
    "obongades": "obongad",
    "obongads": "obongad",
    "obongat": "obongad",
    "obongats": "obongad",
    "oboniterade": "oboniterad",
    "oboniterades": "oboniterad",
    "oboniterads": "oboniterad",
    "oboniterat": "oboniterad",
    "oboniterats": "oboniterad",
    "oboniterbara": "oboniterbar",
    "oboniterbarare": "oboniterbar",
    "oboniterbarares": "oboniterbar",
    "oboniterbaras": "oboniterbar",
    "oboniterbarast": "oboniterbar",
    "oboniterbaraste": "oboniterbar",
    "oboniterbarastes": "oboniterbar",
    "oboniterbarasts": "oboniterbar",
    "oboniterbare": "oboniterbar",
    "oboniterbares": "oboniterbar",
    "oboniterbarheten": "oboniterbarhet",
    "oboniterbarhetens": "oboniterbarhet",
    "oboniterbarhets": "oboniterbarhet",
    "oboniterbars": "oboniterbar",
    "oboniterbart": "oboniterbar",
    "oboniterbarts": "oboniterbar",
    "obootade": "obootad",
    "obootades": "obootad",
    "obootads": "obootad",
    "obootat": "obootad",
    "obootats": "obootad",
    "obordade": "obordad",
    "obordades": "obordad",
    "obordads": "obordad",
    "obordat": "obordad",
    "obordats": "obordad",
    "oborgade": "oborgad",
    "oborgades": "oborgad",
    "oborgads": "oborgad",
    "oborgat": "oborgad",
    "oborgats": "oborgad",
    "oborrade": "oborrad",
    "oborrades": "oborrad",
    "oborrads": "oborrad",
    "oborrat": "oborrad",
    "oborrats": "oborrad",
    "oborstade": "oborstad",
    "oborstades": "oborstad",
    "oborstads": "oborstad",
    "oborstat": "oborstad",
    "oborstats": "oborstad",
    "obortförde": "obortförd",
    "obortfördes": "obortförd",
    "obortförds": "obortförd",
    "obortfört": "obortförd",
    "obortförts": "obortförd",
    "obortresonerbara": "obortresonerbar",
    "obortresonerbarare": "obortresonerbar",
    "obortresonerbarares": "obortresonerbar",
    "obortresonerbaras": "obortresonerbar",
    "obortresonerbarast": "obortresonerbar",
    "obortresonerbaraste": "obortresonerbar",
    "obortresonerbarastes": "obortresonerbar",
    "obortresonerbarasts": "obortresonerbar",
    "obortresonerbare": "obortresonerbar",
    "obortresonerbares": "obortresonerbar",
    "obortresonerbarheten": "obortresonerbarhet",
    "obortresonerbarhetens": "obortresonerbarhet",
    "obortresonerbarhets": "obortresonerbarhet",
    "obortresonerbars": "obortresonerbar",
    "obortresonerbart": "obortresonerbar",
    "obortresonerbarts": "obortresonerbar",
    "obotade": "obotad",
    "obotades": "obotad",
    "obotads": "obotad",
    "obotat": "obotad",
    "obotats": "obotad",
    "obotfärdiga": "obotfärdig",
    "obotfärdigare": "obotfärdig",
    "obotfärdigares": "obotfärdig",
    "obotfärdigas": "obotfärdig",
    "obotfärdigast": "obotfärdig",
    "obotfärdigaste": "obotfärdig",
    "obotfärdigastes": "obotfärdig",
    "obotfärdigasts": "obotfärdig",
    "obotfärdige": "obotfärdig",
    "obotfärdiges": "obotfärdig",
    "obotfärdigheten": "obotfärdighet",
    "obotfärdighetens": "obotfärdighet",
    "obotfärdighets": "obotfärdighet",
    "obotfärdigs": "obotfärdig",
    "obotfärdigt": "obotfärdig",
    "obotfärdigts": "obotfärdig",
    "obotliga": "obotlig",
    "obotligare": "obotlig",
    "obotligares": "obotlig",
    "obotligas": "obotlig",
    "obotligast": "obotlig",
    "obotligaste": "obotlig",
    "obotligastes": "obotlig",
    "obotligasts": "obotlig",
    "obotlige": "obotlig",
    "obotliges": "obotlig",
    "obotligheten": "obotlighet",
    "obotlighetens": "obotlighet",
    "obotlighets": "obotlighet",
    "obotligs": "obotlig",
    "obotligt": "obotlig",
    "obotligts": "obotlig",
    "oboxade": "oboxad",
    "oboxades": "oboxad",
    "oboxads": "oboxad",
    "oboxat": "oboxad",
    "oboxats": "oboxad",
    "obrassade": "obrassad",
    "obrassades": "obrassad",
    "obrassads": "obrassad",
    "obrassat": "obrassad",
    "obrassats": "obrassad",
    "obreddade": "obreddad",
    "obreddades": "obreddad",
    "obreddads": "obreddad",
    "obreddat": "obreddad",
    "obreddats": "obreddad",
    "obriefade": "obriefad",
    "obriefades": "obriefad",
    "obriefads": "obriefad",
    "obriefat": "obriefad",
    "obriefats": "obriefad",
    "obriketterade": "obriketterad",
    "obriketterades": "obriketterad",
    "obriketterads": "obriketterad",
    "obriketterat": "obriketterad",
    "obriketterats": "obriketterad",
    "obriketterbara": "obriketterbar",
    "obriketterbarare": "obriketterbar",
    "obriketterbarares": "obriketterbar",
    "obriketterbaras": "obriketterbar",
    "obriketterbarast": "obriketterbar",
    "obriketterbaraste": "obriketterbar",
    "obriketterbarastes": "obriketterbar",
    "obriketterbarasts": "obriketterbar",
    "obriketterbare": "obriketterbar",
    "obriketterbares": "obriketterbar",
    "obriketterbarheten": "obriketterbarhet",
    "obriketterbarhetens": "obriketterbarhet",
    "obriketterbarhets": "obriketterbarhet",
    "obriketterbars": "obriketterbar",
    "obriketterbart": "obriketterbar",
    "obriketterbarts": "obriketterbar",
    "obriserade": "obriserad",
    "obriserades": "obriserad",
    "obriserads": "obriserad",
    "obriserat": "obriserad",
    "obriserats": "obriserad",
    "obriserbara": "obriserbar",
    "obriserbarare": "obriserbar",
    "obriserbarares": "obriserbar",
    "obriserbaras": "obriserbar",
    "obriserbarast": "obriserbar",
    "obriserbaraste": "obriserbar",
    "obriserbarastes": "obriserbar",
    "obriserbarasts": "obriserbar",
    "obriserbare": "obriserbar",
    "obriserbares": "obriserbar",
    "obriserbarheten": "obriserbarhet",
    "obriserbarhetens": "obriserbarhet",
    "obriserbarhets": "obriserbarhet",
    "obriserbars": "obriserbar",
    "obriserbart": "obriserbar",
    "obriserbarts": "obriserbar",
    "obroade": "obroad",
    "obroades": "obroad",
    "obroads": "obroad",
    "obroat": "obroad",
    "obroats": "obroad",
    "obroddade": "obroddad",
    "obroddades": "obroddad",
    "obroddads": "obroddad",
    "obroddat": "obroddad",
    "obroddats": "obroddad",
    "obroderade": "obroderad",
    "obroderades": "obroderad",
    "obroderads": "obroderad",
    "obroderat": "obroderad",
    "obroderats": "obroderad",
    "obroderbara": "obroderbar",
    "obroderbarare": "obroderbar",
    "obroderbarares": "obroderbar",
    "obroderbaras": "obroderbar",
    "obroderbarast": "obroderbar",
    "obroderbaraste": "obroderbar",
    "obroderbarastes": "obroderbar",
    "obroderbarasts": "obroderbar",
    "obroderbare": "obroderbar",
    "obroderbares": "obroderbar",
    "obroderbarheten": "obroderbarhet",
    "obroderbarhetens": "obroderbarhet",
    "obroderbarhets": "obroderbarhet",
    "obroderbars": "obroderbar",
    "obroderbart": "obroderbar",
    "obroderbarts": "obroderbar",
    "obromerade": "obromerad",
    "obromerades": "obromerad",
    "obromerads": "obromerad",
    "obromerat": "obromerad",
    "obromerats": "obromerad",
    "obromerbara": "obromerbar",
    "obromerbarare": "obromerbar",
    "obromerbarares": "obromerbar",
    "obromerbaras": "obromerbar",
    "obromerbarast": "obromerbar",
    "obromerbaraste": "obromerbar",
    "obromerbarastes": "obromerbar",
    "obromerbarasts": "obromerbar",
    "obromerbare": "obromerbar",
    "obromerbares": "obromerbar",
    "obromerbarheten": "obromerbarhet",
    "obromerbarhetens": "obromerbarhet",
    "obromerbarhets": "obromerbarhet",
    "obromerbars": "obromerbar",
    "obromerbart": "obromerbar",
    "obromerbarts": "obromerbar",
    "obromsade": "obromsad",
    "obromsades": "obromsad",
    "obromsads": "obromsad",
    "obromsat": "obromsad",
    "obromsats": "obromsad",
    "obronserade": "obronserad",
    "obronserades": "obronserad",
    "obronserads": "obronserad",
    "obronserat": "obronserad",
    "obronserats": "obronserad",
    "obronserbara": "obronserbar",
    "obronserbarare": "obronserbar",
    "obronserbarares": "obronserbar",
    "obronserbaras": "obronserbar",
    "obronserbarast": "obronserbar",
    "obronserbaraste": "obronserbar",
    "obronserbarastes": "obronserbar",
    "obronserbarasts": "obronserbar",
    "obronserbare": "obronserbar",
    "obronserbares": "obronserbar",
    "obronserbarheten": "obronserbarhet",
    "obronserbarhetens": "obronserbarhet",
    "obronserbarhets": "obronserbarhet",
    "obronserbars": "obronserbar",
    "obronserbart": "obronserbar",
    "obronserbarts": "obronserbar",
    "obroscherade": "obroscherad",
    "obroscherades": "obroscherad",
    "obroscherads": "obroscherad",
    "obroscherat": "obroscherad",
    "obroscherats": "obroscherad",
    "obroscherbara": "obroscherbar",
    "obroscherbarare": "obroscherbar",
    "obroscherbarares": "obroscherbar",
    "obroscherbaras": "obroscherbar",
    "obroscherbarast": "obroscherbar",
    "obroscherbaraste": "obroscherbar",
    "obroscherbarastes": "obroscherbar",
    "obroscherbarasts": "obroscherbar",
    "obroscherbare": "obroscherbar",
    "obroscherbares": "obroscherbar",
    "obroscherbarheten": "obroscherbarhet",
    "obroscherbarhetens": "obroscherbarhet",
    "obroscherbarhets": "obroscherbarhet",
    "obroscherbars": "obroscherbar",
    "obroscherbart": "obroscherbar",
    "obroscherbarts": "obroscherbar",
    "obrosslade": "obrosslad",
    "obrosslades": "obrosslad",
    "obrosslads": "obrosslad",
    "obrosslat": "obrosslad",
    "obrosslats": "obrosslad",
    "obrotschade": "obrotschad",
    "obrotschades": "obrotschad",
    "obrotschads": "obrotschad",
    "obrotschat": "obrotschad",
    "obrotschats": "obrotschad",
    "obrottsliga": "obrottslig",
    "obrottsligare": "obrottslig",
    "obrottsligares": "obrottslig",
    "obrottsligas": "obrottslig",
    "obrottsligast": "obrottslig",
    "obrottsligaste": "obrottslig",
    "obrottsligastes": "obrottslig",
    "obrottsligasts": "obrottslig",
    "obrottslige": "obrottslig",
    "obrottsliges": "obrottslig",
    "obrottsligheten": "obrottslighet",
    "obrottslighetens": "obrottslighet",
    "obrottslighets": "obrottslighet",
    "obrottsligs": "obrottslig",
    "obrottsligt": "obrottslig",
    "obrottsligts": "obrottslig",
    "obrucklade": "obrucklad",
    "obrucklades": "obrucklad",
    "obrucklads": "obrucklad",
    "obrucklat": "obrucklad",
    "obrucklats": "obrucklad",
    "obrukade": "obrukad",
    "obrukades": "obrukad",
    "obrukads": "obrukad",
    "obrukat": "obrukad",
    "obrukats": "obrukad",
    "obrukbara": "obrukbar",
    "obrukbarare": "obrukbar",
    "obrukbarares": "obrukbar",
    "obrukbaras": "obrukbar",
    "obrukbarast": "obrukbar",
    "obrukbaraste": "obrukbar",
    "obrukbarastes": "obrukbar",
    "obrukbarasts": "obrukbar",
    "obrukbare": "obrukbar",
    "obrukbares": "obrukbar",
    "obrukbarheten": "obrukbarhet",
    "obrukbarhetens": "obrukbarhet",
    "obrukbarhets": "obrukbarhet",
    "obrukbars": "obrukbar",
    "obrukbart": "obrukbar",
    "obrukbarts": "obrukbar",
    "obrukliga": "obruklig",
    "obrukligare": "obruklig",
    "obrukligares": "obruklig",
    "obrukligas": "obruklig",
    "obrukligast": "obruklig",
    "obrukligaste": "obruklig",
    "obrukligastes": "obruklig",
    "obrukligasts": "obruklig",
    "obruklige": "obruklig",
    "obrukliges": "obruklig",
    "obrukligheten": "obruklighet",
    "obruklighetens": "obruklighet",
    "obruklighets": "obruklighet",
    "obrukligs": "obruklig",
    "obrukligt": "obruklig",
    "obrukligts": "obruklig",
    "obrunerade": "obrunerad",
    "obrunerades": "obrunerad",
    "obrunerads": "obrunerad",
    "obrunerat": "obrunerad",
    "obrunerats": "obrunerad",
    "obrunerbara": "obrunerbar",
    "obrunerbarare": "obrunerbar",
    "obrunerbarares": "obrunerbar",
    "obrunerbaras": "obrunerbar",
    "obrunerbarast": "obrunerbar",
    "obrunerbaraste": "obrunerbar",
    "obrunerbarastes": "obrunerbar",
    "obrunerbarasts": "obrunerbar",
    "obrunerbare": "obrunerbar",
    "obrunerbares": "obrunerbar",
    "obrunerbarheten": "obrunerbarhet",
    "obrunerbarhetens": "obrunerbarhet",
    "obrunerbarhets": "obrunerbarhet",
    "obrunerbars": "obrunerbar",
    "obrunerbart": "obrunerbar",
    "obrunerbarts": "obrunerbar",
    "obrunfärgade": "obrunfärgad",
    "obrunfärgades": "obrunfärgad",
    "obrunfärgads": "obrunfärgad",
    "obrunfärgat": "obrunfärgad",
    "obrunfärgats": "obrunfärgad",
    "obrunna": "obrunnen",
    "obrunnare": "obrunnen",
    "obrunnares": "obrunnen",
    "obrunnas": "obrunnen",
    "obrunnast": "obrunnen",
    "obrunnaste": "obrunnen",
    "obrunnastes": "obrunnen",
    "obrunnasts": "obrunnen",
    "obrunne": "obrunnen",
    "obrunnens": "obrunnen",
    "obrunnes": "obrunnen",
    "obrunnet": "obrunnen",
    "obrunnets": "obrunnen",
    "obrutaliserade": "obrutaliserad",
    "obrutaliserades": "obrutaliserad",
    "obrutaliserads": "obrutaliserad",
    "obrutaliserat": "obrutaliserad",
    "obrutaliserats": "obrutaliserad",
    "obrutaliserbara": "obrutaliserbar",
    "obrutaliserbarare": "obrutaliserbar",
    "obrutaliserbarares": "obrutaliserbar",
    "obrutaliserbaras": "obrutaliserbar",
    "obrutaliserbarast": "obrutaliserbar",
    "obrutaliserbaraste": "obrutaliserbar",
    "obrutaliserbarastes": "obrutaliserbar",
    "obrutaliserbarasts": "obrutaliserbar",
    "obrutaliserbare": "obrutaliserbar",
    "obrutaliserbares": "obrutaliserbar",
    "obrutaliserbarheten": "obrutaliserbarhet",
    "obrutaliserbarhetens": "obrutaliserbarhet",
    "obrutaliserbarhets": "obrutaliserbarhet",
    "obrutaliserbars": "obrutaliserbar",
    "obrutaliserbart": "obrutaliserbar",
    "obrutaliserbarts": "obrutaliserbar",
    "obrutens": "obruten",
    "obrutet": "obruten",
    "obrutets": "obruten",
    "obrutna": "obruten",
    "obrutnare": "obruten",
    "obrutnares": "obruten",
    "obrutnas": "obruten",
    "obrutnast": "obruten",
    "obrutnaste": "obruten",
    "obrutnastes": "obruten",
    "obrutnasts": "obruten",
    "obrutne": "obruten",
    "obrutnes": "obruten",
    "obryggde": "obryggd",
    "obryggdes": "obryggd",
    "obryggds": "obryggd",
    "obryggt": "obryggd",
    "obryggts": "obryggd",
    "obrynta": "obrynt",
    "obryntas": "obrynt",
    "obrynte": "obrynt",
    "obryntes": "obrynt",
    "obrynts": "obrynt",
    "obrytbara": "obrytbar",
    "obrytbarare": "obrytbar",
    "obrytbarares": "obrytbar",
    "obrytbaras": "obrytbar",
    "obrytbarast": "obrytbar",
    "obrytbaraste": "obrytbar",
    "obrytbarastes": "obrytbar",
    "obrytbarasts": "obrytbar",
    "obrytbare": "obrytbar",
    "obrytbares": "obrytbar",
    "obrytbarheten": "obrytbarhet",
    "obrytbarhetens": "obrytbarhet",
    "obrytbarhets": "obrytbarhet",
    "obrytbars": "obrytbar",
    "obrytbart": "obrytbar",
    "obrytbarts": "obrytbar",
    "obräckta": "obräckt",
    "obräcktas": "obräckt",
    "obräckte": "obräckt",
    "obräcktes": "obräckt",
    "obräckts": "obräckt",
    "obrädade": "obrädad",
    "obrädades": "obrädad",
    "obrädads": "obrädad",
    "obrädat": "obrädad",
    "obrädats": "obrädad",
    "obräddade": "obräddad",
    "obräddades": "obräddad",
    "obräddads": "obräddad",
    "obräddat": "obräddad",
    "obräddats": "obräddad",
    "obrämade": "obrämad",
    "obrämades": "obrämad",
    "obrämads": "obrämad",
    "obrämat": "obrämad",
    "obrämats": "obrämad",
    "obrända": "obränd",
    "obrändare": "obränd",
    "obrändares": "obränd",
    "obrändas": "obränd",
    "obrändast": "obränd",
    "obrändaste": "obränd",
    "obrändastes": "obränd",
    "obrändasts": "obränd",
    "obrände": "obränd",
    "obrändes": "obränd",
    "obränds": "obränd",
    "obränt": "obränd",
    "obränts": "obränd",
    "obräserade": "obräserad",
    "obräserades": "obräserad",
    "obräserads": "obräserad",
    "obräserat": "obräserad",
    "obräserats": "obräserad",
    "obräserbara": "obräserbar",
    "obräserbarare": "obräserbar",
    "obräserbarares": "obräserbar",
    "obräserbaras": "obräserbar",
    "obräserbarast": "obräserbar",
    "obräserbaraste": "obräserbar",
    "obräserbarastes": "obräserbar",
    "obräserbarasts": "obräserbar",
    "obräserbare": "obräserbar",
    "obräserbares": "obräserbar",
    "obräserbarheten": "obräserbarhet",
    "obräserbarhetens": "obräserbarhet",
    "obräserbarhets": "obräserbarhet",
    "obräserbars": "obräserbar",
    "obräserbart": "obräserbar",
    "obräserbarts": "obräserbar",
    "obråkade": "obråkad",
    "obråkades": "obråkad",
    "obråkads": "obråkad",
    "obråkat": "obråkad",
    "obråkats": "obråkad",
    "obröade": "obröad",
    "obröades": "obröad",
    "obröads": "obröad",
    "obröat": "obröad",
    "obröats": "obröad",
    "obrödade": "obrödad",
    "obrödades": "obrödad",
    "obrödads": "obrödad",
    "obrödat": "obrödad",
    "obrödats": "obrödad",
    "obscena": "obscen",
    "obscenare": "obscen",
    "obscenares": "obscen",
    "obscenas": "obscen",
    "obscenast": "obscen",
    "obscenaste": "obscen",
    "obscenastes": "obscen",
    "obscenasts": "obscen",
    "obscene": "obscen",
    "obscenes": "obscen",
    "obsceniteten": "obscenitet",
    "obscenitetens": "obscenitet",
    "obsceniteter": "obscenitet",
    "obsceniteterna": "obscenitet",
    "obsceniteternas": "obscenitet",
    "obsceniteters": "obscenitet",
    "obscenitets": "obscenitet",
    "obscens": "obscen",
    "obscent": "obscen",
    "obscents": "obscen",
    "observanda": "observandum",
    "observandana": "observandum",
    "observandanas": "observandum",
    "observandas": "observandum",
    "observandumen": "observandum",
    "observandumens": "observandum",
    "observandumet": "observandum",
    "observandumets": "observandum",
    "observandums": "observandum",
    "observansen": "observans",
    "observansens": "observans",
    "observanta": "observant",
    "observantare": "observant",
    "observantares": "observant",
    "observantas": "observant",
    "observantast": "observant",
    "observantaste": "observant",
    "observantastes": "observant",
    "observantasts": "observant",
    "observante": "observant",
    "observantes": "observant",
    "observants": "observant",
    "observationen": "observation",
    "observationens": "observation",
    "observationer": "observation",
    "observationerna": "observation",
    "observationernas": "observation",
    "observationers": "observation",
    "observations": "observation",
    "observationsakten": "observationsakt",
    "observationsaktens": "observationsakt",
    "observationsakter": "observationsakt",
    "observationsakterna": "observationsakt",
    "observationsakternas": "observationsakt",
    "observationsakters": "observationsakt",
    "observationsakts": "observationsakt",
    "observationsklassen": "observationsklass",
    "observationsklassens": "observationsklass",
    "observationsklasser": "observationsklass",
    "observationsklasserna": "observationsklass",
    "observationsklassernas": "observationsklass",
    "observationsklassers": "observationsklass",
    "observationskliniken": "observationsklinik",
    "observationsklinikens": "observationsklinik",
    "observationskliniker": "observationsklinik",
    "observationsklinikerna": "observationsklinik",
    "observationsklinikernas": "observationsklinik",
    "observationsklinikers": "observationsklinik",
    "observationskliniks": "observationsklinik",
    "observationsmaterialen": "observationsmaterial",
    "observationsmaterialens": "observationsmaterial",
    "observationsmaterialet": "observationsmaterial",
    "observationsmaterialets": "observationsmaterial",
    "observationsmaterials": "observationsmaterial",
    "observatorie": "observatorium",
    "observatorier": "observatorium",
    "observatorierna": "observatorium",
    "observatoriernas": "observatorium",
    "observatoriers": "observatorium",
    "observatoriet": "observatorium",
    "observatoriets": "observatorium",
    "observatoriums": "observatorium",
    "observatören": "observatör",
    "observatörens": "observatör",
    "observatörer": "observatör",
    "observatörerna": "observatör",
    "observatörernas": "observatör",
    "observatörers": "observatör",
    "observatörs": "observatör",
    "observerad": "observera",
    "observerade": "observera",
    "observerades": "observera",
    "observerads": "observera",
    "observerande": "observera",
    "observeranden": "observerande",
    "observerandena": "observerande",
    "observerandenas": "observerande",
    "observerandens": "observerande",
    "observerandes": "observerande",
    "observerandet": "observerande",
    "observerandets": "observerande",
    "observerar": "observera",
    "observeras": "observera",
    "observerat": "observera",
    "observerats": "observera",
    "observerbara": "observerbar",
    "observerbarare": "observerbar",
    "observerbarares": "observerbar",
    "observerbaras": "observerbar",
    "observerbarast": "observerbar",
    "observerbaraste": "observerbar",
    "observerbarastes": "observerbar",
    "observerbarasts": "observerbar",
    "observerbare": "observerbar",
    "observerbares": "observerbar",
    "observerbarheten": "observerbarhet",
    "observerbarhetens": "observerbarhet",
    "observerbarhets": "observerbarhet",
    "observerbars": "observerbar",
    "observerbart": "observerbar",
    "observerbarts": "observerbar",
    "observeringar": "observering",
    "observeringarna": "observering",
    "observeringarnas": "observering",
    "observeringars": "observering",
    "observeringen": "observering",
    "observeringens": "observering",
    "observerings": "observering",
    "obsidianen": "obsidian",
    "obsidianens": "obsidian",
    "obsidianer": "obsidian",
    "obsidianerna": "obsidian",
    "obsidianernas": "obsidian",
    "obsidianers": "obsidian",
    "obsidians": "obsidian",
    "obsklassen": "obsklass",
    "obsklassens": "obsklass",
    "obsklasser": "obsklass",
    "obsklasserna": "obsklass",
    "obsklassernas": "obsklass",
    "obsklassers": "obsklass",
    "obskliniken": "obsklinik",
    "obsklinikens": "obsklinik",
    "obskliniker": "obsklinik",
    "obsklinikerna": "obsklinik",
    "obsklinikernas": "obsklinik",
    "obsklinikers": "obsklinik",
    "obskliniks": "obsklinik",
    "obskura": "obskur",
    "obskuranta": "obskurant",
    "obskurantare": "obskurant",
    "obskurantares": "obskurant",
    "obskurantas": "obskurant",
    "obskurantast": "obskurant",
    "obskurantaste": "obskurant",
    "obskurantastes": "obskurant",
    "obskurantasts": "obskurant",
    "obskurante": "obskurant",
    "obskuranten": "obskurant",
    "obskurantens": "obskurant",
    "obskuranter": "obskurant",
    "obskuranterna": "obskurant",
    "obskuranternas": "obskurant",
    "obskuranters": "obskurant",
    "obskurantes": "obskurant",
    "obskurantismen": "obskurantism",
    "obskurantismens": "obskurantism",
    "obskurantismer": "obskurantism",
    "obskurantismerna": "obskurantism",
    "obskurantismernas": "obskurantism",
    "obskurantismers": "obskurantism",
    "obskurantisms": "obskurantism",
    "obskurantisten": "obskurantist",
    "obskurantistens": "obskurantist",
    "obskurantister": "obskurantist",
    "obskurantisterna": "obskurantist",
    "obskurantisternas": "obskurantist",
    "obskurantisters": "obskurantist",
    "obskurantistiska": "obskurantistisk",
    "obskurantistiskas": "obskurantistisk",
    "obskurantistiske": "obskurantistisk",
    "obskurantistiskes": "obskurantistisk",
    "obskurantistisks": "obskurantistisk",
    "obskurantistiskt": "obskurantistisk",
    "obskurantistiskts": "obskurantistisk",
    "obskurantists": "obskurantist",
    "obskurants": "obskurant",
    "obskurare": "obskur",
    "obskurares": "obskur",
    "obskuras": "obskur",
    "obskurast": "obskur",
    "obskuraste": "obskur",
    "obskurastes": "obskur",
    "obskurasts": "obskur",
    "obskure": "obskur",
    "obskures": "obskur",
    "obskurheten": "obskurhet",
    "obskurhetens": "obskurhet",
    "obskurhets": "obskurhet",
    "obskurs": "obskur",
    "obskurt": "obskur",
    "obskurts": "obskur",
    "obskyra": "obskyr",
    "obskyrare": "obskyr",
    "obskyrares": "obskyr",
    "obskyras": "obskyr",
    "obskyrast": "obskyr",
    "obskyraste": "obskyr",
    "obskyrastes": "obskyr",
    "obskyrasts": "obskyr",
    "obskyre": "obskyr",
    "obskyres": "obskyr",
    "obskyrheten": "obskyrhet",
    "obskyrhetens": "obskyrhet",
    "obskyrhets": "obskyrhet",
    "obskyrs": "obskyr",
    "obskyrt": "obskyr",
    "obskyrts": "obskyr",
    "obsoleta": "obsolet",
    "obsoletare": "obsolet",
    "obsoletares": "obsolet",
    "obsoletas": "obsolet",
    "obsoletast": "obsolet",
    "obsoletaste": "obsolet",
    "obsoletastes": "obsolet",
    "obsoletasts": "obsolet",
    "obsolete": "obsolet",
    "obsoletes": "obsolet",
    "obsoletheten": "obsolethet",
    "obsolethetens": "obsolethet",
    "obsolethets": "obsolethet",
    "obsolets": "obsolet",
    "obstetriken": "obstetrik",
    "obstetrikens": "obstetrik",
    "obstetriks": "obstetrik",
    "obstetriska": "obstetrisk",
    "obstetriskare": "obstetrisk",
    "obstetriskares": "obstetrisk",
    "obstetriskas": "obstetrisk",
    "obstetriskast": "obstetrisk",
    "obstetriskaste": "obstetrisk",
    "obstetriskastes": "obstetrisk",
    "obstetriskasts": "obstetrisk",
    "obstetriske": "obstetrisk",
    "obstetriskes": "obstetrisk",
    "obstetrisks": "obstetrisk",
    "obstetriskt": "obstetrisk",
    "obstetriskts": "obstetrisk",
    "obstinata": "obstinat",
    "obstinatare": "obstinat",
    "obstinatares": "obstinat",
    "obstinatas": "obstinat",
    "obstinatast": "obstinat",
    "obstinataste": "obstinat",
    "obstinatastes": "obstinat",
    "obstinatasts": "obstinat",
    "obstinate": "obstinat",
    "obstinates": "obstinat",
    "obstinats": "obstinat",
    "obstipationen": "obstipation",
    "obstipationens": "obstipation",
    "obstipationer": "obstipation",
    "obstipationerna": "obstipation",
    "obstipationernas": "obstipation",
    "obstipationers": "obstipation",
    "obstipations": "obstipation",
    "obstruenten": "obstruent",
    "obstruentens": "obstruent",
    "obstruenter": "obstruent",
    "obstruenterna": "obstruent",
    "obstruenternas": "obstruent",
    "obstruenters": "obstruent",
    "obstruents": "obstruent",
    "obstruerade": "obstruera",
    "obstruerades": "obstruera",
    "obstruerande": "obstruera",
    "obstrueranden": "obstruerande",
    "obstruerandena": "obstruerande",
    "obstruerandenas": "obstruerande",
    "obstruerandens": "obstruerande",
    "obstruerandes": "obstruerande",
    "obstruerandet": "obstruerande",
    "obstruerandets": "obstruerande",
    "obstruerar": "obstruera",
    "obstrueras": "obstruera",
    "obstruerat": "obstruera",
    "obstruerats": "obstruera",
    "obstrueringar": "obstruering",
    "obstrueringarna": "obstruering",
    "obstrueringarnas": "obstruering",
    "obstrueringars": "obstruering",
    "obstrueringen": "obstruering",
    "obstrueringens": "obstruering",
    "obstruerings": "obstruering",
    "obstruktionen": "obstruktion",
    "obstruktionens": "obstruktion",
    "obstruktioner": "obstruktion",
    "obstruktionerna": "obstruktion",
    "obstruktionernas": "obstruktion",
    "obstruktioners": "obstruktion",
    "obstruktions": "obstruktion",
    "obubbade": "obubbad",
    "obubbades": "obubbad",
    "obubbads": "obubbad",
    "obubbat": "obubbad",
    "obubbats": "obubbad",
    "obudade": "obudad",
    "obudades": "obudad",
    "obudads": "obudad",
    "obudat": "obudad",
    "obudats": "obudad",
    "obudgeterade": "obudgeterad",
    "obudgeterades": "obudgeterad",
    "obudgeterads": "obudgeterad",
    "obudgeterat": "obudgeterad",
    "obudgeterats": "obudgeterad",
    "obudgeterbara": "obudgeterbar",
    "obudgeterbarare": "obudgeterbar",
    "obudgeterbarares": "obudgeterbar",
    "obudgeterbaras": "obudgeterbar",
    "obudgeterbarast": "obudgeterbar",
    "obudgeterbaraste": "obudgeterbar",
    "obudgeterbarastes": "obudgeterbar",
    "obudgeterbarasts": "obudgeterbar",
    "obudgeterbare": "obudgeterbar",
    "obudgeterbares": "obudgeterbar",
    "obudgeterbarheten": "obudgeterbarhet",
    "obudgeterbarhetens": "obudgeterbarhet",
    "obudgeterbarhets": "obudgeterbarhet",
    "obudgeterbars": "obudgeterbar",
    "obudgeterbart": "obudgeterbar",
    "obudgeterbarts": "obudgeterbar",
    "obuffade": "obuffad",
    "obuffades": "obuffad",
    "obuffads": "obuffad",
    "obuffat": "obuffad",
    "obuffats": "obuffad",
    "obuffrade": "obuffrad",
    "obuffrades": "obuffrad",
    "obuffrads": "obuffrad",
    "obuffrat": "obuffrad",
    "obuffrats": "obuffrad",
    "obultade": "obultad",
    "obultades": "obultad",
    "obultads": "obultad",
    "obultat": "obultad",
    "obultats": "obultad",
    "obundens": "obunden",
    "obundet": "obunden",
    "obundets": "obunden",
    "obundna": "obunden",
    "obundnare": "obunden",
    "obundnares": "obunden",
    "obundnas": "obunden",
    "obundnast": "obunden",
    "obundnaste": "obunden",
    "obundnastes": "obunden",
    "obundnasts": "obunden",
    "obundne": "obunden",
    "obundnes": "obunden",
    "obunkrade": "obunkrad",
    "obunkrades": "obunkrad",
    "obunkrads": "obunkrad",
    "obunkrat": "obunkrad",
    "obunkrats": "obunkrad",
    "obuntade": "obuntad",
    "obuntades": "obuntad",
    "obuntads": "obuntad",
    "obuntat": "obuntad",
    "obuntats": "obuntad",
    "oburkade": "oburkad",
    "oburkades": "oburkad",
    "oburkads": "oburkad",
    "oburkat": "oburkad",
    "oburkats": "oburkad",
    "obuskade": "obuskad",
    "obuskades": "obuskad",
    "obuskads": "obuskad",
    "obuskat": "obuskad",
    "obuskats": "obuskad",
    "obussade": "obussad",
    "obussades": "obussad",
    "obussads": "obussad",
    "obussat": "obussad",
    "obussats": "obussad",
    "obuteljerade": "obuteljerad",
    "obuteljerades": "obuteljerad",
    "obuteljerads": "obuteljerad",
    "obuteljerat": "obuteljerad",
    "obuteljerats": "obuteljerad",
    "obuteljerbara": "obuteljerbar",
    "obuteljerbarare": "obuteljerbar",
    "obuteljerbarares": "obuteljerbar",
    "obuteljerbaras": "obuteljerbar",
    "obuteljerbarast": "obuteljerbar",
    "obuteljerbaraste": "obuteljerbar",
    "obuteljerbarastes": "obuteljerbar",
    "obuteljerbarasts": "obuteljerbar",
    "obuteljerbare": "obuteljerbar",
    "obuteljerbares": "obuteljerbar",
    "obuteljerbarheten": "obuteljerbarhet",
    "obuteljerbarhetens": "obuteljerbarhet",
    "obuteljerbarhets": "obuteljerbarhet",
    "obuteljerbars": "obuteljerbar",
    "obuteljerbart": "obuteljerbar",
    "obuteljerbarts": "obuteljerbar",
    "obygden": "obygd",
    "obygdens": "obygd",
    "obygder": "obygd",
    "obygderna": "obygd",
    "obygdernas": "obygd",
    "obygders": "obygd",
    "obygds": "obygd",
    "obyggde": "obyggd",
    "obyggdes": "obyggd",
    "obyggds": "obyggd",
    "obyggt": "obyggd",
    "obyggts": "obyggd",
    "obyråkratiserade": "obyråkratiserad",
    "obyråkratiserades": "obyråkratiserad",
    "obyråkratiserads": "obyråkratiserad",
    "obyråkratiserat": "obyråkratiserad",
    "obyråkratiserats": "obyråkratiserad",
    "obyråkratiserbara": "obyråkratiserbar",
    "obyråkratiserbarare": "obyråkratiserbar",
    "obyråkratiserbarares": "obyråkratiserbar",
    "obyråkratiserbaras": "obyråkratiserbar",
    "obyråkratiserbarast": "obyråkratiserbar",
    "obyråkratiserbaraste": "obyråkratiserbar",
    "obyråkratiserbarastes": "obyråkratiserbar",
    "obyråkratiserbarasts": "obyråkratiserbar",
    "obyråkratiserbare": "obyråkratiserbar",
    "obyråkratiserbares": "obyråkratiserbar",
    "obyråkratiserbarheten": "obyråkratiserbarhet",
    "obyråkratiserbarhetens": "obyråkratiserbarhet",
    "obyråkratiserbarhets": "obyråkratiserbarhet",
    "obyråkratiserbars": "obyråkratiserbar",
    "obyråkratiserbart": "obyråkratiserbar",
    "obyråkratiserbarts": "obyråkratiserbar",
    "obytta": "obytt",
    "obyttare": "obytt",
    "obyttares": "obytt",
    "obyttas": "obytt",
    "obyttast": "obytt",
    "obyttaste": "obytt",
    "obyttastes": "obytt",
    "obyttasts": "obytt",
    "obytte": "obytt",
    "obyttes": "obytt",
    "obytts": "obytt",
    "obäddade": "obäddad",
    "obäddades": "obäddad",
    "obäddads": "obäddad",
    "obäddat": "obäddad",
    "obäddats": "obäddad",
    "obälgade": "obälgad",
    "obälgades": "obälgad",
    "obälgads": "obälgad",
    "obälgat": "obälgad",
    "obälgats": "obälgad",
    "obändiga": "obändig",
    "obändigare": "obändig",
    "obändigares": "obändig",
    "obändigas": "obändig",
    "obändigast": "obändig",
    "obändigaste": "obändig",
    "obändigastes": "obändig",
    "obändigasts": "obändig",
    "obändige": "obändig",
    "obändiges": "obändig",
    "obändigheten": "obändighet",
    "obändighetens": "obändighet",
    "obändighets": "obändighet",
    "obändigs": "obändig",
    "obändigt": "obändig",
    "obändigts": "obändig",
    "obändslade": "obändslad",
    "obändslades": "obändslad",
    "obändslads": "obändslad",
    "obändslat": "obändslad",
    "obändslats": "obändslad",
    "obänslade": "obänslad",
    "obänslades": "obänslad",
    "obänslads": "obänslad",
    "obänslat": "obänslad",
    "obänslats": "obänslad",
    "obärgade": "obärgad",
    "obärgades": "obärgad",
    "obärgads": "obärgad",
    "obärgat": "obärgad",
    "obärgats": "obärgad",
    "obättrade": "obättrad",
    "obättrades": "obättrad",
    "obättrads": "obättrad",
    "obättrat": "obättrad",
    "obättrats": "obättrad",
    "obågnade": "obågnad",
    "obågnades": "obågnad",
    "obågnads": "obågnad",
    "obågnat": "obågnad",
    "obågnats": "obågnad",
    "oböjde": "oböjd",
    "oböjdes": "oböjd",
    "oböjds": "oböjd",
    "oböjliga": "oböjlig",
    "oböjligare": "oböjlig",
    "oböjligares": "oböjlig",
    "oböjligas": "oböjlig",
    "oböjligast": "oböjlig",
    "oböjligaste": "oböjlig",
    "oböjligastes": "oböjlig",
    "oböjligasts": "oböjlig",
    "oböjlige": "oböjlig",
    "oböjliges": "oböjlig",
    "oböjligheten": "oböjlighet",
    "oböjlighetens": "oböjlighet",
    "oböjlighets": "oböjlighet",
    "oböjligs": "oböjlig",
    "oböjligt": "oböjlig",
    "oböjligts": "oböjlig",
    "oböjt": "oböjd",
    "oböjts": "oböjd",
    "obönhörde": "obönhörd",
    "obönhördes": "obönhörd",
    "obönhörds": "obönhörd",
    "obönhörliga": "obönhörlig",
    "obönhörligare": "obönhörlig",
    "obönhörligares": "obönhörlig",
    "obönhörligas": "obönhörlig",
    "obönhörligast": "obönhörlig",
    "obönhörligaste": "obönhörlig",
    "obönhörligastes": "obönhörlig",
    "obönhörligasts": "obönhörlig",
    "obönhörlige": "obönhörlig",
    "obönhörliges": "obönhörlig",
    "obönhörligheten": "obönhörlighet",
    "obönhörlighetens": "obönhörlighet",
    "obönhörligheter": "obönhörlighet",
    "obönhörligheterna": "obönhörlighet",
    "obönhörligheternas": "obönhörlighet",
    "obönhörligheters": "obönhörlighet",
    "obönhörlighets": "obönhörlighet",
    "obönhörligs": "obönhörlig",
    "obönhörligt": "obönhörlig",
    "obönhörligts": "obönhörlig",
    "obönhört": "obönhörd",
    "obönhörts": "obönhörd",
    "obörjade": "obörjad",
    "obörjades": "obörjad",
    "obörjads": "obörjad",
    "obörjat": "obörjad",
    "obörjats": "obörjad",
    "obötade": "obötad",
    "obötades": "obötad",
    "obötads": "obötad",
    "obötat": "obötad",
    "obötats": "obötad",
    "ocamouflerade": "ocamouflerad",
    "ocamouflerades": "ocamouflerad",
    "ocamouflerads": "ocamouflerad",
    "ocamouflerat": "ocamouflerad",
    "ocamouflerats": "ocamouflerad",
    "ocamouflerbara": "ocamouflerbar",
    "ocamouflerbarare": "ocamouflerbar",
    "ocamouflerbarares": "ocamouflerbar",
    "ocamouflerbaras": "ocamouflerbar",
    "ocamouflerbarast": "ocamouflerbar",
    "ocamouflerbaraste": "ocamouflerbar",
    "ocamouflerbarastes": "ocamouflerbar",
    "ocamouflerbarasts": "ocamouflerbar",
    "ocamouflerbare": "ocamouflerbar",
    "ocamouflerbares": "ocamouflerbar",
    "ocamouflerbarheten": "ocamouflerbarhet",
    "ocamouflerbarhetens": "ocamouflerbarhet",
    "ocamouflerbarhets": "ocamouflerbarhet",
    "ocamouflerbars": "ocamouflerbar",
    "ocamouflerbart": "ocamouflerbar",
    "ocamouflerbarts": "ocamouflerbar",
    "ocarinan": "ocarina",
    "ocarinans": "ocarina",
    "ocarinas": "ocarina",
    "ocarinor": "ocarina",
    "ocarinorna": "ocarina",
    "ocarinornas": "ocarina",
    "ocarinors": "ocarina",
    "ocaterade": "ocaterad",
    "ocaterades": "ocaterad",
    "ocaterads": "ocaterad",
    "ocaterat": "ocaterad",
    "ocaterats": "ocaterad",
    "occasionen": "occasion",
    "occasionens": "occasion",
    "occasioner": "occasion",
    "occasionerna": "occasion",
    "occasionernas": "occasion",
    "occasioners": "occasion",
    "occasions": "occasion",
    "occidentala": "occidental",
    "occidentalare": "occidental",
    "occidentalares": "occidental",
    "occidentalas": "occidental",
    "occidentalast": "occidental",
    "occidentalaste": "occidental",
    "occidentalastes": "occidental",
    "occidentalasts": "occidental",
    "occidentale": "occidental",
    "occidentales": "occidental",
    "occidentaliserad": "occidentalisera",
    "occidentaliserade": "occidentalisera",
    "occidentaliserades": "occidentalisera",
    "occidentaliserads": "occidentalisera",
    "occidentaliserande": "occidentalisera",
    "occidentaliseranden": "occidentaliserande",
    "occidentaliserandena": "occidentaliserande",
    "occidentaliserandenas": "occidentaliserande",
    "occidentaliserandens": "occidentaliserande",
    "occidentaliserandes": "occidentaliserande",
    "occidentaliserandet": "occidentaliserande",
    "occidentaliserandets": "occidentaliserande",
    "occidentaliserar": "occidentalisera",
    "occidentaliseras": "occidentalisera",
    "occidentaliserat": "occidentalisera",
    "occidentaliserats": "occidentalisera",
    "occidentaliserbara": "occidentaliserbar",
    "occidentaliserbarare": "occidentaliserbar",
    "occidentaliserbarares": "occidentaliserbar",
    "occidentaliserbaras": "occidentaliserbar",
    "occidentaliserbarast": "occidentaliserbar",
    "occidentaliserbaraste": "occidentaliserbar",
    "occidentaliserbarastes": "occidentaliserbar",
    "occidentaliserbarasts": "occidentaliserbar",
    "occidentaliserbare": "occidentaliserbar",
    "occidentaliserbares": "occidentaliserbar",
    "occidentaliserbarheten": "occidentaliserbarhet",
    "occidentaliserbarhetens": "occidentaliserbarhet",
    "occidentaliserbarhets": "occidentaliserbarhet",
    "occidentaliserbars": "occidentaliserbar",
    "occidentaliserbart": "occidentaliserbar",
    "occidentaliserbarts": "occidentaliserbar",
    "occidentaliseringar": "occidentalisering",
    "occidentaliseringarna": "occidentalisering",
    "occidentaliseringarnas": "occidentalisering",
    "occidentaliseringars": "occidentalisering",
    "occidentaliseringen": "occidentalisering",
    "occidentaliseringens": "occidentalisering",
    "occidentaliserings": "occidentalisering",
    "occidentaliska": "occidentalisk",
    "occidentaliskare": "occidentalisk",
    "occidentaliskares": "occidentalisk",
    "occidentaliskas": "occidentalisk",
    "occidentaliskast": "occidentalisk",
    "occidentaliskaste": "occidentalisk",
    "occidentaliskastes": "occidentalisk",
    "occidentaliskasts": "occidentalisk",
    "occidentaliske": "occidentalisk",
    "occidentaliskes": "occidentalisk",
    "occidentalisks": "occidentalisk",
    "occidentaliskt": "occidentalisk",
    "occidentaliskts": "occidentalisk",
    "occidentals": "occidental",
    "occidentalt": "occidental",
    "occidentalts": "occidental",
    "occidenten": "occident",
    "occidentens": "occident",
    "occidents": "occident",
    "oceanen": "ocean",
    "oceanens": "ocean",
    "oceaner": "ocean",
    "oceanerna": "ocean",
    "oceanernas": "ocean",
    "oceaners": "ocean",
    "oceaniska": "oceanisk",
    "oceaniskare": "oceanisk",
    "oceaniskares": "oceanisk",
    "oceaniskas": "oceanisk",
    "oceaniskast": "oceanisk",
    "oceaniskaste": "oceanisk",
    "oceaniskastes": "oceanisk",
    "oceaniskasts": "oceanisk",
    "oceaniske": "oceanisk",
    "oceaniskes": "oceanisk",
    "oceanisks": "oceanisk",
    "oceaniskt": "oceanisk",
    "oceaniskts": "oceanisk",
    "oceanografen": "oceanograf",
    "oceanografens": "oceanograf",
    "oceanografer": "oceanograf",
    "oceanograferna": "oceanograf",
    "oceanografernas": "oceanograf",
    "oceanografers": "oceanograf",
    "oceanografien": "oceanografi",
    "oceanografiens": "oceanografi",
    "oceanografin": "oceanografi",
    "oceanografins": "oceanografi",
    "oceanografis": "oceanografi",
    "oceanografiska": "oceanografisk",
    "oceanografiskare": "oceanografisk",
    "oceanografiskares": "oceanografisk",
    "oceanografiskas": "oceanografisk",
    "oceanografiskast": "oceanografisk",
    "oceanografiskaste": "oceanografisk",
    "oceanografiskastes": "oceanografisk",
    "oceanografiskasts": "oceanografisk",
    "oceanografiske": "oceanografisk",
    "oceanografiskes": "oceanografisk",
    "oceanografisks": "oceanografisk",
    "oceanografiskt": "oceanografisk",
    "oceanografiskts": "oceanografisk",
    "oceanografs": "oceanograf",
    "oceans": "ocean",
    "oceanångar": "oceanångare",
    "oceanångaren": "oceanångare",
    "oceanångarens": "oceanångare",
    "oceanångares": "oceanångare",
    "oceanångarna": "oceanångare",
    "oceanångarnas": "oceanångare",
    "ocederade": "ocederad",
    "ocederades": "ocederad",
    "ocederads": "ocederad",
    "ocederat": "ocederad",
    "ocederats": "ocederad",
    "ocederbara": "ocederbar",
    "ocederbarare": "ocederbar",
    "ocederbarares": "ocederbar",
    "ocederbaras": "ocederbar",
    "ocederbarast": "ocederbar",
    "ocederbaraste": "ocederbar",
    "ocederbarastes": "ocederbar",
    "ocederbarasts": "ocederbar",
    "ocederbare": "ocederbar",
    "ocederbares": "ocederbar",
    "ocederbarheten": "ocederbarhet",
    "ocederbarhetens": "ocederbarhet",
    "ocederbarhets": "ocederbarhet",
    "ocederbars": "ocederbar",
    "ocederbart": "ocederbar",
    "ocederbarts": "ocederbar",
    "ocelebrerade": "ocelebrerad",
    "ocelebrerades": "ocelebrerad",
    "ocelebrerads": "ocelebrerad",
    "ocelebrerat": "ocelebrerad",
    "ocelebrerats": "ocelebrerad",
    "ocelebrerbara": "ocelebrerbar",
    "ocelebrerbarare": "ocelebrerbar",
    "ocelebrerbarares": "ocelebrerbar",
    "ocelebrerbaras": "ocelebrerbar",
    "ocelebrerbarast": "ocelebrerbar",
    "ocelebrerbaraste": "ocelebrerbar",
    "ocelebrerbarastes": "ocelebrerbar",
    "ocelebrerbarasts": "ocelebrerbar",
    "ocelebrerbare": "ocelebrerbar",
    "ocelebrerbares": "ocelebrerbar",
    "ocelebrerbarheten": "ocelebrerbarhet",
    "ocelebrerbarhetens": "ocelebrerbarhet",
    "ocelebrerbarhets": "ocelebrerbarhet",
    "ocelebrerbars": "ocelebrerbar",
    "ocelebrerbart": "ocelebrerbar",
    "ocelebrerbarts": "ocelebrerbar",
    "ocementade": "ocementad",
    "ocementades": "ocementad",
    "ocementads": "ocementad",
    "ocementat": "ocementad",
    "ocementats": "ocementad",
    "ocementerade": "ocementerad",
    "ocementerades": "ocementerad",
    "ocementerads": "ocementerad",
    "ocementerat": "ocementerad",
    "ocementerats": "ocementerad",
    "ocementerbara": "ocementerbar",
    "ocementerbarare": "ocementerbar",
    "ocementerbarares": "ocementerbar",
    "ocementerbaras": "ocementerbar",
    "ocementerbarast": "ocementerbar",
    "ocementerbaraste": "ocementerbar",
    "ocementerbarastes": "ocementerbar",
    "ocementerbarasts": "ocementerbar",
    "ocementerbare": "ocementerbar",
    "ocementerbares": "ocementerbar",
    "ocementerbarheten": "ocementerbarhet",
    "ocementerbarhetens": "ocementerbarhet",
    "ocementerbarhets": "ocementerbarhet",
    "ocementerbars": "ocementerbar",
    "ocementerbart": "ocementerbar",
    "ocementerbarts": "ocementerbar",
    "ocensurerade": "ocensurerad",
    "ocensurerades": "ocensurerad",
    "ocensurerads": "ocensurerad",
    "ocensurerat": "ocensurerad",
    "ocensurerats": "ocensurerad",
    "ocensurerbara": "ocensurerbar",
    "ocensurerbarare": "ocensurerbar",
    "ocensurerbarares": "ocensurerbar",
    "ocensurerbaras": "ocensurerbar",
    "ocensurerbarast": "ocensurerbar",
    "ocensurerbaraste": "ocensurerbar",
    "ocensurerbarastes": "ocensurerbar",
    "ocensurerbarasts": "ocensurerbar",
    "ocensurerbare": "ocensurerbar",
    "ocensurerbares": "ocensurerbar",
    "ocensurerbarheten": "ocensurerbarhet",
    "ocensurerbarhetens": "ocensurerbarhet",
    "ocensurerbarhets": "ocensurerbarhet",
    "ocensurerbars": "ocensurerbar",
    "ocensurerbart": "ocensurerbar",
    "ocensurerbarts": "ocensurerbar",
    "ocentrade": "ocentrad",
    "ocentrades": "ocentrad",
    "ocentrads": "ocentrad",
    "ocentraliserade": "ocentraliserad",
    "ocentraliserades": "ocentraliserad",
    "ocentraliserads": "ocentraliserad",
    "ocentraliserat": "ocentraliserad",
    "ocentraliserats": "ocentraliserad",
    "ocentraliserbara": "ocentraliserbar",
    "ocentraliserbarare": "ocentraliserbar",
    "ocentraliserbarares": "ocentraliserbar",
    "ocentraliserbaras": "ocentraliserbar",
    "ocentraliserbarast": "ocentraliserbar",
    "ocentraliserbaraste": "ocentraliserbar",
    "ocentraliserbarastes": "ocentraliserbar",
    "ocentraliserbarasts": "ocentraliserbar",
    "ocentraliserbare": "ocentraliserbar",
    "ocentraliserbares": "ocentraliserbar",
    "ocentraliserbarheten": "ocentraliserbarhet",
    "ocentraliserbarhetens": "ocentraliserbarhet",
    "ocentraliserbarhets": "ocentraliserbarhet",
    "ocentraliserbars": "ocentraliserbar",
    "ocentraliserbart": "ocentraliserbar",
    "ocentraliserbarts": "ocentraliserbar",
    "ocentrat": "ocentrad",
    "ocentrats": "ocentrad",
    "ocentrerade": "ocentrerad",
    "ocentrerades": "ocentrerad",
    "ocentrerads": "ocentrerad",
    "ocentrerat": "ocentrerad",
    "ocentrerats": "ocentrerad",
    "ocentrerbara": "ocentrerbar",
    "ocentrerbarare": "ocentrerbar",
    "ocentrerbarares": "ocentrerbar",
    "ocentrerbaras": "ocentrerbar",
    "ocentrerbarast": "ocentrerbar",
    "ocentrerbaraste": "ocentrerbar",
    "ocentrerbarastes": "ocentrerbar",
    "ocentrerbarasts": "ocentrerbar",
    "ocentrerbare": "ocentrerbar",
    "ocentrerbares": "ocentrerbar",
    "ocentrerbarheten": "ocentrerbarhet",
    "ocentrerbarhetens": "ocentrerbarhet",
    "ocentrerbarhets": "ocentrerbarhet",
    "ocentrerbars": "ocentrerbar",
    "ocentrerbart": "ocentrerbar",
    "ocentrerbarts": "ocentrerbar",
    "ocentrifugerade": "ocentrifugerad",
    "ocentrifugerades": "ocentrifugerad",
    "ocentrifugerads": "ocentrifugerad",
    "ocentrifugerat": "ocentrifugerad",
    "ocentrifugerats": "ocentrifugerad",
    "ocentrifugerbara": "ocentrifugerbar",
    "ocentrifugerbarare": "ocentrifugerbar",
    "ocentrifugerbarares": "ocentrifugerbar",
    "ocentrifugerbaras": "ocentrifugerbar",
    "ocentrifugerbarast": "ocentrifugerbar",
    "ocentrifugerbaraste": "ocentrifugerbar",
    "ocentrifugerbarastes": "ocentrifugerbar",
    "ocentrifugerbarasts": "ocentrifugerbar",
    "ocentrifugerbare": "ocentrifugerbar",
    "ocentrifugerbares": "ocentrifugerbar",
    "ocentrifugerbarheten": "ocentrifugerbarhet",
    "ocentrifugerbarhetens": "ocentrifugerbarhet",
    "ocentrifugerbarhets": "ocentrifugerbarhet",
    "ocentrifugerbars": "ocentrifugerbar",
    "ocentrifugerbart": "ocentrifugerbar",
    "ocentrifugerbarts": "ocentrifugerbar",
    "ocernerade": "ocernerad",
    "ocernerades": "ocernerad",
    "ocernerads": "ocernerad",
    "ocernerat": "ocernerad",
    "ocernerats": "ocernerad",
    "ocernerbara": "ocernerbar",
    "ocernerbarare": "ocernerbar",
    "ocernerbarares": "ocernerbar",
    "ocernerbaras": "ocernerbar",
    "ocernerbarast": "ocernerbar",
    "ocernerbaraste": "ocernerbar",
    "ocernerbarastes": "ocernerbar",
    "ocernerbarasts": "ocernerbar",
    "ocernerbare": "ocernerbar",
    "ocernerbares": "ocernerbar",
    "ocernerbarheten": "ocernerbarhet",
    "ocernerbarhetens": "ocernerbarhet",
    "ocernerbarhets": "ocernerbarhet",
    "ocernerbars": "ocernerbar",
    "ocernerbart": "ocernerbar",
    "ocernerbarts": "ocernerbar",
    "ochargerade": "ochargerad",
    "ochargerades": "ochargerad",
    "ochargerads": "ochargerad",
    "ochargerat": "ochargerad",
    "ochargerats": "ochargerad",
    "ochargerbara": "ochargerbar",
    "ochargerbarare": "ochargerbar",
    "ochargerbarares": "ochargerbar",
    "ochargerbaras": "ochargerbar",
    "ochargerbarast": "ochargerbar",
    "ochargerbaraste": "ochargerbar",
    "ochargerbarastes": "ochargerbar",
    "ochargerbarasts": "ochargerbar",
    "ochargerbare": "ochargerbar",
    "ochargerbares": "ochargerbar",
    "ochargerbarheten": "ochargerbarhet",
    "ochargerbarhetens": "ochargerbarhet",
    "ochargerbarhets": "ochargerbarhet",
    "ochargerbars": "ochargerbar",
    "ochargerbart": "ochargerbar",
    "ochargerbarts": "ochargerbar",
    "ocharmade": "ocharmad",
    "ocharmades": "ocharmad",
    "ocharmads": "ocharmad",
    "ocharmat": "ocharmad",
    "ocharmats": "ocharmad",
    "ocharmerade": "ocharmerad",
    "ocharmerades": "ocharmerad",
    "ocharmerads": "ocharmerad",
    "ocharmerat": "ocharmerad",
    "ocharmerats": "ocharmerad",
    "ocharmerbara": "ocharmerbar",
    "ocharmerbarare": "ocharmerbar",
    "ocharmerbarares": "ocharmerbar",
    "ocharmerbaras": "ocharmerbar",
    "ocharmerbarast": "ocharmerbar",
    "ocharmerbaraste": "ocharmerbar",
    "ocharmerbarastes": "ocharmerbar",
    "ocharmerbarasts": "ocharmerbar",
    "ocharmerbare": "ocharmerbar",
    "ocharmerbares": "ocharmerbar",
    "ocharmerbarheten": "ocharmerbarhet",
    "ocharmerbarhetens": "ocharmerbarhet",
    "ocharmerbarhets": "ocharmerbarhet",
    "ocharmerbars": "ocharmerbar",
    "ocharmerbart": "ocharmerbar",
    "ocharmerbarts": "ocharmerbar",
    "ochartrade": "ochartrad",
    "ochartrades": "ochartrad",
    "ochartrads": "ochartrad",
    "ochartrat": "ochartrad",
    "ochartrats": "ochartrad",
    "ocheckade": "ocheckad",
    "ocheckades": "ocheckad",
    "ocheckads": "ocheckad",
    "ocheckat": "ocheckad",
    "ocheckats": "ocheckad",
    "ochevroterade": "ochevroterad",
    "ochevroterades": "ochevroterad",
    "ochevroterads": "ochevroterad",
    "ochevroterat": "ochevroterad",
    "ochevroterats": "ochevroterad",
    "ochevroterbara": "ochevroterbar",
    "ochevroterbarare": "ochevroterbar",
    "ochevroterbarares": "ochevroterbar",
    "ochevroterbaras": "ochevroterbar",
    "ochevroterbarast": "ochevroterbar",
    "ochevroterbaraste": "ochevroterbar",
    "ochevroterbarastes": "ochevroterbar",
    "ochevroterbarasts": "ochevroterbar",
    "ochevroterbare": "ochevroterbar",
    "ochevroterbares": "ochevroterbar",
    "ochevroterbarheten": "ochevroterbarhet",
    "ochevroterbarhetens": "ochevroterbarhet",
    "ochevroterbarhets": "ochevroterbarhet",
    "ochevroterbars": "ochevroterbar",
    "ochevroterbart": "ochevroterbar",
    "ochevroterbarts": "ochevroterbar",
    "ochiffrerade": "ochiffrerad",
    "ochiffrerades": "ochiffrerad",
    "ochiffrerads": "ochiffrerad",
    "ochiffrerat": "ochiffrerad",
    "ochiffrerats": "ochiffrerad",
    "ochiffrerbara": "ochiffrerbar",
    "ochiffrerbarare": "ochiffrerbar",
    "ochiffrerbarares": "ochiffrerbar",
    "ochiffrerbaras": "ochiffrerbar",
    "ochiffrerbarast": "ochiffrerbar",
    "ochiffrerbaraste": "ochiffrerbar",
    "ochiffrerbarastes": "ochiffrerbar",
    "ochiffrerbarasts": "ochiffrerbar",
    "ochiffrerbare": "ochiffrerbar",
    "ochiffrerbares": "ochiffrerbar",
    "ochiffrerbarheten": "ochiffrerbarhet",
    "ochiffrerbarhetens": "ochiffrerbarhet",
    "ochiffrerbarhets": "ochiffrerbarhet",
    "ochiffrerbars": "ochiffrerbar",
    "ochiffrerbart": "ochiffrerbar",
    "ochiffrerbarts": "ochiffrerbar",
    "ochikanerade": "ochikanerad",
    "ochikanerades": "ochikanerad",
    "ochikanerads": "ochikanerad",
    "ochikanerat": "ochikanerad",
    "ochikanerats": "ochikanerad",
    "ochikanerbara": "ochikanerbar",
    "ochikanerbarare": "ochikanerbar",
    "ochikanerbarares": "ochikanerbar",
    "ochikanerbaras": "ochikanerbar",
    "ochikanerbarast": "ochikanerbar",
    "ochikanerbaraste": "ochikanerbar",
    "ochikanerbarastes": "ochikanerbar",
    "ochikanerbarasts": "ochikanerbar",
    "ochikanerbare": "ochikanerbar",
    "ochikanerbares": "ochikanerbar",
    "ochikanerbarheten": "ochikanerbarhet",
    "ochikanerbarhetens": "ochikanerbarhet",
    "ochikanerbarhets": "ochikanerbarhet",
    "ochikanerbars": "ochikanerbar",
    "ochikanerbart": "ochikanerbar",
    "ochikanerbarts": "ochikanerbar",
    "ochockade": "ochockad",
    "ochockades": "ochockad",
    "ochockads": "ochockad",
    "ochockat": "ochockad",
    "ochockats": "ochockad",
    "ochockerade": "ochockerad",
    "ochockerades": "ochockerad",
    "ochockerads": "ochockerad",
    "ochockerat": "ochockerad",
    "ochockerats": "ochockerad",
    "ochockerbara": "ochockerbar",
    "ochockerbarare": "ochockerbar",
    "ochockerbarares": "ochockerbar",
    "ochockerbaras": "ochockerbar",
    "ochockerbarast": "ochockerbar",
    "ochockerbaraste": "ochockerbar",
    "ochockerbarastes": "ochockerbar",
    "ochockerbarasts": "ochockerbar",
    "ochockerbare": "ochockerbar",
    "ochockerbares": "ochockerbar",
    "ochockerbarheten": "ochockerbarhet",
    "ochockerbarhetens": "ochockerbarhet",
    "ochockerbarhets": "ochockerbarhet",
    "ochockerbars": "ochockerbar",
    "ochockerbart": "ochockerbar",
    "ochockerbarts": "ochockerbar",
    "ochokade": "ochokad",
    "ochokades": "ochokad",
    "ochokads": "ochokad",
    "ochokat": "ochokad",
    "ochokats": "ochokad",
    "ocirkulerade": "ocirkulerad",
    "ocirkulerades": "ocirkulerad",
    "ocirkulerads": "ocirkulerad",
    "ocirkulerat": "ocirkulerad",
    "ocirkulerats": "ocirkulerad",
    "ocirkulerbara": "ocirkulerbar",
    "ocirkulerbarare": "ocirkulerbar",
    "ocirkulerbarares": "ocirkulerbar",
    "ocirkulerbaras": "ocirkulerbar",
    "ocirkulerbarast": "ocirkulerbar",
    "ocirkulerbaraste": "ocirkulerbar",
    "ocirkulerbarastes": "ocirkulerbar",
    "ocirkulerbarasts": "ocirkulerbar",
    "ocirkulerbare": "ocirkulerbar",
    "ocirkulerbares": "ocirkulerbar",
    "ocirkulerbarheten": "ocirkulerbarhet",
    "ocirkulerbarhetens": "ocirkulerbarhet",
    "ocirkulerbarhets": "ocirkulerbarhet",
    "ocirkulerbars": "ocirkulerbar",
    "ocirkulerbart": "ocirkulerbar",
    "ocirkulerbarts": "ocirkulerbar",
    "ociselerade": "ociselerad",
    "ociselerades": "ociselerad",
    "ociselerads": "ociselerad",
    "ociselerat": "ociselerad",
    "ociselerats": "ociselerad",
    "ociselerbara": "ociselerbar",
    "ociselerbarare": "ociselerbar",
    "ociselerbarares": "ociselerbar",
    "ociselerbaras": "ociselerbar",
    "ociselerbarast": "ociselerbar",
    "ociselerbaraste": "ociselerbar",
    "ociselerbarastes": "ociselerbar",
    "ociselerbarasts": "ociselerbar",
    "ociselerbare": "ociselerbar",
    "ociselerbares": "ociselerbar",
    "ociselerbarheten": "ociselerbarhet",
    "ociselerbarhetens": "ociselerbarhet",
    "ociselerbarhets": "ociselerbarhet",
    "ociselerbars": "ociselerbar",
    "ociselerbart": "ociselerbar",
    "ociselerbarts": "ociselerbar",
    "ociterade": "ociterad",
    "ociterades": "ociterad",
    "ociterads": "ociterad",
    "ociterat": "ociterad",
    "ociterats": "ociterad",
    "ociterbara": "ociterbar",
    "ociterbarare": "ociterbar",
    "ociterbarares": "ociterbar",
    "ociterbaras": "ociterbar",
    "ociterbarast": "ociterbar",
    "ociterbaraste": "ociterbar",
    "ociterbarastes": "ociterbar",
    "ociterbarasts": "ociterbar",
    "ociterbare": "ociterbar",
    "ociterbares": "ociterbar",
    "ociterbarheten": "ociterbarhet",
    "ociterbarhetens": "ociterbarhet",
    "ociterbarhets": "ociterbarhet",
    "ociterbars": "ociterbar",
    "ociterbart": "ociterbar",
    "ociterbarts": "ociterbar",
    "ociviliserade": "ociviliserad",
    "ociviliserades": "ociviliserad",
    "ociviliserads": "ociviliserad",
    "ociviliserat": "ociviliserad",
    "ociviliserats": "ociviliserad",
    "ociviliserbara": "ociviliserbar",
    "ociviliserbarare": "ociviliserbar",
    "ociviliserbarares": "ociviliserbar",
    "ociviliserbaras": "ociviliserbar",
    "ociviliserbarast": "ociviliserbar",
    "ociviliserbaraste": "ociviliserbar",
    "ociviliserbarastes": "ociviliserbar",
    "ociviliserbarasts": "ociviliserbar",
    "ociviliserbare": "ociviliserbar",
    "ociviliserbares": "ociviliserbar",
    "ociviliserbarheten": "ociviliserbarhet",
    "ociviliserbarhetens": "ociviliserbarhet",
    "ociviliserbarhets": "ociviliserbarhet",
    "ociviliserbars": "ociviliserbar",
    "ociviliserbart": "ociviliserbar",
    "ociviliserbarts": "ociviliserbar",
    "ockasionella": "ockasionell",
    "ockasionellare": "ockasionell",
    "ockasionellares": "ockasionell",
    "ockasionellas": "ockasionell",
    "ockasionellast": "ockasionell",
    "ockasionellaste": "ockasionell",
    "ockasionellastes": "ockasionell",
    "ockasionellasts": "ockasionell",
    "ockasionelle": "ockasionell",
    "ockasionelles": "ockasionell",
    "ockasionells": "ockasionell",
    "ockasionellt": "ockasionell",
    "ockasionellts": "ockasionell",
    "ockasionen": "ockasion",
    "ockasionens": "ockasion",
    "ockasioner": "ockasion",
    "ockasionerna": "ockasion",
    "ockasionernas": "ockasion",
    "ockasioners": "ockasion",
    "ockasions": "ockasion",
    "ocker": "ockra",
    "ockerhyr": "ockerhyra",
    "ockerhyran": "ockerhyra",
    "ockerhyrans": "ockerhyra",
    "ockerhyras": "ockerhyra",
    "ockerhyre": "ockerhyra",
    "ockerhyror": "ockerhyra",
    "ockerhyrorna": "ockerhyra",
    "ockerhyrornas": "ockerhyra",
    "ockerhyrors": "ockerhyra",
    "ockerhyrs": "ockerhyra",
    "ockers": "ocker",
    "ocklusionen": "ocklusion",
    "ocklusionens": "ocklusion",
    "ocklusioner": "ocklusion",
    "ocklusionerna": "ocklusion",
    "ocklusionernas": "ocklusion",
    "ocklusioners": "ocklusion",
    "ocklusions": "ocklusion",
    "ockr": "ockra",
    "ockrade": "ockra",
    "ockrades": "ockra",
    "ockran": "ockra",
    "ockrande": "ockra",
    "ockranden": "ockrande",
    "ockrandena": "ockrande",
    "ockrandenas": "ockrande",
    "ockrandens": "ockrande",
    "ockrandes": "ockrande",
    "ockrandet": "ockrande",
    "ockrandets": "ockrande",
    "ockrans": "ockra",
    "ockrar": "ockrare",
    "ockraren": "ockrare",
    "ockrarens": "ockrare",
    "ockrares": "ockrare",
    "ockrarna": "ockrare",
    "ockrarnas": "ockrare",
    "ockras": "ockra",
    "ockrat": "ockra",
    "ockrats": "ockra",
    "ockre": "ockra",
    "ockret": "ocker",
    "ockrets": "ocker",
    "ockror": "ockra",
    "ockrorna": "ockra",
    "ockrornas": "ockra",
    "ockrors": "ockra",
    "ockrs": "ockra",
    "ockulta": "ockult",
    "ockultare": "ockult",
    "ockultares": "ockult",
    "ockultas": "ockult",
    "ockultast": "ockult",
    "ockultaste": "ockult",
    "ockultastes": "ockult",
    "ockultasts": "ockult",
    "ockultationen": "ockultation",
    "ockultationens": "ockultation",
    "ockultationer": "ockultation",
    "ockultationerna": "ockultation",
    "ockultationernas": "ockultation",
    "ockultationers": "ockultation",
    "ockultations": "ockultation",
    "ockulte": "ockult",
    "ockultes": "ockult",
    "ockultheten": "ockulthet",
    "ockulthetens": "ockulthet",
    "ockulthets": "ockulthet",
    "ockultismen": "ockultism",
    "ockultismens": "ockultism",
    "ockultismer": "ockultism",
    "ockultismerna": "ockultism",
    "ockultismernas": "ockultism",
    "ockultismers": "ockultism",
    "ockultisms": "ockultism",
    "ockultistiska": "ockultistisk",
    "ockultistiskas": "ockultistisk",
    "ockultistiske": "ockultistisk",
    "ockultistiskes": "ockultistisk",
    "ockultistisks": "ockultistisk",
    "ockultistiskt": "ockultistisk",
    "ockultistiskts": "ockultistisk",
    "ockults": "ockult",
    "ockupanten": "ockupant",
    "ockupantens": "ockupant",
    "ockupanter": "ockupant",
    "ockupanterna": "ockupant",
    "ockupanternas": "ockupant",
    "ockupanters": "ockupant",
    "ockupants": "ockupant",
    "ockupationen": "ockupation",
    "ockupationens": "ockupation",
    "ockupationer": "ockupation",
    "ockupationerna": "ockupation",
    "ockupationernas": "ockupation",
    "ockupationers": "ockupation",
    "ockupations": "ockupation",
    "ockuperad": "ockupera",
    "ockuperade": "ockupera",
    "ockuperades": "ockupera",
    "ockuperads": "ockupera",
    "ockuperande": "ockupera",
    "ockuperanden": "ockuperande",
    "ockuperandena": "ockuperande",
    "ockuperandenas": "ockuperande",
    "ockuperandens": "ockuperande",
    "ockuperandes": "ockuperande",
    "ockuperandet": "ockuperande",
    "ockuperandets": "ockuperande",
    "ockuperar": "ockupera",
    "ockuperas": "ockupera",
    "ockuperat": "ockupera",
    "ockuperats": "ockupera",
    "ockuperbara": "ockuperbar",
    "ockuperbarare": "ockuperbar",
    "ockuperbarares": "ockuperbar",
    "ockuperbaras": "ockuperbar",
    "ockuperbarast": "ockuperbar",
    "ockuperbaraste": "ockuperbar",
    "ockuperbarastes": "ockuperbar",
    "ockuperbarasts": "ockuperbar",
    "ockuperbare": "ockuperbar",
    "ockuperbares": "ockuperbar",
    "ockuperbarheten": "ockuperbarhet",
    "ockuperbarhetens": "ockuperbarhet",
    "ockuperbarhets": "ockuperbarhet",
    "ockuperbars": "ockuperbar",
    "ockuperbart": "ockuperbar",
    "ockuperbarts": "ockuperbar",
    "ockuperingar": "ockupering",
    "ockuperingarna": "ockupering",
    "ockuperingarnas": "ockupering",
    "ockuperingars": "ockupering",
    "ockuperingen": "ockupering",
    "ockuperingens": "ockupering",
    "ockuperings": "ockupering",
    "oclearade": "oclearad",
    "oclearades": "oclearad",
    "oclearads": "oclearad",
    "oclearat": "oclearad",
    "oclearats": "oclearad",
    "ocuraterade": "ocuraterad",
    "ocuraterades": "ocuraterad",
    "ocuraterads": "ocuraterad",
    "ocuraterat": "ocuraterad",
    "ocuraterats": "ocuraterad",
    "ocuraterbara": "ocuraterbar",
    "ocuraterbarare": "ocuraterbar",
    "ocuraterbarares": "ocuraterbar",
    "ocuraterbaras": "ocuraterbar",
    "ocuraterbarast": "ocuraterbar",
    "ocuraterbaraste": "ocuraterbar",
    "ocuraterbarastes": "ocuraterbar",
    "ocuraterbarasts": "ocuraterbar",
    "ocuraterbare": "ocuraterbar",
    "ocuraterbares": "ocuraterbar",
    "ocuraterbarheten": "ocuraterbarhet",
    "ocuraterbarhetens": "ocuraterbarhet",
    "ocuraterbarhets": "ocuraterbarhet",
    "ocuraterbars": "ocuraterbar",
    "ocuraterbart": "ocuraterbar",
    "ocuraterbarts": "ocuraterbar",
    "ocurerade": "ocurerad",
    "ocurerades": "ocurerad",
    "ocurerads": "ocurerad",
    "ocurerat": "ocurerad",
    "ocurerats": "ocurerad",
    "ocurerbara": "ocurerbar",
    "ocurerbarare": "ocurerbar",
    "ocurerbarares": "ocurerbar",
    "ocurerbaras": "ocurerbar",
    "ocurerbarast": "ocurerbar",
    "ocurerbaraste": "ocurerbar",
    "ocurerbarastes": "ocurerbar",
    "ocurerbarasts": "ocurerbar",
    "ocurerbare": "ocurerbar",
    "ocurerbares": "ocurerbar",
    "ocurerbarheten": "ocurerbarhet",
    "ocurerbarhetens": "ocurerbarhet",
    "ocurerbarhets": "ocurerbarhet",
    "ocurerbars": "ocurerbar",
    "ocurerbart": "ocurerbar",
    "ocurerbarts": "ocurerbar",
    "ocyklade": "ocyklad",
    "ocyklades": "ocyklad",
    "ocyklads": "ocyklad",
    "ocyklat": "ocyklad",
    "ocyklats": "ocyklad",
    "odaddade": "odaddad",
    "odaddades": "odaddad",
    "odaddads": "odaddad",
    "odaddat": "odaddad",
    "odaddats": "odaddad",
    "odalen": "odal",
    "odalens": "odal",
    "odalet": "odal",
    "odalets": "odal",
    "odalisken": "odalisk",
    "odaliskens": "odalisk",
    "odalisker": "odalisk",
    "odaliskerna": "odalisk",
    "odaliskernas": "odalisk",
    "odaliskers": "odalisk",
    "odalisks": "odalisk",
    "odalmannen": "odalman",
    "odalmannens": "odalman",
    "odalmans": "odalman",
    "odalmän": "odalman",
    "odalmännen": "odalman",
    "odalmännens": "odalman",
    "odalmäns": "odalman",
    "odals": "odal",
    "odammade": "odammad",
    "odammades": "odammad",
    "odammads": "odammad",
    "odammat": "odammad",
    "odammats": "odammad",
    "odampade": "odampad",
    "odampades": "odampad",
    "odampads": "odampad",
    "odampat": "odampad",
    "odampats": "odampad",
    "odanade": "odanad",
    "odanades": "odanad",
    "odanads": "odanad",
    "odanat": "odanad",
    "odanats": "odanad",
    "odaskade": "odaskad",
    "odaskades": "odaskad",
    "odaskads": "odaskad",
    "odaskat": "odaskad",
    "odaskats": "odaskad",
    "odaterade": "odaterad",
    "odaterades": "odaterad",
    "odaterads": "odaterad",
    "odaterat": "odaterad",
    "odaterats": "odaterad",
    "odaterbara": "odaterbar",
    "odaterbarare": "odaterbar",
    "odaterbarares": "odaterbar",
    "odaterbaras": "odaterbar",
    "odaterbarast": "odaterbar",
    "odaterbaraste": "odaterbar",
    "odaterbarastes": "odaterbar",
    "odaterbarasts": "odaterbar",
    "odaterbare": "odaterbar",
    "odaterbares": "odaterbar",
    "odaterbarheten": "odaterbarhet",
    "odaterbarhetens": "odaterbarhet",
    "odaterbarhets": "odaterbarhet",
    "odaterbars": "odaterbar",
    "odaterbart": "odaterbar",
    "odaterbarts": "odaterbar",
    "odatoriserade": "odatoriserad",
    "odatoriserades": "odatoriserad",
    "odatoriserads": "odatoriserad",
    "odatoriserat": "odatoriserad",
    "odatoriserats": "odatoriserad",
    "odatoriserbara": "odatoriserbar",
    "odatoriserbarare": "odatoriserbar",
    "odatoriserbarares": "odatoriserbar",
    "odatoriserbaras": "odatoriserbar",
    "odatoriserbarast": "odatoriserbar",
    "odatoriserbaraste": "odatoriserbar",
    "odatoriserbarastes": "odatoriserbar",
    "odatoriserbarasts": "odatoriserbar",
    "odatoriserbare": "odatoriserbar",
    "odatoriserbares": "odatoriserbar",
    "odatoriserbarheten": "odatoriserbarhet",
    "odatoriserbarhetens": "odatoriserbarhet",
    "odatoriserbarhets": "odatoriserbarhet",
    "odatoriserbars": "odatoriserbar",
    "odatoriserbart": "odatoriserbar",
    "odatoriserbarts": "odatoriserbar",
    "oddsen": "odds",
    "oddsens": "odds",
    "oddset": "odds",
    "oddsets": "odds",
    "odebarkerade": "odebarkerad",
    "odebarkerades": "odebarkerad",
    "odebarkerads": "odebarkerad",
    "odebarkerat": "odebarkerad",
    "odebarkerats": "odebarkerad",
    "odebarkerbara": "odebarkerbar",
    "odebarkerbarare": "odebarkerbar",
    "odebarkerbarares": "odebarkerbar",
    "odebarkerbaras": "odebarkerbar",
    "odebarkerbarast": "odebarkerbar",
    "odebarkerbaraste": "odebarkerbar",
    "odebarkerbarastes": "odebarkerbar",
    "odebarkerbarasts": "odebarkerbar",
    "odebarkerbare": "odebarkerbar",
    "odebarkerbares": "odebarkerbar",
    "odebarkerbarheten": "odebarkerbarhet",
    "odebarkerbarhetens": "odebarkerbarhet",
    "odebarkerbarhets": "odebarkerbarhet",
    "odebarkerbars": "odebarkerbar",
    "odebarkerbart": "odebarkerbar",
    "odebarkerbarts": "odebarkerbar",
    "odebatterade": "odebatterad",
    "odebatterades": "odebatterad",
    "odebatterads": "odebatterad",
    "odebatterat": "odebatterad",
    "odebatterats": "odebatterad",
    "odebatterbara": "odebatterbar",
    "odebatterbarare": "odebatterbar",
    "odebatterbarares": "odebatterbar",
    "odebatterbaras": "odebatterbar",
    "odebatterbarast": "odebatterbar",
    "odebatterbaraste": "odebatterbar",
    "odebatterbarastes": "odebatterbar",
    "odebatterbarasts": "odebatterbar",
    "odebatterbare": "odebatterbar",
    "odebatterbares": "odebatterbar",
    "odebatterbarheten": "odebatterbarhet",
    "odebatterbarhetens": "odebatterbarhet",
    "odebatterbarhets": "odebatterbarhet",
    "odebatterbars": "odebatterbar",
    "odebatterbart": "odebatterbar",
    "odebatterbarts": "odebatterbar",
    "odebiterade": "odebiterad",
    "odebiterades": "odebiterad",
    "odebiterads": "odebiterad",
    "odebiterat": "odebiterad",
    "odebiterats": "odebiterad",
    "odebiterbara": "odebiterbar",
    "odebiterbarare": "odebiterbar",
    "odebiterbarares": "odebiterbar",
    "odebiterbaras": "odebiterbar",
    "odebiterbarast": "odebiterbar",
    "odebiterbaraste": "odebiterbar",
    "odebiterbarastes": "odebiterbar",
    "odebiterbarasts": "odebiterbar",
    "odebiterbare": "odebiterbar",
    "odebiterbares": "odebiterbar",
    "odebiterbarheten": "odebiterbarhet",
    "odebiterbarhetens": "odebiterbarhet",
    "odebiterbarhets": "odebiterbarhet",
    "odebiterbars": "odebiterbar",
    "odebiterbart": "odebiterbar",
    "odebiterbarts": "odebiterbar",
    "odecentraliserade": "odecentraliserad",
    "odecentraliserades": "odecentraliserad",
    "odecentraliserads": "odecentraliserad",
    "odecentraliserat": "odecentraliserad",
    "odecentraliserats": "odecentraliserad",
    "odecentraliserbara": "odecentraliserbar",
    "odecentraliserbarare": "odecentraliserbar",
    "odecentraliserbarares": "odecentraliserbar",
    "odecentraliserbaras": "odecentraliserbar",
    "odecentraliserbarast": "odecentraliserbar",
    "odecentraliserbaraste": "odecentraliserbar",
    "odecentraliserbarastes": "odecentraliserbar",
    "odecentraliserbarasts": "odecentraliserbar",
    "odecentraliserbare": "odecentraliserbar",
    "odecentraliserbares": "odecentraliserbar",
    "odecentraliserbarheten": "odecentraliserbarhet",
    "odecentraliserbarhetens": "odecentraliserbarhet",
    "odecentraliserbarhets": "odecentraliserbarhet",
    "odecentraliserbars": "odecentraliserbar",
    "odecentraliserbart": "odecentraliserbar",
    "odecentraliserbarts": "odecentraliserbar",
    "odechiffrerade": "odechiffrerad",
    "odechiffrerades": "odechiffrerad",
    "odechiffrerads": "odechiffrerad",
    "odechiffrerat": "odechiffrerad",
    "odechiffrerats": "odechiffrerad",
    "odechiffrerbara": "odechiffrerbar",
    "odechiffrerbarare": "odechiffrerbar",
    "odechiffrerbarares": "odechiffrerbar",
    "odechiffrerbaras": "odechiffrerbar",
    "odechiffrerbarast": "odechiffrerbar",
    "odechiffrerbaraste": "odechiffrerbar",
    "odechiffrerbarastes": "odechiffrerbar",
    "odechiffrerbarasts": "odechiffrerbar",
    "odechiffrerbare": "odechiffrerbar",
    "odechiffrerbares": "odechiffrerbar",
    "odechiffrerbarheten": "odechiffrerbarhet",
    "odechiffrerbarhetens": "odechiffrerbarhet",
    "odechiffrerbarhets": "odechiffrerbarhet",
    "odechiffrerbars": "odechiffrerbar",
    "odechiffrerbart": "odechiffrerbar",
    "odechiffrerbarts": "odechiffrerbar",
    "odeciderade": "odeciderad",
    "odeciderades": "odeciderad",
    "odeciderads": "odeciderad",
    "odeciderat": "odeciderad",
    "odeciderats": "odeciderad",
    "odecimerade": "odecimerad",
    "odecimerades": "odecimerad",
    "odecimerads": "odecimerad",
    "odecimerat": "odecimerad",
    "odecimerats": "odecimerad",
    "odecimerbara": "odecimerbar",
    "odecimerbarare": "odecimerbar",
    "odecimerbarares": "odecimerbar",
    "odecimerbaras": "odecimerbar",
    "odecimerbarast": "odecimerbar",
    "odecimerbaraste": "odecimerbar",
    "odecimerbarastes": "odecimerbar",
    "odecimerbarasts": "odecimerbar",
    "odecimerbare": "odecimerbar",
    "odecimerbares": "odecimerbar",
    "odecimerbarheten": "odecimerbarhet",
    "odecimerbarhetens": "odecimerbarhet",
    "odecimerbarhets": "odecimerbarhet",
    "odecimerbars": "odecimerbar",
    "odecimerbart": "odecimerbar",
    "odecimerbarts": "odecimerbar",
    "odedicerade": "odedicerad",
    "odedicerades": "odedicerad",
    "odedicerads": "odedicerad",
    "odedicerat": "odedicerad",
    "odedicerats": "odedicerad",
    "odedicerbara": "odedicerbar",
    "odedicerbarare": "odedicerbar",
    "odedicerbarares": "odedicerbar",
    "odedicerbaras": "odedicerbar",
    "odedicerbarast": "odedicerbar",
    "odedicerbaraste": "odedicerbar",
    "odedicerbarastes": "odedicerbar",
    "odedicerbarasts": "odedicerbar",
    "odedicerbare": "odedicerbar",
    "odedicerbares": "odedicerbar",
    "odedicerbarheten": "odedicerbarhet",
    "odedicerbarhetens": "odedicerbarhet",
    "odedicerbarhets": "odedicerbarhet",
    "odedicerbars": "odedicerbar",
    "odedicerbart": "odedicerbar",
    "odedicerbarts": "odedicerbar",
    "odedikerade": "odedikerad",
    "odedikerades": "odedikerad",
    "odedikerads": "odedikerad",
    "odedikerat": "odedikerad",
    "odedikerats": "odedikerad",
    "odedikerbara": "odedikerbar",
    "odedikerbarare": "odedikerbar",
    "odedikerbarares": "odedikerbar",
    "odedikerbaras": "odedikerbar",
    "odedikerbarast": "odedikerbar",
    "odedikerbaraste": "odedikerbar",
    "odedikerbarastes": "odedikerbar",
    "odedikerbarasts": "odedikerbar",
    "odedikerbare": "odedikerbar",
    "odedikerbares": "odedikerbar",
    "odedikerbarheten": "odedikerbarhet",
    "odedikerbarhetens": "odedikerbarhet",
    "odedikerbarhets": "odedikerbarhet",
    "odedikerbars": "odedikerbar",
    "odedikerbart": "odedikerbar",
    "odedikerbarts": "odedikerbar",
    "odeducerade": "odeducerad",
    "odeducerades": "odeducerad",
    "odeducerads": "odeducerad",
    "odeducerat": "odeducerad",
    "odeducerats": "odeducerad",
    "odeducerbara": "odeducerbar",
    "odeducerbarare": "odeducerbar",
    "odeducerbarares": "odeducerbar",
    "odeducerbaras": "odeducerbar",
    "odeducerbarast": "odeducerbar",
    "odeducerbaraste": "odeducerbar",
    "odeducerbarastes": "odeducerbar",
    "odeducerbarasts": "odeducerbar",
    "odeducerbare": "odeducerbar",
    "odeducerbares": "odeducerbar",
    "odeducerbarheten": "odeducerbarhet",
    "odeducerbarhetens": "odeducerbarhet",
    "odeducerbarhets": "odeducerbarhet",
    "odeducerbars": "odeducerbar",
    "odeducerbart": "odeducerbar",
    "odeducerbarts": "odeducerbar",
    "odefilerade": "odefilerad",
    "odefilerades": "odefilerad",
    "odefilerads": "odefilerad",
    "odefilerat": "odefilerad",
    "odefilerats": "odefilerad",
    "odefilerbara": "odefilerbar",
    "odefilerbarare": "odefilerbar",
    "odefilerbarares": "odefilerbar",
    "odefilerbaras": "odefilerbar",
    "odefilerbarast": "odefilerbar",
    "odefilerbaraste": "odefilerbar",
    "odefilerbarastes": "odefilerbar",
    "odefilerbarasts": "odefilerbar",
    "odefilerbare": "odefilerbar",
    "odefilerbares": "odefilerbar",
    "odefilerbarheten": "odefilerbarhet",
    "odefilerbarhetens": "odefilerbarhet",
    "odefilerbarhets": "odefilerbarhet",
    "odefilerbars": "odefilerbar",
    "odefilerbart": "odefilerbar",
    "odefilerbarts": "odefilerbar",
    "odefinierade": "odefinierad",
    "odefinierades": "odefinierad",
    "odefinierads": "odefinierad",
    "odefinierat": "odefinierad",
    "odefinierats": "odefinierad",
    "odefinierbara": "odefinierbar",
    "odefinierbarare": "odefinierbar",
    "odefinierbarares": "odefinierbar",
    "odefinierbaras": "odefinierbar",
    "odefinierbarast": "odefinierbar",
    "odefinierbaraste": "odefinierbar",
    "odefinierbarastes": "odefinierbar",
    "odefinierbarasts": "odefinierbar",
    "odefinierbare": "odefinierbar",
    "odefinierbares": "odefinierbar",
    "odefinierbarheten": "odefinierbarhet",
    "odefinierbarhetens": "odefinierbarhet",
    "odefinierbarhets": "odefinierbarhet",
    "odefinierbars": "odefinierbar",
    "odefinierbart": "odefinierbar",
    "odefinierbarts": "odefinierbar",
    "odeflorerade": "odeflorerad",
    "odeflorerades": "odeflorerad",
    "odeflorerads": "odeflorerad",
    "odeflorerat": "odeflorerad",
    "odeflorerats": "odeflorerad",
    "odeflorerbara": "odeflorerbar",
    "odeflorerbarare": "odeflorerbar",
    "odeflorerbarares": "odeflorerbar",
    "odeflorerbaras": "odeflorerbar",
    "odeflorerbarast": "odeflorerbar",
    "odeflorerbaraste": "odeflorerbar",
    "odeflorerbarastes": "odeflorerbar",
    "odeflorerbarasts": "odeflorerbar",
    "odeflorerbare": "odeflorerbar",
    "odeflorerbares": "odeflorerbar",
    "odeflorerbarheten": "odeflorerbarhet",
    "odeflorerbarhetens": "odeflorerbarhet",
    "odeflorerbarhets": "odeflorerbarhet",
    "odeflorerbars": "odeflorerbar",
    "odeflorerbart": "odeflorerbar",
    "odeflorerbarts": "odeflorerbar",
    "odeformerade": "odeformerad",
    "odeformerades": "odeformerad",
    "odeformerads": "odeformerad",
    "odeformerat": "odeformerad",
    "odeformerats": "odeformerad",
    "odeformerbara": "odeformerbar",
    "odeformerbarare": "odeformerbar",
    "odeformerbarares": "odeformerbar",
    "odeformerbaras": "odeformerbar",
    "odeformerbarast": "odeformerbar",
    "odeformerbaraste": "odeformerbar",
    "odeformerbarastes": "odeformerbar",
    "odeformerbarasts": "odeformerbar",
    "odeformerbare": "odeformerbar",
    "odeformerbares": "odeformerbar",
    "odeformerbarheten": "odeformerbarhet",
    "odeformerbarhetens": "odeformerbarhet",
    "odeformerbarhets": "odeformerbarhet",
    "odeformerbars": "odeformerbar",
    "odeformerbart": "odeformerbar",
    "odeformerbarts": "odeformerbar",
    "odegenererade": "odegenererad",
    "odegenererades": "odegenererad",
    "odegenererads": "odegenererad",
    "odegenererat": "odegenererad",
    "odegenererats": "odegenererad",
    "odegenererbara": "odegenererbar",
    "odegenererbarare": "odegenererbar",
    "odegenererbarares": "odegenererbar",
    "odegenererbaras": "odegenererbar",
    "odegenererbarast": "odegenererbar",
    "odegenererbaraste": "odegenererbar",
    "odegenererbarastes": "odegenererbar",
    "odegenererbarasts": "odegenererbar",
    "odegenererbare": "odegenererbar",
    "odegenererbares": "odegenererbar",
    "odegenererbarheten": "odegenererbarhet",
    "odegenererbarhetens": "odegenererbarhet",
    "odegenererbarhets": "odegenererbarhet",
    "odegenererbars": "odegenererbar",
    "odegenererbart": "odegenererbar",
    "odegenererbarts": "odegenererbar",
    "odegraderade": "odegraderad",
    "odegraderades": "odegraderad",
    "odegraderads": "odegraderad",
    "odegraderat": "odegraderad",
    "odegraderats": "odegraderad",
    "odegraderbara": "odegraderbar",
    "odegraderbarare": "odegraderbar",
    "odegraderbarares": "odegraderbar",
    "odegraderbaras": "odegraderbar",
    "odegraderbarast": "odegraderbar",
    "odegraderbaraste": "odegraderbar",
    "odegraderbarastes": "odegraderbar",
    "odegraderbarasts": "odegraderbar",
    "odegraderbare": "odegraderbar",
    "odegraderbares": "odegraderbar",
    "odegraderbarheten": "odegraderbarhet",
    "odegraderbarhetens": "odegraderbarhet",
    "odegraderbarhets": "odegraderbarhet",
    "odegraderbars": "odegraderbar",
    "odegraderbart": "odegraderbar",
    "odegraderbarts": "odegraderbar",
    "odejtade": "odejtad",
    "odejtades": "odejtad",
    "odejtads": "odejtad",
    "odejtat": "odejtad",
    "odejtats": "odejtad",
    "odekanterade": "odekanterad",
    "odekanterades": "odekanterad",
    "odekanterads": "odekanterad",
    "odekanterat": "odekanterad",
    "odekanterats": "odekanterad",
    "odekanterbara": "odekanterbar",
    "odekanterbarare": "odekanterbar",
    "odekanterbarares": "odekanterbar",
    "odekanterbaras": "odekanterbar",
    "odekanterbarast": "odekanterbar",
    "odekanterbaraste": "odekanterbar",
    "odekanterbarastes": "odekanterbar",
    "odekanterbarasts": "odekanterbar",
    "odekanterbare": "odekanterbar",
    "odekanterbares": "odekanterbar",
    "odekanterbarheten": "odekanterbarhet",
    "odekanterbarhetens": "odekanterbarhet",
    "odekanterbarhets": "odekanterbarhet",
    "odekanterbars": "odekanterbar",
    "odekanterbart": "odekanterbar",
    "odekanterbarts": "odekanterbar",
    "odekapiterade": "odekapiterad",
    "odekapiterades": "odekapiterad",
    "odekapiterads": "odekapiterad",
    "odekapiterat": "odekapiterad",
    "odekapiterats": "odekapiterad",
    "odekapiterbara": "odekapiterbar",
    "odekapiterbarare": "odekapiterbar",
    "odekapiterbarares": "odekapiterbar",
    "odekapiterbaras": "odekapiterbar",
    "odekapiterbarast": "odekapiterbar",
    "odekapiterbaraste": "odekapiterbar",
    "odekapiterbarastes": "odekapiterbar",
    "odekapiterbarasts": "odekapiterbar",
    "odekapiterbare": "odekapiterbar",
    "odekapiterbares": "odekapiterbar",
    "odekapiterbarheten": "odekapiterbarhet",
    "odekapiterbarhetens": "odekapiterbarhet",
    "odekapiterbarhets": "odekapiterbarhet",
    "odekapiterbars": "odekapiterbar",
    "odekapiterbart": "odekapiterbar",
    "odekapiterbarts": "odekapiterbar",
    "odeklamerade": "odeklamerad",
    "odeklamerades": "odeklamerad",
    "odeklamerads": "odeklamerad",
    "odeklamerat": "odeklamerad",
    "odeklamerats": "odeklamerad",
    "odeklamerbara": "odeklamerbar",
    "odeklamerbarare": "odeklamerbar",
    "odeklamerbarares": "odeklamerbar",
    "odeklamerbaras": "odeklamerbar",
    "odeklamerbarast": "odeklamerbar",
    "odeklamerbaraste": "odeklamerbar",
    "odeklamerbarastes": "odeklamerbar",
    "odeklamerbarasts": "odeklamerbar",
    "odeklamerbare": "odeklamerbar",
    "odeklamerbares": "odeklamerbar",
    "odeklamerbarheten": "odeklamerbarhet",
    "odeklamerbarhetens": "odeklamerbarhet",
    "odeklamerbarhets": "odeklamerbarhet",
    "odeklamerbars": "odeklamerbar",
    "odeklamerbart": "odeklamerbar",
    "odeklamerbarts": "odeklamerbar",
    "odeklarerade": "odeklarerad",
    "odeklarerades": "odeklarerad",
    "odeklarerads": "odeklarerad",
    "odeklarerat": "odeklarerad",
    "odeklarerats": "odeklarerad",
    "odeklarerbara": "odeklarerbar",
    "odeklarerbarare": "odeklarerbar",
    "odeklarerbarares": "odeklarerbar",
    "odeklarerbaras": "odeklarerbar",
    "odeklarerbarast": "odeklarerbar",
    "odeklarerbaraste": "odeklarerbar",
    "odeklarerbarastes": "odeklarerbar",
    "odeklarerbarasts": "odeklarerbar",
    "odeklarerbare": "odeklarerbar",
    "odeklarerbares": "odeklarerbar",
    "odeklarerbarheten": "odeklarerbarhet",
    "odeklarerbarhetens": "odeklarerbarhet",
    "odeklarerbarhets": "odeklarerbarhet",
    "odeklarerbars": "odeklarerbar",
    "odeklarerbart": "odeklarerbar",
    "odeklarerbarts": "odeklarerbar",
    "odeklasserade": "odeklasserad",
    "odeklasserades": "odeklasserad",
    "odeklasserads": "odeklasserad",
    "odeklasserat": "odeklasserad",
    "odeklasserats": "odeklasserad",
    "odeklasserbara": "odeklasserbar",
    "odeklasserbarare": "odeklasserbar",
    "odeklasserbarares": "odeklasserbar",
    "odeklasserbaras": "odeklasserbar",
    "odeklasserbarast": "odeklasserbar",
    "odeklasserbaraste": "odeklasserbar",
    "odeklasserbarastes": "odeklasserbar",
    "odeklasserbarasts": "odeklasserbar",
    "odeklasserbare": "odeklasserbar",
    "odeklasserbares": "odeklasserbar",
    "odeklasserbarheten": "odeklasserbarhet",
    "odeklasserbarhetens": "odeklasserbarhet",
    "odeklasserbarhets": "odeklasserbarhet",
    "odeklasserbars": "odeklasserbar",
    "odeklasserbart": "odeklasserbar",
    "odeklasserbarts": "odeklasserbar",
    "odeklinerade": "odeklinerad",
    "odeklinerades": "odeklinerad",
    "odeklinerads": "odeklinerad",
    "odeklinerat": "odeklinerad",
    "odeklinerats": "odeklinerad",
    "odeklinerbara": "odeklinerbar",
    "odeklinerbarare": "odeklinerbar",
    "odeklinerbarares": "odeklinerbar",
    "odeklinerbaras": "odeklinerbar",
    "odeklinerbarast": "odeklinerbar",
    "odeklinerbaraste": "odeklinerbar",
    "odeklinerbarastes": "odeklinerbar",
    "odeklinerbarasts": "odeklinerbar",
    "odeklinerbare": "odeklinerbar",
    "odeklinerbares": "odeklinerbar",
    "odeklinerbarheten": "odeklinerbarhet",
    "odeklinerbarhetens": "odeklinerbarhet",
    "odeklinerbarhets": "odeklinerbarhet",
    "odeklinerbars": "odeklinerbar",
    "odeklinerbart": "odeklinerbar",
    "odeklinerbarts": "odeklinerbar",
    "odekorerade": "odekorerad",
    "odekorerades": "odekorerad",
    "odekorerads": "odekorerad",
    "odekorerat": "odekorerad",
    "odekorerats": "odekorerad",
    "odekorerbara": "odekorerbar",
    "odekorerbarare": "odekorerbar",
    "odekorerbarares": "odekorerbar",
    "odekorerbaras": "odekorerbar",
    "odekorerbarast": "odekorerbar",
    "odekorerbaraste": "odekorerbar",
    "odekorerbarastes": "odekorerbar",
    "odekorerbarasts": "odekorerbar",
    "odekorerbare": "odekorerbar",
    "odekorerbares": "odekorerbar",
    "odekorerbarheten": "odekorerbarhet",
    "odekorerbarhetens": "odekorerbarhet",
    "odekorerbarhets": "odekorerbarhet",
    "odekorerbars": "odekorerbar",
    "odekorerbart": "odekorerbar",
    "odekorerbarts": "odekorerbar",
    "odekouragerade": "odekouragerad",
    "odekouragerades": "odekouragerad",
    "odekouragerads": "odekouragerad",
    "odekouragerat": "odekouragerad",
    "odekouragerats": "odekouragerad",
    "odekouragerbara": "odekouragerbar",
    "odekouragerbarare": "odekouragerbar",
    "odekouragerbarares": "odekouragerbar",
    "odekouragerbaras": "odekouragerbar",
    "odekouragerbarast": "odekouragerbar",
    "odekouragerbaraste": "odekouragerbar",
    "odekouragerbarastes": "odekouragerbar",
    "odekouragerbarasts": "odekouragerbar",
    "odekouragerbare": "odekouragerbar",
    "odekouragerbares": "odekouragerbar",
    "odekouragerbarheten": "odekouragerbarhet",
    "odekouragerbarhetens": "odekouragerbarhet",
    "odekouragerbarhets": "odekouragerbarhet",
    "odekouragerbars": "odekouragerbar",
    "odekouragerbart": "odekouragerbar",
    "odekouragerbarts": "odekouragerbar",
    "odekreterade": "odekreterad",
    "odekreterades": "odekreterad",
    "odekreterads": "odekreterad",
    "odekreterat": "odekreterad",
    "odekreterats": "odekreterad",
    "odekreterbara": "odekreterbar",
    "odekreterbarare": "odekreterbar",
    "odekreterbarares": "odekreterbar",
    "odekreterbaras": "odekreterbar",
    "odekreterbarast": "odekreterbar",
    "odekreterbaraste": "odekreterbar",
    "odekreterbarastes": "odekreterbar",
    "odekreterbarasts": "odekreterbar",
    "odekreterbare": "odekreterbar",
    "odekreterbares": "odekreterbar",
    "odekreterbarheten": "odekreterbarhet",
    "odekreterbarhetens": "odekreterbarhet",
    "odekreterbarhets": "odekreterbarhet",
    "odekreterbars": "odekreterbar",
    "odekreterbart": "odekreterbar",
    "odekreterbarts": "odekreterbar",
    "odelade": "odelad",
    "odelades": "odelad",
    "odelads": "odelad",
    "odelat": "odelad",
    "odelats": "odelad",
    "odelbara": "odelbar",
    "odelbarare": "odelbar",
    "odelbarares": "odelbar",
    "odelbaras": "odelbar",
    "odelbarast": "odelbar",
    "odelbaraste": "odelbar",
    "odelbarastes": "odelbar",
    "odelbarasts": "odelbar",
    "odelbare": "odelbar",
    "odelbares": "odelbar",
    "odelbarheten": "odelbarhet",
    "odelbarhetens": "odelbarhet",
    "odelbarhets": "odelbarhet",
    "odelbars": "odelbar",
    "odelbart": "odelbar",
    "odelbarts": "odelbar",
    "odelegerade": "odelegerad",
    "odelegerades": "odelegerad",
    "odelegerads": "odelegerad",
    "odelegerat": "odelegerad",
    "odelegerats": "odelegerad",
    "odelegerbara": "odelegerbar",
    "odelegerbarare": "odelegerbar",
    "odelegerbarares": "odelegerbar",
    "odelegerbaras": "odelegerbar",
    "odelegerbarast": "odelegerbar",
    "odelegerbaraste": "odelegerbar",
    "odelegerbarastes": "odelegerbar",
    "odelegerbarasts": "odelegerbar",
    "odelegerbare": "odelegerbar",
    "odelegerbares": "odelegerbar",
    "odelegerbarheten": "odelegerbarhet",
    "odelegerbarhetens": "odelegerbarhet",
    "odelegerbarhets": "odelegerbarhet",
    "odelegerbars": "odelegerbar",
    "odelegerbart": "odelegerbar",
    "odelegerbarts": "odelegerbar",
    "odemade": "odemad",
    "odemades": "odemad",
    "odemads": "odemad",
    "odemaskerade": "odemaskerad",
    "odemaskerades": "odemaskerad",
    "odemaskerads": "odemaskerad",
    "odemaskerat": "odemaskerad",
    "odemaskerats": "odemaskerad",
    "odemaskerbara": "odemaskerbar",
    "odemaskerbarare": "odemaskerbar",
    "odemaskerbarares": "odemaskerbar",
    "odemaskerbaras": "odemaskerbar",
    "odemaskerbarast": "odemaskerbar",
    "odemaskerbaraste": "odemaskerbar",
    "odemaskerbarastes": "odemaskerbar",
    "odemaskerbarasts": "odemaskerbar",
    "odemaskerbare": "odemaskerbar",
    "odemaskerbares": "odemaskerbar",
    "odemaskerbarheten": "odemaskerbarhet",
    "odemaskerbarhetens": "odemaskerbarhet",
    "odemaskerbarhets": "odemaskerbarhet",
    "odemaskerbars": "odemaskerbar",
    "odemaskerbart": "odemaskerbar",
    "odemaskerbarts": "odemaskerbar",
    "odemat": "odemad",
    "odemats": "odemad",
    "odementerade": "odementerad",
    "odementerades": "odementerad",
    "odementerads": "odementerad",
    "odementerat": "odementerad",
    "odementerats": "odementerad",
    "odementerbara": "odementerbar",
    "odementerbarare": "odementerbar",
    "odementerbarares": "odementerbar",
    "odementerbaras": "odementerbar",
    "odementerbarast": "odementerbar",
    "odementerbaraste": "odementerbar",
    "odementerbarastes": "odementerbar",
    "odementerbarasts": "odementerbar",
    "odementerbare": "odementerbar",
    "odementerbares": "odementerbar",
    "odementerbarheten": "odementerbarhet",
    "odementerbarhetens": "odementerbarhet",
    "odementerbarhets": "odementerbarhet",
    "odementerbars": "odementerbar",
    "odementerbart": "odementerbar",
    "odementerbarts": "odementerbar",
    "odemilitariserade": "odemilitariserad",
    "odemilitariserades": "odemilitariserad",
    "odemilitariserads": "odemilitariserad",
    "odemilitariserat": "odemilitariserad",
    "odemilitariserats": "odemilitariserad",
    "odemilitariserbara": "odemilitariserbar",
    "odemilitariserbarare": "odemilitariserbar",
    "odemilitariserbarares": "odemilitariserbar",
    "odemilitariserbaras": "odemilitariserbar",
    "odemilitariserbarast": "odemilitariserbar",
    "odemilitariserbaraste": "odemilitariserbar",
    "odemilitariserbarastes": "odemilitariserbar",
    "odemilitariserbarasts": "odemilitariserbar",
    "odemilitariserbare": "odemilitariserbar",
    "odemilitariserbares": "odemilitariserbar",
    "odemilitariserbarheten": "odemilitariserbarhet",
    "odemilitariserbarhetens": "odemilitariserbarhet",
    "odemilitariserbarhets": "odemilitariserbarhet",
    "odemilitariserbars": "odemilitariserbar",
    "odemilitariserbart": "odemilitariserbar",
    "odemilitariserbarts": "odemilitariserbar",
    "odemissionerade": "odemissionerad",
    "odemissionerades": "odemissionerad",
    "odemissionerads": "odemissionerad",
    "odemissionerat": "odemissionerad",
    "odemissionerats": "odemissionerad",
    "odemobiliserade": "odemobiliserad",
    "odemobiliserades": "odemobiliserad",
    "odemobiliserads": "odemobiliserad",
    "odemobiliserat": "odemobiliserad",
    "odemobiliserats": "odemobiliserad",
    "odemobiliserbara": "odemobiliserbar",
    "odemobiliserbarare": "odemobiliserbar",
    "odemobiliserbarares": "odemobiliserbar",
    "odemobiliserbaras": "odemobiliserbar",
    "odemobiliserbarast": "odemobiliserbar",
    "odemobiliserbaraste": "odemobiliserbar",
    "odemobiliserbarastes": "odemobiliserbar",
    "odemobiliserbarasts": "odemobiliserbar",
    "odemobiliserbare": "odemobiliserbar",
    "odemobiliserbares": "odemobiliserbar",
    "odemobiliserbarheten": "odemobiliserbarhet",
    "odemobiliserbarhetens": "odemobiliserbarhet",
    "odemobiliserbarhets": "odemobiliserbarhet",
    "odemobiliserbars": "odemobiliserbar",
    "odemobiliserbart": "odemobiliserbar",
    "odemobiliserbarts": "odemobiliserbar",
    "odemokratiserade": "odemokratiserad",
    "odemokratiserades": "odemokratiserad",
    "odemokratiserads": "odemokratiserad",
    "odemokratiserat": "odemokratiserad",
    "odemokratiserats": "odemokratiserad",
    "odemokratiserbara": "odemokratiserbar",
    "odemokratiserbarare": "odemokratiserbar",
    "odemokratiserbarares": "odemokratiserbar",
    "odemokratiserbaras": "odemokratiserbar",
    "odemokratiserbarast": "odemokratiserbar",
    "odemokratiserbaraste": "odemokratiserbar",
    "odemokratiserbarastes": "odemokratiserbar",
    "odemokratiserbarasts": "odemokratiserbar",
    "odemokratiserbare": "odemokratiserbar",
    "odemokratiserbares": "odemokratiserbar",
    "odemokratiserbarheten": "odemokratiserbarhet",
    "odemokratiserbarhetens": "odemokratiserbarhet",
    "odemokratiserbarhets": "odemokratiserbarhet",
    "odemokratiserbars": "odemokratiserbar",
    "odemokratiserbart": "odemokratiserbar",
    "odemokratiserbarts": "odemokratiserbar",
    "odemokratiska": "odemokratisk",
    "odemokratiskare": "odemokratisk",
    "odemokratiskares": "odemokratisk",
    "odemokratiskas": "odemokratisk",
    "odemokratiskast": "odemokratisk",
    "odemokratiskaste": "odemokratisk",
    "odemokratiskastes": "odemokratisk",
    "odemokratiskasts": "odemokratisk",
    "odemokratiske": "odemokratisk",
    "odemokratiskes": "odemokratisk",
    "odemokratisks": "odemokratisk",
    "odemokratiskt": "odemokratisk",
    "odemokratiskts": "odemokratisk",
    "odemolerade": "odemolerad",
    "odemolerades": "odemolerad",
    "odemolerads": "odemolerad",
    "odemolerat": "odemolerad",
    "odemolerats": "odemolerad",
    "odemolerbara": "odemolerbar",
    "odemolerbarare": "odemolerbar",
    "odemolerbarares": "odemolerbar",
    "odemolerbaras": "odemolerbar",
    "odemolerbarast": "odemolerbar",
    "odemolerbaraste": "odemolerbar",
    "odemolerbarastes": "odemolerbar",
    "odemolerbarasts": "odemolerbar",
    "odemolerbare": "odemolerbar",
    "odemolerbares": "odemolerbar",
    "odemolerbarheten": "odemolerbarhet",
    "odemolerbarhetens": "odemolerbarhet",
    "odemolerbarhets": "odemolerbarhet",
    "odemolerbars": "odemolerbar",
    "odemolerbart": "odemolerbar",
    "odemolerbarts": "odemolerbar",
    "odemonstrerade": "odemonstrerad",
    "odemonstrerades": "odemonstrerad",
    "odemonstrerads": "odemonstrerad",
    "odemonstrerat": "odemonstrerad",
    "odemonstrerats": "odemonstrerad",
    "odemonstrerbara": "odemonstrerbar",
    "odemonstrerbarare": "odemonstrerbar",
    "odemonstrerbarares": "odemonstrerbar",
    "odemonstrerbaras": "odemonstrerbar",
    "odemonstrerbarast": "odemonstrerbar",
    "odemonstrerbaraste": "odemonstrerbar",
    "odemonstrerbarastes": "odemonstrerbar",
    "odemonstrerbarasts": "odemonstrerbar",
    "odemonstrerbare": "odemonstrerbar",
    "odemonstrerbares": "odemonstrerbar",
    "odemonstrerbarheten": "odemonstrerbarhet",
    "odemonstrerbarhetens": "odemonstrerbarhet",
    "odemonstrerbarhets": "odemonstrerbarhet",
    "odemonstrerbars": "odemonstrerbar",
    "odemonstrerbart": "odemonstrerbar",
    "odemonstrerbarts": "odemonstrerbar",
    "odemonterade": "odemonterad",
    "odemonterades": "odemonterad",
    "odemonterads": "odemonterad",
    "odemonterat": "odemonterad",
    "odemonterats": "odemonterad",
    "odemonterbara": "odemonterbar",
    "odemonterbarare": "odemonterbar",
    "odemonterbarares": "odemonterbar",
    "odemonterbaras": "odemonterbar",
    "odemonterbarast": "odemonterbar",
    "odemonterbaraste": "odemonterbar",
    "odemonterbarastes": "odemonterbar",
    "odemonterbarasts": "odemonterbar",
    "odemonterbare": "odemonterbar",
    "odemonterbares": "odemonterbar",
    "odemonterbarheten": "odemonterbarhet",
    "odemonterbarhetens": "odemonterbarhet",
    "odemonterbarhets": "odemonterbarhet",
    "odemonterbars": "odemonterbar",
    "odemonterbart": "odemonterbar",
    "odemonterbarts": "odemonterbar",
    "odemoraliserade": "odemoraliserad",
    "odemoraliserades": "odemoraliserad",
    "odemoraliserads": "odemoraliserad",
    "odemoraliserat": "odemoraliserad",
    "odemoraliserats": "odemoraliserad",
    "odemoraliserbara": "odemoraliserbar",
    "odemoraliserbarare": "odemoraliserbar",
    "odemoraliserbarares": "odemoraliserbar",
    "odemoraliserbaras": "odemoraliserbar",
    "odemoraliserbarast": "odemoraliserbar",
    "odemoraliserbaraste": "odemoraliserbar",
    "odemoraliserbarastes": "odemoraliserbar",
    "odemoraliserbarasts": "odemoraliserbar",
    "odemoraliserbare": "odemoraliserbar",
    "odemoraliserbares": "odemoraliserbar",
    "odemoraliserbarheten": "odemoraliserbarhet",
    "odemoraliserbarhetens": "odemoraliserbarhet",
    "odemoraliserbarhets": "odemoraliserbarhet",
    "odemoraliserbars": "odemoraliserbar",
    "odemoraliserbart": "odemoraliserbar",
    "odemoraliserbarts": "odemoraliserbar",
    "oden": "ode",
    "odena": "ode",
    "odenas": "ode",
    "odenaturaliserade": "odenaturaliserad",
    "odenaturaliserades": "odenaturaliserad",
    "odenaturaliserads": "odenaturaliserad",
    "odenaturaliserat": "odenaturaliserad",
    "odenaturaliserats": "odenaturaliserad",
    "odenaturaliserbara": "odenaturaliserbar",
    "odenaturaliserbarare": "odenaturaliserbar",
    "odenaturaliserbarares": "odenaturaliserbar",
    "odenaturaliserbaras": "odenaturaliserbar",
    "odenaturaliserbarast": "odenaturaliserbar",
    "odenaturaliserbaraste": "odenaturaliserbar",
    "odenaturaliserbarastes": "odenaturaliserbar",
    "odenaturaliserbarasts": "odenaturaliserbar",
    "odenaturaliserbare": "odenaturaliserbar",
    "odenaturaliserbares": "odenaturaliserbar",
    "odenaturaliserbarheten": "odenaturaliserbarhet",
    "odenaturaliserbarhetens": "odenaturaliserbarhet",
    "odenaturaliserbarhets": "odenaturaliserbarhet",
    "odenaturaliserbars": "odenaturaliserbar",
    "odenaturaliserbart": "odenaturaliserbar",
    "odenaturaliserbarts": "odenaturaliserbar",
    "odenaturerade": "odenaturerad",
    "odenaturerades": "odenaturerad",
    "odenaturerads": "odenaturerad",
    "odenaturerat": "odenaturerad",
    "odenaturerats": "odenaturerad",
    "odenaturerbara": "odenaturerbar",
    "odenaturerbarare": "odenaturerbar",
    "odenaturerbarares": "odenaturerbar",
    "odenaturerbaras": "odenaturerbar",
    "odenaturerbarast": "odenaturerbar",
    "odenaturerbaraste": "odenaturerbar",
    "odenaturerbarastes": "odenaturerbar",
    "odenaturerbarasts": "odenaturerbar",
    "odenaturerbare": "odenaturerbar",
    "odenaturerbares": "odenaturerbar",
    "odenaturerbarheten": "odenaturerbarhet",
    "odenaturerbarhetens": "odenaturerbarhet",
    "odenaturerbarhets": "odenaturerbarhet",
    "odenaturerbars": "odenaturerbar",
    "odenaturerbart": "odenaturerbar",
    "odenaturerbarts": "odenaturerbar",
    "odenoterade": "odenoterad",
    "odenoterades": "odenoterad",
    "odenoterads": "odenoterad",
    "odenoterat": "odenoterad",
    "odenoterats": "odenoterad",
    "odenoterbara": "odenoterbar",
    "odenoterbarare": "odenoterbar",
    "odenoterbarares": "odenoterbar",
    "odenoterbaras": "odenoterbar",
    "odenoterbarast": "odenoterbar",
    "odenoterbaraste": "odenoterbar",
    "odenoterbarastes": "odenoterbar",
    "odenoterbarasts": "odenoterbar",
    "odenoterbare": "odenoterbar",
    "odenoterbares": "odenoterbar",
    "odenoterbarheten": "odenoterbarhet",
    "odenoterbarhetens": "odenoterbarhet",
    "odenoterbarhets": "odenoterbarhet",
    "odenoterbars": "odenoterbar",
    "odenoterbart": "odenoterbar",
    "odenoterbarts": "odenoterbar",
    "odens": "ode",
    "odensflyen": "odensfly",
    "odensflyens": "odensfly",
    "odensflyet": "odensfly",
    "odensflyets": "odensfly",
    "odensflyn": "odensfly",
    "odensflyna": "odensfly",
    "odensflynas": "odensfly",
    "odensflyns": "odensfly",
    "odensflys": "odensfly",
    "odensflyt": "odensfly",
    "odensflyts": "odensfly",
    "odenuderade": "odenuderad",
    "odenuderades": "odenuderad",
    "odenuderads": "odenuderad",
    "odenuderat": "odenuderad",
    "odenuderats": "odenuderad",
    "odenuderbara": "odenuderbar",
    "odenuderbarare": "odenuderbar",
    "odenuderbarares": "odenuderbar",
    "odenuderbaras": "odenuderbar",
    "odenuderbarast": "odenuderbar",
    "odenuderbaraste": "odenuderbar",
    "odenuderbarastes": "odenuderbar",
    "odenuderbarasts": "odenuderbar",
    "odenuderbare": "odenuderbar",
    "odenuderbares": "odenuderbar",
    "odenuderbarheten": "odenuderbarhet",
    "odenuderbarhetens": "odenuderbarhet",
    "odenuderbarhets": "odenuderbarhet",
    "odenuderbars": "odenuderbar",
    "odenuderbart": "odenuderbar",
    "odenuderbarts": "odenuderbar",
    "odeodoriserade": "odeodoriserad",
    "odeodoriserades": "odeodoriserad",
    "odeodoriserads": "odeodoriserad",
    "odeodoriserat": "odeodoriserad",
    "odeodoriserats": "odeodoriserad",
    "odeodoriserbara": "odeodoriserbar",
    "odeodoriserbarare": "odeodoriserbar",
    "odeodoriserbarares": "odeodoriserbar",
    "odeodoriserbaras": "odeodoriserbar",
    "odeodoriserbarast": "odeodoriserbar",
    "odeodoriserbaraste": "odeodoriserbar",
    "odeodoriserbarastes": "odeodoriserbar",
    "odeodoriserbarasts": "odeodoriserbar",
    "odeodoriserbare": "odeodoriserbar",
    "odeodoriserbares": "odeodoriserbar",
    "odeodoriserbarheten": "odeodoriserbarhet",
    "odeodoriserbarhetens": "odeodoriserbarhet",
    "odeodoriserbarhets": "odeodoriserbarhet",
    "odeodoriserbars": "odeodoriserbar",
    "odeodoriserbart": "odeodoriserbar",
    "odeodoriserbarts": "odeodoriserbar",
    "odepatrierade": "odepatrierad",
    "odepatrierades": "odepatrierad",
    "odepatrierads": "odepatrierad",
    "odepatrierat": "odepatrierad",
    "odepatrierats": "odepatrierad",
    "odepatrierbara": "odepatrierbar",
    "odepatrierbarare": "odepatrierbar",
    "odepatrierbarares": "odepatrierbar",
    "odepatrierbaras": "odepatrierbar",
    "odepatrierbarast": "odepatrierbar",
    "odepatrierbaraste": "odepatrierbar",
    "odepatrierbarastes": "odepatrierbar",
    "odepatrierbarasts": "odepatrierbar",
    "odepatrierbare": "odepatrierbar",
    "odepatrierbares": "odepatrierbar",
    "odepatrierbarheten": "odepatrierbarhet",
    "odepatrierbarhetens": "odepatrierbarhet",
    "odepatrierbarhets": "odepatrierbarhet",
    "odepatrierbars": "odepatrierbar",
    "odepatrierbart": "odepatrierbar",
    "odepatrierbarts": "odepatrierbar",
    "odepenserade": "odepenserad",
    "odepenserades": "odepenserad",
    "odepenserads": "odepenserad",
    "odepenserat": "odepenserad",
    "odepenserats": "odepenserad",
    "odepenserbara": "odepenserbar",
    "odepenserbarare": "odepenserbar",
    "odepenserbarares": "odepenserbar",
    "odepenserbaras": "odepenserbar",
    "odepenserbarast": "odepenserbar",
    "odepenserbaraste": "odepenserbar",
    "odepenserbarastes": "odepenserbar",
    "odepenserbarasts": "odepenserbar",
    "odepenserbare": "odepenserbar",
    "odepenserbares": "odepenserbar",
    "odepenserbarheten": "odepenserbarhet",
    "odepenserbarhetens": "odepenserbarhet",
    "odepenserbarhets": "odepenserbarhet",
    "odepenserbars": "odepenserbar",
    "odepenserbart": "odepenserbar",
    "odepenserbarts": "odepenserbar",
    "odeplacerade": "odeplacerad",
    "odeplacerades": "odeplacerad",
    "odeplacerads": "odeplacerad",
    "odeplacerat": "odeplacerad",
    "odeplacerats": "odeplacerad",
    "odeplacerbara": "odeplacerbar",
    "odeplacerbarare": "odeplacerbar",
    "odeplacerbarares": "odeplacerbar",
    "odeplacerbaras": "odeplacerbar",
    "odeplacerbarast": "odeplacerbar",
    "odeplacerbaraste": "odeplacerbar",
    "odeplacerbarastes": "odeplacerbar",
    "odeplacerbarasts": "odeplacerbar",
    "odeplacerbare": "odeplacerbar",
    "odeplacerbares": "odeplacerbar",
    "odeplacerbarheten": "odeplacerbarhet",
    "odeplacerbarhetens": "odeplacerbarhet",
    "odeplacerbarhets": "odeplacerbarhet",
    "odeplacerbars": "odeplacerbar",
    "odeplacerbart": "odeplacerbar",
    "odeplacerbarts": "odeplacerbar",
    "odeponerade": "odeponerad",
    "odeponerades": "odeponerad",
    "odeponerads": "odeponerad",
    "odeponerat": "odeponerad",
    "odeponerats": "odeponerad",
    "odeponerbara": "odeponerbar",
    "odeponerbarare": "odeponerbar",
    "odeponerbarares": "odeponerbar",
    "odeponerbaras": "odeponerbar",
    "odeponerbarast": "odeponerbar",
    "odeponerbaraste": "odeponerbar",
    "odeponerbarastes": "odeponerbar",
    "odeponerbarasts": "odeponerbar",
    "odeponerbare": "odeponerbar",
    "odeponerbares": "odeponerbar",
    "odeponerbarheten": "odeponerbarhet",
    "odeponerbarhetens": "odeponerbarhet",
    "odeponerbarhets": "odeponerbarhet",
    "odeponerbars": "odeponerbar",
    "odeponerbart": "odeponerbar",
    "odeponerbarts": "odeponerbar",
    "odeporterade": "odeporterad",
    "odeporterades": "odeporterad",
    "odeporterads": "odeporterad",
    "odeporterat": "odeporterad",
    "odeporterats": "odeporterad",
    "odeporterbara": "odeporterbar",
    "odeporterbarare": "odeporterbar",
    "odeporterbarares": "odeporterbar",
    "odeporterbaras": "odeporterbar",
    "odeporterbarast": "odeporterbar",
    "odeporterbaraste": "odeporterbar",
    "odeporterbarastes": "odeporterbar",
    "odeporterbarasts": "odeporterbar",
    "odeporterbare": "odeporterbar",
    "odeporterbares": "odeporterbar",
    "odeporterbarheten": "odeporterbarhet",
    "odeporterbarhetens": "odeporterbarhet",
    "odeporterbarhets": "odeporterbarhet",
    "odeporterbars": "odeporterbar",
    "odeporterbart": "odeporterbar",
    "odeporterbarts": "odeporterbar",
    "odeprecierade": "odeprecierad",
    "odeprecierades": "odeprecierad",
    "odeprecierads": "odeprecierad",
    "odeprecierat": "odeprecierad",
    "odeprecierats": "odeprecierad",
    "odeprecierbara": "odeprecierbar",
    "odeprecierbarare": "odeprecierbar",
    "odeprecierbarares": "odeprecierbar",
    "odeprecierbaras": "odeprecierbar",
    "odeprecierbarast": "odeprecierbar",
    "odeprecierbaraste": "odeprecierbar",
    "odeprecierbarastes": "odeprecierbar",
    "odeprecierbarasts": "odeprecierbar",
    "odeprecierbare": "odeprecierbar",
    "odeprecierbares": "odeprecierbar",
    "odeprecierbarheten": "odeprecierbarhet",
    "odeprecierbarhetens": "odeprecierbarhet",
    "odeprecierbarhets": "odeprecierbarhet",
    "odeprecierbars": "odeprecierbar",
    "odeprecierbart": "odeprecierbar",
    "odeprecierbarts": "odeprecierbar",
    "oderangerade": "oderangerad",
    "oderangerades": "oderangerad",
    "oderangerads": "oderangerad",
    "oderangerat": "oderangerad",
    "oderangerats": "oderangerad",
    "oderangerbara": "oderangerbar",
    "oderangerbarare": "oderangerbar",
    "oderangerbarares": "oderangerbar",
    "oderangerbaras": "oderangerbar",
    "oderangerbarast": "oderangerbar",
    "oderangerbaraste": "oderangerbar",
    "oderangerbarastes": "oderangerbar",
    "oderangerbarasts": "oderangerbar",
    "oderangerbare": "oderangerbar",
    "oderangerbares": "oderangerbar",
    "oderangerbarheten": "oderangerbarhet",
    "oderangerbarhetens": "oderangerbarhet",
    "oderangerbarhets": "oderangerbarhet",
    "oderangerbars": "oderangerbar",
    "oderangerbart": "oderangerbar",
    "oderangerbarts": "oderangerbar",
    "oderiverade": "oderiverad",
    "oderiverades": "oderiverad",
    "oderiverads": "oderiverad",
    "oderiverat": "oderiverad",
    "oderiverats": "oderiverad",
    "oderiverbara": "oderiverbar",
    "oderiverbarare": "oderiverbar",
    "oderiverbarares": "oderiverbar",
    "oderiverbaras": "oderiverbar",
    "oderiverbarast": "oderiverbar",
    "oderiverbaraste": "oderiverbar",
    "oderiverbarastes": "oderiverbar",
    "oderiverbarasts": "oderiverbar",
    "oderiverbare": "oderiverbar",
    "oderiverbares": "oderiverbar",
    "oderiverbarheten": "oderiverbarhet",
    "oderiverbarhetens": "oderiverbarhet",
    "oderiverbarhets": "oderiverbarhet",
    "oderiverbars": "oderiverbar",
    "oderiverbart": "oderiverbar",
    "oderiverbarts": "oderiverbar",
    "odes": "ode",
    "odesarmerade": "odesarmerad",
    "odesarmerades": "odesarmerad",
    "odesarmerads": "odesarmerad",
    "odesarmerat": "odesarmerad",
    "odesarmerats": "odesarmerad",
    "odesarmerbara": "odesarmerbar",
    "odesarmerbarare": "odesarmerbar",
    "odesarmerbarares": "odesarmerbar",
    "odesarmerbaras": "odesarmerbar",
    "odesarmerbarast": "odesarmerbar",
    "odesarmerbaraste": "odesarmerbar",
    "odesarmerbarastes": "odesarmerbar",
    "odesarmerbarasts": "odesarmerbar",
    "odesarmerbare": "odesarmerbar",
    "odesarmerbares": "odesarmerbar",
    "odesarmerbarheten": "odesarmerbarhet",
    "odesarmerbarhetens": "odesarmerbarhet",
    "odesarmerbarhets": "odesarmerbarhet",
    "odesarmerbars": "odesarmerbar",
    "odesarmerbart": "odesarmerbar",
    "odesarmerbarts": "odesarmerbar",
    "odesavouerade": "odesavouerad",
    "odesavouerades": "odesavouerad",
    "odesavouerads": "odesavouerad",
    "odesavouerat": "odesavouerad",
    "odesavouerats": "odesavouerad",
    "odesavouerbara": "odesavouerbar",
    "odesavouerbarare": "odesavouerbar",
    "odesavouerbarares": "odesavouerbar",
    "odesavouerbaras": "odesavouerbar",
    "odesavouerbarast": "odesavouerbar",
    "odesavouerbaraste": "odesavouerbar",
    "odesavouerbarastes": "odesavouerbar",
    "odesavouerbarasts": "odesavouerbar",
    "odesavouerbare": "odesavouerbar",
    "odesavouerbares": "odesavouerbar",
    "odesavouerbarheten": "odesavouerbarhet",
    "odesavouerbarhetens": "odesavouerbarhet",
    "odesavouerbarhets": "odesavouerbarhet",
    "odesavouerbars": "odesavouerbar",
    "odesavouerbart": "odesavouerbar",
    "odesavouerbarts": "odesavouerbar",
    "odesensibiliserade": "odesensibiliserad",
    "odesensibiliserades": "odesensibiliserad",
    "odesensibiliserads": "odesensibiliserad",
    "odesensibiliserat": "odesensibiliserad",
    "odesensibiliserats": "odesensibiliserad",
    "odesensibiliserbara": "odesensibiliserbar",
    "odesensibiliserbarare": "odesensibiliserbar",
    "odesensibiliserbarares": "odesensibiliserbar",
    "odesensibiliserbaras": "odesensibiliserbar",
    "odesensibiliserbarast": "odesensibiliserbar",
    "odesensibiliserbaraste": "odesensibiliserbar",
    "odesensibiliserbarastes": "odesensibiliserbar",
    "odesensibiliserbarasts": "odesensibiliserbar",
    "odesensibiliserbare": "odesensibiliserbar",
    "odesensibiliserbares": "odesensibiliserbar",
    "odesensibiliserbarheten": "odesensibiliserbarhet",
    "odesensibiliserbarhetens": "odesensibiliserbarhet",
    "odesensibiliserbarhets": "odesensibiliserbarhet",
    "odesensibiliserbars": "odesensibiliserbar",
    "odesensibiliserbart": "odesensibiliserbar",
    "odesensibiliserbarts": "odesensibiliserbar",
    "odesignade": "odesignad",
    "odesignades": "odesignad",
    "odesignads": "odesignad",
    "odesignat": "odesignad",
    "odesignats": "odesignad",
    "odesignerade": "odesignerad",
    "odesignerades": "odesignerad",
    "odesignerads": "odesignerad",
    "odesignerat": "odesignerad",
    "odesignerats": "odesignerad",
    "odesignerbara": "odesignerbar",
    "odesignerbarare": "odesignerbar",
    "odesignerbarares": "odesignerbar",
    "odesignerbaras": "odesignerbar",
    "odesignerbarast": "odesignerbar",
    "odesignerbaraste": "odesignerbar",
    "odesignerbarastes": "odesignerbar",
    "odesignerbarasts": "odesignerbar",
    "odesignerbare": "odesignerbar",
    "odesignerbares": "odesignerbar",
    "odesignerbarheten": "odesignerbarhet",
    "odesignerbarhetens": "odesignerbarhet",
    "odesignerbarhets": "odesignerbarhet",
    "odesignerbars": "odesignerbar",
    "odesignerbart": "odesignerbar",
    "odesignerbarts": "odesignerbar",
    "odesinfekterade": "odesinfekterad",
    "odesinfekterades": "odesinfekterad",
    "odesinfekterads": "odesinfekterad",
    "odesinfekterat": "odesinfekterad",
    "odesinfekterats": "odesinfekterad",
    "odesinfekterbara": "odesinfekterbar",
    "odesinfekterbarare": "odesinfekterbar",
    "odesinfekterbarares": "odesinfekterbar",
    "odesinfekterbaras": "odesinfekterbar",
    "odesinfekterbarast": "odesinfekterbar",
    "odesinfekterbaraste": "odesinfekterbar",
    "odesinfekterbarastes": "odesinfekterbar",
    "odesinfekterbarasts": "odesinfekterbar",
    "odesinfekterbare": "odesinfekterbar",
    "odesinfekterbares": "odesinfekterbar",
    "odesinfekterbarheten": "odesinfekterbarhet",
    "odesinfekterbarhetens": "odesinfekterbarhet",
    "odesinfekterbarhets": "odesinfekterbarhet",
    "odesinfekterbars": "odesinfekterbar",
    "odesinfekterbart": "odesinfekterbar",
    "odesinfekterbarts": "odesinfekterbar",
    "odesinficerade": "odesinficerad",
    "odesinficerades": "odesinficerad",
    "odesinficerads": "odesinficerad",
    "odesinficerat": "odesinficerad",
    "odesinficerats": "odesinficerad",
    "odesinficerbara": "odesinficerbar",
    "odesinficerbarare": "odesinficerbar",
    "odesinficerbarares": "odesinficerbar",
    "odesinficerbaras": "odesinficerbar",
    "odesinficerbarast": "odesinficerbar",
    "odesinficerbaraste": "odesinficerbar",
    "odesinficerbarastes": "odesinficerbar",
    "odesinficerbarasts": "odesinficerbar",
    "odesinficerbare": "odesinficerbar",
    "odesinficerbares": "odesinficerbar",
    "odesinficerbarheten": "odesinficerbarhet",
    "odesinficerbarhetens": "odesinficerbarhet",
    "odesinficerbarhets": "odesinficerbarhet",
    "odesinficerbars": "odesinficerbar",
    "odesinficerbart": "odesinficerbar",
    "odesinficerbarts": "odesinficerbar",
    "odesinformerade": "odesinformerad",
    "odesinformerades": "odesinformerad",
    "odesinformerads": "odesinformerad",
    "odesinformerat": "odesinformerad",
    "odesinformerats": "odesinformerad",
    "odesinformerbara": "odesinformerbar",
    "odesinformerbarare": "odesinformerbar",
    "odesinformerbarares": "odesinformerbar",
    "odesinformerbaras": "odesinformerbar",
    "odesinformerbarast": "odesinformerbar",
    "odesinformerbaraste": "odesinformerbar",
    "odesinformerbarastes": "odesinformerbar",
    "odesinformerbarasts": "odesinformerbar",
    "odesinformerbare": "odesinformerbar",
    "odesinformerbares": "odesinformerbar",
    "odesinformerbarheten": "odesinformerbarhet",
    "odesinformerbarhetens": "odesinformerbarhet",
    "odesinformerbarhets": "odesinformerbarhet",
    "odesinformerbars": "odesinformerbar",
    "odesinformerbart": "odesinformerbar",
    "odesinformerbarts": "odesinformerbar",
    "odesorganiserade": "odesorganiserad",
    "odesorganiserades": "odesorganiserad",
    "odesorganiserads": "odesorganiserad",
    "odesorganiserat": "odesorganiserad",
    "odesorganiserats": "odesorganiserad",
    "odesorganiserbara": "odesorganiserbar",
    "odesorganiserbarare": "odesorganiserbar",
    "odesorganiserbarares": "odesorganiserbar",
    "odesorganiserbaras": "odesorganiserbar",
    "odesorganiserbarast": "odesorganiserbar",
    "odesorganiserbaraste": "odesorganiserbar",
    "odesorganiserbarastes": "odesorganiserbar",
    "odesorganiserbarasts": "odesorganiserbar",
    "odesorganiserbare": "odesorganiserbar",
    "odesorganiserbares": "odesorganiserbar",
    "odesorganiserbarheten": "odesorganiserbarhet",
    "odesorganiserbarhetens": "odesorganiserbarhet",
    "odesorganiserbarhets": "odesorganiserbarhet",
    "odesorganiserbars": "odesorganiserbar",
    "odesorganiserbart": "odesorganiserbar",
    "odesorganiserbarts": "odesorganiserbar",
    "odestabiliserade": "odestabiliserad",
    "odestabiliserades": "odestabiliserad",
    "odestabiliserads": "odestabiliserad",
    "odestabiliserat": "odestabiliserad",
    "odestabiliserats": "odestabiliserad",
    "odestabiliserbara": "odestabiliserbar",
    "odestabiliserbarare": "odestabiliserbar",
    "odestabiliserbarares": "odestabiliserbar",
    "odestabiliserbaras": "odestabiliserbar",
    "odestabiliserbarast": "odestabiliserbar",
    "odestabiliserbaraste": "odestabiliserbar",
    "odestabiliserbarastes": "odestabiliserbar",
    "odestabiliserbarasts": "odestabiliserbar",
    "odestabiliserbare": "odestabiliserbar",
    "odestabiliserbares": "odestabiliserbar",
    "odestabiliserbarheten": "odestabiliserbarhet",
    "odestabiliserbarhetens": "odestabiliserbarhet",
    "odestabiliserbarhets": "odestabiliserbarhet",
    "odestabiliserbars": "odestabiliserbar",
    "odestabiliserbart": "odestabiliserbar",
    "odestabiliserbarts": "odestabiliserbar",
    "odestillerade": "odestillerad",
    "odestillerades": "odestillerad",
    "odestillerads": "odestillerad",
    "odestillerat": "odestillerad",
    "odestillerats": "odestillerad",
    "odestillerbara": "odestillerbar",
    "odestillerbarare": "odestillerbar",
    "odestillerbarares": "odestillerbar",
    "odestillerbaras": "odestillerbar",
    "odestillerbarast": "odestillerbar",
    "odestillerbaraste": "odestillerbar",
    "odestillerbarastes": "odestillerbar",
    "odestillerbarasts": "odestillerbar",
    "odestillerbare": "odestillerbar",
    "odestillerbares": "odestillerbar",
    "odestillerbarheten": "odestillerbarhet",
    "odestillerbarhetens": "odestillerbarhet",
    "odestillerbarhets": "odestillerbarhet",
    "odestillerbars": "odestillerbar",
    "odestillerbart": "odestillerbar",
    "odestillerbarts": "odestillerbar",
    "odestinerade": "odestinerad",
    "odestinerades": "odestinerad",
    "odestinerads": "odestinerad",
    "odestinerat": "odestinerad",
    "odestinerats": "odestinerad",
    "odestinerbara": "odestinerbar",
    "odestinerbarare": "odestinerbar",
    "odestinerbarares": "odestinerbar",
    "odestinerbaras": "odestinerbar",
    "odestinerbarast": "odestinerbar",
    "odestinerbaraste": "odestinerbar",
    "odestinerbarastes": "odestinerbar",
    "odestinerbarasts": "odestinerbar",
    "odestinerbare": "odestinerbar",
    "odestinerbares": "odestinerbar",
    "odestinerbarheten": "odestinerbarhet",
    "odestinerbarhetens": "odestinerbarhet",
    "odestinerbarhets": "odestinerbarhet",
    "odestinerbars": "odestinerbar",
    "odestinerbart": "odestinerbar",
    "odestinerbarts": "odestinerbar",
    "odestruerade": "odestruerad",
    "odestruerades": "odestruerad",
    "odestruerads": "odestruerad",
    "odestruerat": "odestruerad",
    "odestruerats": "odestruerad",
    "odestruerbara": "odestruerbar",
    "odestruerbarare": "odestruerbar",
    "odestruerbarares": "odestruerbar",
    "odestruerbaras": "odestruerbar",
    "odestruerbarast": "odestruerbar",
    "odestruerbaraste": "odestruerbar",
    "odestruerbarastes": "odestruerbar",
    "odestruerbarasts": "odestruerbar",
    "odestruerbare": "odestruerbar",
    "odestruerbares": "odestruerbar",
    "odestruerbarheten": "odestruerbarhet",
    "odestruerbarhetens": "odestruerbarhet",
    "odestruerbarhets": "odestruerbarhet",
    "odestruerbars": "odestruerbar",
    "odestruerbart": "odestruerbar",
    "odestruerbarts": "odestruerbar",
    "odet": "ode",
    "odetacherade": "odetacherad",
    "odetacherades": "odetacherad",
    "odetacherads": "odetacherad",
    "odetacherat": "odetacherad",
    "odetacherats": "odetacherad",
    "odetacherbara": "odetacherbar",
    "odetacherbarare": "odetacherbar",
    "odetacherbarares": "odetacherbar",
    "odetacherbaras": "odetacherbar",
    "odetacherbarast": "odetacherbar",
    "odetacherbaraste": "odetacherbar",
    "odetacherbarastes": "odetacherbar",
    "odetacherbarasts": "odetacherbar",
    "odetacherbare": "odetacherbar",
    "odetacherbares": "odetacherbar",
    "odetacherbarheten": "odetacherbarhet",
    "odetacherbarhetens": "odetacherbarhet",
    "odetacherbarhets": "odetacherbarhet",
    "odetacherbars": "odetacherbar",
    "odetacherbart": "odetacherbar",
    "odetacherbarts": "odetacherbar",
    "odetaljerade": "odetaljerad",
    "odetaljerades": "odetaljerad",
    "odetaljerads": "odetaljerad",
    "odetaljerat": "odetaljerad",
    "odetaljerats": "odetaljerad",
    "odetekterade": "odetekterad",
    "odetekterades": "odetekterad",
    "odetekterads": "odetekterad",
    "odetekterat": "odetekterad",
    "odetekterats": "odetekterad",
    "odetekterbara": "odetekterbar",
    "odetekterbarare": "odetekterbar",
    "odetekterbarares": "odetekterbar",
    "odetekterbaras": "odetekterbar",
    "odetekterbarast": "odetekterbar",
    "odetekterbaraste": "odetekterbar",
    "odetekterbarastes": "odetekterbar",
    "odetekterbarasts": "odetekterbar",
    "odetekterbare": "odetekterbar",
    "odetekterbares": "odetekterbar",
    "odetekterbarheten": "odetekterbarhet",
    "odetekterbarhetens": "odetekterbarhet",
    "odetekterbarhets": "odetekterbarhet",
    "odetekterbars": "odetekterbar",
    "odetekterbart": "odetekterbar",
    "odetekterbarts": "odetekterbar",
    "odeterminerade": "odeterminerad",
    "odeterminerades": "odeterminerad",
    "odeterminerads": "odeterminerad",
    "odeterminerat": "odeterminerad",
    "odeterminerats": "odeterminerad",
    "odeterminerbara": "odeterminerbar",
    "odeterminerbarare": "odeterminerbar",
    "odeterminerbarares": "odeterminerbar",
    "odeterminerbaras": "odeterminerbar",
    "odeterminerbarast": "odeterminerbar",
    "odeterminerbaraste": "odeterminerbar",
    "odeterminerbarastes": "odeterminerbar",
    "odeterminerbarasts": "odeterminerbar",
    "odeterminerbare": "odeterminerbar",
    "odeterminerbares": "odeterminerbar",
    "odeterminerbarheten": "odeterminerbarhet",
    "odeterminerbarhetens": "odeterminerbarhet",
    "odeterminerbarhets": "odeterminerbarhet",
    "odeterminerbars": "odeterminerbar",
    "odeterminerbart": "odeterminerbar",
    "odeterminerbarts": "odeterminerbar",
    "odetonerade": "odetonerad",
    "odetonerades": "odetonerad",
    "odetonerads": "odetonerad",
    "odetonerat": "odetonerad",
    "odetonerats": "odetonerad",
    "odetonerbara": "odetonerbar",
    "odetonerbarare": "odetonerbar",
    "odetonerbarares": "odetonerbar",
    "odetonerbaras": "odetonerbar",
    "odetonerbarast": "odetonerbar",
    "odetonerbaraste": "odetonerbar",
    "odetonerbarastes": "odetonerbar",
    "odetonerbarasts": "odetonerbar",
    "odetonerbare": "odetonerbar",
    "odetonerbares": "odetonerbar",
    "odetonerbarheten": "odetonerbarhet",
    "odetonerbarhetens": "odetonerbarhet",
    "odetonerbarhets": "odetonerbarhet",
    "odetonerbars": "odetonerbar",
    "odetonerbart": "odetonerbar",
    "odetonerbarts": "odetonerbar",
    "odetroniserade": "odetroniserad",
    "odetroniserades": "odetroniserad",
    "odetroniserads": "odetroniserad",
    "odetroniserat": "odetroniserad",
    "odetroniserats": "odetroniserad",
    "odetroniserbara": "odetroniserbar",
    "odetroniserbarare": "odetroniserbar",
    "odetroniserbarares": "odetroniserbar",
    "odetroniserbaras": "odetroniserbar",
    "odetroniserbarast": "odetroniserbar",
    "odetroniserbaraste": "odetroniserbar",
    "odetroniserbarastes": "odetroniserbar",
    "odetroniserbarasts": "odetroniserbar",
    "odetroniserbare": "odetroniserbar",
    "odetroniserbares": "odetroniserbar",
    "odetroniserbarheten": "odetroniserbarhet",
    "odetroniserbarhetens": "odetroniserbarhet",
    "odetroniserbarhets": "odetroniserbarhet",
    "odetroniserbars": "odetroniserbar",
    "odetroniserbart": "odetroniserbar",
    "odetroniserbarts": "odetroniserbar",
    "odets": "ode",
    "odevalverade": "odevalverad",
    "odevalverades": "odevalverad",
    "odevalverads": "odevalverad",
    "odevalverat": "odevalverad",
    "odevalverats": "odevalverad",
    "odevalverbara": "odevalverbar",
    "odevalverbarare": "odevalverbar",
    "odevalverbarares": "odevalverbar",
    "odevalverbaras": "odevalverbar",
    "odevalverbarast": "odevalverbar",
    "odevalverbaraste": "odevalverbar",
    "odevalverbarastes": "odevalverbar",
    "odevalverbarasts": "odevalverbar",
    "odevalverbare": "odevalverbar",
    "odevalverbares": "odevalverbar",
    "odevalverbarheten": "odevalverbarhet",
    "odevalverbarhetens": "odevalverbarhet",
    "odevalverbarhets": "odevalverbarhet",
    "odevalverbars": "odevalverbar",
    "odevalverbart": "odevalverbar",
    "odevalverbarts": "odevalverbar",
    "odiade": "odiad",
    "odiades": "odiad",
    "odiads": "odiad",
    "odiagnosticerade": "odiagnosticerad",
    "odiagnosticerades": "odiagnosticerad",
    "odiagnosticerads": "odiagnosticerad",
    "odiagnosticerat": "odiagnosticerad",
    "odiagnosticerats": "odiagnosticerad",
    "odiagnosticerbara": "odiagnosticerbar",
    "odiagnosticerbarare": "odiagnosticerbar",
    "odiagnosticerbarares": "odiagnosticerbar",
    "odiagnosticerbaras": "odiagnosticerbar",
    "odiagnosticerbarast": "odiagnosticerbar",
    "odiagnosticerbaraste": "odiagnosticerbar",
    "odiagnosticerbarastes": "odiagnosticerbar",
    "odiagnosticerbarasts": "odiagnosticerbar",
    "odiagnosticerbare": "odiagnosticerbar",
    "odiagnosticerbares": "odiagnosticerbar",
    "odiagnosticerbarheten": "odiagnosticerbarhet",
    "odiagnosticerbarhetens": "odiagnosticerbarhet",
    "odiagnosticerbarhets": "odiagnosticerbarhet",
    "odiagnosticerbars": "odiagnosticerbar",
    "odiagnosticerbart": "odiagnosticerbar",
    "odiagnosticerbarts": "odiagnosticerbar",
    "odiagnostiserade": "odiagnostiserad",
    "odiagnostiserades": "odiagnostiserad",
    "odiagnostiserads": "odiagnostiserad",
    "odiagnostiserat": "odiagnostiserad",
    "odiagnostiserats": "odiagnostiserad",
    "odiagnostiserbara": "odiagnostiserbar",
    "odiagnostiserbarare": "odiagnostiserbar",
    "odiagnostiserbarares": "odiagnostiserbar",
    "odiagnostiserbaras": "odiagnostiserbar",
    "odiagnostiserbarast": "odiagnostiserbar",
    "odiagnostiserbaraste": "odiagnostiserbar",
    "odiagnostiserbarastes": "odiagnostiserbar",
    "odiagnostiserbarasts": "odiagnostiserbar",
    "odiagnostiserbare": "odiagnostiserbar",
    "odiagnostiserbares": "odiagnostiserbar",
    "odiagnostiserbarheten": "odiagnostiserbarhet",
    "odiagnostiserbarhetens": "odiagnostiserbarhet",
    "odiagnostiserbarhets": "odiagnostiserbarhet",
    "odiagnostiserbars": "odiagnostiserbar",
    "odiagnostiserbart": "odiagnostiserbar",
    "odiagnostiserbarts": "odiagnostiserbar",
    "odialyserade": "odialyserad",
    "odialyserades": "odialyserad",
    "odialyserads": "odialyserad",
    "odialyserat": "odialyserad",
    "odialyserats": "odialyserad",
    "odialyserbara": "odialyserbar",
    "odialyserbarare": "odialyserbar",
    "odialyserbarares": "odialyserbar",
    "odialyserbaras": "odialyserbar",
    "odialyserbarast": "odialyserbar",
    "odialyserbaraste": "odialyserbar",
    "odialyserbarastes": "odialyserbar",
    "odialyserbarasts": "odialyserbar",
    "odialyserbare": "odialyserbar",
    "odialyserbares": "odialyserbar",
    "odialyserbarheten": "odialyserbarhet",
    "odialyserbarhetens": "odialyserbarhet",
    "odialyserbarhets": "odialyserbarhet",
    "odialyserbars": "odialyserbar",
    "odialyserbart": "odialyserbar",
    "odialyserbarts": "odialyserbar",
    "odiat": "odiad",
    "odiats": "odiad",
    "odibblade": "odibblad",
    "odibblades": "odibblad",
    "odibblads": "odibblad",
    "odibblat": "odibblad",
    "odibblats": "odibblad",
    "odifferentierade": "odifferentierad",
    "odifferentierades": "odifferentierad",
    "odifferentierads": "odifferentierad",
    "odifferentierat": "odifferentierad",
    "odifferentierats": "odifferentierad",
    "odifferentierbara": "odifferentierbar",
    "odifferentierbarare": "odifferentierbar",
    "odifferentierbarares": "odifferentierbar",
    "odifferentierbaras": "odifferentierbar",
    "odifferentierbarast": "odifferentierbar",
    "odifferentierbaraste": "odifferentierbar",
    "odifferentierbarastes": "odifferentierbar",
    "odifferentierbarasts": "odifferentierbar",
    "odifferentierbare": "odifferentierbar",
    "odifferentierbares": "odifferentierbar",
    "odifferentierbarheten": "odifferentierbarhet",
    "odifferentierbarhetens": "odifferentierbarhet",
    "odifferentierbarhets": "odifferentierbarhet",
    "odifferentierbars": "odifferentierbar",
    "odifferentierbart": "odifferentierbar",
    "odifferentierbarts": "odifferentierbar",
    "odiffunderade": "odiffunderad",
    "odiffunderades": "odiffunderad",
    "odiffunderads": "odiffunderad",
    "odiffunderat": "odiffunderad",
    "odiffunderats": "odiffunderad",
    "odiffunderbara": "odiffunderbar",
    "odiffunderbarare": "odiffunderbar",
    "odiffunderbarares": "odiffunderbar",
    "odiffunderbaras": "odiffunderbar",
    "odiffunderbarast": "odiffunderbar",
    "odiffunderbaraste": "odiffunderbar",
    "odiffunderbarastes": "odiffunderbar",
    "odiffunderbarasts": "odiffunderbar",
    "odiffunderbare": "odiffunderbar",
    "odiffunderbares": "odiffunderbar",
    "odiffunderbarheten": "odiffunderbarhet",
    "odiffunderbarhetens": "odiffunderbarhet",
    "odiffunderbarhets": "odiffunderbarhet",
    "odiffunderbars": "odiffunderbar",
    "odiffunderbart": "odiffunderbar",
    "odiffunderbarts": "odiffunderbar",
    "odiftongerade": "odiftongerad",
    "odiftongerades": "odiftongerad",
    "odiftongerads": "odiftongerad",
    "odiftongerat": "odiftongerad",
    "odiftongerats": "odiftongerad",
    "odiftongerbara": "odiftongerbar",
    "odiftongerbarare": "odiftongerbar",
    "odiftongerbarares": "odiftongerbar",
    "odiftongerbaras": "odiftongerbar",
    "odiftongerbarast": "odiftongerbar",
    "odiftongerbaraste": "odiftongerbar",
    "odiftongerbarastes": "odiftongerbar",
    "odiftongerbarasts": "odiftongerbar",
    "odiftongerbare": "odiftongerbar",
    "odiftongerbares": "odiftongerbar",
    "odiftongerbarheten": "odiftongerbarhet",
    "odiftongerbarhetens": "odiftongerbarhet",
    "odiftongerbarhets": "odiftongerbarhet",
    "odiftongerbars": "odiftongerbar",
    "odiftongerbart": "odiftongerbar",
    "odiftongerbarts": "odiftongerbar",
    "odigererade": "odigererad",
    "odigererades": "odigererad",
    "odigererads": "odigererad",
    "odigererat": "odigererad",
    "odigererats": "odigererad",
    "odigererbara": "odigererbar",
    "odigererbarare": "odigererbar",
    "odigererbarares": "odigererbar",
    "odigererbaras": "odigererbar",
    "odigererbarast": "odigererbar",
    "odigererbaraste": "odigererbar",
    "odigererbarastes": "odigererbar",
    "odigererbarasts": "odigererbar",
    "odigererbare": "odigererbar",
    "odigererbares": "odigererbar",
    "odigererbarheten": "odigererbarhet",
    "odigererbarhetens": "odigererbarhet",
    "odigererbarhets": "odigererbarhet",
    "odigererbars": "odigererbar",
    "odigererbart": "odigererbar",
    "odigererbarts": "odigererbar",
    "odiggade": "odiggad",
    "odiggades": "odiggad",
    "odiggads": "odiggad",
    "odiggat": "odiggad",
    "odiggats": "odiggad",
    "odikade": "odikad",
    "odikades": "odikad",
    "odikads": "odikad",
    "odikat": "odikad",
    "odikats": "odikad",
    "odiktade": "odiktad",
    "odiktades": "odiktad",
    "odiktads": "odiktad",
    "odiktat": "odiktad",
    "odiktats": "odiktad",
    "odikterade": "odikterad",
    "odikterades": "odikterad",
    "odikterads": "odikterad",
    "odikterat": "odikterad",
    "odikterats": "odikterad",
    "odikterbara": "odikterbar",
    "odikterbarare": "odikterbar",
    "odikterbarares": "odikterbar",
    "odikterbaras": "odikterbar",
    "odikterbarast": "odikterbar",
    "odikterbaraste": "odikterbar",
    "odikterbarastes": "odikterbar",
    "odikterbarasts": "odikterbar",
    "odikterbare": "odikterbar",
    "odikterbares": "odikterbar",
    "odikterbarheten": "odikterbarhet",
    "odikterbarhetens": "odikterbarhet",
    "odikterbarhets": "odikterbarhet",
    "odikterbars": "odikterbar",
    "odikterbart": "odikterbar",
    "odikterbarts": "odikterbar",
    "odimensionerade": "odimensionerad",
    "odimensionerades": "odimensionerad",
    "odimensionerads": "odimensionerad",
    "odimensionerat": "odimensionerad",
    "odimensionerats": "odimensionerad",
    "odimensionerbara": "odimensionerbar",
    "odimensionerbarare": "odimensionerbar",
    "odimensionerbarares": "odimensionerbar",
    "odimensionerbaras": "odimensionerbar",
    "odimensionerbarast": "odimensionerbar",
    "odimensionerbaraste": "odimensionerbar",
    "odimensionerbarastes": "odimensionerbar",
    "odimensionerbarasts": "odimensionerbar",
    "odimensionerbare": "odimensionerbar",
    "odimensionerbares": "odimensionerbar",
    "odimensionerbarheten": "odimensionerbarhet",
    "odimensionerbarhetens": "odimensionerbarhet",
    "odimensionerbarhets": "odimensionerbarhet",
    "odimensionerbars": "odimensionerbar",
    "odimensionerbart": "odimensionerbar",
    "odimensionerbarts": "odimensionerbar",
    "odiplomatiska": "odiplomatisk",
    "odiplomatiskare": "odiplomatisk",
    "odiplomatiskares": "odiplomatisk",
    "odiplomatiskas": "odiplomatisk",
    "odiplomatiskast": "odiplomatisk",
    "odiplomatiskaste": "odiplomatisk",
    "odiplomatiskastes": "odiplomatisk",
    "odiplomatiskasts": "odiplomatisk",
    "odiplomatiske": "odiplomatisk",
    "odiplomatiskes": "odiplomatisk",
    "odiplomatisks": "odiplomatisk",
    "odiplomatiskt": "odiplomatisk",
    "odiplomatiskts": "odiplomatisk",
    "odiplomerade": "odiplomerad",
    "odiplomerades": "odiplomerad",
    "odiplomerads": "odiplomerad",
    "odiplomerat": "odiplomerad",
    "odiplomerats": "odiplomerad",
    "odiplomerbara": "odiplomerbar",
    "odiplomerbarare": "odiplomerbar",
    "odiplomerbarares": "odiplomerbar",
    "odiplomerbaras": "odiplomerbar",
    "odiplomerbarast": "odiplomerbar",
    "odiplomerbaraste": "odiplomerbar",
    "odiplomerbarastes": "odiplomerbar",
    "odiplomerbarasts": "odiplomerbar",
    "odiplomerbare": "odiplomerbar",
    "odiplomerbares": "odiplomerbar",
    "odiplomerbarheten": "odiplomerbarhet",
    "odiplomerbarhetens": "odiplomerbarhet",
    "odiplomerbarhets": "odiplomerbarhet",
    "odiplomerbars": "odiplomerbar",
    "odiplomerbart": "odiplomerbar",
    "odiplomerbarts": "odiplomerbar",
    "odippade": "odippad",
    "odippades": "odippad",
    "odippads": "odippad",
    "odippat": "odippad",
    "odippats": "odippad",
    "odirigerade": "odirigerad",
    "odirigerades": "odirigerad",
    "odirigerads": "odirigerad",
    "odirigerat": "odirigerad",
    "odirigerats": "odirigerad",
    "odirigerbara": "odirigerbar",
    "odirigerbarare": "odirigerbar",
    "odirigerbarares": "odirigerbar",
    "odirigerbaras": "odirigerbar",
    "odirigerbarast": "odirigerbar",
    "odirigerbaraste": "odirigerbar",
    "odirigerbarastes": "odirigerbar",
    "odirigerbarasts": "odirigerbar",
    "odirigerbare": "odirigerbar",
    "odirigerbares": "odirigerbar",
    "odirigerbarheten": "odirigerbarhet",
    "odirigerbarhetens": "odirigerbarhet",
    "odirigerbarhets": "odirigerbarhet",
    "odirigerbars": "odirigerbar",
    "odirigerbart": "odirigerbar",
    "odirigerbarts": "odirigerbar",
    "odisambiguerade": "odisambiguerad",
    "odisambiguerades": "odisambiguerad",
    "odisambiguerads": "odisambiguerad",
    "odisambiguerat": "odisambiguerad",
    "odisambiguerats": "odisambiguerad",
    "odisambiguerbara": "odisambiguerbar",
    "odisambiguerbarare": "odisambiguerbar",
    "odisambiguerbarares": "odisambiguerbar",
    "odisambiguerbaras": "odisambiguerbar",
    "odisambiguerbarast": "odisambiguerbar",
    "odisambiguerbaraste": "odisambiguerbar",
    "odisambiguerbarastes": "odisambiguerbar",
    "odisambiguerbarasts": "odisambiguerbar",
    "odisambiguerbare": "odisambiguerbar",
    "odisambiguerbares": "odisambiguerbar",
    "odisambiguerbarheten": "odisambiguerbarhet",
    "odisambiguerbarhetens": "odisambiguerbarhet",
    "odisambiguerbarhets": "odisambiguerbarhet",
    "odisambiguerbars": "odisambiguerbar",
    "odisambiguerbart": "odisambiguerbar",
    "odisambiguerbarts": "odisambiguerbar",
    "odisciplinerade": "odisciplinerad",
    "odisciplinerades": "odisciplinerad",
    "odisciplinerads": "odisciplinerad",
    "odisciplinerat": "odisciplinerad",
    "odisciplinerats": "odisciplinerad",
    "odisciplinerbara": "odisciplinerbar",
    "odisciplinerbarare": "odisciplinerbar",
    "odisciplinerbarares": "odisciplinerbar",
    "odisciplinerbaras": "odisciplinerbar",
    "odisciplinerbarast": "odisciplinerbar",
    "odisciplinerbaraste": "odisciplinerbar",
    "odisciplinerbarastes": "odisciplinerbar",
    "odisciplinerbarasts": "odisciplinerbar",
    "odisciplinerbare": "odisciplinerbar",
    "odisciplinerbares": "odisciplinerbar",
    "odisciplinerbarheten": "odisciplinerbarhet",
    "odisciplinerbarhetens": "odisciplinerbarhet",
    "odisciplinerbarhets": "odisciplinerbarhet",
    "odisciplinerbars": "odisciplinerbar",
    "odisciplinerbart": "odisciplinerbar",
    "odisciplinerbarts": "odisciplinerbar",
    "odisharmonierade": "odisharmonierad",
    "odisharmonierades": "odisharmonierad",
    "odisharmonierads": "odisharmonierad",
    "odisharmonierat": "odisharmonierad",
    "odisharmonierats": "odisharmonierad",
    "odisharmonierbara": "odisharmonierbar",
    "odisharmonierbarare": "odisharmonierbar",
    "odisharmonierbarares": "odisharmonierbar",
    "odisharmonierbaras": "odisharmonierbar",
    "odisharmonierbarast": "odisharmonierbar",
    "odisharmonierbaraste": "odisharmonierbar",
    "odisharmonierbarastes": "odisharmonierbar",
    "odisharmonierbarasts": "odisharmonierbar",
    "odisharmonierbare": "odisharmonierbar",
    "odisharmonierbares": "odisharmonierbar",
    "odisharmonierbarheten": "odisharmonierbarhet",
    "odisharmonierbarhetens": "odisharmonierbarhet",
    "odisharmonierbarhets": "odisharmonierbarhet",
    "odisharmonierbars": "odisharmonierbar",
    "odisharmonierbart": "odisharmonierbar",
    "odisharmonierbarts": "odisharmonierbar",
    "odiskade": "odiskad",
    "odiskades": "odiskad",
    "odiskads": "odiskad",
    "odiskat": "odiskad",
    "odiskats": "odiskad",
    "odiskonterade": "odiskonterad",
    "odiskonterades": "odiskonterad",
    "odiskonterads": "odiskonterad",
    "odiskonterat": "odiskonterad",
    "odiskonterats": "odiskonterad",
    "odiskonterbara": "odiskonterbar",
    "odiskonterbarare": "odiskonterbar",
    "odiskonterbarares": "odiskonterbar",
    "odiskonterbaras": "odiskonterbar",
    "odiskonterbarast": "odiskonterbar",
    "odiskonterbaraste": "odiskonterbar",
    "odiskonterbarastes": "odiskonterbar",
    "odiskonterbarasts": "odiskonterbar",
    "odiskonterbare": "odiskonterbar",
    "odiskonterbares": "odiskonterbar",
    "odiskonterbarheten": "odiskonterbarhet",
    "odiskonterbarhetens": "odiskonterbarhet",
    "odiskonterbarhets": "odiskonterbarhet",
    "odiskonterbars": "odiskonterbar",
    "odiskonterbart": "odiskonterbar",
    "odiskonterbarts": "odiskonterbar",
    "odiskrediterade": "odiskrediterad",
    "odiskrediterades": "odiskrediterad",
    "odiskrediterads": "odiskrediterad",
    "odiskrediterat": "odiskrediterad",
    "odiskrediterats": "odiskrediterad",
    "odiskrediterbara": "odiskrediterbar",
    "odiskrediterbarare": "odiskrediterbar",
    "odiskrediterbarares": "odiskrediterbar",
    "odiskrediterbaras": "odiskrediterbar",
    "odiskrediterbarast": "odiskrediterbar",
    "odiskrediterbaraste": "odiskrediterbar",
    "odiskrediterbarastes": "odiskrediterbar",
    "odiskrediterbarasts": "odiskrediterbar",
    "odiskrediterbare": "odiskrediterbar",
    "odiskrediterbares": "odiskrediterbar",
    "odiskrediterbarheten": "odiskrediterbarhet",
    "odiskrediterbarhetens": "odiskrediterbarhet",
    "odiskrediterbarhets": "odiskrediterbarhet",
    "odiskrediterbars": "odiskrediterbar",
    "odiskrediterbart": "odiskrediterbar",
    "odiskrediterbarts": "odiskrediterbar",
    "odiskriminerade": "odiskriminerad",
    "odiskriminerades": "odiskriminerad",
    "odiskriminerads": "odiskriminerad",
    "odiskriminerat": "odiskriminerad",
    "odiskriminerats": "odiskriminerad",
    "odiskriminerbara": "odiskriminerbar",
    "odiskriminerbarare": "odiskriminerbar",
    "odiskriminerbarares": "odiskriminerbar",
    "odiskriminerbaras": "odiskriminerbar",
    "odiskriminerbarast": "odiskriminerbar",
    "odiskriminerbaraste": "odiskriminerbar",
    "odiskriminerbarastes": "odiskriminerbar",
    "odiskriminerbarasts": "odiskriminerbar",
    "odiskriminerbare": "odiskriminerbar",
    "odiskriminerbares": "odiskriminerbar",
    "odiskriminerbarheten": "odiskriminerbarhet",
    "odiskriminerbarhetens": "odiskriminerbarhet",
    "odiskriminerbarhets": "odiskriminerbarhet",
    "odiskriminerbars": "odiskriminerbar",
    "odiskriminerbart": "odiskriminerbar",
    "odiskriminerbarts": "odiskriminerbar",
    "odiskutabels": "odiskutabel",
    "odiskutabelt": "odiskutabel",
    "odiskutabelts": "odiskutabel",
    "odiskutabla": "odiskutabel",
    "odiskutablare": "odiskutabel",
    "odiskutablares": "odiskutabel",
    "odiskutablas": "odiskutabel",
    "odiskutablast": "odiskutabel",
    "odiskutablaste": "odiskutabel",
    "odiskutablastes": "odiskutabel",
    "odiskutablasts": "odiskutabel",
    "odiskutable": "odiskutabel",
    "odiskutables": "odiskutabel",
    "odiskuterade": "odiskuterad",
    "odiskuterades": "odiskuterad",
    "odiskuterads": "odiskuterad",
    "odiskuterat": "odiskuterad",
    "odiskuterats": "odiskuterad",
    "odiskuterbara": "odiskuterbar",
    "odiskuterbarare": "odiskuterbar",
    "odiskuterbarares": "odiskuterbar",
    "odiskuterbaras": "odiskuterbar",
    "odiskuterbarast": "odiskuterbar",
    "odiskuterbaraste": "odiskuterbar",
    "odiskuterbarastes": "odiskuterbar",
    "odiskuterbarasts": "odiskuterbar",
    "odiskuterbare": "odiskuterbar",
    "odiskuterbares": "odiskuterbar",
    "odiskuterbarheten": "odiskuterbarhet",
    "odiskuterbarhetens": "odiskuterbarhet",
    "odiskuterbarhets": "odiskuterbarhet",
    "odiskuterbars": "odiskuterbar",
    "odiskuterbart": "odiskuterbar",
    "odiskuterbarts": "odiskuterbar",
    "odiskvalificerade": "odiskvalificerad",
    "odiskvalificerades": "odiskvalificerad",
    "odiskvalificerads": "odiskvalificerad",
    "odiskvalificerat": "odiskvalificerad",
    "odiskvalificerats": "odiskvalificerad",
    "odiskvalificerbara": "odiskvalificerbar",
    "odiskvalificerbarare": "odiskvalificerbar",
    "odiskvalificerbarares": "odiskvalificerbar",
    "odiskvalificerbaras": "odiskvalificerbar",
    "odiskvalificerbarast": "odiskvalificerbar",
    "odiskvalificerbaraste": "odiskvalificerbar",
    "odiskvalificerbarastes": "odiskvalificerbar",
    "odiskvalificerbarasts": "odiskvalificerbar",
    "odiskvalificerbare": "odiskvalificerbar",
    "odiskvalificerbares": "odiskvalificerbar",
    "odiskvalificerbarheten": "odiskvalificerbarhet",
    "odiskvalificerbarhetens": "odiskvalificerbarhet",
    "odiskvalificerbarhets": "odiskvalificerbarhet",
    "odiskvalificerbars": "odiskvalificerbar",
    "odiskvalificerbart": "odiskvalificerbar",
    "odiskvalificerbarts": "odiskvalificerbar",
    "odispascherade": "odispascherad",
    "odispascherades": "odispascherad",
    "odispascherads": "odispascherad",
    "odispascherat": "odispascherad",
    "odispascherats": "odispascherad",
    "odispascherbara": "odispascherbar",
    "odispascherbarare": "odispascherbar",
    "odispascherbarares": "odispascherbar",
    "odispascherbaras": "odispascherbar",
    "odispascherbarast": "odispascherbar",
    "odispascherbaraste": "odispascherbar",
    "odispascherbarastes": "odispascherbar",
    "odispascherbarasts": "odispascherbar",
    "odispascherbare": "odispascherbar",
    "odispascherbares": "odispascherbar",
    "odispascherbarheten": "odispascherbarhet",
    "odispascherbarhetens": "odispascherbarhet",
    "odispascherbarhets": "odispascherbarhet",
    "odispascherbars": "odispascherbar",
    "odispascherbart": "odispascherbar",
    "odispascherbarts": "odispascherbar",
    "odispenserade": "odispenserad",
    "odispenserades": "odispenserad",
    "odispenserads": "odispenserad",
    "odispenserat": "odispenserad",
    "odispenserats": "odispenserad",
    "odispenserbara": "odispenserbar",
    "odispenserbarare": "odispenserbar",
    "odispenserbarares": "odispenserbar",
    "odispenserbaras": "odispenserbar",
    "odispenserbarast": "odispenserbar",
    "odispenserbaraste": "odispenserbar",
    "odispenserbarastes": "odispenserbar",
    "odispenserbarasts": "odispenserbar",
    "odispenserbare": "odispenserbar",
    "odispenserbares": "odispenserbar",
    "odispenserbarheten": "odispenserbarhet",
    "odispenserbarhetens": "odispenserbarhet",
    "odispenserbarhets": "odispenserbarhet",
    "odispenserbars": "odispenserbar",
    "odispenserbart": "odispenserbar",
    "odispenserbarts": "odispenserbar",
    "odispergerade": "odispergerad",
    "odispergerades": "odispergerad",
    "odispergerads": "odispergerad",
    "odispergerat": "odispergerad",
    "odispergerats": "odispergerad",
    "odispergerbara": "odispergerbar",
    "odispergerbarare": "odispergerbar",
    "odispergerbarares": "odispergerbar",
    "odispergerbaras": "odispergerbar",
    "odispergerbarast": "odispergerbar",
    "odispergerbaraste": "odispergerbar",
    "odispergerbarastes": "odispergerbar",
    "odispergerbarasts": "odispergerbar",
    "odispergerbare": "odispergerbar",
    "odispergerbares": "odispergerbar",
    "odispergerbarheten": "odispergerbarhet",
    "odispergerbarhetens": "odispergerbarhet",
    "odispergerbarhets": "odispergerbarhet",
    "odispergerbars": "odispergerbar",
    "odispergerbart": "odispergerbar",
    "odispergerbarts": "odispergerbar",
    "odisponerade": "odisponerad",
    "odisponerades": "odisponerad",
    "odisponerads": "odisponerad",
    "odisponerat": "odisponerad",
    "odisponerats": "odisponerad",
    "odisponerbara": "odisponerbar",
    "odisponerbarare": "odisponerbar",
    "odisponerbarares": "odisponerbar",
    "odisponerbaras": "odisponerbar",
    "odisponerbarast": "odisponerbar",
    "odisponerbaraste": "odisponerbar",
    "odisponerbarastes": "odisponerbar",
    "odisponerbarasts": "odisponerbar",
    "odisponerbare": "odisponerbar",
    "odisponerbares": "odisponerbar",
    "odisponerbarheten": "odisponerbarhet",
    "odisponerbarhetens": "odisponerbarhet",
    "odisponerbarhets": "odisponerbarhet",
    "odisponerbars": "odisponerbar",
    "odisponerbart": "odisponerbar",
    "odisponerbarts": "odisponerbar",
    "odisputabels": "odisputabel",
    "odisputabelt": "odisputabel",
    "odisputabelts": "odisputabel",
    "odisputabla": "odisputabel",
    "odisputablare": "odisputabel",
    "odisputablares": "odisputabel",
    "odisputablas": "odisputabel",
    "odisputablast": "odisputabel",
    "odisputablaste": "odisputabel",
    "odisputablastes": "odisputabel",
    "odisputablasts": "odisputabel",
    "odisputable": "odisputabel",
    "odisputables": "odisputabel",
    "odisputerade": "odisputerad",
    "odisputerades": "odisputerad",
    "odisputerads": "odisputerad",
    "odisputerat": "odisputerad",
    "odisputerats": "odisputerad",
    "odisputerbara": "odisputerbar",
    "odisputerbarare": "odisputerbar",
    "odisputerbarares": "odisputerbar",
    "odisputerbaras": "odisputerbar",
    "odisputerbarast": "odisputerbar",
    "odisputerbaraste": "odisputerbar",
    "odisputerbarastes": "odisputerbar",
    "odisputerbarasts": "odisputerbar",
    "odisputerbare": "odisputerbar",
    "odisputerbares": "odisputerbar",
    "odisputerbarheten": "odisputerbarhet",
    "odisputerbarhetens": "odisputerbarhet",
    "odisputerbarhets": "odisputerbarhet",
    "odisputerbars": "odisputerbar",
    "odisputerbart": "odisputerbar",
    "odisputerbarts": "odisputerbar",
    "odissade": "odissad",
    "odissades": "odissad",
    "odissads": "odissad",
    "odissat": "odissad",
    "odissats": "odissad",
    "odissekerade": "odissekerad",
    "odissekerades": "odissekerad",
    "odissekerads": "odissekerad",
    "odissekerat": "odissekerad",
    "odissekerats": "odissekerad",
    "odissekerbara": "odissekerbar",
    "odissekerbarare": "odissekerbar",
    "odissekerbarares": "odissekerbar",
    "odissekerbaras": "odissekerbar",
    "odissekerbarast": "odissekerbar",
    "odissekerbaraste": "odissekerbar",
    "odissekerbarastes": "odissekerbar",
    "odissekerbarasts": "odissekerbar",
    "odissekerbare": "odissekerbar",
    "odissekerbares": "odissekerbar",
    "odissekerbarheten": "odissekerbarhet",
    "odissekerbarhetens": "odissekerbarhet",
    "odissekerbarhets": "odissekerbarhet",
    "odissekerbars": "odissekerbar",
    "odissekerbart": "odissekerbar",
    "odissekerbarts": "odissekerbar",
    "odissimilerade": "odissimilerad",
    "odissimilerades": "odissimilerad",
    "odissimilerads": "odissimilerad",
    "odissimilerat": "odissimilerad",
    "odissimilerats": "odissimilerad",
    "odissimilerbara": "odissimilerbar",
    "odissimilerbarare": "odissimilerbar",
    "odissimilerbarares": "odissimilerbar",
    "odissimilerbaras": "odissimilerbar",
    "odissimilerbarast": "odissimilerbar",
    "odissimilerbaraste": "odissimilerbar",
    "odissimilerbarastes": "odissimilerbar",
    "odissimilerbarasts": "odissimilerbar",
    "odissimilerbare": "odissimilerbar",
    "odissimilerbares": "odissimilerbar",
    "odissimilerbarheten": "odissimilerbarhet",
    "odissimilerbarhetens": "odissimilerbarhet",
    "odissimilerbarhets": "odissimilerbarhet",
    "odissimilerbars": "odissimilerbar",
    "odissimilerbart": "odissimilerbar",
    "odissimilerbarts": "odissimilerbar",
    "odissocierade": "odissocierad",
    "odissocierades": "odissocierad",
    "odissocierads": "odissocierad",
    "odissocierat": "odissocierad",
    "odissocierats": "odissocierad",
    "odissocierbara": "odissocierbar",
    "odissocierbarare": "odissocierbar",
    "odissocierbarares": "odissocierbar",
    "odissocierbaras": "odissocierbar",
    "odissocierbarast": "odissocierbar",
    "odissocierbaraste": "odissocierbar",
    "odissocierbarastes": "odissocierbar",
    "odissocierbarasts": "odissocierbar",
    "odissocierbare": "odissocierbar",
    "odissocierbares": "odissocierbar",
    "odissocierbarheten": "odissocierbarhet",
    "odissocierbarhetens": "odissocierbarhet",
    "odissocierbarhets": "odissocierbarhet",
    "odissocierbars": "odissocierbar",
    "odissocierbart": "odissocierbar",
    "odissocierbarts": "odissocierbar",
    "odistanserade": "odistanserad",
    "odistanserades": "odistanserad",
    "odistanserads": "odistanserad",
    "odistanserat": "odistanserad",
    "odistanserats": "odistanserad",
    "odistanserbara": "odistanserbar",
    "odistanserbarare": "odistanserbar",
    "odistanserbarares": "odistanserbar",
    "odistanserbaras": "odistanserbar",
    "odistanserbarast": "odistanserbar",
    "odistanserbaraste": "odistanserbar",
    "odistanserbarastes": "odistanserbar",
    "odistanserbarasts": "odistanserbar",
    "odistanserbare": "odistanserbar",
    "odistanserbares": "odistanserbar",
    "odistanserbarheten": "odistanserbarhet",
    "odistanserbarhetens": "odistanserbarhet",
    "odistanserbarhets": "odistanserbarhet",
    "odistanserbars": "odistanserbar",
    "odistanserbart": "odistanserbar",
    "odistanserbarts": "odistanserbar",
    "odistraherade": "odistraherad",
    "odistraherades": "odistraherad",
    "odistraherads": "odistraherad",
    "odistraherat": "odistraherad",
    "odistraherats": "odistraherad",
    "odistraherbara": "odistraherbar",
    "odistraherbarare": "odistraherbar",
    "odistraherbarares": "odistraherbar",
    "odistraherbaras": "odistraherbar",
    "odistraherbarast": "odistraherbar",
    "odistraherbaraste": "odistraherbar",
    "odistraherbarastes": "odistraherbar",
    "odistraherbarasts": "odistraherbar",
    "odistraherbare": "odistraherbar",
    "odistraherbares": "odistraherbar",
    "odistraherbarheten": "odistraherbarhet",
    "odistraherbarhetens": "odistraherbarhet",
    "odistraherbarhets": "odistraherbarhet",
    "odistraherbars": "odistraherbar",
    "odistraherbart": "odistraherbar",
    "odistraherbarts": "odistraherbar",
    "odistribuerade": "odistribuerad",
    "odistribuerades": "odistribuerad",
    "odistribuerads": "odistribuerad",
    "odistribuerat": "odistribuerad",
    "odistribuerats": "odistribuerad",
    "odistribuerbara": "odistribuerbar",
    "odistribuerbarare": "odistribuerbar",
    "odistribuerbarares": "odistribuerbar",
    "odistribuerbaras": "odistribuerbar",
    "odistribuerbarast": "odistribuerbar",
    "odistribuerbaraste": "odistribuerbar",
    "odistribuerbarastes": "odistribuerbar",
    "odistribuerbarasts": "odistribuerbar",
    "odistribuerbare": "odistribuerbar",
    "odistribuerbares": "odistribuerbar",
    "odistribuerbarheten": "odistribuerbarhet",
    "odistribuerbarhetens": "odistribuerbarhet",
    "odistribuerbarhets": "odistribuerbarhet",
    "odistribuerbars": "odistribuerbar",
    "odistribuerbart": "odistribuerbar",
    "odistribuerbarts": "odistribuerbar",
    "odivergerade": "odivergerad",
    "odivergerades": "odivergerad",
    "odivergerads": "odivergerad",
    "odivergerat": "odivergerad",
    "odivergerats": "odivergerad",
    "odivergerbara": "odivergerbar",
    "odivergerbarare": "odivergerbar",
    "odivergerbarares": "odivergerbar",
    "odivergerbaras": "odivergerbar",
    "odivergerbarast": "odivergerbar",
    "odivergerbaraste": "odivergerbar",
    "odivergerbarastes": "odivergerbar",
    "odivergerbarasts": "odivergerbar",
    "odivergerbare": "odivergerbar",
    "odivergerbares": "odivergerbar",
    "odivergerbarheten": "odivergerbarhet",
    "odivergerbarhetens": "odivergerbarhet",
    "odivergerbarhets": "odivergerbarhet",
    "odivergerbars": "odivergerbar",
    "odivergerbart": "odivergerbar",
    "odivergerbarts": "odivergerbar",
    "odiversifierade": "odiversifierad",
    "odiversifierades": "odiversifierad",
    "odiversifierads": "odiversifierad",
    "odiversifierat": "odiversifierad",
    "odiversifierats": "odiversifierad",
    "odiversifierbara": "odiversifierbar",
    "odiversifierbarare": "odiversifierbar",
    "odiversifierbarares": "odiversifierbar",
    "odiversifierbaras": "odiversifierbar",
    "odiversifierbarast": "odiversifierbar",
    "odiversifierbaraste": "odiversifierbar",
    "odiversifierbarastes": "odiversifierbar",
    "odiversifierbarasts": "odiversifierbar",
    "odiversifierbare": "odiversifierbar",
    "odiversifierbares": "odiversifierbar",
    "odiversifierbarheten": "odiversifierbarhet",
    "odiversifierbarhetens": "odiversifierbarhet",
    "odiversifierbarhets": "odiversifierbarhet",
    "odiversifierbars": "odiversifierbar",
    "odiversifierbart": "odiversifierbar",
    "odiversifierbarts": "odiversifierbar",
    "odividerade": "odividerad",
    "odividerades": "odividerad",
    "odividerads": "odividerad",
    "odividerat": "odividerad",
    "odividerats": "odividerad",
    "odividerbara": "odividerbar",
    "odividerbarare": "odividerbar",
    "odividerbarares": "odividerbar",
    "odividerbaras": "odividerbar",
    "odividerbarast": "odividerbar",
    "odividerbaraste": "odividerbar",
    "odividerbarastes": "odividerbar",
    "odividerbarasts": "odividerbar",
    "odividerbare": "odividerbar",
    "odividerbares": "odividerbar",
    "odividerbarheten": "odividerbarhet",
    "odividerbarhetens": "odividerbarhet",
    "odividerbarhets": "odividerbarhet",
    "odividerbars": "odividerbar",
    "odividerbart": "odividerbar",
    "odividerbarts": "odividerbar",
    "odiösa": "odiös",
    "odiösare": "odiös",
    "odiösares": "odiös",
    "odiösas": "odiös",
    "odiösast": "odiös",
    "odiösaste": "odiös",
    "odiösastes": "odiös",
    "odiösasts": "odiös",
    "odiöse": "odiös",
    "odiöses": "odiös",
    "odiöst": "odiös",
    "odiösts": "odiös",
    "odjuren": "odjur",
    "odjurens": "odjur",
    "odjuret": "odjur",
    "odjurets": "odjur",
    "odjurs": "odjur",
    "odlad": "odla",
    "odlade": "odla",
    "odlades": "odla",
    "odlads": "odla",
    "odlande": "odla",
    "odlanden": "odlande",
    "odlandena": "odlande",
    "odlandenas": "odlande",
    "odlandens": "odlande",
    "odlandes": "odlande",
    "odlandet": "odlande",
    "odlandets": "odlande",
    "odlar": "odlare",
    "odlaren": "odlare",
    "odlarens": "odlare",
    "odlares": "odlare",
    "odlarna": "odlare",
    "odlarnas": "odlare",
    "odlas": "odla",
    "odlat": "odla",
    "odlats": "odla",
    "odlingar": "odling",
    "odlingarna": "odling",
    "odlingarnas": "odling",
    "odlingars": "odling",
    "odlingen": "odling",
    "odlingens": "odling",
    "odlings": "odling",
    "odlingsbara": "odlingsbar",
    "odlingsbarare": "odlingsbar",
    "odlingsbarares": "odlingsbar",
    "odlingsbaras": "odlingsbar",
    "odlingsbarast": "odlingsbar",
    "odlingsbaraste": "odlingsbar",
    "odlingsbarastes": "odlingsbar",
    "odlingsbarasts": "odlingsbar",
    "odlingsbare": "odlingsbar",
    "odlingsbares": "odlingsbar",
    "odlingsbarheten": "odlingsbarhet",
    "odlingsbarhetens": "odlingsbarhet",
    "odlingsbarhets": "odlingsbarhet",
    "odlingsbars": "odlingsbar",
    "odlingsbart": "odlingsbar",
    "odlingsbarts": "odlingsbar",
    "odlingsförsöken": "odlingsförsök",
    "odlingsförsökens": "odlingsförsök",
    "odlingsförsöket": "odlingsförsök",
    "odlingsförsökets": "odlingsförsök",
    "odlingsförsöks": "odlingsförsök",
    "odlingsgränsen": "odlingsgräns",
    "odlingsgränsens": "odlingsgräns",
    "odlingsgränser": "odlingsgräns",
    "odlingsgränserna": "odlingsgräns",
    "odlingsgränsernas": "odlingsgräns",
    "odlingsgränsers": "odlingsgräns",
    "odlingslagerna": "odlingslager",
    "odlingslagernas": "odlingslager",
    "odlingslagers": "odlingslager",
    "odlingslagren": "odlingslager",
    "odlingslagrens": "odlingslager",
    "odlingslagret": "odlingslager",
    "odlingslagrets": "odlingslager",
    "odlingssäsongen": "odlingssäsong",
    "odlingssäsongens": "odlingssäsong",
    "odlingssäsonger": "odlingssäsong",
    "odlingssäsongerna": "odlingssäsong",
    "odlingssäsongernas": "odlingssäsong",
    "odlingssäsongers": "odlingssäsong",
    "odlingssäsongs": "odlingssäsong",
    "odlingsvärdes": "odlingsvärde",
    "odlingsvärdet": "odlingsvärde",
    "odlingsvärdets": "odlingsvärde",
    "odocerade": "odocerad",
    "odocerades": "odocerad",
    "odocerads": "odocerad",
    "odocerat": "odocerad",
    "odocerats": "odocerad",
    "odocerbara": "odocerbar",
    "odocerbarare": "odocerbar",
    "odocerbarares": "odocerbar",
    "odocerbaras": "odocerbar",
    "odocerbarast": "odocerbar",
    "odocerbaraste": "odocerbar",
    "odocerbarastes": "odocerbar",
    "odocerbarasts": "odocerbar",
    "odocerbare": "odocerbar",
    "odocerbares": "odocerbar",
    "odocerbarheten": "odocerbarhet",
    "odocerbarhetens": "odocerbarhet",
    "odocerbarhets": "odocerbarhet",
    "odocerbars": "odocerbar",
    "odocerbart": "odocerbar",
    "odocerbarts": "odocerbar",
    "odockade": "odockad",
    "odockades": "odockad",
    "odockads": "odockad",
    "odockat": "odockad",
    "odockats": "odockad",
    "odogmatiserade": "odogmatiserad",
    "odogmatiserades": "odogmatiserad",
    "odogmatiserads": "odogmatiserad",
    "odogmatiserat": "odogmatiserad",
    "odogmatiserats": "odogmatiserad",
    "odogmatiserbara": "odogmatiserbar",
    "odogmatiserbarare": "odogmatiserbar",
    "odogmatiserbarares": "odogmatiserbar",
    "odogmatiserbaras": "odogmatiserbar",
    "odogmatiserbarast": "odogmatiserbar",
    "odogmatiserbaraste": "odogmatiserbar",
    "odogmatiserbarastes": "odogmatiserbar",
    "odogmatiserbarasts": "odogmatiserbar",
    "odogmatiserbare": "odogmatiserbar",
    "odogmatiserbares": "odogmatiserbar",
    "odogmatiserbarheten": "odogmatiserbarhet",
    "odogmatiserbarhetens": "odogmatiserbarhet",
    "odogmatiserbarhets": "odogmatiserbarhet",
    "odogmatiserbars": "odogmatiserbar",
    "odogmatiserbart": "odogmatiserbar",
    "odogmatiserbarts": "odogmatiserbar",
    "odogmatiska": "odogmatisk",
    "odogmatiskare": "odogmatisk",
    "odogmatiskares": "odogmatisk",
    "odogmatiskas": "odogmatisk",
    "odogmatiskast": "odogmatisk",
    "odogmatiskaste": "odogmatisk",
    "odogmatiskastes": "odogmatisk",
    "odogmatiskasts": "odogmatisk",
    "odogmatiske": "odogmatisk",
    "odogmatiskes": "odogmatisk",
    "odogmatisks": "odogmatisk",
    "odogmatiskt": "odogmatisk",
    "odogmatiskts": "odogmatisk",
    "odoktorerade": "odoktorerad",
    "odoktorerades": "odoktorerad",
    "odoktorerads": "odoktorerad",
    "odoktorerat": "odoktorerad",
    "odoktorerats": "odoktorerad",
    "odokumenterade": "odokumenterad",
    "odokumenterades": "odokumenterad",
    "odokumenterads": "odokumenterad",
    "odokumenterat": "odokumenterad",
    "odokumenterats": "odokumenterad",
    "odokumenterbara": "odokumenterbar",
    "odokumenterbarare": "odokumenterbar",
    "odokumenterbarares": "odokumenterbar",
    "odokumenterbaras": "odokumenterbar",
    "odokumenterbarast": "odokumenterbar",
    "odokumenterbaraste": "odokumenterbar",
    "odokumenterbarastes": "odokumenterbar",
    "odokumenterbarasts": "odokumenterbar",
    "odokumenterbare": "odokumenterbar",
    "odokumenterbares": "odokumenterbar",
    "odokumenterbarheten": "odokumenterbarhet",
    "odokumenterbarhetens": "odokumenterbarhet",
    "odokumenterbarhets": "odokumenterbarhet",
    "odokumenterbars": "odokumenterbar",
    "odokumenterbart": "odokumenterbar",
    "odokumenterbarts": "odokumenterbar",
    "odomesticerade": "odomesticerad",
    "odomesticerades": "odomesticerad",
    "odomesticerads": "odomesticerad",
    "odomesticerat": "odomesticerad",
    "odomesticerats": "odomesticerad",
    "odomesticerbara": "odomesticerbar",
    "odomesticerbarare": "odomesticerbar",
    "odomesticerbarares": "odomesticerbar",
    "odomesticerbaras": "odomesticerbar",
    "odomesticerbarast": "odomesticerbar",
    "odomesticerbaraste": "odomesticerbar",
    "odomesticerbarastes": "odomesticerbar",
    "odomesticerbarasts": "odomesticerbar",
    "odomesticerbare": "odomesticerbar",
    "odomesticerbares": "odomesticerbar",
    "odomesticerbarheten": "odomesticerbarhet",
    "odomesticerbarhetens": "odomesticerbarhet",
    "odomesticerbarhets": "odomesticerbarhet",
    "odomesticerbars": "odomesticerbar",
    "odomesticerbart": "odomesticerbar",
    "odomesticerbarts": "odomesticerbar",
    "odomicilierade": "odomicilierad",
    "odomicilierades": "odomicilierad",
    "odomicilierads": "odomicilierad",
    "odomicilierat": "odomicilierad",
    "odomicilierats": "odomicilierad",
    "odomicilierbara": "odomicilierbar",
    "odomicilierbarare": "odomicilierbar",
    "odomicilierbarares": "odomicilierbar",
    "odomicilierbaras": "odomicilierbar",
    "odomicilierbarast": "odomicilierbar",
    "odomicilierbaraste": "odomicilierbar",
    "odomicilierbarastes": "odomicilierbar",
    "odomicilierbarasts": "odomicilierbar",
    "odomicilierbare": "odomicilierbar",
    "odomicilierbares": "odomicilierbar",
    "odomicilierbarheten": "odomicilierbarhet",
    "odomicilierbarhetens": "odomicilierbarhet",
    "odomicilierbarhets": "odomicilierbarhet",
    "odomicilierbars": "odomicilierbar",
    "odomicilierbart": "odomicilierbar",
    "odomicilierbarts": "odomicilierbar",
    "odominerade": "odominerad",
    "odominerades": "odominerad",
    "odominerads": "odominerad",
    "odominerat": "odominerad",
    "odominerats": "odominerad",
    "odominerbara": "odominerbar",
    "odominerbarare": "odominerbar",
    "odominerbarares": "odominerbar",
    "odominerbaras": "odominerbar",
    "odominerbarast": "odominerbar",
    "odominerbaraste": "odominerbar",
    "odominerbarastes": "odominerbar",
    "odominerbarasts": "odominerbar",
    "odominerbare": "odominerbar",
    "odominerbares": "odominerbar",
    "odominerbarheten": "odominerbarhet",
    "odominerbarhetens": "odominerbarhet",
    "odominerbarhets": "odominerbarhet",
    "odominerbars": "odominerbar",
    "odominerbart": "odominerbar",
    "odominerbarts": "odominerbar",
    "odomnade": "odomnad",
    "odomnades": "odomnad",
    "odomnads": "odomnad",
    "odomnat": "odomnad",
    "odomnats": "odomnad",
    "odompterade": "odompterad",
    "odompterades": "odompterad",
    "odompterads": "odompterad",
    "odompterat": "odompterad",
    "odompterats": "odompterad",
    "odompterbara": "odompterbar",
    "odompterbarare": "odompterbar",
    "odompterbarares": "odompterbar",
    "odompterbaras": "odompterbar",
    "odompterbarast": "odompterbar",
    "odompterbaraste": "odompterbar",
    "odompterbarastes": "odompterbar",
    "odompterbarasts": "odompterbar",
    "odompterbare": "odompterbar",
    "odompterbares": "odompterbar",
    "odompterbarheten": "odompterbarhet",
    "odompterbarhetens": "odompterbarhet",
    "odompterbarhets": "odompterbarhet",
    "odompterbars": "odompterbar",
    "odompterbart": "odompterbar",
    "odompterbarts": "odompterbar",
    "odonen": "odon",
    "odonens": "odon",
    "odonerade": "odonerad",
    "odonerades": "odonerad",
    "odonerads": "odonerad",
    "odonerat": "odonerad",
    "odonerats": "odonerad",
    "odonerbara": "odonerbar",
    "odonerbarare": "odonerbar",
    "odonerbarares": "odonerbar",
    "odonerbaras": "odonerbar",
    "odonerbarast": "odonerbar",
    "odonerbaraste": "odonerbar",
    "odonerbarastes": "odonerbar",
    "odonerbarasts": "odonerbar",
    "odonerbare": "odonerbar",
    "odonerbares": "odonerbar",
    "odonerbarheten": "odonerbarhet",
    "odonerbarhetens": "odonerbarhet",
    "odonerbarhets": "odonerbarhet",
    "odonerbars": "odonerbar",
    "odonerbart": "odonerbar",
    "odonerbarts": "odonerbar",
    "odonet": "odon",
    "odonets": "odon",
    "odonkade": "odonkad",
    "odonkades": "odonkad",
    "odonkads": "odonkad",
    "odonkat": "odonkad",
    "odonkats": "odonkad",
    "odons": "odon",
    "odontologen": "odontolog",
    "odontologens": "odontolog",
    "odontologer": "odontolog",
    "odontologerna": "odontolog",
    "odontologernas": "odontolog",
    "odontologers": "odontolog",
    "odontologien": "odontologi",
    "odontologiens": "odontologi",
    "odontologin": "odontologi",
    "odontologins": "odontologi",
    "odontologis": "odontologi",
    "odontologiska": "odontologisk",
    "odontologiskare": "odontologisk",
    "odontologiskares": "odontologisk",
    "odontologiskas": "odontologisk",
    "odontologiskast": "odontologisk",
    "odontologiskaste": "odontologisk",
    "odontologiskastes": "odontologisk",
    "odontologiskasts": "odontologisk",
    "odontologiske": "odontologisk",
    "odontologiskes": "odontologisk",
    "odontologisks": "odontologisk",
    "odontologiskt": "odontologisk",
    "odontologiskts": "odontologisk",
    "odontologs": "odontolog",
    "odopade": "odopad",
    "odopades": "odopad",
    "odopads": "odopad",
    "odopat": "odopad",
    "odopats": "odopad",
    "odoppade": "odoppad",
    "odoppades": "odoppad",
    "odoppads": "odoppad",
    "odoppat": "odoppad",
    "odoppats": "odoppad",
    "odoserade": "odoserad",
    "odoserades": "odoserad",
    "odoserads": "odoserad",
    "odoserat": "odoserad",
    "odoserats": "odoserad",
    "odoserbara": "odoserbar",
    "odoserbarare": "odoserbar",
    "odoserbarares": "odoserbar",
    "odoserbaras": "odoserbar",
    "odoserbarast": "odoserbar",
    "odoserbaraste": "odoserbar",
    "odoserbarastes": "odoserbar",
    "odoserbarasts": "odoserbar",
    "odoserbare": "odoserbar",
    "odoserbares": "odoserbar",
    "odoserbarheten": "odoserbarhet",
    "odoserbarhetens": "odoserbarhet",
    "odoserbarhets": "odoserbarhet",
    "odoserbars": "odoserbar",
    "odoserbart": "odoserbar",
    "odoserbarts": "odoserbar",
    "odosserade": "odosserad",
    "odosserades": "odosserad",
    "odosserads": "odosserad",
    "odosserat": "odosserad",
    "odosserats": "odosserad",
    "odosserbara": "odosserbar",
    "odosserbarare": "odosserbar",
    "odosserbarares": "odosserbar",
    "odosserbaras": "odosserbar",
    "odosserbarast": "odosserbar",
    "odosserbaraste": "odosserbar",
    "odosserbarastes": "odosserbar",
    "odosserbarasts": "odosserbar",
    "odosserbare": "odosserbar",
    "odosserbares": "odosserbar",
    "odosserbarheten": "odosserbarhet",
    "odosserbarhetens": "odosserbarhet",
    "odosserbarhets": "odosserbarhet",
    "odosserbars": "odosserbar",
    "odosserbart": "odosserbar",
    "odosserbarts": "odosserbar",
    "odoterade": "odoterad",
    "odoterades": "odoterad",
    "odoterads": "odoterad",
    "odoterat": "odoterad",
    "odoterats": "odoterad",
    "odoterbara": "odoterbar",
    "odoterbarare": "odoterbar",
    "odoterbarares": "odoterbar",
    "odoterbaras": "odoterbar",
    "odoterbarast": "odoterbar",
    "odoterbaraste": "odoterbar",
    "odoterbarastes": "odoterbar",
    "odoterbarasts": "odoterbar",
    "odoterbare": "odoterbar",
    "odoterbares": "odoterbar",
    "odoterbarheten": "odoterbarhet",
    "odoterbarhetens": "odoterbarhet",
    "odoterbarhets": "odoterbarhet",
    "odoterbars": "odoterbar",
    "odoterbart": "odoterbar",
    "odoterbarts": "odoterbar",
    "odrabbade": "odrabbad",
    "odrabbades": "odrabbad",
    "odrabbads": "odrabbad",
    "odrabbat": "odrabbad",
    "odrabbats": "odrabbad",
    "odragerade": "odragerad",
    "odragerades": "odragerad",
    "odragerads": "odragerad",
    "odragerat": "odragerad",
    "odragerats": "odragerad",
    "odragerbara": "odragerbar",
    "odragerbarare": "odragerbar",
    "odragerbarares": "odragerbar",
    "odragerbaras": "odragerbar",
    "odragerbarast": "odragerbar",
    "odragerbaraste": "odragerbar",
    "odragerbarastes": "odragerbar",
    "odragerbarasts": "odragerbar",
    "odragerbare": "odragerbar",
    "odragerbares": "odragerbar",
    "odragerbarheten": "odragerbarhet",
    "odragerbarhetens": "odragerbarhet",
    "odragerbarhets": "odragerbarhet",
    "odragerbars": "odragerbar",
    "odragerbart": "odragerbar",
    "odragerbarts": "odragerbar",
    "odraggade": "odraggad",
    "odraggades": "odraggad",
    "odraggads": "odraggad",
    "odraggat": "odraggad",
    "odraggats": "odraggad",
    "odramatiserade": "odramatiserad",
    "odramatiserades": "odramatiserad",
    "odramatiserads": "odramatiserad",
    "odramatiserat": "odramatiserad",
    "odramatiserats": "odramatiserad",
    "odramatiserbara": "odramatiserbar",
    "odramatiserbarare": "odramatiserbar",
    "odramatiserbarares": "odramatiserbar",
    "odramatiserbaras": "odramatiserbar",
    "odramatiserbarast": "odramatiserbar",
    "odramatiserbaraste": "odramatiserbar",
    "odramatiserbarastes": "odramatiserbar",
    "odramatiserbarasts": "odramatiserbar",
    "odramatiserbare": "odramatiserbar",
    "odramatiserbares": "odramatiserbar",
    "odramatiserbarheten": "odramatiserbarhet",
    "odramatiserbarhetens": "odramatiserbarhet",
    "odramatiserbarhets": "odramatiserbarhet",
    "odramatiserbars": "odramatiserbar",
    "odramatiserbart": "odramatiserbar",
    "odramatiserbarts": "odramatiserbar",
    "odramatiska": "odramatisk",
    "odramatiskare": "odramatisk",
    "odramatiskares": "odramatisk",
    "odramatiskas": "odramatisk",
    "odramatiskast": "odramatisk",
    "odramatiskaste": "odramatisk",
    "odramatiskastes": "odramatisk",
    "odramatiskasts": "odramatisk",
    "odramatiske": "odramatisk",
    "odramatiskes": "odramatisk",
    "odramatisks": "odramatisk",
    "odramatiskt": "odramatisk",
    "odramatiskts": "odramatisk",
    "odraperade": "odraperad",
    "odraperades": "odraperad",
    "odraperads": "odraperad",
    "odraperat": "odraperad",
    "odraperats": "odraperad",
    "odraperbara": "odraperbar",
    "odraperbarare": "odraperbar",
    "odraperbarares": "odraperbar",
    "odraperbaras": "odraperbar",
    "odraperbarast": "odraperbar",
    "odraperbaraste": "odraperbar",
    "odraperbarastes": "odraperbar",
    "odraperbarasts": "odraperbar",
    "odraperbare": "odraperbar",
    "odraperbares": "odraperbar",
    "odraperbarheten": "odraperbarhet",
    "odraperbarhetens": "odraperbarhet",
    "odraperbarhets": "odraperbarhet",
    "odraperbars": "odraperbar",
    "odraperbart": "odraperbar",
    "odraperbarts": "odraperbar",
    "odrattade": "odrattad",
    "odrattades": "odrattad",
    "odrattads": "odrattad",
    "odrattat": "odrattad",
    "odrattats": "odrattad",
    "odrejade": "odrejad",
    "odrejades": "odrejad",
    "odrejads": "odrejad",
    "odrejat": "odrejad",
    "odrejats": "odrejad",
    "odresserade": "odresserad",
    "odresserades": "odresserad",
    "odresserads": "odresserad",
    "odresserat": "odresserad",
    "odresserats": "odresserad",
    "odresserbara": "odresserbar",
    "odresserbarare": "odresserbar",
    "odresserbarares": "odresserbar",
    "odresserbaras": "odresserbar",
    "odresserbarast": "odresserbar",
    "odresserbaraste": "odresserbar",
    "odresserbarastes": "odresserbar",
    "odresserbarasts": "odresserbar",
    "odresserbare": "odresserbar",
    "odresserbares": "odresserbar",
    "odresserbarheten": "odresserbarhet",
    "odresserbarhetens": "odresserbarhet",
    "odresserbarhets": "odresserbarhet",
    "odresserbars": "odresserbar",
    "odresserbart": "odresserbar",
    "odresserbarts": "odresserbar",
    "odrevade": "odrevad",
    "odrevades": "odrevad",
    "odrevads": "odrevad",
    "odrevat": "odrevad",
    "odrevats": "odrevad",
    "odribblade": "odribblad",
    "odribblades": "odribblad",
    "odribblads": "odribblad",
    "odribblat": "odribblad",
    "odribblats": "odribblad",
    "odrillade": "odrillad",
    "odrillades": "odrillad",
    "odrillads": "odrillad",
    "odrillat": "odrillad",
    "odrillats": "odrillad",
    "odrivens": "odriven",
    "odrivet": "odriven",
    "odrivets": "odriven",
    "odrivna": "odriven",
    "odrivnare": "odriven",
    "odrivnares": "odriven",
    "odrivnas": "odriven",
    "odrivnast": "odriven",
    "odrivnaste": "odriven",
    "odrivnastes": "odriven",
    "odrivnasts": "odriven",
    "odrivne": "odriven",
    "odrivnes": "odriven",
    "odrogade": "odrogad",
    "odrogades": "odrogad",
    "odrogads": "odrogad",
    "odrogat": "odrogad",
    "odrogats": "odrogad",
    "odroppade": "odroppad",
    "odroppades": "odroppad",
    "odroppads": "odroppad",
    "odroppat": "odroppad",
    "odroppats": "odroppad",
    "odrunknade": "odrunknad",
    "odrunknades": "odrunknad",
    "odrunknads": "odrunknad",
    "odrunknat": "odrunknad",
    "odrunknats": "odrunknad",
    "odryftade": "odryftad",
    "odryftades": "odryftad",
    "odryftads": "odryftad",
    "odryftat": "odryftad",
    "odryftats": "odryftad",
    "odryga": "odryg",
    "odrygare": "odryg",
    "odrygares": "odryg",
    "odrygas": "odryg",
    "odrygast": "odryg",
    "odrygaste": "odryg",
    "odrygastes": "odryg",
    "odrygasts": "odryg",
    "odryge": "odryg",
    "odryges": "odryg",
    "odrygheten": "odryghet",
    "odryghetens": "odryghet",
    "odryghets": "odryghet",
    "odrygs": "odryg",
    "odrygt": "odryg",
    "odrygts": "odryg",
    "odrägliga": "odräglig",
    "odrägligare": "odräglig",
    "odrägligares": "odräglig",
    "odrägligas": "odräglig",
    "odrägligast": "odräglig",
    "odrägligaste": "odräglig",
    "odrägligastes": "odräglig",
    "odrägligasts": "odräglig",
    "odräglige": "odräglig",
    "odrägliges": "odräglig",
    "odrägligheten": "odräglighet",
    "odräglighetens": "odräglighet",
    "odräglighets": "odräglighet",
    "odrägligs": "odräglig",
    "odrägligt": "odräglig",
    "odrägligts": "odräglig",
    "odrämde": "odrämd",
    "odrämdes": "odrämd",
    "odrämds": "odrämd",
    "odrämt": "odrämd",
    "odrämts": "odrämd",
    "odränerade": "odränerad",
    "odränerades": "odränerad",
    "odränerads": "odränerad",
    "odränerat": "odränerad",
    "odränerats": "odränerad",
    "odränerbara": "odränerbar",
    "odränerbarare": "odränerbar",
    "odränerbarares": "odränerbar",
    "odränerbaras": "odränerbar",
    "odränerbarast": "odränerbar",
    "odränerbaraste": "odränerbar",
    "odränerbarastes": "odränerbar",
    "odränerbarasts": "odränerbar",
    "odränerbare": "odränerbar",
    "odränerbares": "odränerbar",
    "odränerbarheten": "odränerbarhet",
    "odränerbarhetens": "odränerbarhet",
    "odränerbarhets": "odränerbarhet",
    "odränerbars": "odränerbar",
    "odränerbart": "odränerbar",
    "odränerbarts": "odränerbar",
    "odränkta": "odränkt",
    "odränktas": "odränkt",
    "odränkte": "odränkt",
    "odränktes": "odränkt",
    "odränkts": "odränkt",
    "odräpta": "odräpt",
    "odräptas": "odräpt",
    "odräpte": "odräpt",
    "odräptes": "odräpt",
    "odräpts": "odräpt",
    "odrömde": "odrömd",
    "odrömdes": "odrömd",
    "odrömds": "odrömd",
    "odrömt": "odrömd",
    "odrömts": "odrömd",
    "ods": "ode",
    "oduade": "oduad",
    "oduades": "oduad",
    "oduads": "oduad",
    "oduat": "oduad",
    "oduats": "oduad",
    "odubbade": "odubbad",
    "odubbades": "odubbad",
    "odubbads": "odubbad",
    "odubbat": "odubbad",
    "odubbats": "odubbad",
    "odubblade": "odubblad",
    "odubblades": "odubblad",
    "odubblads": "odubblad",
    "odubblat": "odubblad",
    "odubblats": "odubblad",
    "odubblerade": "odubblerad",
    "odubblerades": "odubblerad",
    "odubblerads": "odubblerad",
    "odubblerat": "odubblerad",
    "odubblerats": "odubblerad",
    "odubblerbara": "odubblerbar",
    "odubblerbarare": "odubblerbar",
    "odubblerbarares": "odubblerbar",
    "odubblerbaras": "odubblerbar",
    "odubblerbarast": "odubblerbar",
    "odubblerbaraste": "odubblerbar",
    "odubblerbarastes": "odubblerbar",
    "odubblerbarasts": "odubblerbar",
    "odubblerbare": "odubblerbar",
    "odubblerbares": "odubblerbar",
    "odubblerbarheten": "odubblerbarhet",
    "odubblerbarhetens": "odubblerbarhet",
    "odubblerbarhets": "odubblerbarhet",
    "odubblerbars": "odubblerbar",
    "odubblerbart": "odubblerbar",
    "odubblerbarts": "odubblerbar",
    "odugliga": "oduglig",
    "odugligare": "oduglig",
    "odugligares": "oduglig",
    "odugligas": "oduglig",
    "odugligast": "oduglig",
    "odugligaste": "oduglig",
    "odugligastes": "oduglig",
    "odugligasts": "oduglig",
    "oduglige": "oduglig",
    "odugliges": "oduglig",
    "odugligheten": "oduglighet",
    "oduglighetens": "oduglighet",
    "oduglighets": "oduglighet",
    "odugligs": "oduglig",
    "odugligt": "oduglig",
    "odugligts": "oduglig",
    "oduglingar": "odugling",
    "oduglingarna": "odugling",
    "oduglingarnas": "odugling",
    "oduglingars": "odugling",
    "oduglingen": "odugling",
    "oduglingens": "odugling",
    "oduglings": "odugling",
    "odukade": "odukad",
    "odukades": "odukad",
    "odukads": "odukad",
    "odukat": "odukad",
    "odukats": "odukad",
    "odumpade": "odumpad",
    "odumpades": "odumpad",
    "odumpads": "odumpad",
    "odumpat": "odumpad",
    "odumpats": "odumpad",
    "odunkade": "odunkad",
    "odunkades": "odunkad",
    "odunkads": "odunkad",
    "odunkat": "odunkad",
    "odunkats": "odunkad",
    "odunstade": "odunstad",
    "odunstades": "odunstad",
    "odunstads": "odunstad",
    "odunstat": "odunstad",
    "odunstats": "odunstad",
    "oduperade": "oduperad",
    "oduperades": "oduperad",
    "oduperads": "oduperad",
    "oduperat": "oduperad",
    "oduperats": "oduperad",
    "oduperbara": "oduperbar",
    "oduperbarare": "oduperbar",
    "oduperbarares": "oduperbar",
    "oduperbaras": "oduperbar",
    "oduperbarast": "oduperbar",
    "oduperbaraste": "oduperbar",
    "oduperbarastes": "oduperbar",
    "oduperbarasts": "oduperbar",
    "oduperbare": "oduperbar",
    "oduperbares": "oduperbar",
    "oduperbarheten": "oduperbarhet",
    "oduperbarhetens": "oduperbarhet",
    "oduperbarhets": "oduperbarhet",
    "oduperbars": "oduperbar",
    "oduperbart": "oduperbar",
    "oduperbarts": "oduperbar",
    "oduplicerade": "oduplicerad",
    "oduplicerades": "oduplicerad",
    "oduplicerads": "oduplicerad",
    "oduplicerat": "oduplicerad",
    "oduplicerats": "oduplicerad",
    "oduplicerbara": "oduplicerbar",
    "oduplicerbarare": "oduplicerbar",
    "oduplicerbarares": "oduplicerbar",
    "oduplicerbaras": "oduplicerbar",
    "oduplicerbarast": "oduplicerbar",
    "oduplicerbaraste": "oduplicerbar",
    "oduplicerbarastes": "oduplicerbar",
    "oduplicerbarasts": "oduplicerbar",
    "oduplicerbare": "oduplicerbar",
    "oduplicerbares": "oduplicerbar",
    "oduplicerbarheten": "oduplicerbarhet",
    "oduplicerbarhetens": "oduplicerbarhet",
    "oduplicerbarhets": "oduplicerbarhet",
    "oduplicerbars": "oduplicerbar",
    "oduplicerbart": "oduplicerbar",
    "oduplicerbarts": "oduplicerbar",
    "oduschade": "oduschad",
    "oduschades": "oduschad",
    "oduschads": "oduschad",
    "oduschat": "oduschad",
    "oduschats": "oduschad",
    "odygden": "odygd",
    "odygdens": "odygd",
    "odygdiga": "odygdig",
    "odygdigare": "odygdig",
    "odygdigares": "odygdig",
    "odygdigas": "odygdig",
    "odygdigast": "odygdig",
    "odygdigaste": "odygdig",
    "odygdigastes": "odygdig",
    "odygdigasts": "odygdig",
    "odygdige": "odygdig",
    "odygdiges": "odygdig",
    "odygdigheten": "odygdighet",
    "odygdighetens": "odygdighet",
    "odygdighets": "odygdighet",
    "odygdigs": "odygdig",
    "odygdigt": "odygdig",
    "odygdigts": "odygdig",
    "odygds": "odygd",
    "odygdspås": "odygdspåse",
    "odygdspåsar": "odygdspåse",
    "odygdspåsarna": "odygdspåse",
    "odygdspåsarnas": "odygdspåse",
    "odygdspåsars": "odygdspåse",
    "odygdspåsen": "odygdspåse",
    "odygdspåsens": "odygdspåse",
    "odygdspåses": "odygdspåse",
    "odyrkade": "odyrkad",
    "odyrkades": "odyrkad",
    "odyrkads": "odyrkad",
    "odyrkat": "odyrkad",
    "odyrkats": "odyrkad",
    "odysséen": "odyssé",
    "odysséens": "odyssé",
    "odysséer": "odyssé",
    "odysséerna": "odyssé",
    "odysséernas": "odyssé",
    "odysséers": "odyssé",
    "odyssén": "odyssé",
    "odysséns": "odyssé",
    "odyssés": "odyssé",
    "odäckade": "odäckad",
    "odäckades": "odäckad",
    "odäckads": "odäckad",
    "odäckat": "odäckad",
    "odäckats": "odäckad",
    "odäggade": "odäggad",
    "odäggades": "odäggad",
    "odäggads": "odäggad",
    "odäggat": "odäggad",
    "odäggats": "odäggad",
    "odämde": "odämd",
    "odämdes": "odämd",
    "odämds": "odämd",
    "odämpade": "odämpad",
    "odämpades": "odämpad",
    "odämpads": "odämpad",
    "odämpat": "odämpad",
    "odämpats": "odämpad",
    "odämt": "odämd",
    "odämts": "odämd",
    "odängde": "odängd",
    "odängdes": "odängd",
    "odängds": "odängd",
    "odängt": "odängd",
    "odängts": "odängd",
    "odänkta": "odänkt",
    "odänktas": "odänkt",
    "odänkte": "odänkt",
    "odänktes": "odänkt",
    "odänkts": "odänkt",
    "odävnade": "odävnad",
    "odävnades": "odävnad",
    "odävnads": "odävnad",
    "odävnat": "odävnad",
    "odävnats": "odävnad",
    "odåg": "odåga",
    "odågan": "odåga",
    "odågans": "odåga",
    "odågas": "odåga",
    "odåge": "odåga",
    "odågor": "odåga",
    "odågorna": "odåga",
    "odågornas": "odåga",
    "odågors": "odåga",
    "odågs": "odåga",
    "odånade": "odånad",
    "odånades": "odånad",
    "odånads": "odånad",
    "odånat": "odånad",
    "odånats": "odånad",
    "odårade": "odårad",
    "odårades": "odårad",
    "odårads": "odårad",
    "odårat": "odårad",
    "odårats": "odårad",
    "odödade": "odödad",
    "odödades": "odödad",
    "odödads": "odödad",
    "odödat": "odödad",
    "odödats": "odödad",
    "odödliga": "odödlig",
    "odödligare": "odödlig",
    "odödligares": "odödlig",
    "odödligas": "odödlig",
    "odödligast": "odödlig",
    "odödligaste": "odödlig",
    "odödligastes": "odödlig",
    "odödligasts": "odödlig",
    "odödlige": "odödlig",
    "odödliges": "odödlig",
    "odödligheten": "odödlighet",
    "odödlighetens": "odödlighet",
    "odödlighets": "odödlighet",
    "odödligs": "odödlig",
    "odödligt": "odödlig",
    "odödligts": "odödlig",
    "odömde": "odömd",
    "odömdes": "odömd",
    "odömds": "odömd",
    "odömt": "odömd",
    "odömts": "odömd",
    "odöpta": "odöpt",
    "odöptas": "odöpt",
    "odöpte": "odöpt",
    "odöptes": "odöpt",
    "odöpts": "odöpt",
    "odören": "odör",
    "odörens": "odör",
    "odörer": "odör",
    "odörerna": "odör",
    "odörernas": "odör",
    "odörers": "odör",
    "odörjade": "odörjad",
    "odörjades": "odörjad",
    "odörjads": "odörjad",
    "odörjat": "odörjad",
    "odörjats": "odörjad",
    "odörs": "odör",
    "odörten": "odört",
    "odörtens": "odört",
    "odörts": "odört",
    "odövade": "odövad",
    "odövades": "odövad",
    "odövads": "odövad",
    "odövat": "odövad",
    "odövats": "odövad",
    "oederade": "oederad",
    "oederades": "oederad",
    "oederads": "oederad",
    "oederat": "oederad",
    "oederats": "oederad",
    "oederbara": "oederbar",
    "oederbarare": "oederbar",
    "oederbarares": "oederbar",
    "oederbaras": "oederbar",
    "oederbarast": "oederbar",
    "oederbaraste": "oederbar",
    "oederbarastes": "oederbar",
    "oederbarasts": "oederbar",
    "oederbare": "oederbar",
    "oederbares": "oederbar",
    "oederbarheten": "oederbarhet",
    "oederbarhetens": "oederbarhet",
    "oederbarhets": "oederbarhet",
    "oederbars": "oederbar",
    "oederbart": "oederbar",
    "oederbarts": "oederbar",
    "oeffacerade": "oeffacerad",
    "oeffacerades": "oeffacerad",
    "oeffacerads": "oeffacerad",
    "oeffacerat": "oeffacerad",
    "oeffacerats": "oeffacerad",
    "oeffacerbara": "oeffacerbar",
    "oeffacerbarare": "oeffacerbar",
    "oeffacerbarares": "oeffacerbar",
    "oeffacerbaras": "oeffacerbar",
    "oeffacerbarast": "oeffacerbar",
    "oeffacerbaraste": "oeffacerbar",
    "oeffacerbarastes": "oeffacerbar",
    "oeffacerbarasts": "oeffacerbar",
    "oeffacerbare": "oeffacerbar",
    "oeffacerbares": "oeffacerbar",
    "oeffacerbarheten": "oeffacerbarhet",
    "oeffacerbarhetens": "oeffacerbarhet",
    "oeffacerbarhets": "oeffacerbarhet",
    "oeffacerbars": "oeffacerbar",
    "oeffacerbart": "oeffacerbar",
    "oeffacerbarts": "oeffacerbar",
    "oeffektiverade": "oeffektiverad",
    "oeffektiverades": "oeffektiverad",
    "oeffektiverads": "oeffektiverad",
    "oeffektiverat": "oeffektiverad",
    "oeffektiverats": "oeffektiverad",
    "oeffektiverbara": "oeffektiverbar",
    "oeffektiverbarare": "oeffektiverbar",
    "oeffektiverbarares": "oeffektiverbar",
    "oeffektiverbaras": "oeffektiverbar",
    "oeffektiverbarast": "oeffektiverbar",
    "oeffektiverbaraste": "oeffektiverbar",
    "oeffektiverbarastes": "oeffektiverbar",
    "oeffektiverbarasts": "oeffektiverbar",
    "oeffektiverbare": "oeffektiverbar",
    "oeffektiverbares": "oeffektiverbar",
    "oeffektiverbarheten": "oeffektiverbarhet",
    "oeffektiverbarhetens": "oeffektiverbarhet",
    "oeffektiverbarhets": "oeffektiverbarhet",
    "oeffektiverbars": "oeffektiverbar",
    "oeffektiverbart": "oeffektiverbar",
    "oeffektiverbarts": "oeffektiverbar",
    "oeffektiviserade": "oeffektiviserad",
    "oeffektiviserades": "oeffektiviserad",
    "oeffektiviserads": "oeffektiviserad",
    "oeffektiviserat": "oeffektiviserad",
    "oeffektiviserats": "oeffektiviserad",
    "oeffektiviserbara": "oeffektiviserbar",
    "oeffektiviserbarare": "oeffektiviserbar",
    "oeffektiviserbarares": "oeffektiviserbar",
    "oeffektiviserbaras": "oeffektiviserbar",
    "oeffektiviserbarast": "oeffektiviserbar",
    "oeffektiviserbaraste": "oeffektiviserbar",
    "oeffektiviserbarastes": "oeffektiviserbar",
    "oeffektiviserbarasts": "oeffektiviserbar",
    "oeffektiviserbare": "oeffektiviserbar",
    "oeffektiviserbares": "oeffektiviserbar",
    "oeffektiviserbarheten": "oeffektiviserbarhet",
    "oeffektiviserbarhetens": "oeffektiviserbarhet",
    "oeffektiviserbarhets": "oeffektiviserbarhet",
    "oeffektiviserbars": "oeffektiviserbar",
    "oeffektiviserbart": "oeffektiviserbar",
    "oeffektiviserbarts": "oeffektiviserbar",
    "oeffektuerade": "oeffektuerad",
    "oeffektuerades": "oeffektuerad",
    "oeffektuerads": "oeffektuerad",
    "oeffektuerat": "oeffektuerad",
    "oeffektuerats": "oeffektuerad",
    "oeffektuerbara": "oeffektuerbar",
    "oeffektuerbarare": "oeffektuerbar",
    "oeffektuerbarares": "oeffektuerbar",
    "oeffektuerbaras": "oeffektuerbar",
    "oeffektuerbarast": "oeffektuerbar",
    "oeffektuerbaraste": "oeffektuerbar",
    "oeffektuerbarastes": "oeffektuerbar",
    "oeffektuerbarasts": "oeffektuerbar",
    "oeffektuerbare": "oeffektuerbar",
    "oeffektuerbares": "oeffektuerbar",
    "oeffektuerbarheten": "oeffektuerbarhet",
    "oeffektuerbarhetens": "oeffektuerbarhet",
    "oeffektuerbarhets": "oeffektuerbarhet",
    "oeffektuerbars": "oeffektuerbar",
    "oeffektuerbart": "oeffektuerbar",
    "oeffektuerbarts": "oeffektuerbar",
    "oefterapade": "oefterapad",
    "oefterapades": "oefterapad",
    "oefterapads": "oefterapad",
    "oefterapat": "oefterapad",
    "oefterapats": "oefterapad",
    "oefterbehandlade": "oefterbehandlad",
    "oefterbehandlades": "oefterbehandlad",
    "oefterbehandlads": "oefterbehandlad",
    "oefterbehandlat": "oefterbehandlad",
    "oefterbehandlats": "oefterbehandlad",
    "oefterbildade": "oefterbildad",
    "oefterbildades": "oefterbildad",
    "oefterbildads": "oefterbildad",
    "oefterbildat": "oefterbildad",
    "oefterbildats": "oefterbildad",
    "oefterdaterade": "oefterdaterad",
    "oefterdaterades": "oefterdaterad",
    "oefterdaterads": "oefterdaterad",
    "oefterdaterat": "oefterdaterad",
    "oefterdaterats": "oefterdaterad",
    "oefterdaterbara": "oefterdaterbar",
    "oefterdaterbarare": "oefterdaterbar",
    "oefterdaterbarares": "oefterdaterbar",
    "oefterdaterbaras": "oefterdaterbar",
    "oefterdaterbarast": "oefterdaterbar",
    "oefterdaterbaraste": "oefterdaterbar",
    "oefterdaterbarastes": "oefterdaterbar",
    "oefterdaterbarasts": "oefterdaterbar",
    "oefterdaterbare": "oefterdaterbar",
    "oefterdaterbares": "oefterdaterbar",
    "oefterdaterbarheten": "oefterdaterbarhet",
    "oefterdaterbarhetens": "oefterdaterbarhet",
    "oefterdaterbarhets": "oefterdaterbarhet",
    "oefterdaterbars": "oefterdaterbar",
    "oefterdaterbart": "oefterdaterbar",
    "oefterdaterbarts": "oefterdaterbar",
    "oefterdebiterade": "oefterdebiterad",
    "oefterdebiterades": "oefterdebiterad",
    "oefterdebiterads": "oefterdebiterad",
    "oefterdebiterat": "oefterdebiterad",
    "oefterdebiterats": "oefterdebiterad",
    "oefterdebiterbara": "oefterdebiterbar",
    "oefterdebiterbarare": "oefterdebiterbar",
    "oefterdebiterbarares": "oefterdebiterbar",
    "oefterdebiterbaras": "oefterdebiterbar",
    "oefterdebiterbarast": "oefterdebiterbar",
    "oefterdebiterbaraste": "oefterdebiterbar",
    "oefterdebiterbarastes": "oefterdebiterbar",
    "oefterdebiterbarasts": "oefterdebiterbar",
    "oefterdebiterbare": "oefterdebiterbar",
    "oefterdebiterbares": "oefterdebiterbar",
    "oefterdebiterbarheten": "oefterdebiterbarhet",
    "oefterdebiterbarhetens": "oefterdebiterbarhet",
    "oefterdebiterbarhets": "oefterdebiterbarhet",
    "oefterdebiterbars": "oefterdebiterbar",
    "oefterdebiterbart": "oefterdebiterbar",
    "oefterdebiterbarts": "oefterdebiterbar",
    "oefterforskade": "oefterforskad",
    "oefterforskades": "oefterforskad",
    "oefterforskads": "oefterforskad",
    "oefterforskat": "oefterforskad",
    "oefterforskats": "oefterforskad",
    "oefterfrågade": "oefterfrågad",
    "oefterfrågades": "oefterfrågad",
    "oefterfrågads": "oefterfrågad",
    "oefterfrågat": "oefterfrågad",
    "oefterfrågats": "oefterfrågad",
    "oefterföljde": "oefterföljd",
    "oefterföljdes": "oefterföljd",
    "oefterföljds": "oefterföljd",
    "oefterföljt": "oefterföljd",
    "oefterföljts": "oefterföljd",
    "oeftergivliga": "oeftergivlig",
    "oeftergivligare": "oeftergivlig",
    "oeftergivligares": "oeftergivlig",
    "oeftergivligas": "oeftergivlig",
    "oeftergivligast": "oeftergivlig",
    "oeftergivligaste": "oeftergivlig",
    "oeftergivligastes": "oeftergivlig",
    "oeftergivligasts": "oeftergivlig",
    "oeftergivlige": "oeftergivlig",
    "oeftergivliges": "oeftergivlig",
    "oeftergivligheten": "oeftergivlighet",
    "oeftergivlighetens": "oeftergivlighet",
    "oeftergivlighets": "oeftergivlighet",
    "oeftergivligs": "oeftergivlig",
    "oeftergivligt": "oeftergivlig",
    "oeftergivligts": "oeftergivlig",
    "oefterhärmade": "oefterhärmad",
    "oefterhärmades": "oefterhärmad",
    "oefterhärmads": "oefterhärmad",
    "oefterhärmat": "oefterhärmad",
    "oefterhärmats": "oefterhärmad",
    "oefterhärmliga": "oefterhärmlig",
    "oefterhärmligare": "oefterhärmlig",
    "oefterhärmligares": "oefterhärmlig",
    "oefterhärmligas": "oefterhärmlig",
    "oefterhärmligast": "oefterhärmlig",
    "oefterhärmligaste": "oefterhärmlig",
    "oefterhärmligastes": "oefterhärmlig",
    "oefterhärmligasts": "oefterhärmlig",
    "oefterhärmlige": "oefterhärmlig",
    "oefterhärmliges": "oefterhärmlig",
    "oefterhärmligheten": "oefterhärmlighet",
    "oefterhärmlighetens": "oefterhärmlighet",
    "oefterhärmlighets": "oefterhärmlighet",
    "oefterhärmligs": "oefterhärmlig",
    "oefterhärmligt": "oefterhärmlig",
    "oefterhärmligts": "oefterhärmlig",
    "oefterhörde": "oefterhörd",
    "oefterhördes": "oefterhörd",
    "oefterhörds": "oefterhörd",
    "oefterhört": "oefterhörd",
    "oefterhörts": "oefterhörd",
    "oefterliknade": "oefterliknad",
    "oefterliknades": "oefterliknad",
    "oefterliknads": "oefterliknad",
    "oefterliknat": "oefterliknad",
    "oefterliknats": "oefterliknad",
    "oefterlysta": "oefterlyst",
    "oefterlystas": "oefterlyst",
    "oefterlyste": "oefterlyst",
    "oefterlystes": "oefterlyst",
    "oefterlysts": "oefterlyst",
    "oefterlämnade": "oefterlämnad",
    "oefterlämnades": "oefterlämnad",
    "oefterlämnads": "oefterlämnad",
    "oefterlämnat": "oefterlämnad",
    "oefterlämnats": "oefterlämnad",
    "oeftermognade": "oeftermognad",
    "oeftermognades": "oeftermognad",
    "oeftermognads": "oeftermognad",
    "oeftermognat": "oeftermognad",
    "oeftermognats": "oeftermognad",
    "oefterrationaliserade": "oefterrationaliserad",
    "oefterrationaliserades": "oefterrationaliserad",
    "oefterrationaliserads": "oefterrationaliserad",
    "oefterrationaliserat": "oefterrationaliserad",
    "oefterrationaliserats": "oefterrationaliserad",
    "oefterrationaliserbara": "oefterrationaliserbar",
    "oefterrationaliserbarare": "oefterrationaliserbar",
    "oefterrationaliserbarares": "oefterrationaliserbar",
    "oefterrationaliserbaras": "oefterrationaliserbar",
    "oefterrationaliserbarast": "oefterrationaliserbar",
    "oefterrationaliserbaraste": "oefterrationaliserbar",
    "oefterrationaliserbarastes": "oefterrationaliserbar",
    "oefterrationaliserbarasts": "oefterrationaliserbar",
    "oefterrationaliserbare": "oefterrationaliserbar",
    "oefterrationaliserbares": "oefterrationaliserbar",
    "oefterrationaliserbarheten": "oefterrationaliserbarhet",
    "oefterrationaliserbarhetens": "oefterrationaliserbarhet",
    "oefterrationaliserbarhets": "oefterrationaliserbarhet",
    "oefterrationaliserbars": "oefterrationaliserbar",
    "oefterrationaliserbart": "oefterrationaliserbar",
    "oefterrationaliserbarts": "oefterrationaliserbar",
    "oefterrättliga": "oefterrättlig",
    "oefterrättligare": "oefterrättlig",
    "oefterrättligares": "oefterrättlig",
    "oefterrättligas": "oefterrättlig",
    "oefterrättligast": "oefterrättlig",
    "oefterrättligaste": "oefterrättlig",
    "oefterrättligastes": "oefterrättlig",
    "oefterrättligasts": "oefterrättlig",
    "oefterrättlige": "oefterrättlig",
    "oefterrättliges": "oefterrättlig",
    "oefterrättligheten": "oefterrättlighet",
    "oefterrättlighetens": "oefterrättlighet",
    "oefterrättlighets": "oefterrättlighet",
    "oefterrättligs": "oefterrättlig",
    "oefterrättligt": "oefterrättlig",
    "oefterrättligts": "oefterrättlig",
    "oefterskänkta": "oefterskänkt",
    "oefterskänktas": "oefterskänkt",
    "oefterskänkte": "oefterskänkt",
    "oefterskänktes": "oefterskänkt",
    "oefterskänkts": "oefterskänkt",
    "oefterstavade": "oefterstavad",
    "oefterstavades": "oefterstavad",
    "oefterstavads": "oefterstavad",
    "oefterstavat": "oefterstavad",
    "oefterstavats": "oefterstavad",
    "oeftersträvade": "oeftersträvad",
    "oeftersträvades": "oeftersträvad",
    "oeftersträvads": "oeftersträvad",
    "oeftersträvat": "oeftersträvad",
    "oeftersträvats": "oeftersträvad",
    "oeftersynkroniserade": "oeftersynkroniserad",
    "oeftersynkroniserades": "oeftersynkroniserad",
    "oeftersynkroniserads": "oeftersynkroniserad",
    "oeftersynkroniserat": "oeftersynkroniserad",
    "oeftersynkroniserats": "oeftersynkroniserad",
    "oeftersynkroniserbara": "oeftersynkroniserbar",
    "oeftersynkroniserbarare": "oeftersynkroniserbar",
    "oeftersynkroniserbarares": "oeftersynkroniserbar",
    "oeftersynkroniserbaras": "oeftersynkroniserbar",
    "oeftersynkroniserbarast": "oeftersynkroniserbar",
    "oeftersynkroniserbaraste": "oeftersynkroniserbar",
    "oeftersynkroniserbarastes": "oeftersynkroniserbar",
    "oeftersynkroniserbarasts": "oeftersynkroniserbar",
    "oeftersynkroniserbare": "oeftersynkroniserbar",
    "oeftersynkroniserbares": "oeftersynkroniserbar",
    "oeftersynkroniserbarheten": "oeftersynkroniserbarhet",
    "oeftersynkroniserbarhetens": "oeftersynkroniserbarhet",
    "oeftersynkroniserbarhets": "oeftersynkroniserbarhet",
    "oeftersynkroniserbars": "oeftersynkroniserbar",
    "oeftersynkroniserbart": "oeftersynkroniserbar",
    "oeftersynkroniserbarts": "oeftersynkroniserbar",
    "oeftersände": "oeftersänd",
    "oeftersändes": "oeftersänd",
    "oeftersänds": "oeftersänd",
    "oeftersänt": "oeftersänd",
    "oeftersänts": "oeftersänd",
    "oeftersökta": "oeftersökt",
    "oeftersöktas": "oeftersökt",
    "oeftersökte": "oeftersökt",
    "oeftersöktes": "oeftersökt",
    "oeftersökts": "oeftersökt",
    "oeftertaxerade": "oeftertaxerad",
    "oeftertaxerades": "oeftertaxerad",
    "oeftertaxerads": "oeftertaxerad",
    "oeftertaxerat": "oeftertaxerad",
    "oeftertaxerats": "oeftertaxerad",
    "oeftertaxerbara": "oeftertaxerbar",
    "oeftertaxerbarare": "oeftertaxerbar",
    "oeftertaxerbarares": "oeftertaxerbar",
    "oeftertaxerbaras": "oeftertaxerbar",
    "oeftertaxerbarast": "oeftertaxerbar",
    "oeftertaxerbaraste": "oeftertaxerbar",
    "oeftertaxerbarastes": "oeftertaxerbar",
    "oeftertaxerbarasts": "oeftertaxerbar",
    "oeftertaxerbare": "oeftertaxerbar",
    "oeftertaxerbares": "oeftertaxerbar",
    "oeftertaxerbarheten": "oeftertaxerbarhet",
    "oeftertaxerbarhetens": "oeftertaxerbarhet",
    "oeftertaxerbarhets": "oeftertaxerbarhet",
    "oeftertaxerbars": "oeftertaxerbar",
    "oeftertaxerbart": "oeftertaxerbar",
    "oeftertaxerbarts": "oeftertaxerbar",
    "oeftertraktade": "oeftertraktad",
    "oeftertraktades": "oeftertraktad",
    "oeftertraktads": "oeftertraktad",
    "oeftertraktat": "oeftertraktad",
    "oeftertraktats": "oeftertraktad",
    "oegaliserade": "oegaliserad",
    "oegaliserades": "oegaliserad",
    "oegaliserads": "oegaliserad",
    "oegaliserat": "oegaliserad",
    "oegaliserats": "oegaliserad",
    "oegaliserbara": "oegaliserbar",
    "oegaliserbarare": "oegaliserbar",
    "oegaliserbarares": "oegaliserbar",
    "oegaliserbaras": "oegaliserbar",
    "oegaliserbarast": "oegaliserbar",
    "oegaliserbaraste": "oegaliserbar",
    "oegaliserbarastes": "oegaliserbar",
    "oegaliserbarasts": "oegaliserbar",
    "oegaliserbare": "oegaliserbar",
    "oegaliserbares": "oegaliserbar",
    "oegaliserbarheten": "oegaliserbarhet",
    "oegaliserbarhetens": "oegaliserbarhet",
    "oegaliserbarhets": "oegaliserbarhet",
    "oegaliserbars": "oegaliserbar",
    "oegaliserbart": "oegaliserbar",
    "oegaliserbarts": "oegaliserbar",
    "oegennyttan": "oegennytta",
    "oegennyttans": "oegennytta",
    "oegennyttas": "oegennytta",
    "oegennytte": "oegennytta",
    "oegennyttiga": "oegennyttig",
    "oegennyttigare": "oegennyttig",
    "oegennyttigares": "oegennyttig",
    "oegennyttigas": "oegennyttig",
    "oegennyttigast": "oegennyttig",
    "oegennyttigaste": "oegennyttig",
    "oegennyttigastes": "oegennyttig",
    "oegennyttigasts": "oegennyttig",
    "oegennyttige": "oegennyttig",
    "oegennyttiges": "oegennyttig",
    "oegennyttigheten": "oegennyttighet",
    "oegennyttighetens": "oegennyttighet",
    "oegennyttighets": "oegennyttighet",
    "oegennyttigs": "oegennyttig",
    "oegennyttigt": "oegennyttig",
    "oegennyttigts": "oegennyttig",
    "oegennytto": "oegennytta",
    "oegennyttor": "oegennytta",
    "oegennyttorna": "oegennytta",
    "oegennyttornas": "oegennytta",
    "oegennyttors": "oegennytta",
    "oegentliga": "oegentlig",
    "oegentligare": "oegentlig",
    "oegentligares": "oegentlig",
    "oegentligas": "oegentlig",
    "oegentligast": "oegentlig",
    "oegentligaste": "oegentlig",
    "oegentligastes": "oegentlig",
    "oegentligasts": "oegentlig",
    "oegentlige": "oegentlig",
    "oegentliges": "oegentlig",
    "oegentligheten": "oegentlighet",
    "oegentlighetens": "oegentlighet",
    "oegentligheter": "oegentlighet",
    "oegentligheterna": "oegentlighet",
    "oegentligheternas": "oegentlighet",
    "oegentligheters": "oegentlighet",
    "oegentlighets": "oegentlighet",
    "oegentligs": "oegentlig",
    "oegentligt": "oegentlig",
    "oegentligts": "oegentlig",
    "oeggade": "oeggad",
    "oeggades": "oeggad",
    "oeggads": "oeggad",
    "oeggat": "oeggad",
    "oeggats": "oeggad",
    "oekade": "oekad",
    "oekades": "oekad",
    "oekads": "oekad",
    "oekat": "oekad",
    "oekats": "oekad",
    "oekiperade": "oekiperad",
    "oekiperades": "oekiperad",
    "oekiperads": "oekiperad",
    "oekiperat": "oekiperad",
    "oekiperats": "oekiperad",
    "oekiperbara": "oekiperbar",
    "oekiperbarare": "oekiperbar",
    "oekiperbarares": "oekiperbar",
    "oekiperbaras": "oekiperbar",
    "oekiperbarast": "oekiperbar",
    "oekiperbaraste": "oekiperbar",
    "oekiperbarastes": "oekiperbar",
    "oekiperbarasts": "oekiperbar",
    "oekiperbare": "oekiperbar",
    "oekiperbares": "oekiperbar",
    "oekiperbarheten": "oekiperbarhet",
    "oekiperbarhetens": "oekiperbarhet",
    "oekiperbarhets": "oekiperbarhet",
    "oekiperbars": "oekiperbar",
    "oekiperbart": "oekiperbar",
    "oekiperbarts": "oekiperbar",
    "oeklaterade": "oeklaterad",
    "oeklaterades": "oeklaterad",
    "oeklaterads": "oeklaterad",
    "oeklaterat": "oeklaterad",
    "oeklaterats": "oeklaterad",
    "oeklaterbara": "oeklaterbar",
    "oeklaterbarare": "oeklaterbar",
    "oeklaterbarares": "oeklaterbar",
    "oeklaterbaras": "oeklaterbar",
    "oeklaterbarast": "oeklaterbar",
    "oeklaterbaraste": "oeklaterbar",
    "oeklaterbarastes": "oeklaterbar",
    "oeklaterbarasts": "oeklaterbar",
    "oeklaterbare": "oeklaterbar",
    "oeklaterbares": "oeklaterbar",
    "oeklaterbarheten": "oeklaterbarhet",
    "oeklaterbarhetens": "oeklaterbarhet",
    "oeklaterbarhets": "oeklaterbarhet",
    "oeklaterbars": "oeklaterbar",
    "oeklaterbart": "oeklaterbar",
    "oeklaterbarts": "oeklaterbar",
    "oeklärerade": "oeklärerad",
    "oeklärerades": "oeklärerad",
    "oeklärerads": "oeklärerad",
    "oeklärerat": "oeklärerad",
    "oeklärerats": "oeklärerad",
    "oeklärerbara": "oeklärerbar",
    "oeklärerbarare": "oeklärerbar",
    "oeklärerbarares": "oeklärerbar",
    "oeklärerbaras": "oeklärerbar",
    "oeklärerbarast": "oeklärerbar",
    "oeklärerbaraste": "oeklärerbar",
    "oeklärerbarastes": "oeklärerbar",
    "oeklärerbarasts": "oeklärerbar",
    "oeklärerbare": "oeklärerbar",
    "oeklärerbares": "oeklärerbar",
    "oeklärerbarheten": "oeklärerbarhet",
    "oeklärerbarhetens": "oeklärerbarhet",
    "oeklärerbarhets": "oeklärerbarhet",
    "oeklärerbars": "oeklärerbar",
    "oeklärerbart": "oeklärerbar",
    "oeklärerbarts": "oeklärerbar",
    "oekonomiserade": "oekonomiserad",
    "oekonomiserades": "oekonomiserad",
    "oekonomiserads": "oekonomiserad",
    "oekonomiserat": "oekonomiserad",
    "oekonomiserats": "oekonomiserad",
    "oekonomiserbara": "oekonomiserbar",
    "oekonomiserbarare": "oekonomiserbar",
    "oekonomiserbarares": "oekonomiserbar",
    "oekonomiserbaras": "oekonomiserbar",
    "oekonomiserbarast": "oekonomiserbar",
    "oekonomiserbaraste": "oekonomiserbar",
    "oekonomiserbarastes": "oekonomiserbar",
    "oekonomiserbarasts": "oekonomiserbar",
    "oekonomiserbare": "oekonomiserbar",
    "oekonomiserbares": "oekonomiserbar",
    "oekonomiserbarheten": "oekonomiserbarhet",
    "oekonomiserbarhetens": "oekonomiserbarhet",
    "oekonomiserbarhets": "oekonomiserbarhet",
    "oekonomiserbars": "oekonomiserbar",
    "oekonomiserbart": "oekonomiserbar",
    "oekonomiserbarts": "oekonomiserbar",
    "oekonomiska": "oekonomisk",
    "oekonomiskare": "oekonomisk",
    "oekonomiskares": "oekonomisk",
    "oekonomiskas": "oekonomisk",
    "oekonomiskast": "oekonomisk",
    "oekonomiskaste": "oekonomisk",
    "oekonomiskastes": "oekonomisk",
    "oekonomiskasts": "oekonomisk",
    "oekonomiske": "oekonomisk",
    "oekonomiskes": "oekonomisk",
    "oekonomisks": "oekonomisk",
    "oekonomiskt": "oekonomisk",
    "oekonomiskts": "oekonomisk",
    "oelaborerade": "oelaborerad",
    "oelaborerades": "oelaborerad",
    "oelaborerads": "oelaborerad",
    "oelaborerat": "oelaborerad",
    "oelaborerats": "oelaborerad",
    "oelaborerbara": "oelaborerbar",
    "oelaborerbarare": "oelaborerbar",
    "oelaborerbarares": "oelaborerbar",
    "oelaborerbaras": "oelaborerbar",
    "oelaborerbarast": "oelaborerbar",
    "oelaborerbaraste": "oelaborerbar",
    "oelaborerbarastes": "oelaborerbar",
    "oelaborerbarasts": "oelaborerbar",
    "oelaborerbare": "oelaborerbar",
    "oelaborerbares": "oelaborerbar",
    "oelaborerbarheten": "oelaborerbarhet",
    "oelaborerbarhetens": "oelaborerbarhet",
    "oelaborerbarhets": "oelaborerbarhet",
    "oelaborerbars": "oelaborerbar",
    "oelaborerbart": "oelaborerbar",
    "oelaborerbarts": "oelaborerbar",
    "oelastiserade": "oelastiserad",
    "oelastiserades": "oelastiserad",
    "oelastiserads": "oelastiserad",
    "oelastiserat": "oelastiserad",
    "oelastiserats": "oelastiserad",
    "oelastiserbara": "oelastiserbar",
    "oelastiserbarare": "oelastiserbar",
    "oelastiserbarares": "oelastiserbar",
    "oelastiserbaras": "oelastiserbar",
    "oelastiserbarast": "oelastiserbar",
    "oelastiserbaraste": "oelastiserbar",
    "oelastiserbarastes": "oelastiserbar",
    "oelastiserbarasts": "oelastiserbar",
    "oelastiserbare": "oelastiserbar",
    "oelastiserbares": "oelastiserbar",
    "oelastiserbarheten": "oelastiserbarhet",
    "oelastiserbarhetens": "oelastiserbarhet",
    "oelastiserbarhets": "oelastiserbarhet",
    "oelastiserbars": "oelastiserbar",
    "oelastiserbart": "oelastiserbar",
    "oelastiserbarts": "oelastiserbar",
    "oeldade": "oeldad",
    "oeldades": "oeldad",
    "oeldads": "oeldad",
    "oeldat": "oeldad",
    "oeldats": "oeldad",
    "oelektrificerade": "oelektrificerad",
    "oelektrificerades": "oelektrificerad",
    "oelektrificerads": "oelektrificerad",
    "oelektrificerat": "oelektrificerad",
    "oelektrificerats": "oelektrificerad",
    "oelektrificerbara": "oelektrificerbar",
    "oelektrificerbarare": "oelektrificerbar",
    "oelektrificerbarares": "oelektrificerbar",
    "oelektrificerbaras": "oelektrificerbar",
    "oelektrificerbarast": "oelektrificerbar",
    "oelektrificerbaraste": "oelektrificerbar",
    "oelektrificerbarastes": "oelektrificerbar",
    "oelektrificerbarasts": "oelektrificerbar",
    "oelektrificerbare": "oelektrificerbar",
    "oelektrificerbares": "oelektrificerbar",
    "oelektrificerbarheten": "oelektrificerbarhet",
    "oelektrificerbarhetens": "oelektrificerbarhet",
    "oelektrificerbarhets": "oelektrificerbarhet",
    "oelektrificerbars": "oelektrificerbar",
    "oelektrificerbart": "oelektrificerbar",
    "oelektrificerbarts": "oelektrificerbar",
    "oelektrifierade": "oelektrifierad",
    "oelektrifierades": "oelektrifierad",
    "oelektrifierads": "oelektrifierad",
    "oelektrifierat": "oelektrifierad",
    "oelektrifierats": "oelektrifierad",
    "oelektrifierbara": "oelektrifierbar",
    "oelektrifierbarare": "oelektrifierbar",
    "oelektrifierbarares": "oelektrifierbar",
    "oelektrifierbaras": "oelektrifierbar",
    "oelektrifierbarast": "oelektrifierbar",
    "oelektrifierbaraste": "oelektrifierbar",
    "oelektrifierbarastes": "oelektrifierbar",
    "oelektrifierbarasts": "oelektrifierbar",
    "oelektrifierbare": "oelektrifierbar",
    "oelektrifierbares": "oelektrifierbar",
    "oelektrifierbarheten": "oelektrifierbarhet",
    "oelektrifierbarhetens": "oelektrifierbarhet",
    "oelektrifierbarhets": "oelektrifierbarhet",
    "oelektrifierbars": "oelektrifierbar",
    "oelektrifierbart": "oelektrifierbar",
    "oelektrifierbarts": "oelektrifierbar",
    "oelektriserade": "oelektriserad",
    "oelektriserades": "oelektriserad",
    "oelektriserads": "oelektriserad",
    "oelektriserat": "oelektriserad",
    "oelektriserats": "oelektriserad",
    "oelektriserbara": "oelektriserbar",
    "oelektriserbarare": "oelektriserbar",
    "oelektriserbarares": "oelektriserbar",
    "oelektriserbaras": "oelektriserbar",
    "oelektriserbarast": "oelektriserbar",
    "oelektriserbaraste": "oelektriserbar",
    "oelektriserbarastes": "oelektriserbar",
    "oelektriserbarasts": "oelektriserbar",
    "oelektriserbare": "oelektriserbar",
    "oelektriserbares": "oelektriserbar",
    "oelektriserbarheten": "oelektriserbarhet",
    "oelektriserbarhetens": "oelektriserbarhet",
    "oelektriserbarhets": "oelektriserbarhet",
    "oelektriserbars": "oelektriserbar",
    "oelektriserbart": "oelektriserbar",
    "oelektriserbarts": "oelektriserbar",
    "oeliderade": "oeliderad",
    "oeliderades": "oeliderad",
    "oeliderads": "oeliderad",
    "oeliderat": "oeliderad",
    "oeliderats": "oeliderad",
    "oeliderbara": "oeliderbar",
    "oeliderbarare": "oeliderbar",
    "oeliderbarares": "oeliderbar",
    "oeliderbaras": "oeliderbar",
    "oeliderbarast": "oeliderbar",
    "oeliderbaraste": "oeliderbar",
    "oeliderbarastes": "oeliderbar",
    "oeliderbarasts": "oeliderbar",
    "oeliderbare": "oeliderbar",
    "oeliderbares": "oeliderbar",
    "oeliderbarheten": "oeliderbarhet",
    "oeliderbarhetens": "oeliderbarhet",
    "oeliderbarhets": "oeliderbarhet",
    "oeliderbars": "oeliderbar",
    "oeliderbart": "oeliderbar",
    "oeliderbarts": "oeliderbar",
    "oeliminerade": "oeliminerad",
    "oeliminerades": "oeliminerad",
    "oeliminerads": "oeliminerad",
    "oeliminerat": "oeliminerad",
    "oeliminerats": "oeliminerad",
    "oeliminerbara": "oeliminerbar",
    "oeliminerbarare": "oeliminerbar",
    "oeliminerbarares": "oeliminerbar",
    "oeliminerbaras": "oeliminerbar",
    "oeliminerbarast": "oeliminerbar",
    "oeliminerbaraste": "oeliminerbar",
    "oeliminerbarastes": "oeliminerbar",
    "oeliminerbarasts": "oeliminerbar",
    "oeliminerbare": "oeliminerbar",
    "oeliminerbares": "oeliminerbar",
    "oeliminerbarheten": "oeliminerbarhet",
    "oeliminerbarhetens": "oeliminerbarhet",
    "oeliminerbarhets": "oeliminerbarhet",
    "oeliminerbars": "oeliminerbar",
    "oeliminerbart": "oeliminerbar",
    "oeliminerbarts": "oeliminerbar",
    "oeloxerade": "oeloxerad",
    "oeloxerades": "oeloxerad",
    "oeloxerads": "oeloxerad",
    "oeloxerat": "oeloxerad",
    "oeloxerats": "oeloxerad",
    "oeloxerbara": "oeloxerbar",
    "oeloxerbarare": "oeloxerbar",
    "oeloxerbarares": "oeloxerbar",
    "oeloxerbaras": "oeloxerbar",
    "oeloxerbarast": "oeloxerbar",
    "oeloxerbaraste": "oeloxerbar",
    "oeloxerbarastes": "oeloxerbar",
    "oeloxerbarasts": "oeloxerbar",
    "oeloxerbare": "oeloxerbar",
    "oeloxerbares": "oeloxerbar",
    "oeloxerbarheten": "oeloxerbarhet",
    "oeloxerbarhetens": "oeloxerbarhet",
    "oeloxerbarhets": "oeloxerbarhet",
    "oeloxerbars": "oeloxerbar",
    "oeloxerbart": "oeloxerbar",
    "oeloxerbarts": "oeloxerbar",
    "oeluderade": "oeluderad",
    "oeluderades": "oeluderad",
    "oeluderads": "oeluderad",
    "oeluderat": "oeluderad",
    "oeluderats": "oeluderad",
    "oeluderbara": "oeluderbar",
    "oeluderbarare": "oeluderbar",
    "oeluderbarares": "oeluderbar",
    "oeluderbaras": "oeluderbar",
    "oeluderbarast": "oeluderbar",
    "oeluderbaraste": "oeluderbar",
    "oeluderbarastes": "oeluderbar",
    "oeluderbarasts": "oeluderbar",
    "oeluderbare": "oeluderbar",
    "oeluderbares": "oeluderbar",
    "oeluderbarheten": "oeluderbarhet",
    "oeluderbarhetens": "oeluderbarhet",
    "oeluderbarhets": "oeluderbarhet",
    "oeluderbars": "oeluderbar",
    "oeluderbart": "oeluderbar",
    "oeluderbarts": "oeluderbar",
    "oeluerade": "oeluerad",
    "oeluerades": "oeluerad",
    "oeluerads": "oeluerad",
    "oeluerat": "oeluerad",
    "oeluerats": "oeluerad",
    "oeluerbara": "oeluerbar",
    "oeluerbarare": "oeluerbar",
    "oeluerbarares": "oeluerbar",
    "oeluerbaras": "oeluerbar",
    "oeluerbarast": "oeluerbar",
    "oeluerbaraste": "oeluerbar",
    "oeluerbarastes": "oeluerbar",
    "oeluerbarasts": "oeluerbar",
    "oeluerbare": "oeluerbar",
    "oeluerbares": "oeluerbar",
    "oeluerbarheten": "oeluerbarhet",
    "oeluerbarhetens": "oeluerbarhet",
    "oeluerbarhets": "oeluerbarhet",
    "oeluerbars": "oeluerbar",
    "oeluerbart": "oeluerbar",
    "oeluerbarts": "oeluerbar",
    "oemaljerade": "oemaljerad",
    "oemaljerades": "oemaljerad",
    "oemaljerads": "oemaljerad",
    "oemaljerat": "oemaljerad",
    "oemaljerats": "oemaljerad",
    "oemaljerbara": "oemaljerbar",
    "oemaljerbarare": "oemaljerbar",
    "oemaljerbarares": "oemaljerbar",
    "oemaljerbaras": "oemaljerbar",
    "oemaljerbarast": "oemaljerbar",
    "oemaljerbaraste": "oemaljerbar",
    "oemaljerbarastes": "oemaljerbar",
    "oemaljerbarasts": "oemaljerbar",
    "oemaljerbare": "oemaljerbar",
    "oemaljerbares": "oemaljerbar",
    "oemaljerbarheten": "oemaljerbarhet",
    "oemaljerbarhetens": "oemaljerbarhet",
    "oemaljerbarhets": "oemaljerbarhet",
    "oemaljerbars": "oemaljerbar",
    "oemaljerbart": "oemaljerbar",
    "oemaljerbarts": "oemaljerbar",
    "oemanciperade": "oemanciperad",
    "oemanciperades": "oemanciperad",
    "oemanciperads": "oemanciperad",
    "oemanciperat": "oemanciperad",
    "oemanciperats": "oemanciperad",
    "oemanciperbara": "oemanciperbar",
    "oemanciperbarare": "oemanciperbar",
    "oemanciperbarares": "oemanciperbar",
    "oemanciperbaras": "oemanciperbar",
    "oemanciperbarast": "oemanciperbar",
    "oemanciperbaraste": "oemanciperbar",
    "oemanciperbarastes": "oemanciperbar",
    "oemanciperbarasts": "oemanciperbar",
    "oemanciperbare": "oemanciperbar",
    "oemanciperbares": "oemanciperbar",
    "oemanciperbarheten": "oemanciperbarhet",
    "oemanciperbarhetens": "oemanciperbarhet",
    "oemanciperbarhets": "oemanciperbarhet",
    "oemanciperbars": "oemanciperbar",
    "oemanciperbart": "oemanciperbar",
    "oemanciperbarts": "oemanciperbar",
    "oemballerade": "oemballerad",
    "oemballerades": "oemballerad",
    "oemballerads": "oemballerad",
    "oemballerat": "oemballerad",
    "oemballerats": "oemballerad",
    "oemballerbara": "oemballerbar",
    "oemballerbarare": "oemballerbar",
    "oemballerbarares": "oemballerbar",
    "oemballerbaras": "oemballerbar",
    "oemballerbarast": "oemballerbar",
    "oemballerbaraste": "oemballerbar",
    "oemballerbarastes": "oemballerbar",
    "oemballerbarasts": "oemballerbar",
    "oemballerbare": "oemballerbar",
    "oemballerbares": "oemballerbar",
    "oemballerbarheten": "oemballerbarhet",
    "oemballerbarhetens": "oemballerbarhet",
    "oemballerbarhets": "oemballerbarhet",
    "oemballerbars": "oemballerbar",
    "oemballerbart": "oemballerbar",
    "oemballerbarts": "oemballerbar",
    "oembarkerade": "oembarkerad",
    "oembarkerades": "oembarkerad",
    "oembarkerads": "oembarkerad",
    "oembarkerat": "oembarkerad",
    "oembarkerats": "oembarkerad",
    "oembarkerbara": "oembarkerbar",
    "oembarkerbarare": "oembarkerbar",
    "oembarkerbarares": "oembarkerbar",
    "oembarkerbaras": "oembarkerbar",
    "oembarkerbarast": "oembarkerbar",
    "oembarkerbaraste": "oembarkerbar",
    "oembarkerbarastes": "oembarkerbar",
    "oembarkerbarasts": "oembarkerbar",
    "oembarkerbare": "oembarkerbar",
    "oembarkerbares": "oembarkerbar",
    "oembarkerbarheten": "oembarkerbarhet",
    "oembarkerbarhetens": "oembarkerbarhet",
    "oembarkerbarhets": "oembarkerbarhet",
    "oembarkerbars": "oembarkerbar",
    "oembarkerbart": "oembarkerbar",
    "oembarkerbarts": "oembarkerbar",
    "oembellerade": "oembellerad",
    "oembellerades": "oembellerad",
    "oembellerads": "oembellerad",
    "oembellerat": "oembellerad",
    "oembellerats": "oembellerad",
    "oembellerbara": "oembellerbar",
    "oembellerbarare": "oembellerbar",
    "oembellerbarares": "oembellerbar",
    "oembellerbaras": "oembellerbar",
    "oembellerbarast": "oembellerbar",
    "oembellerbaraste": "oembellerbar",
    "oembellerbarastes": "oembellerbar",
    "oembellerbarasts": "oembellerbar",
    "oembellerbare": "oembellerbar",
    "oembellerbares": "oembellerbar",
    "oembellerbarheten": "oembellerbarhet",
    "oembellerbarhetens": "oembellerbarhet",
    "oembellerbarhets": "oembellerbarhet",
    "oembellerbars": "oembellerbar",
    "oembellerbart": "oembellerbar",
    "oembellerbarts": "oembellerbar",
    "oemenderade": "oemenderad",
    "oemenderades": "oemenderad",
    "oemenderads": "oemenderad",
    "oemenderat": "oemenderad",
    "oemenderats": "oemenderad",
    "oemenderbara": "oemenderbar",
    "oemenderbarare": "oemenderbar",
    "oemenderbarares": "oemenderbar",
    "oemenderbaras": "oemenderbar",
    "oemenderbarast": "oemenderbar",
    "oemenderbaraste": "oemenderbar",
    "oemenderbarastes": "oemenderbar",
    "oemenderbarasts": "oemenderbar",
    "oemenderbare": "oemenderbar",
    "oemenderbares": "oemenderbar",
    "oemenderbarheten": "oemenderbarhet",
    "oemenderbarhetens": "oemenderbarhet",
    "oemenderbarhets": "oemenderbarhet",
    "oemenderbars": "oemenderbar",
    "oemenderbart": "oemenderbar",
    "oemenderbarts": "oemenderbar",
    "oemigrerade": "oemigrerad",
    "oemigrerades": "oemigrerad",
    "oemigrerads": "oemigrerad",
    "oemigrerat": "oemigrerad",
    "oemigrerats": "oemigrerad",
    "oemigrerbara": "oemigrerbar",
    "oemigrerbarare": "oemigrerbar",
    "oemigrerbarares": "oemigrerbar",
    "oemigrerbaras": "oemigrerbar",
    "oemigrerbarast": "oemigrerbar",
    "oemigrerbaraste": "oemigrerbar",
    "oemigrerbarastes": "oemigrerbar",
    "oemigrerbarasts": "oemigrerbar",
    "oemigrerbare": "oemigrerbar",
    "oemigrerbares": "oemigrerbar",
    "oemigrerbarheten": "oemigrerbarhet",
    "oemigrerbarhetens": "oemigrerbarhet",
    "oemigrerbarhets": "oemigrerbarhet",
    "oemigrerbars": "oemigrerbar",
    "oemigrerbart": "oemigrerbar",
    "oemigrerbarts": "oemigrerbar",
    "oemitterade": "oemitterad",
    "oemitterades": "oemitterad",
    "oemitterads": "oemitterad",
    "oemitterat": "oemitterad",
    "oemitterats": "oemitterad",
    "oemitterbara": "oemitterbar",
    "oemitterbarare": "oemitterbar",
    "oemitterbarares": "oemitterbar",
    "oemitterbaras": "oemitterbar",
    "oemitterbarast": "oemitterbar",
    "oemitterbaraste": "oemitterbar",
    "oemitterbarastes": "oemitterbar",
    "oemitterbarasts": "oemitterbar",
    "oemitterbare": "oemitterbar",
    "oemitterbares": "oemitterbar",
    "oemitterbarheten": "oemitterbarhet",
    "oemitterbarhetens": "oemitterbarhet",
    "oemitterbarhets": "oemitterbarhet",
    "oemitterbars": "oemitterbar",
    "oemitterbart": "oemitterbar",
    "oemitterbarts": "oemitterbar",
    "oemotsagda": "oemotsagd",
    "oemotsagdare": "oemotsagd",
    "oemotsagdares": "oemotsagd",
    "oemotsagdas": "oemotsagd",
    "oemotsagdast": "oemotsagd",
    "oemotsagdaste": "oemotsagd",
    "oemotsagdastes": "oemotsagd",
    "oemotsagdasts": "oemotsagd",
    "oemotsagde": "oemotsagd",
    "oemotsagdes": "oemotsagd",
    "oemotsagds": "oemotsagd",
    "oemotsagt": "oemotsagd",
    "oemotsagts": "oemotsagd",
    "oemotståndliga": "oemotståndlig",
    "oemotståndligare": "oemotståndlig",
    "oemotståndligares": "oemotståndlig",
    "oemotståndligas": "oemotståndlig",
    "oemotståndligast": "oemotståndlig",
    "oemotståndligaste": "oemotståndlig",
    "oemotståndligastes": "oemotståndlig",
    "oemotståndligasts": "oemotståndlig",
    "oemotståndlige": "oemotståndlig",
    "oemotståndliges": "oemotståndlig",
    "oemotståndligheten": "oemotståndlighet",
    "oemotståndlighetens": "oemotståndlighet",
    "oemotståndlighets": "oemotståndlighet",
    "oemotståndligs": "oemotståndlig",
    "oemotståndligt": "oemotståndlig",
    "oemotståndligts": "oemotståndlig",
    "oemotsägliga": "oemotsäglig",
    "oemotsägligare": "oemotsäglig",
    "oemotsägligares": "oemotsäglig",
    "oemotsägligas": "oemotsäglig",
    "oemotsägligast": "oemotsäglig",
    "oemotsägligaste": "oemotsäglig",
    "oemotsägligastes": "oemotsäglig",
    "oemotsägligasts": "oemotsäglig",
    "oemotsäglige": "oemotsäglig",
    "oemotsägliges": "oemotsäglig",
    "oemotsägligheten": "oemotsäglighet",
    "oemotsäglighetens": "oemotsäglighet",
    "oemotsäglighets": "oemotsäglighet",
    "oemotsägligs": "oemotsäglig",
    "oemotsägligt": "oemotsäglig",
    "oemotsägligts": "oemotsäglig",
    "oemottagliga": "oemottaglig",
    "oemottagligare": "oemottaglig",
    "oemottagligares": "oemottaglig",
    "oemottagligas": "oemottaglig",
    "oemottagligast": "oemottaglig",
    "oemottagligaste": "oemottaglig",
    "oemottagligastes": "oemottaglig",
    "oemottagligasts": "oemottaglig",
    "oemottaglige": "oemottaglig",
    "oemottagliges": "oemottaglig",
    "oemottagligheten": "oemottaglighet",
    "oemottaglighetens": "oemottaglighet",
    "oemottaglighets": "oemottaglighet",
    "oemottagligs": "oemottaglig",
    "oemottagligt": "oemottaglig",
    "oemottagligts": "oemottaglig",
    "oemulgerade": "oemulgerad",
    "oemulgerades": "oemulgerad",
    "oemulgerads": "oemulgerad",
    "oemulgerat": "oemulgerad",
    "oemulgerats": "oemulgerad",
    "oemulgerbara": "oemulgerbar",
    "oemulgerbarare": "oemulgerbar",
    "oemulgerbarares": "oemulgerbar",
    "oemulgerbaras": "oemulgerbar",
    "oemulgerbarast": "oemulgerbar",
    "oemulgerbaraste": "oemulgerbar",
    "oemulgerbarastes": "oemulgerbar",
    "oemulgerbarasts": "oemulgerbar",
    "oemulgerbare": "oemulgerbar",
    "oemulgerbares": "oemulgerbar",
    "oemulgerbarheten": "oemulgerbarhet",
    "oemulgerbarhetens": "oemulgerbarhet",
    "oemulgerbarhets": "oemulgerbarhet",
    "oemulgerbars": "oemulgerbar",
    "oemulgerbart": "oemulgerbar",
    "oemulgerbarts": "oemulgerbar",
    "oen": "o",
    "oenade": "oenad",
    "oenades": "oenad",
    "oenads": "oenad",
    "oenat": "oenad",
    "oenats": "oenad",
    "oendosserade": "oendosserad",
    "oendosserades": "oendosserad",
    "oendosserads": "oendosserad",
    "oendosserat": "oendosserad",
    "oendosserats": "oendosserad",
    "oendosserbara": "oendosserbar",
    "oendosserbarare": "oendosserbar",
    "oendosserbarares": "oendosserbar",
    "oendosserbaras": "oendosserbar",
    "oendosserbarast": "oendosserbar",
    "oendosserbaraste": "oendosserbar",
    "oendosserbarastes": "oendosserbar",
    "oendosserbarasts": "oendosserbar",
    "oendosserbare": "oendosserbar",
    "oendosserbares": "oendosserbar",
    "oendosserbarheten": "oendosserbarhet",
    "oendosserbarhetens": "oendosserbarhet",
    "oendosserbarhets": "oendosserbarhet",
    "oendosserbars": "oendosserbar",
    "oendosserbart": "oendosserbar",
    "oendosserbarts": "oendosserbar",
    "oenerverade": "oenerverad",
    "oenerverades": "oenerverad",
    "oenerverads": "oenerverad",
    "oenerverat": "oenerverad",
    "oenerverats": "oenerverad",
    "oenerverbara": "oenerverbar",
    "oenerverbarare": "oenerverbar",
    "oenerverbarares": "oenerverbar",
    "oenerverbaras": "oenerverbar",
    "oenerverbarast": "oenerverbar",
    "oenerverbaraste": "oenerverbar",
    "oenerverbarastes": "oenerverbar",
    "oenerverbarasts": "oenerverbar",
    "oenerverbare": "oenerverbar",
    "oenerverbares": "oenerverbar",
    "oenerverbarheten": "oenerverbarhet",
    "oenerverbarhetens": "oenerverbarhet",
    "oenerverbarhets": "oenerverbarhet",
    "oenerverbars": "oenerverbar",
    "oenerverbart": "oenerverbar",
    "oenerverbarts": "oenerverbar",
    "oengagerade": "oengagerad",
    "oengagerades": "oengagerad",
    "oengagerads": "oengagerad",
    "oengagerat": "oengagerad",
    "oengagerats": "oengagerad",
    "oengagerbara": "oengagerbar",
    "oengagerbarare": "oengagerbar",
    "oengagerbarares": "oengagerbar",
    "oengagerbaras": "oengagerbar",
    "oengagerbarast": "oengagerbar",
    "oengagerbaraste": "oengagerbar",
    "oengagerbarastes": "oengagerbar",
    "oengagerbarasts": "oengagerbar",
    "oengagerbare": "oengagerbar",
    "oengagerbares": "oengagerbar",
    "oengagerbarheten": "oengagerbarhet",
    "oengagerbarhetens": "oengagerbarhet",
    "oengagerbarhets": "oengagerbarhet",
    "oengagerbars": "oengagerbar",
    "oengagerbart": "oengagerbar",
    "oengagerbarts": "oengagerbar",
    "oeniga": "oenig",
    "oenigare": "oenig",
    "oenigares": "oenig",
    "oenigas": "oenig",
    "oenigast": "oenig",
    "oenigaste": "oenig",
    "oenigastes": "oenig",
    "oenigasts": "oenig",
    "oenige": "oenig",
    "oeniges": "oenig",
    "oenigheten": "oenighet",
    "oenighetens": "oenighet",
    "oenigheter": "oenighet",
    "oenigheterna": "oenighet",
    "oenigheternas": "oenighet",
    "oenigheters": "oenighet",
    "oenighets": "oenighet",
    "oenigs": "oenig",
    "oenigt": "oenig",
    "oenigts": "oenig",
    "oenklade": "oenklad",
    "oenklades": "oenklad",
    "oenklads": "oenklad",
    "oenklat": "oenklad",
    "oenklats": "oenklad",
    "oenleverade": "oenleverad",
    "oenleverades": "oenleverad",
    "oenleverads": "oenleverad",
    "oenleverat": "oenleverad",
    "oenleverats": "oenleverad",
    "oenleverbara": "oenleverbar",
    "oenleverbarare": "oenleverbar",
    "oenleverbarares": "oenleverbar",
    "oenleverbaras": "oenleverbar",
    "oenleverbarast": "oenleverbar",
    "oenleverbaraste": "oenleverbar",
    "oenleverbarastes": "oenleverbar",
    "oenleverbarasts": "oenleverbar",
    "oenleverbare": "oenleverbar",
    "oenleverbares": "oenleverbar",
    "oenleverbarheten": "oenleverbarhet",
    "oenleverbarhetens": "oenleverbarhet",
    "oenleverbarhets": "oenleverbarhet",
    "oenleverbars": "oenleverbar",
    "oenleverbart": "oenleverbar",
    "oenleverbarts": "oenleverbar",
    "oenrollerade": "oenrollerad",
    "oenrollerades": "oenrollerad",
    "oenrollerads": "oenrollerad",
    "oenrollerat": "oenrollerad",
    "oenrollerats": "oenrollerad",
    "oenrollerbara": "oenrollerbar",
    "oenrollerbarare": "oenrollerbar",
    "oenrollerbarares": "oenrollerbar",
    "oenrollerbaras": "oenrollerbar",
    "oenrollerbarast": "oenrollerbar",
    "oenrollerbaraste": "oenrollerbar",
    "oenrollerbarastes": "oenrollerbar",
    "oenrollerbarasts": "oenrollerbar",
    "oenrollerbare": "oenrollerbar",
    "oenrollerbares": "oenrollerbar",
    "oenrollerbarheten": "oenrollerbarhet",
    "oenrollerbarhetens": "oenrollerbarhet",
    "oenrollerbarhets": "oenrollerbarhet",
    "oenrollerbars": "oenrollerbar",
    "oenrollerbart": "oenrollerbar",
    "oenrollerbarts": "oenrollerbar",
    "oens": "o",
    "oensade": "oensad",
    "oensades": "oensad",
    "oensads": "oensad",
    "oensat": "oensad",
    "oensats": "oensad",
    "oensilerade": "oensilerad",
    "oensilerades": "oensilerad",
    "oensilerads": "oensilerad",
    "oensilerat": "oensilerad",
    "oensilerats": "oensilerad",
    "oensilerbara": "oensilerbar",
    "oensilerbarare": "oensilerbar",
    "oensilerbarares": "oensilerbar",
    "oensilerbaras": "oensilerbar",
    "oensilerbarast": "oensilerbar",
    "oensilerbaraste": "oensilerbar",
    "oensilerbarastes": "oensilerbar",
    "oensilerbarasts": "oensilerbar",
    "oensilerbare": "oensilerbar",
    "oensilerbares": "oensilerbar",
    "oensilerbarheten": "oensilerbarhet",
    "oensilerbarhetens": "oensilerbarhet",
    "oensilerbarhets": "oensilerbarhet",
    "oensilerbars": "oensilerbar",
    "oensilerbart": "oensilerbar",
    "oensilerbarts": "oensilerbar",
    "oentledigade": "oentledigad",
    "oentledigades": "oentledigad",
    "oentledigads": "oentledigad",
    "oentledigat": "oentledigad",
    "oentledigats": "oentledigad",
    "oentusiasmerade": "oentusiasmerad",
    "oentusiasmerades": "oentusiasmerad",
    "oentusiasmerads": "oentusiasmerad",
    "oentusiasmerat": "oentusiasmerad",
    "oentusiasmerats": "oentusiasmerad",
    "oentusiasmerbara": "oentusiasmerbar",
    "oentusiasmerbarare": "oentusiasmerbar",
    "oentusiasmerbarares": "oentusiasmerbar",
    "oentusiasmerbaras": "oentusiasmerbar",
    "oentusiasmerbarast": "oentusiasmerbar",
    "oentusiasmerbaraste": "oentusiasmerbar",
    "oentusiasmerbarastes": "oentusiasmerbar",
    "oentusiasmerbarasts": "oentusiasmerbar",
    "oentusiasmerbare": "oentusiasmerbar",
    "oentusiasmerbares": "oentusiasmerbar",
    "oentusiasmerbarheten": "oentusiasmerbarhet",
    "oentusiasmerbarhetens": "oentusiasmerbarhet",
    "oentusiasmerbarhets": "oentusiasmerbarhet",
    "oentusiasmerbars": "oentusiasmerbar",
    "oentusiasmerbart": "oentusiasmerbar",
    "oentusiasmerbarts": "oentusiasmerbar",
    "oepilerade": "oepilerad",
    "oepilerades": "oepilerad",
    "oepilerads": "oepilerad",
    "oepilerat": "oepilerad",
    "oepilerats": "oepilerad",
    "oepilerbara": "oepilerbar",
    "oepilerbarare": "oepilerbar",
    "oepilerbarares": "oepilerbar",
    "oepilerbaras": "oepilerbar",
    "oepilerbarast": "oepilerbar",
    "oepilerbaraste": "oepilerbar",
    "oepilerbarastes": "oepilerbar",
    "oepilerbarasts": "oepilerbar",
    "oepilerbare": "oepilerbar",
    "oepilerbares": "oepilerbar",
    "oepilerbarheten": "oepilerbarhet",
    "oepilerbarhetens": "oepilerbarhet",
    "oepilerbarhets": "oepilerbarhet",
    "oepilerbars": "oepilerbar",
    "oepilerbart": "oepilerbar",
    "oepilerbarts": "oepilerbar",
    "oerfarens": "oerfaren",
    "oerfaret": "oerfaren",
    "oerfarets": "oerfaren",
    "oerfarna": "oerfaren",
    "oerfarnare": "oerfaren",
    "oerfarnares": "oerfaren",
    "oerfarnas": "oerfaren",
    "oerfarnast": "oerfaren",
    "oerfarnaste": "oerfaren",
    "oerfarnastes": "oerfaren",
    "oerfarnasts": "oerfaren",
    "oerfarne": "oerfaren",
    "oerfarnes": "oerfaren",
    "oerfordrade": "oerfordrad",
    "oerfordrades": "oerfordrad",
    "oerfordrads": "oerfordrad",
    "oerfordrat": "oerfordrad",
    "oerfordrats": "oerfordrad",
    "oerhörda": "oerhörd",
    "oerhördare": "oerhörd",
    "oerhördares": "oerhörd",
    "oerhördas": "oerhörd",
    "oerhördast": "oerhörd",
    "oerhördaste": "oerhörd",
    "oerhördastes": "oerhörd",
    "oerhördasts": "oerhörd",
    "oerhörde": "oerhörd",
    "oerhördes": "oerhörd",
    "oerhördheten": "oerhördhet",
    "oerhördhetens": "oerhördhet",
    "oerhördhets": "oerhördhet",
    "oerhörds": "oerhörd",
    "oerhört": "oerhörd",
    "oerhörts": "oerhörd",
    "oerigerade": "oerigerad",
    "oerigerades": "oerigerad",
    "oerigerads": "oerigerad",
    "oerigerat": "oerigerad",
    "oerigerats": "oerigerad",
    "oerigerbara": "oerigerbar",
    "oerigerbarare": "oerigerbar",
    "oerigerbarares": "oerigerbar",
    "oerigerbaras": "oerigerbar",
    "oerigerbarast": "oerigerbar",
    "oerigerbaraste": "oerigerbar",
    "oerigerbarastes": "oerigerbar",
    "oerigerbarasts": "oerigerbar",
    "oerigerbare": "oerigerbar",
    "oerigerbares": "oerigerbar",
    "oerigerbarheten": "oerigerbarhet",
    "oerigerbarhetens": "oerigerbarhet",
    "oerigerbarhets": "oerigerbarhet",
    "oerigerbars": "oerigerbar",
    "oerigerbart": "oerigerbar",
    "oerigerbarts": "oerigerbar",
    "oerkände": "oerkänd",
    "oerkändes": "oerkänd",
    "oerkänds": "oerkänd",
    "oerkänt": "oerkänd",
    "oerkänts": "oerkänd",
    "oeroderade": "oeroderad",
    "oeroderades": "oeroderad",
    "oeroderads": "oeroderad",
    "oeroderat": "oeroderad",
    "oeroderats": "oeroderad",
    "oeroderbara": "oeroderbar",
    "oeroderbarare": "oeroderbar",
    "oeroderbarares": "oeroderbar",
    "oeroderbaras": "oeroderbar",
    "oeroderbarast": "oeroderbar",
    "oeroderbaraste": "oeroderbar",
    "oeroderbarastes": "oeroderbar",
    "oeroderbarasts": "oeroderbar",
    "oeroderbare": "oeroderbar",
    "oeroderbares": "oeroderbar",
    "oeroderbarheten": "oeroderbarhet",
    "oeroderbarhetens": "oeroderbarhet",
    "oeroderbarhets": "oeroderbarhet",
    "oeroderbars": "oeroderbar",
    "oeroderbart": "oeroderbar",
    "oeroderbarts": "oeroderbar",
    "oersättliga": "oersättlig",
    "oersättligare": "oersättlig",
    "oersättligares": "oersättlig",
    "oersättligas": "oersättlig",
    "oersättligast": "oersättlig",
    "oersättligaste": "oersättlig",
    "oersättligastes": "oersättlig",
    "oersättligasts": "oersättlig",
    "oersättlige": "oersättlig",
    "oersättliges": "oersättlig",
    "oersättligheten": "oersättlighet",
    "oersättlighetens": "oersättlighet",
    "oersättlighets": "oersättlighet",
    "oersättligs": "oersättlig",
    "oersättligt": "oersättlig",
    "oersättligts": "oersättlig",
    "oertappade": "oertappad",
    "oertappades": "oertappad",
    "oertappads": "oertappad",
    "oertappat": "oertappad",
    "oertappats": "oertappad",
    "oerövrade": "oerövrad",
    "oerövrades": "oerövrad",
    "oerövrads": "oerövrad",
    "oerövrat": "oerövrad",
    "oerövrats": "oerövrad",
    "oeskalerade": "oeskalerad",
    "oeskalerades": "oeskalerad",
    "oeskalerads": "oeskalerad",
    "oeskalerat": "oeskalerad",
    "oeskalerats": "oeskalerad",
    "oeskalerbara": "oeskalerbar",
    "oeskalerbarare": "oeskalerbar",
    "oeskalerbarares": "oeskalerbar",
    "oeskalerbaras": "oeskalerbar",
    "oeskalerbarast": "oeskalerbar",
    "oeskalerbaraste": "oeskalerbar",
    "oeskalerbarastes": "oeskalerbar",
    "oeskalerbarasts": "oeskalerbar",
    "oeskalerbare": "oeskalerbar",
    "oeskalerbares": "oeskalerbar",
    "oeskalerbarheten": "oeskalerbarhet",
    "oeskalerbarhetens": "oeskalerbarhet",
    "oeskalerbarhets": "oeskalerbarhet",
    "oeskalerbars": "oeskalerbar",
    "oeskalerbart": "oeskalerbar",
    "oeskalerbarts": "oeskalerbar",
    "oeskorterade": "oeskorterad",
    "oeskorterades": "oeskorterad",
    "oeskorterads": "oeskorterad",
    "oeskorterat": "oeskorterad",
    "oeskorterats": "oeskorterad",
    "oeskorterbara": "oeskorterbar",
    "oeskorterbarare": "oeskorterbar",
    "oeskorterbarares": "oeskorterbar",
    "oeskorterbaras": "oeskorterbar",
    "oeskorterbarast": "oeskorterbar",
    "oeskorterbaraste": "oeskorterbar",
    "oeskorterbarastes": "oeskorterbar",
    "oeskorterbarasts": "oeskorterbar",
    "oeskorterbare": "oeskorterbar",
    "oeskorterbares": "oeskorterbar",
    "oeskorterbarheten": "oeskorterbarhet",
    "oeskorterbarhetens": "oeskorterbarhet",
    "oeskorterbarhets": "oeskorterbarhet",
    "oeskorterbars": "oeskorterbar",
    "oeskorterbart": "oeskorterbar",
    "oeskorterbarts": "oeskorterbar",
    "oesteticerade": "oesteticerad",
    "oesteticerades": "oesteticerad",
    "oesteticerads": "oesteticerad",
    "oesteticerat": "oesteticerad",
    "oesteticerats": "oesteticerad",
    "oesteticerbara": "oesteticerbar",
    "oesteticerbarare": "oesteticerbar",
    "oesteticerbarares": "oesteticerbar",
    "oesteticerbaras": "oesteticerbar",
    "oesteticerbarast": "oesteticerbar",
    "oesteticerbaraste": "oesteticerbar",
    "oesteticerbarastes": "oesteticerbar",
    "oesteticerbarasts": "oesteticerbar",
    "oesteticerbare": "oesteticerbar",
    "oesteticerbares": "oesteticerbar",
    "oesteticerbarheten": "oesteticerbarhet",
    "oesteticerbarhetens": "oesteticerbarhet",
    "oesteticerbarhets": "oesteticerbarhet",
    "oesteticerbars": "oesteticerbar",
    "oesteticerbart": "oesteticerbar",
    "oesteticerbarts": "oesteticerbar",
    "oestetiserade": "oestetiserad",
    "oestetiserades": "oestetiserad",
    "oestetiserads": "oestetiserad",
    "oestetiserat": "oestetiserad",
    "oestetiserats": "oestetiserad",
    "oestetiserbara": "oestetiserbar",
    "oestetiserbarare": "oestetiserbar",
    "oestetiserbarares": "oestetiserbar",
    "oestetiserbaras": "oestetiserbar",
    "oestetiserbarast": "oestetiserbar",
    "oestetiserbaraste": "oestetiserbar",
    "oestetiserbarastes": "oestetiserbar",
    "oestetiserbarasts": "oestetiserbar",
    "oestetiserbare": "oestetiserbar",
    "oestetiserbares": "oestetiserbar",
    "oestetiserbarheten": "oestetiserbarhet",
    "oestetiserbarhetens": "oestetiserbarhet",
    "oestetiserbarhets": "oestetiserbarhet",
    "oestetiserbars": "oestetiserbar",
    "oestetiserbart": "oestetiserbar",
    "oestetiserbarts": "oestetiserbar",
    "oestetiska": "oestetisk",
    "oestetiskare": "oestetisk",
    "oestetiskares": "oestetisk",
    "oestetiskas": "oestetisk",
    "oestetiskast": "oestetisk",
    "oestetiskaste": "oestetisk",
    "oestetiskastes": "oestetisk",
    "oestetiskasts": "oestetisk",
    "oestetiske": "oestetisk",
    "oestetiskes": "oestetisk",
    "oestetisks": "oestetisk",
    "oestetiskt": "oestetisk",
    "oestetiskts": "oestetisk",
    "oestimerade": "oestimerad",
    "oestimerades": "oestimerad",
    "oestimerads": "oestimerad",
    "oestimerat": "oestimerad",
    "oestimerats": "oestimerad",
    "oestimerbara": "oestimerbar",
    "oestimerbarare": "oestimerbar",
    "oestimerbarares": "oestimerbar",
    "oestimerbaras": "oestimerbar",
    "oestimerbarast": "oestimerbar",
    "oestimerbaraste": "oestimerbar",
    "oestimerbarastes": "oestimerbar",
    "oestimerbarasts": "oestimerbar",
    "oestimerbare": "oestimerbar",
    "oestimerbares": "oestimerbar",
    "oestimerbarheten": "oestimerbarhet",
    "oestimerbarhetens": "oestimerbarhet",
    "oestimerbarhets": "oestimerbarhet",
    "oestimerbars": "oestimerbar",
    "oestimerbart": "oestimerbar",
    "oestimerbarts": "oestimerbar",
    "oet": "o",
    "oetablerade": "oetablerad",
    "oetablerades": "oetablerad",
    "oetablerads": "oetablerad",
    "oetablerat": "oetablerad",
    "oetablerats": "oetablerad",
    "oetablerbara": "oetablerbar",
    "oetablerbarare": "oetablerbar",
    "oetablerbarares": "oetablerbar",
    "oetablerbaras": "oetablerbar",
    "oetablerbarast": "oetablerbar",
    "oetablerbaraste": "oetablerbar",
    "oetablerbarastes": "oetablerbar",
    "oetablerbarasts": "oetablerbar",
    "oetablerbare": "oetablerbar",
    "oetablerbares": "oetablerbar",
    "oetablerbarheten": "oetablerbarhet",
    "oetablerbarhetens": "oetablerbarhet",
    "oetablerbarhets": "oetablerbarhet",
    "oetablerbars": "oetablerbar",
    "oetablerbart": "oetablerbar",
    "oetablerbarts": "oetablerbar",
    "oeteriserade": "oeteriserad",
    "oeteriserades": "oeteriserad",
    "oeteriserads": "oeteriserad",
    "oeteriserat": "oeteriserad",
    "oeteriserats": "oeteriserad",
    "oeteriserbara": "oeteriserbar",
    "oeteriserbarare": "oeteriserbar",
    "oeteriserbarares": "oeteriserbar",
    "oeteriserbaras": "oeteriserbar",
    "oeteriserbarast": "oeteriserbar",
    "oeteriserbaraste": "oeteriserbar",
    "oeteriserbarastes": "oeteriserbar",
    "oeteriserbarasts": "oeteriserbar",
    "oeteriserbare": "oeteriserbar",
    "oeteriserbares": "oeteriserbar",
    "oeteriserbarheten": "oeteriserbarhet",
    "oeteriserbarhetens": "oeteriserbarhet",
    "oeteriserbarhets": "oeteriserbarhet",
    "oeteriserbars": "oeteriserbar",
    "oeteriserbart": "oeteriserbar",
    "oeteriserbarts": "oeteriserbar",
    "oetiketterade": "oetiketterad",
    "oetiketterades": "oetiketterad",
    "oetiketterads": "oetiketterad",
    "oetiketterat": "oetiketterad",
    "oetiketterats": "oetiketterad",
    "oetiketterbara": "oetiketterbar",
    "oetiketterbarare": "oetiketterbar",
    "oetiketterbarares": "oetiketterbar",
    "oetiketterbaras": "oetiketterbar",
    "oetiketterbarast": "oetiketterbar",
    "oetiketterbaraste": "oetiketterbar",
    "oetiketterbarastes": "oetiketterbar",
    "oetiketterbarasts": "oetiketterbar",
    "oetiketterbare": "oetiketterbar",
    "oetiketterbares": "oetiketterbar",
    "oetiketterbarheten": "oetiketterbarhet",
    "oetiketterbarhetens": "oetiketterbarhet",
    "oetiketterbarhets": "oetiketterbarhet",
    "oetiketterbars": "oetiketterbar",
    "oetiketterbart": "oetiketterbar",
    "oetiketterbarts": "oetiketterbar",
    "oets": "o",
    "oetsade": "oetsad",
    "oetsades": "oetsad",
    "oetsads": "oetsad",
    "oetsat": "oetsad",
    "oetsats": "oetsad",
    "oetymologiserade": "oetymologiserad",
    "oetymologiserades": "oetymologiserad",
    "oetymologiserads": "oetymologiserad",
    "oetymologiserat": "oetymologiserad",
    "oetymologiserats": "oetymologiserad",
    "oetymologiserbara": "oetymologiserbar",
    "oetymologiserbarare": "oetymologiserbar",
    "oetymologiserbarares": "oetymologiserbar",
    "oetymologiserbaras": "oetymologiserbar",
    "oetymologiserbarast": "oetymologiserbar",
    "oetymologiserbaraste": "oetymologiserbar",
    "oetymologiserbarastes": "oetymologiserbar",
    "oetymologiserbarasts": "oetymologiserbar",
    "oetymologiserbare": "oetymologiserbar",
    "oetymologiserbares": "oetymologiserbar",
    "oetymologiserbarheten": "oetymologiserbarhet",
    "oetymologiserbarhetens": "oetymologiserbarhet",
    "oetymologiserbarhets": "oetymologiserbarhet",
    "oetymologiserbars": "oetymologiserbar",
    "oetymologiserbart": "oetymologiserbar",
    "oetymologiserbarts": "oetymologiserbar",
    "oeuropeiserade": "oeuropeiserad",
    "oeuropeiserades": "oeuropeiserad",
    "oeuropeiserads": "oeuropeiserad",
    "oeuropeiserat": "oeuropeiserad",
    "oeuropeiserats": "oeuropeiserad",
    "oeuropeiserbara": "oeuropeiserbar",
    "oeuropeiserbarare": "oeuropeiserbar",
    "oeuropeiserbarares": "oeuropeiserbar",
    "oeuropeiserbaras": "oeuropeiserbar",
    "oeuropeiserbarast": "oeuropeiserbar",
    "oeuropeiserbaraste": "oeuropeiserbar",
    "oeuropeiserbarastes": "oeuropeiserbar",
    "oeuropeiserbarasts": "oeuropeiserbar",
    "oeuropeiserbare": "oeuropeiserbar",
    "oeuropeiserbares": "oeuropeiserbar",
    "oeuropeiserbarheten": "oeuropeiserbarhet",
    "oeuropeiserbarhetens": "oeuropeiserbarhet",
    "oeuropeiserbarhets": "oeuropeiserbarhet",
    "oeuropeiserbars": "oeuropeiserbar",
    "oeuropeiserbart": "oeuropeiserbar",
    "oeuropeiserbarts": "oeuropeiserbar",
    "oevakuerade": "oevakuerad",
    "oevakuerades": "oevakuerad",
    "oevakuerads": "oevakuerad",
    "oevakuerat": "oevakuerad",
    "oevakuerats": "oevakuerad",
    "oevakuerbara": "oevakuerbar",
    "oevakuerbarare": "oevakuerbar",
    "oevakuerbarares": "oevakuerbar",
    "oevakuerbaras": "oevakuerbar",
    "oevakuerbarast": "oevakuerbar",
    "oevakuerbaraste": "oevakuerbar",
    "oevakuerbarastes": "oevakuerbar",
    "oevakuerbarasts": "oevakuerbar",
    "oevakuerbare": "oevakuerbar",
    "oevakuerbares": "oevakuerbar",
    "oevakuerbarheten": "oevakuerbarhet",
    "oevakuerbarhetens": "oevakuerbarhet",
    "oevakuerbarhets": "oevakuerbarhet",
    "oevakuerbars": "oevakuerbar",
    "oevakuerbart": "oevakuerbar",
    "oevakuerbarts": "oevakuerbar",
    "oevaluerade": "oevaluerad",
    "oevaluerades": "oevaluerad",
    "oevaluerads": "oevaluerad",
    "oevaluerat": "oevaluerad",
    "oevaluerats": "oevaluerad",
    "oevaluerbara": "oevaluerbar",
    "oevaluerbarare": "oevaluerbar",
    "oevaluerbarares": "oevaluerbar",
    "oevaluerbaras": "oevaluerbar",
    "oevaluerbarast": "oevaluerbar",
    "oevaluerbaraste": "oevaluerbar",
    "oevaluerbarastes": "oevaluerbar",
    "oevaluerbarasts": "oevaluerbar",
    "oevaluerbare": "oevaluerbar",
    "oevaluerbares": "oevaluerbar",
    "oevaluerbarheten": "oevaluerbarhet",
    "oevaluerbarhetens": "oevaluerbarhet",
    "oevaluerbarhets": "oevaluerbarhet",
    "oevaluerbars": "oevaluerbar",
    "oevaluerbart": "oevaluerbar",
    "oevaluerbarts": "oevaluerbar",
    "oevalverade": "oevalverad",
    "oevalverades": "oevalverad",
    "oevalverads": "oevalverad",
    "oevalverat": "oevalverad",
    "oevalverats": "oevalverad",
    "oevalverbara": "oevalverbar",
    "oevalverbarare": "oevalverbar",
    "oevalverbarares": "oevalverbar",
    "oevalverbaras": "oevalverbar",
    "oevalverbarast": "oevalverbar",
    "oevalverbaraste": "oevalverbar",
    "oevalverbarastes": "oevalverbar",
    "oevalverbarasts": "oevalverbar",
    "oevalverbare": "oevalverbar",
    "oevalverbares": "oevalverbar",
    "oevalverbarheten": "oevalverbarhet",
    "oevalverbarhetens": "oevalverbarhet",
    "oevalverbarhets": "oevalverbarhet",
    "oevalverbars": "oevalverbar",
    "oevalverbart": "oevalverbar",
    "oevalverbarts": "oevalverbar",
    "oevaporerade": "oevaporerad",
    "oevaporerades": "oevaporerad",
    "oevaporerads": "oevaporerad",
    "oevaporerat": "oevaporerad",
    "oevaporerats": "oevaporerad",
    "oevaporerbara": "oevaporerbar",
    "oevaporerbarare": "oevaporerbar",
    "oevaporerbarares": "oevaporerbar",
    "oevaporerbaras": "oevaporerbar",
    "oevaporerbarast": "oevaporerbar",
    "oevaporerbaraste": "oevaporerbar",
    "oevaporerbarastes": "oevaporerbar",
    "oevaporerbarasts": "oevaporerbar",
    "oevaporerbare": "oevaporerbar",
    "oevaporerbares": "oevaporerbar",
    "oevaporerbarheten": "oevaporerbarhet",
    "oevaporerbarhetens": "oevaporerbarhet",
    "oevaporerbarhets": "oevaporerbarhet",
    "oevaporerbars": "oevaporerbar",
    "oevaporerbart": "oevaporerbar",
    "oevaporerbarts": "oevaporerbar",
    "oexaminerade": "oexaminerad",
    "oexaminerades": "oexaminerad",
    "oexaminerads": "oexaminerad",
    "oexaminerat": "oexaminerad",
    "oexaminerats": "oexaminerad",
    "oexaminerbara": "oexaminerbar",
    "oexaminerbarare": "oexaminerbar",
    "oexaminerbarares": "oexaminerbar",
    "oexaminerbaras": "oexaminerbar",
    "oexaminerbarast": "oexaminerbar",
    "oexaminerbaraste": "oexaminerbar",
    "oexaminerbarastes": "oexaminerbar",
    "oexaminerbarasts": "oexaminerbar",
    "oexaminerbare": "oexaminerbar",
    "oexaminerbares": "oexaminerbar",
    "oexaminerbarheten": "oexaminerbarhet",
    "oexaminerbarhetens": "oexaminerbarhet",
    "oexaminerbarhets": "oexaminerbarhet",
    "oexaminerbars": "oexaminerbar",
    "oexaminerbart": "oexaminerbar",
    "oexaminerbarts": "oexaminerbar",
    "oexcerperade": "oexcerperad",
    "oexcerperades": "oexcerperad",
    "oexcerperads": "oexcerperad",
    "oexcerperat": "oexcerperad",
    "oexcerperats": "oexcerperad",
    "oexcerperbara": "oexcerperbar",
    "oexcerperbarare": "oexcerperbar",
    "oexcerperbarares": "oexcerperbar",
    "oexcerperbaras": "oexcerperbar",
    "oexcerperbarast": "oexcerperbar",
    "oexcerperbaraste": "oexcerperbar",
    "oexcerperbarastes": "oexcerperbar",
    "oexcerperbarasts": "oexcerperbar",
    "oexcerperbare": "oexcerperbar",
    "oexcerperbares": "oexcerperbar",
    "oexcerperbarheten": "oexcerperbarhet",
    "oexcerperbarhetens": "oexcerperbarhet",
    "oexcerperbarhets": "oexcerperbarhet",
    "oexcerperbars": "oexcerperbar",
    "oexcerperbart": "oexcerperbar",
    "oexcerperbarts": "oexcerperbar",
    "oexciterade": "oexciterad",
    "oexciterades": "oexciterad",
    "oexciterads": "oexciterad",
    "oexciterat": "oexciterad",
    "oexciterats": "oexciterad",
    "oexciterbara": "oexciterbar",
    "oexciterbarare": "oexciterbar",
    "oexciterbarares": "oexciterbar",
    "oexciterbaras": "oexciterbar",
    "oexciterbarast": "oexciterbar",
    "oexciterbaraste": "oexciterbar",
    "oexciterbarastes": "oexciterbar",
    "oexciterbarasts": "oexciterbar",
    "oexciterbare": "oexciterbar",
    "oexciterbares": "oexciterbar",
    "oexciterbarheten": "oexciterbarhet",
    "oexciterbarhetens": "oexciterbarhet",
    "oexciterbarhets": "oexciterbarhet",
    "oexciterbars": "oexciterbar",
    "oexciterbart": "oexciterbar",
    "oexciterbarts": "oexciterbar",
    "oexekverade": "oexekverad",
    "oexekverades": "oexekverad",
    "oexekverads": "oexekverad",
    "oexekverat": "oexekverad",
    "oexekverats": "oexekverad",
    "oexekverbara": "oexekverbar",
    "oexekverbarare": "oexekverbar",
    "oexekverbarares": "oexekverbar",
    "oexekverbaras": "oexekverbar",
    "oexekverbarast": "oexekverbar",
    "oexekverbaraste": "oexekverbar",
    "oexekverbarastes": "oexekverbar",
    "oexekverbarasts": "oexekverbar",
    "oexekverbare": "oexekverbar",
    "oexekverbares": "oexekverbar",
    "oexekverbarheten": "oexekverbarhet",
    "oexekverbarhetens": "oexekverbarhet",
    "oexekverbarhets": "oexekverbarhet",
    "oexekverbars": "oexekverbar",
    "oexekverbart": "oexekverbar",
    "oexekverbarts": "oexekverbar",
    "oexemplifierade": "oexemplifierad",
    "oexemplifierades": "oexemplifierad",
    "oexemplifierads": "oexemplifierad",
    "oexemplifierat": "oexemplifierad",
    "oexemplifierats": "oexemplifierad",
    "oexemplifierbara": "oexemplifierbar",
    "oexemplifierbarare": "oexemplifierbar",
    "oexemplifierbarares": "oexemplifierbar",
    "oexemplifierbaras": "oexemplifierbar",
    "oexemplifierbarast": "oexemplifierbar",
    "oexemplifierbaraste": "oexemplifierbar",
    "oexemplifierbarastes": "oexemplifierbar",
    "oexemplifierbarasts": "oexemplifierbar",
    "oexemplifierbare": "oexemplifierbar",
    "oexemplifierbares": "oexemplifierbar",
    "oexemplifierbarheten": "oexemplifierbarhet",
    "oexemplifierbarhetens": "oexemplifierbarhet",
    "oexemplifierbarhets": "oexemplifierbarhet",
    "oexemplifierbars": "oexemplifierbar",
    "oexemplifierbart": "oexemplifierbar",
    "oexemplifierbarts": "oexemplifierbar",
    "oexercerade": "oexercerad",
    "oexercerades": "oexercerad",
    "oexercerads": "oexercerad",
    "oexercerat": "oexercerad",
    "oexercerats": "oexercerad",
    "oexercerbara": "oexercerbar",
    "oexercerbarare": "oexercerbar",
    "oexercerbarares": "oexercerbar",
    "oexercerbaras": "oexercerbar",
    "oexercerbarast": "oexercerbar",
    "oexercerbaraste": "oexercerbar",
    "oexercerbarastes": "oexercerbar",
    "oexercerbarasts": "oexercerbar",
    "oexercerbare": "oexercerbar",
    "oexercerbares": "oexercerbar",
    "oexercerbarheten": "oexercerbarhet",
    "oexercerbarhetens": "oexercerbarhet",
    "oexercerbarhets": "oexercerbarhet",
    "oexercerbars": "oexercerbar",
    "oexercerbart": "oexercerbar",
    "oexercerbarts": "oexercerbar",
    "oexkluderade": "oexkluderad",
    "oexkluderades": "oexkluderad",
    "oexkluderads": "oexkluderad",
    "oexkluderat": "oexkluderad",
    "oexkluderats": "oexkluderad",
    "oexkluderbara": "oexkluderbar",
    "oexkluderbarare": "oexkluderbar",
    "oexkluderbarares": "oexkluderbar",
    "oexkluderbaras": "oexkluderbar",
    "oexkluderbarast": "oexkluderbar",
    "oexkluderbaraste": "oexkluderbar",
    "oexkluderbarastes": "oexkluderbar",
    "oexkluderbarasts": "oexkluderbar",
    "oexkluderbare": "oexkluderbar",
    "oexkluderbares": "oexkluderbar",
    "oexkluderbarheten": "oexkluderbarhet",
    "oexkluderbarhetens": "oexkluderbarhet",
    "oexkluderbarhets": "oexkluderbarhet",
    "oexkluderbars": "oexkluderbar",
    "oexkluderbart": "oexkluderbar",
    "oexkluderbarts": "oexkluderbar",
    "oexkommunicerade": "oexkommunicerad",
    "oexkommunicerades": "oexkommunicerad",
    "oexkommunicerads": "oexkommunicerad",
    "oexkommunicerat": "oexkommunicerad",
    "oexkommunicerats": "oexkommunicerad",
    "oexkommunicerbara": "oexkommunicerbar",
    "oexkommunicerbarare": "oexkommunicerbar",
    "oexkommunicerbarares": "oexkommunicerbar",
    "oexkommunicerbaras": "oexkommunicerbar",
    "oexkommunicerbarast": "oexkommunicerbar",
    "oexkommunicerbaraste": "oexkommunicerbar",
    "oexkommunicerbarastes": "oexkommunicerbar",
    "oexkommunicerbarasts": "oexkommunicerbar",
    "oexkommunicerbare": "oexkommunicerbar",
    "oexkommunicerbares": "oexkommunicerbar",
    "oexkommunicerbarheten": "oexkommunicerbarhet",
    "oexkommunicerbarhetens": "oexkommunicerbarhet",
    "oexkommunicerbarhets": "oexkommunicerbarhet",
    "oexkommunicerbars": "oexkommunicerbar",
    "oexkommunicerbart": "oexkommunicerbar",
    "oexkommunicerbarts": "oexkommunicerbar",
    "oexpanderade": "oexpanderad",
    "oexpanderades": "oexpanderad",
    "oexpanderads": "oexpanderad",
    "oexpanderat": "oexpanderad",
    "oexpanderats": "oexpanderad",
    "oexpanderbara": "oexpanderbar",
    "oexpanderbarare": "oexpanderbar",
    "oexpanderbarares": "oexpanderbar",
    "oexpanderbaras": "oexpanderbar",
    "oexpanderbarast": "oexpanderbar",
    "oexpanderbaraste": "oexpanderbar",
    "oexpanderbarastes": "oexpanderbar",
    "oexpanderbarasts": "oexpanderbar",
    "oexpanderbare": "oexpanderbar",
    "oexpanderbares": "oexpanderbar",
    "oexpanderbarheten": "oexpanderbarhet",
    "oexpanderbarhetens": "oexpanderbarhet",
    "oexpanderbarhets": "oexpanderbarhet",
    "oexpanderbars": "oexpanderbar",
    "oexpanderbart": "oexpanderbar",
    "oexpanderbarts": "oexpanderbar",
    "oexpatrierade": "oexpatrierad",
    "oexpatrierades": "oexpatrierad",
    "oexpatrierads": "oexpatrierad",
    "oexpatrierat": "oexpatrierad",
    "oexpatrierats": "oexpatrierad",
    "oexpatrierbara": "oexpatrierbar",
    "oexpatrierbarare": "oexpatrierbar",
    "oexpatrierbarares": "oexpatrierbar",
    "oexpatrierbaras": "oexpatrierbar",
    "oexpatrierbarast": "oexpatrierbar",
    "oexpatrierbaraste": "oexpatrierbar",
    "oexpatrierbarastes": "oexpatrierbar",
    "oexpatrierbarasts": "oexpatrierbar",
    "oexpatrierbare": "oexpatrierbar",
    "oexpatrierbares": "oexpatrierbar",
    "oexpatrierbarheten": "oexpatrierbarhet",
    "oexpatrierbarhetens": "oexpatrierbarhet",
    "oexpatrierbarhets": "oexpatrierbarhet",
    "oexpatrierbars": "oexpatrierbar",
    "oexpatrierbart": "oexpatrierbar",
    "oexpatrierbarts": "oexpatrierbar",
    "oexpedierade": "oexpedierad",
    "oexpedierades": "oexpedierad",
    "oexpedierads": "oexpedierad",
    "oexpedierat": "oexpedierad",
    "oexpedierats": "oexpedierad",
    "oexpedierbara": "oexpedierbar",
    "oexpedierbarare": "oexpedierbar",
    "oexpedierbarares": "oexpedierbar",
    "oexpedierbaras": "oexpedierbar",
    "oexpedierbarast": "oexpedierbar",
    "oexpedierbaraste": "oexpedierbar",
    "oexpedierbarastes": "oexpedierbar",
    "oexpedierbarasts": "oexpedierbar",
    "oexpedierbare": "oexpedierbar",
    "oexpedierbares": "oexpedierbar",
    "oexpedierbarheten": "oexpedierbarhet",
    "oexpedierbarhetens": "oexpedierbarhet",
    "oexpedierbarhets": "oexpedierbarhet",
    "oexpedierbars": "oexpedierbar",
    "oexpedierbart": "oexpedierbar",
    "oexpedierbarts": "oexpedierbar",
    "oexpektorerade": "oexpektorerad",
    "oexpektorerades": "oexpektorerad",
    "oexpektorerads": "oexpektorerad",
    "oexpektorerat": "oexpektorerad",
    "oexpektorerats": "oexpektorerad",
    "oexpektorerbara": "oexpektorerbar",
    "oexpektorerbarare": "oexpektorerbar",
    "oexpektorerbarares": "oexpektorerbar",
    "oexpektorerbaras": "oexpektorerbar",
    "oexpektorerbarast": "oexpektorerbar",
    "oexpektorerbaraste": "oexpektorerbar",
    "oexpektorerbarastes": "oexpektorerbar",
    "oexpektorerbarasts": "oexpektorerbar",
    "oexpektorerbare": "oexpektorerbar",
    "oexpektorerbares": "oexpektorerbar",
    "oexpektorerbarheten": "oexpektorerbarhet",
    "oexpektorerbarhetens": "oexpektorerbarhet",
    "oexpektorerbarhets": "oexpektorerbarhet",
    "oexpektorerbars": "oexpektorerbar",
    "oexpektorerbart": "oexpektorerbar",
    "oexpektorerbarts": "oexpektorerbar",
    "oexplicerade": "oexplicerad",
    "oexplicerades": "oexplicerad",
    "oexplicerads": "oexplicerad",
    "oexplicerat": "oexplicerad",
    "oexplicerats": "oexplicerad",
    "oexplicerbara": "oexplicerbar",
    "oexplicerbarare": "oexplicerbar",
    "oexplicerbarares": "oexplicerbar",
    "oexplicerbaras": "oexplicerbar",
    "oexplicerbarast": "oexplicerbar",
    "oexplicerbaraste": "oexplicerbar",
    "oexplicerbarastes": "oexplicerbar",
    "oexplicerbarasts": "oexplicerbar",
    "oexplicerbare": "oexplicerbar",
    "oexplicerbares": "oexplicerbar",
    "oexplicerbarheten": "oexplicerbarhet",
    "oexplicerbarhetens": "oexplicerbarhet",
    "oexplicerbarhets": "oexplicerbarhet",
    "oexplicerbars": "oexplicerbar",
    "oexplicerbart": "oexplicerbar",
    "oexplicerbarts": "oexplicerbar",
    "oexploaterade": "oexploaterad",
    "oexploaterades": "oexploaterad",
    "oexploaterads": "oexploaterad",
    "oexploaterat": "oexploaterad",
    "oexploaterats": "oexploaterad",
    "oexploaterbara": "oexploaterbar",
    "oexploaterbarare": "oexploaterbar",
    "oexploaterbarares": "oexploaterbar",
    "oexploaterbaras": "oexploaterbar",
    "oexploaterbarast": "oexploaterbar",
    "oexploaterbaraste": "oexploaterbar",
    "oexploaterbarastes": "oexploaterbar",
    "oexploaterbarasts": "oexploaterbar",
    "oexploaterbare": "oexploaterbar",
    "oexploaterbares": "oexploaterbar",
    "oexploaterbarheten": "oexploaterbarhet",
    "oexploaterbarhetens": "oexploaterbarhet",
    "oexploaterbarhets": "oexploaterbarhet",
    "oexploaterbars": "oexploaterbar",
    "oexploaterbart": "oexploaterbar",
    "oexploaterbarts": "oexploaterbar",
    "oexploderade": "oexploderad",
    "oexploderades": "oexploderad",
    "oexploderads": "oexploderad",
    "oexploderat": "oexploderad",
    "oexploderats": "oexploderad",
    "oexploderbara": "oexploderbar",
    "oexploderbarare": "oexploderbar",
    "oexploderbarares": "oexploderbar",
    "oexploderbaras": "oexploderbar",
    "oexploderbarast": "oexploderbar",
    "oexploderbaraste": "oexploderbar",
    "oexploderbarastes": "oexploderbar",
    "oexploderbarasts": "oexploderbar",
    "oexploderbare": "oexploderbar",
    "oexploderbares": "oexploderbar",
    "oexploderbarheten": "oexploderbarhet",
    "oexploderbarhetens": "oexploderbarhet",
    "oexploderbarhets": "oexploderbarhet",
    "oexploderbars": "oexploderbar",
    "oexploderbart": "oexploderbar",
    "oexploderbarts": "oexploderbar",
    "oexponerade": "oexponerad",
    "oexponerades": "oexponerad",
    "oexponerads": "oexponerad",
    "oexponerat": "oexponerad",
    "oexponerats": "oexponerad",
    "oexponerbara": "oexponerbar",
    "oexponerbarare": "oexponerbar",
    "oexponerbarares": "oexponerbar",
    "oexponerbaras": "oexponerbar",
    "oexponerbarast": "oexponerbar",
    "oexponerbaraste": "oexponerbar",
    "oexponerbarastes": "oexponerbar",
    "oexponerbarasts": "oexponerbar",
    "oexponerbare": "oexponerbar",
    "oexponerbares": "oexponerbar",
    "oexponerbarheten": "oexponerbarhet",
    "oexponerbarhetens": "oexponerbarhet",
    "oexponerbarhets": "oexponerbarhet",
    "oexponerbars": "oexponerbar",
    "oexponerbart": "oexponerbar",
    "oexponerbarts": "oexponerbar",
    "oexporterade": "oexporterad",
    "oexporterades": "oexporterad",
    "oexporterads": "oexporterad",
    "oexporterat": "oexporterad",
    "oexporterats": "oexporterad",
    "oexporterbara": "oexporterbar",
    "oexporterbarare": "oexporterbar",
    "oexporterbarares": "oexporterbar",
    "oexporterbaras": "oexporterbar",
    "oexporterbarast": "oexporterbar",
    "oexporterbaraste": "oexporterbar",
    "oexporterbarastes": "oexporterbar",
    "oexporterbarasts": "oexporterbar",
    "oexporterbare": "oexporterbar",
    "oexporterbares": "oexporterbar",
    "oexporterbarheten": "oexporterbarhet",
    "oexporterbarhetens": "oexporterbarhet",
    "oexporterbarhets": "oexporterbarhet",
    "oexporterbars": "oexporterbar",
    "oexporterbart": "oexporterbar",
    "oexporterbarts": "oexporterbar",
    "oexproprierade": "oexproprierad",
    "oexproprierades": "oexproprierad",
    "oexproprierads": "oexproprierad",
    "oexproprierat": "oexproprierad",
    "oexproprierats": "oexproprierad",
    "oexproprierbara": "oexproprierbar",
    "oexproprierbarare": "oexproprierbar",
    "oexproprierbarares": "oexproprierbar",
    "oexproprierbaras": "oexproprierbar",
    "oexproprierbarast": "oexproprierbar",
    "oexproprierbaraste": "oexproprierbar",
    "oexproprierbarastes": "oexproprierbar",
    "oexproprierbarasts": "oexproprierbar",
    "oexproprierbare": "oexproprierbar",
    "oexproprierbares": "oexproprierbar",
    "oexproprierbarheten": "oexproprierbarhet",
    "oexproprierbarhetens": "oexproprierbarhet",
    "oexproprierbarhets": "oexproprierbarhet",
    "oexproprierbars": "oexproprierbar",
    "oexproprierbart": "oexproprierbar",
    "oexproprierbarts": "oexproprierbar",
    "oexstirperade": "oexstirperad",
    "oexstirperades": "oexstirperad",
    "oexstirperads": "oexstirperad",
    "oexstirperat": "oexstirperad",
    "oexstirperats": "oexstirperad",
    "oexstirperbara": "oexstirperbar",
    "oexstirperbarare": "oexstirperbar",
    "oexstirperbarares": "oexstirperbar",
    "oexstirperbaras": "oexstirperbar",
    "oexstirperbarast": "oexstirperbar",
    "oexstirperbaraste": "oexstirperbar",
    "oexstirperbarastes": "oexstirperbar",
    "oexstirperbarasts": "oexstirperbar",
    "oexstirperbare": "oexstirperbar",
    "oexstirperbares": "oexstirperbar",
    "oexstirperbarheten": "oexstirperbarhet",
    "oexstirperbarhetens": "oexstirperbarhet",
    "oexstirperbarhets": "oexstirperbarhet",
    "oexstirperbars": "oexstirperbar",
    "oexstirperbart": "oexstirperbar",
    "oexstirperbarts": "oexstirperbar",
    "oextemporerade": "oextemporerad",
    "oextemporerades": "oextemporerad",
    "oextemporerads": "oextemporerad",
    "oextemporerat": "oextemporerad",
    "oextemporerats": "oextemporerad",
    "oextemporerbara": "oextemporerbar",
    "oextemporerbarare": "oextemporerbar",
    "oextemporerbarares": "oextemporerbar",
    "oextemporerbaras": "oextemporerbar",
    "oextemporerbarast": "oextemporerbar",
    "oextemporerbaraste": "oextemporerbar",
    "oextemporerbarastes": "oextemporerbar",
    "oextemporerbarasts": "oextemporerbar",
    "oextemporerbare": "oextemporerbar",
    "oextemporerbares": "oextemporerbar",
    "oextemporerbarheten": "oextemporerbarhet",
    "oextemporerbarhetens": "oextemporerbarhet",
    "oextemporerbarhets": "oextemporerbarhet",
    "oextemporerbars": "oextemporerbar",
    "oextemporerbart": "oextemporerbar",
    "oextemporerbarts": "oextemporerbar",
    "oextraherade": "oextraherad",
    "oextraherades": "oextraherad",
    "oextraherads": "oextraherad",
    "oextraherat": "oextraherad",
    "oextraherats": "oextraherad",
    "oextraherbara": "oextraherbar",
    "oextraherbarare": "oextraherbar",
    "oextraherbarares": "oextraherbar",
    "oextraherbaras": "oextraherbar",
    "oextraherbarast": "oextraherbar",
    "oextraherbaraste": "oextraherbar",
    "oextraherbarastes": "oextraherbar",
    "oextraherbarasts": "oextraherbar",
    "oextraherbare": "oextraherbar",
    "oextraherbares": "oextraherbar",
    "oextraherbarheten": "oextraherbarhet",
    "oextraherbarhetens": "oextraherbarhet",
    "oextraherbarhets": "oextraherbarhet",
    "oextraherbars": "oextraherbar",
    "oextraherbart": "oextraherbar",
    "oextraherbarts": "oextraherbar",
    "oextrapolerade": "oextrapolerad",
    "oextrapolerades": "oextrapolerad",
    "oextrapolerads": "oextrapolerad",
    "oextrapolerat": "oextrapolerad",
    "oextrapolerats": "oextrapolerad",
    "oextrapolerbara": "oextrapolerbar",
    "oextrapolerbarare": "oextrapolerbar",
    "oextrapolerbarares": "oextrapolerbar",
    "oextrapolerbaras": "oextrapolerbar",
    "oextrapolerbarast": "oextrapolerbar",
    "oextrapolerbaraste": "oextrapolerbar",
    "oextrapolerbarastes": "oextrapolerbar",
    "oextrapolerbarasts": "oextrapolerbar",
    "oextrapolerbare": "oextrapolerbar",
    "oextrapolerbares": "oextrapolerbar",
    "oextrapolerbarheten": "oextrapolerbarhet",
    "oextrapolerbarhetens": "oextrapolerbarhet",
    "oextrapolerbarhets": "oextrapolerbarhet",
    "oextrapolerbars": "oextrapolerbar",
    "oextrapolerbart": "oextrapolerbar",
    "oextrapolerbarts": "oextrapolerbar",
    "ofabricerade": "ofabricerad",
    "ofabricerades": "ofabricerad",
    "ofabricerads": "ofabricerad",
    "ofabricerat": "ofabricerad",
    "ofabricerats": "ofabricerad",
    "ofabricerbara": "ofabricerbar",
    "ofabricerbarare": "ofabricerbar",
    "ofabricerbarares": "ofabricerbar",
    "ofabricerbaras": "ofabricerbar",
    "ofabricerbarast": "ofabricerbar",
    "ofabricerbaraste": "ofabricerbar",
    "ofabricerbarastes": "ofabricerbar",
    "ofabricerbarasts": "ofabricerbar",
    "ofabricerbare": "ofabricerbar",
    "ofabricerbares": "ofabricerbar",
    "ofabricerbarheten": "ofabricerbarhet",
    "ofabricerbarhetens": "ofabricerbarhet",
    "ofabricerbarhets": "ofabricerbarhet",
    "ofabricerbars": "ofabricerbar",
    "ofabricerbart": "ofabricerbar",
    "ofabricerbarts": "ofabricerbar",
    "ofabulerade": "ofabulerad",
    "ofabulerades": "ofabulerad",
    "ofabulerads": "ofabulerad",
    "ofabulerat": "ofabulerad",
    "ofabulerats": "ofabulerad",
    "ofabulerbara": "ofabulerbar",
    "ofabulerbarare": "ofabulerbar",
    "ofabulerbarares": "ofabulerbar",
    "ofabulerbaras": "ofabulerbar",
    "ofabulerbarast": "ofabulerbar",
    "ofabulerbaraste": "ofabulerbar",
    "ofabulerbarastes": "ofabulerbar",
    "ofabulerbarasts": "ofabulerbar",
    "ofabulerbare": "ofabulerbar",
    "ofabulerbares": "ofabulerbar",
    "ofabulerbarheten": "ofabulerbarhet",
    "ofabulerbarhetens": "ofabulerbarhet",
    "ofabulerbarhets": "ofabulerbarhet",
    "ofabulerbars": "ofabulerbar",
    "ofabulerbart": "ofabulerbar",
    "ofabulerbarts": "ofabulerbar",
    "ofacetterade": "ofacetterad",
    "ofacetterades": "ofacetterad",
    "ofacetterads": "ofacetterad",
    "ofacetterat": "ofacetterad",
    "ofacetterats": "ofacetterad",
    "ofacetterbara": "ofacetterbar",
    "ofacetterbarare": "ofacetterbar",
    "ofacetterbarares": "ofacetterbar",
    "ofacetterbaras": "ofacetterbar",
    "ofacetterbarast": "ofacetterbar",
    "ofacetterbaraste": "ofacetterbar",
    "ofacetterbarastes": "ofacetterbar",
    "ofacetterbarasts": "ofacetterbar",
    "ofacetterbare": "ofacetterbar",
    "ofacetterbares": "ofacetterbar",
    "ofacetterbarheten": "ofacetterbarhet",
    "ofacetterbarhetens": "ofacetterbarhet",
    "ofacetterbarhets": "ofacetterbarhet",
    "ofacetterbars": "ofacetterbar",
    "ofacetterbart": "ofacetterbar",
    "ofacetterbarts": "ofacetterbar",
    "ofakturerade": "ofakturerad",
    "ofakturerades": "ofakturerad",
    "ofakturerads": "ofakturerad",
    "ofakturerat": "ofakturerad",
    "ofakturerats": "ofakturerad",
    "ofakturerbara": "ofakturerbar",
    "ofakturerbarare": "ofakturerbar",
    "ofakturerbarares": "ofakturerbar",
    "ofakturerbaras": "ofakturerbar",
    "ofakturerbarast": "ofakturerbar",
    "ofakturerbaraste": "ofakturerbar",
    "ofakturerbarastes": "ofakturerbar",
    "ofakturerbarasts": "ofakturerbar",
    "ofakturerbare": "ofakturerbar",
    "ofakturerbares": "ofakturerbar",
    "ofakturerbarheten": "ofakturerbarhet",
    "ofakturerbarhetens": "ofakturerbarhet",
    "ofakturerbarhets": "ofakturerbarhet",
    "ofakturerbars": "ofakturerbar",
    "ofakturerbart": "ofakturerbar",
    "ofakturerbarts": "ofakturerbar",
    "ofalnade": "ofalnad",
    "ofalnades": "ofalnad",
    "ofalnads": "ofalnad",
    "ofalnat": "ofalnad",
    "ofalnats": "ofalnad",
    "ofalsade": "ofalsad",
    "ofalsades": "ofalsad",
    "ofalsads": "ofalsad",
    "ofalsat": "ofalsad",
    "ofalsats": "ofalsad",
    "ofalsifierade": "ofalsifierad",
    "ofalsifierades": "ofalsifierad",
    "ofalsifierads": "ofalsifierad",
    "ofalsifierat": "ofalsifierad",
    "ofalsifierats": "ofalsifierad",
    "ofalsifierbara": "ofalsifierbar",
    "ofalsifierbarare": "ofalsifierbar",
    "ofalsifierbarares": "ofalsifierbar",
    "ofalsifierbaras": "ofalsifierbar",
    "ofalsifierbarast": "ofalsifierbar",
    "ofalsifierbaraste": "ofalsifierbar",
    "ofalsifierbarastes": "ofalsifierbar",
    "ofalsifierbarasts": "ofalsifierbar",
    "ofalsifierbare": "ofalsifierbar",
    "ofalsifierbares": "ofalsifierbar",
    "ofalsifierbarheten": "ofalsifierbarhet",
    "ofalsifierbarhetens": "ofalsifierbarhet",
    "ofalsifierbarhets": "ofalsifierbarhet",
    "ofalsifierbars": "ofalsifierbar",
    "ofalsifierbart": "ofalsifierbar",
    "ofalsifierbarts": "ofalsifierbar",
    "ofamnade": "ofamnad",
    "ofamnades": "ofamnad",
    "ofamnads": "ofamnad",
    "ofamnat": "ofamnad",
    "ofamnats": "ofamnad",
    "ofantiserade": "ofantiserad",
    "ofantiserades": "ofantiserad",
    "ofantiserads": "ofantiserad",
    "ofantiserat": "ofantiserad",
    "ofantiserats": "ofantiserad",
    "ofantiserbara": "ofantiserbar",
    "ofantiserbarare": "ofantiserbar",
    "ofantiserbarares": "ofantiserbar",
    "ofantiserbaras": "ofantiserbar",
    "ofantiserbarast": "ofantiserbar",
    "ofantiserbaraste": "ofantiserbar",
    "ofantiserbarastes": "ofantiserbar",
    "ofantiserbarasts": "ofantiserbar",
    "ofantiserbare": "ofantiserbar",
    "ofantiserbares": "ofantiserbar",
    "ofantiserbarheten": "ofantiserbarhet",
    "ofantiserbarhetens": "ofantiserbarhet",
    "ofantiserbarhets": "ofantiserbarhet",
    "ofantiserbars": "ofantiserbar",
    "ofantiserbart": "ofantiserbar",
    "ofantiserbarts": "ofantiserbar",
    "ofantliga": "ofantlig",
    "ofantligare": "ofantlig",
    "ofantligares": "ofantlig",
    "ofantligas": "ofantlig",
    "ofantligast": "ofantlig",
    "ofantligaste": "ofantlig",
    "ofantligastes": "ofantlig",
    "ofantligasts": "ofantlig",
    "ofantlige": "ofantlig",
    "ofantliges": "ofantlig",
    "ofantligheten": "ofantlighet",
    "ofantlighetens": "ofantlighet",
    "ofantlighets": "ofantlighet",
    "ofantligs": "ofantlig",
    "ofantligt": "ofantlig",
    "ofantligts": "ofantlig",
    "ofarliga": "ofarlig",
    "ofarligare": "ofarlig",
    "ofarligares": "ofarlig",
    "ofarligas": "ofarlig",
    "ofarligast": "ofarlig",
    "ofarligaste": "ofarlig",
    "ofarligastes": "ofarlig",
    "ofarligasts": "ofarlig",
    "ofarlige": "ofarlig",
    "ofarliges": "ofarlig",
    "ofarligheten": "ofarlighet",
    "ofarlighetens": "ofarlighet",
    "ofarligheter": "ofarlighet",
    "ofarligheterna": "ofarlighet",
    "ofarligheternas": "ofarlighet",
    "ofarligheters": "ofarlighet",
    "ofarlighets": "ofarlighet",
    "ofarligs": "ofarlig",
    "ofarligt": "ofarlig",
    "ofarligts": "ofarlig",
    "ofasade": "ofasad",
    "ofasades": "ofasad",
    "ofasads": "ofasad",
    "ofasat": "ofasad",
    "ofasats": "ofasad",
    "ofascinerade": "ofascinerad",
    "ofascinerades": "ofascinerad",
    "ofascinerads": "ofascinerad",
    "ofascinerat": "ofascinerad",
    "ofascinerats": "ofascinerad",
    "ofascinerbara": "ofascinerbar",
    "ofascinerbarare": "ofascinerbar",
    "ofascinerbarares": "ofascinerbar",
    "ofascinerbaras": "ofascinerbar",
    "ofascinerbarast": "ofascinerbar",
    "ofascinerbaraste": "ofascinerbar",
    "ofascinerbarastes": "ofascinerbar",
    "ofascinerbarasts": "ofascinerbar",
    "ofascinerbare": "ofascinerbar",
    "ofascinerbares": "ofascinerbar",
    "ofascinerbarheten": "ofascinerbarhet",
    "ofascinerbarhetens": "ofascinerbarhet",
    "ofascinerbarhets": "ofascinerbarhet",
    "ofascinerbars": "ofascinerbar",
    "ofascinerbart": "ofascinerbar",
    "ofascinerbarts": "ofascinerbar",
    "ofasetterade": "ofasetterad",
    "ofasetterades": "ofasetterad",
    "ofasetterads": "ofasetterad",
    "ofasetterat": "ofasetterad",
    "ofasetterats": "ofasetterad",
    "ofasetterbara": "ofasetterbar",
    "ofasetterbarare": "ofasetterbar",
    "ofasetterbarares": "ofasetterbar",
    "ofasetterbaras": "ofasetterbar",
    "ofasetterbarast": "ofasetterbar",
    "ofasetterbaraste": "ofasetterbar",
    "ofasetterbarastes": "ofasetterbar",
    "ofasetterbarasts": "ofasetterbar",
    "ofasetterbare": "ofasetterbar",
    "ofasetterbares": "ofasetterbar",
    "ofasetterbarheten": "ofasetterbarhet",
    "ofasetterbarhetens": "ofasetterbarhet",
    "ofasetterbarhets": "ofasetterbarhet",
    "ofasetterbars": "ofasetterbar",
    "ofasetterbart": "ofasetterbar",
    "ofasetterbarts": "ofasetterbar",
    "ofasonerade": "ofasonerad",
    "ofasonerades": "ofasonerad",
    "ofasonerads": "ofasonerad",
    "ofasonerat": "ofasonerad",
    "ofasonerats": "ofasonerad",
    "ofasonerbara": "ofasonerbar",
    "ofasonerbarare": "ofasonerbar",
    "ofasonerbarares": "ofasonerbar",
    "ofasonerbaras": "ofasonerbar",
    "ofasonerbarast": "ofasonerbar",
    "ofasonerbaraste": "ofasonerbar",
    "ofasonerbarastes": "ofasonerbar",
    "ofasonerbarasts": "ofasonerbar",
    "ofasonerbare": "ofasonerbar",
    "ofasonerbares": "ofasonerbar",
    "ofasonerbarheten": "ofasonerbarhet",
    "ofasonerbarhetens": "ofasonerbarhet",
    "ofasonerbarhets": "ofasonerbarhet",
    "ofasonerbars": "ofasonerbar",
    "ofasonerbart": "ofasonerbar",
    "ofasonerbarts": "ofasonerbar",
    "ofattbara": "ofattbar",
    "ofattbarare": "ofattbar",
    "ofattbarares": "ofattbar",
    "ofattbaras": "ofattbar",
    "ofattbarast": "ofattbar",
    "ofattbaraste": "ofattbar",
    "ofattbarastes": "ofattbar",
    "ofattbarasts": "ofattbar",
    "ofattbare": "ofattbar",
    "ofattbares": "ofattbar",
    "ofattbarheten": "ofattbarhet",
    "ofattbarhetens": "ofattbarhet",
    "ofattbarhets": "ofattbarhet",
    "ofattbars": "ofattbar",
    "ofattbart": "ofattbar",
    "ofattbarts": "ofattbar",
    "ofattliga": "ofattlig",
    "ofattligare": "ofattlig",
    "ofattligares": "ofattlig",
    "ofattligas": "ofattlig",
    "ofattligast": "ofattlig",
    "ofattligaste": "ofattlig",
    "ofattligastes": "ofattlig",
    "ofattligasts": "ofattlig",
    "ofattlige": "ofattlig",
    "ofattliges": "ofattlig",
    "ofattligheten": "ofattlighet",
    "ofattlighetens": "ofattlighet",
    "ofattlighets": "ofattlighet",
    "ofattligs": "ofattlig",
    "ofattligt": "ofattlig",
    "ofattligts": "ofattlig",
    "ofavoriserade": "ofavoriserad",
    "ofavoriserades": "ofavoriserad",
    "ofavoriserads": "ofavoriserad",
    "ofavoriserat": "ofavoriserad",
    "ofavoriserats": "ofavoriserad",
    "ofavoriserbara": "ofavoriserbar",
    "ofavoriserbarare": "ofavoriserbar",
    "ofavoriserbarares": "ofavoriserbar",
    "ofavoriserbaras": "ofavoriserbar",
    "ofavoriserbarast": "ofavoriserbar",
    "ofavoriserbaraste": "ofavoriserbar",
    "ofavoriserbarastes": "ofavoriserbar",
    "ofavoriserbarasts": "ofavoriserbar",
    "ofavoriserbare": "ofavoriserbar",
    "ofavoriserbares": "ofavoriserbar",
    "ofavoriserbarheten": "ofavoriserbarhet",
    "ofavoriserbarhetens": "ofavoriserbarhet",
    "ofavoriserbarhets": "ofavoriserbarhet",
    "ofavoriserbars": "ofavoriserbar",
    "ofavoriserbart": "ofavoriserbar",
    "ofavoriserbarts": "ofavoriserbar",
    "ofaxade": "ofaxad",
    "ofaxades": "ofaxad",
    "ofaxads": "ofaxad",
    "ofaxat": "ofaxad",
    "ofaxats": "ofaxad",
    "ofejade": "ofejad",
    "ofejades": "ofejad",
    "ofejads": "ofejad",
    "ofejat": "ofejad",
    "ofejats": "ofejad",
    "ofejkade": "ofejkad",
    "ofejkades": "ofejkad",
    "ofejkads": "ofejkad",
    "ofejkat": "ofejkad",
    "ofejkats": "ofejkad",
    "ofelbara": "ofelbar",
    "ofelbarare": "ofelbar",
    "ofelbarares": "ofelbar",
    "ofelbaras": "ofelbar",
    "ofelbarast": "ofelbar",
    "ofelbaraste": "ofelbar",
    "ofelbarastes": "ofelbar",
    "ofelbarasts": "ofelbar",
    "ofelbare": "ofelbar",
    "ofelbares": "ofelbar",
    "ofelbarheten": "ofelbarhet",
    "ofelbarhetens": "ofelbarhet",
    "ofelbarhets": "ofelbarhet",
    "ofelbars": "ofelbar",
    "ofelbart": "ofelbar",
    "ofelbarts": "ofelbar",
    "ofermenterade": "ofermenterad",
    "ofermenterades": "ofermenterad",
    "ofermenterads": "ofermenterad",
    "ofermenterat": "ofermenterad",
    "ofermenterats": "ofermenterad",
    "ofermenterbara": "ofermenterbar",
    "ofermenterbarare": "ofermenterbar",
    "ofermenterbarares": "ofermenterbar",
    "ofermenterbaras": "ofermenterbar",
    "ofermenterbarast": "ofermenterbar",
    "ofermenterbaraste": "ofermenterbar",
    "ofermenterbarastes": "ofermenterbar",
    "ofermenterbarasts": "ofermenterbar",
    "ofermenterbare": "ofermenterbar",
    "ofermenterbares": "ofermenterbar",
    "ofermenterbarheten": "ofermenterbarhet",
    "ofermenterbarhetens": "ofermenterbarhet",
    "ofermenterbarhets": "ofermenterbarhet",
    "ofermenterbars": "ofermenterbar",
    "ofermenterbart": "ofermenterbar",
    "ofermenterbarts": "ofermenterbar",
    "ofernissade": "ofernissad",
    "ofernissades": "ofernissad",
    "ofernissads": "ofernissad",
    "ofernissat": "ofernissad",
    "ofernissats": "ofernissad",
    "ofeterade": "ofeterad",
    "ofeterades": "ofeterad",
    "ofeterads": "ofeterad",
    "ofeterat": "ofeterad",
    "ofeterats": "ofeterad",
    "ofeterbara": "ofeterbar",
    "ofeterbarare": "ofeterbar",
    "ofeterbarares": "ofeterbar",
    "ofeterbaras": "ofeterbar",
    "ofeterbarast": "ofeterbar",
    "ofeterbaraste": "ofeterbar",
    "ofeterbarastes": "ofeterbar",
    "ofeterbarasts": "ofeterbar",
    "ofeterbare": "ofeterbar",
    "ofeterbares": "ofeterbar",
    "ofeterbarheten": "ofeterbarhet",
    "ofeterbarhetens": "ofeterbarhet",
    "ofeterbarhets": "ofeterbarhet",
    "ofeterbars": "ofeterbar",
    "ofeterbart": "ofeterbar",
    "ofeterbarts": "ofeterbar",
    "offensiva": "offensiv",
    "offensivare": "offensiv",
    "offensivares": "offensiv",
    "offensivas": "offensiv",
    "offensivast": "offensiv",
    "offensivaste": "offensiv",
    "offensivastes": "offensiv",
    "offensivasts": "offensiv",
    "offensive": "offensiv",
    "offensiven": "offensiv",
    "offensivens": "offensiv",
    "offensiver": "offensiv",
    "offensiverna": "offensiv",
    "offensivernas": "offensiv",
    "offensivers": "offensiv",
    "offensives": "offensiv",
    "offensivs": "offensiv",
    "offensivt": "offensiv",
    "offensivts": "offensiv",
    "offentliga": "offentlig",
    "offentliganställde": "offentliganställd",
    "offentliganställdes": "offentliganställd",
    "offentliganställds": "offentliganställd",
    "offentliganställt": "offentliganställd",
    "offentliganställts": "offentliganställd",
    "offentligare": "offentlig",
    "offentligares": "offentlig",
    "offentligas": "offentlig",
    "offentligast": "offentlig",
    "offentligaste": "offentlig",
    "offentligastes": "offentlig",
    "offentligasts": "offentlig",
    "offentlige": "offentlig",
    "offentliges": "offentlig",
    "offentliggjord": "offentliggöra",
    "offentliggjorda": "offentliggöra",
    "offentliggjordas": "offentliggöra",
    "offentliggjorde": "offentliggöra",
    "offentliggjordes": "offentliggöra",
    "offentliggjords": "offentliggöra",
    "offentliggjort": "offentliggöra",
    "offentliggjorts": "offentliggöra",
    "offentliggör": "offentliggöra",
    "offentliggörande": "offentliggöra",
    "offentliggöranden": "offentliggörande",
    "offentliggörandena": "offentliggörande",
    "offentliggörandenas": "offentliggörande",
    "offentliggörandens": "offentliggörande",
    "offentliggörandes": "offentliggörande",
    "offentliggörandet": "offentliggörande",
    "offentliggörandets": "offentliggörande",
    "offentliggöras": "offentliggöra",
    "offentliggöres": "offentliggöra",
    "offentliggörs": "offentliggöra",
    "offentligheten": "offentlighet",
    "offentlighetens": "offentlighet",
    "offentligheter": "offentlighet",
    "offentligheterna": "offentlighet",
    "offentligheternas": "offentlighet",
    "offentligheters": "offentlighet",
    "offentlighets": "offentlighet",
    "offentlighetsprincipen": "offentlighetsprincip",
    "offentlighetsprincipens": "offentlighetsprincip",
    "offentlighetsprincips": "offentlighetsprincip",
    "offentligs": "offentlig",
    "offentligt": "offentlig",
    "offentligts": "offentlig",
    "offer": "offra",
    "offeranoden": "offeranod",
    "offeranodens": "offeranod",
    "offeranoder": "offeranod",
    "offeranoderna": "offeranod",
    "offeranodernas": "offeranod",
    "offeranoders": "offeranod",
    "offeranods": "offeranod",
    "offerenten": "offerent",
    "offerentens": "offerent",
    "offerenter": "offerent",
    "offerenterna": "offerent",
    "offerenternas": "offerent",
    "offerenters": "offerent",
    "offerents": "offerent",
    "offererad": "offerera",
    "offererade": "offerera",
    "offererades": "offerera",
    "offererads": "offerera",
    "offererande": "offerera",
    "offereranden": "offererande",
    "offererandena": "offererande",
    "offererandenas": "offererande",
    "offererandens": "offererande",
    "offererandes": "offererande",
    "offererandet": "offererande",
    "offererandets": "offererande",
    "offererar": "offerera",
    "offereras": "offerera",
    "offererat": "offerera",
    "offererats": "offerera",
    "offererbara": "offererbar",
    "offererbarare": "offererbar",
    "offererbarares": "offererbar",
    "offererbaras": "offererbar",
    "offererbarast": "offererbar",
    "offererbaraste": "offererbar",
    "offererbarastes": "offererbar",
    "offererbarasts": "offererbar",
    "offererbare": "offererbar",
    "offererbares": "offererbar",
    "offererbarheten": "offererbarhet",
    "offererbarhetens": "offererbarhet",
    "offererbarhets": "offererbarhet",
    "offererbars": "offererbar",
    "offererbart": "offererbar",
    "offererbarts": "offererbar",
    "offereringar": "offerering",
    "offereringarna": "offerering",
    "offereringarnas": "offerering",
    "offereringars": "offerering",
    "offereringen": "offerering",
    "offereringens": "offerering",
    "offererings": "offerering",
    "offerfesten": "offerfest",
    "offerfestens": "offerfest",
    "offerfester": "offerfest",
    "offerfesterna": "offerfest",
    "offerfesternas": "offerfest",
    "offerfesters": "offerfest",
    "offerfests": "offerfest",
    "offergärden": "offergärd",
    "offergärdens": "offergärd",
    "offergärds": "offergärd",
    "offergåvan": "offergåva",
    "offergåvans": "offergåva",
    "offergåvas": "offergåva",
    "offergåve": "offergåva",
    "offergåvo": "offergåva",
    "offergåvor": "offergåva",
    "offergåvorna": "offergåva",
    "offergåvornas": "offergåva",
    "offergåvors": "offergåva",
    "offerkist": "offerkista",
    "offerkistan": "offerkista",
    "offerkistans": "offerkista",
    "offerkistas": "offerkista",
    "offerkiste": "offerkista",
    "offerkistor": "offerkista",
    "offerkistorna": "offerkista",
    "offerkistornas": "offerkista",
    "offerkistors": "offerkista",
    "offerlammen": "offerlamm",
    "offerlammens": "offerlamm",
    "offerlammet": "offerlamm",
    "offerlammets": "offerlamm",
    "offerlamms": "offerlamm",
    "offerriten": "offerrit",
    "offerritens": "offerrit",
    "offerriter": "offerrit",
    "offerriterna": "offerrit",
    "offerriternas": "offerrit",
    "offerriters": "offerrit",
    "offerrits": "offerrit",
    "offerrollen": "offerroll",
    "offerrollens": "offerroll",
    "offerroller": "offerroll",
    "offerrollerna": "offerroll",
    "offerrollernas": "offerroll",
    "offerrollers": "offerroll",
    "offerrolls": "offerroll",
    "offers": "offer",
    "offerstockar": "offerstock",
    "offerstockarna": "offerstock",
    "offerstockarnas": "offerstock",
    "offerstockars": "offerstock",
    "offerstocken": "offerstock",
    "offerstockens": "offerstock",
    "offerstocks": "offerstock",
    "offerten": "offert",
    "offertens": "offert",
    "offerter": "offert",
    "offerterna": "offert",
    "offerternas": "offert",
    "offerters": "offert",
    "offertorie": "offertorium",
    "offertorier": "offertorium",
    "offertorierna": "offertorium",
    "offertoriernas": "offertorium",
    "offertoriers": "offertorium",
    "offertoriet": "offertorium",
    "offertoriets": "offertorium",
    "offertoriums": "offertorium",
    "offerts": "offert",
    "officerar": "officerare",
    "officerare": "officer",
    "officeraren": "officerare",
    "officerarens": "officerare",
    "officerares": "officerare",
    "officerarna": "officerare",
    "officerarnas": "officerare",
    "officeren": "officer",
    "officerens": "officer",
    "officern": "officer",
    "officerns": "officer",
    "officers": "officer",
    "officerskamraten": "officerskamrat",
    "officerskamratens": "officerskamrat",
    "officerskamrater": "officerskamrat",
    "officerskamraterna": "officerskamrat",
    "officerskamraternas": "officerskamrat",
    "officerskamraters": "officerskamrat",
    "officerskamrats": "officerskamrat",
    "officerskollegan": "officerskollega",
    "officerskollegans": "officerskollega",
    "officerskollegas": "officerskollega",
    "officerskolleger": "officerskollega",
    "officerskollegerna": "officerskollega",
    "officerskollegernas": "officerskollega",
    "officerskollegers": "officerskollega",
    "officerskollegor": "officerskollega",
    "officerskollegorna": "officerskollega",
    "officerskollegornas": "officerskollega",
    "officerskollegors": "officerskollega",
    "officersmässar": "officersmäss",
    "officersmässarna": "officersmäss",
    "officersmässarnas": "officersmäss",
    "officersmässars": "officersmäss",
    "officersmässen": "officersmäss",
    "officersmässens": "officersmäss",
    "officianten": "officiant",
    "officiantens": "officiant",
    "officianter": "officiant",
    "officianterna": "officiant",
    "officianternas": "officiant",
    "officianters": "officiant",
    "officiants": "officiant",
    "officiella": "officiell",
    "officiellare": "officiell",
    "officiellares": "officiell",
    "officiellas": "officiell",
    "officiellast": "officiell",
    "officiellaste": "officiell",
    "officiellastes": "officiell",
    "officiellasts": "officiell",
    "officielle": "officiell",
    "officielles": "officiell",
    "officiells": "officiell",
    "officiellt": "officiell",
    "officiellts": "officiell",
    "officierade": "officiera",
    "officierades": "officiera",
    "officierande": "officiera",
    "officieranden": "officierande",
    "officierandena": "officierande",
    "officierandenas": "officierande",
    "officierandens": "officierande",
    "officierandes": "officierande",
    "officierandet": "officierande",
    "officierandets": "officierande",
    "officierar": "officiera",
    "officieras": "officiera",
    "officierat": "officiera",
    "officierats": "officiera",
    "officieringar": "officiering",
    "officieringarna": "officiering",
    "officieringarnas": "officiering",
    "officieringars": "officiering",
    "officieringen": "officiering",
    "officieringens": "officiering",
    "officierings": "officiering",
    "officinella": "officinell",
    "officinellare": "officinell",
    "officinellares": "officinell",
    "officinellas": "officinell",
    "officinellast": "officinell",
    "officinellaste": "officinell",
    "officinellastes": "officinell",
    "officinellasts": "officinell",
    "officinelle": "officinell",
    "officinelles": "officinell",
    "officinells": "officinell",
    "officinellt": "officinell",
    "officinellts": "officinell",
    "officinen": "officin",
    "officinens": "officin",
    "officiner": "officin",
    "officinerna": "officin",
    "officinernas": "officin",
    "officiners": "officin",
    "officins": "officin",
    "officiösa": "officiös",
    "officiösare": "officiös",
    "officiösares": "officiös",
    "officiösas": "officiös",
    "officiösast": "officiös",
    "officiösaste": "officiös",
    "officiösastes": "officiös",
    "officiösasts": "officiös",
    "officiöse": "officiös",
    "officiöses": "officiös",
    "officiöst": "officiös",
    "officiösts": "officiös",
    "offrad": "offra",
    "offrade": "offra",
    "offrades": "offra",
    "offrads": "offra",
    "offrande": "offra",
    "offranden": "offrande",
    "offrandena": "offrande",
    "offrandenas": "offrande",
    "offrandens": "offrande",
    "offrandes": "offrande",
    "offrandet": "offrande",
    "offrandets": "offrande",
    "offrar": "offra",
    "offras": "offra",
    "offrat": "offra",
    "offrats": "offra",
    "offren": "offer",
    "offrens": "offer",
    "offret": "offer",
    "offrets": "offer",
    "offseten": "offset",
    "offsetens": "offset",
    "offsets": "offset",
    "ofilade": "ofilad",
    "ofilades": "ofilad",
    "ofilads": "ofilad",
    "ofilat": "ofilad",
    "ofilats": "ofilad",
    "ofileade": "ofilead",
    "ofileades": "ofilead",
    "ofileads": "ofilead",
    "ofileat": "ofilead",
    "ofileats": "ofilead",
    "ofilerade": "ofilerad",
    "ofilerades": "ofilerad",
    "ofilerads": "ofilerad",
    "ofilerat": "ofilerad",
    "ofilerats": "ofilerad",
    "ofilerbara": "ofilerbar",
    "ofilerbarare": "ofilerbar",
    "ofilerbarares": "ofilerbar",
    "ofilerbaras": "ofilerbar",
    "ofilerbarast": "ofilerbar",
    "ofilerbaraste": "ofilerbar",
    "ofilerbarastes": "ofilerbar",
    "ofilerbarasts": "ofilerbar",
    "ofilerbare": "ofilerbar",
    "ofilerbares": "ofilerbar",
    "ofilerbarheten": "ofilerbarhet",
    "ofilerbarhetens": "ofilerbarhet",
    "ofilerbarhets": "ofilerbarhet",
    "ofilerbars": "ofilerbar",
    "ofilerbart": "ofilerbar",
    "ofilerbarts": "ofilerbar",
    "ofilmade": "ofilmad",
    "ofilmades": "ofilmad",
    "ofilmads": "ofilmad",
    "ofilmat": "ofilmad",
    "ofilmatiserade": "ofilmatiserad",
    "ofilmatiserades": "ofilmatiserad",
    "ofilmatiserads": "ofilmatiserad",
    "ofilmatiserat": "ofilmatiserad",
    "ofilmatiserats": "ofilmatiserad",
    "ofilmatiserbara": "ofilmatiserbar",
    "ofilmatiserbarare": "ofilmatiserbar",
    "ofilmatiserbarares": "ofilmatiserbar",
    "ofilmatiserbaras": "ofilmatiserbar",
    "ofilmatiserbarast": "ofilmatiserbar",
    "ofilmatiserbaraste": "ofilmatiserbar",
    "ofilmatiserbarastes": "ofilmatiserbar",
    "ofilmatiserbarasts": "ofilmatiserbar",
    "ofilmatiserbare": "ofilmatiserbar",
    "ofilmatiserbares": "ofilmatiserbar",
    "ofilmatiserbarheten": "ofilmatiserbarhet",
    "ofilmatiserbarhetens": "ofilmatiserbarhet",
    "ofilmatiserbarhets": "ofilmatiserbarhet",
    "ofilmatiserbars": "ofilmatiserbar",
    "ofilmatiserbart": "ofilmatiserbar",
    "ofilmatiserbarts": "ofilmatiserbar",
    "ofilmats": "ofilmad",
    "ofiltade": "ofiltad",
    "ofiltades": "ofiltad",
    "ofiltads": "ofiltad",
    "ofiltat": "ofiltad",
    "ofiltats": "ofiltad",
    "ofiltrerade": "ofiltrerad",
    "ofiltrerades": "ofiltrerad",
    "ofiltrerads": "ofiltrerad",
    "ofiltrerat": "ofiltrerad",
    "ofiltrerats": "ofiltrerad",
    "ofiltrerbara": "ofiltrerbar",
    "ofiltrerbarare": "ofiltrerbar",
    "ofiltrerbarares": "ofiltrerbar",
    "ofiltrerbaras": "ofiltrerbar",
    "ofiltrerbarast": "ofiltrerbar",
    "ofiltrerbaraste": "ofiltrerbar",
    "ofiltrerbarastes": "ofiltrerbar",
    "ofiltrerbarasts": "ofiltrerbar",
    "ofiltrerbare": "ofiltrerbar",
    "ofiltrerbares": "ofiltrerbar",
    "ofiltrerbarheten": "ofiltrerbarhet",
    "ofiltrerbarhetens": "ofiltrerbarhet",
    "ofiltrerbarhets": "ofiltrerbarhet",
    "ofiltrerbars": "ofiltrerbar",
    "ofiltrerbart": "ofiltrerbar",
    "ofiltrerbarts": "ofiltrerbar",
    "ofimpade": "ofimpad",
    "ofimpades": "ofimpad",
    "ofimpads": "ofimpad",
    "ofimpat": "ofimpad",
    "ofimpats": "ofimpad",
    "ofina": "ofin",
    "ofinansierade": "ofinansierad",
    "ofinansierades": "ofinansierad",
    "ofinansierads": "ofinansierad",
    "ofinansierat": "ofinansierad",
    "ofinansierats": "ofinansierad",
    "ofinansierbara": "ofinansierbar",
    "ofinansierbarare": "ofinansierbar",
    "ofinansierbarares": "ofinansierbar",
    "ofinansierbaras": "ofinansierbar",
    "ofinansierbarast": "ofinansierbar",
    "ofinansierbaraste": "ofinansierbar",
    "ofinansierbarastes": "ofinansierbar",
    "ofinansierbarasts": "ofinansierbar",
    "ofinansierbare": "ofinansierbar",
    "ofinansierbares": "ofinansierbar",
    "ofinansierbarheten": "ofinansierbarhet",
    "ofinansierbarhetens": "ofinansierbarhet",
    "ofinansierbarhets": "ofinansierbarhet",
    "ofinansierbars": "ofinansierbar",
    "ofinansierbart": "ofinansierbar",
    "ofinansierbarts": "ofinansierbar",
    "ofinare": "ofin",
    "ofinares": "ofin",
    "ofinas": "ofin",
    "ofinast": "ofin",
    "ofinaste": "ofin",
    "ofinastes": "ofin",
    "ofinasts": "ofin",
    "ofine": "ofin",
    "ofines": "ofin",
    "ofingerade": "ofingerad",
    "ofingerades": "ofingerad",
    "ofingerads": "ofingerad",
    "ofingerat": "ofingerad",
    "ofingerats": "ofingerad",
    "ofingerbara": "ofingerbar",
    "ofingerbarare": "ofingerbar",
    "ofingerbarares": "ofingerbar",
    "ofingerbaras": "ofingerbar",
    "ofingerbarast": "ofingerbar",
    "ofingerbaraste": "ofingerbar",
    "ofingerbarastes": "ofingerbar",
    "ofingerbarasts": "ofingerbar",
    "ofingerbare": "ofingerbar",
    "ofingerbares": "ofingerbar",
    "ofingerbarheten": "ofingerbarhet",
    "ofingerbarhetens": "ofingerbarhet",
    "ofingerbarhets": "ofingerbarhet",
    "ofingerbars": "ofingerbar",
    "ofingerbart": "ofingerbar",
    "ofingerbarts": "ofingerbar",
    "ofinjusterbara": "ofinjusterbar",
    "ofinjusterbarare": "ofinjusterbar",
    "ofinjusterbarares": "ofinjusterbar",
    "ofinjusterbaras": "ofinjusterbar",
    "ofinjusterbarast": "ofinjusterbar",
    "ofinjusterbaraste": "ofinjusterbar",
    "ofinjusterbarastes": "ofinjusterbar",
    "ofinjusterbarasts": "ofinjusterbar",
    "ofinjusterbare": "ofinjusterbar",
    "ofinjusterbares": "ofinjusterbar",
    "ofinjusterbarheten": "ofinjusterbarhet",
    "ofinjusterbarhetens": "ofinjusterbarhet",
    "ofinjusterbarhets": "ofinjusterbarhet",
    "ofinjusterbars": "ofinjusterbar",
    "ofinjusterbart": "ofinjusterbar",
    "ofinjusterbarts": "ofinjusterbar",
    "ofinkade": "ofinkad",
    "ofinkades": "ofinkad",
    "ofinkads": "ofinkad",
    "ofinkat": "ofinkad",
    "ofinkats": "ofinkad",
    "ofinlandiserade": "ofinlandiserad",
    "ofinlandiserades": "ofinlandiserad",
    "ofinlandiserads": "ofinlandiserad",
    "ofinlandiserat": "ofinlandiserad",
    "ofinlandiserats": "ofinlandiserad",
    "ofinlandiserbara": "ofinlandiserbar",
    "ofinlandiserbarare": "ofinlandiserbar",
    "ofinlandiserbarares": "ofinlandiserbar",
    "ofinlandiserbaras": "ofinlandiserbar",
    "ofinlandiserbarast": "ofinlandiserbar",
    "ofinlandiserbaraste": "ofinlandiserbar",
    "ofinlandiserbarastes": "ofinlandiserbar",
    "ofinlandiserbarasts": "ofinlandiserbar",
    "ofinlandiserbare": "ofinlandiserbar",
    "ofinlandiserbares": "ofinlandiserbar",
    "ofinlandiserbarheten": "ofinlandiserbarhet",
    "ofinlandiserbarhetens": "ofinlandiserbarhet",
    "ofinlandiserbarhets": "ofinlandiserbarhet",
    "ofinlandiserbars": "ofinlandiserbar",
    "ofinlandiserbart": "ofinlandiserbar",
    "ofinlandiserbarts": "ofinlandiserbar",
    "ofins": "ofin",
    "ofint": "ofin",
    "ofintade": "ofintad",
    "ofintades": "ofintad",
    "ofintads": "ofintad",
    "ofintat": "ofintad",
    "ofintats": "ofintad",
    "ofints": "ofin",
    "ofirade": "ofirad",
    "ofirades": "ofirad",
    "ofirads": "ofirad",
    "ofirat": "ofirad",
    "ofirats": "ofirad",
    "ofiskade": "ofiskad",
    "ofiskades": "ofiskad",
    "ofiskads": "ofiskad",
    "ofiskat": "ofiskad",
    "ofiskats": "ofiskad",
    "ofixade": "ofixad",
    "ofixades": "ofixad",
    "ofixads": "ofixad",
    "ofixat": "ofixad",
    "ofixats": "ofixad",
    "ofixerade": "ofixerad",
    "ofixerades": "ofixerad",
    "ofixerads": "ofixerad",
    "ofixerat": "ofixerad",
    "ofixerats": "ofixerad",
    "ofixerbara": "ofixerbar",
    "ofixerbarare": "ofixerbar",
    "ofixerbarares": "ofixerbar",
    "ofixerbaras": "ofixerbar",
    "ofixerbarast": "ofixerbar",
    "ofixerbaraste": "ofixerbar",
    "ofixerbarastes": "ofixerbar",
    "ofixerbarasts": "ofixerbar",
    "ofixerbare": "ofixerbar",
    "ofixerbares": "ofixerbar",
    "ofixerbarheten": "ofixerbarhet",
    "ofixerbarhetens": "ofixerbarhet",
    "ofixerbarhets": "ofixerbarhet",
    "ofixerbars": "ofixerbar",
    "ofixerbart": "ofixerbar",
    "ofixerbarts": "ofixerbar",
    "ofjällade": "ofjällad",
    "ofjällades": "ofjällad",
    "ofjällads": "ofjällad",
    "ofjällat": "ofjällad",
    "ofjällats": "ofjällad",
    "ofjärmade": "ofjärmad",
    "ofjärmades": "ofjärmad",
    "ofjärmads": "ofjärmad",
    "ofjärmat": "ofjärmad",
    "ofjärmats": "ofjärmad",
    "ofjättrade": "ofjättrad",
    "ofjättrades": "ofjättrad",
    "ofjättrads": "ofjättrad",
    "ofjättrat": "ofjättrad",
    "ofjättrats": "ofjättrad",
    "oflaggade": "oflaggad",
    "oflaggades": "oflaggad",
    "oflaggads": "oflaggad",
    "oflaggat": "oflaggad",
    "oflaggats": "oflaggad",
    "oflagnade": "oflagnad",
    "oflagnades": "oflagnad",
    "oflagnads": "oflagnad",
    "oflagnat": "oflagnad",
    "oflagnats": "oflagnad",
    "oflamberade": "oflamberad",
    "oflamberades": "oflamberad",
    "oflamberads": "oflamberad",
    "oflamberat": "oflamberad",
    "oflamberats": "oflamberad",
    "oflamberbara": "oflamberbar",
    "oflamberbarare": "oflamberbar",
    "oflamberbarares": "oflamberbar",
    "oflamberbaras": "oflamberbar",
    "oflamberbarast": "oflamberbar",
    "oflamberbaraste": "oflamberbar",
    "oflamberbarastes": "oflamberbar",
    "oflamberbarasts": "oflamberbar",
    "oflamberbare": "oflamberbar",
    "oflamberbares": "oflamberbar",
    "oflamberbarheten": "oflamberbarhet",
    "oflamberbarhetens": "oflamberbarhet",
    "oflamberbarhets": "oflamberbarhet",
    "oflamberbars": "oflamberbar",
    "oflamberbart": "oflamberbar",
    "oflamberbarts": "oflamberbar",
    "oflankerade": "oflankerad",
    "oflankerades": "oflankerad",
    "oflankerads": "oflankerad",
    "oflankerat": "oflankerad",
    "oflankerats": "oflankerad",
    "oflankerbara": "oflankerbar",
    "oflankerbarare": "oflankerbar",
    "oflankerbarares": "oflankerbar",
    "oflankerbaras": "oflankerbar",
    "oflankerbarast": "oflankerbar",
    "oflankerbaraste": "oflankerbar",
    "oflankerbarastes": "oflankerbar",
    "oflankerbarasts": "oflankerbar",
    "oflankerbare": "oflankerbar",
    "oflankerbares": "oflankerbar",
    "oflankerbarheten": "oflankerbarhet",
    "oflankerbarhetens": "oflankerbarhet",
    "oflankerbarhets": "oflankerbarhet",
    "oflankerbars": "oflankerbar",
    "oflankerbart": "oflankerbar",
    "oflankerbarts": "oflankerbar",
    "oflatterade": "oflatterad",
    "oflatterades": "oflatterad",
    "oflatterads": "oflatterad",
    "oflatterat": "oflatterad",
    "oflatterats": "oflatterad",
    "oflatterbara": "oflatterbar",
    "oflatterbarare": "oflatterbar",
    "oflatterbarares": "oflatterbar",
    "oflatterbaras": "oflatterbar",
    "oflatterbarast": "oflatterbar",
    "oflatterbaraste": "oflatterbar",
    "oflatterbarastes": "oflatterbar",
    "oflatterbarasts": "oflatterbar",
    "oflatterbare": "oflatterbar",
    "oflatterbares": "oflatterbar",
    "oflatterbarheten": "oflatterbarhet",
    "oflatterbarhetens": "oflatterbarhet",
    "oflatterbarhets": "oflatterbarhet",
    "oflatterbars": "oflatterbar",
    "oflatterbart": "oflatterbar",
    "oflatterbarts": "oflatterbar",
    "oflekterade": "oflekterad",
    "oflekterades": "oflekterad",
    "oflekterads": "oflekterad",
    "oflekterat": "oflekterad",
    "oflekterats": "oflekterad",
    "oflekterbara": "oflekterbar",
    "oflekterbarare": "oflekterbar",
    "oflekterbarares": "oflekterbar",
    "oflekterbaras": "oflekterbar",
    "oflekterbarast": "oflekterbar",
    "oflekterbaraste": "oflekterbar",
    "oflekterbarastes": "oflekterbar",
    "oflekterbarasts": "oflekterbar",
    "oflekterbare": "oflekterbar",
    "oflekterbares": "oflekterbar",
    "oflekterbarheten": "oflekterbarhet",
    "oflekterbarhetens": "oflekterbarhet",
    "oflekterbarhets": "oflekterbarhet",
    "oflekterbars": "oflekterbar",
    "oflekterbart": "oflekterbar",
    "oflekterbarts": "oflekterbar",
    "oflottade": "oflottad",
    "oflottades": "oflottad",
    "oflottads": "oflottad",
    "oflottat": "oflottad",
    "oflottats": "oflottad",
    "ofluidiserade": "ofluidiserad",
    "ofluidiserades": "ofluidiserad",
    "ofluidiserads": "ofluidiserad",
    "ofluidiserat": "ofluidiserad",
    "ofluidiserats": "ofluidiserad",
    "ofluidiserbara": "ofluidiserbar",
    "ofluidiserbarare": "ofluidiserbar",
    "ofluidiserbarares": "ofluidiserbar",
    "ofluidiserbaras": "ofluidiserbar",
    "ofluidiserbarast": "ofluidiserbar",
    "ofluidiserbaraste": "ofluidiserbar",
    "ofluidiserbarastes": "ofluidiserbar",
    "ofluidiserbarasts": "ofluidiserbar",
    "ofluidiserbare": "ofluidiserbar",
    "ofluidiserbares": "ofluidiserbar",
    "ofluidiserbarheten": "ofluidiserbarhet",
    "ofluidiserbarhetens": "ofluidiserbarhet",
    "ofluidiserbarhets": "ofluidiserbarhet",
    "ofluidiserbars": "ofluidiserbar",
    "ofluidiserbart": "ofluidiserbar",
    "ofluidiserbarts": "ofluidiserbar",
    "ofluorerade": "ofluorerad",
    "ofluorerades": "ofluorerad",
    "ofluorerads": "ofluorerad",
    "ofluorerat": "ofluorerad",
    "ofluorerats": "ofluorerad",
    "ofluorerbara": "ofluorerbar",
    "ofluorerbarare": "ofluorerbar",
    "ofluorerbarares": "ofluorerbar",
    "ofluorerbaras": "ofluorerbar",
    "ofluorerbarast": "ofluorerbar",
    "ofluorerbaraste": "ofluorerbar",
    "ofluorerbarastes": "ofluorerbar",
    "ofluorerbarasts": "ofluorerbar",
    "ofluorerbare": "ofluorerbar",
    "ofluorerbares": "ofluorerbar",
    "ofluorerbarheten": "ofluorerbarhet",
    "ofluorerbarhetens": "ofluorerbarhet",
    "ofluorerbarhets": "ofluorerbarhet",
    "ofluorerbars": "ofluorerbar",
    "ofluorerbart": "ofluorerbar",
    "ofluorerbarts": "ofluorerbar",
    "ofluoriderade": "ofluoriderad",
    "ofluoriderades": "ofluoriderad",
    "ofluoriderads": "ofluoriderad",
    "ofluoriderat": "ofluoriderad",
    "ofluoriderats": "ofluoriderad",
    "ofluoriderbara": "ofluoriderbar",
    "ofluoriderbarare": "ofluoriderbar",
    "ofluoriderbarares": "ofluoriderbar",
    "ofluoriderbaras": "ofluoriderbar",
    "ofluoriderbarast": "ofluoriderbar",
    "ofluoriderbaraste": "ofluoriderbar",
    "ofluoriderbarastes": "ofluoriderbar",
    "ofluoriderbarasts": "ofluoriderbar",
    "ofluoriderbare": "ofluoriderbar",
    "ofluoriderbares": "ofluoriderbar",
    "ofluoriderbarheten": "ofluoriderbarhet",
    "ofluoriderbarhetens": "ofluoriderbarhet",
    "ofluoriderbarhets": "ofluoriderbarhet",
    "ofluoriderbars": "ofluoriderbar",
    "ofluoriderbart": "ofluoriderbar",
    "ofluoriderbarts": "ofluoriderbar",
    "oflyktade": "oflyktad",
    "oflyktades": "oflyktad",
    "oflyktads": "oflyktad",
    "oflyktat": "oflyktad",
    "oflyktats": "oflyktad",
    "oflyttade": "oflyttad",
    "oflyttades": "oflyttad",
    "oflyttads": "oflyttad",
    "oflyttat": "oflyttad",
    "oflyttats": "oflyttad",
    "ofläckade": "ofläckad",
    "ofläckades": "ofläckad",
    "ofläckads": "ofläckad",
    "ofläckat": "ofläckad",
    "ofläckats": "ofläckad",
    "ofläkta": "ofläkt",
    "ofläktas": "ofläkt",
    "ofläkte": "ofläkt",
    "ofläktes": "ofläkt",
    "ofläkts": "ofläkt",
    "oflängde": "oflängd",
    "oflängdes": "oflängd",
    "oflängds": "oflängd",
    "oflängt": "oflängd",
    "oflängts": "oflängd",
    "oflänsade": "oflänsad",
    "oflänsades": "oflänsad",
    "oflänsads": "oflänsad",
    "oflänsat": "oflänsad",
    "oflänsats": "oflänsad",
    "oflätade": "oflätad",
    "oflätades": "oflätad",
    "oflätads": "oflätad",
    "oflätat": "oflätad",
    "oflätats": "oflätad",
    "oflöjlade": "oflöjlad",
    "oflöjlades": "oflöjlad",
    "oflöjlads": "oflöjlad",
    "oflöjlat": "oflöjlad",
    "oflöjlats": "oflöjlad",
    "oflöjtade": "oflöjtad",
    "oflöjtades": "oflöjtad",
    "oflöjtads": "oflöjtad",
    "oflöjtat": "oflöjtad",
    "oflöjtats": "oflöjtad",
    "ofockade": "ofockad",
    "ofockades": "ofockad",
    "ofockads": "ofockad",
    "ofockat": "ofockad",
    "ofockats": "ofockad",
    "ofodrade": "ofodrad",
    "ofodrades": "ofodrad",
    "ofodrads": "ofodrad",
    "ofodrat": "ofodrad",
    "ofodrats": "ofodrad",
    "ofogade": "ofogad",
    "ofogades": "ofogad",
    "ofogads": "ofogad",
    "ofogat": "ofogad",
    "ofogats": "ofogad",
    "ofogen": "ofog",
    "ofogens": "ofog",
    "ofoget": "ofog",
    "ofogets": "ofog",
    "ofogs": "ofog",
    "ofokuserade": "ofokuserad",
    "ofokuserades": "ofokuserad",
    "ofokuserads": "ofokuserad",
    "ofokuserat": "ofokuserad",
    "ofokuserats": "ofokuserad",
    "ofokuserbara": "ofokuserbar",
    "ofokuserbarare": "ofokuserbar",
    "ofokuserbarares": "ofokuserbar",
    "ofokuserbaras": "ofokuserbar",
    "ofokuserbarast": "ofokuserbar",
    "ofokuserbaraste": "ofokuserbar",
    "ofokuserbarastes": "ofokuserbar",
    "ofokuserbarasts": "ofokuserbar",
    "ofokuserbare": "ofokuserbar",
    "ofokuserbares": "ofokuserbar",
    "ofokuserbarheten": "ofokuserbarhet",
    "ofokuserbarhetens": "ofokuserbarhet",
    "ofokuserbarhets": "ofokuserbarhet",
    "ofokuserbars": "ofokuserbar",
    "ofokuserbart": "ofokuserbar",
    "ofokuserbarts": "ofokuserbar",
    "ofolierade": "ofolierad",
    "ofolierades": "ofolierad",
    "ofolierads": "ofolierad",
    "ofolierat": "ofolierad",
    "ofolierats": "ofolierad",
    "ofolierbara": "ofolierbar",
    "ofolierbarare": "ofolierbar",
    "ofolierbarares": "ofolierbar",
    "ofolierbaras": "ofolierbar",
    "ofolierbarast": "ofolierbar",
    "ofolierbaraste": "ofolierbar",
    "ofolierbarastes": "ofolierbar",
    "ofolierbarasts": "ofolierbar",
    "ofolierbare": "ofolierbar",
    "ofolierbares": "ofolierbar",
    "ofolierbarheten": "ofolierbarhet",
    "ofolierbarhetens": "ofolierbarhet",
    "ofolierbarhets": "ofolierbarhet",
    "ofolierbars": "ofolierbar",
    "ofolierbart": "ofolierbar",
    "ofolierbarts": "ofolierbar",
    "ofonderade": "ofonderad",
    "ofonderades": "ofonderad",
    "ofonderads": "ofonderad",
    "ofonderat": "ofonderad",
    "ofonderats": "ofonderad",
    "ofonderbara": "ofonderbar",
    "ofonderbarare": "ofonderbar",
    "ofonderbarares": "ofonderbar",
    "ofonderbaras": "ofonderbar",
    "ofonderbarast": "ofonderbar",
    "ofonderbaraste": "ofonderbar",
    "ofonderbarastes": "ofonderbar",
    "ofonderbarasts": "ofonderbar",
    "ofonderbare": "ofonderbar",
    "ofonderbares": "ofonderbar",
    "ofonderbarheten": "ofonderbarhet",
    "ofonderbarhetens": "ofonderbarhet",
    "ofonderbarhets": "ofonderbarhet",
    "ofonderbars": "ofonderbar",
    "ofonderbart": "ofonderbar",
    "ofonderbarts": "ofonderbar",
    "oforcerade": "oforcerad",
    "oforcerades": "oforcerad",
    "oforcerads": "oforcerad",
    "oforcerat": "oforcerad",
    "oforcerats": "oforcerad",
    "oforcerbara": "oforcerbar",
    "oforcerbarare": "oforcerbar",
    "oforcerbarares": "oforcerbar",
    "oforcerbaras": "oforcerbar",
    "oforcerbarast": "oforcerbar",
    "oforcerbaraste": "oforcerbar",
    "oforcerbarastes": "oforcerbar",
    "oforcerbarasts": "oforcerbar",
    "oforcerbare": "oforcerbar",
    "oforcerbares": "oforcerbar",
    "oforcerbarheten": "oforcerbarhet",
    "oforcerbarhetens": "oforcerbarhet",
    "oforcerbarhets": "oforcerbarhet",
    "oforcerbars": "oforcerbar",
    "oforcerbart": "oforcerbar",
    "oforcerbarts": "oforcerbar",
    "oforecheckade": "oforecheckad",
    "oforecheckades": "oforecheckad",
    "oforecheckads": "oforecheckad",
    "oforecheckat": "oforecheckad",
    "oforecheckats": "oforecheckad",
    "oformade": "oformad",
    "oformades": "oformad",
    "oformads": "oformad",
    "oformaliserade": "oformaliserad",
    "oformaliserades": "oformaliserad",
    "oformaliserads": "oformaliserad",
    "oformaliserat": "oformaliserad",
    "oformaliserats": "oformaliserad",
    "oformaliserbara": "oformaliserbar",
    "oformaliserbarare": "oformaliserbar",
    "oformaliserbarares": "oformaliserbar",
    "oformaliserbaras": "oformaliserbar",
    "oformaliserbarast": "oformaliserbar",
    "oformaliserbaraste": "oformaliserbar",
    "oformaliserbarastes": "oformaliserbar",
    "oformaliserbarasts": "oformaliserbar",
    "oformaliserbare": "oformaliserbar",
    "oformaliserbares": "oformaliserbar",
    "oformaliserbarheten": "oformaliserbarhet",
    "oformaliserbarhetens": "oformaliserbarhet",
    "oformaliserbarhets": "oformaliserbarhet",
    "oformaliserbars": "oformaliserbar",
    "oformaliserbart": "oformaliserbar",
    "oformaliserbarts": "oformaliserbar",
    "oformat": "oformad",
    "oformats": "oformad",
    "oformerade": "oformerad",
    "oformerades": "oformerad",
    "oformerads": "oformerad",
    "oformerat": "oformerad",
    "oformerats": "oformerad",
    "oformerbara": "oformerbar",
    "oformerbarare": "oformerbar",
    "oformerbarares": "oformerbar",
    "oformerbaras": "oformerbar",
    "oformerbarast": "oformerbar",
    "oformerbaraste": "oformerbar",
    "oformerbarastes": "oformerbar",
    "oformerbarasts": "oformerbar",
    "oformerbare": "oformerbar",
    "oformerbares": "oformerbar",
    "oformerbarheten": "oformerbarhet",
    "oformerbarhetens": "oformerbarhet",
    "oformerbarhets": "oformerbarhet",
    "oformerbars": "oformerbar",
    "oformerbart": "oformerbar",
    "oformerbarts": "oformerbar",
    "oformliga": "oformlig",
    "oformligare": "oformlig",
    "oformligares": "oformlig",
    "oformligas": "oformlig",
    "oformligast": "oformlig",
    "oformligaste": "oformlig",
    "oformligastes": "oformlig",
    "oformligasts": "oformlig",
    "oformlige": "oformlig",
    "oformliges": "oformlig",
    "oformligheten": "oformlighet",
    "oformlighetens": "oformlighet",
    "oformligheter": "oformlighet",
    "oformligheterna": "oformlighet",
    "oformligheternas": "oformlighet",
    "oformligheters": "oformlighet",
    "oformlighets": "oformlighet",
    "oformligs": "oformlig",
    "oformligt": "oformlig",
    "oformligts": "oformlig",
    "oformulerade": "oformulerad",
    "oformulerades": "oformulerad",
    "oformulerads": "oformulerad",
    "oformulerat": "oformulerad",
    "oformulerats": "oformulerad",
    "oformulerbara": "oformulerbar",
    "oformulerbarare": "oformulerbar",
    "oformulerbarares": "oformulerbar",
    "oformulerbaras": "oformulerbar",
    "oformulerbarast": "oformulerbar",
    "oformulerbaraste": "oformulerbar",
    "oformulerbarastes": "oformulerbar",
    "oformulerbarasts": "oformulerbar",
    "oformulerbare": "oformulerbar",
    "oformulerbares": "oformulerbar",
    "oformulerbarheten": "oformulerbarhet",
    "oformulerbarhetens": "oformulerbarhet",
    "oformulerbarhets": "oformulerbarhet",
    "oformulerbars": "oformulerbar",
    "oformulerbart": "oformulerbar",
    "oformulerbarts": "oformulerbar",
    "oforslade": "oforslad",
    "oforslades": "oforslad",
    "oforslads": "oforslad",
    "oforslat": "oforslad",
    "oforslats": "oforslad",
    "ofosfaterade": "ofosfaterad",
    "ofosfaterades": "ofosfaterad",
    "ofosfaterads": "ofosfaterad",
    "ofosfaterat": "ofosfaterad",
    "ofosfaterats": "ofosfaterad",
    "ofosfaterbara": "ofosfaterbar",
    "ofosfaterbarare": "ofosfaterbar",
    "ofosfaterbarares": "ofosfaterbar",
    "ofosfaterbaras": "ofosfaterbar",
    "ofosfaterbarast": "ofosfaterbar",
    "ofosfaterbaraste": "ofosfaterbar",
    "ofosfaterbarastes": "ofosfaterbar",
    "ofosfaterbarasts": "ofosfaterbar",
    "ofosfaterbare": "ofosfaterbar",
    "ofosfaterbares": "ofosfaterbar",
    "ofosfaterbarheten": "ofosfaterbarhet",
    "ofosfaterbarhetens": "ofosfaterbarhet",
    "ofosfaterbarhets": "ofosfaterbarhet",
    "ofosfaterbars": "ofosfaterbar",
    "ofosfaterbart": "ofosfaterbar",
    "ofosfaterbarts": "ofosfaterbar",
    "ofossiliserade": "ofossiliserad",
    "ofossiliserades": "ofossiliserad",
    "ofossiliserads": "ofossiliserad",
    "ofossiliserat": "ofossiliserad",
    "ofossiliserats": "ofossiliserad",
    "ofossiliserbara": "ofossiliserbar",
    "ofossiliserbarare": "ofossiliserbar",
    "ofossiliserbarares": "ofossiliserbar",
    "ofossiliserbaras": "ofossiliserbar",
    "ofossiliserbarast": "ofossiliserbar",
    "ofossiliserbaraste": "ofossiliserbar",
    "ofossiliserbarastes": "ofossiliserbar",
    "ofossiliserbarasts": "ofossiliserbar",
    "ofossiliserbare": "ofossiliserbar",
    "ofossiliserbares": "ofossiliserbar",
    "ofossiliserbarheten": "ofossiliserbarhet",
    "ofossiliserbarhetens": "ofossiliserbarhet",
    "ofossiliserbarhets": "ofossiliserbarhet",
    "ofossiliserbars": "ofossiliserbar",
    "ofossiliserbart": "ofossiliserbar",
    "ofossiliserbarts": "ofossiliserbar",
    "ofostrade": "ofostrad",
    "ofostrades": "ofostrad",
    "ofostrads": "ofostrad",
    "ofostrat": "ofostrad",
    "ofostrats": "ofostrad",
    "ofotade": "ofotad",
    "ofotades": "ofotad",
    "ofotads": "ofotad",
    "ofotat": "ofotad",
    "ofotats": "ofotad",
    "ofotograferade": "ofotograferad",
    "ofotograferades": "ofotograferad",
    "ofotograferads": "ofotograferad",
    "ofotograferat": "ofotograferad",
    "ofotograferats": "ofotograferad",
    "ofotograferbara": "ofotograferbar",
    "ofotograferbarare": "ofotograferbar",
    "ofotograferbarares": "ofotograferbar",
    "ofotograferbaras": "ofotograferbar",
    "ofotograferbarast": "ofotograferbar",
    "ofotograferbaraste": "ofotograferbar",
    "ofotograferbarastes": "ofotograferbar",
    "ofotograferbarasts": "ofotograferbar",
    "ofotograferbare": "ofotograferbar",
    "ofotograferbares": "ofotograferbar",
    "ofotograferbarheten": "ofotograferbarhet",
    "ofotograferbarhetens": "ofotograferbarhet",
    "ofotograferbarhets": "ofotograferbarhet",
    "ofotograferbars": "ofotograferbar",
    "ofotograferbart": "ofotograferbar",
    "ofotograferbarts": "ofotograferbar",
    "ofotokopierade": "ofotokopierad",
    "ofotokopierades": "ofotokopierad",
    "ofotokopierads": "ofotokopierad",
    "ofotokopierat": "ofotokopierad",
    "ofotokopierats": "ofotokopierad",
    "ofragmenterade": "ofragmenterad",
    "ofragmenterades": "ofragmenterad",
    "ofragmenterads": "ofragmenterad",
    "ofragmenterat": "ofragmenterad",
    "ofragmenterats": "ofragmenterad",
    "ofragmenterbara": "ofragmenterbar",
    "ofragmenterbarare": "ofragmenterbar",
    "ofragmenterbarares": "ofragmenterbar",
    "ofragmenterbaras": "ofragmenterbar",
    "ofragmenterbarast": "ofragmenterbar",
    "ofragmenterbaraste": "ofragmenterbar",
    "ofragmenterbarastes": "ofragmenterbar",
    "ofragmenterbarasts": "ofragmenterbar",
    "ofragmenterbare": "ofragmenterbar",
    "ofragmenterbares": "ofragmenterbar",
    "ofragmenterbarheten": "ofragmenterbarhet",
    "ofragmenterbarhetens": "ofragmenterbarhet",
    "ofragmenterbarhets": "ofragmenterbarhet",
    "ofragmenterbars": "ofragmenterbar",
    "ofragmenterbart": "ofragmenterbar",
    "ofragmenterbarts": "ofragmenterbar",
    "ofraktade": "ofraktad",
    "ofraktades": "ofraktad",
    "ofraktads": "ofraktad",
    "ofraktat": "ofraktad",
    "ofraktats": "ofraktad",
    "ofraktionerade": "ofraktionerad",
    "ofraktionerades": "ofraktionerad",
    "ofraktionerads": "ofraktionerad",
    "ofraktionerat": "ofraktionerad",
    "ofraktionerats": "ofraktionerad",
    "ofraktionerbara": "ofraktionerbar",
    "ofraktionerbarare": "ofraktionerbar",
    "ofraktionerbarares": "ofraktionerbar",
    "ofraktionerbaras": "ofraktionerbar",
    "ofraktionerbarast": "ofraktionerbar",
    "ofraktionerbaraste": "ofraktionerbar",
    "ofraktionerbarastes": "ofraktionerbar",
    "ofraktionerbarasts": "ofraktionerbar",
    "ofraktionerbare": "ofraktionerbar",
    "ofraktionerbares": "ofraktionerbar",
    "ofraktionerbarheten": "ofraktionerbarhet",
    "ofraktionerbarhetens": "ofraktionerbarhet",
    "ofraktionerbarhets": "ofraktionerbarhet",
    "ofraktionerbars": "ofraktionerbar",
    "ofraktionerbart": "ofraktionerbar",
    "ofraktionerbarts": "ofraktionerbar",
    "oframflyttade": "oframflyttad",
    "oframflyttades": "oframflyttad",
    "oframflyttads": "oframflyttad",
    "oframflyttat": "oframflyttad",
    "oframflyttats": "oframflyttad",
    "oframförde": "oframförd",
    "oframfördes": "oframförd",
    "oframförds": "oframförd",
    "oframfört": "oframförd",
    "oframförts": "oframförd",
    "oframhävde": "oframhävd",
    "oframhävdes": "oframhävd",
    "oframhävds": "oframhävd",
    "oframhävt": "oframhävd",
    "oframhävts": "oframhävd",
    "oframkallade": "oframkallad",
    "oframkallades": "oframkallad",
    "oframkallads": "oframkallad",
    "oframkallat": "oframkallad",
    "oframkallats": "oframkallad",
    "oframkastade": "oframkastad",
    "oframkastades": "oframkastad",
    "oframkastads": "oframkastad",
    "oframkastat": "oframkastad",
    "oframkastats": "oframkastad",
    "oframkomliga": "oframkomlig",
    "oframkomligare": "oframkomlig",
    "oframkomligares": "oframkomlig",
    "oframkomligas": "oframkomlig",
    "oframkomligast": "oframkomlig",
    "oframkomligaste": "oframkomlig",
    "oframkomligastes": "oframkomlig",
    "oframkomligasts": "oframkomlig",
    "oframkomlige": "oframkomlig",
    "oframkomliges": "oframkomlig",
    "oframkomligheten": "oframkomlighet",
    "oframkomlighetens": "oframkomlighet",
    "oframkomlighets": "oframkomlighet",
    "oframkomligs": "oframkomlig",
    "oframkomligt": "oframkomlig",
    "oframkomligts": "oframkomlig",
    "oframmanade": "oframmanad",
    "oframmanades": "oframmanad",
    "oframmanads": "oframmanad",
    "oframmanat": "oframmanad",
    "oframmanats": "oframmanad",
    "oframpressade": "oframpressad",
    "oframpressades": "oframpressad",
    "oframpressads": "oframpressad",
    "oframpressat": "oframpressad",
    "oframpressats": "oframpressad",
    "oframskymtade": "oframskymtad",
    "oframskymtades": "oframskymtad",
    "oframskymtads": "oframskymtad",
    "oframskymtat": "oframskymtad",
    "oframskymtats": "oframskymtad",
    "oframställde": "oframställd",
    "oframställdes": "oframställd",
    "oframställds": "oframställd",
    "oframställt": "oframställd",
    "oframställts": "oframställd",
    "oframträngde": "oframträngd",
    "oframträngdes": "oframträngd",
    "oframträngds": "oframträngd",
    "oframträngt": "oframträngd",
    "oframträngts": "oframträngd",
    "oframvisade": "oframvisad",
    "oframvisades": "oframvisad",
    "oframvisads": "oframvisad",
    "oframvisat": "oframvisad",
    "oframvisats": "oframvisad",
    "ofrankerade": "ofrankerad",
    "ofrankerades": "ofrankerad",
    "ofrankerads": "ofrankerad",
    "ofrankerat": "ofrankerad",
    "ofrankerats": "ofrankerad",
    "ofrankerbara": "ofrankerbar",
    "ofrankerbarare": "ofrankerbar",
    "ofrankerbarares": "ofrankerbar",
    "ofrankerbaras": "ofrankerbar",
    "ofrankerbarast": "ofrankerbar",
    "ofrankerbaraste": "ofrankerbar",
    "ofrankerbarastes": "ofrankerbar",
    "ofrankerbarasts": "ofrankerbar",
    "ofrankerbare": "ofrankerbar",
    "ofrankerbares": "ofrankerbar",
    "ofrankerbarheten": "ofrankerbarhet",
    "ofrankerbarhetens": "ofrankerbarhet",
    "ofrankerbarhets": "ofrankerbarhet",
    "ofrankerbars": "ofrankerbar",
    "ofrankerbart": "ofrankerbar",
    "ofrankerbarts": "ofrankerbar",
    "ofransade": "ofransad",
    "ofransades": "ofransad",
    "ofransads": "ofransad",
    "ofransat": "ofransad",
    "ofransats": "ofransad",
    "ofrapperade": "ofrapperad",
    "ofrapperades": "ofrapperad",
    "ofrapperads": "ofrapperad",
    "ofrapperat": "ofrapperad",
    "ofrapperats": "ofrapperad",
    "ofraserade": "ofraserad",
    "ofraserades": "ofraserad",
    "ofraserads": "ofraserad",
    "ofraserat": "ofraserad",
    "ofraserats": "ofraserad",
    "ofraserbara": "ofraserbar",
    "ofraserbarare": "ofraserbar",
    "ofraserbarares": "ofraserbar",
    "ofraserbaras": "ofraserbar",
    "ofraserbarast": "ofraserbar",
    "ofraserbaraste": "ofraserbar",
    "ofraserbarastes": "ofraserbar",
    "ofraserbarasts": "ofraserbar",
    "ofraserbare": "ofraserbar",
    "ofraserbares": "ofraserbar",
    "ofraserbarheten": "ofraserbarhet",
    "ofraserbarhetens": "ofraserbarhet",
    "ofraserbarhets": "ofraserbarhet",
    "ofraserbars": "ofraserbar",
    "ofraserbart": "ofraserbar",
    "ofraserbarts": "ofraserbar",
    "ofred": "ofreda",
    "ofredad": "ofreda",
    "ofredade": "ofredad",
    "ofredades": "ofredad",
    "ofredads": "ofredad",
    "ofredande": "ofreda",
    "ofredanden": "ofredande",
    "ofredandena": "ofredande",
    "ofredandenas": "ofredande",
    "ofredandens": "ofredande",
    "ofredandes": "ofredande",
    "ofredandet": "ofredande",
    "ofredandets": "ofredande",
    "ofredar": "ofreda",
    "ofredas": "ofreda",
    "ofredat": "ofredad",
    "ofredats": "ofredad",
    "ofreden": "ofred",
    "ofredens": "ofred",
    "ofreds": "ofred",
    "ofrekventerade": "ofrekventerad",
    "ofrekventerades": "ofrekventerad",
    "ofrekventerads": "ofrekventerad",
    "ofrekventerat": "ofrekventerad",
    "ofrekventerats": "ofrekventerad",
    "ofrekventerbara": "ofrekventerbar",
    "ofrekventerbarare": "ofrekventerbar",
    "ofrekventerbarares": "ofrekventerbar",
    "ofrekventerbaras": "ofrekventerbar",
    "ofrekventerbarast": "ofrekventerbar",
    "ofrekventerbaraste": "ofrekventerbar",
    "ofrekventerbarastes": "ofrekventerbar",
    "ofrekventerbarasts": "ofrekventerbar",
    "ofrekventerbare": "ofrekventerbar",
    "ofrekventerbares": "ofrekventerbar",
    "ofrekventerbarheten": "ofrekventerbarhet",
    "ofrekventerbarhetens": "ofrekventerbarhet",
    "ofrekventerbarhets": "ofrekventerbarhet",
    "ofrekventerbars": "ofrekventerbar",
    "ofrekventerbart": "ofrekventerbar",
    "ofrekventerbarts": "ofrekventerbar",
    "ofrestade": "ofrestad",
    "ofrestades": "ofrestad",
    "ofrestads": "ofrestad",
    "ofrestat": "ofrestad",
    "ofrestats": "ofrestad",
    "ofria": "ofri",
    "ofriade": "ofriad",
    "ofriades": "ofriad",
    "ofriads": "ofriad",
    "ofriare": "ofri",
    "ofriares": "ofri",
    "ofrias": "ofri",
    "ofriast": "ofri",
    "ofriaste": "ofri",
    "ofriastes": "ofri",
    "ofriasts": "ofri",
    "ofriat": "ofriad",
    "ofriats": "ofriad",
    "ofrie": "ofri",
    "ofries": "ofri",
    "ofriheten": "ofrihet",
    "ofrihetens": "ofrihet",
    "ofriheter": "ofrihet",
    "ofriheterna": "ofrihet",
    "ofriheternas": "ofrihet",
    "ofriheters": "ofrihet",
    "ofrihets": "ofrihet",
    "ofrimärkta": "ofrimärkt",
    "ofrimärktas": "ofrimärkt",
    "ofrimärkte": "ofrimärkt",
    "ofrimärktes": "ofrimärkt",
    "ofrimärkts": "ofrimärkt",
    "ofris": "ofri",
    "ofriserade": "ofriserad",
    "ofriserades": "ofriserad",
    "ofriserads": "ofriserad",
    "ofriserat": "ofriserad",
    "ofriserats": "ofriserad",
    "ofriserbara": "ofriserbar",
    "ofriserbarare": "ofriserbar",
    "ofriserbarares": "ofriserbar",
    "ofriserbaras": "ofriserbar",
    "ofriserbarast": "ofriserbar",
    "ofriserbaraste": "ofriserbar",
    "ofriserbarastes": "ofriserbar",
    "ofriserbarasts": "ofriserbar",
    "ofriserbare": "ofriserbar",
    "ofriserbares": "ofriserbar",
    "ofriserbarheten": "ofriserbarhet",
    "ofriserbarhetens": "ofriserbarhet",
    "ofriserbarhets": "ofriserbarhet",
    "ofriserbars": "ofriserbar",
    "ofriserbart": "ofriserbar",
    "ofriserbarts": "ofriserbar",
    "ofriterade": "ofriterad",
    "ofriterades": "ofriterad",
    "ofriterads": "ofriterad",
    "ofriterat": "ofriterad",
    "ofriterats": "ofriterad",
    "ofriterbara": "ofriterbar",
    "ofriterbarare": "ofriterbar",
    "ofriterbarares": "ofriterbar",
    "ofriterbaras": "ofriterbar",
    "ofriterbarast": "ofriterbar",
    "ofriterbaraste": "ofriterbar",
    "ofriterbarastes": "ofriterbar",
    "ofriterbarasts": "ofriterbar",
    "ofriterbare": "ofriterbar",
    "ofriterbares": "ofriterbar",
    "ofriterbarheten": "ofriterbarhet",
    "ofriterbarhetens": "ofriterbarhet",
    "ofriterbarhets": "ofriterbarhet",
    "ofriterbars": "ofriterbar",
    "ofriterbart": "ofriterbar",
    "ofriterbarts": "ofriterbar",
    "ofritt": "ofri",
    "ofritts": "ofri",
    "ofrivilliga": "ofrivillig",
    "ofrivilligare": "ofrivillig",
    "ofrivilligares": "ofrivillig",
    "ofrivilligas": "ofrivillig",
    "ofrivilligast": "ofrivillig",
    "ofrivilligaste": "ofrivillig",
    "ofrivilligastes": "ofrivillig",
    "ofrivilligasts": "ofrivillig",
    "ofrivillige": "ofrivillig",
    "ofrivilliges": "ofrivillig",
    "ofrivilligheten": "ofrivillighet",
    "ofrivillighetens": "ofrivillighet",
    "ofrivillighets": "ofrivillighet",
    "ofrivilligs": "ofrivillig",
    "ofrivilligt": "ofrivillig",
    "ofrivilligts": "ofrivillig",
    "ofronderade": "ofronderad",
    "ofronderades": "ofronderad",
    "ofronderads": "ofronderad",
    "ofronderat": "ofronderad",
    "ofronderats": "ofronderad",
    "ofronderbara": "ofronderbar",
    "ofronderbarare": "ofronderbar",
    "ofronderbarares": "ofronderbar",
    "ofronderbaras": "ofronderbar",
    "ofronderbarast": "ofronderbar",
    "ofronderbaraste": "ofronderbar",
    "ofronderbarastes": "ofronderbar",
    "ofronderbarasts": "ofronderbar",
    "ofronderbare": "ofronderbar",
    "ofronderbares": "ofronderbar",
    "ofronderbarheten": "ofronderbarhet",
    "ofronderbarhetens": "ofronderbarhet",
    "ofronderbarhets": "ofronderbarhet",
    "ofronderbars": "ofronderbar",
    "ofronderbart": "ofronderbar",
    "ofronderbarts": "ofronderbar",
    "ofrontade": "ofrontad",
    "ofrontades": "ofrontad",
    "ofrontads": "ofrontad",
    "ofrontat": "ofrontad",
    "ofrontats": "ofrontad",
    "ofrotterade": "ofrotterad",
    "ofrotterades": "ofrotterad",
    "ofrotterads": "ofrotterad",
    "ofrotterat": "ofrotterad",
    "ofrotterats": "ofrotterad",
    "ofrotterbara": "ofrotterbar",
    "ofrotterbarare": "ofrotterbar",
    "ofrotterbarares": "ofrotterbar",
    "ofrotterbaras": "ofrotterbar",
    "ofrotterbarast": "ofrotterbar",
    "ofrotterbaraste": "ofrotterbar",
    "ofrotterbarastes": "ofrotterbar",
    "ofrotterbarasts": "ofrotterbar",
    "ofrotterbare": "ofrotterbar",
    "ofrotterbares": "ofrotterbar",
    "ofrotterbarheten": "ofrotterbarhet",
    "ofrotterbarhetens": "ofrotterbarhet",
    "ofrotterbarhets": "ofrotterbarhet",
    "ofrotterbars": "ofrotterbar",
    "ofrotterbart": "ofrotterbar",
    "ofrotterbarts": "ofrotterbar",
    "ofruktade": "ofruktad",
    "ofruktades": "ofruktad",
    "ofruktads": "ofruktad",
    "ofruktat": "ofruktad",
    "ofruktats": "ofruktad",
    "ofruktbara": "ofruktbar",
    "ofruktbarare": "ofruktbar",
    "ofruktbarares": "ofruktbar",
    "ofruktbaras": "ofruktbar",
    "ofruktbarast": "ofruktbar",
    "ofruktbaraste": "ofruktbar",
    "ofruktbarastes": "ofruktbar",
    "ofruktbarasts": "ofruktbar",
    "ofruktbare": "ofruktbar",
    "ofruktbares": "ofruktbar",
    "ofruktbarheten": "ofruktbarhet",
    "ofruktbarhetens": "ofruktbarhet",
    "ofruktbarhets": "ofruktbarhet",
    "ofruktbars": "ofruktbar",
    "ofruktbart": "ofruktbar",
    "ofruktbarts": "ofruktbar",
    "ofruktsamheten": "ofruktsamhet",
    "ofruktsamhetens": "ofruktsamhet",
    "ofruktsamhets": "ofruktsamhet",
    "ofruktsamma": "ofruktsam",
    "ofruktsammare": "ofruktsam",
    "ofruktsammares": "ofruktsam",
    "ofruktsammas": "ofruktsam",
    "ofruktsammast": "ofruktsam",
    "ofruktsammaste": "ofruktsam",
    "ofruktsammastes": "ofruktsam",
    "ofruktsammasts": "ofruktsam",
    "ofruktsamme": "ofruktsam",
    "ofruktsammes": "ofruktsam",
    "ofruktsams": "ofruktsam",
    "ofruktsamt": "ofruktsam",
    "ofruktsamts": "ofruktsam",
    "ofrustrerade": "ofrustrerad",
    "ofrustrerades": "ofrustrerad",
    "ofrustrerads": "ofrustrerad",
    "ofrustrerat": "ofrustrerad",
    "ofrustrerats": "ofrustrerad",
    "ofrustrerbara": "ofrustrerbar",
    "ofrustrerbarare": "ofrustrerbar",
    "ofrustrerbarares": "ofrustrerbar",
    "ofrustrerbaras": "ofrustrerbar",
    "ofrustrerbarast": "ofrustrerbar",
    "ofrustrerbaraste": "ofrustrerbar",
    "ofrustrerbarastes": "ofrustrerbar",
    "ofrustrerbarasts": "ofrustrerbar",
    "ofrustrerbare": "ofrustrerbar",
    "ofrustrerbares": "ofrustrerbar",
    "ofrustrerbarheten": "ofrustrerbarhet",
    "ofrustrerbarhetens": "ofrustrerbarhet",
    "ofrustrerbarhets": "ofrustrerbarhet",
    "ofrustrerbars": "ofrustrerbar",
    "ofrustrerbart": "ofrustrerbar",
    "ofrustrerbarts": "ofrustrerbar",
    "ofrälsta": "ofrälst",
    "ofrälstas": "ofrälst",
    "ofrälste": "ofrälst",
    "ofrälstes": "ofrälst",
    "ofrälsts": "ofrälst",
    "ofrämjade": "ofrämjad",
    "ofrämjades": "ofrämjad",
    "ofrämjads": "ofrämjad",
    "ofrämjat": "ofrämjad",
    "ofrämjats": "ofrämjad",
    "ofrästa": "ofräst",
    "ofrästas": "ofräst",
    "ofräste": "ofräst",
    "ofrästes": "ofräst",
    "ofrästs": "ofräst",
    "ofrätta": "ofrätt",
    "ofrättas": "ofrätt",
    "ofrätte": "ofrätt",
    "ofrättes": "ofrätt",
    "ofrätts": "ofrätt",
    "ofrågade": "ofrågad",
    "ofrågades": "ofrågad",
    "ofrågads": "ofrågad",
    "ofrågat": "ofrågad",
    "ofrågats": "ofrågad",
    "ofrånkomliga": "ofrånkomlig",
    "ofrånkomligare": "ofrånkomlig",
    "ofrånkomligares": "ofrånkomlig",
    "ofrånkomligas": "ofrånkomlig",
    "ofrånkomligast": "ofrånkomlig",
    "ofrånkomligaste": "ofrånkomlig",
    "ofrånkomligastes": "ofrånkomlig",
    "ofrånkomligasts": "ofrånkomlig",
    "ofrånkomlige": "ofrånkomlig",
    "ofrånkomliges": "ofrånkomlig",
    "ofrånkomligheten": "ofrånkomlighet",
    "ofrånkomlighetens": "ofrånkomlighet",
    "ofrånkomlighets": "ofrånkomlighet",
    "ofrånkomligs": "ofrånkomlig",
    "ofrånkomligt": "ofrånkomlig",
    "ofrånkomligts": "ofrånkomlig",
    "oftalmiatriken": "oftalmiatrik",
    "oftalmiatrikens": "oftalmiatrik",
    "oftalmiatriks": "oftalmiatrik",
    "oftalmien": "oftalmi",
    "oftalmiens": "oftalmi",
    "oftalmier": "oftalmi",
    "oftalmierna": "oftalmi",
    "oftalmiernas": "oftalmi",
    "oftalmiers": "oftalmi",
    "oftalmin": "oftalmi",
    "oftalmins": "oftalmi",
    "oftalmis": "oftalmi",
    "oftalmologien": "oftalmologi",
    "oftalmologiens": "oftalmologi",
    "oftalmologin": "oftalmologi",
    "oftalmologins": "oftalmologi",
    "oftalmologis": "oftalmologi",
    "oftalmologiska": "oftalmologisk",
    "oftalmologiskare": "oftalmologisk",
    "oftalmologiskares": "oftalmologisk",
    "oftalmologiskas": "oftalmologisk",
    "oftalmologiskast": "oftalmologisk",
    "oftalmologiskaste": "oftalmologisk",
    "oftalmologiskastes": "oftalmologisk",
    "oftalmologiskasts": "oftalmologisk",
    "oftalmologiske": "oftalmologisk",
    "oftalmologiskes": "oftalmologisk",
    "oftalmologisks": "oftalmologisk",
    "oftalmologiskt": "oftalmologisk",
    "oftalmologiskts": "oftalmologisk",
    "oftalmoskopen": "oftalmoskop",
    "oftalmoskopens": "oftalmoskop",
    "oftalmoskopet": "oftalmoskop",
    "oftalmoskopets": "oftalmoskop",
    "oftalmoskopien": "oftalmoskopi",
    "oftalmoskopiens": "oftalmoskopi",
    "oftalmoskopin": "oftalmoskopi",
    "oftalmoskopins": "oftalmoskopi",
    "oftalmoskopis": "oftalmoskopi",
    "oftalmoskops": "oftalmoskop",
    "oftare": "ofta",
    "oftast": "ofta",
    "ofuktade": "ofuktad",
    "ofuktades": "ofuktad",
    "ofuktads": "ofuktad",
    "ofuktat": "ofuktad",
    "ofuktats": "ofuktad",
    "ofullbordade": "ofullbordad",
    "ofullbordades": "ofullbordad",
    "ofullbordads": "ofullbordad",
    "ofullbordat": "ofullbordad",
    "ofullbordats": "ofullbordad",
    "ofullföljde": "ofullföljd",
    "ofullföljdes": "ofullföljd",
    "ofullföljds": "ofullföljd",
    "ofullföljt": "ofullföljd",
    "ofullföljts": "ofullföljd",
    "ofullgångens": "ofullgången",
    "ofullgånget": "ofullgången",
    "ofullgångets": "ofullgången",
    "ofullgångna": "ofullgången",
    "ofullgångnare": "ofullgången",
    "ofullgångnares": "ofullgången",
    "ofullgångnas": "ofullgången",
    "ofullgångnast": "ofullgången",
    "ofullgångnaste": "ofullgången",
    "ofullgångnastes": "ofullgången",
    "ofullgångnasts": "ofullgången",
    "ofullgångne": "ofullgången",
    "ofullgångnes": "ofullgången",
    "ofullkomliga": "ofullkomlig",
    "ofullkomligare": "ofullkomlig",
    "ofullkomligares": "ofullkomlig",
    "ofullkomligas": "ofullkomlig",
    "ofullkomligast": "ofullkomlig",
    "ofullkomligaste": "ofullkomlig",
    "ofullkomligastes": "ofullkomlig",
    "ofullkomligasts": "ofullkomlig",
    "ofullkomlige": "ofullkomlig",
    "ofullkomliges": "ofullkomlig",
    "ofullkomligheten": "ofullkomlighet",
    "ofullkomlighetens": "ofullkomlighet",
    "ofullkomligheter": "ofullkomlighet",
    "ofullkomligheterna": "ofullkomlighet",
    "ofullkomligheternas": "ofullkomlighet",
    "ofullkomligheters": "ofullkomlighet",
    "ofullkomlighets": "ofullkomlighet",
    "ofullkomligs": "ofullkomlig",
    "ofullkomligt": "ofullkomlig",
    "ofullkomligts": "ofullkomlig",
    "ofullkomnade": "ofullkomnad",
    "ofullkomnades": "ofullkomnad",
    "ofullkomnads": "ofullkomnad",
    "ofullkomnat": "ofullkomnad",
    "ofullkomnats": "ofullkomnad",
    "ofullständiga": "ofullständig",
    "ofullständigade": "ofullständigad",
    "ofullständigades": "ofullständigad",
    "ofullständigads": "ofullständigad",
    "ofullständigare": "ofullständig",
    "ofullständigares": "ofullständig",
    "ofullständigas": "ofullständig",
    "ofullständigast": "ofullständig",
    "ofullständigaste": "ofullständig",
    "ofullständigastes": "ofullständig",
    "ofullständigasts": "ofullständig",
    "ofullständigat": "ofullständigad",
    "ofullständigats": "ofullständigad",
    "ofullständige": "ofullständig",
    "ofullständiges": "ofullständig",
    "ofullständigheten": "ofullständighet",
    "ofullständighetens": "ofullständighet",
    "ofullständigheter": "ofullständighet",
    "ofullständigheterna": "ofullständighet",
    "ofullständigheternas": "ofullständighet",
    "ofullständigheters": "ofullständighet",
    "ofullständighets": "ofullständighet",
    "ofullständigs": "ofullständig",
    "ofullständigt": "ofullständig",
    "ofullständigts": "ofullständig",
    "ofulländade": "ofulländad",
    "ofulländades": "ofulländad",
    "ofulländads": "ofulländad",
    "ofulländat": "ofulländad",
    "ofulländats": "ofulländad",
    "ofurnerade": "ofurnerad",
    "ofurnerades": "ofurnerad",
    "ofurnerads": "ofurnerad",
    "ofurnerat": "ofurnerad",
    "ofurnerats": "ofurnerad",
    "ofurnerbara": "ofurnerbar",
    "ofurnerbarare": "ofurnerbar",
    "ofurnerbarares": "ofurnerbar",
    "ofurnerbaras": "ofurnerbar",
    "ofurnerbarast": "ofurnerbar",
    "ofurnerbaraste": "ofurnerbar",
    "ofurnerbarastes": "ofurnerbar",
    "ofurnerbarasts": "ofurnerbar",
    "ofurnerbare": "ofurnerbar",
    "ofurnerbares": "ofurnerbar",
    "ofurnerbarheten": "ofurnerbarhet",
    "ofurnerbarhetens": "ofurnerbarhet",
    "ofurnerbarhets": "ofurnerbarhet",
    "ofurnerbars": "ofurnerbar",
    "ofurnerbart": "ofurnerbar",
    "ofurnerbarts": "ofurnerbar",
    "ofusionerade": "ofusionerad",
    "ofusionerades": "ofusionerad",
    "ofusionerads": "ofusionerad",
    "ofusionerat": "ofusionerad",
    "ofusionerats": "ofusionerad",
    "ofusionerbara": "ofusionerbar",
    "ofusionerbarare": "ofusionerbar",
    "ofusionerbarares": "ofusionerbar",
    "ofusionerbaras": "ofusionerbar",
    "ofusionerbarast": "ofusionerbar",
    "ofusionerbaraste": "ofusionerbar",
    "ofusionerbarastes": "ofusionerbar",
    "ofusionerbarasts": "ofusionerbar",
    "ofusionerbare": "ofusionerbar",
    "ofusionerbares": "ofusionerbar",
    "ofusionerbarheten": "ofusionerbarhet",
    "ofusionerbarhetens": "ofusionerbarhet",
    "ofusionerbarhets": "ofusionerbarhet",
    "ofusionerbars": "ofusionerbar",
    "ofusionerbart": "ofusionerbar",
    "ofusionerbarts": "ofusionerbar",
    "ofylkade": "ofylkad",
    "ofylkades": "ofylkad",
    "ofylkads": "ofylkad",
    "ofylkat": "ofylkad",
    "ofylkats": "ofylkad",
    "ofyllde": "ofylld",
    "ofylldes": "ofylld",
    "ofyllds": "ofylld",
    "ofyllt": "ofylld",
    "ofyllts": "ofylld",
    "ofyndade": "ofyndad",
    "ofyndades": "ofyndad",
    "ofyndads": "ofyndad",
    "ofyndat": "ofyndad",
    "ofyndats": "ofyndad",
    "ofyndiga": "ofyndig",
    "ofyndigare": "ofyndig",
    "ofyndigares": "ofyndig",
    "ofyndigas": "ofyndig",
    "ofyndigast": "ofyndig",
    "ofyndigaste": "ofyndig",
    "ofyndigastes": "ofyndig",
    "ofyndigasts": "ofyndig",
    "ofyndige": "ofyndig",
    "ofyndiges": "ofyndig",
    "ofyndigs": "ofyndig",
    "ofyndigt": "ofyndig",
    "ofyndigts": "ofyndig",
    "ofysiljerade": "ofysiljerad",
    "ofysiljerades": "ofysiljerad",
    "ofysiljerads": "ofysiljerad",
    "ofysiljerat": "ofysiljerad",
    "ofysiljerats": "ofysiljerad",
    "ofysiljerbara": "ofysiljerbar",
    "ofysiljerbarare": "ofysiljerbar",
    "ofysiljerbarares": "ofysiljerbar",
    "ofysiljerbaras": "ofysiljerbar",
    "ofysiljerbarast": "ofysiljerbar",
    "ofysiljerbaraste": "ofysiljerbar",
    "ofysiljerbarastes": "ofysiljerbar",
    "ofysiljerbarasts": "ofysiljerbar",
    "ofysiljerbare": "ofysiljerbar",
    "ofysiljerbares": "ofysiljerbar",
    "ofysiljerbarheten": "ofysiljerbarhet",
    "ofysiljerbarhetens": "ofysiljerbarhet",
    "ofysiljerbarhets": "ofysiljerbarhet",
    "ofysiljerbars": "ofysiljerbar",
    "ofysiljerbart": "ofysiljerbar",
    "ofysiljerbarts": "ofysiljerbar",
    "ofägnade": "ofägnad",
    "ofägnades": "ofägnad",
    "ofägnads": "ofägnad",
    "ofägnat": "ofägnad",
    "ofägnats": "ofägnad",
    "ofällde": "ofälld",
    "ofälldes": "ofälld",
    "ofällds": "ofälld",
    "ofällt": "ofälld",
    "ofällts": "ofälld",
    "ofängslade": "ofängslad",
    "ofängslades": "ofängslad",
    "ofängslads": "ofängslad",
    "ofängslat": "ofängslad",
    "ofängslats": "ofängslad",
    "ofärden": "ofärd",
    "ofärdens": "ofärd",
    "ofärdiga": "ofärdig",
    "ofärdigare": "ofärdig",
    "ofärdigares": "ofärdig",
    "ofärdigas": "ofärdig",
    "ofärdigast": "ofärdig",
    "ofärdigaste": "ofärdig",
    "ofärdigastes": "ofärdig",
    "ofärdigasts": "ofärdig",
    "ofärdige": "ofärdig",
    "ofärdiges": "ofärdig",
    "ofärdigheten": "ofärdighet",
    "ofärdighetens": "ofärdighet",
    "ofärdigheter": "ofärdighet",
    "ofärdigheterna": "ofärdighet",
    "ofärdigheternas": "ofärdighet",
    "ofärdigheters": "ofärdighet",
    "ofärdighets": "ofärdighet",
    "ofärdigs": "ofärdig",
    "ofärdigt": "ofärdig",
    "ofärdigts": "ofärdig",
    "ofärds": "ofärd",
    "ofärgade": "ofärgad",
    "ofärgades": "ofärgad",
    "ofärgads": "ofärgad",
    "ofärgat": "ofärgad",
    "ofärgats": "ofärgad",
    "ofärgen": "ofärg",
    "ofärgens": "ofärg",
    "ofärger": "ofärg",
    "ofärgerna": "ofärg",
    "ofärgernas": "ofärg",
    "ofärgers": "ofärg",
    "ofärgs": "ofärg",
    "ofärjade": "ofärjad",
    "ofärjades": "ofärjad",
    "ofärjads": "ofärjad",
    "ofärjat": "ofärjad",
    "ofärjats": "ofärjad",
    "ofärserade": "ofärserad",
    "ofärserades": "ofärserad",
    "ofärserads": "ofärserad",
    "ofärserat": "ofärserad",
    "ofärserats": "ofärserad",
    "ofärserbara": "ofärserbar",
    "ofärserbarare": "ofärserbar",
    "ofärserbarares": "ofärserbar",
    "ofärserbaras": "ofärserbar",
    "ofärserbarast": "ofärserbar",
    "ofärserbaraste": "ofärserbar",
    "ofärserbarastes": "ofärserbar",
    "ofärserbarasts": "ofärserbar",
    "ofärserbare": "ofärserbar",
    "ofärserbares": "ofärserbar",
    "ofärserbarheten": "ofärserbarhet",
    "ofärserbarhetens": "ofärserbarhet",
    "ofärserbarhets": "ofärserbarhet",
    "ofärserbars": "ofärserbar",
    "ofärserbart": "ofärserbar",
    "ofärserbarts": "ofärserbar",
    "ofärskade": "ofärskad",
    "ofärskades": "ofärskad",
    "ofärskads": "ofärskad",
    "ofärskat": "ofärskad",
    "ofärskats": "ofärskad",
    "ofållade": "ofållad",
    "ofållades": "ofållad",
    "ofållads": "ofållad",
    "ofållat": "ofållad",
    "ofållats": "ofållad",
    "ofångade": "ofångad",
    "ofångades": "ofångad",
    "ofångads": "ofångad",
    "ofångat": "ofångad",
    "ofångats": "ofångad",
    "ofårade": "ofårad",
    "ofårades": "ofårad",
    "ofårads": "ofårad",
    "ofårat": "ofårad",
    "ofårats": "ofårad",
    "ofödda": "ofödd",
    "oföddare": "ofödd",
    "oföddares": "ofödd",
    "oföddas": "ofödd",
    "oföddast": "ofödd",
    "oföddaste": "ofödd",
    "oföddastes": "ofödd",
    "oföddasts": "ofödd",
    "ofödde": "ofödd",
    "oföddes": "ofödd",
    "ofödds": "ofödd",
    "oföljde": "oföljd",
    "oföljdes": "oföljd",
    "oföljds": "oföljd",
    "oföljt": "oföljd",
    "oföljts": "oföljd",
    "ofönade": "ofönad",
    "ofönades": "ofönad",
    "ofönads": "ofönad",
    "ofönat": "ofönad",
    "ofönats": "ofönad",
    "oföra": "oför",
    "oföraktade": "oföraktad",
    "oföraktades": "oföraktad",
    "oföraktads": "oföraktad",
    "oföraktat": "oföraktad",
    "oföraktats": "oföraktad",
    "oförallmänligade": "oförallmänligad",
    "oförallmänligades": "oförallmänligad",
    "oförallmänligads": "oförallmänligad",
    "oförallmänligat": "oförallmänligad",
    "oförallmänligats": "oförallmänligad",
    "oförandligade": "oförandligad",
    "oförandligades": "oförandligad",
    "oförandligads": "oförandligad",
    "oförandligat": "oförandligad",
    "oförandligats": "oförandligad",
    "oförankrade": "oförankrad",
    "oförankrades": "oförankrad",
    "oförankrads": "oförankrad",
    "oförankrat": "oförankrad",
    "oförankrats": "oförankrad",
    "oföranmälde": "oföranmäld",
    "oföranmäldes": "oföranmäld",
    "oföranmälds": "oföranmäld",
    "oföranmält": "oföranmäld",
    "oföranmälts": "oföranmäld",
    "oförannonserade": "oförannonserad",
    "oförannonserades": "oförannonserad",
    "oförannonserads": "oförannonserad",
    "oförannonserat": "oförannonserad",
    "oförannonserats": "oförannonserad",
    "oförannonserbara": "oförannonserbar",
    "oförannonserbarare": "oförannonserbar",
    "oförannonserbarares": "oförannonserbar",
    "oförannonserbaras": "oförannonserbar",
    "oförannonserbarast": "oförannonserbar",
    "oförannonserbaraste": "oförannonserbar",
    "oförannonserbarastes": "oförannonserbar",
    "oförannonserbarasts": "oförannonserbar",
    "oförannonserbare": "oförannonserbar",
    "oförannonserbares": "oförannonserbar",
    "oförannonserbarheten": "oförannonserbarhet",
    "oförannonserbarhetens": "oförannonserbarhet",
    "oförannonserbarhets": "oförannonserbarhet",
    "oförannonserbars": "oförannonserbar",
    "oförannonserbart": "oförannonserbar",
    "oförannonserbarts": "oförannonserbar",
    "oföranstaltade": "oföranstaltad",
    "oföranstaltades": "oföranstaltad",
    "oföranstaltads": "oföranstaltad",
    "oföranstaltat": "oföranstaltad",
    "oföranstaltats": "oföranstaltad",
    "oförare": "oför",
    "oförares": "oför",
    "oförargade": "oförargad",
    "oförargades": "oförargad",
    "oförargads": "oförargad",
    "oförargat": "oförargad",
    "oförargats": "oförargad",
    "oförargliga": "oförarglig",
    "oförargligare": "oförarglig",
    "oförargligares": "oförarglig",
    "oförargligas": "oförarglig",
    "oförargligast": "oförarglig",
    "oförargligaste": "oförarglig",
    "oförargligastes": "oförarglig",
    "oförargligasts": "oförarglig",
    "oförarglige": "oförarglig",
    "oförargliges": "oförarglig",
    "oförargligheten": "oförarglighet",
    "oförarglighetens": "oförarglighet",
    "oförargligheter": "oförarglighet",
    "oförargligheterna": "oförarglighet",
    "oförargligheternas": "oförarglighet",
    "oförargligheters": "oförarglighet",
    "oförarglighets": "oförarglighet",
    "oförargligs": "oförarglig",
    "oförargligt": "oförarglig",
    "oförargligts": "oförarglig",
    "oföras": "oför",
    "oförast": "oför",
    "oföraste": "oför",
    "oförastes": "oför",
    "oförasts": "oför",
    "oförbannade": "oförbannad",
    "oförbannades": "oförbannad",
    "oförbannads": "oförbannad",
    "oförbannat": "oförbannad",
    "oförbannats": "oförbannad",
    "oförbehållsamheten": "oförbehållsamhet",
    "oförbehållsamhetens": "oförbehållsamhet",
    "oförbehållsamhets": "oförbehållsamhet",
    "oförbehållsamma": "oförbehållsam",
    "oförbehållsammare": "oförbehållsam",
    "oförbehållsammares": "oförbehållsam",
    "oförbehållsammas": "oförbehållsam",
    "oförbehållsammast": "oförbehållsam",
    "oförbehållsammaste": "oförbehållsam",
    "oförbehållsammastes": "oförbehållsam",
    "oförbehållsammasts": "oförbehållsam",
    "oförbehållsamme": "oförbehållsam",
    "oförbehållsammes": "oförbehållsam",
    "oförbehållsams": "oförbehållsam",
    "oförbehållsamt": "oförbehållsam",
    "oförbehållsamts": "oförbehållsam",
    "oförberedda": "oförberedd",
    "oförbereddare": "oförberedd",
    "oförbereddares": "oförberedd",
    "oförbereddas": "oförberedd",
    "oförbereddast": "oförberedd",
    "oförbereddaste": "oförberedd",
    "oförbereddastes": "oförberedd",
    "oförbereddasts": "oförberedd",
    "oförberedde": "oförberedd",
    "oförbereddes": "oförberedd",
    "oförbereddheten": "oförbereddhet",
    "oförbereddhetens": "oförbereddhet",
    "oförbereddhets": "oförbereddhet",
    "oförberedds": "oförberedd",
    "oförberett": "oförberedd",
    "oförberetts": "oförberedd",
    "oförbidade": "oförbidad",
    "oförbidades": "oförbidad",
    "oförbidads": "oförbidad",
    "oförbidat": "oförbidad",
    "oförbidats": "oförbidad",
    "oförbilligade": "oförbilligad",
    "oförbilligades": "oförbilligad",
    "oförbilligads": "oförbilligad",
    "oförbilligat": "oförbilligad",
    "oförbilligats": "oförbilligad",
    "oförbittrade": "oförbittrad",
    "oförbittrades": "oförbittrad",
    "oförbittrads": "oförbittrad",
    "oförbittrat": "oförbittrad",
    "oförbittrats": "oförbittrad",
    "oförblandade": "oförblandad",
    "oförblandades": "oförblandad",
    "oförblandads": "oförblandad",
    "oförblandat": "oförblandad",
    "oförblandats": "oförblandad",
    "oförbleknade": "oförbleknad",
    "oförbleknades": "oförbleknad",
    "oförbleknads": "oförbleknad",
    "oförbleknat": "oförbleknad",
    "oförbleknats": "oförbleknad",
    "oförblindade": "oförblindad",
    "oförblindades": "oförblindad",
    "oförblindads": "oförblindad",
    "oförblindat": "oförblindad",
    "oförblindats": "oförblindad",
    "oförblommerade": "oförblommerad",
    "oförblommerades": "oförblommerad",
    "oförblommerads": "oförblommerad",
    "oförblommerat": "oförblommerad",
    "oförblommerats": "oförblommerad",
    "oförbluffade": "oförbluffad",
    "oförbluffades": "oförbluffad",
    "oförbluffads": "oförbluffad",
    "oförbluffat": "oförbluffad",
    "oförbluffats": "oförbluffad",
    "oförborgade": "oförborgad",
    "oförborgades": "oförborgad",
    "oförborgads": "oförborgad",
    "oförborgat": "oförborgad",
    "oförborgats": "oförborgad",
    "oförborgerligade": "oförborgerligad",
    "oförborgerligades": "oförborgerligad",
    "oförborgerligads": "oförborgerligad",
    "oförborgerligat": "oförborgerligad",
    "oförborgerligats": "oförborgerligad",
    "oförbrukade": "oförbrukad",
    "oförbrukades": "oförbrukad",
    "oförbrukads": "oförbrukad",
    "oförbrukat": "oförbrukad",
    "oförbrukats": "oförbrukad",
    "oförbryllade": "oförbryllad",
    "oförbryllades": "oförbryllad",
    "oförbryllads": "oförbryllad",
    "oförbryllat": "oförbryllad",
    "oförbryllats": "oförbryllad",
    "oförbrände": "oförbränd",
    "oförbrändes": "oförbränd",
    "oförbränds": "oförbränd",
    "oförbränneliga": "oförbrännelig",
    "oförbränneligare": "oförbrännelig",
    "oförbränneligares": "oförbrännelig",
    "oförbränneligas": "oförbrännelig",
    "oförbränneligast": "oförbrännelig",
    "oförbränneligaste": "oförbrännelig",
    "oförbränneligastes": "oförbrännelig",
    "oförbränneligasts": "oförbrännelig",
    "oförbrännelige": "oförbrännelig",
    "oförbränneliges": "oförbrännelig",
    "oförbränneligheten": "oförbrännelighet",
    "oförbrännelighetens": "oförbrännelighet",
    "oförbrännelighets": "oförbrännelighet",
    "oförbränneligs": "oförbrännelig",
    "oförbränneligt": "oförbrännelig",
    "oförbränneligts": "oförbrännelig",
    "oförbränt": "oförbränd",
    "oförbränts": "oförbränd",
    "oförbrödrade": "oförbrödrad",
    "oförbrödrades": "oförbrödrad",
    "oförbrödrads": "oförbrödrad",
    "oförbrödrat": "oförbrödrad",
    "oförbrödrats": "oförbrödrad",
    "oförbuskade": "oförbuskad",
    "oförbuskades": "oförbuskad",
    "oförbuskads": "oförbuskad",
    "oförbuskat": "oförbuskad",
    "oförbuskats": "oförbuskad",
    "oförbyggde": "oförbyggd",
    "oförbyggdes": "oförbyggd",
    "oförbyggds": "oförbyggd",
    "oförbyggt": "oförbyggd",
    "oförbyggts": "oförbyggd",
    "oförbytta": "oförbytt",
    "oförbyttas": "oförbytt",
    "oförbytte": "oförbytt",
    "oförbyttes": "oförbytt",
    "oförbytts": "oförbytt",
    "oförbätterliga": "oförbätterlig",
    "oförbätterligare": "oförbätterlig",
    "oförbätterligares": "oförbätterlig",
    "oförbätterligas": "oförbätterlig",
    "oförbätterligast": "oförbätterlig",
    "oförbätterligaste": "oförbätterlig",
    "oförbätterligastes": "oförbätterlig",
    "oförbätterligasts": "oförbätterlig",
    "oförbätterlige": "oförbätterlig",
    "oförbätterliges": "oförbätterlig",
    "oförbätterligheten": "oförbätterlighet",
    "oförbätterlighetens": "oförbätterlighet",
    "oförbätterlighets": "oförbätterlighet",
    "oförbätterligs": "oförbätterlig",
    "oförbätterligt": "oförbätterlig",
    "oförbätterligts": "oförbätterlig",
    "oförbättrade": "oförbättrad",
    "oförbättrades": "oförbättrad",
    "oförbättrads": "oförbättrad",
    "oförbättrat": "oförbättrad",
    "oförbättrats": "oförbättrad",
    "oförde": "oförd",
    "ofördelade": "ofördelad",
    "ofördelades": "ofördelad",
    "ofördelads": "ofördelad",
    "ofördelaktiga": "ofördelaktig",
    "ofördelaktigare": "ofördelaktig",
    "ofördelaktigares": "ofördelaktig",
    "ofördelaktigas": "ofördelaktig",
    "ofördelaktigast": "ofördelaktig",
    "ofördelaktigaste": "ofördelaktig",
    "ofördelaktigastes": "ofördelaktig",
    "ofördelaktigasts": "ofördelaktig",
    "ofördelaktige": "ofördelaktig",
    "ofördelaktiges": "ofördelaktig",
    "ofördelaktigheten": "ofördelaktighet",
    "ofördelaktighetens": "ofördelaktighet",
    "ofördelaktighets": "ofördelaktighet",
    "ofördelaktigs": "ofördelaktig",
    "ofördelaktigt": "ofördelaktig",
    "ofördelaktigts": "ofördelaktig",
    "ofördelat": "ofördelad",
    "ofördelats": "ofördelad",
    "ofördes": "oförd",
    "ofördjupade": "ofördjupad",
    "ofördjupades": "ofördjupad",
    "ofördjupads": "ofördjupad",
    "ofördjupat": "ofördjupad",
    "ofördjupats": "ofördjupad",
    "ofördragsamheten": "ofördragsamhet",
    "ofördragsamhetens": "ofördragsamhet",
    "ofördragsamhets": "ofördragsamhet",
    "ofördragsamma": "ofördragsam",
    "ofördragsammare": "ofördragsam",
    "ofördragsammares": "ofördragsam",
    "ofördragsammas": "ofördragsam",
    "ofördragsammast": "ofördragsam",
    "ofördragsammaste": "ofördragsam",
    "ofördragsammastes": "ofördragsam",
    "ofördragsammasts": "ofördragsam",
    "ofördragsamme": "ofördragsam",
    "ofördragsammes": "ofördragsam",
    "ofördragsams": "ofördragsam",
    "ofördragsamt": "ofördragsam",
    "ofördragsamts": "ofördragsam",
    "ofördröjde": "ofördröjd",
    "ofördröjdes": "ofördröjd",
    "ofördröjds": "ofördröjd",
    "ofördröjt": "ofördröjd",
    "ofördröjts": "ofördröjd",
    "oförds": "oförd",
    "ofördubblade": "ofördubblad",
    "ofördubblades": "ofördubblad",
    "ofördubblads": "ofördubblad",
    "ofördubblat": "ofördubblad",
    "ofördubblats": "ofördubblad",
    "ofördummade": "ofördummad",
    "ofördummades": "ofördummad",
    "ofördummads": "ofördummad",
    "ofördummat": "ofördummad",
    "ofördummats": "ofördummad",
    "ofördunklade": "ofördunklad",
    "ofördunklades": "ofördunklad",
    "ofördunklads": "ofördunklad",
    "ofördunklat": "ofördunklad",
    "ofördunklats": "ofördunklad",
    "ofördunstade": "ofördunstad",
    "ofördunstades": "ofördunstad",
    "ofördunstads": "ofördunstad",
    "ofördunstat": "ofördunstad",
    "ofördunstats": "ofördunstad",
    "ofördyrade": "ofördyrad",
    "ofördyrades": "ofördyrad",
    "ofördyrads": "ofördyrad",
    "ofördyrat": "ofördyrad",
    "ofördyrats": "ofördyrad",
    "ofördystrade": "ofördystrad",
    "ofördystrades": "ofördystrad",
    "ofördystrads": "ofördystrad",
    "ofördystrat": "ofördystrad",
    "ofördystrats": "ofördystrad",
    "ofördämde": "ofördämd",
    "ofördämdes": "ofördämd",
    "ofördämds": "ofördämd",
    "ofördämt": "ofördämd",
    "ofördämts": "ofördämd",
    "ofördärvade": "ofördärvad",
    "ofördärvades": "ofördärvad",
    "ofördärvads": "ofördärvad",
    "ofördärvat": "ofördärvad",
    "ofördärvats": "ofördärvad",
    "ofördömde": "ofördömd",
    "ofördömdes": "ofördömd",
    "ofördömds": "ofördömd",
    "ofördömt": "ofördömd",
    "ofördömts": "ofördömd",
    "oföre": "oför",
    "oförebyggde": "oförebyggd",
    "oförebyggdes": "oförebyggd",
    "oförebyggds": "oförebyggd",
    "oförebyggt": "oförebyggd",
    "oförebyggts": "oförebyggd",
    "oförebådade": "oförebådad",
    "oförebådades": "oförebådad",
    "oförebådads": "oförebådad",
    "oförebådat": "oförebådad",
    "oförebådats": "oförebådad",
    "oförenklade": "oförenklad",
    "oförenklades": "oförenklad",
    "oförenklads": "oförenklad",
    "oförenklat": "oförenklad",
    "oförenklats": "oförenklad",
    "oförenliga": "oförenlig",
    "oförenligare": "oförenlig",
    "oförenligares": "oförenlig",
    "oförenligas": "oförenlig",
    "oförenligast": "oförenlig",
    "oförenligaste": "oförenlig",
    "oförenligastes": "oförenlig",
    "oförenligasts": "oförenlig",
    "oförenlige": "oförenlig",
    "oförenliges": "oförenlig",
    "oförenligheten": "oförenlighet",
    "oförenlighetens": "oförenlighet",
    "oförenligheter": "oförenlighet",
    "oförenligheterna": "oförenlighet",
    "oförenligheternas": "oförenlighet",
    "oförenligheters": "oförenlighet",
    "oförenlighets": "oförenlighet",
    "oförenligs": "oförenlig",
    "oförenligt": "oförenlig",
    "oförenligts": "oförenlig",
    "oföres": "oföre",
    "oförespeglade": "oförespeglad",
    "oförespeglades": "oförespeglad",
    "oförespeglads": "oförespeglad",
    "oförespeglat": "oförespeglad",
    "oförespeglats": "oförespeglad",
    "oförespråkade": "oförespråkad",
    "oförespråkades": "oförespråkad",
    "oförespråkads": "oförespråkad",
    "oförespråkat": "oförespråkad",
    "oförespråkats": "oförespråkad",
    "oförestavade": "oförestavad",
    "oförestavades": "oförestavad",
    "oförestavads": "oförestavad",
    "oförestavat": "oförestavad",
    "oförestavats": "oförestavad",
    "oföreställde": "oföreställd",
    "oföreställdes": "oföreställd",
    "oföreställds": "oföreställd",
    "oföreställt": "oföreställd",
    "oföreställts": "oföreställd",
    "oföret": "oföre",
    "oföretagsamheten": "oföretagsamhet",
    "oföretagsamhetens": "oföretagsamhet",
    "oföretagsamhets": "oföretagsamhet",
    "oföretagsamma": "oföretagsam",
    "oföretagsammare": "oföretagsam",
    "oföretagsammares": "oföretagsam",
    "oföretagsammas": "oföretagsam",
    "oföretagsammast": "oföretagsam",
    "oföretagsammaste": "oföretagsam",
    "oföretagsammastes": "oföretagsam",
    "oföretagsammasts": "oföretagsam",
    "oföretagsamme": "oföretagsam",
    "oföretagsammes": "oföretagsam",
    "oföretagsams": "oföretagsam",
    "oföretagsamt": "oföretagsam",
    "oföretagsamts": "oföretagsam",
    "oförets": "oföre",
    "oförevigade": "oförevigad",
    "oförevigades": "oförevigad",
    "oförevigads": "oförevigad",
    "oförevigat": "oförevigad",
    "oförevigats": "oförevigad",
    "oförevisade": "oförevisad",
    "oförevisades": "oförevisad",
    "oförevisads": "oförevisad",
    "oförevisat": "oförevisad",
    "oförevisats": "oförevisad",
    "oförevitade": "oförevitad",
    "oförevitades": "oförevitad",
    "oförevitads": "oförevitad",
    "oförevitat": "oförevitad",
    "oförevitats": "oförevitad",
    "oförfalskade": "oförfalskad",
    "oförfalskades": "oförfalskad",
    "oförfalskads": "oförfalskad",
    "oförfalskat": "oförfalskad",
    "oförfalskats": "oförfalskad",
    "oförfattade": "oförfattad",
    "oförfattades": "oförfattad",
    "oförfattads": "oförfattad",
    "oförfattat": "oförfattad",
    "oförfattats": "oförfattad",
    "oförfelade": "oförfelad",
    "oförfelades": "oförfelad",
    "oförfelads": "oförfelad",
    "oförfelat": "oförfelad",
    "oförfelats": "oförfelad",
    "oförfinade": "oförfinad",
    "oförfinades": "oförfinad",
    "oförfinads": "oförfinad",
    "oförfinat": "oförfinad",
    "oförfinats": "oförfinad",
    "oförflackade": "oförflackad",
    "oförflackades": "oförflackad",
    "oförflackads": "oförflackad",
    "oförflackat": "oförflackad",
    "oförflackats": "oförflackad",
    "oförflyttade": "oförflyttad",
    "oförflyttades": "oförflyttad",
    "oförflyttads": "oförflyttad",
    "oförflyttat": "oförflyttad",
    "oförflyttats": "oförflyttad",
    "oförfranskade": "oförfranskad",
    "oförfranskades": "oförfranskad",
    "oförfranskads": "oförfranskad",
    "oförfranskat": "oförfranskad",
    "oförfranskats": "oförfranskad",
    "oförfuskade": "oförfuskad",
    "oförfuskades": "oförfuskad",
    "oförfuskads": "oförfuskad",
    "oförfuskat": "oförfuskad",
    "oförfuskats": "oförfuskad",
    "oförfäade": "oförfäad",
    "oförfäades": "oförfäad",
    "oförfäads": "oförfäad",
    "oförfäat": "oförfäad",
    "oförfäats": "oförfäad",
    "oförfäktade": "oförfäktad",
    "oförfäktades": "oförfäktad",
    "oförfäktads": "oförfäktad",
    "oförfäktat": "oförfäktad",
    "oförfäktats": "oförfäktad",
    "oförfärade": "oförfärad",
    "oförfärades": "oförfärad",
    "oförfärads": "oförfärad",
    "oförfärat": "oförfärad",
    "oförfärats": "oförfärad",
    "oförfärdigade": "oförfärdigad",
    "oförfärdigades": "oförfärdigad",
    "oförfärdigads": "oförfärdigad",
    "oförfärdigat": "oförfärdigad",
    "oförfärdigats": "oförfärdigad",
    "oförfångade": "oförfångad",
    "oförfångades": "oförfångad",
    "oförfångads": "oförfångad",
    "oförfångat": "oförfångad",
    "oförfångats": "oförfångad",
    "oförföljde": "oförföljd",
    "oförföljdes": "oförföljd",
    "oförföljds": "oförföljd",
    "oförföljt": "oförföljd",
    "oförföljts": "oförföljd",
    "oförförde": "oförförd",
    "oförfördelade": "oförfördelad",
    "oförfördelades": "oförfördelad",
    "oförfördelads": "oförfördelad",
    "oförfördelat": "oförfördelad",
    "oförfördelats": "oförfördelad",
    "oförfördes": "oförförd",
    "oförförds": "oförförd",
    "oförfört": "oförförd",
    "oförförts": "oförförd",
    "oförgasade": "oförgasad",
    "oförgasades": "oförgasad",
    "oförgasads": "oförgasad",
    "oförgasat": "oförgasad",
    "oförgasats": "oförgasad",
    "oförgiftade": "oförgiftad",
    "oförgiftades": "oförgiftad",
    "oförgiftads": "oförgiftad",
    "oförgiftat": "oförgiftad",
    "oförgiftats": "oförgiftad",
    "oförglömde": "oförglömd",
    "oförglömdes": "oförglömd",
    "oförglömds": "oförglömd",
    "oförglömliga": "oförglömlig",
    "oförglömligare": "oförglömlig",
    "oförglömligares": "oförglömlig",
    "oförglömligas": "oförglömlig",
    "oförglömligast": "oförglömlig",
    "oförglömligaste": "oförglömlig",
    "oförglömligastes": "oförglömlig",
    "oförglömligasts": "oförglömlig",
    "oförglömlige": "oförglömlig",
    "oförglömliges": "oförglömlig",
    "oförglömligheten": "oförglömlighet",
    "oförglömlighetens": "oförglömlighet",
    "oförglömligheter": "oförglömlighet",
    "oförglömligheterna": "oförglömlighet",
    "oförglömligheternas": "oförglömlighet",
    "oförglömligheters": "oförglömlighet",
    "oförglömlighets": "oförglömlighet",
    "oförglömligs": "oförglömlig",
    "oförglömligt": "oförglömlig",
    "oförglömligts": "oförglömlig",
    "oförglömt": "oförglömd",
    "oförglömts": "oförglömd",
    "oförgripliga": "oförgriplig",
    "oförgripligare": "oförgriplig",
    "oförgripligares": "oförgriplig",
    "oförgripligas": "oförgriplig",
    "oförgripligast": "oförgriplig",
    "oförgripligaste": "oförgriplig",
    "oförgripligastes": "oförgriplig",
    "oförgripligasts": "oförgriplig",
    "oförgriplige": "oförgriplig",
    "oförgripliges": "oförgriplig",
    "oförgripligheten": "oförgriplighet",
    "oförgriplighetens": "oförgriplighet",
    "oförgriplighets": "oförgriplighet",
    "oförgripligs": "oförgriplig",
    "oförgripligt": "oförgriplig",
    "oförgripligts": "oförgriplig",
    "oförgrovade": "oförgrovad",
    "oförgrovades": "oförgrovad",
    "oförgrovads": "oförgrovad",
    "oförgrovat": "oförgrovad",
    "oförgrovats": "oförgrovad",
    "oförgrymmade": "oförgrymmad",
    "oförgrymmades": "oförgrymmad",
    "oförgrymmads": "oförgrymmad",
    "oförgrymmat": "oförgrymmad",
    "oförgrymmats": "oförgrymmad",
    "oförgyllde": "oförgylld",
    "oförgylldes": "oförgylld",
    "oförgyllds": "oförgylld",
    "oförgyllt": "oförgylld",
    "oförgyllts": "oförgylld",
    "oförgätliga": "oförgätlig",
    "oförgätligare": "oförgätlig",
    "oförgätligares": "oförgätlig",
    "oförgätligas": "oförgätlig",
    "oförgätligast": "oförgätlig",
    "oförgätligaste": "oförgätlig",
    "oförgätligastes": "oförgätlig",
    "oförgätligasts": "oförgätlig",
    "oförgätlige": "oförgätlig",
    "oförgätliges": "oförgätlig",
    "oförgätligheten": "oförgätlighet",
    "oförgätlighetens": "oförgätlighet",
    "oförgätlighets": "oförgätlighet",
    "oförgätligs": "oförgätlig",
    "oförgätligt": "oförgätlig",
    "oförgätligts": "oförgätlig",
    "oförhalade": "oförhalad",
    "oförhalades": "oförhalad",
    "oförhalads": "oförhalad",
    "oförhalat": "oförhalad",
    "oförhalats": "oförhalad",
    "oförhandlade": "oförhandlad",
    "oförhandlades": "oförhandlad",
    "oförhandlads": "oförhandlad",
    "oförhandlat": "oförhandlad",
    "oförhandlats": "oförhandlad",
    "oförhindrade": "oförhindrad",
    "oförhindrades": "oförhindrad",
    "oförhindrads": "oförhindrad",
    "oförhindrat": "oförhindrad",
    "oförhindrats": "oförhindrad",
    "oförhyrde": "oförhyrd",
    "oförhyrdes": "oförhyrd",
    "oförhyrds": "oförhyrd",
    "oförhyrt": "oförhyrd",
    "oförhyrts": "oförhyrd",
    "oförhärdade": "oförhärdad",
    "oförhärdades": "oförhärdad",
    "oförhärdads": "oförhärdad",
    "oförhärdat": "oförhärdad",
    "oförhärdats": "oförhärdad",
    "oförhärjade": "oförhärjad",
    "oförhärjades": "oförhärjad",
    "oförhärjads": "oförhärjad",
    "oförhärjat": "oförhärjad",
    "oförhärjats": "oförhärjad",
    "oförhärligade": "oförhärligad",
    "oförhärligades": "oförhärligad",
    "oförhärligads": "oförhärligad",
    "oförhärligat": "oförhärligad",
    "oförhärligats": "oförhärligad",
    "oförhäxade": "oförhäxad",
    "oförhäxades": "oförhäxad",
    "oförhäxads": "oförhäxad",
    "oförhäxat": "oförhäxad",
    "oförhäxats": "oförhäxad",
    "oförhånade": "oförhånad",
    "oförhånades": "oförhånad",
    "oförhånads": "oförhånad",
    "oförhånat": "oförhånad",
    "oförhånats": "oförhånad",
    "oförhöjde": "oförhöjd",
    "oförhöjdes": "oförhöjd",
    "oförhöjds": "oförhöjd",
    "oförhöjt": "oförhöjd",
    "oförhöjts": "oförhöjd",
    "oförhörde": "oförhörd",
    "oförhördes": "oförhörd",
    "oförhörds": "oförhörd",
    "oförhört": "oförhörd",
    "oförhörts": "oförhörd",
    "oförintade": "oförintad",
    "oförintades": "oförintad",
    "oförintads": "oförintad",
    "oförintat": "oförintad",
    "oförintats": "oförintad",
    "oförjagade": "oförjagad",
    "oförjagades": "oförjagad",
    "oförjagads": "oförjagad",
    "oförjagat": "oförjagad",
    "oförjagats": "oförjagad",
    "oförkastade": "oförkastad",
    "oförkastades": "oförkastad",
    "oförkastads": "oförkastad",
    "oförkastat": "oförkastad",
    "oförkastats": "oförkastad",
    "oförklarade": "oförklarad",
    "oförklarades": "oförklarad",
    "oförklarads": "oförklarad",
    "oförklarat": "oförklarad",
    "oförklarats": "oförklarad",
    "oförklarliga": "oförklarlig",
    "oförklarligare": "oförklarlig",
    "oförklarligares": "oförklarlig",
    "oförklarligas": "oförklarlig",
    "oförklarligast": "oförklarlig",
    "oförklarligaste": "oförklarlig",
    "oförklarligastes": "oförklarlig",
    "oförklarligasts": "oförklarlig",
    "oförklarlige": "oförklarlig",
    "oförklarliges": "oförklarlig",
    "oförklarligheten": "oförklarlighet",
    "oförklarlighetens": "oförklarlighet",
    "oförklarligheter": "oförklarlighet",
    "oförklarligheterna": "oförklarlighet",
    "oförklarligheternas": "oförklarlighet",
    "oförklarligheters": "oförklarlighet",
    "oförklarlighets": "oförklarlighet",
    "oförklarligs": "oförklarlig",
    "oförklarligt": "oförklarlig",
    "oförklarligts": "oförklarlig",
    "oförklingade": "oförklingad",
    "oförklingades": "oförklingad",
    "oförklingads": "oförklingad",
    "oförklingat": "oförklingad",
    "oförklingats": "oförklingad",
    "oförklistrade": "oförklistrad",
    "oförklistrades": "oförklistrad",
    "oförklistrads": "oförklistrad",
    "oförklistrat": "oförklistrad",
    "oförklistrats": "oförklistrad",
    "oförknippade": "oförknippad",
    "oförknippades": "oförknippad",
    "oförknippads": "oförknippad",
    "oförknippat": "oförknippad",
    "oförknippats": "oförknippad",
    "oförkolnade": "oförkolnad",
    "oförkolnades": "oförkolnad",
    "oförkolnads": "oförkolnad",
    "oförkolnat": "oförkolnad",
    "oförkolnats": "oförkolnad",
    "oförkortade": "oförkortad",
    "oförkortades": "oförkortad",
    "oförkortads": "oförkortad",
    "oförkortat": "oförkortad",
    "oförkortats": "oförkortad",
    "oförkovrade": "oförkovrad",
    "oförkovrades": "oförkovrad",
    "oförkovrads": "oförkovrad",
    "oförkovrat": "oförkovrad",
    "oförkovrats": "oförkovrad",
    "oförkromade": "oförkromad",
    "oförkromades": "oförkromad",
    "oförkromads": "oförkromad",
    "oförkromat": "oförkromad",
    "oförkromats": "oförkromad",
    "oförkroppsligade": "oförkroppsligad",
    "oförkroppsligades": "oförkroppsligad",
    "oförkroppsligads": "oförkroppsligad",
    "oförkroppsligat": "oförkroppsligad",
    "oförkroppsligats": "oförkroppsligad",
    "oförkrossade": "oförkrossad",
    "oförkrossades": "oförkrossad",
    "oförkrossads": "oförkrossad",
    "oförkrossat": "oförkrossad",
    "oförkrossats": "oförkrossad",
    "oförkrympta": "oförkrympt",
    "oförkrymptas": "oförkrympt",
    "oförkrympte": "oförkrympt",
    "oförkrymptes": "oförkrympt",
    "oförkrympts": "oförkrympt",
    "oförkunnade": "oförkunnad",
    "oförkunnades": "oförkunnad",
    "oförkunnads": "oförkunnad",
    "oförkunnat": "oförkunnad",
    "oförkunnats": "oförkunnad",
    "oförkvävde": "oförkvävd",
    "oförkvävdes": "oförkvävd",
    "oförkvävds": "oförkvävd",
    "oförkvävt": "oförkvävd",
    "oförkvävts": "oförkvävd",
    "oförlamade": "oförlamad",
    "oförlamades": "oförlamad",
    "oförlamads": "oförlamad",
    "oförlamat": "oförlamad",
    "oförlamats": "oförlamad",
    "oförlikneliga": "oförliknelig",
    "oförlikneligare": "oförliknelig",
    "oförlikneligares": "oförliknelig",
    "oförlikneligas": "oförliknelig",
    "oförlikneligast": "oförliknelig",
    "oförlikneligaste": "oförliknelig",
    "oförlikneligastes": "oförliknelig",
    "oförlikneligasts": "oförliknelig",
    "oförliknelige": "oförliknelig",
    "oförlikneliges": "oförliknelig",
    "oförlikneligheten": "oförliknelighet",
    "oförliknelighetens": "oförliknelighet",
    "oförliknelighets": "oförliknelighet",
    "oförlikneligs": "oförliknelig",
    "oförlikneligt": "oförliknelig",
    "oförlikneligts": "oförliknelig",
    "oförlikta": "oförlikt",
    "oförliktas": "oförlikt",
    "oförlikte": "oförlikt",
    "oförliktes": "oförlikt",
    "oförlikts": "oförlikt",
    "oförlista": "oförlist",
    "oförlistas": "oförlist",
    "oförliste": "oförlist",
    "oförlistes": "oförlist",
    "oförlists": "oförlist",
    "oförljuvade": "oförljuvad",
    "oförljuvades": "oförljuvad",
    "oförljuvads": "oförljuvad",
    "oförljuvat": "oförljuvad",
    "oförljuvats": "oförljuvad",
    "oförlorade": "oförlorad",
    "oförlorades": "oförlorad",
    "oförlorads": "oförlorad",
    "oförlorat": "oförlorad",
    "oförlorats": "oförlorad",
    "oförlossade": "oförlossad",
    "oförlossades": "oförlossad",
    "oförlossads": "oförlossad",
    "oförlossat": "oförlossad",
    "oförlossats": "oförlossad",
    "oförlustade": "oförlustad",
    "oförlustades": "oförlustad",
    "oförlustads": "oförlustad",
    "oförlustat": "oförlustad",
    "oförlustats": "oförlustad",
    "oförlänade": "oförlänad",
    "oförlänades": "oförlänad",
    "oförlänads": "oförlänad",
    "oförlänat": "oförlänad",
    "oförlänats": "oförlänad",
    "oförlängde": "oförlängd",
    "oförlängdes": "oförlängd",
    "oförlängds": "oförlängd",
    "oförlängt": "oförlängd",
    "oförlängts": "oförlängd",
    "oförlåtliga": "oförlåtlig",
    "oförlåtligare": "oförlåtlig",
    "oförlåtligares": "oförlåtlig",
    "oförlåtligas": "oförlåtlig",
    "oförlåtligast": "oförlåtlig",
    "oförlåtligaste": "oförlåtlig",
    "oförlåtligastes": "oförlåtlig",
    "oförlåtligasts": "oförlåtlig",
    "oförlåtlige": "oförlåtlig",
    "oförlåtliges": "oförlåtlig",
    "oförlåtligheten": "oförlåtlighet",
    "oförlåtlighetens": "oförlåtlighet",
    "oförlåtlighets": "oförlåtlighet",
    "oförlåtligs": "oförlåtlig",
    "oförlåtligt": "oförlåtlig",
    "oförlåtligts": "oförlåtlig",
    "oförlöjligade": "oförlöjligad",
    "oförlöjligades": "oförlöjligad",
    "oförlöjligads": "oförlöjligad",
    "oförlöjligat": "oförlöjligad",
    "oförlöjligats": "oförlöjligad",
    "oförlösta": "oförlöst",
    "oförlöstas": "oförlöst",
    "oförlöste": "oförlöst",
    "oförlöstes": "oförlöst",
    "oförlösts": "oförlöst",
    "oförmanade": "oförmanad",
    "oförmanades": "oförmanad",
    "oförmanads": "oförmanad",
    "oförmanat": "oförmanad",
    "oförmanats": "oförmanad",
    "oförmedlade": "oförmedlad",
    "oförmedlades": "oförmedlad",
    "oförmedlads": "oförmedlad",
    "oförmedlat": "oförmedlad",
    "oförmedlats": "oförmedlad",
    "oförmenade": "oförmenad",
    "oförmenades": "oförmenad",
    "oförmenads": "oförmenad",
    "oförmenat": "oförmenad",
    "oförmenats": "oförmenad",
    "oförmildrade": "oförmildrad",
    "oförmildrades": "oförmildrad",
    "oförmildrads": "oförmildrad",
    "oförmildrat": "oförmildrad",
    "oförmildrats": "oförmildrad",
    "oförminskade": "oförminskad",
    "oförminskades": "oförminskad",
    "oförminskads": "oförminskad",
    "oförminskat": "oförminskad",
    "oförminskats": "oförminskad",
    "oförmodade": "oförmodad",
    "oförmodades": "oförmodad",
    "oförmodads": "oförmodad",
    "oförmodat": "oförmodad",
    "oförmodats": "oförmodad",
    "oförmultnade": "oförmultnad",
    "oförmultnades": "oförmultnad",
    "oförmultnads": "oförmultnad",
    "oförmultnat": "oförmultnad",
    "oförmultnats": "oförmultnad",
    "oförmälde": "oförmäld",
    "oförmäldes": "oförmäld",
    "oförmälds": "oförmäld",
    "oförmält": "oförmäld",
    "oförmälts": "oförmäld",
    "oförmänskligade": "oförmänskligad",
    "oförmänskligades": "oförmänskligad",
    "oförmänskligads": "oförmänskligad",
    "oförmänskligat": "oförmänskligad",
    "oförmänskligats": "oförmänskligad",
    "oförmärkta": "oförmärkt",
    "oförmärktare": "oförmärkt",
    "oförmärktares": "oförmärkt",
    "oförmärktas": "oförmärkt",
    "oförmärktast": "oförmärkt",
    "oförmärktaste": "oförmärkt",
    "oförmärktastes": "oförmärkt",
    "oförmärktasts": "oförmärkt",
    "oförmärkte": "oförmärkt",
    "oförmärktes": "oförmärkt",
    "oförmärktheten": "oförmärkthet",
    "oförmärkthetens": "oförmärkthet",
    "oförmärkthets": "oförmärkthet",
    "oförmärkts": "oförmärkt",
    "oförmågan": "oförmåga",
    "oförmågans": "oförmåga",
    "oförmågas": "oförmåga",
    "oförmåge": "oförmåga",
    "oförmågor": "oförmåga",
    "oförmågorna": "oförmåga",
    "oförmågornas": "oförmåga",
    "oförmågors": "oförmåga",
    "oförmögens": "oförmögen",
    "oförmöget": "oförmögen",
    "oförmögets": "oförmögen",
    "oförmögna": "oförmögen",
    "oförmögnare": "oförmögen",
    "oförmögnares": "oförmögen",
    "oförmögnas": "oförmögen",
    "oförmögnast": "oförmögen",
    "oförmögnaste": "oförmögen",
    "oförmögnastes": "oförmögen",
    "oförmögnasts": "oförmögen",
    "oförmögne": "oförmögen",
    "oförmögnes": "oförmögen",
    "oförmörkade": "oförmörkad",
    "oförmörkades": "oförmörkad",
    "oförmörkads": "oförmörkad",
    "oförmörkat": "oförmörkad",
    "oförmörkats": "oförmörkad",
    "oförnedrade": "oförnedrad",
    "oförnedrades": "oförnedrad",
    "oförnedrads": "oförnedrad",
    "oförnedrat": "oförnedrad",
    "oförnedrats": "oförnedrad",
    "oförnekade": "oförnekad",
    "oförnekades": "oförnekad",
    "oförnekads": "oförnekad",
    "oförnekat": "oförnekad",
    "oförnekats": "oförnekad",
    "oförnekliga": "oförneklig",
    "oförnekligare": "oförneklig",
    "oförnekligares": "oförneklig",
    "oförnekligas": "oförneklig",
    "oförnekligast": "oförneklig",
    "oförnekligaste": "oförneklig",
    "oförnekligastes": "oförneklig",
    "oförnekligasts": "oförneklig",
    "oförneklige": "oförneklig",
    "oförnekliges": "oförneklig",
    "oförnekligheten": "oförneklighet",
    "oförneklighetens": "oförneklighet",
    "oförneklighets": "oförneklighet",
    "oförnekligs": "oförneklig",
    "oförnekligt": "oförneklig",
    "oförnekligts": "oförneklig",
    "oförnicklade": "oförnicklad",
    "oförnicklades": "oförnicklad",
    "oförnicklads": "oförnicklad",
    "oförnicklat": "oförnicklad",
    "oförnicklats": "oförnicklad",
    "oförnuftiga": "oförnuftig",
    "oförnuftigare": "oförnuftig",
    "oförnuftigares": "oförnuftig",
    "oförnuftigas": "oförnuftig",
    "oförnuftigast": "oförnuftig",
    "oförnuftigaste": "oförnuftig",
    "oförnuftigastes": "oförnuftig",
    "oförnuftigasts": "oförnuftig",
    "oförnuftige": "oförnuftig",
    "oförnuftiges": "oförnuftig",
    "oförnuftigheten": "oförnuftighet",
    "oförnuftighetens": "oförnuftighet",
    "oförnuftighets": "oförnuftighet",
    "oförnuftigs": "oförnuftig",
    "oförnuftigt": "oförnuftig",
    "oförnuftigts": "oförnuftig",
    "oförnyade": "oförnyad",
    "oförnyades": "oförnyad",
    "oförnyads": "oförnyad",
    "oförnyat": "oförnyad",
    "oförnyats": "oförnyad",
    "oförnärmade": "oförnärmad",
    "oförnärmades": "oförnärmad",
    "oförnärmads": "oförnärmad",
    "oförnärmat": "oförnärmad",
    "oförnärmats": "oförnärmad",
    "oförnöjde": "oförnöjd",
    "oförnöjdes": "oförnöjd",
    "oförnöjdheten": "oförnöjdhet",
    "oförnöjdhetens": "oförnöjdhet",
    "oförnöjdhets": "oförnöjdhet",
    "oförnöjds": "oförnöjd",
    "oförnöjt": "oförnöjd",
    "oförnöjts": "oförnöjd",
    "oförnötta": "oförnött",
    "oförnöttas": "oförnött",
    "oförnötte": "oförnött",
    "oförnöttes": "oförnött",
    "oförnötts": "oförnött",
    "oförolämpade": "oförolämpad",
    "oförolämpades": "oförolämpad",
    "oförolämpads": "oförolämpad",
    "oförolämpat": "oförolämpad",
    "oförolämpats": "oförolämpad",
    "oförordade": "oförordad",
    "oförordades": "oförordad",
    "oförordads": "oförordad",
    "oförordat": "oförordad",
    "oförordats": "oförordad",
    "oförordnade": "oförordnad",
    "oförordnades": "oförordnad",
    "oförordnads": "oförordnad",
    "oförordnat": "oförordnad",
    "oförordnats": "oförordnad",
    "oförorenade": "oförorenad",
    "oförorenades": "oförorenad",
    "oförorenads": "oförorenad",
    "oförorenat": "oförorenad",
    "oförorenats": "oförorenad",
    "oförorsakade": "oförorsakad",
    "oförorsakades": "oförorsakad",
    "oförorsakads": "oförorsakad",
    "oförorsakat": "oförorsakad",
    "oförorsakats": "oförorsakad",
    "oförorättade": "oförorättad",
    "oförorättades": "oförorättad",
    "oförorättads": "oförorättad",
    "oförorättat": "oförorättad",
    "oförorättats": "oförorättad",
    "oförpackade": "oförpackad",
    "oförpackades": "oförpackad",
    "oförpackads": "oförpackad",
    "oförpackat": "oförpackad",
    "oförpackats": "oförpackad",
    "oförpaktade": "oförpaktad",
    "oförpaktades": "oförpaktad",
    "oförpaktads": "oförpaktad",
    "oförpaktat": "oförpaktad",
    "oförpaktats": "oförpaktad",
    "oförpantade": "oförpantad",
    "oförpantades": "oförpantad",
    "oförpantads": "oförpantad",
    "oförpantat": "oförpantad",
    "oförpantats": "oförpantad",
    "oförpassade": "oförpassad",
    "oförpassades": "oförpassad",
    "oförpassads": "oförpassad",
    "oförpassat": "oförpassad",
    "oförpassats": "oförpassad",
    "oförpestade": "oförpestad",
    "oförpestades": "oförpestad",
    "oförpestads": "oförpestad",
    "oförpestat": "oförpestad",
    "oförpestats": "oförpestad",
    "oförpliktade": "oförpliktad",
    "oförpliktades": "oförpliktad",
    "oförpliktads": "oförpliktad",
    "oförpliktat": "oförpliktad",
    "oförpliktats": "oförpliktad",
    "oförpliktigade": "oförpliktigad",
    "oförpliktigades": "oförpliktigad",
    "oförpliktigads": "oförpliktigad",
    "oförpliktigat": "oförpliktigad",
    "oförpliktigats": "oförpliktigad",
    "oförplägade": "oförplägad",
    "oförplägades": "oförplägad",
    "oförplägads": "oförplägad",
    "oförplägat": "oförplägad",
    "oförplägats": "oförplägad",
    "oförprickade": "oförprickad",
    "oförprickades": "oförprickad",
    "oförprickads": "oförprickad",
    "oförprickat": "oförprickad",
    "oförprickats": "oförprickad",
    "oförringade": "oförringad",
    "oförringades": "oförringad",
    "oförringads": "oförringad",
    "oförringat": "oförringad",
    "oförringats": "oförringad",
    "oförruttnade": "oförruttnad",
    "oförruttnades": "oförruttnad",
    "oförruttnads": "oförruttnad",
    "oförruttnat": "oförruttnad",
    "oförruttnats": "oförruttnad",
    "oförryckta": "oförryckt",
    "oförrycktas": "oförryckt",
    "oförryckte": "oförryckt",
    "oförrycktes": "oförryckt",
    "oförrycktheten": "oförryckthet",
    "oförryckthetens": "oförryckthet",
    "oförryckthets": "oförryckthet",
    "oförryckts": "oförryckt",
    "oförryskade": "oförryskad",
    "oförryskades": "oförryskad",
    "oförryskads": "oförryskad",
    "oförryskat": "oförryskad",
    "oförryskats": "oförryskad",
    "oförräntade": "oförräntad",
    "oförräntades": "oförräntad",
    "oförräntads": "oförräntad",
    "oförräntat": "oförräntad",
    "oförräntats": "oförräntad",
    "oförrättade": "oförrättad",
    "oförrättades": "oförrättad",
    "oförrättads": "oförrättad",
    "oförrättat": "oförrättad",
    "oförrättats": "oförrättad",
    "oförrätten": "oförrätt",
    "oförrättens": "oförrätt",
    "oförrätter": "oförrätt",
    "oförrätterna": "oförrätt",
    "oförrätternas": "oförrätt",
    "oförrätters": "oförrätt",
    "oförrätts": "oförrätt",
    "oförråade": "oförråad",
    "oförråades": "oförråad",
    "oförråads": "oförråad",
    "oförråat": "oförråad",
    "oförråats": "oförråad",
    "oförs": "oför",
    "oförsakade": "oförsakad",
    "oförsakades": "oförsakad",
    "oförsakads": "oförsakad",
    "oförsakat": "oförsakad",
    "oförsakats": "oförsakad",
    "oförsamlade": "oförsamlad",
    "oförsamlades": "oförsamlad",
    "oförsamlads": "oförsamlad",
    "oförsamlat": "oförsamlad",
    "oförsamlats": "oförsamlad",
    "oförseglade": "oförseglad",
    "oförseglades": "oförseglad",
    "oförseglads": "oförseglad",
    "oförseglat": "oförseglad",
    "oförseglats": "oförseglad",
    "oförsenade": "oförsenad",
    "oförsenades": "oförsenad",
    "oförsenads": "oförsenad",
    "oförsenat": "oförsenad",
    "oförsenats": "oförsenad",
    "oförsiktiga": "oförsiktig",
    "oförsiktigare": "oförsiktig",
    "oförsiktigares": "oförsiktig",
    "oförsiktigas": "oförsiktig",
    "oförsiktigast": "oförsiktig",
    "oförsiktigaste": "oförsiktig",
    "oförsiktigastes": "oförsiktig",
    "oförsiktigasts": "oförsiktig",
    "oförsiktige": "oförsiktig",
    "oförsiktiges": "oförsiktig",
    "oförsiktigheten": "oförsiktighet",
    "oförsiktighetens": "oförsiktighet",
    "oförsiktighets": "oförsiktighet",
    "oförsiktigs": "oförsiktig",
    "oförsiktigt": "oförsiktig",
    "oförsiktigts": "oförsiktig",
    "oförsilvrade": "oförsilvrad",
    "oförsilvrades": "oförsilvrad",
    "oförsilvrads": "oförsilvrad",
    "oförsilvrat": "oförsilvrad",
    "oförsilvrats": "oförsilvrad",
    "oförsinkade": "oförsinkad",
    "oförsinkades": "oförsinkad",
    "oförsinkads": "oförsinkad",
    "oförsinkat": "oförsinkad",
    "oförsinkats": "oförsinkad",
    "oförskaffade": "oförskaffad",
    "oförskaffades": "oförskaffad",
    "oförskaffads": "oförskaffad",
    "oförskaffat": "oförskaffad",
    "oförskaffats": "oförskaffad",
    "oförskansade": "oförskansad",
    "oförskansades": "oförskansad",
    "oförskansads": "oförskansad",
    "oförskansat": "oförskansad",
    "oförskansats": "oförskansad",
    "oförskingrade": "oförskingrad",
    "oförskingrades": "oförskingrad",
    "oförskingrads": "oförskingrad",
    "oförskingrat": "oförskingrad",
    "oförskingrats": "oförskingrad",
    "oförskonade": "oförskonad",
    "oförskonades": "oförskonad",
    "oförskonads": "oförskonad",
    "oförskonat": "oförskonad",
    "oförskonats": "oförskonad",
    "oförskotterade": "oförskotterad",
    "oförskotterades": "oförskotterad",
    "oförskotterads": "oförskotterad",
    "oförskotterat": "oförskotterad",
    "oförskotterats": "oförskotterad",
    "oförskotterbara": "oförskotterbar",
    "oförskotterbarare": "oförskotterbar",
    "oförskotterbarares": "oförskotterbar",
    "oförskotterbaras": "oförskotterbar",
    "oförskotterbarast": "oförskotterbar",
    "oförskotterbaraste": "oförskotterbar",
    "oförskotterbarastes": "oförskotterbar",
    "oförskotterbarasts": "oförskotterbar",
    "oförskotterbare": "oförskotterbar",
    "oförskotterbares": "oförskotterbar",
    "oförskotterbarheten": "oförskotterbarhet",
    "oförskotterbarhetens": "oförskotterbarhet",
    "oförskotterbarhets": "oförskotterbarhet",
    "oförskotterbars": "oförskotterbar",
    "oförskotterbart": "oförskotterbar",
    "oförskotterbarts": "oförskotterbar",
    "oförskräckta": "oförskräckt",
    "oförskräcktare": "oförskräckt",
    "oförskräcktares": "oförskräckt",
    "oförskräcktas": "oförskräckt",
    "oförskräcktast": "oförskräckt",
    "oförskräcktaste": "oförskräckt",
    "oförskräcktastes": "oförskräckt",
    "oförskräcktasts": "oförskräckt",
    "oförskräckte": "oförskräckt",
    "oförskräcktes": "oförskräckt",
    "oförskräcktheten": "oförskräckthet",
    "oförskräckthetens": "oförskräckthet",
    "oförskräckthets": "oförskräckthet",
    "oförskräckts": "oförskräckt",
    "oförskyllda": "oförskylld",
    "oförskylldare": "oförskylld",
    "oförskylldares": "oförskylld",
    "oförskylldas": "oförskylld",
    "oförskylldast": "oförskylld",
    "oförskylldaste": "oförskylld",
    "oförskylldastes": "oförskylld",
    "oförskylldasts": "oförskylld",
    "oförskyllde": "oförskylld",
    "oförskylldes": "oförskylld",
    "oförskylldheten": "oförskylldhet",
    "oförskylldhetens": "oförskylldhet",
    "oförskylldhets": "oförskylldhet",
    "oförskyllds": "oförskylld",
    "oförskyllt": "oförskylld",
    "oförskyllts": "oförskylld",
    "oförskämda": "oförskämd",
    "oförskämdare": "oförskämd",
    "oförskämdares": "oförskämd",
    "oförskämdas": "oförskämd",
    "oförskämdast": "oförskämd",
    "oförskämdaste": "oförskämd",
    "oförskämdastes": "oförskämd",
    "oförskämdasts": "oförskämd",
    "oförskämde": "oförskämd",
    "oförskämdes": "oförskämd",
    "oförskämdheten": "oförskämdhet",
    "oförskämdhetens": "oförskämdhet",
    "oförskämdheter": "oförskämdhet",
    "oförskämdheterna": "oförskämdhet",
    "oförskämdheternas": "oförskämdhet",
    "oförskämdheters": "oförskämdhet",
    "oförskämdhets": "oförskämdhet",
    "oförskämds": "oförskämd",
    "oförskämt": "oförskämd",
    "oförskämts": "oförskämd",
    "oförskönade": "oförskönad",
    "oförskönades": "oförskönad",
    "oförskönads": "oförskönad",
    "oförskönat": "oförskönad",
    "oförskönats": "oförskönad",
    "oförslappade": "oförslappad",
    "oförslappades": "oförslappad",
    "oförslappads": "oförslappad",
    "oförslappat": "oförslappad",
    "oförslappats": "oförslappad",
    "oförslavade": "oförslavad",
    "oförslavades": "oförslavad",
    "oförslavads": "oförslavad",
    "oförslavat": "oförslavad",
    "oförslavats": "oförslavad",
    "oförslöade": "oförslöad",
    "oförslöades": "oförslöad",
    "oförslöads": "oförslöad",
    "oförslöat": "oförslöad",
    "oförslöats": "oförslöad",
    "oförslösade": "oförslösad",
    "oförslösades": "oförslösad",
    "oförslösads": "oförslösad",
    "oförslösat": "oförslösad",
    "oförslösats": "oförslösad",
    "oförsnillade": "oförsnillad",
    "oförsnillades": "oförsnillad",
    "oförsnillads": "oförsnillad",
    "oförsnillat": "oförsnillad",
    "oförsnillats": "oförsnillad",
    "oförsoffade": "oförsoffad",
    "oförsoffades": "oförsoffad",
    "oförsoffads": "oförsoffad",
    "oförsoffat": "oförsoffad",
    "oförsoffats": "oförsoffad",
    "oförsonade": "oförsonad",
    "oförsonades": "oförsonad",
    "oförsonads": "oförsonad",
    "oförsonat": "oförsonad",
    "oförsonats": "oförsonad",
    "oförsonliga": "oförsonlig",
    "oförsonligare": "oförsonlig",
    "oförsonligares": "oförsonlig",
    "oförsonligas": "oförsonlig",
    "oförsonligast": "oförsonlig",
    "oförsonligaste": "oförsonlig",
    "oförsonligastes": "oförsonlig",
    "oförsonligasts": "oförsonlig",
    "oförsonlige": "oförsonlig",
    "oförsonliges": "oförsonlig",
    "oförsonligheten": "oförsonlighet",
    "oförsonlighetens": "oförsonlighet",
    "oförsonlighets": "oförsonlighet",
    "oförsonligs": "oförsonlig",
    "oförsonligt": "oförsonlig",
    "oförsonligts": "oförsonlig",
    "oförspillde": "oförspilld",
    "oförspilldes": "oförspilld",
    "oförspillds": "oförspilld",
    "oförspillt": "oförspilld",
    "oförspillts": "oförspilld",
    "oförstatligade": "oförstatligad",
    "oförstatligades": "oförstatligad",
    "oförstatligads": "oförstatligad",
    "oförstatligat": "oförstatligad",
    "oförstatligats": "oförstatligad",
    "oförstelnade": "oförstelnad",
    "oförstelnades": "oförstelnad",
    "oförstelnads": "oförstelnad",
    "oförstelnat": "oförstelnad",
    "oförstelnats": "oförstelnad",
    "oförstenade": "oförstenad",
    "oförstenades": "oförstenad",
    "oförstenads": "oförstenad",
    "oförstenat": "oförstenad",
    "oförstenats": "oförstenad",
    "oförstockade": "oförstockad",
    "oförstockades": "oförstockad",
    "oförstockads": "oförstockad",
    "oförstockat": "oförstockad",
    "oförstockats": "oförstockad",
    "oförstoppade": "oförstoppad",
    "oförstoppades": "oförstoppad",
    "oförstoppads": "oförstoppad",
    "oförstoppat": "oförstoppad",
    "oförstoppats": "oförstoppad",
    "oförstorade": "oförstorad",
    "oförstorades": "oförstorad",
    "oförstorads": "oförstorad",
    "oförstorat": "oförstorad",
    "oförstorats": "oförstorad",
    "oförsträckta": "oförsträckt",
    "oförsträcktas": "oförsträckt",
    "oförsträckte": "oförsträckt",
    "oförsträcktes": "oförsträckt",
    "oförsträckts": "oförsträckt",
    "oförsträvade": "oförsträvad",
    "oförsträvades": "oförsträvad",
    "oförsträvads": "oförsträvad",
    "oförsträvat": "oförsträvad",
    "oförsträvats": "oförsträvad",
    "oförstummade": "oförstummad",
    "oförstummades": "oförstummad",
    "oförstummads": "oförstummad",
    "oförstummat": "oförstummad",
    "oförstummats": "oförstummad",
    "oförställda": "oförställd",
    "oförställdare": "oförställd",
    "oförställdares": "oförställd",
    "oförställdas": "oförställd",
    "oförställdast": "oförställd",
    "oförställdaste": "oförställd",
    "oförställdastes": "oförställd",
    "oförställdasts": "oförställd",
    "oförställde": "oförställd",
    "oförställdes": "oförställd",
    "oförställdheten": "oförställdhet",
    "oförställdhetens": "oförställdhet",
    "oförställdhets": "oförställdhet",
    "oförställds": "oförställd",
    "oförställt": "oförställd",
    "oförställts": "oförställd",
    "oförstämde": "oförstämd",
    "oförstämdes": "oförstämd",
    "oförstämdheten": "oförstämdhet",
    "oförstämdhetens": "oförstämdhet",
    "oförstämdhets": "oförstämdhet",
    "oförstämds": "oförstämd",
    "oförstämt": "oförstämd",
    "oförstämts": "oförstämd",
    "oförständigade": "oförständigad",
    "oförständigades": "oförständigad",
    "oförständigads": "oförständigad",
    "oförständigat": "oförständigad",
    "oförständigats": "oförständigad",
    "oförstärkta": "oförstärkt",
    "oförstärktas": "oförstärkt",
    "oförstärkte": "oförstärkt",
    "oförstärktes": "oförstärkt",
    "oförstärkts": "oförstärkt",
    "oförståeliga": "oförståelig",
    "oförståeligare": "oförståelig",
    "oförståeligares": "oförståelig",
    "oförståeligas": "oförståelig",
    "oförståeligast": "oförståelig",
    "oförståeligaste": "oförståelig",
    "oförståeligastes": "oförståelig",
    "oförståeligasts": "oförståelig",
    "oförståelige": "oförståelig",
    "oförståeliges": "oförståelig",
    "oförståeligheten": "oförståelighet",
    "oförståelighetens": "oförståelighet",
    "oförståeligheter": "oförståelighet",
    "oförståeligheterna": "oförståelighet",
    "oförståeligheternas": "oförståelighet",
    "oförståeligheters": "oförståelighet",
    "oförståelighets": "oförståelighet",
    "oförståeligs": "oförståelig",
    "oförståeligt": "oförståelig",
    "oförståeligts": "oförståelig",
    "oförståelsen": "oförståelse",
    "oförståelsens": "oförståelse",
    "oförståelses": "oförståelse",
    "oförståndet": "oförstånd",
    "oförståndets": "oförstånd",
    "oförståndiga": "oförståndig",
    "oförståndigare": "oförståndig",
    "oförståndigares": "oförståndig",
    "oförståndigas": "oförståndig",
    "oförståndigast": "oförståndig",
    "oförståndigaste": "oförståndig",
    "oförståndigastes": "oförståndig",
    "oförståndigasts": "oförståndig",
    "oförståndige": "oförståndig",
    "oförståndiges": "oförståndig",
    "oförståndigheten": "oförståndighet",
    "oförståndighetens": "oförståndighet",
    "oförståndighets": "oförståndighet",
    "oförståndigs": "oförståndig",
    "oförståndigt": "oförståndig",
    "oförståndigts": "oförståndig",
    "oförstånds": "oförstånd",
    "oförstörbara": "oförstörbar",
    "oförstörbarare": "oförstörbar",
    "oförstörbarares": "oförstörbar",
    "oförstörbaras": "oförstörbar",
    "oförstörbarast": "oförstörbar",
    "oförstörbaraste": "oförstörbar",
    "oförstörbarastes": "oförstörbar",
    "oförstörbarasts": "oförstörbar",
    "oförstörbare": "oförstörbar",
    "oförstörbares": "oförstörbar",
    "oförstörbarheten": "oförstörbarhet",
    "oförstörbarhetens": "oförstörbarhet",
    "oförstörbarhets": "oförstörbarhet",
    "oförstörbars": "oförstörbar",
    "oförstörbart": "oförstörbar",
    "oförstörbarts": "oförstörbar",
    "oförstörda": "oförstörd",
    "oförstördare": "oförstörd",
    "oförstördares": "oförstörd",
    "oförstördas": "oförstörd",
    "oförstördast": "oförstörd",
    "oförstördaste": "oförstörd",
    "oförstördastes": "oförstörd",
    "oförstördasts": "oförstörd",
    "oförstörde": "oförstörd",
    "oförstördes": "oförstörd",
    "oförstördheten": "oförstördhet",
    "oförstördhetens": "oförstördhet",
    "oförstördhets": "oförstördhet",
    "oförstörds": "oförstörd",
    "oförstört": "oförstörd",
    "oförstörts": "oförstörd",
    "oförsummade": "oförsummad",
    "oförsummades": "oförsummad",
    "oförsummads": "oförsummad",
    "oförsummat": "oförsummad",
    "oförsummats": "oförsummad",
    "oförsurade": "oförsurad",
    "oförsurades": "oförsurad",
    "oförsurads": "oförsurad",
    "oförsurat": "oförsurad",
    "oförsurats": "oförsurad",
    "oförsvagade": "oförsvagad",
    "oförsvagades": "oförsvagad",
    "oförsvagads": "oförsvagad",
    "oförsvagat": "oförsvagad",
    "oförsvagats": "oförsvagad",
    "oförsvarade": "oförsvarad",
    "oförsvarades": "oförsvarad",
    "oförsvarads": "oförsvarad",
    "oförsvarat": "oförsvarad",
    "oförsvarats": "oförsvarad",
    "oförsvarliga": "oförsvarlig",
    "oförsvarligare": "oförsvarlig",
    "oförsvarligares": "oförsvarlig",
    "oförsvarligas": "oförsvarlig",
    "oförsvarligast": "oförsvarlig",
    "oförsvarligaste": "oförsvarlig",
    "oförsvarligastes": "oförsvarlig",
    "oförsvarligasts": "oförsvarlig",
    "oförsvarlige": "oförsvarlig",
    "oförsvarliges": "oförsvarlig",
    "oförsvarligheten": "oförsvarlighet",
    "oförsvarlighetens": "oförsvarlighet",
    "oförsvarlighets": "oförsvarlighet",
    "oförsvarligs": "oförsvarlig",
    "oförsvarligt": "oförsvarlig",
    "oförsvarligts": "oförsvarlig",
    "oförsvenskade": "oförsvenskad",
    "oförsvenskades": "oförsvenskad",
    "oförsvenskads": "oförsvenskad",
    "oförsvenskat": "oförsvenskad",
    "oförsvenskats": "oförsvenskad",
    "oförsvårade": "oförsvårad",
    "oförsvårades": "oförsvårad",
    "oförsvårads": "oförsvårad",
    "oförsvårat": "oförsvårad",
    "oförsvårats": "oförsvårad",
    "oförsynta": "oförsynt",
    "oförsyntare": "oförsynt",
    "oförsyntares": "oförsynt",
    "oförsyntas": "oförsynt",
    "oförsyntast": "oförsynt",
    "oförsyntaste": "oförsynt",
    "oförsyntastes": "oförsynt",
    "oförsyntasts": "oförsynt",
    "oförsynte": "oförsynt",
    "oförsyntes": "oförsynt",
    "oförsyntheten": "oförsynthet",
    "oförsynthetens": "oförsynthet",
    "oförsynthets": "oförsynthet",
    "oförsynts": "oförsynt",
    "oförsäkrade": "oförsäkrad",
    "oförsäkrades": "oförsäkrad",
    "oförsäkrads": "oförsäkrad",
    "oförsäkrat": "oförsäkrad",
    "oförsäkrats": "oförsäkrad",
    "oförsämrade": "oförsämrad",
    "oförsämrades": "oförsämrad",
    "oförsämrads": "oförsämrad",
    "oförsämrat": "oförsämrad",
    "oförsämrats": "oförsämrad",
    "oförsände": "oförsänd",
    "oförsändes": "oförsänd",
    "oförsänds": "oförsänd",
    "oförsänkta": "oförsänkt",
    "oförsänktas": "oförsänkt",
    "oförsänkte": "oförsänkt",
    "oförsänktes": "oförsänkt",
    "oförsänkts": "oförsänkt",
    "oförsänt": "oförsänd",
    "oförsänts": "oförsänd",
    "oförsörjde": "oförsörjd",
    "oförsörjdes": "oförsörjd",
    "oförsörjds": "oförsörjd",
    "oförsörjt": "oförsörjd",
    "oförsörjts": "oförsörjd",
    "ofört": "oförd",
    "oförtalade": "oförtalad",
    "oförtalades": "oförtalad",
    "oförtalads": "oförtalad",
    "oförtalat": "oförtalad",
    "oförtalats": "oförtalad",
    "oförtecknade": "oförtecknad",
    "oförtecknades": "oförtecknad",
    "oförtecknads": "oförtecknad",
    "oförtecknat": "oförtecknad",
    "oförtecknats": "oförtecknad",
    "oförtennade": "oförtennad",
    "oförtennades": "oförtennad",
    "oförtennads": "oförtennad",
    "oförtennat": "oförtennad",
    "oförtennats": "oförtennad",
    "oförtjockade": "oförtjockad",
    "oförtjockades": "oförtjockad",
    "oförtjockads": "oförtjockad",
    "oförtjockat": "oförtjockad",
    "oförtjockats": "oförtjockad",
    "oförtjusta": "oförtjust",
    "oförtjustas": "oförtjust",
    "oförtjuste": "oförtjust",
    "oförtjustes": "oförtjust",
    "oförtjustheten": "oförtjusthet",
    "oförtjusthetens": "oförtjusthet",
    "oförtjusthets": "oförtjusthet",
    "oförtjusts": "oförtjust",
    "oförtjänade": "oförtjänad",
    "oförtjänades": "oförtjänad",
    "oförtjänads": "oförtjänad",
    "oförtjänat": "oförtjänad",
    "oförtjänats": "oförtjänad",
    "oförtjänta": "oförtjänt",
    "oförtjäntare": "oförtjänt",
    "oförtjäntares": "oförtjänt",
    "oförtjäntas": "oförtjänt",
    "oförtjäntast": "oförtjänt",
    "oförtjäntaste": "oförtjänt",
    "oförtjäntastes": "oförtjänt",
    "oförtjäntasts": "oförtjänt",
    "oförtjänte": "oförtjänt",
    "oförtjäntes": "oförtjänt",
    "oförtjäntheten": "oförtjänthet",
    "oförtjänthetens": "oförtjänthet",
    "oförtjänthets": "oförtjänthet",
    "oförtjänts": "oförtjänt",
    "oförtorkade": "oförtorkad",
    "oförtorkades": "oförtorkad",
    "oförtorkads": "oförtorkad",
    "oförtorkat": "oförtorkad",
    "oförtorkats": "oförtorkad",
    "oförtrampade": "oförtrampad",
    "oförtrampades": "oförtrampad",
    "oförtrampads": "oförtrampad",
    "oförtrampat": "oförtrampad",
    "oförtrampats": "oförtrampad",
    "oförtretade": "oförtretad",
    "oförtretades": "oförtretad",
    "oförtretads": "oförtretad",
    "oförtretat": "oförtretad",
    "oförtretats": "oförtretad",
    "oförtrollade": "oförtrollad",
    "oförtrollades": "oförtrollad",
    "oförtrollads": "oförtrollad",
    "oförtrollat": "oförtrollad",
    "oförtrollats": "oförtrollad",
    "oförtrustade": "oförtrustad",
    "oförtrustades": "oförtrustad",
    "oförtrustads": "oförtrustad",
    "oförtrustat": "oförtrustad",
    "oförtrustats": "oförtrustad",
    "oförtrutens": "oförtruten",
    "oförtrutet": "oförtruten",
    "oförtrutets": "oförtruten",
    "oförtrutna": "oförtruten",
    "oförtrutnare": "oförtruten",
    "oförtrutnares": "oförtruten",
    "oförtrutnas": "oförtruten",
    "oförtrutnast": "oförtruten",
    "oförtrutnaste": "oförtruten",
    "oförtrutnastes": "oförtruten",
    "oförtrutnasts": "oförtruten",
    "oförtrutne": "oförtruten",
    "oförtrutnes": "oförtruten",
    "oförtryckta": "oförtryckt",
    "oförtrycktas": "oförtryckt",
    "oförtryckte": "oförtryckt",
    "oförtrycktes": "oförtryckt",
    "oförtryckts": "oförtryckt",
    "oförträngde": "oförträngd",
    "oförträngdes": "oförträngd",
    "oförträngds": "oförträngd",
    "oförträngt": "oförträngd",
    "oförträngts": "oförträngd",
    "oförtröstade": "oförtröstad",
    "oförtröstades": "oförtröstad",
    "oförtröstads": "oförtröstad",
    "oförtröstat": "oförtröstad",
    "oförtröstats": "oförtröstad",
    "oförtröttliga": "oförtröttlig",
    "oförtröttligare": "oförtröttlig",
    "oförtröttligares": "oförtröttlig",
    "oförtröttligas": "oförtröttlig",
    "oförtröttligast": "oförtröttlig",
    "oförtröttligaste": "oförtröttlig",
    "oförtröttligastes": "oförtröttlig",
    "oförtröttligasts": "oförtröttlig",
    "oförtröttlige": "oförtröttlig",
    "oförtröttliges": "oförtröttlig",
    "oförtröttligheten": "oförtröttlighet",
    "oförtröttlighetens": "oförtröttlighet",
    "oförtröttlighets": "oförtröttlighet",
    "oförtröttligs": "oförtröttlig",
    "oförtröttligt": "oförtröttlig",
    "oförtröttligts": "oförtröttlig",
    "oförts": "oförd",
    "oförtullade": "oförtullad",
    "oförtullades": "oförtullad",
    "oförtullads": "oförtullad",
    "oförtullat": "oförtullad",
    "oförtullats": "oförtullad",
    "oförtunnade": "oförtunnad",
    "oförtunnades": "oförtunnad",
    "oförtunnads": "oförtunnad",
    "oförtunnat": "oförtunnad",
    "oförtunnats": "oförtunnad",
    "oförtvinade": "oförtvinad",
    "oförtvinades": "oförtvinad",
    "oförtvinads": "oförtvinad",
    "oförtvinat": "oförtvinad",
    "oförtvinats": "oförtvinad",
    "oförtvivlade": "oförtvivlad",
    "oförtvivlades": "oförtvivlad",
    "oförtvivlads": "oförtvivlad",
    "oförtvivlat": "oförtvivlad",
    "oförtvivlats": "oförtvivlad",
    "oförtvålade": "oförtvålad",
    "oförtvålades": "oförtvålad",
    "oförtvålads": "oförtvålad",
    "oförtvålat": "oförtvålad",
    "oförtvålats": "oförtvålad",
    "oförtyckta": "oförtyckt",
    "oförtycktas": "oförtyckt",
    "oförtyckte": "oförtyckt",
    "oförtycktes": "oförtyckt",
    "oförtyckts": "oförtyckt",
    "oförtydbara": "oförtydbar",
    "oförtydbarare": "oförtydbar",
    "oförtydbarares": "oförtydbar",
    "oförtydbaras": "oförtydbar",
    "oförtydbarast": "oförtydbar",
    "oförtydbaraste": "oförtydbar",
    "oförtydbarastes": "oförtydbar",
    "oförtydbarasts": "oförtydbar",
    "oförtydbare": "oförtydbar",
    "oförtydbares": "oförtydbar",
    "oförtydbarheten": "oförtydbarhet",
    "oförtydbarhetens": "oförtydbarhet",
    "oförtydbarhets": "oförtydbarhet",
    "oförtydbars": "oförtydbar",
    "oförtydbart": "oförtydbar",
    "oförtydbarts": "oförtydbar",
    "oförtydligade": "oförtydligad",
    "oförtydligades": "oförtydligad",
    "oförtydligads": "oförtydligad",
    "oförtydligat": "oförtydligad",
    "oförtydligats": "oförtydligad",
    "oförtyskade": "oförtyskad",
    "oförtyskades": "oförtyskad",
    "oförtyskads": "oförtyskad",
    "oförtyskat": "oförtyskad",
    "oförtyskats": "oförtyskad",
    "oförtäckta": "oförtäckt",
    "oförtäcktare": "oförtäckt",
    "oförtäcktares": "oförtäckt",
    "oförtäcktas": "oförtäckt",
    "oförtäcktast": "oförtäckt",
    "oförtäcktaste": "oförtäckt",
    "oförtäcktastes": "oförtäckt",
    "oförtäcktasts": "oförtäckt",
    "oförtäckte": "oförtäckt",
    "oförtäcktes": "oförtäckt",
    "oförtäcktheten": "oförtäckthet",
    "oförtäckthetens": "oförtäckthet",
    "oförtäckthets": "oförtäckthet",
    "oförtäckts": "oförtäckt",
    "oförtänkta": "oförtänkt",
    "oförtänktare": "oförtänkt",
    "oförtänktares": "oförtänkt",
    "oförtänktas": "oförtänkt",
    "oförtänktast": "oförtänkt",
    "oförtänktaste": "oförtänkt",
    "oförtänktastes": "oförtänkt",
    "oförtänktasts": "oförtänkt",
    "oförtänkte": "oförtänkt",
    "oförtänktes": "oförtänkt",
    "oförtänkts": "oförtänkt",
    "oförtärde": "oförtärd",
    "oförtärdes": "oförtärd",
    "oförtärds": "oförtärd",
    "oförtärt": "oförtärd",
    "oförtärts": "oförtärd",
    "oförtätade": "oförtätad",
    "oförtätades": "oförtätad",
    "oförtätads": "oförtätad",
    "oförtätat": "oförtätad",
    "oförtätats": "oförtätad",
    "oförtöjde": "oförtöjd",
    "oförtöjdes": "oförtöjd",
    "oförtöjds": "oförtöjd",
    "oförtöjt": "oförtöjd",
    "oförtöjts": "oförtöjd",
    "oförtövade": "oförtövad",
    "oförtövades": "oförtövad",
    "oförtövads": "oförtövad",
    "oförtövat": "oförtövad",
    "oförtövats": "oförtövad",
    "oförundrade": "oförundrad",
    "oförundrades": "oförundrad",
    "oförundrads": "oförundrad",
    "oförundrat": "oförundrad",
    "oförundrats": "oförundrad",
    "oförunnade": "oförunnad",
    "oförunnades": "oförunnad",
    "oförunnads": "oförunnad",
    "oförunnat": "oförunnad",
    "oförunnats": "oförunnad",
    "oförutbestämde": "oförutbestämd",
    "oförutbestämdes": "oförutbestämd",
    "oförutbestämdheten": "oförutbestämdhet",
    "oförutbestämdhetens": "oförutbestämdhet",
    "oförutbestämdhets": "oförutbestämdhet",
    "oförutbestämds": "oförutbestämd",
    "oförutbestämt": "oförutbestämd",
    "oförutbestämts": "oförutbestämd",
    "oförutsebara": "oförutsebar",
    "oförutsebarare": "oförutsebar",
    "oförutsebarares": "oförutsebar",
    "oförutsebaras": "oförutsebar",
    "oförutsebarast": "oförutsebar",
    "oförutsebaraste": "oförutsebar",
    "oförutsebarastes": "oförutsebar",
    "oförutsebarasts": "oförutsebar",
    "oförutsebare": "oförutsebar",
    "oförutsebares": "oförutsebar",
    "oförutsebarheten": "oförutsebarhet",
    "oförutsebarhetens": "oförutsebarhet",
    "oförutsebarhets": "oförutsebarhet",
    "oförutsebars": "oförutsebar",
    "oförutsebart": "oförutsebar",
    "oförutsebarts": "oförutsebar",
    "oförutsedda": "oförutsedd",
    "oförutseddare": "oförutsedd",
    "oförutseddares": "oförutsedd",
    "oförutseddas": "oförutsedd",
    "oförutseddast": "oförutsedd",
    "oförutseddaste": "oförutsedd",
    "oförutseddastes": "oförutsedd",
    "oförutseddasts": "oförutsedd",
    "oförutsedde": "oförutsedd",
    "oförutseddes": "oförutsedd",
    "oförutseddheten": "oförutseddhet",
    "oförutseddhetens": "oförutseddhet",
    "oförutseddhets": "oförutseddhet",
    "oförutsedds": "oförutsedd",
    "oförutsett": "oförutsedd",
    "oförutsetts": "oförutsedd",
    "oförutskickade": "oförutskickad",
    "oförutskickades": "oförutskickad",
    "oförutskickads": "oförutskickad",
    "oförutskickat": "oförutskickad",
    "oförutskickats": "oförutskickad",
    "oförutspådda": "oförutspådd",
    "oförutspåddare": "oförutspådd",
    "oförutspåddares": "oförutspådd",
    "oförutspåddas": "oförutspådd",
    "oförutspåddast": "oförutspådd",
    "oförutspåddaste": "oförutspådd",
    "oförutspåddastes": "oförutspådd",
    "oförutspåddasts": "oförutspådd",
    "oförutspådde": "oförutspådd",
    "oförutspåddes": "oförutspådd",
    "oförutspåddheten": "oförutspåddhet",
    "oförutspåddhetens": "oförutspåddhet",
    "oförutspåddhets": "oförutspåddhet",
    "oförutspådds": "oförutspådd",
    "oförutspått": "oförutspådd",
    "oförutspåtts": "oförutspådd",
    "oförutsägbara": "oförutsägbar",
    "oförutsägbarare": "oförutsägbar",
    "oförutsägbarares": "oförutsägbar",
    "oförutsägbaras": "oförutsägbar",
    "oförutsägbarast": "oförutsägbar",
    "oförutsägbaraste": "oförutsägbar",
    "oförutsägbarastes": "oförutsägbar",
    "oförutsägbarasts": "oförutsägbar",
    "oförutsägbare": "oförutsägbar",
    "oförutsägbares": "oförutsägbar",
    "oförutsägbarheten": "oförutsägbarhet",
    "oförutsägbarhetens": "oförutsägbarhet",
    "oförutsägbarhets": "oförutsägbarhet",
    "oförutsägbars": "oförutsägbar",
    "oförutsägbart": "oförutsägbar",
    "oförutsägbarts": "oförutsägbar",
    "oförvaltade": "oförvaltad",
    "oförvaltades": "oförvaltad",
    "oförvaltads": "oförvaltad",
    "oförvaltat": "oförvaltad",
    "oförvaltats": "oförvaltad",
    "oförvandlade": "oförvandlad",
    "oförvandlades": "oförvandlad",
    "oförvandlads": "oförvandlad",
    "oförvandlat": "oförvandlad",
    "oförvandlats": "oförvandlad",
    "oförvanskade": "oförvanskad",
    "oförvanskades": "oförvanskad",
    "oförvanskads": "oförvanskad",
    "oförvanskat": "oförvanskad",
    "oförvanskats": "oförvanskad",
    "oförvarade": "oförvarad",
    "oförvarades": "oförvarad",
    "oförvarads": "oförvarad",
    "oförvarat": "oförvarad",
    "oförvarats": "oförvarad",
    "oförvarnade": "oförvarnad",
    "oförvarnades": "oförvarnad",
    "oförvarnads": "oförvarnad",
    "oförvarnat": "oförvarnad",
    "oförvarnats": "oförvarnad",
    "oförvedade": "oförvedad",
    "oförvedades": "oförvedad",
    "oförvedads": "oförvedad",
    "oförvedat": "oförvedad",
    "oförvedats": "oförvedad",
    "oförvekligade": "oförvekligad",
    "oförvekligades": "oförvekligad",
    "oförvekligads": "oförvekligad",
    "oförvekligat": "oförvekligad",
    "oförvekligats": "oförvekligad",
    "oförverkade": "oförverkad",
    "oförverkades": "oförverkad",
    "oförverkads": "oförverkad",
    "oförverkat": "oförverkad",
    "oförverkats": "oförverkad",
    "oförverkligade": "oförverkligad",
    "oförverkligades": "oförverkligad",
    "oförverkligads": "oförverkligad",
    "oförverkligat": "oförverkligad",
    "oförverkligats": "oförverkligad",
    "oförvillade": "oförvillad",
    "oförvillades": "oförvillad",
    "oförvillads": "oförvillad",
    "oförvillat": "oförvillad",
    "oförvillats": "oförvillad",
    "oförvirrade": "oförvirrad",
    "oförvirrades": "oförvirrad",
    "oförvirrads": "oförvirrad",
    "oförvirrat": "oförvirrad",
    "oförvirrats": "oförvirrad",
    "oförvisade": "oförvisad",
    "oförvisades": "oförvisad",
    "oförvisads": "oförvisad",
    "oförvisat": "oförvisad",
    "oförvisats": "oförvisad",
    "oförvissade": "oförvissad",
    "oförvissades": "oförvissad",
    "oförvissads": "oförvissad",
    "oförvissat": "oförvissad",
    "oförvissats": "oförvissad",
    "oförvissnade": "oförvissnad",
    "oförvissnades": "oförvissnad",
    "oförvissnads": "oförvissnad",
    "oförvissnat": "oförvissnad",
    "oförvissnats": "oförvissnad",
    "oförvitliga": "oförvitlig",
    "oförvitligare": "oförvitlig",
    "oförvitligares": "oförvitlig",
    "oförvitligas": "oförvitlig",
    "oförvitligast": "oförvitlig",
    "oförvitligaste": "oförvitlig",
    "oförvitligastes": "oförvitlig",
    "oförvitligasts": "oförvitlig",
    "oförvitlige": "oförvitlig",
    "oförvitliges": "oförvitlig",
    "oförvitligheten": "oförvitlighet",
    "oförvitlighetens": "oförvitlighet",
    "oförvitlighets": "oförvitlighet",
    "oförvitligs": "oförvitlig",
    "oförvitligt": "oförvitlig",
    "oförvitligts": "oförvitlig",
    "oförvittrade": "oförvittrad",
    "oförvittrades": "oförvittrad",
    "oförvittrads": "oförvittrad",
    "oförvittrat": "oförvittrad",
    "oförvittrats": "oförvittrad",
    "oförvrängde": "oförvrängd",
    "oförvrängdes": "oförvrängd",
    "oförvrängds": "oförvrängd",
    "oförvrängt": "oförvrängd",
    "oförvrängts": "oförvrängd",
    "oförvägens": "oförvägen",
    "oförväget": "oförvägen",
    "oförvägets": "oförvägen",
    "oförvägna": "oförvägen",
    "oförvägnare": "oförvägen",
    "oförvägnares": "oförvägen",
    "oförvägnas": "oförvägen",
    "oförvägnast": "oförvägen",
    "oförvägnaste": "oförvägen",
    "oförvägnastes": "oförvägen",
    "oförvägnasts": "oförvägen",
    "oförvägne": "oförvägen",
    "oförvägnes": "oförvägen",
    "oförvägrade": "oförvägrad",
    "oförvägrades": "oförvägrad",
    "oförvägrads": "oförvägrad",
    "oförvägrat": "oförvägrad",
    "oförvägrats": "oförvägrad",
    "oförvällde": "oförvälld",
    "oförvälldes": "oförvälld",
    "oförvällds": "oförvälld",
    "oförvällt": "oförvälld",
    "oförvällts": "oförvälld",
    "oförvände": "oförvänd",
    "oförvändes": "oförvänd",
    "oförvänds": "oförvänd",
    "oförvänt": "oförvänd",
    "oförväntade": "oförväntad",
    "oförväntades": "oförväntad",
    "oförväntads": "oförväntad",
    "oförväntat": "oförväntad",
    "oförväntats": "oförväntad",
    "oförvänts": "oförvänd",
    "oförvärldsligade": "oförvärldsligad",
    "oförvärldsligades": "oförvärldsligad",
    "oförvärldsligads": "oförvärldsligad",
    "oförvärldsligat": "oförvärldsligad",
    "oförvärldsligats": "oförvärldsligad",
    "oförvärrade": "oförvärrad",
    "oförvärrades": "oförvärrad",
    "oförvärrads": "oförvärrad",
    "oförvärrat": "oförvärrad",
    "oförvärrats": "oförvärrad",
    "oförvärvade": "oförvärvad",
    "oförvärvades": "oförvärvad",
    "oförvärvads": "oförvärvad",
    "oförvärvat": "oförvärvad",
    "oförvärvats": "oförvärvad",
    "oförväxlade": "oförväxlad",
    "oförväxlades": "oförväxlad",
    "oförväxlads": "oförväxlad",
    "oförväxlat": "oförväxlad",
    "oförväxlats": "oförväxlad",
    "oförvållade": "oförvållad",
    "oförvållades": "oförvållad",
    "oförvållads": "oförvållad",
    "oförvållat": "oförvållad",
    "oförvållats": "oförvållad",
    "oförvånade": "oförvånad",
    "oförvånades": "oförvånad",
    "oförvånads": "oförvånad",
    "oförvånat": "oförvånad",
    "oförvånats": "oförvånad",
    "oföryngrade": "oföryngrad",
    "oföryngrades": "oföryngrad",
    "oföryngrads": "oföryngrad",
    "oföryngrat": "oföryngrad",
    "oföryngrats": "oföryngrad",
    "oförytterliga": "oförytterlig",
    "oförytterligare": "oförytterlig",
    "oförytterligares": "oförytterlig",
    "oförytterligas": "oförytterlig",
    "oförytterligast": "oförytterlig",
    "oförytterligaste": "oförytterlig",
    "oförytterligastes": "oförytterlig",
    "oförytterligasts": "oförytterlig",
    "oförytterlige": "oförytterlig",
    "oförytterliges": "oförytterlig",
    "oförytterligheten": "oförytterlighet",
    "oförytterlighetens": "oförytterlighet",
    "oförytterlighets": "oförytterlighet",
    "oförytterligs": "oförytterlig",
    "oförytterligt": "oförytterlig",
    "oförytterligts": "oförytterlig",
    "oförzinkade": "oförzinkad",
    "oförzinkades": "oförzinkad",
    "oförzinkads": "oförzinkad",
    "oförzinkat": "oförzinkad",
    "oförzinkats": "oförzinkad",
    "oförädlade": "oförädlad",
    "oförädlades": "oförädlad",
    "oförädlads": "oförädlad",
    "oförädlat": "oförädlad",
    "oförädlats": "oförädlad",
    "oföränderliga": "oföränderlig",
    "oföränderligare": "oföränderlig",
    "oföränderligares": "oföränderlig",
    "oföränderligas": "oföränderlig",
    "oföränderligast": "oföränderlig",
    "oföränderligaste": "oföränderlig",
    "oföränderligastes": "oföränderlig",
    "oföränderligasts": "oföränderlig",
    "oföränderlige": "oföränderlig",
    "oföränderliges": "oföränderlig",
    "oföränderligheten": "oföränderlighet",
    "oföränderlighetens": "oföränderlighet",
    "oföränderligheter": "oföränderlighet",
    "oföränderligheterna": "oföränderlighet",
    "oföränderligheternas": "oföränderlighet",
    "oföränderligheters": "oföränderlighet",
    "oföränderlighets": "oföränderlighet",
    "oföränderligs": "oföränderlig",
    "oföränderligt": "oföränderlig",
    "oföränderligts": "oföränderlig",
    "oförändrade": "oförändrad",
    "oförändrades": "oförändrad",
    "oförändrads": "oförändrad",
    "oförändrat": "oförändrad",
    "oförändrats": "oförändrad",
    "oförärade": "oförärad",
    "oförärades": "oförärad",
    "oförärads": "oförärad",
    "oförärat": "oförärad",
    "oförärats": "oförärad",
    "oförångade": "oförångad",
    "oförångades": "oförångad",
    "oförångads": "oförångad",
    "oförångat": "oförångad",
    "oförångats": "oförångad",
    "oförödmjukade": "oförödmjukad",
    "oförödmjukades": "oförödmjukad",
    "oförödmjukads": "oförödmjukad",
    "oförödmjukat": "oförödmjukad",
    "oförödmjukats": "oförödmjukad",
    "oförökade": "oförökad",
    "oförökades": "oförökad",
    "oförökads": "oförökad",
    "oförökat": "oförökad",
    "oförökats": "oförökad",
    "oförövade": "oförövad",
    "oförövades": "oförövad",
    "oförövads": "oförövad",
    "oförövat": "oförövad",
    "oförövats": "oförövad",
    "ofösta": "oföst",
    "oföstas": "oföst",
    "oföste": "oföst",
    "oföstes": "oföst",
    "ofösts": "oföst",
    "ofött": "ofödd",
    "ofötts": "ofödd",
    "ogagnade": "ogagnad",
    "ogagnades": "ogagnad",
    "ogagnads": "ogagnad",
    "ogagnat": "ogagnad",
    "ogagnats": "ogagnad",
    "ogalliserade": "ogalliserad",
    "ogalliserades": "ogalliserad",
    "ogalliserads": "ogalliserad",
    "ogalliserat": "ogalliserad",
    "ogalliserats": "ogalliserad",
    "ogalliserbara": "ogalliserbar",
    "ogalliserbarare": "ogalliserbar",
    "ogalliserbarares": "ogalliserbar",
    "ogalliserbaras": "ogalliserbar",
    "ogalliserbarast": "ogalliserbar",
    "ogalliserbaraste": "ogalliserbar",
    "ogalliserbarastes": "ogalliserbar",
    "ogalliserbarasts": "ogalliserbar",
    "ogalliserbare": "ogalliserbar",
    "ogalliserbares": "ogalliserbar",
    "ogalliserbarheten": "ogalliserbarhet",
    "ogalliserbarhetens": "ogalliserbarhet",
    "ogalliserbarhets": "ogalliserbarhet",
    "ogalliserbars": "ogalliserbar",
    "ogalliserbart": "ogalliserbar",
    "ogalliserbarts": "ogalliserbar",
    "ogallrade": "ogallrad",
    "ogallrades": "ogallrad",
    "ogallrads": "ogallrad",
    "ogallrat": "ogallrad",
    "ogallrats": "ogallrad",
    "ogaloscherade": "ogaloscherad",
    "ogaloscherades": "ogaloscherad",
    "ogaloscherads": "ogaloscherad",
    "ogaloscherat": "ogaloscherad",
    "ogaloscherats": "ogaloscherad",
    "ogaloscherbara": "ogaloscherbar",
    "ogaloscherbarare": "ogaloscherbar",
    "ogaloscherbarares": "ogaloscherbar",
    "ogaloscherbaras": "ogaloscherbar",
    "ogaloscherbarast": "ogaloscherbar",
    "ogaloscherbaraste": "ogaloscherbar",
    "ogaloscherbarastes": "ogaloscherbar",
    "ogaloscherbarasts": "ogaloscherbar",
    "ogaloscherbare": "ogaloscherbar",
    "ogaloscherbares": "ogaloscherbar",
    "ogaloscherbarheten": "ogaloscherbarhet",
    "ogaloscherbarhetens": "ogaloscherbarhet",
    "ogaloscherbarhets": "ogaloscherbarhet",
    "ogaloscherbars": "ogaloscherbar",
    "ogaloscherbart": "ogaloscherbar",
    "ogaloscherbarts": "ogaloscherbar",
    "ogalvade": "ogalvad",
    "ogalvades": "ogalvad",
    "ogalvads": "ogalvad",
    "ogalvaniserade": "ogalvaniserad",
    "ogalvaniserades": "ogalvaniserad",
    "ogalvaniserads": "ogalvaniserad",
    "ogalvaniserat": "ogalvaniserad",
    "ogalvaniserats": "ogalvaniserad",
    "ogalvaniserbara": "ogalvaniserbar",
    "ogalvaniserbarare": "ogalvaniserbar",
    "ogalvaniserbarares": "ogalvaniserbar",
    "ogalvaniserbaras": "ogalvaniserbar",
    "ogalvaniserbarast": "ogalvaniserbar",
    "ogalvaniserbaraste": "ogalvaniserbar",
    "ogalvaniserbarastes": "ogalvaniserbar",
    "ogalvaniserbarasts": "ogalvaniserbar",
    "ogalvaniserbare": "ogalvaniserbar",
    "ogalvaniserbares": "ogalvaniserbar",
    "ogalvaniserbarheten": "ogalvaniserbarhet",
    "ogalvaniserbarhetens": "ogalvaniserbarhet",
    "ogalvaniserbarhets": "ogalvaniserbarhet",
    "ogalvaniserbars": "ogalvaniserbar",
    "ogalvaniserbart": "ogalvaniserbar",
    "ogalvaniserbarts": "ogalvaniserbar",
    "ogalvat": "ogalvad",
    "ogalvats": "ogalvad",
    "oganade": "oganad",
    "oganades": "oganad",
    "oganads": "oganad",
    "oganat": "oganad",
    "oganats": "oganad",
    "ogarade": "ogarad",
    "ogarades": "ogarad",
    "ogarads": "ogarad",
    "ogaragerade": "ogaragerad",
    "ogaragerades": "ogaragerad",
    "ogaragerads": "ogaragerad",
    "ogaragerat": "ogaragerad",
    "ogaragerats": "ogaragerad",
    "ogaragerbara": "ogaragerbar",
    "ogaragerbarare": "ogaragerbar",
    "ogaragerbarares": "ogaragerbar",
    "ogaragerbaras": "ogaragerbar",
    "ogaragerbarast": "ogaragerbar",
    "ogaragerbaraste": "ogaragerbar",
    "ogaragerbarastes": "ogaragerbar",
    "ogaragerbarasts": "ogaragerbar",
    "ogaragerbare": "ogaragerbar",
    "ogaragerbares": "ogaragerbar",
    "ogaragerbarheten": "ogaragerbarhet",
    "ogaragerbarhetens": "ogaragerbarhet",
    "ogaragerbarhets": "ogaragerbarhet",
    "ogaragerbars": "ogaragerbar",
    "ogaragerbart": "ogaragerbar",
    "ogaragerbarts": "ogaragerbar",
    "ogaranterade": "ogaranterad",
    "ogaranterades": "ogaranterad",
    "ogaranterads": "ogaranterad",
    "ogaranterat": "ogaranterad",
    "ogaranterats": "ogaranterad",
    "ogaranterbara": "ogaranterbar",
    "ogaranterbarare": "ogaranterbar",
    "ogaranterbarares": "ogaranterbar",
    "ogaranterbaras": "ogaranterbar",
    "ogaranterbarast": "ogaranterbar",
    "ogaranterbaraste": "ogaranterbar",
    "ogaranterbarastes": "ogaranterbar",
    "ogaranterbarasts": "ogaranterbar",
    "ogaranterbare": "ogaranterbar",
    "ogaranterbares": "ogaranterbar",
    "ogaranterbarheten": "ogaranterbarhet",
    "ogaranterbarhetens": "ogaranterbarhet",
    "ogaranterbarhets": "ogaranterbarhet",
    "ogaranterbars": "ogaranterbar",
    "ogaranterbart": "ogaranterbar",
    "ogaranterbarts": "ogaranterbar",
    "ogarat": "ogarad",
    "ogarats": "ogarad",
    "ogarderade": "ogarderad",
    "ogarderades": "ogarderad",
    "ogarderads": "ogarderad",
    "ogarderat": "ogarderad",
    "ogarderats": "ogarderad",
    "ogarderbara": "ogarderbar",
    "ogarderbarare": "ogarderbar",
    "ogarderbarares": "ogarderbar",
    "ogarderbaras": "ogarderbar",
    "ogarderbarast": "ogarderbar",
    "ogarderbaraste": "ogarderbar",
    "ogarderbarastes": "ogarderbar",
    "ogarderbarasts": "ogarderbar",
    "ogarderbare": "ogarderbar",
    "ogarderbares": "ogarderbar",
    "ogarderbarheten": "ogarderbarhet",
    "ogarderbarhetens": "ogarderbarhet",
    "ogarderbarhets": "ogarderbarhet",
    "ogarderbars": "ogarderbar",
    "ogarderbart": "ogarderbar",
    "ogarderbarts": "ogarderbar",
    "ogarnerade": "ogarnerad",
    "ogarnerades": "ogarnerad",
    "ogarnerads": "ogarnerad",
    "ogarnerat": "ogarnerad",
    "ogarnerats": "ogarnerad",
    "ogarnerbara": "ogarnerbar",
    "ogarnerbarare": "ogarnerbar",
    "ogarnerbarares": "ogarnerbar",
    "ogarnerbaras": "ogarnerbar",
    "ogarnerbarast": "ogarnerbar",
    "ogarnerbaraste": "ogarnerbar",
    "ogarnerbarastes": "ogarnerbar",
    "ogarnerbarasts": "ogarnerbar",
    "ogarnerbare": "ogarnerbar",
    "ogarnerbares": "ogarnerbar",
    "ogarnerbarheten": "ogarnerbarhet",
    "ogarnerbarhetens": "ogarnerbarhet",
    "ogarnerbarhets": "ogarnerbarhet",
    "ogarnerbars": "ogarnerbar",
    "ogarnerbart": "ogarnerbar",
    "ogarnerbarts": "ogarnerbar",
    "ogarnisonerade": "ogarnisonerad",
    "ogarnisonerades": "ogarnisonerad",
    "ogarnisonerads": "ogarnisonerad",
    "ogarnisonerat": "ogarnisonerad",
    "ogarnisonerats": "ogarnisonerad",
    "ogarnisonerbara": "ogarnisonerbar",
    "ogarnisonerbarare": "ogarnisonerbar",
    "ogarnisonerbarares": "ogarnisonerbar",
    "ogarnisonerbaras": "ogarnisonerbar",
    "ogarnisonerbarast": "ogarnisonerbar",
    "ogarnisonerbaraste": "ogarnisonerbar",
    "ogarnisonerbarastes": "ogarnisonerbar",
    "ogarnisonerbarasts": "ogarnisonerbar",
    "ogarnisonerbare": "ogarnisonerbar",
    "ogarnisonerbares": "ogarnisonerbar",
    "ogarnisonerbarheten": "ogarnisonerbarhet",
    "ogarnisonerbarhetens": "ogarnisonerbarhet",
    "ogarnisonerbarhets": "ogarnisonerbarhet",
    "ogarnisonerbars": "ogarnisonerbar",
    "ogarnisonerbart": "ogarnisonerbar",
    "ogarnisonerbarts": "ogarnisonerbar",
    "ogarrotterade": "ogarrotterad",
    "ogarrotterades": "ogarrotterad",
    "ogarrotterads": "ogarrotterad",
    "ogarrotterat": "ogarrotterad",
    "ogarrotterats": "ogarrotterad",
    "ogarrotterbara": "ogarrotterbar",
    "ogarrotterbarare": "ogarrotterbar",
    "ogarrotterbarares": "ogarrotterbar",
    "ogarrotterbaras": "ogarrotterbar",
    "ogarrotterbarast": "ogarrotterbar",
    "ogarrotterbaraste": "ogarrotterbar",
    "ogarrotterbarastes": "ogarrotterbar",
    "ogarrotterbarasts": "ogarrotterbar",
    "ogarrotterbare": "ogarrotterbar",
    "ogarrotterbares": "ogarrotterbar",
    "ogarrotterbarheten": "ogarrotterbarhet",
    "ogarrotterbarhetens": "ogarrotterbarhet",
    "ogarrotterbarhets": "ogarrotterbarhet",
    "ogarrotterbars": "ogarrotterbar",
    "ogarrotterbart": "ogarrotterbar",
    "ogarrotterbarts": "ogarrotterbar",
    "ogarvade": "ogarvad",
    "ogarvades": "ogarvad",
    "ogarvads": "ogarvad",
    "ogarvat": "ogarvad",
    "ogarvats": "ogarvad",
    "ogasade": "ogasad",
    "ogasades": "ogasad",
    "ogasads": "ogasad",
    "ogasat": "ogasad",
    "ogasats": "ogasad",
    "ogastroskoperade": "ogastroskoperad",
    "ogastroskoperades": "ogastroskoperad",
    "ogastroskoperads": "ogastroskoperad",
    "ogastroskoperat": "ogastroskoperad",
    "ogastroskoperats": "ogastroskoperad",
    "ogastroskoperbara": "ogastroskoperbar",
    "ogastroskoperbarare": "ogastroskoperbar",
    "ogastroskoperbarares": "ogastroskoperbar",
    "ogastroskoperbaras": "ogastroskoperbar",
    "ogastroskoperbarast": "ogastroskoperbar",
    "ogastroskoperbaraste": "ogastroskoperbar",
    "ogastroskoperbarastes": "ogastroskoperbar",
    "ogastroskoperbarasts": "ogastroskoperbar",
    "ogastroskoperbare": "ogastroskoperbar",
    "ogastroskoperbares": "ogastroskoperbar",
    "ogastroskoperbarheten": "ogastroskoperbarhet",
    "ogastroskoperbarhetens": "ogastroskoperbarhet",
    "ogastroskoperbarhets": "ogastroskoperbarhet",
    "ogastroskoperbars": "ogastroskoperbar",
    "ogastroskoperbart": "ogastroskoperbar",
    "ogastroskoperbarts": "ogastroskoperbar",
    "ogauffrerade": "ogauffrerad",
    "ogauffrerades": "ogauffrerad",
    "ogauffrerads": "ogauffrerad",
    "ogauffrerat": "ogauffrerad",
    "ogauffrerats": "ogauffrerad",
    "ogauffrerbara": "ogauffrerbar",
    "ogauffrerbarare": "ogauffrerbar",
    "ogauffrerbarares": "ogauffrerbar",
    "ogauffrerbaras": "ogauffrerbar",
    "ogauffrerbarast": "ogauffrerbar",
    "ogauffrerbaraste": "ogauffrerbar",
    "ogauffrerbarastes": "ogauffrerbar",
    "ogauffrerbarasts": "ogauffrerbar",
    "ogauffrerbare": "ogauffrerbar",
    "ogauffrerbares": "ogauffrerbar",
    "ogauffrerbarheten": "ogauffrerbarhet",
    "ogauffrerbarhetens": "ogauffrerbarhet",
    "ogauffrerbarhets": "ogauffrerbarhet",
    "ogauffrerbars": "ogauffrerbar",
    "ogauffrerbart": "ogauffrerbar",
    "ogauffrerbarts": "ogauffrerbar",
    "ogelatinerade": "ogelatinerad",
    "ogelatinerades": "ogelatinerad",
    "ogelatinerads": "ogelatinerad",
    "ogelatinerat": "ogelatinerad",
    "ogelatinerats": "ogelatinerad",
    "ogelatinerbara": "ogelatinerbar",
    "ogelatinerbarare": "ogelatinerbar",
    "ogelatinerbarares": "ogelatinerbar",
    "ogelatinerbaras": "ogelatinerbar",
    "ogelatinerbarast": "ogelatinerbar",
    "ogelatinerbaraste": "ogelatinerbar",
    "ogelatinerbarastes": "ogelatinerbar",
    "ogelatinerbarasts": "ogelatinerbar",
    "ogelatinerbare": "ogelatinerbar",
    "ogelatinerbares": "ogelatinerbar",
    "ogelatinerbarheten": "ogelatinerbarhet",
    "ogelatinerbarhetens": "ogelatinerbarhet",
    "ogelatinerbarhets": "ogelatinerbarhet",
    "ogelatinerbars": "ogelatinerbar",
    "ogelatinerbart": "ogelatinerbar",
    "ogelatinerbarts": "ogelatinerbar",
    "ogeleade": "ogelead",
    "ogeleades": "ogelead",
    "ogeleads": "ogelead",
    "ogeleat": "ogelead",
    "ogeleats": "ogelead",
    "ogemena": "ogemen",
    "ogemenare": "ogemen",
    "ogemenares": "ogemen",
    "ogemenas": "ogemen",
    "ogemenast": "ogemen",
    "ogemenaste": "ogemen",
    "ogemenastes": "ogemen",
    "ogemenasts": "ogemen",
    "ogemene": "ogemen",
    "ogemenes": "ogemen",
    "ogemens": "ogemen",
    "ogement": "ogemen",
    "ogements": "ogemen",
    "ogeminerade": "ogeminerad",
    "ogeminerades": "ogeminerad",
    "ogeminerads": "ogeminerad",
    "ogeminerat": "ogeminerad",
    "ogeminerats": "ogeminerad",
    "ogeminerbara": "ogeminerbar",
    "ogeminerbarare": "ogeminerbar",
    "ogeminerbarares": "ogeminerbar",
    "ogeminerbaras": "ogeminerbar",
    "ogeminerbarast": "ogeminerbar",
    "ogeminerbaraste": "ogeminerbar",
    "ogeminerbarastes": "ogeminerbar",
    "ogeminerbarasts": "ogeminerbar",
    "ogeminerbare": "ogeminerbar",
    "ogeminerbares": "ogeminerbar",
    "ogeminerbarheten": "ogeminerbarhet",
    "ogeminerbarhetens": "ogeminerbarhet",
    "ogeminerbarhets": "ogeminerbarhet",
    "ogeminerbars": "ogeminerbar",
    "ogeminerbart": "ogeminerbar",
    "ogeminerbarts": "ogeminerbar",
    "ogenerade": "ogenerad",
    "ogenerades": "ogenerad",
    "ogenerads": "ogenerad",
    "ogeneraliserade": "ogeneraliserad",
    "ogeneraliserades": "ogeneraliserad",
    "ogeneraliserads": "ogeneraliserad",
    "ogeneraliserat": "ogeneraliserad",
    "ogeneraliserats": "ogeneraliserad",
    "ogeneraliserbara": "ogeneraliserbar",
    "ogeneraliserbarare": "ogeneraliserbar",
    "ogeneraliserbarares": "ogeneraliserbar",
    "ogeneraliserbaras": "ogeneraliserbar",
    "ogeneraliserbarast": "ogeneraliserbar",
    "ogeneraliserbaraste": "ogeneraliserbar",
    "ogeneraliserbarastes": "ogeneraliserbar",
    "ogeneraliserbarasts": "ogeneraliserbar",
    "ogeneraliserbare": "ogeneraliserbar",
    "ogeneraliserbares": "ogeneraliserbar",
    "ogeneraliserbarheten": "ogeneraliserbarhet",
    "ogeneraliserbarhetens": "ogeneraliserbarhet",
    "ogeneraliserbarhets": "ogeneraliserbarhet",
    "ogeneraliserbars": "ogeneraliserbar",
    "ogeneraliserbart": "ogeneraliserbar",
    "ogeneraliserbarts": "ogeneraliserbar",
    "ogenerat": "ogenerad",
    "ogenerats": "ogenerad",
    "ogenerbara": "ogenerbar",
    "ogenerbarare": "ogenerbar",
    "ogenerbarares": "ogenerbar",
    "ogenerbaras": "ogenerbar",
    "ogenerbarast": "ogenerbar",
    "ogenerbaraste": "ogenerbar",
    "ogenerbarastes": "ogenerbar",
    "ogenerbarasts": "ogenerbar",
    "ogenerbare": "ogenerbar",
    "ogenerbares": "ogenerbar",
    "ogenerbarheten": "ogenerbarhet",
    "ogenerbarhetens": "ogenerbarhet",
    "ogenerbarhets": "ogenerbarhet",
    "ogenerbars": "ogenerbar",
    "ogenerbart": "ogenerbar",
    "ogenerbarts": "ogenerbar",
    "ogenererade": "ogenererad",
    "ogenererades": "ogenererad",
    "ogenererads": "ogenererad",
    "ogenererat": "ogenererad",
    "ogenererats": "ogenererad",
    "ogenererbara": "ogenererbar",
    "ogenererbarare": "ogenererbar",
    "ogenererbarares": "ogenererbar",
    "ogenererbaras": "ogenererbar",
    "ogenererbarast": "ogenererbar",
    "ogenererbaraste": "ogenererbar",
    "ogenererbarastes": "ogenererbar",
    "ogenererbarasts": "ogenererbar",
    "ogenererbare": "ogenererbar",
    "ogenererbares": "ogenererbar",
    "ogenererbarheten": "ogenererbarhet",
    "ogenererbarhetens": "ogenererbarhet",
    "ogenererbarhets": "ogenererbarhet",
    "ogenererbars": "ogenererbar",
    "ogenererbart": "ogenererbar",
    "ogenererbarts": "ogenererbar",
    "ogengäldade": "ogengäldad",
    "ogengäldades": "ogengäldad",
    "ogengäldads": "ogengäldad",
    "ogengäldat": "ogengäldad",
    "ogengäldats": "ogengäldad",
    "ogenomarbetade": "ogenomarbetad",
    "ogenomarbetades": "ogenomarbetad",
    "ogenomarbetads": "ogenomarbetad",
    "ogenomarbetat": "ogenomarbetad",
    "ogenomarbetats": "ogenomarbetad",
    "ogenomborrade": "ogenomborrad",
    "ogenomborrades": "ogenomborrad",
    "ogenomborrads": "ogenomborrad",
    "ogenomborrat": "ogenomborrad",
    "ogenomborrats": "ogenomborrad",
    "ogenomförbara": "ogenomförbar",
    "ogenomförbarare": "ogenomförbar",
    "ogenomförbarares": "ogenomförbar",
    "ogenomförbaras": "ogenomförbar",
    "ogenomförbarast": "ogenomförbar",
    "ogenomförbaraste": "ogenomförbar",
    "ogenomförbarastes": "ogenomförbar",
    "ogenomförbarasts": "ogenomförbar",
    "ogenomförbare": "ogenomförbar",
    "ogenomförbares": "ogenomförbar",
    "ogenomförbarheten": "ogenomförbarhet",
    "ogenomförbarhetens": "ogenomförbarhet",
    "ogenomförbarhets": "ogenomförbarhet",
    "ogenomförbars": "ogenomförbar",
    "ogenomförbart": "ogenomförbar",
    "ogenomförbarts": "ogenomförbar",
    "ogenomförde": "ogenomförd",
    "ogenomfördes": "ogenomförd",
    "ogenomförds": "ogenomförd",
    "ogenomfört": "ogenomförd",
    "ogenomförts": "ogenomförd",
    "ogenomkorsade": "ogenomkorsad",
    "ogenomkorsades": "ogenomkorsad",
    "ogenomkorsads": "ogenomkorsad",
    "ogenomkorsat": "ogenomkorsad",
    "ogenomkorsats": "ogenomkorsad",
    "ogenomlysta": "ogenomlyst",
    "ogenomlystas": "ogenomlyst",
    "ogenomlyste": "ogenomlyst",
    "ogenomlystes": "ogenomlyst",
    "ogenomlysts": "ogenomlyst",
    "ogenomsipprade": "ogenomsipprad",
    "ogenomsipprades": "ogenomsipprad",
    "ogenomsipprads": "ogenomsipprad",
    "ogenomsipprat": "ogenomsipprad",
    "ogenomsipprats": "ogenomsipprad",
    "ogenomskinliga": "ogenomskinlig",
    "ogenomskinligare": "ogenomskinlig",
    "ogenomskinligares": "ogenomskinlig",
    "ogenomskinligas": "ogenomskinlig",
    "ogenomskinligast": "ogenomskinlig",
    "ogenomskinligaste": "ogenomskinlig",
    "ogenomskinligastes": "ogenomskinlig",
    "ogenomskinligasts": "ogenomskinlig",
    "ogenomskinlige": "ogenomskinlig",
    "ogenomskinliges": "ogenomskinlig",
    "ogenomskinligheten": "ogenomskinlighet",
    "ogenomskinlighetens": "ogenomskinlighet",
    "ogenomskinlighets": "ogenomskinlighet",
    "ogenomskinligs": "ogenomskinlig",
    "ogenomskinligt": "ogenomskinlig",
    "ogenomskinligts": "ogenomskinlig",
    "ogenomskådade": "ogenomskådad",
    "ogenomskådades": "ogenomskådad",
    "ogenomskådads": "ogenomskådad",
    "ogenomskådat": "ogenomskådad",
    "ogenomskådats": "ogenomskådad",
    "ogenomsköljde": "ogenomsköljd",
    "ogenomsköljdes": "ogenomsköljd",
    "ogenomsköljds": "ogenomsköljd",
    "ogenomsköljt": "ogenomsköljd",
    "ogenomsköljts": "ogenomsköljd",
    "ogenomsläppliga": "ogenomsläpplig",
    "ogenomsläppligare": "ogenomsläpplig",
    "ogenomsläppligares": "ogenomsläpplig",
    "ogenomsläppligas": "ogenomsläpplig",
    "ogenomsläppligast": "ogenomsläpplig",
    "ogenomsläppligaste": "ogenomsläpplig",
    "ogenomsläppligastes": "ogenomsläpplig",
    "ogenomsläppligasts": "ogenomsläpplig",
    "ogenomsläpplige": "ogenomsläpplig",
    "ogenomsläppliges": "ogenomsläpplig",
    "ogenomsläppligheten": "ogenomsläpplighet",
    "ogenomsläpplighetens": "ogenomsläpplighet",
    "ogenomsläpplighets": "ogenomsläpplighet",
    "ogenomsläppligs": "ogenomsläpplig",
    "ogenomsläppligt": "ogenomsläpplig",
    "ogenomsläppligts": "ogenomsläpplig",
    "ogenomströmmade": "ogenomströmmad",
    "ogenomströmmades": "ogenomströmmad",
    "ogenomströmmads": "ogenomströmmad",
    "ogenomströmmat": "ogenomströmmad",
    "ogenomströmmats": "ogenomströmmad",
    "ogenomsyrade": "ogenomsyrad",
    "ogenomsyrades": "ogenomsyrad",
    "ogenomsyrads": "ogenomsyrad",
    "ogenomsyrat": "ogenomsyrad",
    "ogenomsyrats": "ogenomsyrad",
    "ogenomsökta": "ogenomsökt",
    "ogenomsöktas": "ogenomsökt",
    "ogenomsökte": "ogenomsökt",
    "ogenomsöktes": "ogenomsökt",
    "ogenomsökts": "ogenomsökt",
    "ogenomträngde": "ogenomträngd",
    "ogenomträngdes": "ogenomträngd",
    "ogenomträngds": "ogenomträngd",
    "ogenomträngliga": "ogenomtränglig",
    "ogenomträngligare": "ogenomtränglig",
    "ogenomträngligares": "ogenomtränglig",
    "ogenomträngligas": "ogenomtränglig",
    "ogenomträngligast": "ogenomtränglig",
    "ogenomträngligaste": "ogenomtränglig",
    "ogenomträngligastes": "ogenomtränglig",
    "ogenomträngligasts": "ogenomtränglig",
    "ogenomtränglige": "ogenomtränglig",
    "ogenomträngliges": "ogenomtränglig",
    "ogenomträngligheten": "ogenomtränglighet",
    "ogenomtränglighetens": "ogenomtränglighet",
    "ogenomtränglighets": "ogenomtränglighet",
    "ogenomträngligs": "ogenomtränglig",
    "ogenomträngligt": "ogenomtränglig",
    "ogenomträngligts": "ogenomtränglig",
    "ogenomträngt": "ogenomträngd",
    "ogenomträngts": "ogenomträngd",
    "ogenomtänkta": "ogenomtänkt",
    "ogenomtänktare": "ogenomtänkt",
    "ogenomtänktares": "ogenomtänkt",
    "ogenomtänktas": "ogenomtänkt",
    "ogenomtänktast": "ogenomtänkt",
    "ogenomtänktaste": "ogenomtänkt",
    "ogenomtänktastes": "ogenomtänkt",
    "ogenomtänktasts": "ogenomtänkt",
    "ogenomtänkte": "ogenomtänkt",
    "ogenomtänktes": "ogenomtänkt",
    "ogenomtänktheten": "ogenomtänkthet",
    "ogenomtänkthetens": "ogenomtänkthet",
    "ogenomtänkthets": "ogenomtänkthet",
    "ogenomtänkts": "ogenomtänkt",
    "ogensägliga": "ogensäglig",
    "ogensägligare": "ogensäglig",
    "ogensägligares": "ogensäglig",
    "ogensägligas": "ogensäglig",
    "ogensägligast": "ogensäglig",
    "ogensägligaste": "ogensäglig",
    "ogensägligastes": "ogensäglig",
    "ogensägligasts": "ogensäglig",
    "ogensäglige": "ogensäglig",
    "ogensägliges": "ogensäglig",
    "ogensägligheten": "ogensäglighet",
    "ogensäglighetens": "ogensäglighet",
    "ogensäglighets": "ogensäglighet",
    "ogensägligs": "ogensäglig",
    "ogensägligt": "ogensäglig",
    "ogensägligts": "ogensäglig",
    "ogeometriserade": "ogeometriserad",
    "ogeometriserades": "ogeometriserad",
    "ogeometriserads": "ogeometriserad",
    "ogeometriserat": "ogeometriserad",
    "ogeometriserats": "ogeometriserad",
    "ogeometriserbara": "ogeometriserbar",
    "ogeometriserbarare": "ogeometriserbar",
    "ogeometriserbarares": "ogeometriserbar",
    "ogeometriserbaras": "ogeometriserbar",
    "ogeometriserbarast": "ogeometriserbar",
    "ogeometriserbaraste": "ogeometriserbar",
    "ogeometriserbarastes": "ogeometriserbar",
    "ogeometriserbarasts": "ogeometriserbar",
    "ogeometriserbare": "ogeometriserbar",
    "ogeometriserbares": "ogeometriserbar",
    "ogeometriserbarheten": "ogeometriserbarhet",
    "ogeometriserbarhetens": "ogeometriserbarhet",
    "ogeometriserbarhets": "ogeometriserbarhet",
    "ogeometriserbars": "ogeometriserbar",
    "ogeometriserbart": "ogeometriserbar",
    "ogeometriserbarts": "ogeometriserbar",
    "ogeotaggade": "ogeotaggad",
    "ogeotaggades": "ogeotaggad",
    "ogeotaggads": "ogeotaggad",
    "ogeotaggat": "ogeotaggad",
    "ogeotaggats": "ogeotaggad",
    "ogermaniserade": "ogermaniserad",
    "ogermaniserades": "ogermaniserad",
    "ogermaniserads": "ogermaniserad",
    "ogermaniserat": "ogermaniserad",
    "ogermaniserats": "ogermaniserad",
    "ogermaniserbara": "ogermaniserbar",
    "ogermaniserbarare": "ogermaniserbar",
    "ogermaniserbarares": "ogermaniserbar",
    "ogermaniserbaras": "ogermaniserbar",
    "ogermaniserbarast": "ogermaniserbar",
    "ogermaniserbaraste": "ogermaniserbar",
    "ogermaniserbarastes": "ogermaniserbar",
    "ogermaniserbarasts": "ogermaniserbar",
    "ogermaniserbare": "ogermaniserbar",
    "ogermaniserbares": "ogermaniserbar",
    "ogermaniserbarheten": "ogermaniserbarhet",
    "ogermaniserbarhetens": "ogermaniserbarhet",
    "ogermaniserbarhets": "ogermaniserbarhet",
    "ogermaniserbars": "ogermaniserbar",
    "ogermaniserbart": "ogermaniserbar",
    "ogermaniserbarts": "ogermaniserbar",
    "ogestaltade": "ogestaltad",
    "ogestaltades": "ogestaltad",
    "ogestaltads": "ogestaltad",
    "ogestaltat": "ogestaltad",
    "ogestaltats": "ogestaltad",
    "ogifta": "ogift",
    "ogiftare": "ogift",
    "ogiftares": "ogift",
    "ogiftas": "ogift",
    "ogiftast": "ogift",
    "ogiftaste": "ogift",
    "ogiftastes": "ogift",
    "ogiftasts": "ogift",
    "ogifte": "ogift",
    "ogiftes": "ogift",
    "ogiftiga": "ogiftig",
    "ogiftigare": "ogiftig",
    "ogiftigares": "ogiftig",
    "ogiftigas": "ogiftig",
    "ogiftigast": "ogiftig",
    "ogiftigaste": "ogiftig",
    "ogiftigastes": "ogiftig",
    "ogiftigasts": "ogiftig",
    "ogiftige": "ogiftig",
    "ogiftiges": "ogiftig",
    "ogiftigheten": "ogiftighet",
    "ogiftighetens": "ogiftighet",
    "ogiftighets": "ogiftighet",
    "ogiftigs": "ogiftig",
    "ogiftigt": "ogiftig",
    "ogiftigts": "ogiftig",
    "ogifts": "ogift",
    "ogigade": "ogigad",
    "ogigades": "ogigad",
    "ogigads": "ogigad",
    "ogigat": "ogigad",
    "ogigats": "ogigad",
    "ogiljotinerade": "ogiljotinerad",
    "ogiljotinerades": "ogiljotinerad",
    "ogiljotinerads": "ogiljotinerad",
    "ogiljotinerat": "ogiljotinerad",
    "ogiljotinerats": "ogiljotinerad",
    "ogiljotinerbara": "ogiljotinerbar",
    "ogiljotinerbarare": "ogiljotinerbar",
    "ogiljotinerbarares": "ogiljotinerbar",
    "ogiljotinerbaras": "ogiljotinerbar",
    "ogiljotinerbarast": "ogiljotinerbar",
    "ogiljotinerbaraste": "ogiljotinerbar",
    "ogiljotinerbarastes": "ogiljotinerbar",
    "ogiljotinerbarasts": "ogiljotinerbar",
    "ogiljotinerbare": "ogiljotinerbar",
    "ogiljotinerbares": "ogiljotinerbar",
    "ogiljotinerbarheten": "ogiljotinerbarhet",
    "ogiljotinerbarhetens": "ogiljotinerbarhet",
    "ogiljotinerbarhets": "ogiljotinerbarhet",
    "ogiljotinerbars": "ogiljotinerbar",
    "ogiljotinerbart": "ogiljotinerbar",
    "ogiljotinerbarts": "ogiljotinerbar",
    "ogill": "ogilla",
    "ogilla": "ogill",
    "ogillad": "ogilla",
    "ogillade": "ogillad",
    "ogillades": "ogillad",
    "ogillads": "ogillad",
    "ogillande": "ogilla",
    "ogillanden": "ogillande",
    "ogillandena": "ogillande",
    "ogillandenas": "ogillande",
    "ogillandens": "ogillande",
    "ogillandes": "ogillande",
    "ogillandet": "ogillande",
    "ogillandets": "ogillande",
    "ogillar": "ogilla",
    "ogillare": "ogill",
    "ogillares": "ogill",
    "ogillas": "ogilla",
    "ogillast": "ogill",
    "ogillaste": "ogill",
    "ogillastes": "ogill",
    "ogillasts": "ogill",
    "ogillat": "ogillad",
    "ogillats": "ogillad",
    "ogille": "ogill",
    "ogilles": "ogill",
    "ogillheten": "ogillhet",
    "ogillhetens": "ogillhet",
    "ogillhets": "ogillhet",
    "ogillrade": "ogillrad",
    "ogillrades": "ogillrad",
    "ogillrads": "ogillrad",
    "ogillrat": "ogillrad",
    "ogillrats": "ogillrad",
    "ogills": "ogill",
    "ogillt": "ogill",
    "ogillts": "ogill",
    "ogiltiga": "ogiltig",
    "ogiltigare": "ogiltig",
    "ogiltigares": "ogiltig",
    "ogiltigas": "ogiltig",
    "ogiltigast": "ogiltig",
    "ogiltigaste": "ogiltig",
    "ogiltigastes": "ogiltig",
    "ogiltigasts": "ogiltig",
    "ogiltige": "ogiltig",
    "ogiltiges": "ogiltig",
    "ogiltigförklarade": "ogiltigförklarad",
    "ogiltigförklarades": "ogiltigförklarad",
    "ogiltigförklarads": "ogiltigförklarad",
    "ogiltigförklarat": "ogiltigförklarad",
    "ogiltigförklarats": "ogiltigförklarad",
    "ogiltigheten": "ogiltighet",
    "ogiltighetens": "ogiltighet",
    "ogiltighets": "ogiltighet",
    "ogiltigs": "ogiltig",
    "ogiltigt": "ogiltig",
    "ogiltigts": "ogiltig",
    "ogina": "ogin",
    "oginare": "ogin",
    "oginares": "ogin",
    "oginas": "ogin",
    "oginast": "ogin",
    "oginaste": "ogin",
    "oginastes": "ogin",
    "oginasts": "ogin",
    "ogine": "ogin",
    "ogines": "ogin",
    "ogins": "ogin",
    "ogint": "ogin",
    "ogints": "ogin",
    "ogipsade": "ogipsad",
    "ogipsades": "ogipsad",
    "ogipsads": "ogipsad",
    "ogipsat": "ogipsad",
    "ogipsats": "ogipsad",
    "ogirerade": "ogirerad",
    "ogirerades": "ogirerad",
    "ogirerads": "ogirerad",
    "ogirerat": "ogirerad",
    "ogirerats": "ogirerad",
    "ogirerbara": "ogirerbar",
    "ogirerbarare": "ogirerbar",
    "ogirerbarares": "ogirerbar",
    "ogirerbaras": "ogirerbar",
    "ogirerbarast": "ogirerbar",
    "ogirerbaraste": "ogirerbar",
    "ogirerbarastes": "ogirerbar",
    "ogirerbarasts": "ogirerbar",
    "ogirerbare": "ogirerbar",
    "ogirerbares": "ogirerbar",
    "ogirerbarheten": "ogirerbarhet",
    "ogirerbarhetens": "ogirerbarhet",
    "ogirerbarhets": "ogirerbarhet",
    "ogirerbars": "ogirerbar",
    "ogirerbart": "ogirerbar",
    "ogirerbarts": "ogirerbar",
    "ogissade": "ogissad",
    "ogissades": "ogissad",
    "ogissads": "ogissad",
    "ogissat": "ogissad",
    "ogissats": "ogissad",
    "ogisslade": "ogisslad",
    "ogisslades": "ogisslad",
    "ogisslads": "ogisslad",
    "ogisslat": "ogisslad",
    "ogisslats": "ogisslad",
    "ogistade": "ogistad",
    "ogistades": "ogistad",
    "ogistads": "ogistad",
    "ogistat": "ogistad",
    "ogistats": "ogistad",
    "ogjorda": "ogjord",
    "ogjordade": "ogjordad",
    "ogjordades": "ogjordad",
    "ogjordads": "ogjordad",
    "ogjordare": "ogjord",
    "ogjordares": "ogjord",
    "ogjordas": "ogjord",
    "ogjordast": "ogjord",
    "ogjordaste": "ogjord",
    "ogjordastes": "ogjord",
    "ogjordasts": "ogjord",
    "ogjordat": "ogjordad",
    "ogjordats": "ogjordad",
    "ogjorde": "ogjord",
    "ogjordes": "ogjord",
    "ogjords": "ogjord",
    "ogjort": "ogjord",
    "ogjorts": "ogjord",
    "oglamoriserade": "oglamoriserad",
    "oglamoriserades": "oglamoriserad",
    "oglamoriserads": "oglamoriserad",
    "oglamoriserat": "oglamoriserad",
    "oglamoriserats": "oglamoriserad",
    "oglamoriserbara": "oglamoriserbar",
    "oglamoriserbarare": "oglamoriserbar",
    "oglamoriserbarares": "oglamoriserbar",
    "oglamoriserbaras": "oglamoriserbar",
    "oglamoriserbarast": "oglamoriserbar",
    "oglamoriserbaraste": "oglamoriserbar",
    "oglamoriserbarastes": "oglamoriserbar",
    "oglamoriserbarasts": "oglamoriserbar",
    "oglamoriserbare": "oglamoriserbar",
    "oglamoriserbares": "oglamoriserbar",
    "oglamoriserbarheten": "oglamoriserbarhet",
    "oglamoriserbarhetens": "oglamoriserbarhet",
    "oglamoriserbarhets": "oglamoriserbarhet",
    "oglamoriserbars": "oglamoriserbar",
    "oglamoriserbart": "oglamoriserbar",
    "oglamoriserbarts": "oglamoriserbar",
    "oglamouriserade": "oglamouriserad",
    "oglamouriserades": "oglamouriserad",
    "oglamouriserads": "oglamouriserad",
    "oglamouriserat": "oglamouriserad",
    "oglamouriserats": "oglamouriserad",
    "oglamouriserbara": "oglamouriserbar",
    "oglamouriserbarare": "oglamouriserbar",
    "oglamouriserbarares": "oglamouriserbar",
    "oglamouriserbaras": "oglamouriserbar",
    "oglamouriserbarast": "oglamouriserbar",
    "oglamouriserbaraste": "oglamouriserbar",
    "oglamouriserbarastes": "oglamouriserbar",
    "oglamouriserbarasts": "oglamouriserbar",
    "oglamouriserbare": "oglamouriserbar",
    "oglamouriserbares": "oglamouriserbar",
    "oglamouriserbarheten": "oglamouriserbarhet",
    "oglamouriserbarhetens": "oglamouriserbarhet",
    "oglamouriserbarhets": "oglamouriserbarhet",
    "oglamouriserbars": "oglamouriserbar",
    "oglamouriserbart": "oglamouriserbar",
    "oglamouriserbarts": "oglamouriserbar",
    "oglansade": "oglansad",
    "oglansades": "oglansad",
    "oglansads": "oglansad",
    "oglansat": "oglansad",
    "oglansats": "oglansad",
    "oglanskade": "oglanskad",
    "oglanskades": "oglanskad",
    "oglanskads": "oglanskad",
    "oglanskat": "oglanskad",
    "oglanskats": "oglanskad",
    "oglasade": "oglasad",
    "oglasades": "oglasad",
    "oglasads": "oglasad",
    "oglasat": "oglasad",
    "oglasats": "oglasad",
    "oglaserade": "oglaserad",
    "oglaserades": "oglaserad",
    "oglaserads": "oglaserad",
    "oglaserat": "oglaserad",
    "oglaserats": "oglaserad",
    "oglaserbara": "oglaserbar",
    "oglaserbarare": "oglaserbar",
    "oglaserbarares": "oglaserbar",
    "oglaserbaras": "oglaserbar",
    "oglaserbarast": "oglaserbar",
    "oglaserbaraste": "oglaserbar",
    "oglaserbarastes": "oglaserbar",
    "oglaserbarasts": "oglaserbar",
    "oglaserbare": "oglaserbar",
    "oglaserbares": "oglaserbar",
    "oglaserbarheten": "oglaserbarhet",
    "oglaserbarhetens": "oglaserbarhet",
    "oglaserbarhets": "oglaserbarhet",
    "oglaserbars": "oglaserbar",
    "oglaserbart": "oglaserbar",
    "oglaserbarts": "oglaserbar",
    "oglattade": "oglattad",
    "oglattades": "oglattad",
    "oglattads": "oglattad",
    "oglattat": "oglattad",
    "oglattats": "oglattad",
    "oglesade": "oglesad",
    "oglesades": "oglesad",
    "oglesads": "oglesad",
    "oglesat": "oglesad",
    "oglesats": "oglesad",
    "oglesnade": "oglesnad",
    "oglesnades": "oglesnad",
    "oglesnads": "oglesnad",
    "oglesnat": "oglesnad",
    "oglesnats": "oglesnad",
    "oglorifierade": "oglorifierad",
    "oglorifierades": "oglorifierad",
    "oglorifierads": "oglorifierad",
    "oglorifierat": "oglorifierad",
    "oglorifierats": "oglorifierad",
    "oglorifierbara": "oglorifierbar",
    "oglorifierbarare": "oglorifierbar",
    "oglorifierbarares": "oglorifierbar",
    "oglorifierbaras": "oglorifierbar",
    "oglorifierbarast": "oglorifierbar",
    "oglorifierbaraste": "oglorifierbar",
    "oglorifierbarastes": "oglorifierbar",
    "oglorifierbarasts": "oglorifierbar",
    "oglorifierbare": "oglorifierbar",
    "oglorifierbares": "oglorifierbar",
    "oglorifierbarheten": "oglorifierbarhet",
    "oglorifierbarhetens": "oglorifierbarhet",
    "oglorifierbarhets": "oglorifierbarhet",
    "oglorifierbars": "oglorifierbar",
    "oglorifierbart": "oglorifierbar",
    "oglorifierbarts": "oglorifierbar",
    "ogläntade": "ogläntad",
    "ogläntades": "ogläntad",
    "ogläntads": "ogläntad",
    "ogläntat": "ogläntad",
    "ogläntats": "ogläntad",
    "oglättade": "oglättad",
    "oglättades": "oglättad",
    "oglättads": "oglättad",
    "oglättat": "oglättad",
    "oglättats": "oglättad",
    "oglödgade": "oglödgad",
    "oglödgades": "oglödgad",
    "oglödgads": "oglödgad",
    "oglödgat": "oglödgad",
    "oglödgats": "oglödgad",
    "oglömde": "oglömd",
    "oglömdes": "oglömd",
    "oglömds": "oglömd",
    "oglömt": "oglömd",
    "oglömts": "oglömd",
    "ognagde": "ognagd",
    "ognagdes": "ognagd",
    "ognagds": "ognagd",
    "ognagt": "ognagd",
    "ognagts": "ognagd",
    "ognavde": "ognavd",
    "ognavdes": "ognavd",
    "ognavds": "ognavd",
    "ognavt": "ognavd",
    "ognavts": "ognavd",
    "ognistade": "ognistad",
    "ognistades": "ognistad",
    "ognistads": "ognistad",
    "ognistat": "ognistad",
    "ognistats": "ognistad",
    "ognolade": "ognolad",
    "ognolades": "ognolad",
    "ognolads": "ognolad",
    "ognolat": "ognolad",
    "ognolats": "ognolad",
    "ognuggade": "ognuggad",
    "ognuggades": "ognuggad",
    "ognuggads": "ognuggad",
    "ognuggat": "ognuggad",
    "ognuggats": "ognuggad",
    "ogodkände": "ogodkänd",
    "ogodkändes": "ogodkänd",
    "ogodkänds": "ogodkänd",
    "ogodkänt": "ogodkänd",
    "ogodkänts": "ogodkänd",
    "ogoffrerade": "ogoffrerad",
    "ogoffrerades": "ogoffrerad",
    "ogoffrerads": "ogoffrerad",
    "ogoffrerat": "ogoffrerad",
    "ogoffrerats": "ogoffrerad",
    "ogoffrerbara": "ogoffrerbar",
    "ogoffrerbarare": "ogoffrerbar",
    "ogoffrerbarares": "ogoffrerbar",
    "ogoffrerbaras": "ogoffrerbar",
    "ogoffrerbarast": "ogoffrerbar",
    "ogoffrerbaraste": "ogoffrerbar",
    "ogoffrerbarastes": "ogoffrerbar",
    "ogoffrerbarasts": "ogoffrerbar",
    "ogoffrerbare": "ogoffrerbar",
    "ogoffrerbares": "ogoffrerbar",
    "ogoffrerbarheten": "ogoffrerbarhet",
    "ogoffrerbarhetens": "ogoffrerbarhet",
    "ogoffrerbarhets": "ogoffrerbarhet",
    "ogoffrerbars": "ogoffrerbar",
    "ogoffrerbart": "ogoffrerbar",
    "ogoffrerbarts": "ogoffrerbar",
    "ogolvade": "ogolvad",
    "ogolvades": "ogolvad",
    "ogolvads": "ogolvad",
    "ogolvat": "ogolvad",
    "ogolvats": "ogolvad",
    "ogooglade": "ogooglad",
    "ogooglades": "ogooglad",
    "ogooglads": "ogooglad",
    "ogooglat": "ogooglad",
    "ogooglats": "ogooglad",
    "ogouterade": "ogouterad",
    "ogouterades": "ogouterad",
    "ogouterads": "ogouterad",
    "ogouterat": "ogouterad",
    "ogouterats": "ogouterad",
    "ogouterbara": "ogouterbar",
    "ogouterbarare": "ogouterbar",
    "ogouterbarares": "ogouterbar",
    "ogouterbaras": "ogouterbar",
    "ogouterbarast": "ogouterbar",
    "ogouterbaraste": "ogouterbar",
    "ogouterbarastes": "ogouterbar",
    "ogouterbarasts": "ogouterbar",
    "ogouterbare": "ogouterbar",
    "ogouterbares": "ogouterbar",
    "ogouterbarheten": "ogouterbarhet",
    "ogouterbarhetens": "ogouterbarhet",
    "ogouterbarhets": "ogouterbarhet",
    "ogouterbars": "ogouterbar",
    "ogouterbart": "ogouterbar",
    "ogouterbarts": "ogouterbar",
    "ograbbade": "ograbbad",
    "ograbbades": "ograbbad",
    "ograbbads": "ograbbad",
    "ograbbat": "ograbbad",
    "ograbbats": "ograbbad",
    "ogradade": "ogradad",
    "ogradades": "ogradad",
    "ogradads": "ogradad",
    "ogradat": "ogradad",
    "ogradats": "ogradad",
    "ograderade": "ograderad",
    "ograderades": "ograderad",
    "ograderads": "ograderad",
    "ograderat": "ograderad",
    "ograderats": "ograderad",
    "ograderbara": "ograderbar",
    "ograderbarare": "ograderbar",
    "ograderbarares": "ograderbar",
    "ograderbaras": "ograderbar",
    "ograderbarast": "ograderbar",
    "ograderbaraste": "ograderbar",
    "ograderbarastes": "ograderbar",
    "ograderbarasts": "ograderbar",
    "ograderbare": "ograderbar",
    "ograderbares": "ograderbar",
    "ograderbarheten": "ograderbarhet",
    "ograderbarhetens": "ograderbarhet",
    "ograderbarhets": "ograderbarhet",
    "ograderbars": "ograderbar",
    "ograderbart": "ograderbar",
    "ograderbarts": "ograderbar",
    "ograduerade": "ograduerad",
    "ograduerades": "ograduerad",
    "ograduerads": "ograduerad",
    "ograduerat": "ograduerad",
    "ograduerats": "ograduerad",
    "ograduerbara": "ograduerbar",
    "ograduerbarare": "ograduerbar",
    "ograduerbarares": "ograduerbar",
    "ograduerbaras": "ograduerbar",
    "ograduerbarast": "ograduerbar",
    "ograduerbaraste": "ograduerbar",
    "ograduerbarastes": "ograduerbar",
    "ograduerbarasts": "ograduerbar",
    "ograduerbare": "ograduerbar",
    "ograduerbares": "ograduerbar",
    "ograduerbarheten": "ograduerbarhet",
    "ograduerbarhetens": "ograduerbarhet",
    "ograduerbarhets": "ograduerbarhet",
    "ograduerbars": "ograduerbar",
    "ograduerbart": "ograduerbar",
    "ograduerbarts": "ograduerbar",
    "ografiterade": "ografiterad",
    "ografiterades": "ografiterad",
    "ografiterads": "ografiterad",
    "ografiterat": "ografiterad",
    "ografiterats": "ografiterad",
    "ografiterbara": "ografiterbar",
    "ografiterbarare": "ografiterbar",
    "ografiterbarares": "ografiterbar",
    "ografiterbaras": "ografiterbar",
    "ografiterbarast": "ografiterbar",
    "ografiterbaraste": "ografiterbar",
    "ografiterbarastes": "ografiterbar",
    "ografiterbarasts": "ografiterbar",
    "ografiterbare": "ografiterbar",
    "ografiterbares": "ografiterbar",
    "ografiterbarheten": "ografiterbarhet",
    "ografiterbarhetens": "ografiterbarhet",
    "ografiterbarhets": "ografiterbarhet",
    "ografiterbars": "ografiterbar",
    "ografiterbart": "ografiterbar",
    "ografiterbarts": "ografiterbar",
    "ogrammatikaliska": "ogrammatikalisk",
    "ogrammatikaliskare": "ogrammatikalisk",
    "ogrammatikaliskares": "ogrammatikalisk",
    "ogrammatikaliskas": "ogrammatikalisk",
    "ogrammatikaliskast": "ogrammatikalisk",
    "ogrammatikaliskaste": "ogrammatikalisk",
    "ogrammatikaliskastes": "ogrammatikalisk",
    "ogrammatikaliskasts": "ogrammatikalisk",
    "ogrammatikaliske": "ogrammatikalisk",
    "ogrammatikaliskes": "ogrammatikalisk",
    "ogrammatikalisks": "ogrammatikalisk",
    "ogrammatikaliskt": "ogrammatikalisk",
    "ogrammatikaliskts": "ogrammatikalisk",
    "ogrammatiska": "ogrammatisk",
    "ogrammatiskare": "ogrammatisk",
    "ogrammatiskares": "ogrammatisk",
    "ogrammatiskas": "ogrammatisk",
    "ogrammatiskast": "ogrammatisk",
    "ogrammatiskaste": "ogrammatisk",
    "ogrammatiskastes": "ogrammatisk",
    "ogrammatiskasts": "ogrammatisk",
    "ogrammatiske": "ogrammatisk",
    "ogrammatiskes": "ogrammatisk",
    "ogrammatisks": "ogrammatisk",
    "ogrammatiskt": "ogrammatisk",
    "ogrammatiskts": "ogrammatisk",
    "ogranskade": "ogranskad",
    "ogranskades": "ogranskad",
    "ogranskads": "ogranskad",
    "ogranskat": "ogranskad",
    "ogranskats": "ogranskad",
    "ogranulerade": "ogranulerad",
    "ogranulerades": "ogranulerad",
    "ogranulerads": "ogranulerad",
    "ogranulerat": "ogranulerad",
    "ogranulerats": "ogranulerad",
    "ogranulerbara": "ogranulerbar",
    "ogranulerbarare": "ogranulerbar",
    "ogranulerbarares": "ogranulerbar",
    "ogranulerbaras": "ogranulerbar",
    "ogranulerbarast": "ogranulerbar",
    "ogranulerbaraste": "ogranulerbar",
    "ogranulerbarastes": "ogranulerbar",
    "ogranulerbarasts": "ogranulerbar",
    "ogranulerbare": "ogranulerbar",
    "ogranulerbares": "ogranulerbar",
    "ogranulerbarheten": "ogranulerbarhet",
    "ogranulerbarhetens": "ogranulerbarhet",
    "ogranulerbarhets": "ogranulerbarhet",
    "ogranulerbars": "ogranulerbar",
    "ogranulerbart": "ogranulerbar",
    "ogranulerbarts": "ogranulerbar",
    "ogratinerade": "ogratinerad",
    "ogratinerades": "ogratinerad",
    "ogratinerads": "ogratinerad",
    "ogratinerat": "ogratinerad",
    "ogratinerats": "ogratinerad",
    "ogratinerbara": "ogratinerbar",
    "ogratinerbarare": "ogratinerbar",
    "ogratinerbarares": "ogratinerbar",
    "ogratinerbaras": "ogratinerbar",
    "ogratinerbarast": "ogratinerbar",
    "ogratinerbaraste": "ogratinerbar",
    "ogratinerbarastes": "ogratinerbar",
    "ogratinerbarasts": "ogratinerbar",
    "ogratinerbare": "ogratinerbar",
    "ogratinerbares": "ogratinerbar",
    "ogratinerbarheten": "ogratinerbarhet",
    "ogratinerbarhetens": "ogratinerbarhet",
    "ogratinerbarhets": "ogratinerbarhet",
    "ogratinerbars": "ogratinerbar",
    "ogratinerbart": "ogratinerbar",
    "ogratinerbarts": "ogratinerbar",
    "ograttade": "ograttad",
    "ograttades": "ograttad",
    "ograttads": "ograttad",
    "ograttat": "ograttad",
    "ograttats": "ograttad",
    "ogratulerade": "ogratulerad",
    "ogratulerades": "ogratulerad",
    "ogratulerads": "ogratulerad",
    "ogratulerat": "ogratulerad",
    "ogratulerats": "ogratulerad",
    "ogratulerbara": "ogratulerbar",
    "ogratulerbarare": "ogratulerbar",
    "ogratulerbarares": "ogratulerbar",
    "ogratulerbaras": "ogratulerbar",
    "ogratulerbarast": "ogratulerbar",
    "ogratulerbaraste": "ogratulerbar",
    "ogratulerbarastes": "ogratulerbar",
    "ogratulerbarasts": "ogratulerbar",
    "ogratulerbare": "ogratulerbar",
    "ogratulerbares": "ogratulerbar",
    "ogratulerbarheten": "ogratulerbarhet",
    "ogratulerbarhetens": "ogratulerbarhet",
    "ogratulerbarhets": "ogratulerbarhet",
    "ogratulerbars": "ogratulerbar",
    "ogratulerbart": "ogratulerbar",
    "ogratulerbarts": "ogratulerbar",
    "ogravade": "ogravad",
    "ogravades": "ogravad",
    "ogravads": "ogravad",
    "ogravat": "ogravad",
    "ogravats": "ogravad",
    "ograverade": "ograverad",
    "ograverades": "ograverad",
    "ograverads": "ograverad",
    "ograverat": "ograverad",
    "ograverats": "ograverad",
    "ograverbara": "ograverbar",
    "ograverbarare": "ograverbar",
    "ograverbarares": "ograverbar",
    "ograverbaras": "ograverbar",
    "ograverbarast": "ograverbar",
    "ograverbaraste": "ograverbar",
    "ograverbarastes": "ograverbar",
    "ograverbarasts": "ograverbar",
    "ograverbare": "ograverbar",
    "ograverbares": "ograverbar",
    "ograverbarheten": "ograverbarhet",
    "ograverbarhetens": "ograverbarhet",
    "ograverbarhets": "ograverbarhet",
    "ograverbars": "ograverbar",
    "ograverbart": "ograverbar",
    "ograverbarts": "ograverbar",
    "ogrejade": "ogrejad",
    "ogrejades": "ogrejad",
    "ogrejads": "ogrejad",
    "ogrejat": "ogrejad",
    "ogrejats": "ogrejad",
    "ogrenade": "ogrenad",
    "ogrenades": "ogrenad",
    "ogrenads": "ogrenad",
    "ogrenat": "ogrenad",
    "ogrenats": "ogrenad",
    "ogrenslade": "ogrenslad",
    "ogrenslades": "ogrenslad",
    "ogrenslads": "ogrenslad",
    "ogrenslat": "ogrenslad",
    "ogrenslats": "ogrenslad",
    "ogreppade": "ogreppad",
    "ogreppades": "ogreppad",
    "ogreppads": "ogreppad",
    "ogreppat": "ogreppad",
    "ogreppats": "ogreppad",
    "ogriljerade": "ogriljerad",
    "ogriljerades": "ogriljerad",
    "ogriljerads": "ogriljerad",
    "ogriljerat": "ogriljerad",
    "ogriljerats": "ogriljerad",
    "ogriljerbara": "ogriljerbar",
    "ogriljerbarare": "ogriljerbar",
    "ogriljerbarares": "ogriljerbar",
    "ogriljerbaras": "ogriljerbar",
    "ogriljerbarast": "ogriljerbar",
    "ogriljerbaraste": "ogriljerbar",
    "ogriljerbarastes": "ogriljerbar",
    "ogriljerbarasts": "ogriljerbar",
    "ogriljerbare": "ogriljerbar",
    "ogriljerbares": "ogriljerbar",
    "ogriljerbarheten": "ogriljerbarhet",
    "ogriljerbarhetens": "ogriljerbarhet",
    "ogriljerbarhets": "ogriljerbarhet",
    "ogriljerbars": "ogriljerbar",
    "ogriljerbart": "ogriljerbar",
    "ogriljerbarts": "ogriljerbar",
    "ogrillade": "ogrillad",
    "ogrillades": "ogrillad",
    "ogrillads": "ogrillad",
    "ogrillat": "ogrillad",
    "ogrillats": "ogrillad",
    "ogrimerade": "ogrimerad",
    "ogrimerades": "ogrimerad",
    "ogrimerads": "ogrimerad",
    "ogrimerat": "ogrimerad",
    "ogrimerats": "ogrimerad",
    "ogrimerbara": "ogrimerbar",
    "ogrimerbarare": "ogrimerbar",
    "ogrimerbarares": "ogrimerbar",
    "ogrimerbaras": "ogrimerbar",
    "ogrimerbarast": "ogrimerbar",
    "ogrimerbaraste": "ogrimerbar",
    "ogrimerbarastes": "ogrimerbar",
    "ogrimerbarasts": "ogrimerbar",
    "ogrimerbare": "ogrimerbar",
    "ogrimerbares": "ogrimerbar",
    "ogrimerbarheten": "ogrimerbarhet",
    "ogrimerbarhetens": "ogrimerbarhet",
    "ogrimerbarhets": "ogrimerbarhet",
    "ogrimerbars": "ogrimerbar",
    "ogrimerbart": "ogrimerbar",
    "ogrimerbarts": "ogrimerbar",
    "ogripbara": "ogripbar",
    "ogripbarare": "ogripbar",
    "ogripbarares": "ogripbar",
    "ogripbaras": "ogripbar",
    "ogripbarast": "ogripbar",
    "ogripbaraste": "ogripbar",
    "ogripbarastes": "ogripbar",
    "ogripbarasts": "ogripbar",
    "ogripbare": "ogripbar",
    "ogripbares": "ogripbar",
    "ogripbarheten": "ogripbarhet",
    "ogripbarhetens": "ogripbarhet",
    "ogripbarhets": "ogripbarhet",
    "ogripbars": "ogripbar",
    "ogripbart": "ogripbar",
    "ogripbarts": "ogripbar",
    "ogroddade": "ogroddad",
    "ogroddades": "ogroddad",
    "ogroddads": "ogroddad",
    "ogroddat": "ogroddad",
    "ogroddats": "ogroddad",
    "ogrumlade": "ogrumlad",
    "ogrumlades": "ogrumlad",
    "ogrumlads": "ogrumlad",
    "ogrumlat": "ogrumlad",
    "ogrumlats": "ogrumlad",
    "ogrumsade": "ogrumsad",
    "ogrumsades": "ogrumsad",
    "ogrumsads": "ogrumsad",
    "ogrumsat": "ogrumsad",
    "ogrumsats": "ogrumsad",
    "ogrundade": "ogrundad",
    "ogrundades": "ogrundad",
    "ogrundads": "ogrundad",
    "ogrundat": "ogrundad",
    "ogrundats": "ogrundad",
    "ogrunderade": "ogrunderad",
    "ogrunderades": "ogrunderad",
    "ogrunderads": "ogrunderad",
    "ogrunderat": "ogrunderad",
    "ogrunderats": "ogrunderad",
    "ogrunderbara": "ogrunderbar",
    "ogrunderbarare": "ogrunderbar",
    "ogrunderbarares": "ogrunderbar",
    "ogrunderbaras": "ogrunderbar",
    "ogrunderbarast": "ogrunderbar",
    "ogrunderbaraste": "ogrunderbar",
    "ogrunderbarastes": "ogrunderbar",
    "ogrunderbarasts": "ogrunderbar",
    "ogrunderbare": "ogrunderbar",
    "ogrunderbares": "ogrunderbar",
    "ogrunderbarheten": "ogrunderbarhet",
    "ogrunderbarhetens": "ogrunderbarhet",
    "ogrunderbarhets": "ogrunderbarhet",
    "ogrunderbars": "ogrunderbar",
    "ogrunderbart": "ogrunderbar",
    "ogrunderbarts": "ogrunderbar",
    "ogrupperade": "ogrupperad",
    "ogrupperades": "ogrupperad",
    "ogrupperads": "ogrupperad",
    "ogrupperat": "ogrupperad",
    "ogrupperats": "ogrupperad",
    "ogrupperbara": "ogrupperbar",
    "ogrupperbarare": "ogrupperbar",
    "ogrupperbarares": "ogrupperbar",
    "ogrupperbaras": "ogrupperbar",
    "ogrupperbarast": "ogrupperbar",
    "ogrupperbaraste": "ogrupperbar",
    "ogrupperbarastes": "ogrupperbar",
    "ogrupperbarasts": "ogrupperbar",
    "ogrupperbare": "ogrupperbar",
    "ogrupperbares": "ogrupperbar",
    "ogrupperbarheten": "ogrupperbarhet",
    "ogrupperbarhetens": "ogrupperbarhet",
    "ogrupperbarhets": "ogrupperbarhet",
    "ogrupperbars": "ogrupperbar",
    "ogrupperbart": "ogrupperbar",
    "ogrupperbarts": "ogrupperbar",
    "ogrusade": "ogrusad",
    "ogrusades": "ogrusad",
    "ogrusads": "ogrusad",
    "ogrusat": "ogrusad",
    "ogrusats": "ogrusad",
    "ogräddade": "ogräddad",
    "ogräddades": "ogräddad",
    "ogräddads": "ogräddad",
    "ogräddat": "ogräddad",
    "ogräddats": "ogräddad",
    "ogräftade": "ogräftad",
    "ogräftades": "ogräftad",
    "ogräftads": "ogräftad",
    "ogräftat": "ogräftad",
    "ogräftats": "ogräftad",
    "ogränslade": "ogränslad",
    "ogränslades": "ogränslad",
    "ogränslads": "ogränslad",
    "ogränslat": "ogränslad",
    "ogränslats": "ogränslad",
    "ogräsbekämpade": "ogräsbekämpad",
    "ogräsbekämpades": "ogräsbekämpad",
    "ogräsbekämpads": "ogräsbekämpad",
    "ogräsbekämpat": "ogräsbekämpad",
    "ogräsbekämpats": "ogräsbekämpad",
    "ogräsbekämpningar": "ogräsbekämpning",
    "ogräsbekämpningarna": "ogräsbekämpning",
    "ogräsbekämpningarnas": "ogräsbekämpning",
    "ogräsbekämpningars": "ogräsbekämpning",
    "ogräsbekämpningen": "ogräsbekämpning",
    "ogräsbekämpningens": "ogräsbekämpning",
    "ogräsbekämpnings": "ogräsbekämpning",
    "ogräset": "ogräs",
    "ogräsets": "ogräs",
    "ogräsfiskar": "ogräsfisk",
    "ogräsfiskarna": "ogräsfisk",
    "ogräsfiskarnas": "ogräsfisk",
    "ogräsfiskars": "ogräsfisk",
    "ogräsfisken": "ogräsfisk",
    "ogräsfiskens": "ogräsfisk",
    "ogräsfisks": "ogräsfisk",
    "ogrävde": "ogrävd",
    "ogrävdes": "ogrävd",
    "ogrävds": "ogrävd",
    "ogrävt": "ogrävd",
    "ogrävts": "ogrävd",
    "ogrånade": "ogrånad",
    "ogrånades": "ogrånad",
    "ogrånads": "ogrånad",
    "ogrånat": "ogrånad",
    "ogrånats": "ogrånad",
    "ogröpade": "ogröpad",
    "ogröpades": "ogröpad",
    "ogröpads": "ogröpad",
    "ogröpat": "ogröpad",
    "ogröpats": "ogröpad",
    "ogudaktiga": "ogudaktig",
    "ogudaktigare": "ogudaktig",
    "ogudaktigares": "ogudaktig",
    "ogudaktigas": "ogudaktig",
    "ogudaktigast": "ogudaktig",
    "ogudaktigaste": "ogudaktig",
    "ogudaktigastes": "ogudaktig",
    "ogudaktigasts": "ogudaktig",
    "ogudaktige": "ogudaktig",
    "ogudaktiges": "ogudaktig",
    "ogudaktigheten": "ogudaktighet",
    "ogudaktighetens": "ogudaktighet",
    "ogudaktighets": "ogudaktighet",
    "ogudaktigs": "ogudaktig",
    "ogudaktigt": "ogudaktig",
    "ogudaktigts": "ogudaktig",
    "ogudliga": "ogudlig",
    "ogudligare": "ogudlig",
    "ogudligares": "ogudlig",
    "ogudligas": "ogudlig",
    "ogudligast": "ogudlig",
    "ogudligaste": "ogudlig",
    "ogudligastes": "ogudlig",
    "ogudligasts": "ogudlig",
    "ogudlige": "ogudlig",
    "ogudliges": "ogudlig",
    "ogudligheten": "ogudlighet",
    "ogudlighetens": "ogudlighet",
    "ogudlighets": "ogudlighet",
    "ogudligs": "ogudlig",
    "ogudligt": "ogudlig",
    "ogudligts": "ogudlig",
    "oguidade": "oguidad",
    "oguidades": "oguidad",
    "oguidads": "oguidad",
    "oguidat": "oguidad",
    "oguidats": "oguidad",
    "oguldens": "ogulden",
    "oguldet": "ogulden",
    "oguldets": "ogulden",
    "oguldna": "ogulden",
    "oguldnas": "ogulden",
    "oguldne": "ogulden",
    "oguldnes": "ogulden",
    "ogulnade": "ogulnad",
    "ogulnades": "ogulnad",
    "ogulnads": "ogulnad",
    "ogulnat": "ogulnad",
    "ogulnats": "ogulnad",
    "ogummerade": "ogummerad",
    "ogummerades": "ogummerad",
    "ogummerads": "ogummerad",
    "ogummerat": "ogummerad",
    "ogummerats": "ogummerad",
    "ogummerbara": "ogummerbar",
    "ogummerbarare": "ogummerbar",
    "ogummerbarares": "ogummerbar",
    "ogummerbaras": "ogummerbar",
    "ogummerbarast": "ogummerbar",
    "ogummerbaraste": "ogummerbar",
    "ogummerbarastes": "ogummerbar",
    "ogummerbarasts": "ogummerbar",
    "ogummerbare": "ogummerbar",
    "ogummerbares": "ogummerbar",
    "ogummerbarheten": "ogummerbarhet",
    "ogummerbarhetens": "ogummerbarhet",
    "ogummerbarhets": "ogummerbarhet",
    "ogummerbars": "ogummerbar",
    "ogummerbart": "ogummerbar",
    "ogummerbarts": "ogummerbar",
    "ogungade": "ogungad",
    "ogungades": "ogungad",
    "ogungads": "ogungad",
    "ogungat": "ogungad",
    "ogungats": "ogungad",
    "ogunstiga": "ogunstig",
    "ogunstigare": "ogunstig",
    "ogunstigares": "ogunstig",
    "ogunstigas": "ogunstig",
    "ogunstigast": "ogunstig",
    "ogunstigaste": "ogunstig",
    "ogunstigastes": "ogunstig",
    "ogunstigasts": "ogunstig",
    "ogunstige": "ogunstig",
    "ogunstiges": "ogunstig",
    "ogunstigheten": "ogunstighet",
    "ogunstighetens": "ogunstighet",
    "ogunstighets": "ogunstighet",
    "ogunstigs": "ogunstig",
    "ogunstigt": "ogunstig",
    "ogunstigts": "ogunstig",
    "ogurglade": "ogurglad",
    "ogurglades": "ogurglad",
    "ogurglads": "ogurglad",
    "ogurglat": "ogurglad",
    "ogurglats": "ogurglad",
    "oguskade": "oguskad",
    "oguskades": "oguskad",
    "oguskads": "oguskad",
    "oguskat": "oguskad",
    "oguskats": "oguskad",
    "oguterade": "oguterad",
    "oguterades": "oguterad",
    "oguterads": "oguterad",
    "oguterat": "oguterad",
    "oguterats": "oguterad",
    "oguterbara": "oguterbar",
    "oguterbarare": "oguterbar",
    "oguterbarares": "oguterbar",
    "oguterbaras": "oguterbar",
    "oguterbarast": "oguterbar",
    "oguterbaraste": "oguterbar",
    "oguterbarastes": "oguterbar",
    "oguterbarasts": "oguterbar",
    "oguterbare": "oguterbar",
    "oguterbares": "oguterbar",
    "oguterbarheten": "oguterbarhet",
    "oguterbarhetens": "oguterbarhet",
    "oguterbarhets": "oguterbarhet",
    "oguterbars": "oguterbar",
    "oguterbart": "oguterbar",
    "oguterbarts": "oguterbar",
    "ogymnastiserade": "ogymnastiserad",
    "ogymnastiserades": "ogymnastiserad",
    "ogymnastiserads": "ogymnastiserad",
    "ogymnastiserat": "ogymnastiserad",
    "ogymnastiserats": "ogymnastiserad",
    "ogymnastiserbara": "ogymnastiserbar",
    "ogymnastiserbarare": "ogymnastiserbar",
    "ogymnastiserbarares": "ogymnastiserbar",
    "ogymnastiserbaras": "ogymnastiserbar",
    "ogymnastiserbarast": "ogymnastiserbar",
    "ogymnastiserbaraste": "ogymnastiserbar",
    "ogymnastiserbarastes": "ogymnastiserbar",
    "ogymnastiserbarasts": "ogymnastiserbar",
    "ogymnastiserbare": "ogymnastiserbar",
    "ogymnastiserbares": "ogymnastiserbar",
    "ogymnastiserbarheten": "ogymnastiserbarhet",
    "ogymnastiserbarhetens": "ogymnastiserbarhet",
    "ogymnastiserbarhets": "ogymnastiserbarhet",
    "ogymnastiserbars": "ogymnastiserbar",
    "ogymnastiserbart": "ogymnastiserbar",
    "ogymnastiserbarts": "ogymnastiserbar",
    "ogynnade": "ogynnad",
    "ogynnades": "ogynnad",
    "ogynnads": "ogynnad",
    "ogynnat": "ogynnad",
    "ogynnats": "ogynnad",
    "ogynnsamheten": "ogynnsamhet",
    "ogynnsamhetens": "ogynnsamhet",
    "ogynnsamhets": "ogynnsamhet",
    "ogynnsamma": "ogynnsam",
    "ogynnsammare": "ogynnsam",
    "ogynnsammares": "ogynnsam",
    "ogynnsammas": "ogynnsam",
    "ogynnsammast": "ogynnsam",
    "ogynnsammaste": "ogynnsam",
    "ogynnsammastes": "ogynnsam",
    "ogynnsammasts": "ogynnsam",
    "ogynnsamme": "ogynnsam",
    "ogynnsammes": "ogynnsam",
    "ogynnsams": "ogynnsam",
    "ogynnsamt": "ogynnsam",
    "ogynnsamts": "ogynnsam",
    "ogäckade": "ogäckad",
    "ogäckades": "ogäckad",
    "ogäckads": "ogäckad",
    "ogäckat": "ogäckad",
    "ogäckats": "ogäckad",
    "ogälade": "ogälad",
    "ogälades": "ogälad",
    "ogälads": "ogälad",
    "ogälat": "ogälad",
    "ogälats": "ogälad",
    "ogängade": "ogängad",
    "ogängades": "ogängad",
    "ogängads": "ogängad",
    "ogängat": "ogängad",
    "ogängats": "ogängad",
    "ogärdade": "ogärdad",
    "ogärdades": "ogärdad",
    "ogärdads": "ogärdad",
    "ogärdat": "ogärdad",
    "ogärdats": "ogärdad",
    "ogärdslade": "ogärdslad",
    "ogärdslades": "ogärdslad",
    "ogärdslads": "ogärdslad",
    "ogärdslat": "ogärdslad",
    "ogärdslats": "ogärdslad",
    "ogärningar": "ogärning",
    "ogärningarna": "ogärning",
    "ogärningarnas": "ogärning",
    "ogärningars": "ogärning",
    "ogärningen": "ogärning",
    "ogärningens": "ogärning",
    "ogärnings": "ogärning",
    "ogästade": "ogästad",
    "ogästades": "ogästad",
    "ogästads": "ogästad",
    "ogästat": "ogästad",
    "ogästats": "ogästad",
    "ogästvänliga": "ogästvänlig",
    "ogästvänligare": "ogästvänlig",
    "ogästvänligares": "ogästvänlig",
    "ogästvänligas": "ogästvänlig",
    "ogästvänligast": "ogästvänlig",
    "ogästvänligaste": "ogästvänlig",
    "ogästvänligastes": "ogästvänlig",
    "ogästvänligasts": "ogästvänlig",
    "ogästvänlige": "ogästvänlig",
    "ogästvänliges": "ogästvänlig",
    "ogästvänligheten": "ogästvänlighet",
    "ogästvänlighetens": "ogästvänlighet",
    "ogästvänlighets": "ogästvänlighet",
    "ogästvänligs": "ogästvänlig",
    "ogästvänligt": "ogästvänlig",
    "ogästvänligts": "ogästvänlig",
    "ogångrade": "ogångrad",
    "ogångrades": "ogångrad",
    "ogångrads": "ogångrad",
    "ogångrat": "ogångrad",
    "ogångrats": "ogångrad",
    "ogödslade": "ogödslad",
    "ogödslades": "ogödslad",
    "ogödslads": "ogödslad",
    "ogödslat": "ogödslad",
    "ogödslats": "ogödslad",
    "ogökade": "ogökad",
    "ogökades": "ogökad",
    "ogökads": "ogökad",
    "ogökat": "ogökad",
    "ogökats": "ogökad",
    "ogömde": "ogömd",
    "ogömdes": "ogömd",
    "ogömds": "ogömd",
    "ogömt": "ogömd",
    "ogömts": "ogömd",
    "ogördlade": "ogördlad",
    "ogördlades": "ogördlad",
    "ogördlads": "ogördlad",
    "ogördlat": "ogördlad",
    "ogördlats": "ogördlad",
    "ogörliga": "ogörlig",
    "ogörligare": "ogörlig",
    "ogörligares": "ogörlig",
    "ogörligas": "ogörlig",
    "ogörligast": "ogörlig",
    "ogörligaste": "ogörlig",
    "ogörligastes": "ogörlig",
    "ogörligasts": "ogörlig",
    "ogörlige": "ogörlig",
    "ogörliges": "ogörlig",
    "ogörligheten": "ogörlighet",
    "ogörlighetens": "ogörlighet",
    "ogörlighets": "ogörlighet",
    "ogörligs": "ogörlig",
    "ogörligt": "ogörlig",
    "ogörligts": "ogörlig",
    "ohackade": "ohackad",
    "ohackades": "ohackad",
    "ohackads": "ohackad",
    "ohackat": "ohackad",
    "ohackats": "ohackad",
    "ohaffade": "ohaffad",
    "ohaffades": "ohaffad",
    "ohaffads": "ohaffad",
    "ohaffat": "ohaffad",
    "ohaffats": "ohaffad",
    "ohajade": "ohajad",
    "ohajades": "ohajad",
    "ohajads": "ohajad",
    "ohajat": "ohajad",
    "ohajats": "ohajad",
    "ohakade": "ohakad",
    "ohakades": "ohakad",
    "ohakads": "ohakad",
    "ohakat": "ohakad",
    "ohakats": "ohakad",
    "ohalade": "ohalad",
    "ohalades": "ohalad",
    "ohalads": "ohalad",
    "ohalat": "ohalad",
    "ohalats": "ohalad",
    "ohallucinerade": "ohallucinerad",
    "ohallucinerades": "ohallucinerad",
    "ohallucinerads": "ohallucinerad",
    "ohallucinerat": "ohallucinerad",
    "ohallucinerats": "ohallucinerad",
    "ohallucinerbara": "ohallucinerbar",
    "ohallucinerbarare": "ohallucinerbar",
    "ohallucinerbarares": "ohallucinerbar",
    "ohallucinerbaras": "ohallucinerbar",
    "ohallucinerbarast": "ohallucinerbar",
    "ohallucinerbaraste": "ohallucinerbar",
    "ohallucinerbarastes": "ohallucinerbar",
    "ohallucinerbarasts": "ohallucinerbar",
    "ohallucinerbare": "ohallucinerbar",
    "ohallucinerbares": "ohallucinerbar",
    "ohallucinerbarheten": "ohallucinerbarhet",
    "ohallucinerbarhetens": "ohallucinerbarhet",
    "ohallucinerbarhets": "ohallucinerbarhet",
    "ohallucinerbars": "ohallucinerbar",
    "ohallucinerbart": "ohallucinerbar",
    "ohallucinerbarts": "ohallucinerbar",
    "ohalsade": "ohalsad",
    "ohalsades": "ohalsad",
    "ohalsads": "ohalsad",
    "ohalsat": "ohalsad",
    "ohalsats": "ohalsad",
    "ohalstrade": "ohalstrad",
    "ohalstrades": "ohalstrad",
    "ohalstrads": "ohalstrad",
    "ohalstrat": "ohalstrad",
    "ohalstrats": "ohalstrad",
    "ohalverade": "ohalverad",
    "ohalverades": "ohalverad",
    "ohalverads": "ohalverad",
    "ohalverat": "ohalverad",
    "ohalverats": "ohalverad",
    "ohalverbara": "ohalverbar",
    "ohalverbarare": "ohalverbar",
    "ohalverbarares": "ohalverbar",
    "ohalverbaras": "ohalverbar",
    "ohalverbarast": "ohalverbar",
    "ohalverbaraste": "ohalverbar",
    "ohalverbarastes": "ohalverbar",
    "ohalverbarasts": "ohalverbar",
    "ohalverbare": "ohalverbar",
    "ohalverbares": "ohalverbar",
    "ohalverbarheten": "ohalverbarhet",
    "ohalverbarhetens": "ohalverbarhet",
    "ohalverbarhets": "ohalverbarhet",
    "ohalverbars": "ohalverbar",
    "ohalverbart": "ohalverbar",
    "ohalverbarts": "ohalverbar",
    "ohamlade": "ohamlad",
    "ohamlades": "ohamlad",
    "ohamlads": "ohamlad",
    "ohamlat": "ohamlad",
    "ohamlats": "ohamlad",
    "ohamrade": "ohamrad",
    "ohamrades": "ohamrad",
    "ohamrads": "ohamrad",
    "ohamrat": "ohamrad",
    "ohamrats": "ohamrad",
    "ohamstrade": "ohamstrad",
    "ohamstrades": "ohamstrad",
    "ohamstrads": "ohamstrad",
    "ohamstrat": "ohamstrad",
    "ohamstrats": "ohamstrad",
    "ohandikappade": "ohandikappad",
    "ohandikappades": "ohandikappad",
    "ohandikappads": "ohandikappad",
    "ohandikappat": "ohandikappad",
    "ohandikappats": "ohandikappad",
    "ohandlade": "ohandlad",
    "ohandlades": "ohandlad",
    "ohandlads": "ohandlad",
    "ohandlat": "ohandlad",
    "ohandlats": "ohandlad",
    "ohanterade": "ohanterad",
    "ohanterades": "ohanterad",
    "ohanterads": "ohanterad",
    "ohanterat": "ohanterad",
    "ohanterats": "ohanterad",
    "ohanterbara": "ohanterbar",
    "ohanterbarare": "ohanterbar",
    "ohanterbarares": "ohanterbar",
    "ohanterbaras": "ohanterbar",
    "ohanterbarast": "ohanterbar",
    "ohanterbaraste": "ohanterbar",
    "ohanterbarastes": "ohanterbar",
    "ohanterbarasts": "ohanterbar",
    "ohanterbare": "ohanterbar",
    "ohanterbares": "ohanterbar",
    "ohanterbarheten": "ohanterbarhet",
    "ohanterbarhetens": "ohanterbarhet",
    "ohanterbarhets": "ohanterbarhet",
    "ohanterbars": "ohanterbar",
    "ohanterbart": "ohanterbar",
    "ohanterbarts": "ohanterbar",
    "ohanterliga": "ohanterlig",
    "ohanterligare": "ohanterlig",
    "ohanterligares": "ohanterlig",
    "ohanterligas": "ohanterlig",
    "ohanterligast": "ohanterlig",
    "ohanterligaste": "ohanterlig",
    "ohanterligastes": "ohanterlig",
    "ohanterligasts": "ohanterlig",
    "ohanterlige": "ohanterlig",
    "ohanterliges": "ohanterlig",
    "ohanterligheten": "ohanterlighet",
    "ohanterlighetens": "ohanterlighet",
    "ohanterlighets": "ohanterlighet",
    "ohanterligs": "ohanterlig",
    "ohanterligt": "ohanterlig",
    "ohanterligts": "ohanterlig",
    "oharangerade": "oharangerad",
    "oharangerades": "oharangerad",
    "oharangerads": "oharangerad",
    "oharangerat": "oharangerad",
    "oharangerats": "oharangerad",
    "oharangerbara": "oharangerbar",
    "oharangerbarare": "oharangerbar",
    "oharangerbarares": "oharangerbar",
    "oharangerbaras": "oharangerbar",
    "oharangerbarast": "oharangerbar",
    "oharangerbaraste": "oharangerbar",
    "oharangerbarastes": "oharangerbar",
    "oharangerbarasts": "oharangerbar",
    "oharangerbare": "oharangerbar",
    "oharangerbares": "oharangerbar",
    "oharangerbarheten": "oharangerbarhet",
    "oharangerbarhetens": "oharangerbarhet",
    "oharangerbarhets": "oharangerbarhet",
    "oharangerbars": "oharangerbar",
    "oharangerbart": "oharangerbar",
    "oharangerbarts": "oharangerbar",
    "oharmade": "oharmad",
    "oharmades": "oharmad",
    "oharmads": "oharmad",
    "oharmat": "oharmad",
    "oharmats": "oharmad",
    "oharmoniserade": "oharmoniserad",
    "oharmoniserades": "oharmoniserad",
    "oharmoniserads": "oharmoniserad",
    "oharmoniserat": "oharmoniserad",
    "oharmoniserats": "oharmoniserad",
    "oharmoniserbara": "oharmoniserbar",
    "oharmoniserbarare": "oharmoniserbar",
    "oharmoniserbarares": "oharmoniserbar",
    "oharmoniserbaras": "oharmoniserbar",
    "oharmoniserbarast": "oharmoniserbar",
    "oharmoniserbaraste": "oharmoniserbar",
    "oharmoniserbarastes": "oharmoniserbar",
    "oharmoniserbarasts": "oharmoniserbar",
    "oharmoniserbare": "oharmoniserbar",
    "oharmoniserbares": "oharmoniserbar",
    "oharmoniserbarheten": "oharmoniserbarhet",
    "oharmoniserbarhetens": "oharmoniserbarhet",
    "oharmoniserbarhets": "oharmoniserbarhet",
    "oharmoniserbars": "oharmoniserbar",
    "oharmoniserbart": "oharmoniserbar",
    "oharmoniserbarts": "oharmoniserbar",
    "oharpunerade": "oharpunerad",
    "oharpunerades": "oharpunerad",
    "oharpunerads": "oharpunerad",
    "oharpunerat": "oharpunerad",
    "oharpunerats": "oharpunerad",
    "oharpunerbara": "oharpunerbar",
    "oharpunerbarare": "oharpunerbar",
    "oharpunerbarares": "oharpunerbar",
    "oharpunerbaras": "oharpunerbar",
    "oharpunerbarast": "oharpunerbar",
    "oharpunerbaraste": "oharpunerbar",
    "oharpunerbarastes": "oharpunerbar",
    "oharpunerbarasts": "oharpunerbar",
    "oharpunerbare": "oharpunerbar",
    "oharpunerbares": "oharpunerbar",
    "oharpunerbarheten": "oharpunerbarhet",
    "oharpunerbarhetens": "oharpunerbarhet",
    "oharpunerbarhets": "oharpunerbarhet",
    "oharpunerbars": "oharpunerbar",
    "oharpunerbart": "oharpunerbar",
    "oharpunerbarts": "oharpunerbar",
    "ohartsade": "ohartsad",
    "ohartsades": "ohartsad",
    "ohartsads": "ohartsad",
    "ohartsat": "ohartsad",
    "ohartsats": "ohartsad",
    "oharvade": "oharvad",
    "oharvades": "oharvad",
    "oharvads": "oharvad",
    "oharvat": "oharvad",
    "oharvats": "oharvad",
    "ohasade": "ohasad",
    "ohasades": "ohasad",
    "ohasads": "ohasad",
    "ohasarderade": "ohasarderad",
    "ohasarderades": "ohasarderad",
    "ohasarderads": "ohasarderad",
    "ohasarderat": "ohasarderad",
    "ohasarderats": "ohasarderad",
    "ohasarderbara": "ohasarderbar",
    "ohasarderbarare": "ohasarderbar",
    "ohasarderbarares": "ohasarderbar",
    "ohasarderbaras": "ohasarderbar",
    "ohasarderbarast": "ohasarderbar",
    "ohasarderbaraste": "ohasarderbar",
    "ohasarderbarastes": "ohasarderbar",
    "ohasarderbarasts": "ohasarderbar",
    "ohasarderbare": "ohasarderbar",
    "ohasarderbares": "ohasarderbar",
    "ohasarderbarheten": "ohasarderbarhet",
    "ohasarderbarhetens": "ohasarderbarhet",
    "ohasarderbarhets": "ohasarderbarhet",
    "ohasarderbars": "ohasarderbar",
    "ohasarderbart": "ohasarderbar",
    "ohasarderbarts": "ohasarderbar",
    "ohasat": "ohasad",
    "ohasats": "ohasad",
    "ohaspade": "ohaspad",
    "ohaspades": "ohaspad",
    "ohaspads": "ohaspad",
    "ohaspat": "ohaspad",
    "ohaspats": "ohaspad",
    "ohasplade": "ohasplad",
    "ohasplades": "ohasplad",
    "ohasplads": "ohasplad",
    "ohasplat": "ohasplad",
    "ohasplats": "ohasplad",
    "ohatade": "ohatad",
    "ohatades": "ohatad",
    "ohatads": "ohatad",
    "ohatat": "ohatad",
    "ohatats": "ohatad",
    "ohaussade": "ohaussad",
    "ohaussades": "ohaussad",
    "ohaussads": "ohaussad",
    "ohaussat": "ohaussad",
    "ohaussats": "ohaussad",
    "ohavererade": "ohavererad",
    "ohavererades": "ohavererad",
    "ohavererads": "ohavererad",
    "ohavererat": "ohavererad",
    "ohavererats": "ohavererad",
    "ohavererbara": "ohavererbar",
    "ohavererbarare": "ohavererbar",
    "ohavererbarares": "ohavererbar",
    "ohavererbaras": "ohavererbar",
    "ohavererbarast": "ohavererbar",
    "ohavererbaraste": "ohavererbar",
    "ohavererbarastes": "ohavererbar",
    "ohavererbarasts": "ohavererbar",
    "ohavererbare": "ohavererbar",
    "ohavererbares": "ohavererbar",
    "ohavererbarheten": "ohavererbarhet",
    "ohavererbarhetens": "ohavererbarhet",
    "ohavererbarhets": "ohavererbarhet",
    "ohavererbars": "ohavererbar",
    "ohavererbart": "ohavererbar",
    "ohavererbarts": "ohavererbar",
    "ohederliga": "ohederlig",
    "ohederligare": "ohederlig",
    "ohederligares": "ohederlig",
    "ohederligas": "ohederlig",
    "ohederligast": "ohederlig",
    "ohederligaste": "ohederlig",
    "ohederligastes": "ohederlig",
    "ohederligasts": "ohederlig",
    "ohederlige": "ohederlig",
    "ohederliges": "ohederlig",
    "ohederligheten": "ohederlighet",
    "ohederlighetens": "ohederlighet",
    "ohederligheter": "ohederlighet",
    "ohederligheterna": "ohederlighet",
    "ohederligheternas": "ohederlighet",
    "ohederligheters": "ohederlighet",
    "ohederlighets": "ohederlighet",
    "ohederligs": "ohederlig",
    "ohederligt": "ohederlig",
    "ohederligts": "ohederlig",
    "ohedrade": "ohedrad",
    "ohedrades": "ohedrad",
    "ohedrads": "ohedrad",
    "ohedrat": "ohedrad",
    "ohedrats": "ohedrad",
    "ohejade": "ohejad",
    "ohejades": "ohejad",
    "ohejads": "ohejad",
    "ohejat": "ohejad",
    "ohejats": "ohejad",
    "ohejdade": "ohejdad",
    "ohejdades": "ohejdad",
    "ohejdads": "ohejdad",
    "ohejdat": "ohejdad",
    "ohejdats": "ohejdad",
    "ohektograferbara": "ohektograferbar",
    "ohektograferbarare": "ohektograferbar",
    "ohektograferbarares": "ohektograferbar",
    "ohektograferbaras": "ohektograferbar",
    "ohektograferbarast": "ohektograferbar",
    "ohektograferbaraste": "ohektograferbar",
    "ohektograferbarastes": "ohektograferbar",
    "ohektograferbarasts": "ohektograferbar",
    "ohektograferbare": "ohektograferbar",
    "ohektograferbares": "ohektograferbar",
    "ohektograferbarheten": "ohektograferbarhet",
    "ohektograferbarhetens": "ohektograferbarhet",
    "ohektograferbarhets": "ohektograferbarhet",
    "ohektograferbars": "ohektograferbar",
    "ohektograferbart": "ohektograferbar",
    "ohektograferbarts": "ohektograferbar",
    "ohelade": "ohelad",
    "ohelades": "ohelad",
    "ohelads": "ohelad",
    "ohelat": "ohelad",
    "ohelats": "ohelad",
    "ohelgade": "ohelgad",
    "ohelgades": "ohelgad",
    "ohelgads": "ohelgad",
    "ohelgat": "ohelgad",
    "ohelgats": "ohelgad",
    "oheliga": "ohelig",
    "oheligare": "ohelig",
    "oheligares": "ohelig",
    "oheligas": "ohelig",
    "oheligast": "ohelig",
    "oheligaste": "ohelig",
    "oheligastes": "ohelig",
    "oheligasts": "ohelig",
    "ohelige": "ohelig",
    "oheliges": "ohelig",
    "oheligheten": "ohelighet",
    "ohelighetens": "ohelighet",
    "ohelighets": "ohelighet",
    "oheligs": "ohelig",
    "oheligt": "ohelig",
    "oheligts": "ohelig",
    "ohemsökta": "ohemsökt",
    "ohemsöktas": "ohemsökt",
    "ohemsökte": "ohemsökt",
    "ohemsöktes": "ohemsökt",
    "ohemsökts": "ohemsökt",
    "ohemula": "ohemul",
    "ohemulare": "ohemul",
    "ohemulares": "ohemul",
    "ohemulas": "ohemul",
    "ohemulast": "ohemul",
    "ohemulaste": "ohemul",
    "ohemulastes": "ohemul",
    "ohemulasts": "ohemul",
    "ohemule": "ohemul",
    "ohemules": "ohemul",
    "ohemuls": "ohemul",
    "ohemult": "ohemul",
    "ohemults": "ohemul",
    "ohenade": "ohenad",
    "ohenades": "ohenad",
    "ohenads": "ohenad",
    "ohenat": "ohenad",
    "ohenats": "ohenad",
    "oheroiserade": "oheroiserad",
    "oheroiserades": "oheroiserad",
    "oheroiserads": "oheroiserad",
    "oheroiserat": "oheroiserad",
    "oheroiserats": "oheroiserad",
    "oheroiserbara": "oheroiserbar",
    "oheroiserbarare": "oheroiserbar",
    "oheroiserbarares": "oheroiserbar",
    "oheroiserbaras": "oheroiserbar",
    "oheroiserbarast": "oheroiserbar",
    "oheroiserbaraste": "oheroiserbar",
    "oheroiserbarastes": "oheroiserbar",
    "oheroiserbarasts": "oheroiserbar",
    "oheroiserbare": "oheroiserbar",
    "oheroiserbares": "oheroiserbar",
    "oheroiserbarheten": "oheroiserbarhet",
    "oheroiserbarhetens": "oheroiserbarhet",
    "oheroiserbarhets": "oheroiserbarhet",
    "oheroiserbars": "oheroiserbar",
    "oheroiserbart": "oheroiserbar",
    "oheroiserbarts": "oheroiserbar",
    "ohetsade": "ohetsad",
    "ohetsades": "ohetsad",
    "ohetsads": "ohetsad",
    "ohetsat": "ohetsad",
    "ohetsats": "ohetsad",
    "ohindrade": "ohindrad",
    "ohindrades": "ohindrad",
    "ohindrads": "ohindrad",
    "ohindrat": "ohindrad",
    "ohindrats": "ohindrad",
    "ohinkade": "ohinkad",
    "ohinkades": "ohinkad",
    "ohinkads": "ohinkad",
    "ohinkat": "ohinkad",
    "ohinkats": "ohinkad",
    "ohissade": "ohissad",
    "ohissades": "ohissad",
    "ohissads": "ohissad",
    "ohissat": "ohissad",
    "ohissats": "ohissad",
    "ohistorierade": "ohistorierad",
    "ohistorierades": "ohistorierad",
    "ohistorierads": "ohistorierad",
    "ohistorierat": "ohistorierad",
    "ohistorierats": "ohistorierad",
    "ohistorierbara": "ohistorierbar",
    "ohistorierbarare": "ohistorierbar",
    "ohistorierbarares": "ohistorierbar",
    "ohistorierbaras": "ohistorierbar",
    "ohistorierbarast": "ohistorierbar",
    "ohistorierbaraste": "ohistorierbar",
    "ohistorierbarastes": "ohistorierbar",
    "ohistorierbarasts": "ohistorierbar",
    "ohistorierbare": "ohistorierbar",
    "ohistorierbares": "ohistorierbar",
    "ohistorierbarheten": "ohistorierbarhet",
    "ohistorierbarhetens": "ohistorierbarhet",
    "ohistorierbarhets": "ohistorierbarhet",
    "ohistorierbars": "ohistorierbar",
    "ohistorierbart": "ohistorierbar",
    "ohistorierbarts": "ohistorierbar",
    "ohistoriserade": "ohistoriserad",
    "ohistoriserades": "ohistoriserad",
    "ohistoriserads": "ohistoriserad",
    "ohistoriserat": "ohistoriserad",
    "ohistoriserats": "ohistoriserad",
    "ohistoriserbara": "ohistoriserbar",
    "ohistoriserbarare": "ohistoriserbar",
    "ohistoriserbarares": "ohistoriserbar",
    "ohistoriserbaras": "ohistoriserbar",
    "ohistoriserbarast": "ohistoriserbar",
    "ohistoriserbaraste": "ohistoriserbar",
    "ohistoriserbarastes": "ohistoriserbar",
    "ohistoriserbarasts": "ohistoriserbar",
    "ohistoriserbare": "ohistoriserbar",
    "ohistoriserbares": "ohistoriserbar",
    "ohistoriserbarheten": "ohistoriserbarhet",
    "ohistoriserbarhetens": "ohistoriserbarhet",
    "ohistoriserbarhets": "ohistoriserbarhet",
    "ohistoriserbars": "ohistoriserbar",
    "ohistoriserbart": "ohistoriserbar",
    "ohistoriserbarts": "ohistoriserbar",
    "ohistoriska": "ohistorisk",
    "ohistoriskare": "ohistorisk",
    "ohistoriskares": "ohistorisk",
    "ohistoriskas": "ohistorisk",
    "ohistoriskast": "ohistorisk",
    "ohistoriskaste": "ohistorisk",
    "ohistoriskastes": "ohistorisk",
    "ohistoriskasts": "ohistorisk",
    "ohistoriske": "ohistorisk",
    "ohistoriskes": "ohistorisk",
    "ohistorisks": "ohistorisk",
    "ohistoriskt": "ohistorisk",
    "ohistoriskts": "ohistorisk",
    "ohittade": "ohittad",
    "ohittades": "ohittad",
    "ohittads": "ohittad",
    "ohittat": "ohittad",
    "ohittats": "ohittad",
    "ohivade": "ohivad",
    "ohivades": "ohivad",
    "ohivads": "ohivad",
    "ohivat": "ohivad",
    "ohivats": "ohivad",
    "ohjälpliga": "ohjälplig",
    "ohjälpligare": "ohjälplig",
    "ohjälpligares": "ohjälplig",
    "ohjälpligas": "ohjälplig",
    "ohjälpligast": "ohjälplig",
    "ohjälpligaste": "ohjälplig",
    "ohjälpligastes": "ohjälplig",
    "ohjälpligasts": "ohjälplig",
    "ohjälplige": "ohjälplig",
    "ohjälpliges": "ohjälplig",
    "ohjälpligheten": "ohjälplighet",
    "ohjälplighetens": "ohjälplighet",
    "ohjälplighets": "ohjälplighet",
    "ohjälpligs": "ohjälplig",
    "ohjälpligt": "ohjälplig",
    "ohjälpligts": "ohjälplig",
    "ohjälpta": "ohjälpt",
    "ohjälptas": "ohjälpt",
    "ohjälpte": "ohjälpt",
    "ohjälptes": "ohjälpt",
    "ohjälpts": "ohjälpt",
    "ohmen": "ohm",
    "ohmens": "ohm",
    "ohms": "ohm",
    "oholograferade": "oholograferad",
    "oholograferades": "oholograferad",
    "oholograferads": "oholograferad",
    "oholograferat": "oholograferad",
    "oholograferats": "oholograferad",
    "oholograferbara": "oholograferbar",
    "oholograferbarare": "oholograferbar",
    "oholograferbarares": "oholograferbar",
    "oholograferbaras": "oholograferbar",
    "oholograferbarast": "oholograferbar",
    "oholograferbaraste": "oholograferbar",
    "oholograferbarastes": "oholograferbar",
    "oholograferbarasts": "oholograferbar",
    "oholograferbare": "oholograferbar",
    "oholograferbares": "oholograferbar",
    "oholograferbarheten": "oholograferbarhet",
    "oholograferbarhetens": "oholograferbarhet",
    "oholograferbarhets": "oholograferbarhet",
    "oholograferbars": "oholograferbar",
    "oholograferbart": "oholograferbar",
    "oholograferbarts": "oholograferbar",
    "ohomogeniserade": "ohomogeniserad",
    "ohomogeniserades": "ohomogeniserad",
    "ohomogeniserads": "ohomogeniserad",
    "ohomogeniserat": "ohomogeniserad",
    "ohomogeniserats": "ohomogeniserad",
    "ohomogeniserbara": "ohomogeniserbar",
    "ohomogeniserbarare": "ohomogeniserbar",
    "ohomogeniserbarares": "ohomogeniserbar",
    "ohomogeniserbaras": "ohomogeniserbar",
    "ohomogeniserbarast": "ohomogeniserbar",
    "ohomogeniserbaraste": "ohomogeniserbar",
    "ohomogeniserbarastes": "ohomogeniserbar",
    "ohomogeniserbarasts": "ohomogeniserbar",
    "ohomogeniserbare": "ohomogeniserbar",
    "ohomogeniserbares": "ohomogeniserbar",
    "ohomogeniserbarheten": "ohomogeniserbarhet",
    "ohomogeniserbarhetens": "ohomogeniserbarhet",
    "ohomogeniserbarhets": "ohomogeniserbarhet",
    "ohomogeniserbars": "ohomogeniserbar",
    "ohomogeniserbart": "ohomogeniserbar",
    "ohomogeniserbarts": "ohomogeniserbar",
    "ohonorerade": "ohonorerad",
    "ohonorerades": "ohonorerad",
    "ohonorerads": "ohonorerad",
    "ohonorerat": "ohonorerad",
    "ohonorerats": "ohonorerad",
    "ohonorerbara": "ohonorerbar",
    "ohonorerbarare": "ohonorerbar",
    "ohonorerbarares": "ohonorerbar",
    "ohonorerbaras": "ohonorerbar",
    "ohonorerbarast": "ohonorerbar",
    "ohonorerbaraste": "ohonorerbar",
    "ohonorerbarastes": "ohonorerbar",
    "ohonorerbarasts": "ohonorerbar",
    "ohonorerbare": "ohonorerbar",
    "ohonorerbares": "ohonorerbar",
    "ohonorerbarheten": "ohonorerbarhet",
    "ohonorerbarhetens": "ohonorerbarhet",
    "ohonorerbarhets": "ohonorerbarhet",
    "ohonorerbars": "ohonorerbar",
    "ohonorerbart": "ohonorerbar",
    "ohonorerbarts": "ohonorerbar",
    "ohopade": "ohopad",
    "ohopades": "ohopad",
    "ohopads": "ohopad",
    "ohopat": "ohopad",
    "ohopats": "ohopad",
    "ohopdiktade": "ohopdiktad",
    "ohopdiktades": "ohopdiktad",
    "ohopdiktads": "ohopdiktad",
    "ohopdiktat": "ohopdiktad",
    "ohopdiktats": "ohopdiktad",
    "ohopfogade": "ohopfogad",
    "ohopfogades": "ohopfogad",
    "ohopfogads": "ohopfogad",
    "ohopfogat": "ohopfogad",
    "ohopfogats": "ohopfogad",
    "ohoplappade": "ohoplappad",
    "ohoplappades": "ohoplappad",
    "ohoplappads": "ohoplappad",
    "ohoplappat": "ohoplappad",
    "ohoplappats": "ohoplappad",
    "ohoppade": "ohoppad",
    "ohoppades": "ohoppad",
    "ohoppads": "ohoppad",
    "ohoppat": "ohoppad",
    "ohoppats": "ohoppad",
    "ohospitaliserade": "ohospitaliserad",
    "ohospitaliserades": "ohospitaliserad",
    "ohospitaliserads": "ohospitaliserad",
    "ohospitaliserat": "ohospitaliserad",
    "ohospitaliserats": "ohospitaliserad",
    "ohospitaliserbara": "ohospitaliserbar",
    "ohospitaliserbarare": "ohospitaliserbar",
    "ohospitaliserbarares": "ohospitaliserbar",
    "ohospitaliserbaras": "ohospitaliserbar",
    "ohospitaliserbarast": "ohospitaliserbar",
    "ohospitaliserbaraste": "ohospitaliserbar",
    "ohospitaliserbarastes": "ohospitaliserbar",
    "ohospitaliserbarasts": "ohospitaliserbar",
    "ohospitaliserbare": "ohospitaliserbar",
    "ohospitaliserbares": "ohospitaliserbar",
    "ohospitaliserbarheten": "ohospitaliserbarhet",
    "ohospitaliserbarhetens": "ohospitaliserbarhet",
    "ohospitaliserbarhets": "ohospitaliserbarhet",
    "ohospitaliserbars": "ohospitaliserbar",
    "ohospitaliserbart": "ohospitaliserbar",
    "ohospitaliserbarts": "ohospitaliserbar",
    "ohostade": "ohostad",
    "ohostades": "ohostad",
    "ohostads": "ohostad",
    "ohostat": "ohostad",
    "ohostats": "ohostad",
    "ohotade": "ohotad",
    "ohotades": "ohotad",
    "ohotads": "ohotad",
    "ohotat": "ohotad",
    "ohotats": "ohotad",
    "ohottade": "ohottad",
    "ohottades": "ohottad",
    "ohottads": "ohottad",
    "ohottat": "ohottad",
    "ohottats": "ohottad",
    "ohugnade": "ohugnad",
    "ohugnades": "ohugnad",
    "ohugnads": "ohugnad",
    "ohugnat": "ohugnad",
    "ohugnats": "ohugnad",
    "ohumaniserade": "ohumaniserad",
    "ohumaniserades": "ohumaniserad",
    "ohumaniserads": "ohumaniserad",
    "ohumaniserat": "ohumaniserad",
    "ohumaniserats": "ohumaniserad",
    "ohumaniserbara": "ohumaniserbar",
    "ohumaniserbarare": "ohumaniserbar",
    "ohumaniserbarares": "ohumaniserbar",
    "ohumaniserbaras": "ohumaniserbar",
    "ohumaniserbarast": "ohumaniserbar",
    "ohumaniserbaraste": "ohumaniserbar",
    "ohumaniserbarastes": "ohumaniserbar",
    "ohumaniserbarasts": "ohumaniserbar",
    "ohumaniserbare": "ohumaniserbar",
    "ohumaniserbares": "ohumaniserbar",
    "ohumaniserbarheten": "ohumaniserbarhet",
    "ohumaniserbarhetens": "ohumaniserbarhet",
    "ohumaniserbarhets": "ohumaniserbarhet",
    "ohumaniserbars": "ohumaniserbar",
    "ohumaniserbart": "ohumaniserbar",
    "ohumaniserbarts": "ohumaniserbar",
    "ohundsade": "ohundsad",
    "ohundsades": "ohundsad",
    "ohundsads": "ohundsad",
    "ohundsat": "ohundsad",
    "ohundsats": "ohundsad",
    "ohundsfotterade": "ohundsfotterad",
    "ohundsfotterades": "ohundsfotterad",
    "ohundsfotterads": "ohundsfotterad",
    "ohundsfotterat": "ohundsfotterad",
    "ohundsfotterats": "ohundsfotterad",
    "ohundsfotterbara": "ohundsfotterbar",
    "ohundsfotterbarare": "ohundsfotterbar",
    "ohundsfotterbarares": "ohundsfotterbar",
    "ohundsfotterbaras": "ohundsfotterbar",
    "ohundsfotterbarast": "ohundsfotterbar",
    "ohundsfotterbaraste": "ohundsfotterbar",
    "ohundsfotterbarastes": "ohundsfotterbar",
    "ohundsfotterbarasts": "ohundsfotterbar",
    "ohundsfotterbare": "ohundsfotterbar",
    "ohundsfotterbares": "ohundsfotterbar",
    "ohundsfotterbarheten": "ohundsfotterbarhet",
    "ohundsfotterbarhetens": "ohundsfotterbarhet",
    "ohundsfotterbarhets": "ohundsfotterbarhet",
    "ohundsfotterbars": "ohundsfotterbar",
    "ohundsfotterbart": "ohundsfotterbar",
    "ohundsfotterbarts": "ohundsfotterbar",
    "ohunsade": "ohunsad",
    "ohunsades": "ohunsad",
    "ohunsads": "ohunsad",
    "ohunsat": "ohunsad",
    "ohunsats": "ohunsad",
    "ohuserade": "ohuserad",
    "ohuserades": "ohuserad",
    "ohuserads": "ohuserad",
    "ohuserat": "ohuserad",
    "ohuserats": "ohuserad",
    "ohuserbara": "ohuserbar",
    "ohuserbarare": "ohuserbar",
    "ohuserbarares": "ohuserbar",
    "ohuserbaras": "ohuserbar",
    "ohuserbarast": "ohuserbar",
    "ohuserbaraste": "ohuserbar",
    "ohuserbarastes": "ohuserbar",
    "ohuserbarasts": "ohuserbar",
    "ohuserbare": "ohuserbar",
    "ohuserbares": "ohuserbar",
    "ohuserbarheten": "ohuserbarhet",
    "ohuserbarhetens": "ohuserbarhet",
    "ohuserbarhets": "ohuserbarhet",
    "ohuserbars": "ohuserbar",
    "ohuserbart": "ohuserbar",
    "ohuserbarts": "ohuserbar",
    "ohybridiserade": "ohybridiserad",
    "ohybridiserades": "ohybridiserad",
    "ohybridiserads": "ohybridiserad",
    "ohybridiserat": "ohybridiserad",
    "ohybridiserats": "ohybridiserad",
    "ohybridiserbara": "ohybridiserbar",
    "ohybridiserbarare": "ohybridiserbar",
    "ohybridiserbarares": "ohybridiserbar",
    "ohybridiserbaras": "ohybridiserbar",
    "ohybridiserbarast": "ohybridiserbar",
    "ohybridiserbaraste": "ohybridiserbar",
    "ohybridiserbarastes": "ohybridiserbar",
    "ohybridiserbarasts": "ohybridiserbar",
    "ohybridiserbare": "ohybridiserbar",
    "ohybridiserbares": "ohybridiserbar",
    "ohybridiserbarheten": "ohybridiserbarhet",
    "ohybridiserbarhetens": "ohybridiserbarhet",
    "ohybridiserbarhets": "ohybridiserbarhet",
    "ohybridiserbars": "ohybridiserbar",
    "ohybridiserbart": "ohybridiserbar",
    "ohybridiserbarts": "ohybridiserbar",
    "ohycklade": "ohycklad",
    "ohycklades": "ohycklad",
    "ohycklads": "ohycklad",
    "ohycklat": "ohycklad",
    "ohycklats": "ohycklad",
    "ohydrerade": "ohydrerad",
    "ohydrerades": "ohydrerad",
    "ohydrerads": "ohydrerad",
    "ohydrerat": "ohydrerad",
    "ohydrerats": "ohydrerad",
    "ohydrerbara": "ohydrerbar",
    "ohydrerbarare": "ohydrerbar",
    "ohydrerbarares": "ohydrerbar",
    "ohydrerbaras": "ohydrerbar",
    "ohydrerbarast": "ohydrerbar",
    "ohydrerbaraste": "ohydrerbar",
    "ohydrerbarastes": "ohydrerbar",
    "ohydrerbarasts": "ohydrerbar",
    "ohydrerbare": "ohydrerbar",
    "ohydrerbares": "ohydrerbar",
    "ohydrerbarheten": "ohydrerbarhet",
    "ohydrerbarhetens": "ohydrerbarhet",
    "ohydrerbarhets": "ohydrerbarhet",
    "ohydrerbars": "ohydrerbar",
    "ohydrerbart": "ohydrerbar",
    "ohydrerbarts": "ohydrerbar",
    "ohyfsade": "ohyfsad",
    "ohyfsades": "ohyfsad",
    "ohyfsads": "ohyfsad",
    "ohyfsat": "ohyfsad",
    "ohyfsats": "ohyfsad",
    "ohyggliga": "ohygglig",
    "ohyggligare": "ohygglig",
    "ohyggligares": "ohygglig",
    "ohyggligas": "ohygglig",
    "ohyggligast": "ohygglig",
    "ohyggligaste": "ohygglig",
    "ohyggligastes": "ohygglig",
    "ohyggligasts": "ohygglig",
    "ohygglige": "ohygglig",
    "ohyggliges": "ohygglig",
    "ohyggligheten": "ohygglighet",
    "ohygglighetens": "ohygglighet",
    "ohyggligheter": "ohygglighet",
    "ohyggligheterna": "ohygglighet",
    "ohyggligheternas": "ohygglighet",
    "ohyggligheters": "ohygglighet",
    "ohygglighets": "ohygglighet",
    "ohyggligs": "ohygglig",
    "ohyggligt": "ohygglig",
    "ohyggligts": "ohygglig",
    "ohygieniska": "ohygienisk",
    "ohygieniskare": "ohygienisk",
    "ohygieniskares": "ohygienisk",
    "ohygieniskas": "ohygienisk",
    "ohygieniskast": "ohygienisk",
    "ohygieniskaste": "ohygienisk",
    "ohygieniskastes": "ohygienisk",
    "ohygieniskasts": "ohygienisk",
    "ohygieniske": "ohygienisk",
    "ohygieniskes": "ohygienisk",
    "ohygienisks": "ohygienisk",
    "ohygieniskt": "ohygienisk",
    "ohygieniskts": "ohygienisk",
    "ohyllade": "ohyllad",
    "ohyllades": "ohyllad",
    "ohyllads": "ohyllad",
    "ohyllat": "ohyllad",
    "ohyllats": "ohyllad",
    "ohypnotiserade": "ohypnotiserad",
    "ohypnotiserades": "ohypnotiserad",
    "ohypnotiserads": "ohypnotiserad",
    "ohypnotiserat": "ohypnotiserad",
    "ohypnotiserats": "ohypnotiserad",
    "ohypnotiserbara": "ohypnotiserbar",
    "ohypnotiserbarare": "ohypnotiserbar",
    "ohypnotiserbarares": "ohypnotiserbar",
    "ohypnotiserbaras": "ohypnotiserbar",
    "ohypnotiserbarast": "ohypnotiserbar",
    "ohypnotiserbaraste": "ohypnotiserbar",
    "ohypnotiserbarastes": "ohypnotiserbar",
    "ohypnotiserbarasts": "ohypnotiserbar",
    "ohypnotiserbare": "ohypnotiserbar",
    "ohypnotiserbares": "ohypnotiserbar",
    "ohypnotiserbarheten": "ohypnotiserbarhet",
    "ohypnotiserbarhetens": "ohypnotiserbarhet",
    "ohypnotiserbarhets": "ohypnotiserbarhet",
    "ohypnotiserbars": "ohypnotiserbar",
    "ohypnotiserbart": "ohypnotiserbar",
    "ohypnotiserbarts": "ohypnotiserbar",
    "ohypotiserade": "ohypotiserad",
    "ohypotiserades": "ohypotiserad",
    "ohypotiserads": "ohypotiserad",
    "ohypotiserat": "ohypotiserad",
    "ohypotiserats": "ohypotiserad",
    "ohypotiserbara": "ohypotiserbar",
    "ohypotiserbarare": "ohypotiserbar",
    "ohypotiserbarares": "ohypotiserbar",
    "ohypotiserbaras": "ohypotiserbar",
    "ohypotiserbarast": "ohypotiserbar",
    "ohypotiserbaraste": "ohypotiserbar",
    "ohypotiserbarastes": "ohypotiserbar",
    "ohypotiserbarasts": "ohypotiserbar",
    "ohypotiserbare": "ohypotiserbar",
    "ohypotiserbares": "ohypotiserbar",
    "ohypotiserbarheten": "ohypotiserbarhet",
    "ohypotiserbarhetens": "ohypotiserbarhet",
    "ohypotiserbarhets": "ohypotiserbarhet",
    "ohypotiserbars": "ohypotiserbar",
    "ohypotiserbart": "ohypotiserbar",
    "ohypotiserbarts": "ohypotiserbar",
    "ohyran": "ohyra",
    "ohyrans": "ohyra",
    "ohyras": "ohyra",
    "ohyrde": "ohyrd",
    "ohyrdes": "ohyrd",
    "ohyrds": "ohyrd",
    "ohyrt": "ohyrd",
    "ohyrts": "ohyrd",
    "ohysbara": "ohysbar",
    "ohysbarare": "ohysbar",
    "ohysbarares": "ohysbar",
    "ohysbaras": "ohysbar",
    "ohysbarast": "ohysbar",
    "ohysbaraste": "ohysbar",
    "ohysbarastes": "ohysbar",
    "ohysbarasts": "ohysbar",
    "ohysbare": "ohysbar",
    "ohysbares": "ohysbar",
    "ohysbarheten": "ohysbarhet",
    "ohysbarhetens": "ohysbarhet",
    "ohysbarhets": "ohysbarhet",
    "ohysbars": "ohysbar",
    "ohysbart": "ohysbar",
    "ohysbarts": "ohysbar",
    "ohyssjade": "ohyssjad",
    "ohyssjades": "ohyssjad",
    "ohyssjads": "ohyssjad",
    "ohyssjat": "ohyssjad",
    "ohyssjats": "ohyssjad",
    "ohysta": "ohyst",
    "ohystade": "ohystad",
    "ohystades": "ohystad",
    "ohystads": "ohystad",
    "ohystas": "ohyst",
    "ohystat": "ohystad",
    "ohystats": "ohystad",
    "ohyste": "ohyst",
    "ohystes": "ohyst",
    "ohysts": "ohyst",
    "ohyvade": "ohyvad",
    "ohyvades": "ohyvad",
    "ohyvads": "ohyvad",
    "ohyvat": "ohyvad",
    "ohyvats": "ohyvad",
    "ohyvlade": "ohyvlad",
    "ohyvlades": "ohyvlad",
    "ohyvlads": "ohyvlad",
    "ohyvlat": "ohyvlad",
    "ohyvlats": "ohyvlad",
    "ohäcklade": "ohäcklad",
    "ohäcklades": "ohäcklad",
    "ohäcklads": "ohäcklad",
    "ohäcklat": "ohäcklad",
    "ohäcklats": "ohäcklad",
    "ohädankallade": "ohädankallad",
    "ohädankallades": "ohädankallad",
    "ohädankallads": "ohädankallad",
    "ohädankallat": "ohädankallad",
    "ohädankallats": "ohädankallad",
    "ohäftade": "ohäftad",
    "ohäftades": "ohäftad",
    "ohäftads": "ohäftad",
    "ohäftat": "ohäftad",
    "ohäftats": "ohäftad",
    "ohägnade": "ohägnad",
    "ohägnades": "ohägnad",
    "ohägnads": "ohägnad",
    "ohägnat": "ohägnad",
    "ohägnats": "ohägnad",
    "ohägnet": "ohägn",
    "ohägnets": "ohägn",
    "ohägns": "ohägn",
    "ohäktade": "ohäktad",
    "ohäktades": "ohäktad",
    "ohäktads": "ohäktad",
    "ohäktat": "ohäktad",
    "ohäktats": "ohäktad",
    "ohällde": "ohälld",
    "ohälldes": "ohälld",
    "ohällds": "ohälld",
    "ohällt": "ohälld",
    "ohällts": "ohälld",
    "ohälsade": "ohälsad",
    "ohälsades": "ohälsad",
    "ohälsads": "ohälsad",
    "ohälsan": "ohälsa",
    "ohälsans": "ohälsa",
    "ohälsas": "ohälsa",
    "ohälsat": "ohälsad",
    "ohälsats": "ohälsad",
    "ohälse": "ohälsa",
    "ohälso": "ohälsa",
    "ohälsosamheten": "ohälsosamhet",
    "ohälsosamhetens": "ohälsosamhet",
    "ohälsosamhets": "ohälsosamhet",
    "ohälsosamma": "ohälsosam",
    "ohälsosammare": "ohälsosam",
    "ohälsosammares": "ohälsosam",
    "ohälsosammas": "ohälsosam",
    "ohälsosammast": "ohälsosam",
    "ohälsosammaste": "ohälsosam",
    "ohälsosammastes": "ohälsosam",
    "ohälsosammasts": "ohälsosam",
    "ohälsosamme": "ohälsosam",
    "ohälsosammes": "ohälsosam",
    "ohälsosams": "ohälsosam",
    "ohälsosamt": "ohälsosam",
    "ohälsosamts": "ohälsosam",
    "ohämmade": "ohämmad",
    "ohämmades": "ohämmad",
    "ohämmads": "ohämmad",
    "ohämmat": "ohämmad",
    "ohämmats": "ohämmad",
    "ohämnade": "ohämnad",
    "ohämnades": "ohämnad",
    "ohämnads": "ohämnad",
    "ohämnat": "ohämnad",
    "ohämnats": "ohämnad",
    "ohämtade": "ohämtad",
    "ohämtades": "ohämtad",
    "ohämtads": "ohämtad",
    "ohämtat": "ohämtad",
    "ohämtats": "ohämtad",
    "ohänförde": "ohänförd",
    "ohänfördes": "ohänförd",
    "ohänförds": "ohänförd",
    "ohänfört": "ohänförd",
    "ohänförts": "ohänförd",
    "ohängda": "ohängd",
    "ohängdare": "ohängd",
    "ohängdares": "ohängd",
    "ohängdas": "ohängd",
    "ohängdast": "ohängd",
    "ohängdaste": "ohängd",
    "ohängdastes": "ohängd",
    "ohängdasts": "ohängd",
    "ohängde": "ohängd",
    "ohängdes": "ohängd",
    "ohängdheten": "ohängdhet",
    "ohängdhetens": "ohängdhet",
    "ohängdhets": "ohängdhet",
    "ohängds": "ohängd",
    "ohängt": "ohängd",
    "ohängts": "ohängd",
    "ohänryckta": "ohänryckt",
    "ohänrycktas": "ohänryckt",
    "ohänryckte": "ohänryckt",
    "ohänrycktes": "ohänryckt",
    "ohänryckts": "ohänryckt",
    "ohänvisade": "ohänvisad",
    "ohänvisades": "ohänvisad",
    "ohänvisads": "ohänvisad",
    "ohänvisat": "ohänvisad",
    "ohänvisats": "ohänvisad",
    "ohärbärgerade": "ohärbärgerad",
    "ohärbärgerades": "ohärbärgerad",
    "ohärbärgerads": "ohärbärgerad",
    "ohärbärgerat": "ohärbärgerad",
    "ohärbärgerats": "ohärbärgerad",
    "ohärbärgerbara": "ohärbärgerbar",
    "ohärbärgerbarare": "ohärbärgerbar",
    "ohärbärgerbarares": "ohärbärgerbar",
    "ohärbärgerbaras": "ohärbärgerbar",
    "ohärbärgerbarast": "ohärbärgerbar",
    "ohärbärgerbaraste": "ohärbärgerbar",
    "ohärbärgerbarastes": "ohärbärgerbar",
    "ohärbärgerbarasts": "ohärbärgerbar",
    "ohärbärgerbare": "ohärbärgerbar",
    "ohärbärgerbares": "ohärbärgerbar",
    "ohärbärgerbarheten": "ohärbärgerbarhet",
    "ohärbärgerbarhetens": "ohärbärgerbarhet",
    "ohärbärgerbarhets": "ohärbärgerbarhet",
    "ohärbärgerbars": "ohärbärgerbar",
    "ohärbärgerbart": "ohärbärgerbar",
    "ohärbärgerbarts": "ohärbärgerbar",
    "ohärdade": "ohärdad",
    "ohärdades": "ohärdad",
    "ohärdads": "ohärdad",
    "ohärdat": "ohärdad",
    "ohärdats": "ohärdad",
    "ohärjade": "ohärjad",
    "ohärjades": "ohärjad",
    "ohärjads": "ohärjad",
    "ohärjat": "ohärjad",
    "ohärjats": "ohärjad",
    "ohärmade": "ohärmad",
    "ohärmades": "ohärmad",
    "ohärmads": "ohärmad",
    "ohärmat": "ohärmad",
    "ohärmats": "ohärmad",
    "ohärsknade": "ohärsknad",
    "ohärsknades": "ohärsknad",
    "ohärsknads": "ohärsknad",
    "ohärsknat": "ohärsknad",
    "ohärsknats": "ohärsknad",
    "ohässjade": "ohässjad",
    "ohässjades": "ohässjad",
    "ohässjads": "ohässjad",
    "ohässjat": "ohässjad",
    "ohässjats": "ohässjad",
    "ohävdade": "ohävdad",
    "ohävdades": "ohävdad",
    "ohävdads": "ohävdad",
    "ohävdat": "ohävdad",
    "ohävdats": "ohävdad",
    "ohävde": "ohävd",
    "ohävdes": "ohävd",
    "ohävds": "ohävd",
    "ohävt": "ohävd",
    "ohävts": "ohävd",
    "ohågade": "ohågad",
    "ohågades": "ohågad",
    "ohågads": "ohågad",
    "ohågat": "ohågad",
    "ohågats": "ohågad",
    "ohålade": "ohålad",
    "ohålades": "ohålad",
    "ohålads": "ohålad",
    "ohålat": "ohålad",
    "ohålats": "ohålad",
    "ohållbara": "ohållbar",
    "ohållbarare": "ohållbar",
    "ohållbarares": "ohållbar",
    "ohållbaras": "ohållbar",
    "ohållbarast": "ohållbar",
    "ohållbaraste": "ohållbar",
    "ohållbarastes": "ohållbar",
    "ohållbarasts": "ohållbar",
    "ohållbare": "ohållbar",
    "ohållbares": "ohållbar",
    "ohållbarheten": "ohållbarhet",
    "ohållbarhetens": "ohållbarhet",
    "ohållbarheter": "ohållbarhet",
    "ohållbarheterna": "ohållbarhet",
    "ohållbarheternas": "ohållbarhet",
    "ohållbarheters": "ohållbarhet",
    "ohållbarhets": "ohållbarhet",
    "ohållbars": "ohållbar",
    "ohållbart": "ohållbar",
    "ohållbarts": "ohållbar",
    "ohånade": "ohånad",
    "ohånades": "ohånad",
    "ohånads": "ohånad",
    "ohånat": "ohånad",
    "ohånats": "ohånad",
    "ohårdnade": "ohårdnad",
    "ohårdnades": "ohårdnad",
    "ohårdnads": "ohårdnad",
    "ohårdnat": "ohårdnad",
    "ohårdnats": "ohårdnad",
    "ohåvade": "ohåvad",
    "ohåvades": "ohåvad",
    "ohåvads": "ohåvad",
    "ohåvat": "ohåvad",
    "ohåvats": "ohåvad",
    "ohögaktade": "ohögaktad",
    "ohögaktades": "ohögaktad",
    "ohögaktads": "ohögaktad",
    "ohögaktat": "ohögaktad",
    "ohögaktats": "ohögaktad",
    "ohöjde": "ohöjd",
    "ohöjdes": "ohöjd",
    "ohöjds": "ohöjd",
    "ohöjt": "ohöjd",
    "ohöjts": "ohöjd",
    "ohöljda": "ohöljd",
    "ohöljdare": "ohöljd",
    "ohöljdares": "ohöljd",
    "ohöljdas": "ohöljd",
    "ohöljdast": "ohöljd",
    "ohöljdaste": "ohöljd",
    "ohöljdastes": "ohöljd",
    "ohöljdasts": "ohöljd",
    "ohöljde": "ohöljd",
    "ohöljdes": "ohöljd",
    "ohöljdheten": "ohöljdhet",
    "ohöljdhetens": "ohöljdhet",
    "ohöljdhets": "ohöljdhet",
    "ohöljds": "ohöljd",
    "ohöljt": "ohöljd",
    "ohöljts": "ohöljd",
    "ohörbara": "ohörbar",
    "ohörbarare": "ohörbar",
    "ohörbarares": "ohörbar",
    "ohörbaras": "ohörbar",
    "ohörbarast": "ohörbar",
    "ohörbaraste": "ohörbar",
    "ohörbarastes": "ohörbar",
    "ohörbarasts": "ohörbar",
    "ohörbare": "ohörbar",
    "ohörbares": "ohörbar",
    "ohörbarheten": "ohörbarhet",
    "ohörbarhetens": "ohörbarhet",
    "ohörbarheter": "ohörbarhet",
    "ohörbarheterna": "ohörbarhet",
    "ohörbarheternas": "ohörbarhet",
    "ohörbarheters": "ohörbarhet",
    "ohörbarhets": "ohörbarhet",
    "ohörbars": "ohörbar",
    "ohörbart": "ohörbar",
    "ohörbarts": "ohörbar",
    "ohörda": "ohörd",
    "ohördare": "ohörd",
    "ohördares": "ohörd",
    "ohördas": "ohörd",
    "ohördast": "ohörd",
    "ohördaste": "ohörd",
    "ohördastes": "ohörd",
    "ohördasts": "ohörd",
    "ohörde": "ohörd",
    "ohördes": "ohörd",
    "ohörds": "ohörd",
    "ohörsamheten": "ohörsamhet",
    "ohörsamhetens": "ohörsamhet",
    "ohörsamhets": "ohörsamhet",
    "ohörsamma": "ohörsam",
    "ohörsammade": "ohörsammad",
    "ohörsammades": "ohörsammad",
    "ohörsammads": "ohörsammad",
    "ohörsammare": "ohörsam",
    "ohörsammares": "ohörsam",
    "ohörsammas": "ohörsam",
    "ohörsammast": "ohörsam",
    "ohörsammaste": "ohörsam",
    "ohörsammastes": "ohörsam",
    "ohörsammasts": "ohörsam",
    "ohörsammat": "ohörsammad",
    "ohörsammats": "ohörsammad",
    "ohörsamme": "ohörsam",
    "ohörsammes": "ohörsam",
    "ohörsams": "ohörsam",
    "ohörsamt": "ohörsam",
    "ohörsamts": "ohörsam",
    "ohört": "ohörd",
    "ohörts": "ohörd",
    "ohövliga": "ohövlig",
    "ohövligare": "ohövlig",
    "ohövligares": "ohövlig",
    "ohövligas": "ohövlig",
    "ohövligast": "ohövlig",
    "ohövligaste": "ohövlig",
    "ohövligastes": "ohövlig",
    "ohövligasts": "ohövlig",
    "ohövlige": "ohövlig",
    "ohövliges": "ohövlig",
    "ohövligheten": "ohövlighet",
    "ohövlighetens": "ohövlighet",
    "ohövlighets": "ohövlighet",
    "ohövligs": "ohövlig",
    "ohövligt": "ohövlig",
    "ohövligts": "ohövlig",
    "oidealiserade": "oidealiserad",
    "oidealiserades": "oidealiserad",
    "oidealiserads": "oidealiserad",
    "oidealiserat": "oidealiserad",
    "oidealiserats": "oidealiserad",
    "oidealiserbara": "oidealiserbar",
    "oidealiserbarare": "oidealiserbar",
    "oidealiserbarares": "oidealiserbar",
    "oidealiserbaras": "oidealiserbar",
    "oidealiserbarast": "oidealiserbar",
    "oidealiserbaraste": "oidealiserbar",
    "oidealiserbarastes": "oidealiserbar",
    "oidealiserbarasts": "oidealiserbar",
    "oidealiserbare": "oidealiserbar",
    "oidealiserbares": "oidealiserbar",
    "oidealiserbarheten": "oidealiserbarhet",
    "oidealiserbarhetens": "oidealiserbarhet",
    "oidealiserbarhets": "oidealiserbarhet",
    "oidealiserbars": "oidealiserbar",
    "oidealiserbart": "oidealiserbar",
    "oidealiserbarts": "oidealiserbar",
    "oidentifierade": "oidentifierad",
    "oidentifierades": "oidentifierad",
    "oidentifierads": "oidentifierad",
    "oidentifierat": "oidentifierad",
    "oidentifierats": "oidentifierad",
    "oidentifierbara": "oidentifierbar",
    "oidentifierbarare": "oidentifierbar",
    "oidentifierbarares": "oidentifierbar",
    "oidentifierbaras": "oidentifierbar",
    "oidentifierbarast": "oidentifierbar",
    "oidentifierbaraste": "oidentifierbar",
    "oidentifierbarastes": "oidentifierbar",
    "oidentifierbarasts": "oidentifierbar",
    "oidentifierbare": "oidentifierbar",
    "oidentifierbares": "oidentifierbar",
    "oidentifierbarheten": "oidentifierbarhet",
    "oidentifierbarhetens": "oidentifierbarhet",
    "oidentifierbarhets": "oidentifierbarhet",
    "oidentifierbars": "oidentifierbar",
    "oidentifierbart": "oidentifierbar",
    "oidentifierbarts": "oidentifierbar",
    "oidipuskomplexet": "oidipuskomplex",
    "oidipuskomplexets": "oidipuskomplex",
    "oidisslade": "oidisslad",
    "oidisslades": "oidisslad",
    "oidisslads": "oidisslad",
    "oidisslat": "oidisslad",
    "oidisslats": "oidisslad",
    "oidkade": "oidkad",
    "oidkades": "oidkad",
    "oidkads": "oidkad",
    "oidkat": "oidkad",
    "oidkats": "oidkad",
    "oigenkännliga": "oigenkännlig",
    "oigenkännligare": "oigenkännlig",
    "oigenkännligares": "oigenkännlig",
    "oigenkännligas": "oigenkännlig",
    "oigenkännligast": "oigenkännlig",
    "oigenkännligaste": "oigenkännlig",
    "oigenkännligastes": "oigenkännlig",
    "oigenkännligasts": "oigenkännlig",
    "oigenkännlige": "oigenkännlig",
    "oigenkännliges": "oigenkännlig",
    "oigenkännligheten": "oigenkännlighet",
    "oigenkännlighetens": "oigenkännlighet",
    "oigenkännlighets": "oigenkännlighet",
    "oigenkännligs": "oigenkännlig",
    "oigenkännligt": "oigenkännlig",
    "oigenkännligts": "oigenkännlig",
    "oignorerade": "oignorerad",
    "oignorerades": "oignorerad",
    "oignorerads": "oignorerad",
    "oignorerat": "oignorerad",
    "oignorerats": "oignorerad",
    "oignorerbara": "oignorerbar",
    "oignorerbarare": "oignorerbar",
    "oignorerbarares": "oignorerbar",
    "oignorerbaras": "oignorerbar",
    "oignorerbarast": "oignorerbar",
    "oignorerbaraste": "oignorerbar",
    "oignorerbarastes": "oignorerbar",
    "oignorerbarasts": "oignorerbar",
    "oignorerbare": "oignorerbar",
    "oignorerbares": "oignorerbar",
    "oignorerbarheten": "oignorerbarhet",
    "oignorerbarhetens": "oignorerbarhet",
    "oignorerbarhets": "oignorerbarhet",
    "oignorerbars": "oignorerbar",
    "oignorerbart": "oignorerbar",
    "oignorerbarts": "oignorerbar",
    "oilluminerade": "oilluminerad",
    "oilluminerades": "oilluminerad",
    "oilluminerads": "oilluminerad",
    "oilluminerat": "oilluminerad",
    "oilluminerats": "oilluminerad",
    "oilluminerbara": "oilluminerbar",
    "oilluminerbarare": "oilluminerbar",
    "oilluminerbarares": "oilluminerbar",
    "oilluminerbaras": "oilluminerbar",
    "oilluminerbarast": "oilluminerbar",
    "oilluminerbaraste": "oilluminerbar",
    "oilluminerbarastes": "oilluminerbar",
    "oilluminerbarasts": "oilluminerbar",
    "oilluminerbare": "oilluminerbar",
    "oilluminerbares": "oilluminerbar",
    "oilluminerbarheten": "oilluminerbarhet",
    "oilluminerbarhetens": "oilluminerbarhet",
    "oilluminerbarhets": "oilluminerbarhet",
    "oilluminerbars": "oilluminerbar",
    "oilluminerbart": "oilluminerbar",
    "oilluminerbarts": "oilluminerbar",
    "oillustrerade": "oillustrerad",
    "oillustrerades": "oillustrerad",
    "oillustrerads": "oillustrerad",
    "oillustrerat": "oillustrerad",
    "oillustrerats": "oillustrerad",
    "oillustrerbara": "oillustrerbar",
    "oillustrerbarare": "oillustrerbar",
    "oillustrerbarares": "oillustrerbar",
    "oillustrerbaras": "oillustrerbar",
    "oillustrerbarast": "oillustrerbar",
    "oillustrerbaraste": "oillustrerbar",
    "oillustrerbarastes": "oillustrerbar",
    "oillustrerbarasts": "oillustrerbar",
    "oillustrerbare": "oillustrerbar",
    "oillustrerbares": "oillustrerbar",
    "oillustrerbarheten": "oillustrerbarhet",
    "oillustrerbarhetens": "oillustrerbarhet",
    "oillustrerbarhets": "oillustrerbarhet",
    "oillustrerbars": "oillustrerbar",
    "oillustrerbart": "oillustrerbar",
    "oillustrerbarts": "oillustrerbar",
    "oimiterade": "oimiterad",
    "oimiterades": "oimiterad",
    "oimiterads": "oimiterad",
    "oimiterat": "oimiterad",
    "oimiterats": "oimiterad",
    "oimiterbara": "oimiterbar",
    "oimiterbarare": "oimiterbar",
    "oimiterbarares": "oimiterbar",
    "oimiterbaras": "oimiterbar",
    "oimiterbarast": "oimiterbar",
    "oimiterbaraste": "oimiterbar",
    "oimiterbarastes": "oimiterbar",
    "oimiterbarasts": "oimiterbar",
    "oimiterbare": "oimiterbar",
    "oimiterbares": "oimiterbar",
    "oimiterbarheten": "oimiterbarhet",
    "oimiterbarhetens": "oimiterbarhet",
    "oimiterbarhets": "oimiterbarhet",
    "oimiterbars": "oimiterbar",
    "oimiterbart": "oimiterbar",
    "oimiterbarts": "oimiterbar",
    "oimmatrikulerade": "oimmatrikulerad",
    "oimmatrikulerades": "oimmatrikulerad",
    "oimmatrikulerads": "oimmatrikulerad",
    "oimmatrikulerat": "oimmatrikulerad",
    "oimmatrikulerats": "oimmatrikulerad",
    "oimmatrikulerbara": "oimmatrikulerbar",
    "oimmatrikulerbarare": "oimmatrikulerbar",
    "oimmatrikulerbarares": "oimmatrikulerbar",
    "oimmatrikulerbaras": "oimmatrikulerbar",
    "oimmatrikulerbarast": "oimmatrikulerbar",
    "oimmatrikulerbaraste": "oimmatrikulerbar",
    "oimmatrikulerbarastes": "oimmatrikulerbar",
    "oimmatrikulerbarasts": "oimmatrikulerbar",
    "oimmatrikulerbare": "oimmatrikulerbar",
    "oimmatrikulerbares": "oimmatrikulerbar",
    "oimmatrikulerbarheten": "oimmatrikulerbarhet",
    "oimmatrikulerbarhetens": "oimmatrikulerbarhet",
    "oimmatrikulerbarhets": "oimmatrikulerbarhet",
    "oimmatrikulerbars": "oimmatrikulerbar",
    "oimmatrikulerbart": "oimmatrikulerbar",
    "oimmatrikulerbarts": "oimmatrikulerbar",
    "oimmigrerade": "oimmigrerad",
    "oimmigrerades": "oimmigrerad",
    "oimmigrerads": "oimmigrerad",
    "oimmigrerat": "oimmigrerad",
    "oimmigrerats": "oimmigrerad",
    "oimmigrerbara": "oimmigrerbar",
    "oimmigrerbarare": "oimmigrerbar",
    "oimmigrerbarares": "oimmigrerbar",
    "oimmigrerbaras": "oimmigrerbar",
    "oimmigrerbarast": "oimmigrerbar",
    "oimmigrerbaraste": "oimmigrerbar",
    "oimmigrerbarastes": "oimmigrerbar",
    "oimmigrerbarasts": "oimmigrerbar",
    "oimmigrerbare": "oimmigrerbar",
    "oimmigrerbares": "oimmigrerbar",
    "oimmigrerbarheten": "oimmigrerbarhet",
    "oimmigrerbarhetens": "oimmigrerbarhet",
    "oimmigrerbarhets": "oimmigrerbarhet",
    "oimmigrerbars": "oimmigrerbar",
    "oimmigrerbart": "oimmigrerbar",
    "oimmigrerbarts": "oimmigrerbar",
    "oimmuniserade": "oimmuniserad",
    "oimmuniserades": "oimmuniserad",
    "oimmuniserads": "oimmuniserad",
    "oimmuniserat": "oimmuniserad",
    "oimmuniserats": "oimmuniserad",
    "oimmuniserbara": "oimmuniserbar",
    "oimmuniserbarare": "oimmuniserbar",
    "oimmuniserbarares": "oimmuniserbar",
    "oimmuniserbaras": "oimmuniserbar",
    "oimmuniserbarast": "oimmuniserbar",
    "oimmuniserbaraste": "oimmuniserbar",
    "oimmuniserbarastes": "oimmuniserbar",
    "oimmuniserbarasts": "oimmuniserbar",
    "oimmuniserbare": "oimmuniserbar",
    "oimmuniserbares": "oimmuniserbar",
    "oimmuniserbarheten": "oimmuniserbarhet",
    "oimmuniserbarhetens": "oimmuniserbarhet",
    "oimmuniserbarhets": "oimmuniserbarhet",
    "oimmuniserbars": "oimmuniserbar",
    "oimmuniserbart": "oimmuniserbar",
    "oimmuniserbarts": "oimmuniserbar",
    "oimpade": "oimpad",
    "oimpades": "oimpad",
    "oimpads": "oimpad",
    "oimpat": "oimpad",
    "oimpats": "oimpad",
    "oimplanterade": "oimplanterad",
    "oimplanterades": "oimplanterad",
    "oimplanterads": "oimplanterad",
    "oimplanterat": "oimplanterad",
    "oimplanterats": "oimplanterad",
    "oimplanterbara": "oimplanterbar",
    "oimplanterbarare": "oimplanterbar",
    "oimplanterbarares": "oimplanterbar",
    "oimplanterbaras": "oimplanterbar",
    "oimplanterbarast": "oimplanterbar",
    "oimplanterbaraste": "oimplanterbar",
    "oimplanterbarastes": "oimplanterbar",
    "oimplanterbarasts": "oimplanterbar",
    "oimplanterbare": "oimplanterbar",
    "oimplanterbares": "oimplanterbar",
    "oimplanterbarheten": "oimplanterbarhet",
    "oimplanterbarhetens": "oimplanterbarhet",
    "oimplanterbarhets": "oimplanterbarhet",
    "oimplanterbars": "oimplanterbar",
    "oimplanterbart": "oimplanterbar",
    "oimplanterbarts": "oimplanterbar",
    "oimplicerade": "oimplicerad",
    "oimplicerades": "oimplicerad",
    "oimplicerads": "oimplicerad",
    "oimplicerat": "oimplicerad",
    "oimplicerats": "oimplicerad",
    "oimplicerbara": "oimplicerbar",
    "oimplicerbarare": "oimplicerbar",
    "oimplicerbarares": "oimplicerbar",
    "oimplicerbaras": "oimplicerbar",
    "oimplicerbarast": "oimplicerbar",
    "oimplicerbaraste": "oimplicerbar",
    "oimplicerbarastes": "oimplicerbar",
    "oimplicerbarasts": "oimplicerbar",
    "oimplicerbare": "oimplicerbar",
    "oimplicerbares": "oimplicerbar",
    "oimplicerbarheten": "oimplicerbarhet",
    "oimplicerbarhetens": "oimplicerbarhet",
    "oimplicerbarhets": "oimplicerbarhet",
    "oimplicerbars": "oimplicerbar",
    "oimplicerbart": "oimplicerbar",
    "oimplicerbarts": "oimplicerbar",
    "oimploderade": "oimploderad",
    "oimploderades": "oimploderad",
    "oimploderads": "oimploderad",
    "oimploderat": "oimploderad",
    "oimploderats": "oimploderad",
    "oimploderbara": "oimploderbar",
    "oimploderbarare": "oimploderbar",
    "oimploderbarares": "oimploderbar",
    "oimploderbaras": "oimploderbar",
    "oimploderbarast": "oimploderbar",
    "oimploderbaraste": "oimploderbar",
    "oimploderbarastes": "oimploderbar",
    "oimploderbarasts": "oimploderbar",
    "oimploderbare": "oimploderbar",
    "oimploderbares": "oimploderbar",
    "oimploderbarheten": "oimploderbarhet",
    "oimploderbarhetens": "oimploderbarhet",
    "oimploderbarhets": "oimploderbarhet",
    "oimploderbars": "oimploderbar",
    "oimploderbart": "oimploderbar",
    "oimploderbarts": "oimploderbar",
    "oimponerade": "oimponerad",
    "oimponerades": "oimponerad",
    "oimponerads": "oimponerad",
    "oimponerat": "oimponerad",
    "oimponerats": "oimponerad",
    "oimponerbara": "oimponerbar",
    "oimponerbarare": "oimponerbar",
    "oimponerbarares": "oimponerbar",
    "oimponerbaras": "oimponerbar",
    "oimponerbarast": "oimponerbar",
    "oimponerbaraste": "oimponerbar",
    "oimponerbarastes": "oimponerbar",
    "oimponerbarasts": "oimponerbar",
    "oimponerbare": "oimponerbar",
    "oimponerbares": "oimponerbar",
    "oimponerbarheten": "oimponerbarhet",
    "oimponerbarhetens": "oimponerbarhet",
    "oimponerbarhets": "oimponerbarhet",
    "oimponerbars": "oimponerbar",
    "oimponerbart": "oimponerbar",
    "oimponerbarts": "oimponerbar",
    "oimporterade": "oimporterad",
    "oimporterades": "oimporterad",
    "oimporterads": "oimporterad",
    "oimporterat": "oimporterad",
    "oimporterats": "oimporterad",
    "oimporterbara": "oimporterbar",
    "oimporterbarare": "oimporterbar",
    "oimporterbarares": "oimporterbar",
    "oimporterbaras": "oimporterbar",
    "oimporterbarast": "oimporterbar",
    "oimporterbaraste": "oimporterbar",
    "oimporterbarastes": "oimporterbar",
    "oimporterbarasts": "oimporterbar",
    "oimporterbare": "oimporterbar",
    "oimporterbares": "oimporterbar",
    "oimporterbarheten": "oimporterbarhet",
    "oimporterbarhetens": "oimporterbarhet",
    "oimporterbarhets": "oimporterbarhet",
    "oimporterbars": "oimporterbar",
    "oimporterbart": "oimporterbar",
    "oimporterbarts": "oimporterbar",
    "oimpregnerade": "oimpregnerad",
    "oimpregnerades": "oimpregnerad",
    "oimpregnerads": "oimpregnerad",
    "oimpregnerat": "oimpregnerad",
    "oimpregnerats": "oimpregnerad",
    "oimpregnerbara": "oimpregnerbar",
    "oimpregnerbarare": "oimpregnerbar",
    "oimpregnerbarares": "oimpregnerbar",
    "oimpregnerbaras": "oimpregnerbar",
    "oimpregnerbarast": "oimpregnerbar",
    "oimpregnerbaraste": "oimpregnerbar",
    "oimpregnerbarastes": "oimpregnerbar",
    "oimpregnerbarasts": "oimpregnerbar",
    "oimpregnerbare": "oimpregnerbar",
    "oimpregnerbares": "oimpregnerbar",
    "oimpregnerbarheten": "oimpregnerbarhet",
    "oimpregnerbarhetens": "oimpregnerbarhet",
    "oimpregnerbarhets": "oimpregnerbarhet",
    "oimpregnerbars": "oimpregnerbar",
    "oimpregnerbart": "oimpregnerbar",
    "oimpregnerbarts": "oimpregnerbar",
    "oimproviserade": "oimproviserad",
    "oimproviserades": "oimproviserad",
    "oimproviserads": "oimproviserad",
    "oimproviserat": "oimproviserad",
    "oimproviserats": "oimproviserad",
    "oimproviserbara": "oimproviserbar",
    "oimproviserbarare": "oimproviserbar",
    "oimproviserbarares": "oimproviserbar",
    "oimproviserbaras": "oimproviserbar",
    "oimproviserbarast": "oimproviserbar",
    "oimproviserbaraste": "oimproviserbar",
    "oimproviserbarastes": "oimproviserbar",
    "oimproviserbarasts": "oimproviserbar",
    "oimproviserbare": "oimproviserbar",
    "oimproviserbares": "oimproviserbar",
    "oimproviserbarheten": "oimproviserbarhet",
    "oimproviserbarhetens": "oimproviserbarhet",
    "oimproviserbarhets": "oimproviserbarhet",
    "oimproviserbars": "oimproviserbar",
    "oimproviserbart": "oimproviserbar",
    "oimproviserbarts": "oimproviserbar",
    "oinackorderade": "oinackorderad",
    "oinackorderades": "oinackorderad",
    "oinackorderads": "oinackorderad",
    "oinackorderat": "oinackorderad",
    "oinackorderats": "oinackorderad",
    "oinackorderbara": "oinackorderbar",
    "oinackorderbarare": "oinackorderbar",
    "oinackorderbarares": "oinackorderbar",
    "oinackorderbaras": "oinackorderbar",
    "oinackorderbarast": "oinackorderbar",
    "oinackorderbaraste": "oinackorderbar",
    "oinackorderbarastes": "oinackorderbar",
    "oinackorderbarasts": "oinackorderbar",
    "oinackorderbare": "oinackorderbar",
    "oinackorderbares": "oinackorderbar",
    "oinackorderbarheten": "oinackorderbarhet",
    "oinackorderbarhetens": "oinackorderbarhet",
    "oinackorderbarhets": "oinackorderbarhet",
    "oinackorderbars": "oinackorderbar",
    "oinackorderbart": "oinackorderbar",
    "oinackorderbarts": "oinackorderbar",
    "oinarbetade": "oinarbetad",
    "oinarbetades": "oinarbetad",
    "oinarbetads": "oinarbetad",
    "oinarbetat": "oinarbetad",
    "oinarbetats": "oinarbetad",
    "oinaugurerade": "oinaugurerad",
    "oinaugurerades": "oinaugurerad",
    "oinaugurerads": "oinaugurerad",
    "oinaugurerat": "oinaugurerad",
    "oinaugurerats": "oinaugurerad",
    "oinaugurerbara": "oinaugurerbar",
    "oinaugurerbarare": "oinaugurerbar",
    "oinaugurerbarares": "oinaugurerbar",
    "oinaugurerbaras": "oinaugurerbar",
    "oinaugurerbarast": "oinaugurerbar",
    "oinaugurerbaraste": "oinaugurerbar",
    "oinaugurerbarastes": "oinaugurerbar",
    "oinaugurerbarasts": "oinaugurerbar",
    "oinaugurerbare": "oinaugurerbar",
    "oinaugurerbares": "oinaugurerbar",
    "oinaugurerbarheten": "oinaugurerbarhet",
    "oinaugurerbarhetens": "oinaugurerbarhet",
    "oinaugurerbarhets": "oinaugurerbarhet",
    "oinaugurerbars": "oinaugurerbar",
    "oinaugurerbart": "oinaugurerbar",
    "oinaugurerbarts": "oinaugurerbar",
    "oinbakade": "oinbakad",
    "oinbakades": "oinbakad",
    "oinbakads": "oinbakad",
    "oinbakat": "oinbakad",
    "oinbakats": "oinbakad",
    "oinberäknade": "oinberäknad",
    "oinberäknades": "oinberäknad",
    "oinberäknads": "oinberäknad",
    "oinberäknat": "oinberäknad",
    "oinberäknats": "oinberäknad",
    "oinbesparade": "oinbesparad",
    "oinbesparades": "oinbesparad",
    "oinbesparads": "oinbesparad",
    "oinbesparat": "oinbesparad",
    "oinbesparats": "oinbesparad",
    "oinbillade": "oinbillad",
    "oinbillades": "oinbillad",
    "oinbillads": "oinbillad",
    "oinbillat": "oinbillad",
    "oinbillats": "oinbillad",
    "oinblandade": "oinblandad",
    "oinblandades": "oinblandad",
    "oinblandads": "oinblandad",
    "oinblandat": "oinblandad",
    "oinblandats": "oinblandad",
    "oinbundens": "oinbunden",
    "oinbundet": "oinbunden",
    "oinbundets": "oinbunden",
    "oinbundna": "oinbunden",
    "oinbundnare": "oinbunden",
    "oinbundnares": "oinbunden",
    "oinbundnas": "oinbunden",
    "oinbundnast": "oinbunden",
    "oinbundnaste": "oinbunden",
    "oinbundnastes": "oinbunden",
    "oinbundnasts": "oinbunden",
    "oinbundne": "oinbunden",
    "oinbundnes": "oinbunden",
    "oinbyggde": "oinbyggd",
    "oinbyggdes": "oinbyggd",
    "oinbyggds": "oinbyggd",
    "oinbyggt": "oinbyggd",
    "oinbyggts": "oinbyggd",
    "oindelade": "oindelad",
    "oindelades": "oindelad",
    "oindelads": "oindelad",
    "oindelat": "oindelad",
    "oindelats": "oindelad",
    "oindexerade": "oindexerad",
    "oindexerades": "oindexerad",
    "oindexerads": "oindexerad",
    "oindexerat": "oindexerad",
    "oindexerats": "oindexerad",
    "oindexerbara": "oindexerbar",
    "oindexerbarare": "oindexerbar",
    "oindexerbarares": "oindexerbar",
    "oindexerbaras": "oindexerbar",
    "oindexerbarast": "oindexerbar",
    "oindexerbaraste": "oindexerbar",
    "oindexerbarastes": "oindexerbar",
    "oindexerbarasts": "oindexerbar",
    "oindexerbare": "oindexerbar",
    "oindexerbares": "oindexerbar",
    "oindexerbarheten": "oindexerbarhet",
    "oindexerbarhetens": "oindexerbarhet",
    "oindexerbarhets": "oindexerbarhet",
    "oindexerbars": "oindexerbar",
    "oindexerbart": "oindexerbar",
    "oindexerbarts": "oindexerbar",
    "oindexreglerbara": "oindexreglerbar",
    "oindexreglerbarare": "oindexreglerbar",
    "oindexreglerbarares": "oindexreglerbar",
    "oindexreglerbaras": "oindexreglerbar",
    "oindexreglerbarast": "oindexreglerbar",
    "oindexreglerbaraste": "oindexreglerbar",
    "oindexreglerbarastes": "oindexreglerbar",
    "oindexreglerbarasts": "oindexreglerbar",
    "oindexreglerbare": "oindexreglerbar",
    "oindexreglerbares": "oindexreglerbar",
    "oindexreglerbarheten": "oindexreglerbarhet",
    "oindexreglerbarhetens": "oindexreglerbarhet",
    "oindexreglerbarhets": "oindexreglerbarhet",
    "oindexreglerbars": "oindexreglerbar",
    "oindexreglerbart": "oindexreglerbar",
    "oindexreglerbarts": "oindexreglerbar",
    "oindicerade": "oindicerad",
    "oindicerades": "oindicerad",
    "oindicerads": "oindicerad",
    "oindicerat": "oindicerad",
    "oindicerats": "oindicerad",
    "oindicerbara": "oindicerbar",
    "oindicerbarare": "oindicerbar",
    "oindicerbarares": "oindicerbar",
    "oindicerbaras": "oindicerbar",
    "oindicerbarast": "oindicerbar",
    "oindicerbaraste": "oindicerbar",
    "oindicerbarastes": "oindicerbar",
    "oindicerbarasts": "oindicerbar",
    "oindicerbare": "oindicerbar",
    "oindicerbares": "oindicerbar",
    "oindicerbarheten": "oindicerbarhet",
    "oindicerbarhetens": "oindicerbarhet",
    "oindicerbarhets": "oindicerbarhet",
    "oindicerbars": "oindicerbar",
    "oindicerbart": "oindicerbar",
    "oindicerbarts": "oindicerbar",
    "oindikerade": "oindikerad",
    "oindikerades": "oindikerad",
    "oindikerads": "oindikerad",
    "oindikerat": "oindikerad",
    "oindikerats": "oindikerad",
    "oindikerbara": "oindikerbar",
    "oindikerbarare": "oindikerbar",
    "oindikerbarares": "oindikerbar",
    "oindikerbaras": "oindikerbar",
    "oindikerbarast": "oindikerbar",
    "oindikerbaraste": "oindikerbar",
    "oindikerbarastes": "oindikerbar",
    "oindikerbarasts": "oindikerbar",
    "oindikerbare": "oindikerbar",
    "oindikerbares": "oindikerbar",
    "oindikerbarheten": "oindikerbarhet",
    "oindikerbarhetens": "oindikerbarhet",
    "oindikerbarhets": "oindikerbarhet",
    "oindikerbars": "oindikerbar",
    "oindikerbart": "oindikerbar",
    "oindikerbarts": "oindikerbar",
    "oindividualiserade": "oindividualiserad",
    "oindividualiserades": "oindividualiserad",
    "oindividualiserads": "oindividualiserad",
    "oindividualiserat": "oindividualiserad",
    "oindividualiserats": "oindividualiserad",
    "oindividualiserbara": "oindividualiserbar",
    "oindividualiserbarare": "oindividualiserbar",
    "oindividualiserbarares": "oindividualiserbar",
    "oindividualiserbaras": "oindividualiserbar",
    "oindividualiserbarast": "oindividualiserbar",
    "oindividualiserbaraste": "oindividualiserbar",
    "oindividualiserbarastes": "oindividualiserbar",
    "oindividualiserbarasts": "oindividualiserbar",
    "oindividualiserbare": "oindividualiserbar",
    "oindividualiserbares": "oindividualiserbar",
    "oindividualiserbarheten": "oindividualiserbarhet",
    "oindividualiserbarhetens": "oindividualiserbarhet",
    "oindividualiserbarhets": "oindividualiserbarhet",
    "oindividualiserbars": "oindividualiserbar",
    "oindividualiserbart": "oindividualiserbar",
    "oindividualiserbarts": "oindividualiserbar",
    "oindoktrinerade": "oindoktrinerad",
    "oindoktrinerades": "oindoktrinerad",
    "oindoktrinerads": "oindoktrinerad",
    "oindoktrinerat": "oindoktrinerad",
    "oindoktrinerats": "oindoktrinerad",
    "oindoktrinerbara": "oindoktrinerbar",
    "oindoktrinerbarare": "oindoktrinerbar",
    "oindoktrinerbarares": "oindoktrinerbar",
    "oindoktrinerbaras": "oindoktrinerbar",
    "oindoktrinerbarast": "oindoktrinerbar",
    "oindoktrinerbaraste": "oindoktrinerbar",
    "oindoktrinerbarastes": "oindoktrinerbar",
    "oindoktrinerbarasts": "oindoktrinerbar",
    "oindoktrinerbare": "oindoktrinerbar",
    "oindoktrinerbares": "oindoktrinerbar",
    "oindoktrinerbarheten": "oindoktrinerbarhet",
    "oindoktrinerbarhetens": "oindoktrinerbarhet",
    "oindoktrinerbarhets": "oindoktrinerbarhet",
    "oindoktrinerbars": "oindoktrinerbar",
    "oindoktrinerbart": "oindoktrinerbar",
    "oindoktrinerbarts": "oindoktrinerbar",
    "oindränkta": "oindränkt",
    "oindränktas": "oindränkt",
    "oindränkte": "oindränkt",
    "oindränktes": "oindränkt",
    "oindränkts": "oindränkt",
    "oinducerade": "oinducerad",
    "oinducerades": "oinducerad",
    "oinducerads": "oinducerad",
    "oinducerat": "oinducerad",
    "oinducerats": "oinducerad",
    "oinducerbara": "oinducerbar",
    "oinducerbarare": "oinducerbar",
    "oinducerbarares": "oinducerbar",
    "oinducerbaras": "oinducerbar",
    "oinducerbarast": "oinducerbar",
    "oinducerbaraste": "oinducerbar",
    "oinducerbarastes": "oinducerbar",
    "oinducerbarasts": "oinducerbar",
    "oinducerbare": "oinducerbar",
    "oinducerbares": "oinducerbar",
    "oinducerbarheten": "oinducerbarhet",
    "oinducerbarhetens": "oinducerbarhet",
    "oinducerbarhets": "oinducerbarhet",
    "oinducerbars": "oinducerbar",
    "oinducerbart": "oinducerbar",
    "oinducerbarts": "oinducerbar",
    "oindunstade": "oindunstad",
    "oindunstades": "oindunstad",
    "oindunstads": "oindunstad",
    "oindunstat": "oindunstad",
    "oindunstats": "oindunstad",
    "oindustrialiserade": "oindustrialiserad",
    "oindustrialiserades": "oindustrialiserad",
    "oindustrialiserads": "oindustrialiserad",
    "oindustrialiserat": "oindustrialiserad",
    "oindustrialiserats": "oindustrialiserad",
    "oindustrialiserbara": "oindustrialiserbar",
    "oindustrialiserbarare": "oindustrialiserbar",
    "oindustrialiserbarares": "oindustrialiserbar",
    "oindustrialiserbaras": "oindustrialiserbar",
    "oindustrialiserbarast": "oindustrialiserbar",
    "oindustrialiserbaraste": "oindustrialiserbar",
    "oindustrialiserbarastes": "oindustrialiserbar",
    "oindustrialiserbarasts": "oindustrialiserbar",
    "oindustrialiserbare": "oindustrialiserbar",
    "oindustrialiserbares": "oindustrialiserbar",
    "oindustrialiserbarheten": "oindustrialiserbarhet",
    "oindustrialiserbarhetens": "oindustrialiserbarhet",
    "oindustrialiserbarhets": "oindustrialiserbarhet",
    "oindustrialiserbars": "oindustrialiserbar",
    "oindustrialiserbart": "oindustrialiserbar",
    "oindustrialiserbarts": "oindustrialiserbar",
    "oinfattade": "oinfattad",
    "oinfattades": "oinfattad",
    "oinfattads": "oinfattad",
    "oinfattat": "oinfattad",
    "oinfattats": "oinfattad",
    "oinfekterade": "oinfekterad",
    "oinfekterades": "oinfekterad",
    "oinfekterads": "oinfekterad",
    "oinfekterat": "oinfekterad",
    "oinfekterats": "oinfekterad",
    "oinfekterbara": "oinfekterbar",
    "oinfekterbarare": "oinfekterbar",
    "oinfekterbarares": "oinfekterbar",
    "oinfekterbaras": "oinfekterbar",
    "oinfekterbarast": "oinfekterbar",
    "oinfekterbaraste": "oinfekterbar",
    "oinfekterbarastes": "oinfekterbar",
    "oinfekterbarasts": "oinfekterbar",
    "oinfekterbare": "oinfekterbar",
    "oinfekterbares": "oinfekterbar",
    "oinfekterbarheten": "oinfekterbarhet",
    "oinfekterbarhetens": "oinfekterbarhet",
    "oinfekterbarhets": "oinfekterbarhet",
    "oinfekterbars": "oinfekterbar",
    "oinfekterbart": "oinfekterbar",
    "oinfekterbarts": "oinfekterbar",
    "oinfettade": "oinfettad",
    "oinfettades": "oinfettad",
    "oinfettads": "oinfettad",
    "oinfettat": "oinfettad",
    "oinfettats": "oinfettad",
    "oinfiltrerade": "oinfiltrerad",
    "oinfiltrerades": "oinfiltrerad",
    "oinfiltrerads": "oinfiltrerad",
    "oinfiltrerat": "oinfiltrerad",
    "oinfiltrerats": "oinfiltrerad",
    "oinfiltrerbara": "oinfiltrerbar",
    "oinfiltrerbarare": "oinfiltrerbar",
    "oinfiltrerbarares": "oinfiltrerbar",
    "oinfiltrerbaras": "oinfiltrerbar",
    "oinfiltrerbarast": "oinfiltrerbar",
    "oinfiltrerbaraste": "oinfiltrerbar",
    "oinfiltrerbarastes": "oinfiltrerbar",
    "oinfiltrerbarasts": "oinfiltrerbar",
    "oinfiltrerbare": "oinfiltrerbar",
    "oinfiltrerbares": "oinfiltrerbar",
    "oinfiltrerbarheten": "oinfiltrerbarhet",
    "oinfiltrerbarhetens": "oinfiltrerbarhet",
    "oinfiltrerbarhets": "oinfiltrerbarhet",
    "oinfiltrerbars": "oinfiltrerbar",
    "oinfiltrerbart": "oinfiltrerbar",
    "oinfiltrerbarts": "oinfiltrerbar",
    "oinflammerade": "oinflammerad",
    "oinflammerades": "oinflammerad",
    "oinflammerads": "oinflammerad",
    "oinflammerat": "oinflammerad",
    "oinflammerats": "oinflammerad",
    "oinflammerbara": "oinflammerbar",
    "oinflammerbarare": "oinflammerbar",
    "oinflammerbarares": "oinflammerbar",
    "oinflammerbaras": "oinflammerbar",
    "oinflammerbarast": "oinflammerbar",
    "oinflammerbaraste": "oinflammerbar",
    "oinflammerbarastes": "oinflammerbar",
    "oinflammerbarasts": "oinflammerbar",
    "oinflammerbare": "oinflammerbar",
    "oinflammerbares": "oinflammerbar",
    "oinflammerbarheten": "oinflammerbarhet",
    "oinflammerbarhetens": "oinflammerbarhet",
    "oinflammerbarhets": "oinflammerbarhet",
    "oinflammerbars": "oinflammerbar",
    "oinflammerbart": "oinflammerbar",
    "oinflammerbarts": "oinflammerbar",
    "oinfluerade": "oinfluerad",
    "oinfluerades": "oinfluerad",
    "oinfluerads": "oinfluerad",
    "oinfluerat": "oinfluerad",
    "oinfluerats": "oinfluerad",
    "oinfluerbara": "oinfluerbar",
    "oinfluerbarare": "oinfluerbar",
    "oinfluerbarares": "oinfluerbar",
    "oinfluerbaras": "oinfluerbar",
    "oinfluerbarast": "oinfluerbar",
    "oinfluerbaraste": "oinfluerbar",
    "oinfluerbarastes": "oinfluerbar",
    "oinfluerbarasts": "oinfluerbar",
    "oinfluerbare": "oinfluerbar",
    "oinfluerbares": "oinfluerbar",
    "oinfluerbarheten": "oinfluerbarhet",
    "oinfluerbarhetens": "oinfluerbarhet",
    "oinfluerbarhets": "oinfluerbarhet",
    "oinfluerbars": "oinfluerbar",
    "oinfluerbart": "oinfluerbar",
    "oinfluerbarts": "oinfluerbar",
    "oinflyttade": "oinflyttad",
    "oinflyttades": "oinflyttad",
    "oinflyttads": "oinflyttad",
    "oinflyttat": "oinflyttad",
    "oinflyttats": "oinflyttad",
    "oinflätade": "oinflätad",
    "oinflätades": "oinflätad",
    "oinflätads": "oinflätad",
    "oinflätat": "oinflätad",
    "oinflätats": "oinflätad",
    "oinfodrade": "oinfodrad",
    "oinfodrades": "oinfodrad",
    "oinfodrads": "oinfodrad",
    "oinfodrat": "oinfodrad",
    "oinfodrats": "oinfodrad",
    "oinfogade": "oinfogad",
    "oinfogades": "oinfogad",
    "oinfogads": "oinfogad",
    "oinfogat": "oinfogad",
    "oinfogats": "oinfogad",
    "oinfordrade": "oinfordrad",
    "oinfordrades": "oinfordrad",
    "oinfordrads": "oinfordrad",
    "oinfordrat": "oinfordrad",
    "oinfordrats": "oinfordrad",
    "oinformerade": "oinformerad",
    "oinformerades": "oinformerad",
    "oinformerads": "oinformerad",
    "oinformerat": "oinformerad",
    "oinformerats": "oinformerad",
    "oinformerbara": "oinformerbar",
    "oinformerbarare": "oinformerbar",
    "oinformerbarares": "oinformerbar",
    "oinformerbaras": "oinformerbar",
    "oinformerbarast": "oinformerbar",
    "oinformerbaraste": "oinformerbar",
    "oinformerbarastes": "oinformerbar",
    "oinformerbarasts": "oinformerbar",
    "oinformerbare": "oinformerbar",
    "oinformerbares": "oinformerbar",
    "oinformerbarheten": "oinformerbarhet",
    "oinformerbarhetens": "oinformerbarhet",
    "oinformerbarhets": "oinformerbarhet",
    "oinformerbars": "oinformerbar",
    "oinformerbart": "oinformerbar",
    "oinformerbarts": "oinformerbar",
    "oinfriade": "oinfriad",
    "oinfriades": "oinfriad",
    "oinfriads": "oinfriad",
    "oinfriat": "oinfriad",
    "oinfriats": "oinfriad",
    "oinfångade": "oinfångad",
    "oinfångades": "oinfångad",
    "oinfångads": "oinfångad",
    "oinfångat": "oinfångad",
    "oinfångats": "oinfångad",
    "oinförde": "oinförd",
    "oinfördes": "oinförd",
    "oinförds": "oinförd",
    "oinförlivade": "oinförlivad",
    "oinförlivades": "oinförlivad",
    "oinförlivads": "oinförlivad",
    "oinförlivat": "oinförlivad",
    "oinförlivats": "oinförlivad",
    "oinförskaffade": "oinförskaffad",
    "oinförskaffades": "oinförskaffad",
    "oinförskaffads": "oinförskaffad",
    "oinförskaffat": "oinförskaffad",
    "oinförskaffats": "oinförskaffad",
    "oinfört": "oinförd",
    "oinförts": "oinförd",
    "oingraverade": "oingraverad",
    "oingraverades": "oingraverad",
    "oingraverads": "oingraverad",
    "oingraverat": "oingraverad",
    "oingraverats": "oingraverad",
    "oingraverbara": "oingraverbar",
    "oingraverbarare": "oingraverbar",
    "oingraverbarares": "oingraverbar",
    "oingraverbaras": "oingraverbar",
    "oingraverbarast": "oingraverbar",
    "oingraverbaraste": "oingraverbar",
    "oingraverbarastes": "oingraverbar",
    "oingraverbarasts": "oingraverbar",
    "oingraverbare": "oingraverbar",
    "oingraverbares": "oingraverbar",
    "oingraverbarheten": "oingraverbarhet",
    "oingraverbarhetens": "oingraverbarhet",
    "oingraverbarhets": "oingraverbarhet",
    "oingraverbars": "oingraverbar",
    "oingraverbart": "oingraverbar",
    "oingraverbarts": "oingraverbar",
    "oinhalerade": "oinhalerad",
    "oinhalerades": "oinhalerad",
    "oinhalerads": "oinhalerad",
    "oinhalerat": "oinhalerad",
    "oinhalerats": "oinhalerad",
    "oinhalerbara": "oinhalerbar",
    "oinhalerbarare": "oinhalerbar",
    "oinhalerbarares": "oinhalerbar",
    "oinhalerbaras": "oinhalerbar",
    "oinhalerbarast": "oinhalerbar",
    "oinhalerbaraste": "oinhalerbar",
    "oinhalerbarastes": "oinhalerbar",
    "oinhalerbarasts": "oinhalerbar",
    "oinhalerbare": "oinhalerbar",
    "oinhalerbares": "oinhalerbar",
    "oinhalerbarheten": "oinhalerbarhet",
    "oinhalerbarhetens": "oinhalerbarhet",
    "oinhalerbarhets": "oinhalerbarhet",
    "oinhalerbars": "oinhalerbar",
    "oinhalerbart": "oinhalerbar",
    "oinhalerbarts": "oinhalerbar",
    "oinhandlade": "oinhandlad",
    "oinhandlades": "oinhandlad",
    "oinhandlads": "oinhandlad",
    "oinhandlat": "oinhandlad",
    "oinhandlats": "oinhandlad",
    "oinhiberade": "oinhiberad",
    "oinhiberades": "oinhiberad",
    "oinhiberads": "oinhiberad",
    "oinhiberat": "oinhiberad",
    "oinhiberats": "oinhiberad",
    "oinhiberbara": "oinhiberbar",
    "oinhiberbarare": "oinhiberbar",
    "oinhiberbarares": "oinhiberbar",
    "oinhiberbaras": "oinhiberbar",
    "oinhiberbarast": "oinhiberbar",
    "oinhiberbaraste": "oinhiberbar",
    "oinhiberbarastes": "oinhiberbar",
    "oinhiberbarasts": "oinhiberbar",
    "oinhiberbare": "oinhiberbar",
    "oinhiberbares": "oinhiberbar",
    "oinhiberbarheten": "oinhiberbarhet",
    "oinhiberbarhetens": "oinhiberbarhet",
    "oinhiberbarhets": "oinhiberbarhet",
    "oinhiberbars": "oinhiberbar",
    "oinhiberbart": "oinhiberbar",
    "oinhiberbarts": "oinhiberbar",
    "oinhibiterade": "oinhibiterad",
    "oinhibiterades": "oinhibiterad",
    "oinhibiterads": "oinhibiterad",
    "oinhibiterat": "oinhibiterad",
    "oinhibiterats": "oinhibiterad",
    "oinhibiterbara": "oinhibiterbar",
    "oinhibiterbarare": "oinhibiterbar",
    "oinhibiterbarares": "oinhibiterbar",
    "oinhibiterbaras": "oinhibiterbar",
    "oinhibiterbarast": "oinhibiterbar",
    "oinhibiterbaraste": "oinhibiterbar",
    "oinhibiterbarastes": "oinhibiterbar",
    "oinhibiterbarasts": "oinhibiterbar",
    "oinhibiterbare": "oinhibiterbar",
    "oinhibiterbares": "oinhibiterbar",
    "oinhibiterbarheten": "oinhibiterbarhet",
    "oinhibiterbarhetens": "oinhibiterbarhet",
    "oinhibiterbarhets": "oinhibiterbarhet",
    "oinhibiterbars": "oinhibiterbar",
    "oinhibiterbart": "oinhibiterbar",
    "oinhibiterbarts": "oinhibiterbar",
    "oinhysta": "oinhyst",
    "oinhystas": "oinhyst",
    "oinhyste": "oinhyst",
    "oinhystes": "oinhyst",
    "oinhysts": "oinhyst",
    "oinhägnade": "oinhägnad",
    "oinhägnades": "oinhägnad",
    "oinhägnads": "oinhägnad",
    "oinhägnat": "oinhägnad",
    "oinhägnats": "oinhägnad",
    "oinhämtade": "oinhämtad",
    "oinhämtades": "oinhämtad",
    "oinhämtads": "oinhämtad",
    "oinhämtat": "oinhämtad",
    "oinhämtats": "oinhämtad",
    "oinhöstade": "oinhöstad",
    "oinhöstades": "oinhöstad",
    "oinhöstads": "oinhöstad",
    "oinhöstat": "oinhöstad",
    "oinhöstats": "oinhöstad",
    "oinitierade": "oinitierad",
    "oinitierades": "oinitierad",
    "oinitierads": "oinitierad",
    "oinitierat": "oinitierad",
    "oinitierats": "oinitierad",
    "oinitierbara": "oinitierbar",
    "oinitierbarare": "oinitierbar",
    "oinitierbarares": "oinitierbar",
    "oinitierbaras": "oinitierbar",
    "oinitierbarast": "oinitierbar",
    "oinitierbaraste": "oinitierbar",
    "oinitierbarastes": "oinitierbar",
    "oinitierbarasts": "oinitierbar",
    "oinitierbare": "oinitierbar",
    "oinitierbares": "oinitierbar",
    "oinitierbarheten": "oinitierbarhet",
    "oinitierbarhetens": "oinitierbarhet",
    "oinitierbarhets": "oinitierbarhet",
    "oinitierbars": "oinitierbar",
    "oinitierbart": "oinitierbar",
    "oinitierbarts": "oinitierbar",
    "oinjagade": "oinjagad",
    "oinjagades": "oinjagad",
    "oinjagads": "oinjagad",
    "oinjagat": "oinjagad",
    "oinjagats": "oinjagad",
    "oinjekterade": "oinjekterad",
    "oinjekterades": "oinjekterad",
    "oinjekterads": "oinjekterad",
    "oinjekterat": "oinjekterad",
    "oinjekterats": "oinjekterad",
    "oinjekterbara": "oinjekterbar",
    "oinjekterbarare": "oinjekterbar",
    "oinjekterbarares": "oinjekterbar",
    "oinjekterbaras": "oinjekterbar",
    "oinjekterbarast": "oinjekterbar",
    "oinjekterbaraste": "oinjekterbar",
    "oinjekterbarastes": "oinjekterbar",
    "oinjekterbarasts": "oinjekterbar",
    "oinjekterbare": "oinjekterbar",
    "oinjekterbares": "oinjekterbar",
    "oinjekterbarheten": "oinjekterbarhet",
    "oinjekterbarhetens": "oinjekterbarhet",
    "oinjekterbarhets": "oinjekterbarhet",
    "oinjekterbars": "oinjekterbar",
    "oinjekterbart": "oinjekterbar",
    "oinjekterbarts": "oinjekterbar",
    "oinjicerade": "oinjicerad",
    "oinjicerades": "oinjicerad",
    "oinjicerads": "oinjicerad",
    "oinjicerat": "oinjicerad",
    "oinjicerats": "oinjicerad",
    "oinjicerbara": "oinjicerbar",
    "oinjicerbarare": "oinjicerbar",
    "oinjicerbarares": "oinjicerbar",
    "oinjicerbaras": "oinjicerbar",
    "oinjicerbarast": "oinjicerbar",
    "oinjicerbaraste": "oinjicerbar",
    "oinjicerbarastes": "oinjicerbar",
    "oinjicerbarasts": "oinjicerbar",
    "oinjicerbare": "oinjicerbar",
    "oinjicerbares": "oinjicerbar",
    "oinjicerbarheten": "oinjicerbarhet",
    "oinjicerbarhetens": "oinjicerbarhet",
    "oinjicerbarhets": "oinjicerbarhet",
    "oinjicerbars": "oinjicerbar",
    "oinjicerbart": "oinjicerbar",
    "oinjicerbarts": "oinjicerbar",
    "oinkallade": "oinkallad",
    "oinkallades": "oinkallad",
    "oinkallads": "oinkallad",
    "oinkallat": "oinkallad",
    "oinkallats": "oinkallad",
    "oinkapslade": "oinkapslad",
    "oinkapslades": "oinkapslad",
    "oinkapslads": "oinkapslad",
    "oinkapslat": "oinkapslad",
    "oinkapslats": "oinkapslad",
    "oinkarnerade": "oinkarnerad",
    "oinkarnerades": "oinkarnerad",
    "oinkarnerads": "oinkarnerad",
    "oinkarnerat": "oinkarnerad",
    "oinkarnerats": "oinkarnerad",
    "oinkarnerbara": "oinkarnerbar",
    "oinkarnerbarare": "oinkarnerbar",
    "oinkarnerbarares": "oinkarnerbar",
    "oinkarnerbaras": "oinkarnerbar",
    "oinkarnerbarast": "oinkarnerbar",
    "oinkarnerbaraste": "oinkarnerbar",
    "oinkarnerbarastes": "oinkarnerbar",
    "oinkarnerbarasts": "oinkarnerbar",
    "oinkarnerbare": "oinkarnerbar",
    "oinkarnerbares": "oinkarnerbar",
    "oinkarnerbarheten": "oinkarnerbarhet",
    "oinkarnerbarhetens": "oinkarnerbarhet",
    "oinkarnerbarhets": "oinkarnerbarhet",
    "oinkarnerbars": "oinkarnerbar",
    "oinkarnerbart": "oinkarnerbar",
    "oinkarnerbarts": "oinkarnerbar",
    "oinkasserade": "oinkasserad",
    "oinkasserades": "oinkasserad",
    "oinkasserads": "oinkasserad",
    "oinkasserat": "oinkasserad",
    "oinkasserats": "oinkasserad",
    "oinkasserbara": "oinkasserbar",
    "oinkasserbarare": "oinkasserbar",
    "oinkasserbarares": "oinkasserbar",
    "oinkasserbaras": "oinkasserbar",
    "oinkasserbarast": "oinkasserbar",
    "oinkasserbaraste": "oinkasserbar",
    "oinkasserbarastes": "oinkasserbar",
    "oinkasserbarasts": "oinkasserbar",
    "oinkasserbare": "oinkasserbar",
    "oinkasserbares": "oinkasserbar",
    "oinkasserbarheten": "oinkasserbarhet",
    "oinkasserbarhetens": "oinkasserbarhet",
    "oinkasserbarhets": "oinkasserbarhet",
    "oinkasserbars": "oinkasserbar",
    "oinkasserbart": "oinkasserbar",
    "oinkasserbarts": "oinkasserbar",
    "oinklarerade": "oinklarerad",
    "oinklarerades": "oinklarerad",
    "oinklarerads": "oinklarerad",
    "oinklarerat": "oinklarerad",
    "oinklarerats": "oinklarerad",
    "oinklarerbara": "oinklarerbar",
    "oinklarerbarare": "oinklarerbar",
    "oinklarerbarares": "oinklarerbar",
    "oinklarerbaras": "oinklarerbar",
    "oinklarerbarast": "oinklarerbar",
    "oinklarerbaraste": "oinklarerbar",
    "oinklarerbarastes": "oinklarerbar",
    "oinklarerbarasts": "oinklarerbar",
    "oinklarerbare": "oinklarerbar",
    "oinklarerbares": "oinklarerbar",
    "oinklarerbarheten": "oinklarerbarhet",
    "oinklarerbarhetens": "oinklarerbarhet",
    "oinklarerbarhets": "oinklarerbarhet",
    "oinklarerbars": "oinklarerbar",
    "oinklarerbart": "oinklarerbar",
    "oinklarerbarts": "oinklarerbar",
    "oinkluderade": "oinkluderad",
    "oinkluderades": "oinkluderad",
    "oinkluderads": "oinkluderad",
    "oinkluderat": "oinkluderad",
    "oinkluderats": "oinkluderad",
    "oinkluderbara": "oinkluderbar",
    "oinkluderbarare": "oinkluderbar",
    "oinkluderbarares": "oinkluderbar",
    "oinkluderbaras": "oinkluderbar",
    "oinkluderbarast": "oinkluderbar",
    "oinkluderbaraste": "oinkluderbar",
    "oinkluderbarastes": "oinkluderbar",
    "oinkluderbarasts": "oinkluderbar",
    "oinkluderbare": "oinkluderbar",
    "oinkluderbares": "oinkluderbar",
    "oinkluderbarheten": "oinkluderbarhet",
    "oinkluderbarhetens": "oinkluderbarhet",
    "oinkluderbarhets": "oinkluderbarhet",
    "oinkluderbars": "oinkluderbar",
    "oinkluderbart": "oinkluderbar",
    "oinkluderbarts": "oinkluderbar",
    "oinkopplade": "oinkopplad",
    "oinkopplades": "oinkopplad",
    "oinkopplads": "oinkopplad",
    "oinkopplat": "oinkopplad",
    "oinkopplats": "oinkopplad",
    "oinkorporerade": "oinkorporerad",
    "oinkorporerades": "oinkorporerad",
    "oinkorporerads": "oinkorporerad",
    "oinkorporerat": "oinkorporerad",
    "oinkorporerats": "oinkorporerad",
    "oinkorporerbara": "oinkorporerbar",
    "oinkorporerbarare": "oinkorporerbar",
    "oinkorporerbarares": "oinkorporerbar",
    "oinkorporerbaras": "oinkorporerbar",
    "oinkorporerbarast": "oinkorporerbar",
    "oinkorporerbaraste": "oinkorporerbar",
    "oinkorporerbarastes": "oinkorporerbar",
    "oinkorporerbarasts": "oinkorporerbar",
    "oinkorporerbare": "oinkorporerbar",
    "oinkorporerbares": "oinkorporerbar",
    "oinkorporerbarheten": "oinkorporerbarhet",
    "oinkorporerbarhetens": "oinkorporerbarhet",
    "oinkorporerbarhets": "oinkorporerbarhet",
    "oinkorporerbars": "oinkorporerbar",
    "oinkorporerbart": "oinkorporerbar",
    "oinkorporerbarts": "oinkorporerbar",
    "oinkrävde": "oinkrävd",
    "oinkrävdes": "oinkrävd",
    "oinkrävds": "oinkrävd",
    "oinkrävt": "oinkrävd",
    "oinkrävts": "oinkrävd",
    "oinkvarterade": "oinkvarterad",
    "oinkvarterades": "oinkvarterad",
    "oinkvarterads": "oinkvarterad",
    "oinkvarterat": "oinkvarterad",
    "oinkvarterats": "oinkvarterad",
    "oinkvarterbara": "oinkvarterbar",
    "oinkvarterbarare": "oinkvarterbar",
    "oinkvarterbarares": "oinkvarterbar",
    "oinkvarterbaras": "oinkvarterbar",
    "oinkvarterbarast": "oinkvarterbar",
    "oinkvarterbaraste": "oinkvarterbar",
    "oinkvarterbarastes": "oinkvarterbar",
    "oinkvarterbarasts": "oinkvarterbar",
    "oinkvarterbare": "oinkvarterbar",
    "oinkvarterbares": "oinkvarterbar",
    "oinkvarterbarheten": "oinkvarterbarhet",
    "oinkvarterbarhetens": "oinkvarterbarhet",
    "oinkvarterbarhets": "oinkvarterbarhet",
    "oinkvarterbars": "oinkvarterbar",
    "oinkvarterbart": "oinkvarterbar",
    "oinkvarterbarts": "oinkvarterbar",
    "oinköpta": "oinköpt",
    "oinköptas": "oinköpt",
    "oinköpte": "oinköpt",
    "oinköptes": "oinköpt",
    "oinköpts": "oinköpt",
    "oinlemmade": "oinlemmad",
    "oinlemmades": "oinlemmad",
    "oinlemmads": "oinlemmad",
    "oinlemmat": "oinlemmad",
    "oinlemmats": "oinlemmad",
    "oinlämnade": "oinlämnad",
    "oinlämnades": "oinlämnad",
    "oinlämnads": "oinlämnad",
    "oinlämnat": "oinlämnad",
    "oinlämnats": "oinlämnad",
    "oinlärde": "oinlärd",
    "oinlärdes": "oinlärd",
    "oinlärds": "oinlärd",
    "oinlärt": "oinlärd",
    "oinlärts": "oinlärd",
    "oinlånade": "oinlånad",
    "oinlånades": "oinlånad",
    "oinlånads": "oinlånad",
    "oinlånat": "oinlånad",
    "oinlånats": "oinlånad",
    "oinlöpta": "oinlöpt",
    "oinlöptas": "oinlöpt",
    "oinlöpte": "oinlöpt",
    "oinlöptes": "oinlöpt",
    "oinlöpts": "oinlöpt",
    "oinlösta": "oinlöst",
    "oinlöstas": "oinlöst",
    "oinlöste": "oinlöst",
    "oinlöstes": "oinlöst",
    "oinlösts": "oinlöst",
    "oinmatade": "oinmatad",
    "oinmatades": "oinmatad",
    "oinmatads": "oinmatad",
    "oinmatat": "oinmatad",
    "oinmatats": "oinmatad",
    "oinmundigade": "oinmundigad",
    "oinmundigades": "oinmundigad",
    "oinmundigads": "oinmundigad",
    "oinmundigat": "oinmundigad",
    "oinmundigats": "oinmundigad",
    "oinmängde": "oinmängd",
    "oinmängdes": "oinmängd",
    "oinmängds": "oinmängd",
    "oinmängt": "oinmängd",
    "oinmängts": "oinmängd",
    "oinmönstrade": "oinmönstrad",
    "oinmönstrades": "oinmönstrad",
    "oinmönstrads": "oinmönstrad",
    "oinmönstrat": "oinmönstrad",
    "oinmönstrats": "oinmönstrad",
    "oinnefattade": "oinnefattad",
    "oinnefattades": "oinnefattad",
    "oinnefattads": "oinnefattad",
    "oinnefattat": "oinnefattad",
    "oinnefattats": "oinnefattad",
    "oinnerverade": "oinnerverad",
    "oinnerverades": "oinnerverad",
    "oinnerverads": "oinnerverad",
    "oinnerverat": "oinnerverad",
    "oinnerverats": "oinnerverad",
    "oinnerverbara": "oinnerverbar",
    "oinnerverbarare": "oinnerverbar",
    "oinnerverbarares": "oinnerverbar",
    "oinnerverbaras": "oinnerverbar",
    "oinnerverbarast": "oinnerverbar",
    "oinnerverbaraste": "oinnerverbar",
    "oinnerverbarastes": "oinnerverbar",
    "oinnerverbarasts": "oinnerverbar",
    "oinnerverbare": "oinnerverbar",
    "oinnerverbares": "oinnerverbar",
    "oinnerverbarheten": "oinnerverbarhet",
    "oinnerverbarhetens": "oinnerverbarhet",
    "oinnerverbarhets": "oinnerverbarhet",
    "oinnerverbars": "oinnerverbar",
    "oinnerverbart": "oinnerverbar",
    "oinnerverbarts": "oinnerverbar",
    "oinnestängde": "oinnestängd",
    "oinnestängdes": "oinnestängd",
    "oinnestängdheten": "oinnestängdhet",
    "oinnestängdhetens": "oinnestängdhet",
    "oinnestängdhets": "oinnestängdhet",
    "oinnestängds": "oinnestängd",
    "oinnestängt": "oinnestängd",
    "oinnestängts": "oinnestängd",
    "oinokulerade": "oinokulerad",
    "oinokulerades": "oinokulerad",
    "oinokulerads": "oinokulerad",
    "oinokulerat": "oinokulerad",
    "oinokulerats": "oinokulerad",
    "oinokulerbara": "oinokulerbar",
    "oinokulerbarare": "oinokulerbar",
    "oinokulerbarares": "oinokulerbar",
    "oinokulerbaras": "oinokulerbar",
    "oinokulerbarast": "oinokulerbar",
    "oinokulerbaraste": "oinokulerbar",
    "oinokulerbarastes": "oinokulerbar",
    "oinokulerbarasts": "oinokulerbar",
    "oinokulerbare": "oinokulerbar",
    "oinokulerbares": "oinokulerbar",
    "oinokulerbarheten": "oinokulerbarhet",
    "oinokulerbarhetens": "oinokulerbarhet",
    "oinokulerbarhets": "oinokulerbarhet",
    "oinokulerbars": "oinokulerbar",
    "oinokulerbart": "oinokulerbar",
    "oinokulerbarts": "oinokulerbar",
    "oinoljade": "oinoljad",
    "oinoljades": "oinoljad",
    "oinoljads": "oinoljad",
    "oinoljat": "oinoljad",
    "oinoljats": "oinoljad",
    "oinordnade": "oinordnad",
    "oinordnades": "oinordnad",
    "oinordnads": "oinordnad",
    "oinordnat": "oinordnad",
    "oinordnats": "oinordnad",
    "oinpassade": "oinpassad",
    "oinpassades": "oinpassad",
    "oinpassads": "oinpassad",
    "oinpassat": "oinpassad",
    "oinpassats": "oinpassad",
    "oinplantade": "oinplantad",
    "oinplantades": "oinplantad",
    "oinplantads": "oinplantad",
    "oinplantat": "oinplantad",
    "oinplantats": "oinplantad",
    "oinplanterade": "oinplanterad",
    "oinplanterades": "oinplanterad",
    "oinplanterads": "oinplanterad",
    "oinplanterat": "oinplanterad",
    "oinplanterats": "oinplanterad",
    "oinplanterbara": "oinplanterbar",
    "oinplanterbarare": "oinplanterbar",
    "oinplanterbarares": "oinplanterbar",
    "oinplanterbaras": "oinplanterbar",
    "oinplanterbarast": "oinplanterbar",
    "oinplanterbaraste": "oinplanterbar",
    "oinplanterbarastes": "oinplanterbar",
    "oinplanterbarasts": "oinplanterbar",
    "oinplanterbare": "oinplanterbar",
    "oinplanterbares": "oinplanterbar",
    "oinplanterbarheten": "oinplanterbarhet",
    "oinplanterbarhetens": "oinplanterbarhet",
    "oinplanterbarhets": "oinplanterbarhet",
    "oinplanterbars": "oinplanterbar",
    "oinplanterbart": "oinplanterbar",
    "oinplanterbarts": "oinplanterbar",
    "oinpressade": "oinpressad",
    "oinpressades": "oinpressad",
    "oinpressads": "oinpressad",
    "oinpressat": "oinpressad",
    "oinpressats": "oinpressad",
    "oinprickade": "oinprickad",
    "oinprickades": "oinprickad",
    "oinprickads": "oinprickad",
    "oinprickat": "oinprickad",
    "oinprickats": "oinprickad",
    "oinpräglade": "oinpräglad",
    "oinpräglades": "oinpräglad",
    "oinpräglads": "oinpräglad",
    "oinpräglat": "oinpräglad",
    "oinpräglats": "oinpräglad",
    "oinpräntade": "oinpräntad",
    "oinpräntades": "oinpräntad",
    "oinpräntads": "oinpräntad",
    "oinpräntat": "oinpräntad",
    "oinpräntats": "oinpräntad",
    "oinramade": "oinramad",
    "oinramades": "oinramad",
    "oinramads": "oinramad",
    "oinramat": "oinramad",
    "oinramats": "oinramad",
    "oinrangerade": "oinrangerad",
    "oinrangerades": "oinrangerad",
    "oinrangerads": "oinrangerad",
    "oinrangerat": "oinrangerad",
    "oinrangerats": "oinrangerad",
    "oinrangerbara": "oinrangerbar",
    "oinrangerbarare": "oinrangerbar",
    "oinrangerbarares": "oinrangerbar",
    "oinrangerbaras": "oinrangerbar",
    "oinrangerbarast": "oinrangerbar",
    "oinrangerbaraste": "oinrangerbar",
    "oinrangerbarastes": "oinrangerbar",
    "oinrangerbarasts": "oinrangerbar",
    "oinrangerbare": "oinrangerbar",
    "oinrangerbares": "oinrangerbar",
    "oinrangerbarheten": "oinrangerbarhet",
    "oinrangerbarhetens": "oinrangerbarhet",
    "oinrangerbarhets": "oinrangerbarhet",
    "oinrangerbars": "oinrangerbar",
    "oinrangerbart": "oinrangerbar",
    "oinrangerbarts": "oinrangerbar",
    "oinrapporterade": "oinrapporterad",
    "oinrapporterades": "oinrapporterad",
    "oinrapporterads": "oinrapporterad",
    "oinrapporterat": "oinrapporterad",
    "oinrapporterats": "oinrapporterad",
    "oinrapporterbara": "oinrapporterbar",
    "oinrapporterbarare": "oinrapporterbar",
    "oinrapporterbarares": "oinrapporterbar",
    "oinrapporterbaras": "oinrapporterbar",
    "oinrapporterbarast": "oinrapporterbar",
    "oinrapporterbaraste": "oinrapporterbar",
    "oinrapporterbarastes": "oinrapporterbar",
    "oinrapporterbarasts": "oinrapporterbar",
    "oinrapporterbare": "oinrapporterbar",
    "oinrapporterbares": "oinrapporterbar",
    "oinrapporterbarheten": "oinrapporterbarhet",
    "oinrapporterbarhetens": "oinrapporterbarhet",
    "oinrapporterbarhets": "oinrapporterbarhet",
    "oinrapporterbars": "oinrapporterbar",
    "oinrapporterbart": "oinrapporterbar",
    "oinrapporterbarts": "oinrapporterbar",
    "oinredda": "oinredd",
    "oinreddare": "oinredd",
    "oinreddares": "oinredd",
    "oinreddas": "oinredd",
    "oinreddast": "oinredd",
    "oinreddaste": "oinredd",
    "oinreddastes": "oinredd",
    "oinreddasts": "oinredd",
    "oinredde": "oinredd",
    "oinreddes": "oinredd",
    "oinredds": "oinredd",
    "oinregistrerade": "oinregistrerad",
    "oinregistrerades": "oinregistrerad",
    "oinregistrerads": "oinregistrerad",
    "oinregistrerat": "oinregistrerad",
    "oinregistrerats": "oinregistrerad",
    "oinregistrerbara": "oinregistrerbar",
    "oinregistrerbarare": "oinregistrerbar",
    "oinregistrerbarares": "oinregistrerbar",
    "oinregistrerbaras": "oinregistrerbar",
    "oinregistrerbarast": "oinregistrerbar",
    "oinregistrerbaraste": "oinregistrerbar",
    "oinregistrerbarastes": "oinregistrerbar",
    "oinregistrerbarasts": "oinregistrerbar",
    "oinregistrerbare": "oinregistrerbar",
    "oinregistrerbares": "oinregistrerbar",
    "oinregistrerbarheten": "oinregistrerbarhet",
    "oinregistrerbarhetens": "oinregistrerbarhet",
    "oinregistrerbarhets": "oinregistrerbarhet",
    "oinregistrerbars": "oinregistrerbar",
    "oinregistrerbart": "oinregistrerbar",
    "oinregistrerbarts": "oinregistrerbar",
    "oinrett": "oinredd",
    "oinretts": "oinredd",
    "oinriktade": "oinriktad",
    "oinriktades": "oinriktad",
    "oinriktads": "oinriktad",
    "oinriktat": "oinriktad",
    "oinriktats": "oinriktad",
    "oinringade": "oinringad",
    "oinringades": "oinringad",
    "oinringads": "oinringad",
    "oinringat": "oinringad",
    "oinringats": "oinringad",
    "oinristade": "oinristad",
    "oinristades": "oinristad",
    "oinristads": "oinristad",
    "oinristat": "oinristad",
    "oinristats": "oinristad",
    "oinropade": "oinropad",
    "oinropades": "oinropad",
    "oinropads": "oinropad",
    "oinropat": "oinropad",
    "oinropats": "oinropad",
    "oinrymde": "oinrymd",
    "oinrymdes": "oinrymd",
    "oinrymds": "oinrymd",
    "oinrymt": "oinrymd",
    "oinrymts": "oinrymd",
    "oinräknade": "oinräknad",
    "oinräknades": "oinräknad",
    "oinräknads": "oinräknad",
    "oinräknat": "oinräknad",
    "oinräknats": "oinräknad",
    "oinrättade": "oinrättad",
    "oinrättades": "oinrättad",
    "oinrättads": "oinrättad",
    "oinrättat": "oinrättad",
    "oinrättats": "oinrättad",
    "oinsamlade": "oinsamlad",
    "oinsamlades": "oinsamlad",
    "oinsamlads": "oinsamlad",
    "oinsamlat": "oinsamlad",
    "oinsamlats": "oinsamlad",
    "oinscenerade": "oinscenerad",
    "oinscenerades": "oinscenerad",
    "oinscenerads": "oinscenerad",
    "oinscenerat": "oinscenerad",
    "oinscenerats": "oinscenerad",
    "oinscenerbara": "oinscenerbar",
    "oinscenerbarare": "oinscenerbar",
    "oinscenerbarares": "oinscenerbar",
    "oinscenerbaras": "oinscenerbar",
    "oinscenerbarast": "oinscenerbar",
    "oinscenerbaraste": "oinscenerbar",
    "oinscenerbarastes": "oinscenerbar",
    "oinscenerbarasts": "oinscenerbar",
    "oinscenerbare": "oinscenerbar",
    "oinscenerbares": "oinscenerbar",
    "oinscenerbarheten": "oinscenerbarhet",
    "oinscenerbarhetens": "oinscenerbarhet",
    "oinscenerbarhets": "oinscenerbarhet",
    "oinscenerbars": "oinscenerbar",
    "oinscenerbart": "oinscenerbar",
    "oinscenerbarts": "oinscenerbar",
    "oinseglade": "oinseglad",
    "oinseglades": "oinseglad",
    "oinseglads": "oinseglad",
    "oinseglat": "oinseglad",
    "oinseglats": "oinseglad",
    "oinseminerade": "oinseminerad",
    "oinseminerades": "oinseminerad",
    "oinseminerads": "oinseminerad",
    "oinseminerat": "oinseminerad",
    "oinseminerats": "oinseminerad",
    "oinseminerbara": "oinseminerbar",
    "oinseminerbarare": "oinseminerbar",
    "oinseminerbarares": "oinseminerbar",
    "oinseminerbaras": "oinseminerbar",
    "oinseminerbarast": "oinseminerbar",
    "oinseminerbaraste": "oinseminerbar",
    "oinseminerbarastes": "oinseminerbar",
    "oinseminerbarasts": "oinseminerbar",
    "oinseminerbare": "oinseminerbar",
    "oinseminerbares": "oinseminerbar",
    "oinseminerbarheten": "oinseminerbarhet",
    "oinseminerbarhetens": "oinseminerbarhet",
    "oinseminerbarhets": "oinseminerbarhet",
    "oinseminerbars": "oinseminerbar",
    "oinseminerbart": "oinseminerbar",
    "oinseminerbarts": "oinseminerbar",
    "oinsinuerade": "oinsinuerad",
    "oinsinuerades": "oinsinuerad",
    "oinsinuerads": "oinsinuerad",
    "oinsinuerat": "oinsinuerad",
    "oinsinuerats": "oinsinuerad",
    "oinsinuerbara": "oinsinuerbar",
    "oinsinuerbarare": "oinsinuerbar",
    "oinsinuerbarares": "oinsinuerbar",
    "oinsinuerbaras": "oinsinuerbar",
    "oinsinuerbarast": "oinsinuerbar",
    "oinsinuerbaraste": "oinsinuerbar",
    "oinsinuerbarastes": "oinsinuerbar",
    "oinsinuerbarasts": "oinsinuerbar",
    "oinsinuerbare": "oinsinuerbar",
    "oinsinuerbares": "oinsinuerbar",
    "oinsinuerbarheten": "oinsinuerbarhet",
    "oinsinuerbarhetens": "oinsinuerbarhet",
    "oinsinuerbarhets": "oinsinuerbarhet",
    "oinsinuerbars": "oinsinuerbar",
    "oinsinuerbart": "oinsinuerbar",
    "oinsinuerbarts": "oinsinuerbar",
    "oinsisterade": "oinsisterad",
    "oinsisterades": "oinsisterad",
    "oinsisterads": "oinsisterad",
    "oinsisterat": "oinsisterad",
    "oinsisterats": "oinsisterad",
    "oinsjuknade": "oinsjuknad",
    "oinsjuknades": "oinsjuknad",
    "oinsjuknads": "oinsjuknad",
    "oinsjuknat": "oinsjuknad",
    "oinsjuknats": "oinsjuknad",
    "oinskaffade": "oinskaffad",
    "oinskaffades": "oinskaffad",
    "oinskaffads": "oinskaffad",
    "oinskaffat": "oinskaffad",
    "oinskaffats": "oinskaffad",
    "oinskeppade": "oinskeppad",
    "oinskeppades": "oinskeppad",
    "oinskeppads": "oinskeppad",
    "oinskeppat": "oinskeppad",
    "oinskeppats": "oinskeppad",
    "oinskolade": "oinskolad",
    "oinskolades": "oinskolad",
    "oinskolads": "oinskolad",
    "oinskolat": "oinskolad",
    "oinskolats": "oinskolad",
    "oinskränkta": "oinskränkt",
    "oinskränktare": "oinskränkt",
    "oinskränktares": "oinskränkt",
    "oinskränktas": "oinskränkt",
    "oinskränktast": "oinskränkt",
    "oinskränktaste": "oinskränkt",
    "oinskränktastes": "oinskränkt",
    "oinskränktasts": "oinskränkt",
    "oinskränkte": "oinskränkt",
    "oinskränktes": "oinskränkt",
    "oinskränktheten": "oinskränkthet",
    "oinskränkthetens": "oinskränkthet",
    "oinskränkthets": "oinskränkthet",
    "oinskränkts": "oinskränkt",
    "oinskärpta": "oinskärpt",
    "oinskärptas": "oinskärpt",
    "oinskärpte": "oinskärpt",
    "oinskärptes": "oinskärpt",
    "oinskärpts": "oinskärpt",
    "oinsomnade": "oinsomnad",
    "oinsomnades": "oinsomnad",
    "oinsomnads": "oinsomnad",
    "oinsomnat": "oinsomnad",
    "oinsomnats": "oinsomnad",
    "oinspekterade": "oinspekterad",
    "oinspekterades": "oinspekterad",
    "oinspekterads": "oinspekterad",
    "oinspekterat": "oinspekterad",
    "oinspekterats": "oinspekterad",
    "oinspekterbara": "oinspekterbar",
    "oinspekterbarare": "oinspekterbar",
    "oinspekterbarares": "oinspekterbar",
    "oinspekterbaras": "oinspekterbar",
    "oinspekterbarast": "oinspekterbar",
    "oinspekterbaraste": "oinspekterbar",
    "oinspekterbarastes": "oinspekterbar",
    "oinspekterbarasts": "oinspekterbar",
    "oinspekterbare": "oinspekterbar",
    "oinspekterbares": "oinspekterbar",
    "oinspekterbarheten": "oinspekterbarhet",
    "oinspekterbarhetens": "oinspekterbarhet",
    "oinspekterbarhets": "oinspekterbarhet",
    "oinspekterbars": "oinspekterbar",
    "oinspekterbart": "oinspekterbar",
    "oinspekterbarts": "oinspekterbar",
    "oinspirerade": "oinspirerad",
    "oinspirerades": "oinspirerad",
    "oinspirerads": "oinspirerad",
    "oinspirerat": "oinspirerad",
    "oinspirerats": "oinspirerad",
    "oinspirerbara": "oinspirerbar",
    "oinspirerbarare": "oinspirerbar",
    "oinspirerbarares": "oinspirerbar",
    "oinspirerbaras": "oinspirerbar",
    "oinspirerbarast": "oinspirerbar",
    "oinspirerbaraste": "oinspirerbar",
    "oinspirerbarastes": "oinspirerbar",
    "oinspirerbarasts": "oinspirerbar",
    "oinspirerbare": "oinspirerbar",
    "oinspirerbares": "oinspirerbar",
    "oinspirerbarheten": "oinspirerbarhet",
    "oinspirerbarhetens": "oinspirerbarhet",
    "oinspirerbarhets": "oinspirerbarhet",
    "oinspirerbars": "oinspirerbar",
    "oinspirerbart": "oinspirerbar",
    "oinspirerbarts": "oinspirerbar",
    "oinstallerade": "oinstallerad",
    "oinstallerades": "oinstallerad",
    "oinstallerads": "oinstallerad",
    "oinstallerat": "oinstallerad",
    "oinstallerats": "oinstallerad",
    "oinstallerbara": "oinstallerbar",
    "oinstallerbarare": "oinstallerbar",
    "oinstallerbarares": "oinstallerbar",
    "oinstallerbaras": "oinstallerbar",
    "oinstallerbarast": "oinstallerbar",
    "oinstallerbaraste": "oinstallerbar",
    "oinstallerbarastes": "oinstallerbar",
    "oinstallerbarasts": "oinstallerbar",
    "oinstallerbare": "oinstallerbar",
    "oinstallerbares": "oinstallerbar",
    "oinstallerbarheten": "oinstallerbarhet",
    "oinstallerbarhetens": "oinstallerbarhet",
    "oinstallerbarhets": "oinstallerbarhet",
    "oinstallerbars": "oinstallerbar",
    "oinstallerbart": "oinstallerbar",
    "oinstallerbarts": "oinstallerbar",
    "oinstiftade": "oinstiftad",
    "oinstiftades": "oinstiftad",
    "oinstiftads": "oinstiftad",
    "oinstiftat": "oinstiftad",
    "oinstiftats": "oinstiftad",
    "oinstitutionaliserade": "oinstitutionaliserad",
    "oinstitutionaliserades": "oinstitutionaliserad",
    "oinstitutionaliserads": "oinstitutionaliserad",
    "oinstitutionaliserat": "oinstitutionaliserad",
    "oinstitutionaliserats": "oinstitutionaliserad",
    "oinstitutionaliserbara": "oinstitutionaliserbar",
    "oinstitutionaliserbarare": "oinstitutionaliserbar",
    "oinstitutionaliserbarares": "oinstitutionaliserbar",
    "oinstitutionaliserbaras": "oinstitutionaliserbar",
    "oinstitutionaliserbarast": "oinstitutionaliserbar",
    "oinstitutionaliserbaraste": "oinstitutionaliserbar",
    "oinstitutionaliserbarastes": "oinstitutionaliserbar",
    "oinstitutionaliserbarasts": "oinstitutionaliserbar",
    "oinstitutionaliserbare": "oinstitutionaliserbar",
    "oinstitutionaliserbares": "oinstitutionaliserbar",
    "oinstitutionaliserbarheten": "oinstitutionaliserbarhet",
    "oinstitutionaliserbarhetens": "oinstitutionaliserbarhet",
    "oinstitutionaliserbarhets": "oinstitutionaliserbarhet",
    "oinstitutionaliserbars": "oinstitutionaliserbar",
    "oinstitutionaliserbart": "oinstitutionaliserbar",
    "oinstitutionaliserbarts": "oinstitutionaliserbar",
    "oinstruerade": "oinstruerad",
    "oinstruerades": "oinstruerad",
    "oinstruerads": "oinstruerad",
    "oinstruerat": "oinstruerad",
    "oinstruerats": "oinstruerad",
    "oinstruerbara": "oinstruerbar",
    "oinstruerbarare": "oinstruerbar",
    "oinstruerbarares": "oinstruerbar",
    "oinstruerbaras": "oinstruerbar",
    "oinstruerbarast": "oinstruerbar",
    "oinstruerbaraste": "oinstruerbar",
    "oinstruerbarastes": "oinstruerbar",
    "oinstruerbarasts": "oinstruerbar",
    "oinstruerbare": "oinstruerbar",
    "oinstruerbares": "oinstruerbar",
    "oinstruerbarheten": "oinstruerbarhet",
    "oinstruerbarhetens": "oinstruerbarhet",
    "oinstruerbarhets": "oinstruerbarhet",
    "oinstruerbars": "oinstruerbar",
    "oinstruerbart": "oinstruerbar",
    "oinstruerbarts": "oinstruerbar",
    "oinstrumenterade": "oinstrumenterad",
    "oinstrumenterades": "oinstrumenterad",
    "oinstrumenterads": "oinstrumenterad",
    "oinstrumenterat": "oinstrumenterad",
    "oinstrumenterats": "oinstrumenterad",
    "oinstrumenterbara": "oinstrumenterbar",
    "oinstrumenterbarare": "oinstrumenterbar",
    "oinstrumenterbarares": "oinstrumenterbar",
    "oinstrumenterbaras": "oinstrumenterbar",
    "oinstrumenterbarast": "oinstrumenterbar",
    "oinstrumenterbaraste": "oinstrumenterbar",
    "oinstrumenterbarastes": "oinstrumenterbar",
    "oinstrumenterbarasts": "oinstrumenterbar",
    "oinstrumenterbare": "oinstrumenterbar",
    "oinstrumenterbares": "oinstrumenterbar",
    "oinstrumenterbarheten": "oinstrumenterbarhet",
    "oinstrumenterbarhetens": "oinstrumenterbarhet",
    "oinstrumenterbarhets": "oinstrumenterbarhet",
    "oinstrumenterbars": "oinstrumenterbar",
    "oinstrumenterbart": "oinstrumenterbar",
    "oinstrumenterbarts": "oinstrumenterbar",
    "oinstrålade": "oinstrålad",
    "oinstrålades": "oinstrålad",
    "oinstrålads": "oinstrålad",
    "oinstrålat": "oinstrålad",
    "oinstrålats": "oinstrålad",
    "oinstuderade": "oinstuderad",
    "oinstuderades": "oinstuderad",
    "oinstuderads": "oinstuderad",
    "oinstuderat": "oinstuderad",
    "oinstuderats": "oinstuderad",
    "oinstuderbara": "oinstuderbar",
    "oinstuderbarare": "oinstuderbar",
    "oinstuderbarares": "oinstuderbar",
    "oinstuderbaras": "oinstuderbar",
    "oinstuderbarast": "oinstuderbar",
    "oinstuderbaraste": "oinstuderbar",
    "oinstuderbarastes": "oinstuderbar",
    "oinstuderbarasts": "oinstuderbar",
    "oinstuderbare": "oinstuderbar",
    "oinstuderbares": "oinstuderbar",
    "oinstuderbarheten": "oinstuderbarhet",
    "oinstuderbarhetens": "oinstuderbarhet",
    "oinstuderbarhets": "oinstuderbarhet",
    "oinstuderbars": "oinstuderbar",
    "oinstuderbart": "oinstuderbar",
    "oinstuderbarts": "oinstuderbar",
    "oinstämde": "oinstämd",
    "oinstämdes": "oinstämd",
    "oinstämds": "oinstämd",
    "oinstämt": "oinstämd",
    "oinstämts": "oinstämd",
    "oinstängde": "oinstängd",
    "oinstängdes": "oinstängd",
    "oinstängdheten": "oinstängdhet",
    "oinstängdhetens": "oinstängdhet",
    "oinstängdhets": "oinstängdhet",
    "oinstängds": "oinstängd",
    "oinstängt": "oinstängd",
    "oinstängts": "oinstängd",
    "oinsvepta": "oinsvept",
    "oinsveptas": "oinsvept",
    "oinsvepte": "oinsvept",
    "oinsveptes": "oinsvept",
    "oinsvepts": "oinsvept",
    "oinsände": "oinsänd",
    "oinsändes": "oinsänd",
    "oinsänds": "oinsänd",
    "oinsänt": "oinsänd",
    "oinsänts": "oinsänd",
    "oinsöndrade": "oinsöndrad",
    "oinsöndrades": "oinsöndrad",
    "oinsöndrads": "oinsöndrad",
    "oinsöndrat": "oinsöndrad",
    "oinsöndrats": "oinsöndrad",
    "ointagliga": "ointaglig",
    "ointagligare": "ointaglig",
    "ointagligares": "ointaglig",
    "ointagligas": "ointaglig",
    "ointagligast": "ointaglig",
    "ointagligaste": "ointaglig",
    "ointagligastes": "ointaglig",
    "ointagligasts": "ointaglig",
    "ointaglige": "ointaglig",
    "ointagliges": "ointaglig",
    "ointagligheten": "ointaglighet",
    "ointaglighetens": "ointaglighet",
    "ointaglighets": "ointaglighet",
    "ointagligs": "ointaglig",
    "ointagligt": "ointaglig",
    "ointagligts": "ointaglig",
    "ointecknade": "ointecknad",
    "ointecknades": "ointecknad",
    "ointecknads": "ointecknad",
    "ointecknat": "ointecknad",
    "ointecknats": "ointecknad",
    "ointegrerade": "ointegrerad",
    "ointegrerades": "ointegrerad",
    "ointegrerads": "ointegrerad",
    "ointegrerat": "ointegrerad",
    "ointegrerats": "ointegrerad",
    "ointegrerbara": "ointegrerbar",
    "ointegrerbarare": "ointegrerbar",
    "ointegrerbarares": "ointegrerbar",
    "ointegrerbaras": "ointegrerbar",
    "ointegrerbarast": "ointegrerbar",
    "ointegrerbaraste": "ointegrerbar",
    "ointegrerbarastes": "ointegrerbar",
    "ointegrerbarasts": "ointegrerbar",
    "ointegrerbare": "ointegrerbar",
    "ointegrerbares": "ointegrerbar",
    "ointegrerbarheten": "ointegrerbarhet",
    "ointegrerbarhetens": "ointegrerbarhet",
    "ointegrerbarhets": "ointegrerbarhet",
    "ointegrerbars": "ointegrerbar",
    "ointegrerbart": "ointegrerbar",
    "ointegrerbarts": "ointegrerbar",
    "ointellektualiserade": "ointellektualiserad",
    "ointellektualiserades": "ointellektualiserad",
    "ointellektualiserads": "ointellektualiserad",
    "ointellektualiserat": "ointellektualiserad",
    "ointellektualiserats": "ointellektualiserad",
    "ointellektualiserbara": "ointellektualiserbar",
    "ointellektualiserbarare": "ointellektualiserbar",
    "ointellektualiserbarares": "ointellektualiserbar",
    "ointellektualiserbaras": "ointellektualiserbar",
    "ointellektualiserbarast": "ointellektualiserbar",
    "ointellektualiserbaraste": "ointellektualiserbar",
    "ointellektualiserbarastes": "ointellektualiserbar",
    "ointellektualiserbarasts": "ointellektualiserbar",
    "ointellektualiserbare": "ointellektualiserbar",
    "ointellektualiserbares": "ointellektualiserbar",
    "ointellektualiserbarheten": "ointellektualiserbarhet",
    "ointellektualiserbarhetens": "ointellektualiserbarhet",
    "ointellektualiserbarhets": "ointellektualiserbarhet",
    "ointellektualiserbars": "ointellektualiserbar",
    "ointellektualiserbart": "ointellektualiserbar",
    "ointellektualiserbarts": "ointellektualiserbar",
    "ointelligenta": "ointelligent",
    "ointelligentare": "ointelligent",
    "ointelligentares": "ointelligent",
    "ointelligentas": "ointelligent",
    "ointelligentast": "ointelligent",
    "ointelligentaste": "ointelligent",
    "ointelligentastes": "ointelligent",
    "ointelligentasts": "ointelligent",
    "ointelligente": "ointelligent",
    "ointelligentes": "ointelligent",
    "ointelligentheten": "ointelligenthet",
    "ointelligenthetens": "ointelligenthet",
    "ointelligenthets": "ointelligenthet",
    "ointelligents": "ointelligent",
    "ointensifierade": "ointensifierad",
    "ointensifierades": "ointensifierad",
    "ointensifierads": "ointensifierad",
    "ointensifierat": "ointensifierad",
    "ointensifierats": "ointensifierad",
    "ointensifierbara": "ointensifierbar",
    "ointensifierbarare": "ointensifierbar",
    "ointensifierbarares": "ointensifierbar",
    "ointensifierbaras": "ointensifierbar",
    "ointensifierbarast": "ointensifierbar",
    "ointensifierbaraste": "ointensifierbar",
    "ointensifierbarastes": "ointensifierbar",
    "ointensifierbarasts": "ointensifierbar",
    "ointensifierbare": "ointensifierbar",
    "ointensifierbares": "ointensifierbar",
    "ointensifierbarheten": "ointensifierbarhet",
    "ointensifierbarhetens": "ointensifierbarhet",
    "ointensifierbarhets": "ointensifierbarhet",
    "ointensifierbars": "ointensifierbar",
    "ointensifierbart": "ointensifierbar",
    "ointensifierbarts": "ointensifierbar",
    "ointensiverade": "ointensiverad",
    "ointensiverades": "ointensiverad",
    "ointensiverads": "ointensiverad",
    "ointensiverat": "ointensiverad",
    "ointensiverats": "ointensiverad",
    "ointensiverbara": "ointensiverbar",
    "ointensiverbarare": "ointensiverbar",
    "ointensiverbarares": "ointensiverbar",
    "ointensiverbaras": "ointensiverbar",
    "ointensiverbarast": "ointensiverbar",
    "ointensiverbaraste": "ointensiverbar",
    "ointensiverbarastes": "ointensiverbar",
    "ointensiverbarasts": "ointensiverbar",
    "ointensiverbare": "ointensiverbar",
    "ointensiverbares": "ointensiverbar",
    "ointensiverbarheten": "ointensiverbarhet",
    "ointensiverbarhetens": "ointensiverbarhet",
    "ointensiverbarhets": "ointensiverbarhet",
    "ointensiverbars": "ointensiverbar",
    "ointensiverbart": "ointensiverbar",
    "ointensiverbarts": "ointensiverbar",
    "ointerfolierade": "ointerfolierad",
    "ointerfolierades": "ointerfolierad",
    "ointerfolierads": "ointerfolierad",
    "ointerfolierat": "ointerfolierad",
    "ointerfolierats": "ointerfolierad",
    "ointerfolierbara": "ointerfolierbar",
    "ointerfolierbarare": "ointerfolierbar",
    "ointerfolierbarares": "ointerfolierbar",
    "ointerfolierbaras": "ointerfolierbar",
    "ointerfolierbarast": "ointerfolierbar",
    "ointerfolierbaraste": "ointerfolierbar",
    "ointerfolierbarastes": "ointerfolierbar",
    "ointerfolierbarasts": "ointerfolierbar",
    "ointerfolierbare": "ointerfolierbar",
    "ointerfolierbares": "ointerfolierbar",
    "ointerfolierbarheten": "ointerfolierbarhet",
    "ointerfolierbarhetens": "ointerfolierbarhet",
    "ointerfolierbarhets": "ointerfolierbarhet",
    "ointerfolierbars": "ointerfolierbar",
    "ointerfolierbart": "ointerfolierbar",
    "ointerfolierbarts": "ointerfolierbar",
    "ointernaliserade": "ointernaliserad",
    "ointernaliserades": "ointernaliserad",
    "ointernaliserads": "ointernaliserad",
    "ointernaliserat": "ointernaliserad",
    "ointernaliserats": "ointernaliserad",
    "ointernaliserbara": "ointernaliserbar",
    "ointernaliserbarare": "ointernaliserbar",
    "ointernaliserbarares": "ointernaliserbar",
    "ointernaliserbaras": "ointernaliserbar",
    "ointernaliserbarast": "ointernaliserbar",
    "ointernaliserbaraste": "ointernaliserbar",
    "ointernaliserbarastes": "ointernaliserbar",
    "ointernaliserbarasts": "ointernaliserbar",
    "ointernaliserbare": "ointernaliserbar",
    "ointernaliserbares": "ointernaliserbar",
    "ointernaliserbarheten": "ointernaliserbarhet",
    "ointernaliserbarhetens": "ointernaliserbarhet",
    "ointernaliserbarhets": "ointernaliserbarhet",
    "ointernaliserbars": "ointernaliserbar",
    "ointernaliserbart": "ointernaliserbar",
    "ointernaliserbarts": "ointernaliserbar",
    "ointernationaliserade": "ointernationaliserad",
    "ointernationaliserades": "ointernationaliserad",
    "ointernationaliserads": "ointernationaliserad",
    "ointernationaliserat": "ointernationaliserad",
    "ointernationaliserats": "ointernationaliserad",
    "ointernationaliserbara": "ointernationaliserbar",
    "ointernationaliserbarare": "ointernationaliserbar",
    "ointernationaliserbarares": "ointernationaliserbar",
    "ointernationaliserbaras": "ointernationaliserbar",
    "ointernationaliserbarast": "ointernationaliserbar",
    "ointernationaliserbaraste": "ointernationaliserbar",
    "ointernationaliserbarastes": "ointernationaliserbar",
    "ointernationaliserbarasts": "ointernationaliserbar",
    "ointernationaliserbare": "ointernationaliserbar",
    "ointernationaliserbares": "ointernationaliserbar",
    "ointernationaliserbarheten": "ointernationaliserbarhet",
    "ointernationaliserbarhetens": "ointernationaliserbarhet",
    "ointernationaliserbarhets": "ointernationaliserbarhet",
    "ointernationaliserbars": "ointernationaliserbar",
    "ointernationaliserbart": "ointernationaliserbar",
    "ointernationaliserbarts": "ointernationaliserbar",
    "ointernerade": "ointernerad",
    "ointernerades": "ointernerad",
    "ointernerads": "ointernerad",
    "ointernerat": "ointernerad",
    "ointernerats": "ointernerad",
    "ointernerbara": "ointernerbar",
    "ointernerbarare": "ointernerbar",
    "ointernerbarares": "ointernerbar",
    "ointernerbaras": "ointernerbar",
    "ointernerbarast": "ointernerbar",
    "ointernerbaraste": "ointernerbar",
    "ointernerbarastes": "ointernerbar",
    "ointernerbarasts": "ointernerbar",
    "ointernerbare": "ointernerbar",
    "ointernerbares": "ointernerbar",
    "ointernerbarheten": "ointernerbarhet",
    "ointernerbarhetens": "ointernerbarhet",
    "ointernerbarhets": "ointernerbarhet",
    "ointernerbars": "ointernerbar",
    "ointernerbart": "ointernerbar",
    "ointernerbarts": "ointernerbar",
    "ointerpellerade": "ointerpellerad",
    "ointerpellerades": "ointerpellerad",
    "ointerpellerads": "ointerpellerad",
    "ointerpellerat": "ointerpellerad",
    "ointerpellerats": "ointerpellerad",
    "ointerpellerbara": "ointerpellerbar",
    "ointerpellerbarare": "ointerpellerbar",
    "ointerpellerbarares": "ointerpellerbar",
    "ointerpellerbaras": "ointerpellerbar",
    "ointerpellerbarast": "ointerpellerbar",
    "ointerpellerbaraste": "ointerpellerbar",
    "ointerpellerbarastes": "ointerpellerbar",
    "ointerpellerbarasts": "ointerpellerbar",
    "ointerpellerbare": "ointerpellerbar",
    "ointerpellerbares": "ointerpellerbar",
    "ointerpellerbarheten": "ointerpellerbarhet",
    "ointerpellerbarhetens": "ointerpellerbarhet",
    "ointerpellerbarhets": "ointerpellerbarhet",
    "ointerpellerbars": "ointerpellerbar",
    "ointerpellerbart": "ointerpellerbar",
    "ointerpellerbarts": "ointerpellerbar",
    "ointerpolerade": "ointerpolerad",
    "ointerpolerades": "ointerpolerad",
    "ointerpolerads": "ointerpolerad",
    "ointerpolerat": "ointerpolerad",
    "ointerpolerats": "ointerpolerad",
    "ointerpolerbara": "ointerpolerbar",
    "ointerpolerbarare": "ointerpolerbar",
    "ointerpolerbarares": "ointerpolerbar",
    "ointerpolerbaras": "ointerpolerbar",
    "ointerpolerbarast": "ointerpolerbar",
    "ointerpolerbaraste": "ointerpolerbar",
    "ointerpolerbarastes": "ointerpolerbar",
    "ointerpolerbarasts": "ointerpolerbar",
    "ointerpolerbare": "ointerpolerbar",
    "ointerpolerbares": "ointerpolerbar",
    "ointerpolerbarheten": "ointerpolerbarhet",
    "ointerpolerbarhetens": "ointerpolerbarhet",
    "ointerpolerbarhets": "ointerpolerbarhet",
    "ointerpolerbars": "ointerpolerbar",
    "ointerpolerbart": "ointerpolerbar",
    "ointerpolerbarts": "ointerpolerbar",
    "ointerpreterade": "ointerpreterad",
    "ointerpreterades": "ointerpreterad",
    "ointerpreterads": "ointerpreterad",
    "ointerpreterat": "ointerpreterad",
    "ointerpreterats": "ointerpreterad",
    "ointerpreterbara": "ointerpreterbar",
    "ointerpreterbarare": "ointerpreterbar",
    "ointerpreterbarares": "ointerpreterbar",
    "ointerpreterbaras": "ointerpreterbar",
    "ointerpreterbarast": "ointerpreterbar",
    "ointerpreterbaraste": "ointerpreterbar",
    "ointerpreterbarastes": "ointerpreterbar",
    "ointerpreterbarasts": "ointerpreterbar",
    "ointerpreterbare": "ointerpreterbar",
    "ointerpreterbares": "ointerpreterbar",
    "ointerpreterbarheten": "ointerpreterbarhet",
    "ointerpreterbarhetens": "ointerpreterbarhet",
    "ointerpreterbarhets": "ointerpreterbarhet",
    "ointerpreterbars": "ointerpreterbar",
    "ointerpreterbart": "ointerpreterbar",
    "ointerpreterbarts": "ointerpreterbar",
    "ointerpunkterade": "ointerpunkterad",
    "ointerpunkterades": "ointerpunkterad",
    "ointerpunkterads": "ointerpunkterad",
    "ointerpunkterat": "ointerpunkterad",
    "ointerpunkterats": "ointerpunkterad",
    "ointerpunkterbara": "ointerpunkterbar",
    "ointerpunkterbarare": "ointerpunkterbar",
    "ointerpunkterbarares": "ointerpunkterbar",
    "ointerpunkterbaras": "ointerpunkterbar",
    "ointerpunkterbarast": "ointerpunkterbar",
    "ointerpunkterbaraste": "ointerpunkterbar",
    "ointerpunkterbarastes": "ointerpunkterbar",
    "ointerpunkterbarasts": "ointerpunkterbar",
    "ointerpunkterbare": "ointerpunkterbar",
    "ointerpunkterbares": "ointerpunkterbar",
    "ointerpunkterbarheten": "ointerpunkterbarhet",
    "ointerpunkterbarhetens": "ointerpunkterbarhet",
    "ointerpunkterbarhets": "ointerpunkterbarhet",
    "ointerpunkterbars": "ointerpunkterbar",
    "ointerpunkterbart": "ointerpunkterbar",
    "ointerpunkterbarts": "ointerpunkterbar",
    "ointervenerade": "ointervenerad",
    "ointervenerades": "ointervenerad",
    "ointervenerads": "ointervenerad",
    "ointervenerat": "ointervenerad",
    "ointervenerats": "ointervenerad",
    "ointervenerbara": "ointervenerbar",
    "ointervenerbarare": "ointervenerbar",
    "ointervenerbarares": "ointervenerbar",
    "ointervenerbaras": "ointervenerbar",
    "ointervenerbarast": "ointervenerbar",
    "ointervenerbaraste": "ointervenerbar",
    "ointervenerbarastes": "ointervenerbar",
    "ointervenerbarasts": "ointervenerbar",
    "ointervenerbare": "ointervenerbar",
    "ointervenerbares": "ointervenerbar",
    "ointervenerbarheten": "ointervenerbarhet",
    "ointervenerbarhetens": "ointervenerbarhet",
    "ointervenerbarhets": "ointervenerbarhet",
    "ointervenerbars": "ointervenerbar",
    "ointervenerbart": "ointervenerbar",
    "ointervenerbarts": "ointervenerbar",
    "ointervjuade": "ointervjuad",
    "ointervjuades": "ointervjuad",
    "ointervjuads": "ointervjuad",
    "ointervjuat": "ointervjuad",
    "ointervjuats": "ointervjuad",
    "ointolkade": "ointolkad",
    "ointolkades": "ointolkad",
    "ointolkads": "ointolkad",
    "ointolkat": "ointolkad",
    "ointolkats": "ointolkad",
    "ointonerade": "ointonerad",
    "ointonerades": "ointonerad",
    "ointonerads": "ointonerad",
    "ointonerat": "ointonerad",
    "ointonerats": "ointonerad",
    "ointonerbara": "ointonerbar",
    "ointonerbarare": "ointonerbar",
    "ointonerbarares": "ointonerbar",
    "ointonerbaras": "ointonerbar",
    "ointonerbarast": "ointonerbar",
    "ointonerbaraste": "ointonerbar",
    "ointonerbarastes": "ointonerbar",
    "ointonerbarasts": "ointonerbar",
    "ointonerbare": "ointonerbar",
    "ointonerbares": "ointonerbar",
    "ointonerbarheten": "ointonerbarhet",
    "ointonerbarhetens": "ointonerbarhet",
    "ointonerbarhets": "ointonerbarhet",
    "ointonerbars": "ointonerbar",
    "ointonerbart": "ointonerbar",
    "ointonerbarts": "ointonerbar",
    "ointressanta": "ointressant",
    "ointressantare": "ointressant",
    "ointressantares": "ointressant",
    "ointressantas": "ointressant",
    "ointressantast": "ointressant",
    "ointressantaste": "ointressant",
    "ointressantastes": "ointressant",
    "ointressantasts": "ointressant",
    "ointressante": "ointressant",
    "ointressantes": "ointressant",
    "ointressants": "ointressant",
    "ointresserade": "ointresserad",
    "ointresserades": "ointresserad",
    "ointresserads": "ointresserad",
    "ointresserat": "ointresserad",
    "ointresserats": "ointresserad",
    "ointresserbara": "ointresserbar",
    "ointresserbarare": "ointresserbar",
    "ointresserbarares": "ointresserbar",
    "ointresserbaras": "ointresserbar",
    "ointresserbarast": "ointresserbar",
    "ointresserbaraste": "ointresserbar",
    "ointresserbarastes": "ointresserbar",
    "ointresserbarasts": "ointresserbar",
    "ointresserbare": "ointresserbar",
    "ointresserbares": "ointresserbar",
    "ointresserbarheten": "ointresserbarhet",
    "ointresserbarhetens": "ointresserbarhet",
    "ointresserbarhets": "ointresserbarhet",
    "ointresserbars": "ointresserbar",
    "ointresserbart": "ointresserbar",
    "ointresserbarts": "ointresserbar",
    "ointresses": "ointresse",
    "ointresset": "ointresse",
    "ointressets": "ointresse",
    "ointroducerade": "ointroducerad",
    "ointroducerades": "ointroducerad",
    "ointroducerads": "ointroducerad",
    "ointroducerat": "ointroducerad",
    "ointroducerats": "ointroducerad",
    "ointroducerbara": "ointroducerbar",
    "ointroducerbarare": "ointroducerbar",
    "ointroducerbarares": "ointroducerbar",
    "ointroducerbaras": "ointroducerbar",
    "ointroducerbarast": "ointroducerbar",
    "ointroducerbaraste": "ointroducerbar",
    "ointroducerbarastes": "ointroducerbar",
    "ointroducerbarasts": "ointroducerbar",
    "ointroducerbare": "ointroducerbar",
    "ointroducerbares": "ointroducerbar",
    "ointroducerbarheten": "ointroducerbarhet",
    "ointroducerbarhetens": "ointroducerbarhet",
    "ointroducerbarhets": "ointroducerbarhet",
    "ointroducerbars": "ointroducerbar",
    "ointroducerbart": "ointroducerbar",
    "ointroducerbarts": "ointroducerbar",
    "ointrumfade": "ointrumfad",
    "ointrumfades": "ointrumfad",
    "ointrumfads": "ointrumfad",
    "ointrumfat": "ointrumfad",
    "ointrumfats": "ointrumfad",
    "ointräffade": "ointräffad",
    "ointräffades": "ointräffad",
    "ointräffads": "ointräffad",
    "ointräffat": "ointräffad",
    "ointräffats": "ointräffad",
    "ointrängde": "ointrängd",
    "ointrängdes": "ointrängd",
    "ointrängds": "ointrängd",
    "ointrängt": "ointrängd",
    "ointrängts": "ointrängd",
    "ointygade": "ointygad",
    "ointygades": "ointygad",
    "ointygads": "ointygad",
    "ointygat": "ointygad",
    "ointygats": "ointygad",
    "ointågade": "ointågad",
    "ointågades": "ointågad",
    "ointågads": "ointågad",
    "ointågat": "ointågad",
    "ointågats": "ointågad",
    "oinvaderade": "oinvaderad",
    "oinvaderades": "oinvaderad",
    "oinvaderads": "oinvaderad",
    "oinvaderat": "oinvaderad",
    "oinvaderats": "oinvaderad",
    "oinvaderbara": "oinvaderbar",
    "oinvaderbarare": "oinvaderbar",
    "oinvaderbarares": "oinvaderbar",
    "oinvaderbaras": "oinvaderbar",
    "oinvaderbarast": "oinvaderbar",
    "oinvaderbaraste": "oinvaderbar",
    "oinvaderbarastes": "oinvaderbar",
    "oinvaderbarasts": "oinvaderbar",
    "oinvaderbare": "oinvaderbar",
    "oinvaderbares": "oinvaderbar",
    "oinvaderbarheten": "oinvaderbarhet",
    "oinvaderbarhetens": "oinvaderbarhet",
    "oinvaderbarhets": "oinvaderbarhet",
    "oinvaderbars": "oinvaderbar",
    "oinvaderbart": "oinvaderbar",
    "oinvaderbarts": "oinvaderbar",
    "oinvaggade": "oinvaggad",
    "oinvaggades": "oinvaggad",
    "oinvaggads": "oinvaggad",
    "oinvaggat": "oinvaggad",
    "oinvaggats": "oinvaggad",
    "oinvalidiserade": "oinvalidiserad",
    "oinvalidiserades": "oinvalidiserad",
    "oinvalidiserads": "oinvalidiserad",
    "oinvalidiserat": "oinvalidiserad",
    "oinvalidiserats": "oinvalidiserad",
    "oinvalidiserbara": "oinvalidiserbar",
    "oinvalidiserbarare": "oinvalidiserbar",
    "oinvalidiserbarares": "oinvalidiserbar",
    "oinvalidiserbaras": "oinvalidiserbar",
    "oinvalidiserbarast": "oinvalidiserbar",
    "oinvalidiserbaraste": "oinvalidiserbar",
    "oinvalidiserbarastes": "oinvalidiserbar",
    "oinvalidiserbarasts": "oinvalidiserbar",
    "oinvalidiserbare": "oinvalidiserbar",
    "oinvalidiserbares": "oinvalidiserbar",
    "oinvalidiserbarheten": "oinvalidiserbarhet",
    "oinvalidiserbarhetens": "oinvalidiserbarhet",
    "oinvalidiserbarhets": "oinvalidiserbarhet",
    "oinvalidiserbars": "oinvalidiserbar",
    "oinvalidiserbart": "oinvalidiserbar",
    "oinvalidiserbarts": "oinvalidiserbar",
    "oinvandrade": "oinvandrad",
    "oinvandrades": "oinvandrad",
    "oinvandrads": "oinvandrad",
    "oinvandrat": "oinvandrad",
    "oinvandrats": "oinvandrad",
    "oinvecklade": "oinvecklad",
    "oinvecklades": "oinvecklad",
    "oinvecklads": "oinvecklad",
    "oinvecklat": "oinvecklad",
    "oinvecklats": "oinvecklad",
    "oinventerade": "oinventerad",
    "oinventerades": "oinventerad",
    "oinventerads": "oinventerad",
    "oinventerat": "oinventerad",
    "oinventerats": "oinventerad",
    "oinventerbara": "oinventerbar",
    "oinventerbarare": "oinventerbar",
    "oinventerbarares": "oinventerbar",
    "oinventerbaras": "oinventerbar",
    "oinventerbarast": "oinventerbar",
    "oinventerbaraste": "oinventerbar",
    "oinventerbarastes": "oinventerbar",
    "oinventerbarasts": "oinventerbar",
    "oinventerbare": "oinventerbar",
    "oinventerbares": "oinventerbar",
    "oinventerbarheten": "oinventerbarhet",
    "oinventerbarhetens": "oinventerbarhet",
    "oinventerbarhets": "oinventerbarhet",
    "oinventerbars": "oinventerbar",
    "oinventerbart": "oinventerbar",
    "oinventerbarts": "oinventerbar",
    "oinverterade": "oinverterad",
    "oinverterades": "oinverterad",
    "oinverterads": "oinverterad",
    "oinverterat": "oinverterad",
    "oinverterats": "oinverterad",
    "oinverterbara": "oinverterbar",
    "oinverterbarare": "oinverterbar",
    "oinverterbarares": "oinverterbar",
    "oinverterbaras": "oinverterbar",
    "oinverterbarast": "oinverterbar",
    "oinverterbaraste": "oinverterbar",
    "oinverterbarastes": "oinverterbar",
    "oinverterbarasts": "oinverterbar",
    "oinverterbare": "oinverterbar",
    "oinverterbares": "oinverterbar",
    "oinverterbarheten": "oinverterbarhet",
    "oinverterbarhetens": "oinverterbarhet",
    "oinverterbarhets": "oinverterbarhet",
    "oinverterbars": "oinverterbar",
    "oinverterbart": "oinverterbar",
    "oinverterbarts": "oinverterbar",
    "oinvesterade": "oinvesterad",
    "oinvesterades": "oinvesterad",
    "oinvesterads": "oinvesterad",
    "oinvesterat": "oinvesterad",
    "oinvesterats": "oinvesterad",
    "oinvesterbara": "oinvesterbar",
    "oinvesterbarare": "oinvesterbar",
    "oinvesterbarares": "oinvesterbar",
    "oinvesterbaras": "oinvesterbar",
    "oinvesterbarast": "oinvesterbar",
    "oinvesterbaraste": "oinvesterbar",
    "oinvesterbarastes": "oinvesterbar",
    "oinvesterbarasts": "oinvesterbar",
    "oinvesterbare": "oinvesterbar",
    "oinvesterbares": "oinvesterbar",
    "oinvesterbarheten": "oinvesterbarhet",
    "oinvesterbarhetens": "oinvesterbarhet",
    "oinvesterbarhets": "oinvesterbarhet",
    "oinvesterbars": "oinvesterbar",
    "oinvesterbart": "oinvesterbar",
    "oinvesterbarts": "oinvesterbar",
    "oinvigda": "oinvigd",
    "oinvigdare": "oinvigd",
    "oinvigdares": "oinvigd",
    "oinvigdas": "oinvigd",
    "oinvigdast": "oinvigd",
    "oinvigdaste": "oinvigd",
    "oinvigdastes": "oinvigd",
    "oinvigdasts": "oinvigd",
    "oinvigde": "oinvigd",
    "oinvigdes": "oinvigd",
    "oinvigdheten": "oinvigdhet",
    "oinvigdhetens": "oinvigdhet",
    "oinvigdhets": "oinvigdhet",
    "oinvigds": "oinvigd",
    "oinvigt": "oinvigd",
    "oinvigts": "oinvigd",
    "oinviterade": "oinviterad",
    "oinviterades": "oinviterad",
    "oinviterads": "oinviterad",
    "oinviterat": "oinviterad",
    "oinviterats": "oinviterad",
    "oinviterbara": "oinviterbar",
    "oinviterbarare": "oinviterbar",
    "oinviterbarares": "oinviterbar",
    "oinviterbaras": "oinviterbar",
    "oinviterbarast": "oinviterbar",
    "oinviterbaraste": "oinviterbar",
    "oinviterbarastes": "oinviterbar",
    "oinviterbarasts": "oinviterbar",
    "oinviterbare": "oinviterbar",
    "oinviterbares": "oinviterbar",
    "oinviterbarheten": "oinviterbarhet",
    "oinviterbarhetens": "oinviterbarhet",
    "oinviterbarhets": "oinviterbarhet",
    "oinviterbars": "oinviterbar",
    "oinviterbart": "oinviterbar",
    "oinviterbarts": "oinviterbar",
    "oinvolverade": "oinvolverad",
    "oinvolverades": "oinvolverad",
    "oinvolverads": "oinvolverad",
    "oinvolverat": "oinvolverad",
    "oinvolverats": "oinvolverad",
    "oinvolverbara": "oinvolverbar",
    "oinvolverbarare": "oinvolverbar",
    "oinvolverbarares": "oinvolverbar",
    "oinvolverbaras": "oinvolverbar",
    "oinvolverbarast": "oinvolverbar",
    "oinvolverbaraste": "oinvolverbar",
    "oinvolverbarastes": "oinvolverbar",
    "oinvolverbarasts": "oinvolverbar",
    "oinvolverbare": "oinvolverbar",
    "oinvolverbares": "oinvolverbar",
    "oinvolverbarheten": "oinvolverbarhet",
    "oinvolverbarhetens": "oinvolverbarhet",
    "oinvolverbarhets": "oinvolverbarhet",
    "oinvolverbars": "oinvolverbar",
    "oinvolverbart": "oinvolverbar",
    "oinvolverbarts": "oinvolverbar",
    "oinväntade": "oinväntad",
    "oinväntades": "oinväntad",
    "oinväntads": "oinväntad",
    "oinväntat": "oinväntad",
    "oinväntats": "oinväntad",
    "oinvävde": "oinvävd",
    "oinvävdes": "oinvävd",
    "oinvävds": "oinvävd",
    "oinvävt": "oinvävd",
    "oinvävts": "oinvävd",
    "oinympade": "oinympad",
    "oinympades": "oinympad",
    "oinympads": "oinympad",
    "oinympat": "oinympad",
    "oinympats": "oinympad",
    "oinövade": "oinövad",
    "oinövades": "oinövad",
    "oinövads": "oinövad",
    "oinövat": "oinövad",
    "oinövats": "oinövad",
    "oirriterade": "oirriterad",
    "oirriterades": "oirriterad",
    "oirriterads": "oirriterad",
    "oirriterat": "oirriterad",
    "oirriterats": "oirriterad",
    "oirriterbara": "oirriterbar",
    "oirriterbarare": "oirriterbar",
    "oirriterbarares": "oirriterbar",
    "oirriterbaras": "oirriterbar",
    "oirriterbarast": "oirriterbar",
    "oirriterbaraste": "oirriterbar",
    "oirriterbarastes": "oirriterbar",
    "oirriterbarasts": "oirriterbar",
    "oirriterbare": "oirriterbar",
    "oirriterbares": "oirriterbar",
    "oirriterbarheten": "oirriterbarhet",
    "oirriterbarhetens": "oirriterbarhet",
    "oirriterbarhets": "oirriterbarhet",
    "oirriterbars": "oirriterbar",
    "oirriterbart": "oirriterbar",
    "oirriterbarts": "oirriterbar",
    "oislamiserade": "oislamiserad",
    "oislamiserades": "oislamiserad",
    "oislamiserads": "oislamiserad",
    "oislamiserat": "oislamiserad",
    "oislamiserats": "oislamiserad",
    "oislamiserbara": "oislamiserbar",
    "oislamiserbarare": "oislamiserbar",
    "oislamiserbarares": "oislamiserbar",
    "oislamiserbaras": "oislamiserbar",
    "oislamiserbarast": "oislamiserbar",
    "oislamiserbaraste": "oislamiserbar",
    "oislamiserbarastes": "oislamiserbar",
    "oislamiserbarasts": "oislamiserbar",
    "oislamiserbare": "oislamiserbar",
    "oislamiserbares": "oislamiserbar",
    "oislamiserbarheten": "oislamiserbarhet",
    "oislamiserbarhetens": "oislamiserbarhet",
    "oislamiserbarhets": "oislamiserbarhet",
    "oislamiserbars": "oislamiserbar",
    "oislamiserbart": "oislamiserbar",
    "oislamiserbarts": "oislamiserbar",
    "oisolerade": "oisolerad",
    "oisolerades": "oisolerad",
    "oisolerads": "oisolerad",
    "oisolerat": "oisolerad",
    "oisolerats": "oisolerad",
    "oisolerbara": "oisolerbar",
    "oisolerbarare": "oisolerbar",
    "oisolerbarares": "oisolerbar",
    "oisolerbaras": "oisolerbar",
    "oisolerbarast": "oisolerbar",
    "oisolerbaraste": "oisolerbar",
    "oisolerbarastes": "oisolerbar",
    "oisolerbarasts": "oisolerbar",
    "oisolerbare": "oisolerbar",
    "oisolerbares": "oisolerbar",
    "oisolerbarheten": "oisolerbarhet",
    "oisolerbarhetens": "oisolerbarhet",
    "oisolerbarhets": "oisolerbarhet",
    "oisolerbars": "oisolerbar",
    "oisolerbart": "oisolerbar",
    "oisolerbarts": "oisolerbar",
    "oitererade": "oitererad",
    "oitererades": "oitererad",
    "oitererads": "oitererad",
    "oitererat": "oitererad",
    "oitererats": "oitererad",
    "oitererbara": "oitererbar",
    "oitererbarare": "oitererbar",
    "oitererbarares": "oitererbar",
    "oitererbaras": "oitererbar",
    "oitererbarast": "oitererbar",
    "oitererbaraste": "oitererbar",
    "oitererbarastes": "oitererbar",
    "oitererbarasts": "oitererbar",
    "oitererbare": "oitererbar",
    "oitererbares": "oitererbar",
    "oitererbarheten": "oitererbarhet",
    "oitererbarhetens": "oitererbarhet",
    "oitererbarhets": "oitererbarhet",
    "oitererbars": "oitererbar",
    "oitererbart": "oitererbar",
    "oitererbarts": "oitererbar",
    "oitutade": "oitutad",
    "oitutades": "oitutad",
    "oitutads": "oitutad",
    "oitutat": "oitutad",
    "oitutats": "oitutad",
    "ojabbade": "ojabbad",
    "ojabbades": "ojabbad",
    "ojabbads": "ojabbad",
    "ojabbat": "ojabbad",
    "ojabbats": "ojabbad",
    "ojade": "oja",
    "ojades": "oja",
    "ojagade": "ojagad",
    "ojagades": "ojagad",
    "ojagads": "ojagad",
    "ojagat": "ojagad",
    "ojagats": "ojagad",
    "ojakade": "ojakad",
    "ojakades": "ojakad",
    "ojakads": "ojakad",
    "ojakat": "ojakad",
    "ojakats": "ojakad",
    "ojande": "oja",
    "ojanden": "ojande",
    "ojandena": "ojande",
    "ojandenas": "ojande",
    "ojandens": "ojande",
    "ojandes": "ojande",
    "ojandet": "ojande",
    "ojandets": "ojande",
    "ojar": "oja",
    "ojas": "oja",
    "ojat": "oja",
    "ojats": "oja",
    "ojazzifierade": "ojazzifierad",
    "ojazzifierades": "ojazzifierad",
    "ojazzifierads": "ojazzifierad",
    "ojazzifierat": "ojazzifierad",
    "ojazzifierats": "ojazzifierad",
    "ojazzifierbara": "ojazzifierbar",
    "ojazzifierbarare": "ojazzifierbar",
    "ojazzifierbarares": "ojazzifierbar",
    "ojazzifierbaras": "ojazzifierbar",
    "ojazzifierbarast": "ojazzifierbar",
    "ojazzifierbaraste": "ojazzifierbar",
    "ojazzifierbarastes": "ojazzifierbar",
    "ojazzifierbarasts": "ojazzifierbar",
    "ojazzifierbare": "ojazzifierbar",
    "ojazzifierbares": "ojazzifierbar",
    "ojazzifierbarheten": "ojazzifierbarhet",
    "ojazzifierbarhetens": "ojazzifierbarhet",
    "ojazzifierbarhets": "ojazzifierbarhet",
    "ojazzifierbars": "ojazzifierbar",
    "ojazzifierbart": "ojazzifierbar",
    "ojazzifierbarts": "ojazzifierbar",
    "ojoddlade": "ojoddlad",
    "ojoddlades": "ojoddlad",
    "ojoddlads": "ojoddlad",
    "ojoddlat": "ojoddlad",
    "ojoddlats": "ojoddlad",
    "ojoderade": "ojoderad",
    "ojoderades": "ojoderad",
    "ojoderads": "ojoderad",
    "ojoderat": "ojoderad",
    "ojoderats": "ojoderad",
    "ojoderbara": "ojoderbar",
    "ojoderbarare": "ojoderbar",
    "ojoderbarares": "ojoderbar",
    "ojoderbaras": "ojoderbar",
    "ojoderbarast": "ojoderbar",
    "ojoderbaraste": "ojoderbar",
    "ojoderbarastes": "ojoderbar",
    "ojoderbarasts": "ojoderbar",
    "ojoderbare": "ojoderbar",
    "ojoderbares": "ojoderbar",
    "ojoderbarheten": "ojoderbarhet",
    "ojoderbarhetens": "ojoderbarhet",
    "ojoderbarhets": "ojoderbarhet",
    "ojoderbars": "ojoderbar",
    "ojoderbart": "ojoderbar",
    "ojoderbarts": "ojoderbar",
    "ojoggade": "ojoggad",
    "ojoggades": "ojoggad",
    "ojoggads": "ojoggad",
    "ojoggat": "ojoggad",
    "ojoggats": "ojoggad",
    "ojojkade": "ojojkad",
    "ojojkades": "ojojkad",
    "ojojkads": "ojojkad",
    "ojojkat": "ojojkad",
    "ojojkats": "ojojkad",
    "ojollrade": "ojollrad",
    "ojollrades": "ojollrad",
    "ojollrads": "ojollrad",
    "ojollrat": "ojollrad",
    "ojollrats": "ojollrad",
    "ojonglerade": "ojonglerad",
    "ojonglerades": "ojonglerad",
    "ojonglerads": "ojonglerad",
    "ojonglerat": "ojonglerad",
    "ojonglerats": "ojonglerad",
    "ojonglerbara": "ojonglerbar",
    "ojonglerbarare": "ojonglerbar",
    "ojonglerbarares": "ojonglerbar",
    "ojonglerbaras": "ojonglerbar",
    "ojonglerbarast": "ojonglerbar",
    "ojonglerbaraste": "ojonglerbar",
    "ojonglerbarastes": "ojonglerbar",
    "ojonglerbarasts": "ojonglerbar",
    "ojonglerbare": "ojonglerbar",
    "ojonglerbares": "ojonglerbar",
    "ojonglerbarheten": "ojonglerbarhet",
    "ojonglerbarhetens": "ojonglerbarhet",
    "ojonglerbarhets": "ojonglerbarhet",
    "ojonglerbars": "ojonglerbar",
    "ojonglerbart": "ojonglerbar",
    "ojonglerbarts": "ojonglerbar",
    "ojoniserade": "ojoniserad",
    "ojoniserades": "ojoniserad",
    "ojoniserads": "ojoniserad",
    "ojoniserat": "ojoniserad",
    "ojoniserats": "ojoniserad",
    "ojoniserbara": "ojoniserbar",
    "ojoniserbarare": "ojoniserbar",
    "ojoniserbarares": "ojoniserbar",
    "ojoniserbaras": "ojoniserbar",
    "ojoniserbarast": "ojoniserbar",
    "ojoniserbaraste": "ojoniserbar",
    "ojoniserbarastes": "ojoniserbar",
    "ojoniserbarasts": "ojoniserbar",
    "ojoniserbare": "ojoniserbar",
    "ojoniserbares": "ojoniserbar",
    "ojoniserbarheten": "ojoniserbarhet",
    "ojoniserbarhetens": "ojoniserbarhet",
    "ojoniserbarhets": "ojoniserbarhet",
    "ojoniserbars": "ojoniserbar",
    "ojoniserbart": "ojoniserbar",
    "ojoniserbarts": "ojoniserbar",
    "ojordade": "ojordad",
    "ojordades": "ojordad",
    "ojordads": "ojordad",
    "ojordat": "ojordad",
    "ojordats": "ojordad",
    "ojusta": "ojust",
    "ojustare": "ojust",
    "ojustares": "ojust",
    "ojustas": "ojust",
    "ojustast": "ojust",
    "ojustaste": "ojust",
    "ojustastes": "ojust",
    "ojustasts": "ojust",
    "ojuste": "ojust",
    "ojusterade": "ojusterad",
    "ojusterades": "ojusterad",
    "ojusterads": "ojusterad",
    "ojusterat": "ojusterad",
    "ojusterats": "ojusterad",
    "ojusterbara": "ojusterbar",
    "ojusterbarare": "ojusterbar",
    "ojusterbarares": "ojusterbar",
    "ojusterbaras": "ojusterbar",
    "ojusterbarast": "ojusterbar",
    "ojusterbaraste": "ojusterbar",
    "ojusterbarastes": "ojusterbar",
    "ojusterbarasts": "ojusterbar",
    "ojusterbare": "ojusterbar",
    "ojusterbares": "ojusterbar",
    "ojusterbarheten": "ojusterbarhet",
    "ojusterbarhetens": "ojusterbarhet",
    "ojusterbarhets": "ojusterbarhet",
    "ojusterbars": "ojusterbar",
    "ojusterbart": "ojusterbar",
    "ojusterbarts": "ojusterbar",
    "ojustes": "ojust",
    "ojustheten": "ojusthet",
    "ojusthetens": "ojusthet",
    "ojustheter": "ojusthet",
    "ojustheterna": "ojusthet",
    "ojustheternas": "ojusthet",
    "ojustheters": "ojusthet",
    "ojusthets": "ojusthet",
    "ojusts": "ojust",
    "ojäktade": "ojäktad",
    "ojäktades": "ojäktad",
    "ojäktads": "ojäktad",
    "ojäktat": "ojäktad",
    "ojäktats": "ojäktad",
    "ojämförbara": "ojämförbar",
    "ojämförbarare": "ojämförbar",
    "ojämförbarares": "ojämförbar",
    "ojämförbaras": "ojämförbar",
    "ojämförbarast": "ojämförbar",
    "ojämförbaraste": "ojämförbar",
    "ojämförbarastes": "ojämförbar",
    "ojämförbarasts": "ojämförbar",
    "ojämförbare": "ojämförbar",
    "ojämförbares": "ojämförbar",
    "ojämförbarheten": "ojämförbarhet",
    "ojämförbarhetens": "ojämförbarhet",
    "ojämförbarhets": "ojämförbarhet",
    "ojämförbars": "ojämförbar",
    "ojämförbart": "ojämförbar",
    "ojämförbarts": "ojämförbar",
    "ojämförde": "ojämförd",
    "ojämfördes": "ojämförd",
    "ojämförds": "ojämförd",
    "ojämförliga": "ojämförlig",
    "ojämförligare": "ojämförlig",
    "ojämförligares": "ojämförlig",
    "ojämförligas": "ojämförlig",
    "ojämförligast": "ojämförlig",
    "ojämförligaste": "ojämförlig",
    "ojämförligastes": "ojämförlig",
    "ojämförligasts": "ojämförlig",
    "ojämförlige": "ojämförlig",
    "ojämförliges": "ojämförlig",
    "ojämförligheten": "ojämförlighet",
    "ojämförlighetens": "ojämförlighet",
    "ojämförlighets": "ojämförlighet",
    "ojämförligs": "ojämförlig",
    "ojämförligt": "ojämförlig",
    "ojämförligts": "ojämförlig",
    "ojämfört": "ojämförd",
    "ojämförts": "ojämförd",
    "ojämkade": "ojämkad",
    "ojämkades": "ojämkad",
    "ojämkads": "ojämkad",
    "ojämkat": "ojämkad",
    "ojämkats": "ojämkad",
    "ojämlika": "ojämlik",
    "ojämlikare": "ojämlik",
    "ojämlikares": "ojämlik",
    "ojämlikas": "ojämlik",
    "ojämlikast": "ojämlik",
    "ojämlikaste": "ojämlik",
    "ojämlikastes": "ojämlik",
    "ojämlikasts": "ojämlik",
    "ojämlike": "ojämlik",
    "ojämlikes": "ojämlik",
    "ojämlikheten": "ojämlikhet",
    "ojämlikhetens": "ojämlikhet",
    "ojämlikheter": "ojämlikhet",
    "ojämlikheterna": "ojämlikhet",
    "ojämlikheternas": "ojämlikhet",
    "ojämlikheters": "ojämlikhet",
    "ojämlikhets": "ojämlikhet",
    "ojämliks": "ojämlik",
    "ojämlikt": "ojämlik",
    "ojämlikts": "ojämlik",
    "ojämna": "ojämn",
    "ojämnade": "ojämnad",
    "ojämnades": "ojämnad",
    "ojämnads": "ojämnad",
    "ojämnare": "ojämn",
    "ojämnares": "ojämn",
    "ojämnas": "ojämn",
    "ojämnast": "ojämn",
    "ojämnaste": "ojämn",
    "ojämnastes": "ojämn",
    "ojämnasts": "ojämn",
    "ojämnat": "ojämnad",
    "ojämnats": "ojämnad",
    "ojämne": "ojämn",
    "ojämnes": "ojämn",
    "ojämnheten": "ojämnhet",
    "ojämnhetens": "ojämnhet",
    "ojämnheter": "ojämnhet",
    "ojämnheterna": "ojämnhet",
    "ojämnheternas": "ojämnhet",
    "ojämnheters": "ojämnhet",
    "ojämnhets": "ojämnhet",
    "ojämns": "ojämn",
    "ojämnt": "ojämn",
    "ojämnts": "ojämn",
    "ojämställde": "ojämställd",
    "ojämställdes": "ojämställd",
    "ojämställdheten": "ojämställdhet",
    "ojämställdhetens": "ojämställdhet",
    "ojämställdhets": "ojämställdhet",
    "ojämställds": "ojämställd",
    "ojämställt": "ojämställd",
    "ojämställts": "ojämställd",
    "ojästa": "ojäst",
    "ojästas": "ojäst",
    "ojäste": "ojäst",
    "ojästes": "ojäst",
    "ojästs": "ojäst",
    "ojävade": "ojävad",
    "ojävades": "ojävad",
    "ojävads": "ojävad",
    "ojävat": "ojävad",
    "ojävats": "ojävad",
    "ojäviga": "ojävig",
    "ojävigare": "ojävig",
    "ojävigares": "ojävig",
    "ojävigas": "ojävig",
    "ojävigast": "ojävig",
    "ojävigaste": "ojävig",
    "ojävigastes": "ojävig",
    "ojävigasts": "ojävig",
    "ojävige": "ojävig",
    "ojäviges": "ojävig",
    "ojävigheten": "ojävighet",
    "ojävighetens": "ojävighet",
    "ojävighets": "ojävighet",
    "ojävigs": "ojävig",
    "ojävigt": "ojävig",
    "ojävigts": "ojävig",
    "ok": "oka",
    "okablade": "okablad",
    "okablades": "okablad",
    "okablads": "okablad",
    "okablat": "okablad",
    "okablats": "okablad",
    "okad": "oka",
    "okade": "oka",
    "okades": "oka",
    "okads": "oka",
    "okaklade": "okaklad",
    "okaklades": "okaklad",
    "okaklads": "okaklad",
    "okaklat": "okaklad",
    "okaklats": "okaklad",
    "okalandrerade": "okalandrerad",
    "okalandrerades": "okalandrerad",
    "okalandrerads": "okalandrerad",
    "okalandrerat": "okalandrerad",
    "okalandrerats": "okalandrerad",
    "okalandrerbara": "okalandrerbar",
    "okalandrerbarare": "okalandrerbar",
    "okalandrerbarares": "okalandrerbar",
    "okalandrerbaras": "okalandrerbar",
    "okalandrerbarast": "okalandrerbar",
    "okalandrerbaraste": "okalandrerbar",
    "okalandrerbarastes": "okalandrerbar",
    "okalandrerbarasts": "okalandrerbar",
    "okalandrerbare": "okalandrerbar",
    "okalandrerbares": "okalandrerbar",
    "okalandrerbarheten": "okalandrerbarhet",
    "okalandrerbarhetens": "okalandrerbarhet",
    "okalandrerbarhets": "okalandrerbarhet",
    "okalandrerbars": "okalandrerbar",
    "okalandrerbart": "okalandrerbar",
    "okalandrerbarts": "okalandrerbar",
    "okalcinerade": "okalcinerad",
    "okalcinerades": "okalcinerad",
    "okalcinerads": "okalcinerad",
    "okalcinerat": "okalcinerad",
    "okalcinerats": "okalcinerad",
    "okalcinerbara": "okalcinerbar",
    "okalcinerbarare": "okalcinerbar",
    "okalcinerbarares": "okalcinerbar",
    "okalcinerbaras": "okalcinerbar",
    "okalcinerbarast": "okalcinerbar",
    "okalcinerbaraste": "okalcinerbar",
    "okalcinerbarastes": "okalcinerbar",
    "okalcinerbarasts": "okalcinerbar",
    "okalcinerbare": "okalcinerbar",
    "okalcinerbares": "okalcinerbar",
    "okalcinerbarheten": "okalcinerbarhet",
    "okalcinerbarhetens": "okalcinerbarhet",
    "okalcinerbarhets": "okalcinerbarhet",
    "okalcinerbars": "okalcinerbar",
    "okalcinerbart": "okalcinerbar",
    "okalcinerbarts": "okalcinerbar",
    "okalfatrade": "okalfatrad",
    "okalfatrades": "okalfatrad",
    "okalfatrads": "okalfatrad",
    "okalfatrat": "okalfatrad",
    "okalfatrats": "okalfatrad",
    "okalibrerade": "okalibrerad",
    "okalibrerades": "okalibrerad",
    "okalibrerads": "okalibrerad",
    "okalibrerat": "okalibrerad",
    "okalibrerats": "okalibrerad",
    "okalibrerbara": "okalibrerbar",
    "okalibrerbarare": "okalibrerbar",
    "okalibrerbarares": "okalibrerbar",
    "okalibrerbaras": "okalibrerbar",
    "okalibrerbarast": "okalibrerbar",
    "okalibrerbaraste": "okalibrerbar",
    "okalibrerbarastes": "okalibrerbar",
    "okalibrerbarasts": "okalibrerbar",
    "okalibrerbare": "okalibrerbar",
    "okalibrerbares": "okalibrerbar",
    "okalibrerbarheten": "okalibrerbarhet",
    "okalibrerbarhetens": "okalibrerbarhet",
    "okalibrerbarhets": "okalibrerbarhet",
    "okalibrerbars": "okalibrerbar",
    "okalibrerbart": "okalibrerbar",
    "okalibrerbarts": "okalibrerbar",
    "okalkade": "okalkad",
    "okalkades": "okalkad",
    "okalkads": "okalkad",
    "okalkat": "okalkad",
    "okalkats": "okalkad",
    "okalkerade": "okalkerad",
    "okalkerades": "okalkerad",
    "okalkerads": "okalkerad",
    "okalkerat": "okalkerad",
    "okalkerats": "okalkerad",
    "okalkerbara": "okalkerbar",
    "okalkerbarare": "okalkerbar",
    "okalkerbarares": "okalkerbar",
    "okalkerbaras": "okalkerbar",
    "okalkerbarast": "okalkerbar",
    "okalkerbaraste": "okalkerbar",
    "okalkerbarastes": "okalkerbar",
    "okalkerbarasts": "okalkerbar",
    "okalkerbare": "okalkerbar",
    "okalkerbares": "okalkerbar",
    "okalkerbarheten": "okalkerbarhet",
    "okalkerbarhetens": "okalkerbarhet",
    "okalkerbarhets": "okalkerbarhet",
    "okalkerbars": "okalkerbar",
    "okalkerbart": "okalkerbar",
    "okalkerbarts": "okalkerbar",
    "okalkylerade": "okalkylerad",
    "okalkylerades": "okalkylerad",
    "okalkylerads": "okalkylerad",
    "okalkylerat": "okalkylerad",
    "okalkylerats": "okalkylerad",
    "okalkylerbara": "okalkylerbar",
    "okalkylerbarare": "okalkylerbar",
    "okalkylerbarares": "okalkylerbar",
    "okalkylerbaras": "okalkylerbar",
    "okalkylerbarast": "okalkylerbar",
    "okalkylerbaraste": "okalkylerbar",
    "okalkylerbarastes": "okalkylerbar",
    "okalkylerbarasts": "okalkylerbar",
    "okalkylerbare": "okalkylerbar",
    "okalkylerbares": "okalkylerbar",
    "okalkylerbarheten": "okalkylerbarhet",
    "okalkylerbarhetens": "okalkylerbarhet",
    "okalkylerbarhets": "okalkylerbarhet",
    "okalkylerbars": "okalkylerbar",
    "okalkylerbart": "okalkylerbar",
    "okalkylerbarts": "okalkylerbar",
    "okallade": "okallad",
    "okallades": "okallad",
    "okallads": "okallad",
    "okallat": "okallad",
    "okallats": "okallad",
    "okallnade": "okallnad",
    "okallnades": "okallnad",
    "okallnads": "okallnad",
    "okallnat": "okallnad",
    "okallnats": "okallnad",
    "okalmerade": "okalmerad",
    "okalmerades": "okalmerad",
    "okalmerads": "okalmerad",
    "okalmerat": "okalmerad",
    "okalmerats": "okalmerad",
    "okalmerbara": "okalmerbar",
    "okalmerbarare": "okalmerbar",
    "okalmerbarares": "okalmerbar",
    "okalmerbaras": "okalmerbar",
    "okalmerbarast": "okalmerbar",
    "okalmerbaraste": "okalmerbar",
    "okalmerbarastes": "okalmerbar",
    "okalmerbarasts": "okalmerbar",
    "okalmerbare": "okalmerbar",
    "okalmerbares": "okalmerbar",
    "okalmerbarheten": "okalmerbarhet",
    "okalmerbarhetens": "okalmerbarhet",
    "okalmerbarhets": "okalmerbarhet",
    "okalmerbars": "okalmerbar",
    "okalmerbart": "okalmerbar",
    "okalmerbarts": "okalmerbar",
    "okammade": "okammad",
    "okammades": "okammad",
    "okammads": "okammad",
    "okammat": "okammad",
    "okammats": "okammad",
    "okamouflerade": "okamouflerad",
    "okamouflerades": "okamouflerad",
    "okamouflerads": "okamouflerad",
    "okamouflerat": "okamouflerad",
    "okamouflerats": "okamouflerad",
    "okamouflerbara": "okamouflerbar",
    "okamouflerbarare": "okamouflerbar",
    "okamouflerbarares": "okamouflerbar",
    "okamouflerbaras": "okamouflerbar",
    "okamouflerbarast": "okamouflerbar",
    "okamouflerbaraste": "okamouflerbar",
    "okamouflerbarastes": "okamouflerbar",
    "okamouflerbarasts": "okamouflerbar",
    "okamouflerbare": "okamouflerbar",
    "okamouflerbares": "okamouflerbar",
    "okamouflerbarheten": "okamouflerbarhet",
    "okamouflerbarhetens": "okamouflerbarhet",
    "okamouflerbarhets": "okamouflerbarhet",
    "okamouflerbars": "okamouflerbar",
    "okamouflerbart": "okamouflerbar",
    "okamouflerbarts": "okamouflerbar",
    "okamratliga": "okamratlig",
    "okamratligare": "okamratlig",
    "okamratligares": "okamratlig",
    "okamratligas": "okamratlig",
    "okamratligast": "okamratlig",
    "okamratligaste": "okamratlig",
    "okamratligastes": "okamratlig",
    "okamratligasts": "okamratlig",
    "okamratlige": "okamratlig",
    "okamratliges": "okamratlig",
    "okamratligheten": "okamratlighet",
    "okamratlighetens": "okamratlighet",
    "okamratligheter": "okamratlighet",
    "okamratligheterna": "okamratlighet",
    "okamratligheternas": "okamratlighet",
    "okamratligheters": "okamratlighet",
    "okamratlighets": "okamratlighet",
    "okamratligs": "okamratlig",
    "okamratligt": "okamratlig",
    "okamratligts": "okamratlig",
    "okanaliserade": "okanaliserad",
    "okanaliserades": "okanaliserad",
    "okanaliserads": "okanaliserad",
    "okanaliserat": "okanaliserad",
    "okanaliserats": "okanaliserad",
    "okanaliserbara": "okanaliserbar",
    "okanaliserbarare": "okanaliserbar",
    "okanaliserbarares": "okanaliserbar",
    "okanaliserbaras": "okanaliserbar",
    "okanaliserbarast": "okanaliserbar",
    "okanaliserbaraste": "okanaliserbar",
    "okanaliserbarastes": "okanaliserbar",
    "okanaliserbarasts": "okanaliserbar",
    "okanaliserbare": "okanaliserbar",
    "okanaliserbares": "okanaliserbar",
    "okanaliserbarheten": "okanaliserbarhet",
    "okanaliserbarhetens": "okanaliserbarhet",
    "okanaliserbarhets": "okanaliserbarhet",
    "okanaliserbars": "okanaliserbar",
    "okanaliserbart": "okanaliserbar",
    "okanaliserbarts": "okanaliserbar",
    "okande": "oka",
    "okanden": "okande",
    "okandena": "okande",
    "okandenas": "okande",
    "okandens": "okande",
    "okanderade": "okanderad",
    "okanderades": "okanderad",
    "okanderads": "okanderad",
    "okanderat": "okanderad",
    "okanderats": "okanderad",
    "okanderbara": "okanderbar",
    "okanderbarare": "okanderbar",
    "okanderbarares": "okanderbar",
    "okanderbaras": "okanderbar",
    "okanderbarast": "okanderbar",
    "okanderbaraste": "okanderbar",
    "okanderbarastes": "okanderbar",
    "okanderbarasts": "okanderbar",
    "okanderbare": "okanderbar",
    "okanderbares": "okanderbar",
    "okanderbarheten": "okanderbarhet",
    "okanderbarhetens": "okanderbarhet",
    "okanderbarhets": "okanderbarhet",
    "okanderbars": "okanderbar",
    "okanderbart": "okanderbar",
    "okanderbarts": "okanderbar",
    "okandes": "okande",
    "okandet": "okande",
    "okandets": "okande",
    "okandiderbara": "okandiderbar",
    "okandiderbarare": "okandiderbar",
    "okandiderbarares": "okandiderbar",
    "okandiderbaras": "okandiderbar",
    "okandiderbarast": "okandiderbar",
    "okandiderbaraste": "okandiderbar",
    "okandiderbarastes": "okandiderbar",
    "okandiderbarasts": "okandiderbar",
    "okandiderbare": "okandiderbar",
    "okandiderbares": "okandiderbar",
    "okandiderbarheten": "okandiderbarhet",
    "okandiderbarhetens": "okandiderbarhet",
    "okandiderbarhets": "okandiderbarhet",
    "okandiderbars": "okandiderbar",
    "okandiderbart": "okandiderbar",
    "okandiderbarts": "okandiderbar",
    "okannelerade": "okannelerad",
    "okannelerades": "okannelerad",
    "okannelerads": "okannelerad",
    "okannelerat": "okannelerad",
    "okannelerats": "okannelerad",
    "okannelerbara": "okannelerbar",
    "okannelerbarare": "okannelerbar",
    "okannelerbarares": "okannelerbar",
    "okannelerbaras": "okannelerbar",
    "okannelerbarast": "okannelerbar",
    "okannelerbaraste": "okannelerbar",
    "okannelerbarastes": "okannelerbar",
    "okannelerbarasts": "okannelerbar",
    "okannelerbare": "okannelerbar",
    "okannelerbares": "okannelerbar",
    "okannelerbarheten": "okannelerbarhet",
    "okannelerbarhetens": "okannelerbarhet",
    "okannelerbarhets": "okannelerbarhet",
    "okannelerbars": "okannelerbar",
    "okannelerbart": "okannelerbar",
    "okannelerbarts": "okannelerbar",
    "okanoniserade": "okanoniserad",
    "okanoniserades": "okanoniserad",
    "okanoniserads": "okanoniserad",
    "okanoniserat": "okanoniserad",
    "okanoniserats": "okanoniserad",
    "okanoniserbara": "okanoniserbar",
    "okanoniserbarare": "okanoniserbar",
    "okanoniserbarares": "okanoniserbar",
    "okanoniserbaras": "okanoniserbar",
    "okanoniserbarast": "okanoniserbar",
    "okanoniserbaraste": "okanoniserbar",
    "okanoniserbarastes": "okanoniserbar",
    "okanoniserbarasts": "okanoniserbar",
    "okanoniserbare": "okanoniserbar",
    "okanoniserbares": "okanoniserbar",
    "okanoniserbarheten": "okanoniserbarhet",
    "okanoniserbarhetens": "okanoniserbarhet",
    "okanoniserbarhets": "okanoniserbarhet",
    "okanoniserbars": "okanoniserbar",
    "okanoniserbart": "okanoniserbar",
    "okanoniserbarts": "okanoniserbar",
    "okantade": "okantad",
    "okantades": "okantad",
    "okantads": "okantad",
    "okantat": "okantad",
    "okantats": "okantad",
    "okantrade": "okantrad",
    "okantrades": "okantrad",
    "okantrads": "okantrad",
    "okantrat": "okantrad",
    "okantrats": "okantrad",
    "okapade": "okapad",
    "okapades": "okapad",
    "okapads": "okapad",
    "okapat": "okapad",
    "okapats": "okapad",
    "okapier": "okapi",
    "okapierna": "okapi",
    "okapiernas": "okapi",
    "okapiers": "okapi",
    "okapin": "okapi",
    "okapins": "okapi",
    "okapis": "okapi",
    "okapitaliserade": "okapitaliserad",
    "okapitaliserades": "okapitaliserad",
    "okapitaliserads": "okapitaliserad",
    "okapitaliserat": "okapitaliserad",
    "okapitaliserats": "okapitaliserad",
    "okapitaliserbara": "okapitaliserbar",
    "okapitaliserbarare": "okapitaliserbar",
    "okapitaliserbarares": "okapitaliserbar",
    "okapitaliserbaras": "okapitaliserbar",
    "okapitaliserbarast": "okapitaliserbar",
    "okapitaliserbaraste": "okapitaliserbar",
    "okapitaliserbarastes": "okapitaliserbar",
    "okapitaliserbarasts": "okapitaliserbar",
    "okapitaliserbare": "okapitaliserbar",
    "okapitaliserbares": "okapitaliserbar",
    "okapitaliserbarheten": "okapitaliserbarhet",
    "okapitaliserbarhetens": "okapitaliserbarhet",
    "okapitaliserbarhets": "okapitaliserbarhet",
    "okapitaliserbars": "okapitaliserbar",
    "okapitaliserbart": "okapitaliserbar",
    "okapitaliserbarts": "okapitaliserbar",
    "okapsejsade": "okapsejsad",
    "okapsejsades": "okapsejsad",
    "okapsejsads": "okapsejsad",
    "okapsejsat": "okapsejsad",
    "okapsejsats": "okapsejsad",
    "okapslade": "okapslad",
    "okapslades": "okapslad",
    "okapslads": "okapslad",
    "okapslat": "okapslad",
    "okapslats": "okapslad",
    "okar": "oka",
    "okarade": "okarad",
    "okarades": "okarad",
    "okarads": "okarad",
    "okarakteriserade": "okarakteriserad",
    "okarakteriserades": "okarakteriserad",
    "okarakteriserads": "okarakteriserad",
    "okarakteriserat": "okarakteriserad",
    "okarakteriserats": "okarakteriserad",
    "okarakteriserbara": "okarakteriserbar",
    "okarakteriserbarare": "okarakteriserbar",
    "okarakteriserbarares": "okarakteriserbar",
    "okarakteriserbaras": "okarakteriserbar",
    "okarakteriserbarast": "okarakteriserbar",
    "okarakteriserbaraste": "okarakteriserbar",
    "okarakteriserbarastes": "okarakteriserbar",
    "okarakteriserbarasts": "okarakteriserbar",
    "okarakteriserbare": "okarakteriserbar",
    "okarakteriserbares": "okarakteriserbar",
    "okarakteriserbarheten": "okarakteriserbarhet",
    "okarakteriserbarhetens": "okarakteriserbarhet",
    "okarakteriserbarhets": "okarakteriserbarhet",
    "okarakteriserbars": "okarakteriserbar",
    "okarakteriserbart": "okarakteriserbar",
    "okarakteriserbarts": "okarakteriserbar",
    "okaraktäriserade": "okaraktäriserad",
    "okaraktäriserades": "okaraktäriserad",
    "okaraktäriserads": "okaraktäriserad",
    "okaraktäriserat": "okaraktäriserad",
    "okaraktäriserats": "okaraktäriserad",
    "okaraktäriserbara": "okaraktäriserbar",
    "okaraktäriserbarare": "okaraktäriserbar",
    "okaraktäriserbarares": "okaraktäriserbar",
    "okaraktäriserbaras": "okaraktäriserbar",
    "okaraktäriserbarast": "okaraktäriserbar",
    "okaraktäriserbaraste": "okaraktäriserbar",
    "okaraktäriserbarastes": "okaraktäriserbar",
    "okaraktäriserbarasts": "okaraktäriserbar",
    "okaraktäriserbare": "okaraktäriserbar",
    "okaraktäriserbares": "okaraktäriserbar",
    "okaraktäriserbarheten": "okaraktäriserbarhet",
    "okaraktäriserbarhetens": "okaraktäriserbarhet",
    "okaraktäriserbarhets": "okaraktäriserbarhet",
    "okaraktäriserbars": "okaraktäriserbar",
    "okaraktäriserbart": "okaraktäriserbar",
    "okaraktäriserbarts": "okaraktäriserbar",
    "okarambolerade": "okarambolerad",
    "okarambolerades": "okarambolerad",
    "okarambolerads": "okarambolerad",
    "okarambolerat": "okarambolerad",
    "okarambolerats": "okarambolerad",
    "okarambolerbara": "okarambolerbar",
    "okarambolerbarare": "okarambolerbar",
    "okarambolerbarares": "okarambolerbar",
    "okarambolerbaras": "okarambolerbar",
    "okarambolerbarast": "okarambolerbar",
    "okarambolerbaraste": "okarambolerbar",
    "okarambolerbarastes": "okarambolerbar",
    "okarambolerbarasts": "okarambolerbar",
    "okarambolerbare": "okarambolerbar",
    "okarambolerbares": "okarambolerbar",
    "okarambolerbarheten": "okarambolerbarhet",
    "okarambolerbarhetens": "okarambolerbarhet",
    "okarambolerbarhets": "okarambolerbarhet",
    "okarambolerbars": "okarambolerbar",
    "okarambolerbart": "okarambolerbar",
    "okarambolerbarts": "okarambolerbar",
    "okarat": "okarad",
    "okarats": "okarad",
    "okarboniserade": "okarboniserad",
    "okarboniserades": "okarboniserad",
    "okarboniserads": "okarboniserad",
    "okarboniserat": "okarboniserad",
    "okarboniserats": "okarboniserad",
    "okarboniserbara": "okarboniserbar",
    "okarboniserbarare": "okarboniserbar",
    "okarboniserbarares": "okarboniserbar",
    "okarboniserbaras": "okarboniserbar",
    "okarboniserbarast": "okarboniserbar",
    "okarboniserbaraste": "okarboniserbar",
    "okarboniserbarastes": "okarboniserbar",
    "okarboniserbarasts": "okarboniserbar",
    "okarboniserbare": "okarboniserbar",
    "okarboniserbares": "okarboniserbar",
    "okarboniserbarheten": "okarboniserbarhet",
    "okarboniserbarhetens": "okarboniserbarhet",
    "okarboniserbarhets": "okarboniserbarhet",
    "okarboniserbars": "okarboniserbar",
    "okarboniserbart": "okarboniserbar",
    "okarboniserbarts": "okarboniserbar",
    "okardade": "okardad",
    "okardades": "okardad",
    "okardads": "okardad",
    "okardat": "okardad",
    "okardats": "okardad",
    "okarikerade": "okarikerad",
    "okarikerades": "okarikerad",
    "okarikerads": "okarikerad",
    "okarikerat": "okarikerad",
    "okarikerats": "okarikerad",
    "okarikerbara": "okarikerbar",
    "okarikerbarare": "okarikerbar",
    "okarikerbarares": "okarikerbar",
    "okarikerbaras": "okarikerbar",
    "okarikerbarast": "okarikerbar",
    "okarikerbaraste": "okarikerbar",
    "okarikerbarastes": "okarikerbar",
    "okarikerbarasts": "okarikerbar",
    "okarikerbare": "okarikerbar",
    "okarikerbares": "okarikerbar",
    "okarikerbarheten": "okarikerbarhet",
    "okarikerbarhetens": "okarikerbarhet",
    "okarikerbarhets": "okarikerbarhet",
    "okarikerbars": "okarikerbar",
    "okarikerbart": "okarikerbar",
    "okarikerbarts": "okarikerbar",
    "okarinan": "okarina",
    "okarinans": "okarina",
    "okarinas": "okarina",
    "okarinor": "okarina",
    "okarinorna": "okarina",
    "okarinornas": "okarina",
    "okarinors": "okarina",
    "okarterade": "okarterad",
    "okarterades": "okarterad",
    "okarterads": "okarterad",
    "okarterat": "okarterad",
    "okarterats": "okarterad",
    "okarterbara": "okarterbar",
    "okarterbarare": "okarterbar",
    "okarterbarares": "okarterbar",
    "okarterbaras": "okarterbar",
    "okarterbarast": "okarterbar",
    "okarterbaraste": "okarterbar",
    "okarterbarastes": "okarterbar",
    "okarterbarasts": "okarterbar",
    "okarterbare": "okarterbar",
    "okarterbares": "okarterbar",
    "okarterbarheten": "okarterbarhet",
    "okarterbarhetens": "okarterbarhet",
    "okarterbarhets": "okarterbarhet",
    "okarterbars": "okarterbar",
    "okarterbart": "okarterbar",
    "okarterbarts": "okarterbar",
    "okartonnerade": "okartonnerad",
    "okartonnerades": "okartonnerad",
    "okartonnerads": "okartonnerad",
    "okartonnerat": "okartonnerad",
    "okartonnerats": "okartonnerad",
    "okartonnerbara": "okartonnerbar",
    "okartonnerbarare": "okartonnerbar",
    "okartonnerbarares": "okartonnerbar",
    "okartonnerbaras": "okartonnerbar",
    "okartonnerbarast": "okartonnerbar",
    "okartonnerbaraste": "okartonnerbar",
    "okartonnerbarastes": "okartonnerbar",
    "okartonnerbarasts": "okartonnerbar",
    "okartonnerbare": "okartonnerbar",
    "okartonnerbares": "okartonnerbar",
    "okartonnerbarheten": "okartonnerbarhet",
    "okartonnerbarhetens": "okartonnerbarhet",
    "okartonnerbarhets": "okartonnerbarhet",
    "okartonnerbars": "okartonnerbar",
    "okartonnerbart": "okartonnerbar",
    "okartonnerbarts": "okartonnerbar",
    "okarvade": "okarvad",
    "okarvades": "okarvad",
    "okarvads": "okarvad",
    "okarvat": "okarvad",
    "okarvats": "okarvad",
    "okas": "oka",
    "okasserade": "okasserad",
    "okasserades": "okasserad",
    "okasserads": "okasserad",
    "okasserat": "okasserad",
    "okasserats": "okasserad",
    "okasserbara": "okasserbar",
    "okasserbarare": "okasserbar",
    "okasserbarares": "okasserbar",
    "okasserbaras": "okasserbar",
    "okasserbarast": "okasserbar",
    "okasserbaraste": "okasserbar",
    "okasserbarastes": "okasserbar",
    "okasserbarasts": "okasserbar",
    "okasserbare": "okasserbar",
    "okasserbares": "okasserbar",
    "okasserbarheten": "okasserbarhet",
    "okasserbarhetens": "okasserbarhet",
    "okasserbarhets": "okasserbarhet",
    "okasserbars": "okasserbar",
    "okasserbart": "okasserbar",
    "okasserbarts": "okasserbar",
    "okastade": "okastad",
    "okastades": "okastad",
    "okastads": "okastad",
    "okastat": "okastad",
    "okastats": "okastad",
    "okastrerade": "okastrerad",
    "okastrerades": "okastrerad",
    "okastrerads": "okastrerad",
    "okastrerat": "okastrerad",
    "okastrerats": "okastrerad",
    "okastrerbara": "okastrerbar",
    "okastrerbarare": "okastrerbar",
    "okastrerbarares": "okastrerbar",
    "okastrerbaras": "okastrerbar",
    "okastrerbarast": "okastrerbar",
    "okastrerbaraste": "okastrerbar",
    "okastrerbarastes": "okastrerbar",
    "okastrerbarasts": "okastrerbar",
    "okastrerbare": "okastrerbar",
    "okastrerbares": "okastrerbar",
    "okastrerbarheten": "okastrerbarhet",
    "okastrerbarhetens": "okastrerbarhet",
    "okastrerbarhets": "okastrerbarhet",
    "okastrerbars": "okastrerbar",
    "okastrerbart": "okastrerbar",
    "okastrerbarts": "okastrerbar",
    "okat": "oka",
    "okatalogiserade": "okatalogiserad",
    "okatalogiserades": "okatalogiserad",
    "okatalogiserads": "okatalogiserad",
    "okatalogiserat": "okatalogiserad",
    "okatalogiserats": "okatalogiserad",
    "okatalogiserbara": "okatalogiserbar",
    "okatalogiserbarare": "okatalogiserbar",
    "okatalogiserbarares": "okatalogiserbar",
    "okatalogiserbaras": "okatalogiserbar",
    "okatalogiserbarast": "okatalogiserbar",
    "okatalogiserbaraste": "okatalogiserbar",
    "okatalogiserbarastes": "okatalogiserbar",
    "okatalogiserbarasts": "okatalogiserbar",
    "okatalogiserbare": "okatalogiserbar",
    "okatalogiserbares": "okatalogiserbar",
    "okatalogiserbarheten": "okatalogiserbarhet",
    "okatalogiserbarhetens": "okatalogiserbarhet",
    "okatalogiserbarhets": "okatalogiserbarhet",
    "okatalogiserbars": "okatalogiserbar",
    "okatalogiserbart": "okatalogiserbar",
    "okatalogiserbarts": "okatalogiserbar",
    "okatalyserade": "okatalyserad",
    "okatalyserades": "okatalyserad",
    "okatalyserads": "okatalyserad",
    "okatalyserat": "okatalyserad",
    "okatalyserats": "okatalyserad",
    "okatalyserbara": "okatalyserbar",
    "okatalyserbarare": "okatalyserbar",
    "okatalyserbarares": "okatalyserbar",
    "okatalyserbaras": "okatalyserbar",
    "okatalyserbarast": "okatalyserbar",
    "okatalyserbaraste": "okatalyserbar",
    "okatalyserbarastes": "okatalyserbar",
    "okatalyserbarasts": "okatalyserbar",
    "okatalyserbare": "okatalyserbar",
    "okatalyserbares": "okatalyserbar",
    "okatalyserbarheten": "okatalyserbarhet",
    "okatalyserbarhetens": "okatalyserbarhet",
    "okatalyserbarhets": "okatalyserbarhet",
    "okatalyserbars": "okatalyserbar",
    "okatalyserbart": "okatalyserbar",
    "okatalyserbarts": "okatalyserbar",
    "okategoriserade": "okategoriserad",
    "okategoriserades": "okategoriserad",
    "okategoriserads": "okategoriserad",
    "okategoriserat": "okategoriserad",
    "okategoriserats": "okategoriserad",
    "okategoriserbara": "okategoriserbar",
    "okategoriserbarare": "okategoriserbar",
    "okategoriserbarares": "okategoriserbar",
    "okategoriserbaras": "okategoriserbar",
    "okategoriserbarast": "okategoriserbar",
    "okategoriserbaraste": "okategoriserbar",
    "okategoriserbarastes": "okategoriserbar",
    "okategoriserbarasts": "okategoriserbar",
    "okategoriserbare": "okategoriserbar",
    "okategoriserbares": "okategoriserbar",
    "okategoriserbarheten": "okategoriserbarhet",
    "okategoriserbarhetens": "okategoriserbarhet",
    "okategoriserbarhets": "okategoriserbarhet",
    "okategoriserbars": "okategoriserbar",
    "okategoriserbart": "okategoriserbar",
    "okategoriserbarts": "okategoriserbar",
    "okateteriserade": "okateteriserad",
    "okateteriserades": "okateteriserad",
    "okateteriserads": "okateteriserad",
    "okateteriserat": "okateteriserad",
    "okateteriserats": "okateteriserad",
    "okateteriserbara": "okateteriserbar",
    "okateteriserbarare": "okateteriserbar",
    "okateteriserbarares": "okateteriserbar",
    "okateteriserbaras": "okateteriserbar",
    "okateteriserbarast": "okateteriserbar",
    "okateteriserbaraste": "okateteriserbar",
    "okateteriserbarastes": "okateteriserbar",
    "okateteriserbarasts": "okateteriserbar",
    "okateteriserbare": "okateteriserbar",
    "okateteriserbares": "okateteriserbar",
    "okateteriserbarheten": "okateteriserbarhet",
    "okateteriserbarhetens": "okateteriserbarhet",
    "okateteriserbarhets": "okateteriserbarhet",
    "okateteriserbars": "okateteriserbar",
    "okateteriserbart": "okateteriserbar",
    "okateteriserbarts": "okateteriserbar",
    "okatetriserade": "okatetriserad",
    "okatetriserades": "okatetriserad",
    "okatetriserads": "okatetriserad",
    "okatetriserat": "okatetriserad",
    "okatetriserats": "okatetriserad",
    "okatetriserbara": "okatetriserbar",
    "okatetriserbarare": "okatetriserbar",
    "okatetriserbarares": "okatetriserbar",
    "okatetriserbaras": "okatetriserbar",
    "okatetriserbarast": "okatetriserbar",
    "okatetriserbaraste": "okatetriserbar",
    "okatetriserbarastes": "okatetriserbar",
    "okatetriserbarasts": "okatetriserbar",
    "okatetriserbare": "okatetriserbar",
    "okatetriserbares": "okatetriserbar",
    "okatetriserbarheten": "okatetriserbarhet",
    "okatetriserbarhetens": "okatetriserbarhet",
    "okatetriserbarhets": "okatetriserbarhet",
    "okatetriserbars": "okatetriserbar",
    "okatetriserbart": "okatetriserbar",
    "okatetriserbarts": "okatetriserbar",
    "okats": "oka",
    "okattade": "okattad",
    "okattades": "okattad",
    "okattads": "okattad",
    "okattat": "okattad",
    "okattats": "okattad",
    "okauteriserade": "okauteriserad",
    "okauteriserades": "okauteriserad",
    "okauteriserads": "okauteriserad",
    "okauteriserat": "okauteriserad",
    "okauteriserats": "okauteriserad",
    "okauteriserbara": "okauteriserbar",
    "okauteriserbarare": "okauteriserbar",
    "okauteriserbarares": "okauteriserbar",
    "okauteriserbaras": "okauteriserbar",
    "okauteriserbarast": "okauteriserbar",
    "okauteriserbaraste": "okauteriserbar",
    "okauteriserbarastes": "okauteriserbar",
    "okauteriserbarasts": "okauteriserbar",
    "okauteriserbare": "okauteriserbar",
    "okauteriserbares": "okauteriserbar",
    "okauteriserbarheten": "okauteriserbarhet",
    "okauteriserbarhetens": "okauteriserbarhet",
    "okauteriserbarhets": "okauteriserbarhet",
    "okauteriserbars": "okauteriserbar",
    "okauteriserbart": "okauteriserbar",
    "okauteriserbarts": "okauteriserbar",
    "okavlade": "okavlad",
    "okavlades": "okavlad",
    "okavlads": "okavlad",
    "okavlat": "okavlad",
    "okavlats": "okavlad",
    "okbenen": "okben",
    "okbenens": "okben",
    "okbenet": "okben",
    "okbenets": "okben",
    "okbens": "okben",
    "okbåg": "okbåge",
    "okbågar": "okbåge",
    "okbågarna": "okbåge",
    "okbågarnas": "okbåge",
    "okbågars": "okbåge",
    "okbågen": "okbåge",
    "okbågens": "okbåge",
    "okbåges": "okbåge",
    "okbågs": "okbåge",
    "okedjade": "okedjad",
    "okedjades": "okedjad",
    "okedjads": "okedjad",
    "okedjat": "okedjad",
    "okedjats": "okedjad",
    "oken": "ok",
    "okens": "ok",
    "oket": "ok",
    "okets": "ok",
    "okickade": "okickad",
    "okickades": "okickad",
    "okickads": "okickad",
    "okickat": "okickad",
    "okickats": "okickad",
    "okidnappade": "okidnappad",
    "okidnappades": "okidnappad",
    "okidnappads": "okidnappad",
    "okidnappat": "okidnappad",
    "okidnappats": "okidnappad",
    "okikade": "okikad",
    "okikades": "okikad",
    "okikads": "okikad",
    "okikat": "okikad",
    "okikats": "okikad",
    "okilade": "okilad",
    "okilades": "okilad",
    "okilads": "okilad",
    "okilat": "okilad",
    "okilats": "okilad",
    "okillade": "okillad",
    "okillades": "okillad",
    "okillads": "okillad",
    "okillat": "okillad",
    "okillats": "okillad",
    "okirrade": "okirrad",
    "okirrades": "okirrad",
    "okirrads": "okirrad",
    "okirrat": "okirrad",
    "okirrats": "okirrad",
    "okissade": "okissad",
    "okissades": "okissad",
    "okissads": "okissad",
    "okissat": "okissad",
    "okissats": "okissad",
    "okittade": "okittad",
    "okittades": "okittad",
    "okittads": "okittad",
    "okittat": "okittad",
    "okittats": "okittad",
    "okittlade": "okittlad",
    "okittlades": "okittlad",
    "okittlads": "okittlad",
    "okittlat": "okittlad",
    "okittlats": "okittlad",
    "oklackade": "oklackad",
    "oklackades": "oklackad",
    "oklackads": "oklackad",
    "oklackat": "oklackad",
    "oklackats": "oklackad",
    "oklampade": "oklampad",
    "oklampades": "oklampad",
    "oklampads": "oklampad",
    "oklampat": "oklampad",
    "oklampats": "oklampad",
    "oklamrade": "oklamrad",
    "oklamrades": "oklamrad",
    "oklamrads": "oklamrad",
    "oklamrat": "oklamrad",
    "oklamrats": "oklamrad",
    "oklanderliga": "oklanderlig",
    "oklanderligare": "oklanderlig",
    "oklanderligares": "oklanderlig",
    "oklanderligas": "oklanderlig",
    "oklanderligast": "oklanderlig",
    "oklanderligaste": "oklanderlig",
    "oklanderligastes": "oklanderlig",
    "oklanderligasts": "oklanderlig",
    "oklanderlige": "oklanderlig",
    "oklanderliges": "oklanderlig",
    "oklanderligheten": "oklanderlighet",
    "oklanderlighetens": "oklanderlighet",
    "oklanderlighets": "oklanderlighet",
    "oklanderligs": "oklanderlig",
    "oklanderligt": "oklanderlig",
    "oklanderligts": "oklanderlig",
    "oklandrade": "oklandrad",
    "oklandrades": "oklandrad",
    "oklandrads": "oklandrad",
    "oklandrat": "oklandrad",
    "oklandrats": "oklandrad",
    "oklappade": "oklappad",
    "oklappades": "oklappad",
    "oklappads": "oklappad",
    "oklappat": "oklappad",
    "oklappats": "oklappad",
    "oklara": "oklar",
    "oklarade": "oklarad",
    "oklarades": "oklarad",
    "oklarads": "oklarad",
    "oklarare": "oklar",
    "oklarares": "oklar",
    "oklaras": "oklar",
    "oklarast": "oklar",
    "oklaraste": "oklar",
    "oklarastes": "oklar",
    "oklarasts": "oklar",
    "oklarat": "oklarad",
    "oklarats": "oklarad",
    "oklare": "oklar",
    "oklarerade": "oklarerad",
    "oklarerades": "oklarerad",
    "oklarerads": "oklarerad",
    "oklarerat": "oklarerad",
    "oklarerats": "oklarerad",
    "oklarerbara": "oklarerbar",
    "oklarerbarare": "oklarerbar",
    "oklarerbarares": "oklarerbar",
    "oklarerbaras": "oklarerbar",
    "oklarerbarast": "oklarerbar",
    "oklarerbaraste": "oklarerbar",
    "oklarerbarastes": "oklarerbar",
    "oklarerbarasts": "oklarerbar",
    "oklarerbare": "oklarerbar",
    "oklarerbares": "oklarerbar",
    "oklarerbarheten": "oklarerbarhet",
    "oklarerbarhetens": "oklarerbarhet",
    "oklarerbarhets": "oklarerbarhet",
    "oklarerbars": "oklarerbar",
    "oklarerbart": "oklarerbar",
    "oklarerbarts": "oklarerbar",
    "oklares": "oklar",
    "oklarheten": "oklarhet",
    "oklarhetens": "oklarhet",
    "oklarheter": "oklarhet",
    "oklarheterna": "oklarhet",
    "oklarheternas": "oklarhet",
    "oklarheters": "oklarhet",
    "oklarhets": "oklarhet",
    "oklars": "oklar",
    "oklart": "oklar",
    "oklarts": "oklar",
    "oklassade": "oklassad",
    "oklassades": "oklassad",
    "oklassads": "oklassad",
    "oklassat": "oklassad",
    "oklassats": "oklassad",
    "oklassificerade": "oklassificerad",
    "oklassificerades": "oklassificerad",
    "oklassificerads": "oklassificerad",
    "oklassificerat": "oklassificerad",
    "oklassificerats": "oklassificerad",
    "oklassificerbara": "oklassificerbar",
    "oklassificerbarare": "oklassificerbar",
    "oklassificerbarares": "oklassificerbar",
    "oklassificerbaras": "oklassificerbar",
    "oklassificerbarast": "oklassificerbar",
    "oklassificerbaraste": "oklassificerbar",
    "oklassificerbarastes": "oklassificerbar",
    "oklassificerbarasts": "oklassificerbar",
    "oklassificerbare": "oklassificerbar",
    "oklassificerbares": "oklassificerbar",
    "oklassificerbarheten": "oklassificerbarhet",
    "oklassificerbarhetens": "oklassificerbarhet",
    "oklassificerbarhets": "oklassificerbarhet",
    "oklassificerbars": "oklassificerbar",
    "oklassificerbart": "oklassificerbar",
    "oklassificerbarts": "oklassificerbar",
    "oklatschade": "oklatschad",
    "oklatschades": "oklatschad",
    "oklatschads": "oklatschad",
    "oklatschat": "oklatschad",
    "oklatschats": "oklatschad",
    "oklenade": "oklenad",
    "oklenades": "oklenad",
    "oklenads": "oklenad",
    "oklenat": "oklenad",
    "oklenats": "oklenad",
    "okletade": "okletad",
    "okletades": "okletad",
    "okletads": "okletad",
    "okletat": "okletad",
    "okletats": "okletad",
    "okliade": "okliad",
    "okliades": "okliad",
    "okliads": "okliad",
    "okliat": "okliad",
    "okliats": "okliad",
    "oklippta": "oklippt",
    "oklipptare": "oklippt",
    "oklipptares": "oklippt",
    "oklipptas": "oklippt",
    "oklipptast": "oklippt",
    "oklipptaste": "oklippt",
    "oklipptastes": "oklippt",
    "oklipptasts": "oklippt",
    "oklippte": "oklippt",
    "oklipptes": "oklippt",
    "oklippts": "oklippt",
    "oklirade": "oklirad",
    "oklirades": "oklirad",
    "oklirads": "oklirad",
    "oklirat": "oklirad",
    "oklirats": "oklirad",
    "oklistrade": "oklistrad",
    "oklistrades": "oklistrad",
    "oklistrads": "oklistrad",
    "oklistrat": "oklistrad",
    "oklistrats": "oklistrad",
    "oklockade": "oklockad",
    "oklockades": "oklockad",
    "oklockads": "oklockad",
    "oklockat": "oklockad",
    "oklockats": "oklockad",
    "okloka": "oklok",
    "oklokare": "oklok",
    "oklokares": "oklok",
    "oklokas": "oklok",
    "oklokast": "oklok",
    "oklokaste": "oklok",
    "oklokastes": "oklok",
    "oklokasts": "oklok",
    "okloke": "oklok",
    "oklokes": "oklok",
    "oklokheten": "oklokhet",
    "oklokhetens": "oklokhet",
    "oklokhets": "oklokhet",
    "okloks": "oklok",
    "oklokt": "oklok",
    "oklokts": "oklok",
    "oklonade": "oklonad",
    "oklonades": "oklonad",
    "oklonads": "oklonad",
    "oklonat": "oklonad",
    "oklonats": "oklonad",
    "oklorerade": "oklorerad",
    "oklorerades": "oklorerad",
    "oklorerads": "oklorerad",
    "oklorerat": "oklorerad",
    "oklorerats": "oklorerad",
    "oklorerbara": "oklorerbar",
    "oklorerbarare": "oklorerbar",
    "oklorerbarares": "oklorerbar",
    "oklorerbaras": "oklorerbar",
    "oklorerbarast": "oklorerbar",
    "oklorerbaraste": "oklorerbar",
    "oklorerbarastes": "oklorerbar",
    "oklorerbarasts": "oklorerbar",
    "oklorerbare": "oklorerbar",
    "oklorerbares": "oklorerbar",
    "oklorerbarheten": "oklorerbarhet",
    "oklorerbarhetens": "oklorerbarhet",
    "oklorerbarhets": "oklorerbarhet",
    "oklorerbars": "oklorerbar",
    "oklorerbart": "oklorerbar",
    "oklorerbarts": "oklorerbar",
    "oklottrade": "oklottrad",
    "oklottrades": "oklottrad",
    "oklottrads": "oklottrad",
    "oklottrat": "oklottrad",
    "oklottrats": "oklottrad",
    "oklubbade": "oklubbad",
    "oklubbades": "oklubbad",
    "oklubbads": "oklubbad",
    "oklubbat": "oklubbad",
    "oklubbats": "oklubbad",
    "okluddade": "okluddad",
    "okluddades": "okluddad",
    "okluddads": "okluddad",
    "okluddat": "okluddad",
    "okluddats": "okluddad",
    "oklyftade": "oklyftad",
    "oklyftades": "oklyftad",
    "oklyftads": "oklyftad",
    "oklyftat": "oklyftad",
    "oklyftats": "oklyftad",
    "okläckta": "okläckt",
    "okläcktas": "okläckt",
    "okläckte": "okläckt",
    "okläcktes": "okläckt",
    "okläckts": "okläckt",
    "oklädda": "oklädd",
    "okläddare": "oklädd",
    "okläddares": "oklädd",
    "okläddas": "oklädd",
    "okläddast": "oklädd",
    "okläddaste": "oklädd",
    "okläddastes": "oklädd",
    "okläddasts": "oklädd",
    "oklädde": "oklädd",
    "okläddes": "oklädd",
    "okläddheten": "okläddhet",
    "okläddhetens": "okläddhet",
    "okläddhets": "okläddhet",
    "oklädds": "oklädd",
    "oklämde": "oklämd",
    "oklämdes": "oklämd",
    "oklämds": "oklämd",
    "oklämt": "oklämd",
    "oklämts": "oklämd",
    "oklängde": "oklängd",
    "oklängdes": "oklängd",
    "oklängds": "oklängd",
    "oklängt": "oklängd",
    "oklängts": "oklängd",
    "oklätt": "oklädd",
    "oklättrade": "oklättrad",
    "oklättrades": "oklättrad",
    "oklättrads": "oklättrad",
    "oklättrat": "oklättrad",
    "oklättrats": "oklättrad",
    "oklätts": "oklädd",
    "oklösta": "oklöst",
    "oklöstas": "oklöst",
    "oklöste": "oklöst",
    "oklöstes": "oklöst",
    "oklösts": "oklöst",
    "oklövjade": "oklövjad",
    "oklövjades": "oklövjad",
    "oklövjads": "oklövjad",
    "oklövjat": "oklövjad",
    "oklövjats": "oklövjad",
    "oknackade": "oknackad",
    "oknackades": "oknackad",
    "oknackads": "oknackad",
    "oknackat": "oknackad",
    "oknackats": "oknackad",
    "oknaprade": "oknaprad",
    "oknaprades": "oknaprad",
    "oknaprads": "oknaprad",
    "oknaprat": "oknaprad",
    "oknaprats": "oknaprad",
    "oknarkade": "oknarkad",
    "oknarkades": "oknarkad",
    "oknarkads": "oknarkad",
    "oknarkat": "oknarkad",
    "oknarkats": "oknarkad",
    "oknatade": "oknatad",
    "oknatades": "oknatad",
    "oknatads": "oknatad",
    "oknatat": "oknatad",
    "oknatats": "oknatad",
    "oknipsade": "oknipsad",
    "oknipsades": "oknipsad",
    "oknipsads": "oknipsad",
    "oknipsat": "oknipsad",
    "oknipsats": "oknipsad",
    "oknivade": "oknivad",
    "oknivades": "oknivad",
    "oknivads": "oknivad",
    "oknivat": "oknivad",
    "oknivats": "oknivad",
    "oknockade": "oknockad",
    "oknockades": "oknockad",
    "oknockads": "oknockad",
    "oknockat": "oknockad",
    "oknockats": "oknockad",
    "oknollrade": "oknollrad",
    "oknollrades": "oknollrad",
    "oknollrads": "oknollrad",
    "oknollrat": "oknollrad",
    "oknollrats": "oknollrad",
    "oknopade": "oknopad",
    "oknopades": "oknopad",
    "oknopads": "oknopad",
    "oknopat": "oknopad",
    "oknopats": "oknopad",
    "oknorvade": "oknorvad",
    "oknorvades": "oknorvad",
    "oknorvads": "oknorvad",
    "oknorvat": "oknorvad",
    "oknorvats": "oknorvad",
    "oknuffade": "oknuffad",
    "oknuffades": "oknuffad",
    "oknuffads": "oknuffad",
    "oknuffat": "oknuffad",
    "oknuffats": "oknuffad",
    "oknullade": "oknullad",
    "oknullades": "oknullad",
    "oknullads": "oknullad",
    "oknullat": "oknullad",
    "oknullats": "oknullad",
    "oknycklade": "oknycklad",
    "oknycklades": "oknycklad",
    "oknycklads": "oknycklad",
    "oknycklat": "oknycklad",
    "oknycklats": "oknycklad",
    "oknyckta": "oknyckt",
    "oknycktas": "oknyckt",
    "oknyckte": "oknyckt",
    "oknycktes": "oknyckt",
    "oknyckts": "oknyckt",
    "oknypplade": "oknypplad",
    "oknypplades": "oknypplad",
    "oknypplads": "oknypplad",
    "oknypplat": "oknypplad",
    "oknypplats": "oknypplad",
    "oknyttet": "oknytt",
    "oknyttets": "oknytt",
    "oknytts": "oknytt",
    "oknäade": "oknäad",
    "oknäades": "oknäad",
    "oknäads": "oknäad",
    "oknäat": "oknäad",
    "oknäats": "oknäad",
    "oknäböjde": "oknäböjd",
    "oknäböjdes": "oknäböjd",
    "oknäböjds": "oknäböjd",
    "oknäböjt": "oknäböjd",
    "oknäböjts": "oknäböjd",
    "oknäckta": "oknäckt",
    "oknäcktas": "oknäckt",
    "oknäckte": "oknäckt",
    "oknäcktes": "oknäckt",
    "oknäckts": "oknäckt",
    "oknäppta": "oknäppt",
    "oknäpptas": "oknäppt",
    "oknäppte": "oknäppt",
    "oknäpptes": "oknäppt",
    "oknäppts": "oknäppt",
    "oknådade": "oknådad",
    "oknådades": "oknådad",
    "oknådads": "oknådad",
    "oknådat": "oknådad",
    "oknådats": "oknådad",
    "oknölade": "oknölad",
    "oknölades": "oknölad",
    "oknölads": "oknölad",
    "oknölat": "oknölad",
    "oknölats": "oknölad",
    "okoafferade": "okoafferad",
    "okoafferades": "okoafferad",
    "okoafferads": "okoafferad",
    "okoafferat": "okoafferad",
    "okoafferats": "okoafferad",
    "okoafferbara": "okoafferbar",
    "okoafferbarare": "okoafferbar",
    "okoafferbarares": "okoafferbar",
    "okoafferbaras": "okoafferbar",
    "okoafferbarast": "okoafferbar",
    "okoafferbaraste": "okoafferbar",
    "okoafferbarastes": "okoafferbar",
    "okoafferbarasts": "okoafferbar",
    "okoafferbare": "okoafferbar",
    "okoafferbares": "okoafferbar",
    "okoafferbarheten": "okoafferbarhet",
    "okoafferbarhetens": "okoafferbarhet",
    "okoafferbarhets": "okoafferbarhet",
    "okoafferbars": "okoafferbar",
    "okoafferbart": "okoafferbar",
    "okoafferbarts": "okoafferbar",
    "okoagulerade": "okoagulerad",
    "okoagulerades": "okoagulerad",
    "okoagulerads": "okoagulerad",
    "okoagulerat": "okoagulerad",
    "okoagulerats": "okoagulerad",
    "okoagulerbara": "okoagulerbar",
    "okoagulerbarare": "okoagulerbar",
    "okoagulerbarares": "okoagulerbar",
    "okoagulerbaras": "okoagulerbar",
    "okoagulerbarast": "okoagulerbar",
    "okoagulerbaraste": "okoagulerbar",
    "okoagulerbarastes": "okoagulerbar",
    "okoagulerbarasts": "okoagulerbar",
    "okoagulerbare": "okoagulerbar",
    "okoagulerbares": "okoagulerbar",
    "okoagulerbarheten": "okoagulerbarhet",
    "okoagulerbarhetens": "okoagulerbarhet",
    "okoagulerbarhets": "okoagulerbarhet",
    "okoagulerbars": "okoagulerbar",
    "okoagulerbart": "okoagulerbar",
    "okoagulerbarts": "okoagulerbar",
    "okodade": "okodad",
    "okodades": "okodad",
    "okodads": "okodad",
    "okodat": "okodad",
    "okodats": "okodad",
    "okodifierade": "okodifierad",
    "okodifierades": "okodifierad",
    "okodifierads": "okodifierad",
    "okodifierat": "okodifierad",
    "okodifierats": "okodifierad",
    "okodifierbara": "okodifierbar",
    "okodifierbarare": "okodifierbar",
    "okodifierbarares": "okodifierbar",
    "okodifierbaras": "okodifierbar",
    "okodifierbarast": "okodifierbar",
    "okodifierbaraste": "okodifierbar",
    "okodifierbarastes": "okodifierbar",
    "okodifierbarasts": "okodifierbar",
    "okodifierbare": "okodifierbar",
    "okodifierbares": "okodifierbar",
    "okodifierbarheten": "okodifierbarhet",
    "okodifierbarhetens": "okodifierbarhet",
    "okodifierbarhets": "okodifierbarhet",
    "okodifierbars": "okodifierbar",
    "okodifierbart": "okodifierbar",
    "okodifierbarts": "okodifierbar",
    "okojade": "okojad",
    "okojades": "okojad",
    "okojads": "okojad",
    "okojat": "okojad",
    "okojats": "okojad",
    "okojsade": "okojsad",
    "okojsades": "okojsad",
    "okojsads": "okojsad",
    "okojsat": "okojsad",
    "okojsats": "okojsad",
    "okokta": "okokt",
    "okoktare": "okokt",
    "okoktares": "okokt",
    "okoktas": "okokt",
    "okoktast": "okokt",
    "okoktaste": "okokt",
    "okoktastes": "okokt",
    "okoktasts": "okokt",
    "okokte": "okokt",
    "okoktes": "okokt",
    "okokts": "okokt",
    "okolade": "okolad",
    "okolades": "okolad",
    "okolads": "okolad",
    "okolat": "okolad",
    "okolats": "okolad",
    "okolkade": "okolkad",
    "okolkades": "okolkad",
    "okolkads": "okolkad",
    "okolkat": "okolkad",
    "okolkats": "okolkad",
    "okollade": "okollad",
    "okollades": "okollad",
    "okollads": "okollad",
    "okollapsade": "okollapsad",
    "okollapsades": "okollapsad",
    "okollapsads": "okollapsad",
    "okollapsat": "okollapsad",
    "okollapsats": "okollapsad",
    "okollat": "okollad",
    "okollationerade": "okollationerad",
    "okollationerades": "okollationerad",
    "okollationerads": "okollationerad",
    "okollationerat": "okollationerad",
    "okollationerats": "okollationerad",
    "okollationerbara": "okollationerbar",
    "okollationerbarare": "okollationerbar",
    "okollationerbarares": "okollationerbar",
    "okollationerbaras": "okollationerbar",
    "okollationerbarast": "okollationerbar",
    "okollationerbaraste": "okollationerbar",
    "okollationerbarastes": "okollationerbar",
    "okollationerbarasts": "okollationerbar",
    "okollationerbare": "okollationerbar",
    "okollationerbares": "okollationerbar",
    "okollationerbarheten": "okollationerbarhet",
    "okollationerbarhetens": "okollationerbarhet",
    "okollationerbarhets": "okollationerbarhet",
    "okollationerbars": "okollationerbar",
    "okollationerbart": "okollationerbar",
    "okollationerbarts": "okollationerbar",
    "okollats": "okollad",
    "okollektiviserade": "okollektiviserad",
    "okollektiviserades": "okollektiviserad",
    "okollektiviserads": "okollektiviserad",
    "okollektiviserat": "okollektiviserad",
    "okollektiviserats": "okollektiviserad",
    "okollektiviserbara": "okollektiviserbar",
    "okollektiviserbarare": "okollektiviserbar",
    "okollektiviserbarares": "okollektiviserbar",
    "okollektiviserbaras": "okollektiviserbar",
    "okollektiviserbarast": "okollektiviserbar",
    "okollektiviserbaraste": "okollektiviserbar",
    "okollektiviserbarastes": "okollektiviserbar",
    "okollektiviserbarasts": "okollektiviserbar",
    "okollektiviserbare": "okollektiviserbar",
    "okollektiviserbares": "okollektiviserbar",
    "okollektiviserbarheten": "okollektiviserbarhet",
    "okollektiviserbarhetens": "okollektiviserbarhet",
    "okollektiviserbarhets": "okollektiviserbarhet",
    "okollektiviserbars": "okollektiviserbar",
    "okollektiviserbart": "okollektiviserbar",
    "okollektiviserbarts": "okollektiviserbar",
    "okoloniserade": "okoloniserad",
    "okoloniserades": "okoloniserad",
    "okoloniserads": "okoloniserad",
    "okoloniserat": "okoloniserad",
    "okoloniserats": "okoloniserad",
    "okoloniserbara": "okoloniserbar",
    "okoloniserbarare": "okoloniserbar",
    "okoloniserbarares": "okoloniserbar",
    "okoloniserbaras": "okoloniserbar",
    "okoloniserbarast": "okoloniserbar",
    "okoloniserbaraste": "okoloniserbar",
    "okoloniserbarastes": "okoloniserbar",
    "okoloniserbarasts": "okoloniserbar",
    "okoloniserbare": "okoloniserbar",
    "okoloniserbares": "okoloniserbar",
    "okoloniserbarheten": "okoloniserbarhet",
    "okoloniserbarhetens": "okoloniserbarhet",
    "okoloniserbarhets": "okoloniserbarhet",
    "okoloniserbars": "okoloniserbar",
    "okoloniserbart": "okoloniserbar",
    "okoloniserbarts": "okoloniserbar",
    "okolorerade": "okolorerad",
    "okolorerades": "okolorerad",
    "okolorerads": "okolorerad",
    "okolorerat": "okolorerad",
    "okolorerats": "okolorerad",
    "okolorerbara": "okolorerbar",
    "okolorerbarare": "okolorerbar",
    "okolorerbarares": "okolorerbar",
    "okolorerbaras": "okolorerbar",
    "okolorerbarast": "okolorerbar",
    "okolorerbaraste": "okolorerbar",
    "okolorerbarastes": "okolorerbar",
    "okolorerbarasts": "okolorerbar",
    "okolorerbare": "okolorerbar",
    "okolorerbares": "okolorerbar",
    "okolorerbarheten": "okolorerbarhet",
    "okolorerbarhetens": "okolorerbarhet",
    "okolorerbarhets": "okolorerbarhet",
    "okolorerbars": "okolorerbar",
    "okolorerbart": "okolorerbar",
    "okolorerbarts": "okolorerbar",
    "okolporterade": "okolporterad",
    "okolporterades": "okolporterad",
    "okolporterads": "okolporterad",
    "okolporterat": "okolporterad",
    "okolporterats": "okolporterad",
    "okolporterbara": "okolporterbar",
    "okolporterbarare": "okolporterbar",
    "okolporterbarares": "okolporterbar",
    "okolporterbaras": "okolporterbar",
    "okolporterbarast": "okolporterbar",
    "okolporterbaraste": "okolporterbar",
    "okolporterbarastes": "okolporterbar",
    "okolporterbarasts": "okolporterbar",
    "okolporterbare": "okolporterbar",
    "okolporterbares": "okolporterbar",
    "okolporterbarheten": "okolporterbarhet",
    "okolporterbarhetens": "okolporterbarhet",
    "okolporterbarhets": "okolporterbarhet",
    "okolporterbars": "okolporterbar",
    "okolporterbart": "okolporterbar",
    "okolporterbarts": "okolporterbar",
    "okombinerade": "okombinerad",
    "okombinerades": "okombinerad",
    "okombinerads": "okombinerad",
    "okombinerat": "okombinerad",
    "okombinerats": "okombinerad",
    "okombinerbara": "okombinerbar",
    "okombinerbarare": "okombinerbar",
    "okombinerbarares": "okombinerbar",
    "okombinerbaras": "okombinerbar",
    "okombinerbarast": "okombinerbar",
    "okombinerbaraste": "okombinerbar",
    "okombinerbarastes": "okombinerbar",
    "okombinerbarasts": "okombinerbar",
    "okombinerbare": "okombinerbar",
    "okombinerbares": "okombinerbar",
    "okombinerbarheten": "okombinerbarhet",
    "okombinerbarhetens": "okombinerbarhet",
    "okombinerbarhets": "okombinerbarhet",
    "okombinerbars": "okombinerbar",
    "okombinerbart": "okombinerbar",
    "okombinerbarts": "okombinerbar",
    "okommaterade": "okommaterad",
    "okommaterades": "okommaterad",
    "okommaterads": "okommaterad",
    "okommaterat": "okommaterad",
    "okommaterats": "okommaterad",
    "okommaterbara": "okommaterbar",
    "okommaterbarare": "okommaterbar",
    "okommaterbarares": "okommaterbar",
    "okommaterbaras": "okommaterbar",
    "okommaterbarast": "okommaterbar",
    "okommaterbaraste": "okommaterbar",
    "okommaterbarastes": "okommaterbar",
    "okommaterbarasts": "okommaterbar",
    "okommaterbare": "okommaterbar",
    "okommaterbares": "okommaterbar",
    "okommaterbarheten": "okommaterbarhet",
    "okommaterbarhetens": "okommaterbarhet",
    "okommaterbarhets": "okommaterbarhet",
    "okommaterbars": "okommaterbar",
    "okommaterbart": "okommaterbar",
    "okommaterbarts": "okommaterbar",
    "okommenderade": "okommenderad",
    "okommenderades": "okommenderad",
    "okommenderads": "okommenderad",
    "okommenderat": "okommenderad",
    "okommenderats": "okommenderad",
    "okommenderbara": "okommenderbar",
    "okommenderbarare": "okommenderbar",
    "okommenderbarares": "okommenderbar",
    "okommenderbaras": "okommenderbar",
    "okommenderbarast": "okommenderbar",
    "okommenderbaraste": "okommenderbar",
    "okommenderbarastes": "okommenderbar",
    "okommenderbarasts": "okommenderbar",
    "okommenderbare": "okommenderbar",
    "okommenderbares": "okommenderbar",
    "okommenderbarheten": "okommenderbarhet",
    "okommenderbarhetens": "okommenderbarhet",
    "okommenderbarhets": "okommenderbarhet",
    "okommenderbars": "okommenderbar",
    "okommenderbart": "okommenderbar",
    "okommenderbarts": "okommenderbar",
    "okommenterade": "okommenterad",
    "okommenterades": "okommenterad",
    "okommenterads": "okommenterad",
    "okommenterat": "okommenterad",
    "okommenterats": "okommenterad",
    "okommenterbara": "okommenterbar",
    "okommenterbarare": "okommenterbar",
    "okommenterbarares": "okommenterbar",
    "okommenterbaras": "okommenterbar",
    "okommenterbarast": "okommenterbar",
    "okommenterbaraste": "okommenterbar",
    "okommenterbarastes": "okommenterbar",
    "okommenterbarasts": "okommenterbar",
    "okommenterbare": "okommenterbar",
    "okommenterbares": "okommenterbar",
    "okommenterbarheten": "okommenterbarhet",
    "okommenterbarhetens": "okommenterbarhet",
    "okommenterbarhets": "okommenterbarhet",
    "okommenterbars": "okommenterbar",
    "okommenterbart": "okommenterbar",
    "okommenterbarts": "okommenterbar",
    "okommersade": "okommersad",
    "okommersades": "okommersad",
    "okommersads": "okommersad",
    "okommersat": "okommersad",
    "okommersats": "okommersad",
    "okommersialiserade": "okommersialiserad",
    "okommersialiserades": "okommersialiserad",
    "okommersialiserads": "okommersialiserad",
    "okommersialiserat": "okommersialiserad",
    "okommersialiserats": "okommersialiserad",
    "okommersialiserbara": "okommersialiserbar",
    "okommersialiserbarare": "okommersialiserbar",
    "okommersialiserbarares": "okommersialiserbar",
    "okommersialiserbaras": "okommersialiserbar",
    "okommersialiserbarast": "okommersialiserbar",
    "okommersialiserbaraste": "okommersialiserbar",
    "okommersialiserbarastes": "okommersialiserbar",
    "okommersialiserbarasts": "okommersialiserbar",
    "okommersialiserbare": "okommersialiserbar",
    "okommersialiserbares": "okommersialiserbar",
    "okommersialiserbarheten": "okommersialiserbarhet",
    "okommersialiserbarhetens": "okommersialiserbarhet",
    "okommersialiserbarhets": "okommersialiserbarhet",
    "okommersialiserbars": "okommersialiserbar",
    "okommersialiserbart": "okommersialiserbar",
    "okommersialiserbarts": "okommersialiserbar",
    "okommunaliserade": "okommunaliserad",
    "okommunaliserades": "okommunaliserad",
    "okommunaliserads": "okommunaliserad",
    "okommunaliserat": "okommunaliserad",
    "okommunaliserats": "okommunaliserad",
    "okommunaliserbara": "okommunaliserbar",
    "okommunaliserbarare": "okommunaliserbar",
    "okommunaliserbarares": "okommunaliserbar",
    "okommunaliserbaras": "okommunaliserbar",
    "okommunaliserbarast": "okommunaliserbar",
    "okommunaliserbaraste": "okommunaliserbar",
    "okommunaliserbarastes": "okommunaliserbar",
    "okommunaliserbarasts": "okommunaliserbar",
    "okommunaliserbare": "okommunaliserbar",
    "okommunaliserbares": "okommunaliserbar",
    "okommunaliserbarheten": "okommunaliserbarhet",
    "okommunaliserbarhetens": "okommunaliserbarhet",
    "okommunaliserbarhets": "okommunaliserbarhet",
    "okommunaliserbars": "okommunaliserbar",
    "okommunaliserbart": "okommunaliserbar",
    "okommunaliserbarts": "okommunaliserbar",
    "okommunicerade": "okommunicerad",
    "okommunicerades": "okommunicerad",
    "okommunicerads": "okommunicerad",
    "okommunicerat": "okommunicerad",
    "okommunicerats": "okommunicerad",
    "okommunicerbara": "okommunicerbar",
    "okommunicerbarare": "okommunicerbar",
    "okommunicerbarares": "okommunicerbar",
    "okommunicerbaras": "okommunicerbar",
    "okommunicerbarast": "okommunicerbar",
    "okommunicerbaraste": "okommunicerbar",
    "okommunicerbarastes": "okommunicerbar",
    "okommunicerbarasts": "okommunicerbar",
    "okommunicerbare": "okommunicerbar",
    "okommunicerbares": "okommunicerbar",
    "okommunicerbarheten": "okommunicerbarhet",
    "okommunicerbarhetens": "okommunicerbarhet",
    "okommunicerbarhets": "okommunicerbarhet",
    "okommunicerbars": "okommunicerbar",
    "okommunicerbart": "okommunicerbar",
    "okommunicerbarts": "okommunicerbar",
    "okommuterade": "okommuterad",
    "okommuterades": "okommuterad",
    "okommuterads": "okommuterad",
    "okommuterat": "okommuterad",
    "okommuterats": "okommuterad",
    "okommuterbara": "okommuterbar",
    "okommuterbarare": "okommuterbar",
    "okommuterbarares": "okommuterbar",
    "okommuterbaras": "okommuterbar",
    "okommuterbarast": "okommuterbar",
    "okommuterbaraste": "okommuterbar",
    "okommuterbarastes": "okommuterbar",
    "okommuterbarasts": "okommuterbar",
    "okommuterbare": "okommuterbar",
    "okommuterbares": "okommuterbar",
    "okommuterbarheten": "okommuterbarhet",
    "okommuterbarhetens": "okommuterbarhet",
    "okommuterbarhets": "okommuterbarhet",
    "okommuterbars": "okommuterbar",
    "okommuterbart": "okommuterbar",
    "okommuterbarts": "okommuterbar",
    "okompade": "okompad",
    "okompades": "okompad",
    "okompads": "okompad",
    "okomparerade": "okomparerad",
    "okomparerades": "okomparerad",
    "okomparerads": "okomparerad",
    "okomparerat": "okomparerad",
    "okomparerats": "okomparerad",
    "okomparerbara": "okomparerbar",
    "okomparerbarare": "okomparerbar",
    "okomparerbarares": "okomparerbar",
    "okomparerbaras": "okomparerbar",
    "okomparerbarast": "okomparerbar",
    "okomparerbaraste": "okomparerbar",
    "okomparerbarastes": "okomparerbar",
    "okomparerbarasts": "okomparerbar",
    "okomparerbare": "okomparerbar",
    "okomparerbares": "okomparerbar",
    "okomparerbarheten": "okomparerbarhet",
    "okomparerbarhetens": "okomparerbarhet",
    "okomparerbarhets": "okomparerbarhet",
    "okomparerbars": "okomparerbar",
    "okomparerbart": "okomparerbar",
    "okomparerbarts": "okomparerbar",
    "okompat": "okompad",
    "okompats": "okompad",
    "okompenserade": "okompenserad",
    "okompenserades": "okompenserad",
    "okompenserads": "okompenserad",
    "okompenserat": "okompenserad",
    "okompenserats": "okompenserad",
    "okompenserbara": "okompenserbar",
    "okompenserbarare": "okompenserbar",
    "okompenserbarares": "okompenserbar",
    "okompenserbaras": "okompenserbar",
    "okompenserbarast": "okompenserbar",
    "okompenserbaraste": "okompenserbar",
    "okompenserbarastes": "okompenserbar",
    "okompenserbarasts": "okompenserbar",
    "okompenserbare": "okompenserbar",
    "okompenserbares": "okompenserbar",
    "okompenserbarheten": "okompenserbarhet",
    "okompenserbarhetens": "okompenserbarhet",
    "okompenserbarhets": "okompenserbarhet",
    "okompenserbars": "okompenserbar",
    "okompenserbart": "okompenserbar",
    "okompenserbarts": "okompenserbar",
    "okompilerade": "okompilerad",
    "okompilerades": "okompilerad",
    "okompilerads": "okompilerad",
    "okompilerat": "okompilerad",
    "okompilerats": "okompilerad",
    "okompilerbara": "okompilerbar",
    "okompilerbarare": "okompilerbar",
    "okompilerbarares": "okompilerbar",
    "okompilerbaras": "okompilerbar",
    "okompilerbarast": "okompilerbar",
    "okompilerbaraste": "okompilerbar",
    "okompilerbarastes": "okompilerbar",
    "okompilerbarasts": "okompilerbar",
    "okompilerbare": "okompilerbar",
    "okompilerbares": "okompilerbar",
    "okompilerbarheten": "okompilerbarhet",
    "okompilerbarhetens": "okompilerbarhet",
    "okompilerbarhets": "okompilerbarhet",
    "okompilerbars": "okompilerbar",
    "okompilerbart": "okompilerbar",
    "okompilerbarts": "okompilerbar",
    "okompletterade": "okompletterad",
    "okompletterades": "okompletterad",
    "okompletterads": "okompletterad",
    "okompletterat": "okompletterad",
    "okompletterats": "okompletterad",
    "okompletterbara": "okompletterbar",
    "okompletterbarare": "okompletterbar",
    "okompletterbarares": "okompletterbar",
    "okompletterbaras": "okompletterbar",
    "okompletterbarast": "okompletterbar",
    "okompletterbaraste": "okompletterbar",
    "okompletterbarastes": "okompletterbar",
    "okompletterbarasts": "okompletterbar",
    "okompletterbare": "okompletterbar",
    "okompletterbares": "okompletterbar",
    "okompletterbarheten": "okompletterbarhet",
    "okompletterbarhetens": "okompletterbarhet",
    "okompletterbarhets": "okompletterbarhet",
    "okompletterbars": "okompletterbar",
    "okompletterbart": "okompletterbar",
    "okompletterbarts": "okompletterbar",
    "okomplicerade": "okomplicerad",
    "okomplicerades": "okomplicerad",
    "okomplicerads": "okomplicerad",
    "okomplicerat": "okomplicerad",
    "okomplicerats": "okomplicerad",
    "okomplicerbara": "okomplicerbar",
    "okomplicerbarare": "okomplicerbar",
    "okomplicerbarares": "okomplicerbar",
    "okomplicerbaras": "okomplicerbar",
    "okomplicerbarast": "okomplicerbar",
    "okomplicerbaraste": "okomplicerbar",
    "okomplicerbarastes": "okomplicerbar",
    "okomplicerbarasts": "okomplicerbar",
    "okomplicerbare": "okomplicerbar",
    "okomplicerbares": "okomplicerbar",
    "okomplicerbarheten": "okomplicerbarhet",
    "okomplicerbarhetens": "okomplicerbarhet",
    "okomplicerbarhets": "okomplicerbarhet",
    "okomplicerbars": "okomplicerbar",
    "okomplicerbart": "okomplicerbar",
    "okomplicerbarts": "okomplicerbar",
    "okomplimenterade": "okomplimenterad",
    "okomplimenterades": "okomplimenterad",
    "okomplimenterads": "okomplimenterad",
    "okomplimenterat": "okomplimenterad",
    "okomplimenterats": "okomplimenterad",
    "okomplimenterbara": "okomplimenterbar",
    "okomplimenterbarare": "okomplimenterbar",
    "okomplimenterbarares": "okomplimenterbar",
    "okomplimenterbaras": "okomplimenterbar",
    "okomplimenterbarast": "okomplimenterbar",
    "okomplimenterbaraste": "okomplimenterbar",
    "okomplimenterbarastes": "okomplimenterbar",
    "okomplimenterbarasts": "okomplimenterbar",
    "okomplimenterbare": "okomplimenterbar",
    "okomplimenterbares": "okomplimenterbar",
    "okomplimenterbarheten": "okomplimenterbarhet",
    "okomplimenterbarhetens": "okomplimenterbarhet",
    "okomplimenterbarhets": "okomplimenterbarhet",
    "okomplimenterbars": "okomplimenterbar",
    "okomplimenterbart": "okomplimenterbar",
    "okomplimenterbarts": "okomplimenterbar",
    "okomponerade": "okomponerad",
    "okomponerades": "okomponerad",
    "okomponerads": "okomponerad",
    "okomponerat": "okomponerad",
    "okomponerats": "okomponerad",
    "okomponerbara": "okomponerbar",
    "okomponerbarare": "okomponerbar",
    "okomponerbarares": "okomponerbar",
    "okomponerbaras": "okomponerbar",
    "okomponerbarast": "okomponerbar",
    "okomponerbaraste": "okomponerbar",
    "okomponerbarastes": "okomponerbar",
    "okomponerbarasts": "okomponerbar",
    "okomponerbare": "okomponerbar",
    "okomponerbares": "okomponerbar",
    "okomponerbarheten": "okomponerbarhet",
    "okomponerbarhetens": "okomponerbarhet",
    "okomponerbarhets": "okomponerbarhet",
    "okomponerbars": "okomponerbar",
    "okomponerbart": "okomponerbar",
    "okomponerbarts": "okomponerbar",
    "okomposterade": "okomposterad",
    "okomposterades": "okomposterad",
    "okomposterads": "okomposterad",
    "okomposterat": "okomposterad",
    "okomposterats": "okomposterad",
    "okomposterbara": "okomposterbar",
    "okomposterbarare": "okomposterbar",
    "okomposterbarares": "okomposterbar",
    "okomposterbaras": "okomposterbar",
    "okomposterbarast": "okomposterbar",
    "okomposterbaraste": "okomposterbar",
    "okomposterbarastes": "okomposterbar",
    "okomposterbarasts": "okomposterbar",
    "okomposterbare": "okomposterbar",
    "okomposterbares": "okomposterbar",
    "okomposterbarheten": "okomposterbarhet",
    "okomposterbarhetens": "okomposterbarhet",
    "okomposterbarhets": "okomposterbarhet",
    "okomposterbars": "okomposterbar",
    "okomposterbart": "okomposterbar",
    "okomposterbarts": "okomposterbar",
    "okomprimerade": "okomprimerad",
    "okomprimerades": "okomprimerad",
    "okomprimerads": "okomprimerad",
    "okomprimerat": "okomprimerad",
    "okomprimerats": "okomprimerad",
    "okomprimerbara": "okomprimerbar",
    "okomprimerbarare": "okomprimerbar",
    "okomprimerbarares": "okomprimerbar",
    "okomprimerbaras": "okomprimerbar",
    "okomprimerbarast": "okomprimerbar",
    "okomprimerbaraste": "okomprimerbar",
    "okomprimerbarastes": "okomprimerbar",
    "okomprimerbarasts": "okomprimerbar",
    "okomprimerbare": "okomprimerbar",
    "okomprimerbares": "okomprimerbar",
    "okomprimerbarheten": "okomprimerbarhet",
    "okomprimerbarhetens": "okomprimerbarhet",
    "okomprimerbarhets": "okomprimerbarhet",
    "okomprimerbars": "okomprimerbar",
    "okomprimerbart": "okomprimerbar",
    "okomprimerbarts": "okomprimerbar",
    "okomprometterade": "okomprometterad",
    "okomprometterades": "okomprometterad",
    "okomprometterads": "okomprometterad",
    "okomprometterat": "okomprometterad",
    "okomprometterats": "okomprometterad",
    "okomprometterbara": "okomprometterbar",
    "okomprometterbarare": "okomprometterbar",
    "okomprometterbarares": "okomprometterbar",
    "okomprometterbaras": "okomprometterbar",
    "okomprometterbarast": "okomprometterbar",
    "okomprometterbaraste": "okomprometterbar",
    "okomprometterbarastes": "okomprometterbar",
    "okomprometterbarasts": "okomprometterbar",
    "okomprometterbare": "okomprometterbar",
    "okomprometterbares": "okomprometterbar",
    "okomprometterbarheten": "okomprometterbarhet",
    "okomprometterbarhetens": "okomprometterbarhet",
    "okomprometterbarhets": "okomprometterbarhet",
    "okomprometterbars": "okomprometterbar",
    "okomprometterbart": "okomprometterbar",
    "okomprometterbarts": "okomprometterbar",
    "okoncentrerade": "okoncentrerad",
    "okoncentrerades": "okoncentrerad",
    "okoncentrerads": "okoncentrerad",
    "okoncentrerat": "okoncentrerad",
    "okoncentrerats": "okoncentrerad",
    "okoncentrerbara": "okoncentrerbar",
    "okoncentrerbarare": "okoncentrerbar",
    "okoncentrerbarares": "okoncentrerbar",
    "okoncentrerbaras": "okoncentrerbar",
    "okoncentrerbarast": "okoncentrerbar",
    "okoncentrerbaraste": "okoncentrerbar",
    "okoncentrerbarastes": "okoncentrerbar",
    "okoncentrerbarasts": "okoncentrerbar",
    "okoncentrerbare": "okoncentrerbar",
    "okoncentrerbares": "okoncentrerbar",
    "okoncentrerbarheten": "okoncentrerbarhet",
    "okoncentrerbarhetens": "okoncentrerbarhet",
    "okoncentrerbarhets": "okoncentrerbarhet",
    "okoncentrerbars": "okoncentrerbar",
    "okoncentrerbart": "okoncentrerbar",
    "okoncentrerbarts": "okoncentrerbar",
    "okoncessionerade": "okoncessionerad",
    "okoncessionerades": "okoncessionerad",
    "okoncessionerads": "okoncessionerad",
    "okoncessionerat": "okoncessionerad",
    "okoncessionerats": "okoncessionerad",
    "okoncessionerbara": "okoncessionerbar",
    "okoncessionerbarare": "okoncessionerbar",
    "okoncessionerbarares": "okoncessionerbar",
    "okoncessionerbaras": "okoncessionerbar",
    "okoncessionerbarast": "okoncessionerbar",
    "okoncessionerbaraste": "okoncessionerbar",
    "okoncessionerbarastes": "okoncessionerbar",
    "okoncessionerbarasts": "okoncessionerbar",
    "okoncessionerbare": "okoncessionerbar",
    "okoncessionerbares": "okoncessionerbar",
    "okoncessionerbarheten": "okoncessionerbarhet",
    "okoncessionerbarhetens": "okoncessionerbarhet",
    "okoncessionerbarhets": "okoncessionerbarhet",
    "okoncessionerbars": "okoncessionerbar",
    "okoncessionerbart": "okoncessionerbar",
    "okoncessionerbarts": "okoncessionerbar",
    "okoncipierade": "okoncipierad",
    "okoncipierades": "okoncipierad",
    "okoncipierads": "okoncipierad",
    "okoncipierat": "okoncipierad",
    "okoncipierats": "okoncipierad",
    "okoncipierbara": "okoncipierbar",
    "okoncipierbarare": "okoncipierbar",
    "okoncipierbarares": "okoncipierbar",
    "okoncipierbaras": "okoncipierbar",
    "okoncipierbarast": "okoncipierbar",
    "okoncipierbaraste": "okoncipierbar",
    "okoncipierbarastes": "okoncipierbar",
    "okoncipierbarasts": "okoncipierbar",
    "okoncipierbare": "okoncipierbar",
    "okoncipierbares": "okoncipierbar",
    "okoncipierbarheten": "okoncipierbarhet",
    "okoncipierbarhetens": "okoncipierbarhet",
    "okoncipierbarhets": "okoncipierbarhet",
    "okoncipierbars": "okoncipierbar",
    "okoncipierbart": "okoncipierbar",
    "okoncipierbarts": "okoncipierbar",
    "okondemnerade": "okondemnerad",
    "okondemnerades": "okondemnerad",
    "okondemnerads": "okondemnerad",
    "okondemnerat": "okondemnerad",
    "okondemnerats": "okondemnerad",
    "okondemnerbara": "okondemnerbar",
    "okondemnerbarare": "okondemnerbar",
    "okondemnerbarares": "okondemnerbar",
    "okondemnerbaras": "okondemnerbar",
    "okondemnerbarast": "okondemnerbar",
    "okondemnerbaraste": "okondemnerbar",
    "okondemnerbarastes": "okondemnerbar",
    "okondemnerbarasts": "okondemnerbar",
    "okondemnerbare": "okondemnerbar",
    "okondemnerbares": "okondemnerbar",
    "okondemnerbarheten": "okondemnerbarhet",
    "okondemnerbarhetens": "okondemnerbarhet",
    "okondemnerbarhets": "okondemnerbarhet",
    "okondemnerbars": "okondemnerbar",
    "okondemnerbart": "okondemnerbar",
    "okondemnerbarts": "okondemnerbar",
    "okondenserade": "okondenserad",
    "okondenserades": "okondenserad",
    "okondenserads": "okondenserad",
    "okondenserat": "okondenserad",
    "okondenserats": "okondenserad",
    "okondenserbara": "okondenserbar",
    "okondenserbarare": "okondenserbar",
    "okondenserbarares": "okondenserbar",
    "okondenserbaras": "okondenserbar",
    "okondenserbarast": "okondenserbar",
    "okondenserbaraste": "okondenserbar",
    "okondenserbarastes": "okondenserbar",
    "okondenserbarasts": "okondenserbar",
    "okondenserbare": "okondenserbar",
    "okondenserbares": "okondenserbar",
    "okondenserbarheten": "okondenserbarhet",
    "okondenserbarhetens": "okondenserbarhet",
    "okondenserbarhets": "okondenserbarhet",
    "okondenserbars": "okondenserbar",
    "okondenserbart": "okondenserbar",
    "okondenserbarts": "okondenserbar",
    "okonditionerade": "okonditionerad",
    "okonditionerades": "okonditionerad",
    "okonditionerads": "okonditionerad",
    "okonditionerat": "okonditionerad",
    "okonditionerats": "okonditionerad",
    "okonditionerbara": "okonditionerbar",
    "okonditionerbarare": "okonditionerbar",
    "okonditionerbarares": "okonditionerbar",
    "okonditionerbaras": "okonditionerbar",
    "okonditionerbarast": "okonditionerbar",
    "okonditionerbaraste": "okonditionerbar",
    "okonditionerbarastes": "okonditionerbar",
    "okonditionerbarasts": "okonditionerbar",
    "okonditionerbare": "okonditionerbar",
    "okonditionerbares": "okonditionerbar",
    "okonditionerbarheten": "okonditionerbarhet",
    "okonditionerbarhetens": "okonditionerbarhet",
    "okonditionerbarhets": "okonditionerbarhet",
    "okonditionerbars": "okonditionerbar",
    "okonditionerbart": "okonditionerbar",
    "okonditionerbarts": "okonditionerbar",
    "okondolerade": "okondolerad",
    "okondolerades": "okondolerad",
    "okondolerads": "okondolerad",
    "okondolerat": "okondolerad",
    "okondolerats": "okondolerad",
    "okondolerbara": "okondolerbar",
    "okondolerbarare": "okondolerbar",
    "okondolerbarares": "okondolerbar",
    "okondolerbaras": "okondolerbar",
    "okondolerbarast": "okondolerbar",
    "okondolerbaraste": "okondolerbar",
    "okondolerbarastes": "okondolerbar",
    "okondolerbarasts": "okondolerbar",
    "okondolerbare": "okondolerbar",
    "okondolerbares": "okondolerbar",
    "okondolerbarheten": "okondolerbarhet",
    "okondolerbarhetens": "okondolerbarhet",
    "okondolerbarhets": "okondolerbarhet",
    "okondolerbars": "okondolerbar",
    "okondolerbart": "okondolerbar",
    "okondolerbarts": "okondolerbar",
    "okonfirmerade": "okonfirmerad",
    "okonfirmerades": "okonfirmerad",
    "okonfirmerads": "okonfirmerad",
    "okonfirmerat": "okonfirmerad",
    "okonfirmerats": "okonfirmerad",
    "okonfirmerbara": "okonfirmerbar",
    "okonfirmerbarare": "okonfirmerbar",
    "okonfirmerbarares": "okonfirmerbar",
    "okonfirmerbaras": "okonfirmerbar",
    "okonfirmerbarast": "okonfirmerbar",
    "okonfirmerbaraste": "okonfirmerbar",
    "okonfirmerbarastes": "okonfirmerbar",
    "okonfirmerbarasts": "okonfirmerbar",
    "okonfirmerbare": "okonfirmerbar",
    "okonfirmerbares": "okonfirmerbar",
    "okonfirmerbarheten": "okonfirmerbarhet",
    "okonfirmerbarhetens": "okonfirmerbarhet",
    "okonfirmerbarhets": "okonfirmerbarhet",
    "okonfirmerbars": "okonfirmerbar",
    "okonfirmerbart": "okonfirmerbar",
    "okonfirmerbarts": "okonfirmerbar",
    "okonfiskerade": "okonfiskerad",
    "okonfiskerades": "okonfiskerad",
    "okonfiskerads": "okonfiskerad",
    "okonfiskerat": "okonfiskerad",
    "okonfiskerats": "okonfiskerad",
    "okonfiskerbara": "okonfiskerbar",
    "okonfiskerbarare": "okonfiskerbar",
    "okonfiskerbarares": "okonfiskerbar",
    "okonfiskerbaras": "okonfiskerbar",
    "okonfiskerbarast": "okonfiskerbar",
    "okonfiskerbaraste": "okonfiskerbar",
    "okonfiskerbarastes": "okonfiskerbar",
    "okonfiskerbarasts": "okonfiskerbar",
    "okonfiskerbare": "okonfiskerbar",
    "okonfiskerbares": "okonfiskerbar",
    "okonfiskerbarheten": "okonfiskerbarhet",
    "okonfiskerbarhetens": "okonfiskerbarhet",
    "okonfiskerbarhets": "okonfiskerbarhet",
    "okonfiskerbars": "okonfiskerbar",
    "okonfiskerbart": "okonfiskerbar",
    "okonfiskerbarts": "okonfiskerbar",
    "okonfronterade": "okonfronterad",
    "okonfronterades": "okonfronterad",
    "okonfronterads": "okonfronterad",
    "okonfronterat": "okonfronterad",
    "okonfronterats": "okonfronterad",
    "okonfronterbara": "okonfronterbar",
    "okonfronterbarare": "okonfronterbar",
    "okonfronterbarares": "okonfronterbar",
    "okonfronterbaras": "okonfronterbar",
    "okonfronterbarast": "okonfronterbar",
    "okonfronterbaraste": "okonfronterbar",
    "okonfronterbarastes": "okonfronterbar",
    "okonfronterbarasts": "okonfronterbar",
    "okonfronterbare": "okonfronterbar",
    "okonfronterbares": "okonfronterbar",
    "okonfronterbarheten": "okonfronterbarhet",
    "okonfronterbarhetens": "okonfronterbarhet",
    "okonfronterbarhets": "okonfronterbarhet",
    "okonfronterbars": "okonfronterbar",
    "okonfronterbart": "okonfronterbar",
    "okonfronterbarts": "okonfronterbar",
    "okonfunderade": "okonfunderad",
    "okonfunderades": "okonfunderad",
    "okonfunderads": "okonfunderad",
    "okonfunderat": "okonfunderad",
    "okonfunderats": "okonfunderad",
    "okonfunderbara": "okonfunderbar",
    "okonfunderbarare": "okonfunderbar",
    "okonfunderbarares": "okonfunderbar",
    "okonfunderbaras": "okonfunderbar",
    "okonfunderbarast": "okonfunderbar",
    "okonfunderbaraste": "okonfunderbar",
    "okonfunderbarastes": "okonfunderbar",
    "okonfunderbarasts": "okonfunderbar",
    "okonfunderbare": "okonfunderbar",
    "okonfunderbares": "okonfunderbar",
    "okonfunderbarheten": "okonfunderbarhet",
    "okonfunderbarhetens": "okonfunderbarhet",
    "okonfunderbarhets": "okonfunderbarhet",
    "okonfunderbars": "okonfunderbar",
    "okonfunderbart": "okonfunderbar",
    "okonfunderbarts": "okonfunderbar",
    "okongruerade": "okongruerad",
    "okongruerades": "okongruerad",
    "okongruerads": "okongruerad",
    "okongruerat": "okongruerad",
    "okongruerats": "okongruerad",
    "okongruerbara": "okongruerbar",
    "okongruerbarare": "okongruerbar",
    "okongruerbarares": "okongruerbar",
    "okongruerbaras": "okongruerbar",
    "okongruerbarast": "okongruerbar",
    "okongruerbaraste": "okongruerbar",
    "okongruerbarastes": "okongruerbar",
    "okongruerbarasts": "okongruerbar",
    "okongruerbare": "okongruerbar",
    "okongruerbares": "okongruerbar",
    "okongruerbarheten": "okongruerbarhet",
    "okongruerbarhetens": "okongruerbarhet",
    "okongruerbarhets": "okongruerbarhet",
    "okongruerbars": "okongruerbar",
    "okongruerbart": "okongruerbar",
    "okongruerbarts": "okongruerbar",
    "okonjugerade": "okonjugerad",
    "okonjugerades": "okonjugerad",
    "okonjugerads": "okonjugerad",
    "okonjugerat": "okonjugerad",
    "okonjugerats": "okonjugerad",
    "okonjugerbara": "okonjugerbar",
    "okonjugerbarare": "okonjugerbar",
    "okonjugerbarares": "okonjugerbar",
    "okonjugerbaras": "okonjugerbar",
    "okonjugerbarast": "okonjugerbar",
    "okonjugerbaraste": "okonjugerbar",
    "okonjugerbarastes": "okonjugerbar",
    "okonjugerbarasts": "okonjugerbar",
    "okonjugerbare": "okonjugerbar",
    "okonjugerbares": "okonjugerbar",
    "okonjugerbarheten": "okonjugerbarhet",
    "okonjugerbarhetens": "okonjugerbarhet",
    "okonjugerbarhets": "okonjugerbarhet",
    "okonjugerbars": "okonjugerbar",
    "okonjugerbart": "okonjugerbar",
    "okonjugerbarts": "okonjugerbar",
    "okonkluderade": "okonkluderad",
    "okonkluderades": "okonkluderad",
    "okonkluderads": "okonkluderad",
    "okonkluderat": "okonkluderad",
    "okonkluderats": "okonkluderad",
    "okonkluderbara": "okonkluderbar",
    "okonkluderbarare": "okonkluderbar",
    "okonkluderbarares": "okonkluderbar",
    "okonkluderbaras": "okonkluderbar",
    "okonkluderbarast": "okonkluderbar",
    "okonkluderbaraste": "okonkluderbar",
    "okonkluderbarastes": "okonkluderbar",
    "okonkluderbarasts": "okonkluderbar",
    "okonkluderbare": "okonkluderbar",
    "okonkluderbares": "okonkluderbar",
    "okonkluderbarheten": "okonkluderbarhet",
    "okonkluderbarhetens": "okonkluderbarhet",
    "okonkluderbarhets": "okonkluderbarhet",
    "okonkluderbars": "okonkluderbar",
    "okonkluderbart": "okonkluderbar",
    "okonkluderbarts": "okonkluderbar",
    "okonkretiserade": "okonkretiserad",
    "okonkretiserades": "okonkretiserad",
    "okonkretiserads": "okonkretiserad",
    "okonkretiserat": "okonkretiserad",
    "okonkretiserats": "okonkretiserad",
    "okonkretiserbara": "okonkretiserbar",
    "okonkretiserbarare": "okonkretiserbar",
    "okonkretiserbarares": "okonkretiserbar",
    "okonkretiserbaras": "okonkretiserbar",
    "okonkretiserbarast": "okonkretiserbar",
    "okonkretiserbaraste": "okonkretiserbar",
    "okonkretiserbarastes": "okonkretiserbar",
    "okonkretiserbarasts": "okonkretiserbar",
    "okonkretiserbare": "okonkretiserbar",
    "okonkretiserbares": "okonkretiserbar",
    "okonkretiserbarheten": "okonkretiserbarhet",
    "okonkretiserbarhetens": "okonkretiserbarhet",
    "okonkretiserbarhets": "okonkretiserbarhet",
    "okonkretiserbars": "okonkretiserbar",
    "okonkretiserbart": "okonkretiserbar",
    "okonkretiserbarts": "okonkretiserbar",
    "okonserverade": "okonserverad",
    "okonserverades": "okonserverad",
    "okonserverads": "okonserverad",
    "okonserverat": "okonserverad",
    "okonserverats": "okonserverad",
    "okonserverbara": "okonserverbar",
    "okonserverbarare": "okonserverbar",
    "okonserverbarares": "okonserverbar",
    "okonserverbaras": "okonserverbar",
    "okonserverbarast": "okonserverbar",
    "okonserverbaraste": "okonserverbar",
    "okonserverbarastes": "okonserverbar",
    "okonserverbarasts": "okonserverbar",
    "okonserverbare": "okonserverbar",
    "okonserverbares": "okonserverbar",
    "okonserverbarheten": "okonserverbarhet",
    "okonserverbarhetens": "okonserverbarhet",
    "okonserverbarhets": "okonserverbarhet",
    "okonserverbars": "okonserverbar",
    "okonserverbart": "okonserverbar",
    "okonserverbarts": "okonserverbar",
    "okonsignerade": "okonsignerad",
    "okonsignerades": "okonsignerad",
    "okonsignerads": "okonsignerad",
    "okonsignerat": "okonsignerad",
    "okonsignerats": "okonsignerad",
    "okonsignerbara": "okonsignerbar",
    "okonsignerbarare": "okonsignerbar",
    "okonsignerbarares": "okonsignerbar",
    "okonsignerbaras": "okonsignerbar",
    "okonsignerbarast": "okonsignerbar",
    "okonsignerbaraste": "okonsignerbar",
    "okonsignerbarastes": "okonsignerbar",
    "okonsignerbarasts": "okonsignerbar",
    "okonsignerbare": "okonsignerbar",
    "okonsignerbares": "okonsignerbar",
    "okonsignerbarheten": "okonsignerbarhet",
    "okonsignerbarhetens": "okonsignerbarhet",
    "okonsignerbarhets": "okonsignerbarhet",
    "okonsignerbars": "okonsignerbar",
    "okonsignerbart": "okonsignerbar",
    "okonsignerbarts": "okonsignerbar",
    "okonsoliderade": "okonsoliderad",
    "okonsoliderades": "okonsoliderad",
    "okonsoliderads": "okonsoliderad",
    "okonsoliderat": "okonsoliderad",
    "okonsoliderats": "okonsoliderad",
    "okonsoliderbara": "okonsoliderbar",
    "okonsoliderbarare": "okonsoliderbar",
    "okonsoliderbarares": "okonsoliderbar",
    "okonsoliderbaras": "okonsoliderbar",
    "okonsoliderbarast": "okonsoliderbar",
    "okonsoliderbaraste": "okonsoliderbar",
    "okonsoliderbarastes": "okonsoliderbar",
    "okonsoliderbarasts": "okonsoliderbar",
    "okonsoliderbare": "okonsoliderbar",
    "okonsoliderbares": "okonsoliderbar",
    "okonsoliderbarheten": "okonsoliderbarhet",
    "okonsoliderbarhetens": "okonsoliderbarhet",
    "okonsoliderbarhets": "okonsoliderbarhet",
    "okonsoliderbars": "okonsoliderbar",
    "okonsoliderbart": "okonsoliderbar",
    "okonsoliderbarts": "okonsoliderbar",
    "okonstaterade": "okonstaterad",
    "okonstaterades": "okonstaterad",
    "okonstaterads": "okonstaterad",
    "okonstaterat": "okonstaterad",
    "okonstaterats": "okonstaterad",
    "okonstaterbara": "okonstaterbar",
    "okonstaterbarare": "okonstaterbar",
    "okonstaterbarares": "okonstaterbar",
    "okonstaterbaras": "okonstaterbar",
    "okonstaterbarast": "okonstaterbar",
    "okonstaterbaraste": "okonstaterbar",
    "okonstaterbarastes": "okonstaterbar",
    "okonstaterbarasts": "okonstaterbar",
    "okonstaterbare": "okonstaterbar",
    "okonstaterbares": "okonstaterbar",
    "okonstaterbarheten": "okonstaterbarhet",
    "okonstaterbarhetens": "okonstaterbarhet",
    "okonstaterbarhets": "okonstaterbarhet",
    "okonstaterbars": "okonstaterbar",
    "okonstaterbart": "okonstaterbar",
    "okonstaterbarts": "okonstaterbar",
    "okonstbefruktade": "okonstbefruktad",
    "okonstbefruktades": "okonstbefruktad",
    "okonstbefruktads": "okonstbefruktad",
    "okonstbefruktat": "okonstbefruktad",
    "okonstbefruktats": "okonstbefruktad",
    "okonstbevattnade": "okonstbevattnad",
    "okonstbevattnades": "okonstbevattnad",
    "okonstbevattnads": "okonstbevattnad",
    "okonstbevattnat": "okonstbevattnad",
    "okonstbevattnats": "okonstbevattnad",
    "okonsternerade": "okonsternerad",
    "okonsternerades": "okonsternerad",
    "okonsternerads": "okonsternerad",
    "okonsternerat": "okonsternerad",
    "okonsternerats": "okonsternerad",
    "okonsternerbara": "okonsternerbar",
    "okonsternerbarare": "okonsternerbar",
    "okonsternerbarares": "okonsternerbar",
    "okonsternerbaras": "okonsternerbar",
    "okonsternerbarast": "okonsternerbar",
    "okonsternerbaraste": "okonsternerbar",
    "okonsternerbarastes": "okonsternerbar",
    "okonsternerbarasts": "okonsternerbar",
    "okonsternerbare": "okonsternerbar",
    "okonsternerbares": "okonsternerbar",
    "okonsternerbarheten": "okonsternerbarhet",
    "okonsternerbarhetens": "okonsternerbarhet",
    "okonsternerbarhets": "okonsternerbarhet",
    "okonsternerbars": "okonsternerbar",
    "okonsternerbart": "okonsternerbar",
    "okonsternerbarts": "okonsternerbar",
    "okonstituerade": "okonstituerad",
    "okonstituerades": "okonstituerad",
    "okonstituerads": "okonstituerad",
    "okonstituerat": "okonstituerad",
    "okonstituerats": "okonstituerad",
    "okonstituerbara": "okonstituerbar",
    "okonstituerbarare": "okonstituerbar",
    "okonstituerbarares": "okonstituerbar",
    "okonstituerbaras": "okonstituerbar",
    "okonstituerbarast": "okonstituerbar",
    "okonstituerbaraste": "okonstituerbar",
    "okonstituerbarastes": "okonstituerbar",
    "okonstituerbarasts": "okonstituerbar",
    "okonstituerbare": "okonstituerbar",
    "okonstituerbares": "okonstituerbar",
    "okonstituerbarheten": "okonstituerbarhet",
    "okonstituerbarhetens": "okonstituerbarhet",
    "okonstituerbarhets": "okonstituerbarhet",
    "okonstituerbars": "okonstituerbar",
    "okonstituerbart": "okonstituerbar",
    "okonstituerbarts": "okonstituerbar",
    "okonstlade": "okonstlad",
    "okonstlades": "okonstlad",
    "okonstlads": "okonstlad",
    "okonstlat": "okonstlad",
    "okonstlats": "okonstlad",
    "okonstruerade": "okonstruerad",
    "okonstruerades": "okonstruerad",
    "okonstruerads": "okonstruerad",
    "okonstruerat": "okonstruerad",
    "okonstruerats": "okonstruerad",
    "okonstruerbara": "okonstruerbar",
    "okonstruerbarare": "okonstruerbar",
    "okonstruerbarares": "okonstruerbar",
    "okonstruerbaras": "okonstruerbar",
    "okonstruerbarast": "okonstruerbar",
    "okonstruerbaraste": "okonstruerbar",
    "okonstruerbarastes": "okonstruerbar",
    "okonstruerbarasts": "okonstruerbar",
    "okonstruerbare": "okonstruerbar",
    "okonstruerbares": "okonstruerbar",
    "okonstruerbarheten": "okonstruerbarhet",
    "okonstruerbarhetens": "okonstruerbarhet",
    "okonstruerbarhets": "okonstruerbarhet",
    "okonstruerbars": "okonstruerbar",
    "okonstruerbart": "okonstruerbar",
    "okonstruerbarts": "okonstruerbar",
    "okonsulterade": "okonsulterad",
    "okonsulterades": "okonsulterad",
    "okonsulterads": "okonsulterad",
    "okonsulterat": "okonsulterad",
    "okonsulterats": "okonsulterad",
    "okonsulterbara": "okonsulterbar",
    "okonsulterbarare": "okonsulterbar",
    "okonsulterbarares": "okonsulterbar",
    "okonsulterbaras": "okonsulterbar",
    "okonsulterbarast": "okonsulterbar",
    "okonsulterbaraste": "okonsulterbar",
    "okonsulterbarastes": "okonsulterbar",
    "okonsulterbarasts": "okonsulterbar",
    "okonsulterbare": "okonsulterbar",
    "okonsulterbares": "okonsulterbar",
    "okonsulterbarheten": "okonsulterbarhet",
    "okonsulterbarhetens": "okonsulterbarhet",
    "okonsulterbarhets": "okonsulterbarhet",
    "okonsulterbars": "okonsulterbar",
    "okonsulterbart": "okonsulterbar",
    "okonsulterbarts": "okonsulterbar",
    "okonsumerade": "okonsumerad",
    "okonsumerades": "okonsumerad",
    "okonsumerads": "okonsumerad",
    "okonsumerat": "okonsumerad",
    "okonsumerats": "okonsumerad",
    "okonsumerbara": "okonsumerbar",
    "okonsumerbarare": "okonsumerbar",
    "okonsumerbarares": "okonsumerbar",
    "okonsumerbaras": "okonsumerbar",
    "okonsumerbarast": "okonsumerbar",
    "okonsumerbaraste": "okonsumerbar",
    "okonsumerbarastes": "okonsumerbar",
    "okonsumerbarasts": "okonsumerbar",
    "okonsumerbare": "okonsumerbar",
    "okonsumerbares": "okonsumerbar",
    "okonsumerbarheten": "okonsumerbarhet",
    "okonsumerbarhetens": "okonsumerbarhet",
    "okonsumerbarhets": "okonsumerbarhet",
    "okonsumerbars": "okonsumerbar",
    "okonsumerbart": "okonsumerbar",
    "okonsumerbarts": "okonsumerbar",
    "okontaktade": "okontaktad",
    "okontaktades": "okontaktad",
    "okontaktads": "okontaktad",
    "okontaktat": "okontaktad",
    "okontaktats": "okontaktad",
    "okontaminerade": "okontaminerad",
    "okontaminerades": "okontaminerad",
    "okontaminerads": "okontaminerad",
    "okontaminerat": "okontaminerad",
    "okontaminerats": "okontaminerad",
    "okontaminerbara": "okontaminerbar",
    "okontaminerbarare": "okontaminerbar",
    "okontaminerbarares": "okontaminerbar",
    "okontaminerbaras": "okontaminerbar",
    "okontaminerbarast": "okontaminerbar",
    "okontaminerbaraste": "okontaminerbar",
    "okontaminerbarastes": "okontaminerbar",
    "okontaminerbarasts": "okontaminerbar",
    "okontaminerbare": "okontaminerbar",
    "okontaminerbares": "okontaminerbar",
    "okontaminerbarheten": "okontaminerbarhet",
    "okontaminerbarhetens": "okontaminerbarhet",
    "okontaminerbarhets": "okontaminerbarhet",
    "okontaminerbars": "okontaminerbar",
    "okontaminerbart": "okontaminerbar",
    "okontaminerbarts": "okontaminerbar",
    "okontanta": "okontant",
    "okontantare": "okontant",
    "okontantares": "okontant",
    "okontantas": "okontant",
    "okontantast": "okontant",
    "okontantaste": "okontant",
    "okontantastes": "okontant",
    "okontantasts": "okontant",
    "okontante": "okontant",
    "okontantes": "okontant",
    "okontants": "okontant",
    "okonterade": "okonterad",
    "okonterades": "okonterad",
    "okonterads": "okonterad",
    "okonterat": "okonterad",
    "okonterats": "okonterad",
    "okonterbara": "okonterbar",
    "okonterbarare": "okonterbar",
    "okonterbarares": "okonterbar",
    "okonterbaras": "okonterbar",
    "okonterbarast": "okonterbar",
    "okonterbaraste": "okonterbar",
    "okonterbarastes": "okonterbar",
    "okonterbarasts": "okonterbar",
    "okonterbare": "okonterbar",
    "okonterbares": "okonterbar",
    "okonterbarheten": "okonterbarhet",
    "okonterbarhetens": "okonterbarhet",
    "okonterbarhets": "okonterbarhet",
    "okonterbars": "okonterbar",
    "okonterbart": "okonterbar",
    "okonterbarts": "okonterbar",
    "okontingenterade": "okontingenterad",
    "okontingenterades": "okontingenterad",
    "okontingenterads": "okontingenterad",
    "okontingenterat": "okontingenterad",
    "okontingenterats": "okontingenterad",
    "okontingenterbara": "okontingenterbar",
    "okontingenterbarare": "okontingenterbar",
    "okontingenterbarares": "okontingenterbar",
    "okontingenterbaras": "okontingenterbar",
    "okontingenterbarast": "okontingenterbar",
    "okontingenterbaraste": "okontingenterbar",
    "okontingenterbarastes": "okontingenterbar",
    "okontingenterbarasts": "okontingenterbar",
    "okontingenterbare": "okontingenterbar",
    "okontingenterbares": "okontingenterbar",
    "okontingenterbarheten": "okontingenterbarhet",
    "okontingenterbarhetens": "okontingenterbarhet",
    "okontingenterbarhets": "okontingenterbarhet",
    "okontingenterbars": "okontingenterbar",
    "okontingenterbart": "okontingenterbar",
    "okontingenterbarts": "okontingenterbar",
    "okontoriserade": "okontoriserad",
    "okontoriserades": "okontoriserad",
    "okontoriserads": "okontoriserad",
    "okontoriserat": "okontoriserad",
    "okontoriserats": "okontoriserad",
    "okontoriserbara": "okontoriserbar",
    "okontoriserbarare": "okontoriserbar",
    "okontoriserbarares": "okontoriserbar",
    "okontoriserbaras": "okontoriserbar",
    "okontoriserbarast": "okontoriserbar",
    "okontoriserbaraste": "okontoriserbar",
    "okontoriserbarastes": "okontoriserbar",
    "okontoriserbarasts": "okontoriserbar",
    "okontoriserbare": "okontoriserbar",
    "okontoriserbares": "okontoriserbar",
    "okontoriserbarheten": "okontoriserbarhet",
    "okontoriserbarhetens": "okontoriserbarhet",
    "okontoriserbarhets": "okontoriserbarhet",
    "okontoriserbars": "okontoriserbar",
    "okontoriserbart": "okontoriserbar",
    "okontoriserbarts": "okontoriserbar",
    "okontraherade": "okontraherad",
    "okontraherades": "okontraherad",
    "okontraherads": "okontraherad",
    "okontraherat": "okontraherad",
    "okontraherats": "okontraherad",
    "okontraherbara": "okontraherbar",
    "okontraherbarare": "okontraherbar",
    "okontraherbarares": "okontraherbar",
    "okontraherbaras": "okontraherbar",
    "okontraherbarast": "okontraherbar",
    "okontraherbaraste": "okontraherbar",
    "okontraherbarastes": "okontraherbar",
    "okontraherbarasts": "okontraherbar",
    "okontraherbare": "okontraherbar",
    "okontraherbares": "okontraherbar",
    "okontraherbarheten": "okontraherbarhet",
    "okontraherbarhetens": "okontraherbarhet",
    "okontraherbarhets": "okontraherbarhet",
    "okontraherbars": "okontraherbar",
    "okontraherbart": "okontraherbar",
    "okontraherbarts": "okontraherbar",
    "okontrakterade": "okontrakterad",
    "okontrakterades": "okontrakterad",
    "okontrakterads": "okontrakterad",
    "okontrakterat": "okontrakterad",
    "okontrakterats": "okontrakterad",
    "okontrakterbara": "okontrakterbar",
    "okontrakterbarare": "okontrakterbar",
    "okontrakterbarares": "okontrakterbar",
    "okontrakterbaras": "okontrakterbar",
    "okontrakterbarast": "okontrakterbar",
    "okontrakterbaraste": "okontrakterbar",
    "okontrakterbarastes": "okontrakterbar",
    "okontrakterbarasts": "okontrakterbar",
    "okontrakterbare": "okontrakterbar",
    "okontrakterbares": "okontrakterbar",
    "okontrakterbarheten": "okontrakterbarhet",
    "okontrakterbarhetens": "okontrakterbarhet",
    "okontrakterbarhets": "okontrakterbarhet",
    "okontrakterbars": "okontrakterbar",
    "okontrakterbart": "okontrakterbar",
    "okontrakterbarts": "okontrakterbar",
    "okontramanderade": "okontramanderad",
    "okontramanderades": "okontramanderad",
    "okontramanderads": "okontramanderad",
    "okontramanderat": "okontramanderad",
    "okontramanderats": "okontramanderad",
    "okontramanderbara": "okontramanderbar",
    "okontramanderbarare": "okontramanderbar",
    "okontramanderbarares": "okontramanderbar",
    "okontramanderbaras": "okontramanderbar",
    "okontramanderbarast": "okontramanderbar",
    "okontramanderbaraste": "okontramanderbar",
    "okontramanderbarastes": "okontramanderbar",
    "okontramanderbarasts": "okontramanderbar",
    "okontramanderbare": "okontramanderbar",
    "okontramanderbares": "okontramanderbar",
    "okontramanderbarheten": "okontramanderbarhet",
    "okontramanderbarhetens": "okontramanderbarhet",
    "okontramanderbarhets": "okontramanderbarhet",
    "okontramanderbars": "okontramanderbar",
    "okontramanderbart": "okontramanderbar",
    "okontramanderbarts": "okontramanderbar",
    "okontrasignerade": "okontrasignerad",
    "okontrasignerades": "okontrasignerad",
    "okontrasignerads": "okontrasignerad",
    "okontrasignerat": "okontrasignerad",
    "okontrasignerats": "okontrasignerad",
    "okontrasignerbara": "okontrasignerbar",
    "okontrasignerbarare": "okontrasignerbar",
    "okontrasignerbarares": "okontrasignerbar",
    "okontrasignerbaras": "okontrasignerbar",
    "okontrasignerbarast": "okontrasignerbar",
    "okontrasignerbaraste": "okontrasignerbar",
    "okontrasignerbarastes": "okontrasignerbar",
    "okontrasignerbarasts": "okontrasignerbar",
    "okontrasignerbare": "okontrasignerbar",
    "okontrasignerbares": "okontrasignerbar",
    "okontrasignerbarheten": "okontrasignerbarhet",
    "okontrasignerbarhetens": "okontrasignerbarhet",
    "okontrasignerbarhets": "okontrasignerbarhet",
    "okontrasignerbars": "okontrasignerbar",
    "okontrasignerbart": "okontrasignerbar",
    "okontrasignerbarts": "okontrasignerbar",
    "okontrasterade": "okontrasterad",
    "okontrasterades": "okontrasterad",
    "okontrasterads": "okontrasterad",
    "okontrasterat": "okontrasterad",
    "okontrasterats": "okontrasterad",
    "okontrasterbara": "okontrasterbar",
    "okontrasterbarare": "okontrasterbar",
    "okontrasterbarares": "okontrasterbar",
    "okontrasterbaras": "okontrasterbar",
    "okontrasterbarast": "okontrasterbar",
    "okontrasterbaraste": "okontrasterbar",
    "okontrasterbarastes": "okontrasterbar",
    "okontrasterbarasts": "okontrasterbar",
    "okontrasterbare": "okontrasterbar",
    "okontrasterbares": "okontrasterbar",
    "okontrasterbarheten": "okontrasterbarhet",
    "okontrasterbarhetens": "okontrasterbarhet",
    "okontrasterbarhets": "okontrasterbarhet",
    "okontrasterbars": "okontrasterbar",
    "okontrasterbart": "okontrasterbar",
    "okontrasterbarts": "okontrasterbar",
    "okontribuerade": "okontribuerad",
    "okontribuerades": "okontribuerad",
    "okontribuerads": "okontribuerad",
    "okontribuerat": "okontribuerad",
    "okontribuerats": "okontribuerad",
    "okontribuerbara": "okontribuerbar",
    "okontribuerbarare": "okontribuerbar",
    "okontribuerbarares": "okontribuerbar",
    "okontribuerbaras": "okontribuerbar",
    "okontribuerbarast": "okontribuerbar",
    "okontribuerbaraste": "okontribuerbar",
    "okontribuerbarastes": "okontribuerbar",
    "okontribuerbarasts": "okontribuerbar",
    "okontribuerbare": "okontribuerbar",
    "okontribuerbares": "okontribuerbar",
    "okontribuerbarheten": "okontribuerbarhet",
    "okontribuerbarhetens": "okontribuerbarhet",
    "okontribuerbarhets": "okontribuerbarhet",
    "okontribuerbars": "okontribuerbar",
    "okontribuerbart": "okontribuerbar",
    "okontribuerbarts": "okontribuerbar",
    "okontrollerade": "okontrollerad",
    "okontrollerades": "okontrollerad",
    "okontrollerads": "okontrollerad",
    "okontrollerat": "okontrollerad",
    "okontrollerats": "okontrollerad",
    "okontrollerbara": "okontrollerbar",
    "okontrollerbarare": "okontrollerbar",
    "okontrollerbarares": "okontrollerbar",
    "okontrollerbaras": "okontrollerbar",
    "okontrollerbarast": "okontrollerbar",
    "okontrollerbaraste": "okontrollerbar",
    "okontrollerbarastes": "okontrollerbar",
    "okontrollerbarasts": "okontrollerbar",
    "okontrollerbare": "okontrollerbar",
    "okontrollerbares": "okontrollerbar",
    "okontrollerbarheten": "okontrollerbarhet",
    "okontrollerbarhetens": "okontrollerbarhet",
    "okontrollerbarhets": "okontrollerbarhet",
    "okontrollerbars": "okontrollerbar",
    "okontrollerbart": "okontrollerbar",
    "okontrollerbarts": "okontrollerbar",
    "okontroversiella": "okontroversiell",
    "okontroversiellare": "okontroversiell",
    "okontroversiellares": "okontroversiell",
    "okontroversiellas": "okontroversiell",
    "okontroversiellast": "okontroversiell",
    "okontroversiellaste": "okontroversiell",
    "okontroversiellastes": "okontroversiell",
    "okontroversiellasts": "okontroversiell",
    "okontroversielle": "okontroversiell",
    "okontroversielles": "okontroversiell",
    "okontroversiells": "okontroversiell",
    "okontroversiellt": "okontroversiell",
    "okontroversiellts": "okontroversiell",
    "okonturerade": "okonturerad",
    "okonturerades": "okonturerad",
    "okonturerads": "okonturerad",
    "okonturerat": "okonturerad",
    "okonturerats": "okonturerad",
    "okonturerbara": "okonturerbar",
    "okonturerbarare": "okonturerbar",
    "okonturerbarares": "okonturerbar",
    "okonturerbaras": "okonturerbar",
    "okonturerbarast": "okonturerbar",
    "okonturerbaraste": "okonturerbar",
    "okonturerbarastes": "okonturerbar",
    "okonturerbarasts": "okonturerbar",
    "okonturerbare": "okonturerbar",
    "okonturerbares": "okonturerbar",
    "okonturerbarheten": "okonturerbarhet",
    "okonturerbarhetens": "okonturerbarhet",
    "okonturerbarhets": "okonturerbarhet",
    "okonturerbars": "okonturerbar",
    "okonturerbart": "okonturerbar",
    "okonturerbarts": "okonturerbar",
    "okonventionella": "okonventionell",
    "okonventionellare": "okonventionell",
    "okonventionellares": "okonventionell",
    "okonventionellas": "okonventionell",
    "okonventionellast": "okonventionell",
    "okonventionellaste": "okonventionell",
    "okonventionellastes": "okonventionell",
    "okonventionellasts": "okonventionell",
    "okonventionelle": "okonventionell",
    "okonventionelles": "okonventionell",
    "okonventionells": "okonventionell",
    "okonventionellt": "okonventionell",
    "okonventionellts": "okonventionell",
    "okonvergerade": "okonvergerad",
    "okonvergerades": "okonvergerad",
    "okonvergerads": "okonvergerad",
    "okonvergerat": "okonvergerad",
    "okonvergerats": "okonvergerad",
    "okonvergerbara": "okonvergerbar",
    "okonvergerbarare": "okonvergerbar",
    "okonvergerbarares": "okonvergerbar",
    "okonvergerbaras": "okonvergerbar",
    "okonvergerbarast": "okonvergerbar",
    "okonvergerbaraste": "okonvergerbar",
    "okonvergerbarastes": "okonvergerbar",
    "okonvergerbarasts": "okonvergerbar",
    "okonvergerbare": "okonvergerbar",
    "okonvergerbares": "okonvergerbar",
    "okonvergerbarheten": "okonvergerbarhet",
    "okonvergerbarhetens": "okonvergerbarhet",
    "okonvergerbarhets": "okonvergerbarhet",
    "okonvergerbars": "okonvergerbar",
    "okonvergerbart": "okonvergerbar",
    "okonvergerbarts": "okonvergerbar",
    "okonverserade": "okonverserad",
    "okonverserades": "okonverserad",
    "okonverserads": "okonverserad",
    "okonverserat": "okonverserad",
    "okonverserats": "okonverserad",
    "okonverserbara": "okonverserbar",
    "okonverserbarare": "okonverserbar",
    "okonverserbarares": "okonverserbar",
    "okonverserbaras": "okonverserbar",
    "okonverserbarast": "okonverserbar",
    "okonverserbaraste": "okonverserbar",
    "okonverserbarastes": "okonverserbar",
    "okonverserbarasts": "okonverserbar",
    "okonverserbare": "okonverserbar",
    "okonverserbares": "okonverserbar",
    "okonverserbarheten": "okonverserbarhet",
    "okonverserbarhetens": "okonverserbarhet",
    "okonverserbarhets": "okonverserbarhet",
    "okonverserbars": "okonverserbar",
    "okonverserbart": "okonverserbar",
    "okonverserbarts": "okonverserbar",
    "okonverterade": "okonverterad",
    "okonverterades": "okonverterad",
    "okonverterads": "okonverterad",
    "okonverterat": "okonverterad",
    "okonverterats": "okonverterad",
    "okonverterbara": "okonverterbar",
    "okonverterbarare": "okonverterbar",
    "okonverterbarares": "okonverterbar",
    "okonverterbaras": "okonverterbar",
    "okonverterbarast": "okonverterbar",
    "okonverterbaraste": "okonverterbar",
    "okonverterbarastes": "okonverterbar",
    "okonverterbarasts": "okonverterbar",
    "okonverterbare": "okonverterbar",
    "okonverterbares": "okonverterbar",
    "okonverterbarheten": "okonverterbarhet",
    "okonverterbarhetens": "okonverterbarhet",
    "okonverterbarhets": "okonverterbarhet",
    "okonverterbars": "okonverterbar",
    "okonverterbart": "okonverterbar",
    "okonverterbarts": "okonverterbar",
    "okonvojerade": "okonvojerad",
    "okonvojerades": "okonvojerad",
    "okonvojerads": "okonvojerad",
    "okonvojerat": "okonvojerad",
    "okonvojerats": "okonvojerad",
    "okonvojerbara": "okonvojerbar",
    "okonvojerbarare": "okonvojerbar",
    "okonvojerbarares": "okonvojerbar",
    "okonvojerbaras": "okonvojerbar",
    "okonvojerbarast": "okonvojerbar",
    "okonvojerbaraste": "okonvojerbar",
    "okonvojerbarastes": "okonvojerbar",
    "okonvojerbarasts": "okonvojerbar",
    "okonvojerbare": "okonvojerbar",
    "okonvojerbares": "okonvojerbar",
    "okonvojerbarheten": "okonvojerbarhet",
    "okonvojerbarhetens": "okonvojerbarhet",
    "okonvojerbarhets": "okonvojerbarhet",
    "okonvojerbars": "okonvojerbar",
    "okonvojerbart": "okonvojerbar",
    "okonvojerbarts": "okonvojerbar",
    "okoordinerade": "okoordinerad",
    "okoordinerades": "okoordinerad",
    "okoordinerads": "okoordinerad",
    "okoordinerat": "okoordinerad",
    "okoordinerats": "okoordinerad",
    "okoordinerbara": "okoordinerbar",
    "okoordinerbarare": "okoordinerbar",
    "okoordinerbarares": "okoordinerbar",
    "okoordinerbaras": "okoordinerbar",
    "okoordinerbarast": "okoordinerbar",
    "okoordinerbaraste": "okoordinerbar",
    "okoordinerbarastes": "okoordinerbar",
    "okoordinerbarasts": "okoordinerbar",
    "okoordinerbare": "okoordinerbar",
    "okoordinerbares": "okoordinerbar",
    "okoordinerbarheten": "okoordinerbarhet",
    "okoordinerbarhetens": "okoordinerbarhet",
    "okoordinerbarhets": "okoordinerbarhet",
    "okoordinerbars": "okoordinerbar",
    "okoordinerbart": "okoordinerbar",
    "okoordinerbarts": "okoordinerbar",
    "okopierade": "okopierad",
    "okopierades": "okopierad",
    "okopierads": "okopierad",
    "okopierat": "okopierad",
    "okopierats": "okopierad",
    "okopierbara": "okopierbar",
    "okopierbarare": "okopierbar",
    "okopierbarares": "okopierbar",
    "okopierbaras": "okopierbar",
    "okopierbarast": "okopierbar",
    "okopierbaraste": "okopierbar",
    "okopierbarastes": "okopierbar",
    "okopierbarasts": "okopierbar",
    "okopierbare": "okopierbar",
    "okopierbares": "okopierbar",
    "okopierbarheten": "okopierbarhet",
    "okopierbarhetens": "okopierbarhet",
    "okopierbarhets": "okopierbarhet",
    "okopierbars": "okopierbar",
    "okopierbart": "okopierbar",
    "okopierbarts": "okopierbar",
    "okoppade": "okoppad",
    "okoppades": "okoppad",
    "okoppads": "okoppad",
    "okoppat": "okoppad",
    "okoppats": "okoppad",
    "okopplade": "okopplad",
    "okopplades": "okopplad",
    "okopplads": "okopplad",
    "okopplat": "okopplad",
    "okopplats": "okopplad",
    "okorade": "okorad",
    "okorades": "okorad",
    "okorads": "okorad",
    "okorat": "okorad",
    "okorats": "okorad",
    "okorkade": "okorkad",
    "okorkades": "okorkad",
    "okorkads": "okorkad",
    "okorkat": "okorkad",
    "okorkats": "okorkad",
    "okorpade": "okorpad",
    "okorpades": "okorpad",
    "okorpads": "okorpad",
    "okorpat": "okorpad",
    "okorpats": "okorpad",
    "okorrelerade": "okorrelerad",
    "okorrelerades": "okorrelerad",
    "okorrelerads": "okorrelerad",
    "okorrelerat": "okorrelerad",
    "okorrelerats": "okorrelerad",
    "okorrelerbara": "okorrelerbar",
    "okorrelerbarare": "okorrelerbar",
    "okorrelerbarares": "okorrelerbar",
    "okorrelerbaras": "okorrelerbar",
    "okorrelerbarast": "okorrelerbar",
    "okorrelerbaraste": "okorrelerbar",
    "okorrelerbarastes": "okorrelerbar",
    "okorrelerbarasts": "okorrelerbar",
    "okorrelerbare": "okorrelerbar",
    "okorrelerbares": "okorrelerbar",
    "okorrelerbarheten": "okorrelerbarhet",
    "okorrelerbarhetens": "okorrelerbarhet",
    "okorrelerbarhets": "okorrelerbarhet",
    "okorrelerbars": "okorrelerbar",
    "okorrelerbart": "okorrelerbar",
    "okorrelerbarts": "okorrelerbar",
    "okorrigerade": "okorrigerad",
    "okorrigerades": "okorrigerad",
    "okorrigerads": "okorrigerad",
    "okorrigerat": "okorrigerad",
    "okorrigerats": "okorrigerad",
    "okorrigerbara": "okorrigerbar",
    "okorrigerbarare": "okorrigerbar",
    "okorrigerbarares": "okorrigerbar",
    "okorrigerbaras": "okorrigerbar",
    "okorrigerbarast": "okorrigerbar",
    "okorrigerbaraste": "okorrigerbar",
    "okorrigerbarastes": "okorrigerbar",
    "okorrigerbarasts": "okorrigerbar",
    "okorrigerbare": "okorrigerbar",
    "okorrigerbares": "okorrigerbar",
    "okorrigerbarheten": "okorrigerbarhet",
    "okorrigerbarhetens": "okorrigerbarhet",
    "okorrigerbarhets": "okorrigerbarhet",
    "okorrigerbars": "okorrigerbar",
    "okorrigerbart": "okorrigerbar",
    "okorrigerbarts": "okorrigerbar",
    "okorroderade": "okorroderad",
    "okorroderades": "okorroderad",
    "okorroderads": "okorroderad",
    "okorroderat": "okorroderad",
    "okorroderats": "okorroderad",
    "okorroderbara": "okorroderbar",
    "okorroderbarare": "okorroderbar",
    "okorroderbarares": "okorroderbar",
    "okorroderbaras": "okorroderbar",
    "okorroderbarast": "okorroderbar",
    "okorroderbaraste": "okorroderbar",
    "okorroderbarastes": "okorroderbar",
    "okorroderbarasts": "okorroderbar",
    "okorroderbare": "okorroderbar",
    "okorroderbares": "okorroderbar",
    "okorroderbarheten": "okorroderbarhet",
    "okorroderbarhetens": "okorroderbarhet",
    "okorroderbarhets": "okorroderbarhet",
    "okorroderbars": "okorroderbar",
    "okorroderbart": "okorroderbar",
    "okorroderbarts": "okorroderbar",
    "okorrugerade": "okorrugerad",
    "okorrugerades": "okorrugerad",
    "okorrugerads": "okorrugerad",
    "okorrugerat": "okorrugerad",
    "okorrugerats": "okorrugerad",
    "okorrugerbara": "okorrugerbar",
    "okorrugerbarare": "okorrugerbar",
    "okorrugerbarares": "okorrugerbar",
    "okorrugerbaras": "okorrugerbar",
    "okorrugerbarast": "okorrugerbar",
    "okorrugerbaraste": "okorrugerbar",
    "okorrugerbarastes": "okorrugerbar",
    "okorrugerbarasts": "okorrugerbar",
    "okorrugerbare": "okorrugerbar",
    "okorrugerbares": "okorrugerbar",
    "okorrugerbarheten": "okorrugerbarhet",
    "okorrugerbarhetens": "okorrugerbarhet",
    "okorrugerbarhets": "okorrugerbarhet",
    "okorrugerbars": "okorrugerbar",
    "okorrugerbart": "okorrugerbar",
    "okorrugerbarts": "okorrugerbar",
    "okorrumperade": "okorrumperad",
    "okorrumperades": "okorrumperad",
    "okorrumperads": "okorrumperad",
    "okorrumperat": "okorrumperad",
    "okorrumperats": "okorrumperad",
    "okorrumperbara": "okorrumperbar",
    "okorrumperbarare": "okorrumperbar",
    "okorrumperbarares": "okorrumperbar",
    "okorrumperbaras": "okorrumperbar",
    "okorrumperbarast": "okorrumperbar",
    "okorrumperbaraste": "okorrumperbar",
    "okorrumperbarastes": "okorrumperbar",
    "okorrumperbarasts": "okorrumperbar",
    "okorrumperbare": "okorrumperbar",
    "okorrumperbares": "okorrumperbar",
    "okorrumperbarheten": "okorrumperbarhet",
    "okorrumperbarhetens": "okorrumperbarhet",
    "okorrumperbarhets": "okorrumperbarhet",
    "okorrumperbars": "okorrumperbar",
    "okorrumperbart": "okorrumperbar",
    "okorrumperbarts": "okorrumperbar",
    "okorsade": "okorsad",
    "okorsades": "okorsad",
    "okorsads": "okorsad",
    "okorsat": "okorsad",
    "okorsats": "okorsad",
    "okorsetterade": "okorsetterad",
    "okorsetterades": "okorsetterad",
    "okorsetterads": "okorsetterad",
    "okorsetterat": "okorsetterad",
    "okorsetterats": "okorsetterad",
    "okorsetterbara": "okorsetterbar",
    "okorsetterbarare": "okorsetterbar",
    "okorsetterbarares": "okorsetterbar",
    "okorsetterbaras": "okorsetterbar",
    "okorsetterbarast": "okorsetterbar",
    "okorsetterbaraste": "okorsetterbar",
    "okorsetterbarastes": "okorsetterbar",
    "okorsetterbarasts": "okorsetterbar",
    "okorsetterbare": "okorsetterbar",
    "okorsetterbares": "okorsetterbar",
    "okorsetterbarheten": "okorsetterbarhet",
    "okorsetterbarhetens": "okorsetterbarhet",
    "okorsetterbarhets": "okorsetterbarhet",
    "okorsetterbars": "okorsetterbar",
    "okorsetterbart": "okorsetterbar",
    "okorsetterbarts": "okorsetterbar",
    "okorsförhörde": "okorsförhörd",
    "okorsförhördes": "okorsförhörd",
    "okorsförhörds": "okorsförhörd",
    "okorsförhört": "okorsförhörd",
    "okorsförhörts": "okorsförhörd",
    "okortade": "okortad",
    "okortades": "okortad",
    "okortads": "okortad",
    "okortat": "okortad",
    "okortats": "okortad",
    "okostymerade": "okostymerad",
    "okostymerades": "okostymerad",
    "okostymerads": "okostymerad",
    "okostymerat": "okostymerad",
    "okostymerats": "okostymerad",
    "okostymerbara": "okostymerbar",
    "okostymerbarare": "okostymerbar",
    "okostymerbarares": "okostymerbar",
    "okostymerbaras": "okostymerbar",
    "okostymerbarast": "okostymerbar",
    "okostymerbaraste": "okostymerbar",
    "okostymerbarastes": "okostymerbar",
    "okostymerbarasts": "okostymerbar",
    "okostymerbare": "okostymerbar",
    "okostymerbares": "okostymerbar",
    "okostymerbarheten": "okostymerbarhet",
    "okostymerbarhetens": "okostymerbarhet",
    "okostymerbarhets": "okostymerbarhet",
    "okostymerbars": "okostymerbar",
    "okostymerbart": "okostymerbar",
    "okostymerbarts": "okostymerbar",
    "okrackade": "okrackad",
    "okrackades": "okrackad",
    "okrackads": "okrackad",
    "okrackat": "okrackad",
    "okrackats": "okrackad",
    "okrackelerade": "okrackelerad",
    "okrackelerades": "okrackelerad",
    "okrackelerads": "okrackelerad",
    "okrackelerat": "okrackelerad",
    "okrackelerats": "okrackelerad",
    "okrackelerbara": "okrackelerbar",
    "okrackelerbarare": "okrackelerbar",
    "okrackelerbarares": "okrackelerbar",
    "okrackelerbaras": "okrackelerbar",
    "okrackelerbarast": "okrackelerbar",
    "okrackelerbaraste": "okrackelerbar",
    "okrackelerbarastes": "okrackelerbar",
    "okrackelerbarasts": "okrackelerbar",
    "okrackelerbare": "okrackelerbar",
    "okrackelerbares": "okrackelerbar",
    "okrackelerbarheten": "okrackelerbarhet",
    "okrackelerbarhetens": "okrackelerbarhet",
    "okrackelerbarhets": "okrackelerbarhet",
    "okrackelerbars": "okrackelerbar",
    "okrackelerbart": "okrackelerbar",
    "okrackelerbarts": "okrackelerbar",
    "okrafsade": "okrafsad",
    "okrafsades": "okrafsad",
    "okrafsads": "okrafsad",
    "okrafsat": "okrafsad",
    "okrafsats": "okrafsad",
    "okramade": "okramad",
    "okramades": "okramad",
    "okramads": "okramad",
    "okramat": "okramad",
    "okramats": "okramad",
    "okransade": "okransad",
    "okransades": "okransad",
    "okransads": "okransad",
    "okransat": "okransad",
    "okransats": "okransad",
    "okraschade": "okraschad",
    "okraschades": "okraschad",
    "okraschads": "okraschad",
    "okraschat": "okraschad",
    "okraschats": "okraschad",
    "okratsade": "okratsad",
    "okratsades": "okratsad",
    "okratsads": "okratsad",
    "okratsat": "okratsad",
    "okratsats": "okratsad",
    "okrattade": "okrattad",
    "okrattades": "okrattad",
    "okrattads": "okrattad",
    "okrattat": "okrattad",
    "okrattats": "okrattad",
    "okredensade": "okredensad",
    "okredensades": "okredensad",
    "okredensads": "okredensad",
    "okredensat": "okredensad",
    "okredensats": "okredensad",
    "okrediterade": "okrediterad",
    "okrediterades": "okrediterad",
    "okrediterads": "okrediterad",
    "okrediterat": "okrediterad",
    "okrediterats": "okrediterad",
    "okrediterbara": "okrediterbar",
    "okrediterbarare": "okrediterbar",
    "okrediterbarares": "okrediterbar",
    "okrediterbaras": "okrediterbar",
    "okrediterbarast": "okrediterbar",
    "okrediterbaraste": "okrediterbar",
    "okrediterbarastes": "okrediterbar",
    "okrediterbarasts": "okrediterbar",
    "okrediterbare": "okrediterbar",
    "okrediterbares": "okrediterbar",
    "okrediterbarheten": "okrediterbarhet",
    "okrediterbarhetens": "okrediterbarhet",
    "okrediterbarhets": "okrediterbarhet",
    "okrediterbars": "okrediterbar",
    "okrediterbart": "okrediterbar",
    "okrediterbarts": "okrediterbar",
    "okreerade": "okreerad",
    "okreerades": "okreerad",
    "okreerads": "okreerad",
    "okreerat": "okreerad",
    "okreerats": "okreerad",
    "okreerbara": "okreerbar",
    "okreerbarare": "okreerbar",
    "okreerbarares": "okreerbar",
    "okreerbaras": "okreerbar",
    "okreerbarast": "okreerbar",
    "okreerbaraste": "okreerbar",
    "okreerbarastes": "okreerbar",
    "okreerbarasts": "okreerbar",
    "okreerbare": "okreerbar",
    "okreerbares": "okreerbar",
    "okreerbarheten": "okreerbarhet",
    "okreerbarhetens": "okreerbarhet",
    "okreerbarhets": "okreerbarhet",
    "okreerbars": "okreerbar",
    "okreerbart": "okreerbar",
    "okreerbarts": "okreerbar",
    "okremerade": "okremerad",
    "okremerades": "okremerad",
    "okremerads": "okremerad",
    "okremerat": "okremerad",
    "okremerats": "okremerad",
    "okremerbara": "okremerbar",
    "okremerbarare": "okremerbar",
    "okremerbarares": "okremerbar",
    "okremerbaras": "okremerbar",
    "okremerbarast": "okremerbar",
    "okremerbaraste": "okremerbar",
    "okremerbarastes": "okremerbar",
    "okremerbarasts": "okremerbar",
    "okremerbare": "okremerbar",
    "okremerbares": "okremerbar",
    "okremerbarheten": "okremerbarhet",
    "okremerbarhetens": "okremerbarhet",
    "okremerbarhets": "okremerbarhet",
    "okremerbars": "okremerbar",
    "okremerbart": "okremerbar",
    "okremerbarts": "okremerbar",
    "okreperade": "okreperad",
    "okreperades": "okreperad",
    "okreperads": "okreperad",
    "okreperat": "okreperad",
    "okreperats": "okreperad",
    "okreperbara": "okreperbar",
    "okreperbarare": "okreperbar",
    "okreperbarares": "okreperbar",
    "okreperbaras": "okreperbar",
    "okreperbarast": "okreperbar",
    "okreperbaraste": "okreperbar",
    "okreperbarastes": "okreperbar",
    "okreperbarasts": "okreperbar",
    "okreperbare": "okreperbar",
    "okreperbares": "okreperbar",
    "okreperbarheten": "okreperbarhet",
    "okreperbarhetens": "okreperbarhet",
    "okreperbarhets": "okreperbarhet",
    "okreperbars": "okreperbar",
    "okreperbart": "okreperbar",
    "okreperbarts": "okreperbar",
    "okretade": "okretad",
    "okretades": "okretad",
    "okretads": "okretad",
    "okretat": "okretad",
    "okretats": "okretad",
    "okreverade": "okreverad",
    "okreverades": "okreverad",
    "okreverads": "okreverad",
    "okreverat": "okreverad",
    "okreverats": "okreverad",
    "okreverbara": "okreverbar",
    "okreverbarare": "okreverbar",
    "okreverbarares": "okreverbar",
    "okreverbaras": "okreverbar",
    "okreverbarast": "okreverbar",
    "okreverbaraste": "okreverbar",
    "okreverbarastes": "okreverbar",
    "okreverbarasts": "okreverbar",
    "okreverbare": "okreverbar",
    "okreverbares": "okreverbar",
    "okreverbarheten": "okreverbarhet",
    "okreverbarhetens": "okreverbarhet",
    "okreverbarhets": "okreverbarhet",
    "okreverbars": "okreverbar",
    "okreverbart": "okreverbar",
    "okreverbarts": "okreverbar",
    "okriminaliserade": "okriminaliserad",
    "okriminaliserades": "okriminaliserad",
    "okriminaliserads": "okriminaliserad",
    "okriminaliserat": "okriminaliserad",
    "okriminaliserats": "okriminaliserad",
    "okriminaliserbara": "okriminaliserbar",
    "okriminaliserbarare": "okriminaliserbar",
    "okriminaliserbarares": "okriminaliserbar",
    "okriminaliserbaras": "okriminaliserbar",
    "okriminaliserbarast": "okriminaliserbar",
    "okriminaliserbaraste": "okriminaliserbar",
    "okriminaliserbarastes": "okriminaliserbar",
    "okriminaliserbarasts": "okriminaliserbar",
    "okriminaliserbare": "okriminaliserbar",
    "okriminaliserbares": "okriminaliserbar",
    "okriminaliserbarheten": "okriminaliserbarhet",
    "okriminaliserbarhetens": "okriminaliserbarhet",
    "okriminaliserbarhets": "okriminaliserbarhet",
    "okriminaliserbars": "okriminaliserbar",
    "okriminaliserbart": "okriminaliserbar",
    "okriminaliserbarts": "okriminaliserbar",
    "okringgärdade": "okringgärdad",
    "okringgärdades": "okringgärdad",
    "okringgärdads": "okringgärdad",
    "okringgärdat": "okringgärdad",
    "okringgärdats": "okringgärdad",
    "okringrände": "okringränd",
    "okringrändes": "okringränd",
    "okringränds": "okringränd",
    "okringränt": "okringränd",
    "okringränts": "okringränd",
    "okringskansade": "okringskansad",
    "okringskansades": "okringskansad",
    "okringskansads": "okringskansad",
    "okringskansat": "okringskansad",
    "okringskansats": "okringskansad",
    "okristalliserade": "okristalliserad",
    "okristalliserades": "okristalliserad",
    "okristalliserads": "okristalliserad",
    "okristalliserat": "okristalliserad",
    "okristalliserats": "okristalliserad",
    "okristalliserbara": "okristalliserbar",
    "okristalliserbarare": "okristalliserbar",
    "okristalliserbarares": "okristalliserbar",
    "okristalliserbaras": "okristalliserbar",
    "okristalliserbarast": "okristalliserbar",
    "okristalliserbaraste": "okristalliserbar",
    "okristalliserbarastes": "okristalliserbar",
    "okristalliserbarasts": "okristalliserbar",
    "okristalliserbare": "okristalliserbar",
    "okristalliserbares": "okristalliserbar",
    "okristalliserbarheten": "okristalliserbarhet",
    "okristalliserbarhetens": "okristalliserbarhet",
    "okristalliserbarhets": "okristalliserbarhet",
    "okristalliserbars": "okristalliserbar",
    "okristalliserbart": "okristalliserbar",
    "okristalliserbarts": "okristalliserbar",
    "okristliga": "okristlig",
    "okristligare": "okristlig",
    "okristligares": "okristlig",
    "okristligas": "okristlig",
    "okristligast": "okristlig",
    "okristligaste": "okristlig",
    "okristligastes": "okristlig",
    "okristligasts": "okristlig",
    "okristlige": "okristlig",
    "okristliges": "okristlig",
    "okristligheten": "okristlighet",
    "okristlighetens": "okristlighet",
    "okristligheter": "okristlighet",
    "okristligheterna": "okristlighet",
    "okristligheternas": "okristlighet",
    "okristligheters": "okristlighet",
    "okristlighets": "okristlighet",
    "okristligs": "okristlig",
    "okristligt": "okristlig",
    "okristligts": "okristlig",
    "okristnade": "okristnad",
    "okristnades": "okristnad",
    "okristnads": "okristnad",
    "okristnat": "okristnad",
    "okristnats": "okristnad",
    "okritade": "okritad",
    "okritades": "okritad",
    "okritads": "okritad",
    "okritat": "okritad",
    "okritats": "okritad",
    "okritiserade": "okritiserad",
    "okritiserades": "okritiserad",
    "okritiserads": "okritiserad",
    "okritiserat": "okritiserad",
    "okritiserats": "okritiserad",
    "okritiserbara": "okritiserbar",
    "okritiserbarare": "okritiserbar",
    "okritiserbarares": "okritiserbar",
    "okritiserbaras": "okritiserbar",
    "okritiserbarast": "okritiserbar",
    "okritiserbaraste": "okritiserbar",
    "okritiserbarastes": "okritiserbar",
    "okritiserbarasts": "okritiserbar",
    "okritiserbare": "okritiserbar",
    "okritiserbares": "okritiserbar",
    "okritiserbarheten": "okritiserbarhet",
    "okritiserbarhetens": "okritiserbarhet",
    "okritiserbarhets": "okritiserbarhet",
    "okritiserbars": "okritiserbar",
    "okritiserbart": "okritiserbar",
    "okritiserbarts": "okritiserbar",
    "okritiska": "okritisk",
    "okritiskare": "okritisk",
    "okritiskares": "okritisk",
    "okritiskas": "okritisk",
    "okritiskast": "okritisk",
    "okritiskaste": "okritisk",
    "okritiskastes": "okritisk",
    "okritiskasts": "okritisk",
    "okritiske": "okritisk",
    "okritiskes": "okritisk",
    "okritisks": "okritisk",
    "okritiskt": "okritisk",
    "okritiskts": "okritisk",
    "okrockade": "okrockad",
    "okrockades": "okrockad",
    "okrockads": "okrockad",
    "okrockat": "okrockad",
    "okrockats": "okrockad",
    "okrokade": "okrokad",
    "okrokades": "okrokad",
    "okrokads": "okrokad",
    "okrokat": "okrokad",
    "okrokats": "okrokad",
    "okroknade": "okroknad",
    "okroknades": "okroknad",
    "okroknads": "okroknad",
    "okroknat": "okroknad",
    "okroknats": "okroknad",
    "okromade": "okromad",
    "okromades": "okromad",
    "okromads": "okromad",
    "okromat": "okromad",
    "okromats": "okromad",
    "okroppsliga": "okroppslig",
    "okroppsligare": "okroppslig",
    "okroppsligares": "okroppslig",
    "okroppsligas": "okroppslig",
    "okroppsligast": "okroppslig",
    "okroppsligaste": "okroppslig",
    "okroppsligastes": "okroppslig",
    "okroppsligasts": "okroppslig",
    "okroppslige": "okroppslig",
    "okroppsliges": "okroppslig",
    "okroppsligheten": "okroppslighet",
    "okroppslighetens": "okroppslighet",
    "okroppslighets": "okroppslighet",
    "okroppsligs": "okroppslig",
    "okroppsligt": "okroppslig",
    "okroppsligts": "okroppslig",
    "okrossade": "okrossad",
    "okrossades": "okrossad",
    "okrossads": "okrossad",
    "okrossat": "okrossad",
    "okrossats": "okrossad",
    "okrossbara": "okrossbar",
    "okrossbarare": "okrossbar",
    "okrossbarares": "okrossbar",
    "okrossbaras": "okrossbar",
    "okrossbarast": "okrossbar",
    "okrossbaraste": "okrossbar",
    "okrossbarastes": "okrossbar",
    "okrossbarasts": "okrossbar",
    "okrossbare": "okrossbar",
    "okrossbares": "okrossbar",
    "okrossbarheten": "okrossbarhet",
    "okrossbarhetens": "okrossbarhet",
    "okrossbarhets": "okrossbarhet",
    "okrossbars": "okrossbar",
    "okrossbart": "okrossbar",
    "okrossbarts": "okrossbar",
    "okrullade": "okrullad",
    "okrullades": "okrullad",
    "okrullads": "okrullad",
    "okrullat": "okrullad",
    "okrullats": "okrullad",
    "okrusade": "okrusad",
    "okrusades": "okrusad",
    "okrusads": "okrusad",
    "okrusat": "okrusad",
    "okrusats": "okrusad",
    "okryddade": "okryddad",
    "okryddades": "okryddad",
    "okryddads": "okryddad",
    "okryddat": "okryddad",
    "okryddats": "okryddad",
    "okrympta": "okrympt",
    "okrymptas": "okrympt",
    "okrympte": "okrympt",
    "okrymptes": "okrympt",
    "okrympts": "okrympt",
    "okrypterade": "okrypterad",
    "okrypterades": "okrypterad",
    "okrypterads": "okrypterad",
    "okrypterat": "okrypterad",
    "okrypterats": "okrypterad",
    "okrypterbara": "okrypterbar",
    "okrypterbarare": "okrypterbar",
    "okrypterbarares": "okrypterbar",
    "okrypterbaras": "okrypterbar",
    "okrypterbarast": "okrypterbar",
    "okrypterbaraste": "okrypterbar",
    "okrypterbarastes": "okrypterbar",
    "okrypterbarasts": "okrypterbar",
    "okrypterbare": "okrypterbar",
    "okrypterbares": "okrypterbar",
    "okrypterbarheten": "okrypterbarhet",
    "okrypterbarhetens": "okrypterbarhet",
    "okrypterbarhets": "okrypterbarhet",
    "okrypterbars": "okrypterbar",
    "okrypterbart": "okrypterbar",
    "okrypterbarts": "okrypterbar",
    "okryssade": "okryssad",
    "okryssades": "okryssad",
    "okryssads": "okryssad",
    "okryssat": "okryssad",
    "okryssats": "okryssad",
    "okrängde": "okrängd",
    "okrängdes": "okrängd",
    "okrängds": "okrängd",
    "okrängt": "okrängd",
    "okrängts": "okrängd",
    "okränkbara": "okränkbar",
    "okränkbarare": "okränkbar",
    "okränkbarares": "okränkbar",
    "okränkbaras": "okränkbar",
    "okränkbarast": "okränkbar",
    "okränkbaraste": "okränkbar",
    "okränkbarastes": "okränkbar",
    "okränkbarasts": "okränkbar",
    "okränkbare": "okränkbar",
    "okränkbares": "okränkbar",
    "okränkbarheten": "okränkbarhet",
    "okränkbarhetens": "okränkbarhet",
    "okränkbarhets": "okränkbarhet",
    "okränkbars": "okränkbar",
    "okränkbart": "okränkbar",
    "okränkbarts": "okränkbar",
    "okränkta": "okränkt",
    "okränktas": "okränkt",
    "okränkte": "okränkt",
    "okränktes": "okränkt",
    "okränkts": "okränkt",
    "okräppade": "okräppad",
    "okräppades": "okräppad",
    "okräppads": "okräppad",
    "okräppat": "okräppad",
    "okräppats": "okräppad",
    "okrävde": "okrävd",
    "okrävdes": "okrävd",
    "okrävds": "okrävd",
    "okrävt": "okrävd",
    "okrävts": "okrävd",
    "okrökta": "okrökt",
    "okröktas": "okrökt",
    "okrökte": "okrökt",
    "okröktes": "okrökt",
    "okrökts": "okrökt",
    "okrönta": "okrönt",
    "okröntare": "okrönt",
    "okröntares": "okrönt",
    "okröntas": "okrönt",
    "okröntast": "okrönt",
    "okröntaste": "okrönt",
    "okröntastes": "okrönt",
    "okröntasts": "okrönt",
    "okrönte": "okrönt",
    "okröntes": "okrönt",
    "okrönts": "okrönt",
    "oks": "ok",
    "oktaedern": "oktaeder",
    "oktaederns": "oktaeder",
    "oktaeders": "oktaeder",
    "oktaedrar": "oktaeder",
    "oktaedrarna": "oktaeder",
    "oktaedrarnas": "oktaeder",
    "oktaedrars": "oktaeder",
    "oktanen": "oktan",
    "oktanens": "oktan",
    "oktaner": "oktan",
    "oktanerna": "oktan",
    "oktanernas": "oktan",
    "oktaners": "oktan",
    "oktanet": "oktan",
    "oktanets": "oktan",
    "oktanolen": "oktanol",
    "oktanolens": "oktanol",
    "oktanoler": "oktanol",
    "oktanolerna": "oktanol",
    "oktanolernas": "oktanol",
    "oktanolers": "oktanol",
    "oktanols": "oktanol",
    "oktans": "oktan",
    "oktantalen": "oktantal",
    "oktantalens": "oktantal",
    "oktantalet": "oktantal",
    "oktantalets": "oktantal",
    "oktantals": "oktantal",
    "oktanten": "oktant",
    "oktantens": "oktant",
    "oktanter": "oktant",
    "oktanterna": "oktant",
    "oktanternas": "oktant",
    "oktanters": "oktant",
    "oktants": "oktant",
    "oktanvärden": "oktanvärde",
    "oktanvärdena": "oktanvärde",
    "oktanvärdenas": "oktanvärde",
    "oktanvärdens": "oktanvärde",
    "oktanvärdes": "oktanvärde",
    "oktanvärdet": "oktanvärde",
    "oktanvärdets": "oktanvärde",
    "oktaven": "oktav",
    "oktavens": "oktav",
    "oktaver": "oktav",
    "oktaverade": "oktavera",
    "oktaverades": "oktavera",
    "oktaverande": "oktavera",
    "oktaveranden": "oktaverande",
    "oktaverandena": "oktaverande",
    "oktaverandenas": "oktaverande",
    "oktaverandens": "oktaverande",
    "oktaverandes": "oktaverande",
    "oktaverandet": "oktaverande",
    "oktaverandets": "oktaverande",
    "oktaverar": "oktavera",
    "oktaveras": "oktavera",
    "oktaverat": "oktavera",
    "oktaverats": "oktavera",
    "oktaveringar": "oktavering",
    "oktaveringarna": "oktavering",
    "oktaveringarnas": "oktavering",
    "oktaveringars": "oktavering",
    "oktaveringen": "oktavering",
    "oktaveringens": "oktavering",
    "oktaverings": "oktavering",
    "oktaverna": "oktav",
    "oktavernas": "oktav",
    "oktavers": "oktav",
    "oktavs": "oktav",
    "oktetten": "oktett",
    "oktettens": "oktett",
    "oktetter": "oktett",
    "oktetterna": "oktett",
    "oktetternas": "oktett",
    "oktetters": "oktett",
    "oktetts": "oktett",
    "oktoberhimlar": "oktoberhimmel",
    "oktoberhimlarna": "oktoberhimmel",
    "oktoberhimlarnas": "oktoberhimmel",
    "oktoberhimlars": "oktoberhimmel",
    "oktoberhimlen": "oktoberhimmel",
    "oktoberhimlens": "oktoberhimmel",
    "oktoberhimmelen": "oktoberhimmel",
    "oktoberhimmelens": "oktoberhimmel",
    "oktoberhimmeln": "oktoberhimmel",
    "oktoberhimmelns": "oktoberhimmel",
    "oktoberhimmels": "oktoberhimmel",
    "oktobers": "oktober",
    "oktoden": "oktod",
    "oktodens": "oktod",
    "oktoder": "oktod",
    "oktoderna": "oktod",
    "oktodernas": "oktod",
    "oktoders": "oktod",
    "oktods": "oktod",
    "oktogenet": "oktogen",
    "oktogenets": "oktogen",
    "oktogens": "oktogen",
    "oktogonen": "oktogon",
    "oktogonens": "oktogon",
    "oktogoner": "oktogon",
    "oktogonerna": "oktogon",
    "oktogonernas": "oktogon",
    "oktogoners": "oktogon",
    "oktogons": "oktogon",
    "oktrojen": "oktroj",
    "oktrojens": "oktroj",
    "oktrojer": "oktroj",
    "oktrojerad": "oktrojera",
    "oktrojerade": "oktrojera",
    "oktrojerades": "oktrojera",
    "oktrojerads": "oktrojera",
    "oktrojerande": "oktrojera",
    "oktrojeranden": "oktrojerande",
    "oktrojerandena": "oktrojerande",
    "oktrojerandenas": "oktrojerande",
    "oktrojerandens": "oktrojerande",
    "oktrojerandes": "oktrojerande",
    "oktrojerandet": "oktrojerande",
    "oktrojerandets": "oktrojerande",
    "oktrojerar": "oktrojera",
    "oktrojeras": "oktrojera",
    "oktrojerat": "oktrojera",
    "oktrojerats": "oktrojera",
    "oktrojerbara": "oktrojerbar",
    "oktrojerbarare": "oktrojerbar",
    "oktrojerbarares": "oktrojerbar",
    "oktrojerbaras": "oktrojerbar",
    "oktrojerbarast": "oktrojerbar",
    "oktrojerbaraste": "oktrojerbar",
    "oktrojerbarastes": "oktrojerbar",
    "oktrojerbarasts": "oktrojerbar",
    "oktrojerbare": "oktrojerbar",
    "oktrojerbares": "oktrojerbar",
    "oktrojerbarheten": "oktrojerbarhet",
    "oktrojerbarhetens": "oktrojerbarhet",
    "oktrojerbarhets": "oktrojerbarhet",
    "oktrojerbars": "oktrojerbar",
    "oktrojerbart": "oktrojerbar",
    "oktrojerbarts": "oktrojerbar",
    "oktrojeringar": "oktrojering",
    "oktrojeringarna": "oktrojering",
    "oktrojeringarnas": "oktrojering",
    "oktrojeringars": "oktrojering",
    "oktrojeringen": "oktrojering",
    "oktrojeringens": "oktrojering",
    "oktrojerings": "oktrojering",
    "oktrojerna": "oktroj",
    "oktrojernas": "oktroj",
    "oktrojers": "oktroj",
    "oktrojs": "oktroj",
    "okuberade": "okuberad",
    "okuberades": "okuberad",
    "okuberads": "okuberad",
    "okuberat": "okuberad",
    "okuberats": "okuberad",
    "okuberbara": "okuberbar",
    "okuberbarare": "okuberbar",
    "okuberbarares": "okuberbar",
    "okuberbaras": "okuberbar",
    "okuberbarast": "okuberbar",
    "okuberbaraste": "okuberbar",
    "okuberbarastes": "okuberbar",
    "okuberbarasts": "okuberbar",
    "okuberbare": "okuberbar",
    "okuberbares": "okuberbar",
    "okuberbarheten": "okuberbarhet",
    "okuberbarhetens": "okuberbarhet",
    "okuberbarhets": "okuberbarhet",
    "okuberbars": "okuberbar",
    "okuberbart": "okuberbar",
    "okuberbarts": "okuberbar",
    "okuggade": "okuggad",
    "okuggades": "okuggad",
    "okuggads": "okuggad",
    "okuggat": "okuggad",
    "okuggats": "okuggad",
    "okujonerade": "okujonerad",
    "okujonerades": "okujonerad",
    "okujonerads": "okujonerad",
    "okujonerat": "okujonerad",
    "okujonerats": "okujonerad",
    "okujonerbara": "okujonerbar",
    "okujonerbarare": "okujonerbar",
    "okujonerbarares": "okujonerbar",
    "okujonerbaras": "okujonerbar",
    "okujonerbarast": "okujonerbar",
    "okujonerbaraste": "okujonerbar",
    "okujonerbarastes": "okujonerbar",
    "okujonerbarasts": "okujonerbar",
    "okujonerbare": "okujonerbar",
    "okujonerbares": "okujonerbar",
    "okujonerbarheten": "okujonerbarhet",
    "okujonerbarhetens": "okujonerbarhet",
    "okujonerbarhets": "okujonerbarhet",
    "okujonerbars": "okujonerbar",
    "okujonerbart": "okujonerbar",
    "okujonerbarts": "okujonerbar",
    "okulager": "okulage",
    "okulagerna": "okulage",
    "okulagernas": "okulage",
    "okulagers": "okulage",
    "okulages": "okulage",
    "okulaget": "okulage",
    "okulagets": "okulage",
    "okulara": "okular",
    "okularare": "okular",
    "okularares": "okular",
    "okularas": "okular",
    "okularast": "okular",
    "okularaste": "okular",
    "okularastes": "okular",
    "okularasts": "okular",
    "okulare": "okular",
    "okularen": "okular",
    "okularens": "okular",
    "okulares": "okular",
    "okularet": "okular",
    "okularets": "okular",
    "okulars": "okular",
    "okulart": "okular",
    "okularts": "okular",
    "okulerad": "okulera",
    "okulerade": "okulera",
    "okulerades": "okulera",
    "okulerads": "okulera",
    "okulerande": "okulera",
    "okuleranden": "okulerande",
    "okulerandena": "okulerande",
    "okulerandenas": "okulerande",
    "okulerandens": "okulerande",
    "okulerandes": "okulerande",
    "okulerandet": "okulerande",
    "okulerandets": "okulerande",
    "okulerar": "okulera",
    "okuleras": "okulera",
    "okulerat": "okulera",
    "okulerats": "okulera",
    "okulerbara": "okulerbar",
    "okulerbarare": "okulerbar",
    "okulerbarares": "okulerbar",
    "okulerbaras": "okulerbar",
    "okulerbarast": "okulerbar",
    "okulerbaraste": "okulerbar",
    "okulerbarastes": "okulerbar",
    "okulerbarasts": "okulerbar",
    "okulerbare": "okulerbar",
    "okulerbares": "okulerbar",
    "okulerbarheten": "okulerbarhet",
    "okulerbarhetens": "okulerbarhet",
    "okulerbarhets": "okulerbarhet",
    "okulerbars": "okulerbar",
    "okulerbart": "okulerbar",
    "okulerbarts": "okulerbar",
    "okuleringar": "okulering",
    "okuleringarna": "okulering",
    "okuleringarnas": "okulering",
    "okuleringars": "okulering",
    "okuleringen": "okulering",
    "okuleringens": "okulering",
    "okulerings": "okulering",
    "okullade": "okullad",
    "okullades": "okullad",
    "okullads": "okullad",
    "okullat": "okullad",
    "okullats": "okullad",
    "okullkastade": "okullkastad",
    "okullkastades": "okullkastad",
    "okullkastads": "okullkastad",
    "okullkastat": "okullkastad",
    "okullkastats": "okullkastad",
    "okullpratade": "okullpratad",
    "okullpratades": "okullpratad",
    "okullpratads": "okullpratad",
    "okullpratat": "okullpratad",
    "okullpratats": "okullpratad",
    "okultiverade": "okultiverad",
    "okultiverades": "okultiverad",
    "okultiverads": "okultiverad",
    "okultiverat": "okultiverad",
    "okultiverats": "okultiverad",
    "okultiverbara": "okultiverbar",
    "okultiverbarare": "okultiverbar",
    "okultiverbarares": "okultiverbar",
    "okultiverbaras": "okultiverbar",
    "okultiverbarast": "okultiverbar",
    "okultiverbaraste": "okultiverbar",
    "okultiverbarastes": "okultiverbar",
    "okultiverbarasts": "okultiverbar",
    "okultiverbare": "okultiverbar",
    "okultiverbares": "okultiverbar",
    "okultiverbarheten": "okultiverbarhet",
    "okultiverbarhetens": "okultiverbarhet",
    "okultiverbarhets": "okultiverbarhet",
    "okultiverbars": "okultiverbar",
    "okultiverbart": "okultiverbar",
    "okultiverbarts": "okultiverbar",
    "okulturen": "okultur",
    "okulturens": "okultur",
    "okulturs": "okultur",
    "okulära": "okulär",
    "okulärare": "okulär",
    "okulärares": "okulär",
    "okuläras": "okulär",
    "okulärast": "okulär",
    "okuläraste": "okulär",
    "okulärastes": "okulär",
    "okulärasts": "okulär",
    "okuläre": "okulär",
    "okuläres": "okulär",
    "okulärs": "okulär",
    "okulärt": "okulär",
    "okulärts": "okulär",
    "okumulerade": "okumulerad",
    "okumulerades": "okumulerad",
    "okumulerads": "okumulerad",
    "okumulerat": "okumulerad",
    "okumulerats": "okumulerad",
    "okumulerbara": "okumulerbar",
    "okumulerbarare": "okumulerbar",
    "okumulerbarares": "okumulerbar",
    "okumulerbaras": "okumulerbar",
    "okumulerbarast": "okumulerbar",
    "okumulerbaraste": "okumulerbar",
    "okumulerbarastes": "okumulerbar",
    "okumulerbarasts": "okumulerbar",
    "okumulerbare": "okumulerbar",
    "okumulerbares": "okumulerbar",
    "okumulerbarheten": "okumulerbarhet",
    "okumulerbarhetens": "okumulerbarhet",
    "okumulerbarhets": "okumulerbarhet",
    "okumulerbars": "okumulerbar",
    "okumulerbart": "okumulerbar",
    "okumulerbarts": "okumulerbar",
    "okunniga": "okunnig",
    "okunnigare": "okunnig",
    "okunnigares": "okunnig",
    "okunnigas": "okunnig",
    "okunnigast": "okunnig",
    "okunnigaste": "okunnig",
    "okunnigastes": "okunnig",
    "okunnigasts": "okunnig",
    "okunnige": "okunnig",
    "okunniges": "okunnig",
    "okunnigheten": "okunnighet",
    "okunnighetens": "okunnighet",
    "okunnigheter": "okunnighet",
    "okunnigheterna": "okunnighet",
    "okunnigheternas": "okunnighet",
    "okunnigheters": "okunnighet",
    "okunnighets": "okunnighet",
    "okunnigs": "okunnig",
    "okunnigt": "okunnig",
    "okunnigts": "okunnig",
    "okunskapen": "okunskap",
    "okunskapens": "okunskap",
    "okunskaps": "okunskap",
    "okupade": "okupad",
    "okupades": "okupad",
    "okupads": "okupad",
    "okupat": "okupad",
    "okupats": "okupad",
    "okuperade": "okuperad",
    "okuperades": "okuperad",
    "okuperads": "okuperad",
    "okuperat": "okuperad",
    "okuperats": "okuperad",
    "okuperbara": "okuperbar",
    "okuperbarare": "okuperbar",
    "okuperbarares": "okuperbar",
    "okuperbaras": "okuperbar",
    "okuperbarast": "okuperbar",
    "okuperbaraste": "okuperbar",
    "okuperbarastes": "okuperbar",
    "okuperbarasts": "okuperbar",
    "okuperbare": "okuperbar",
    "okuperbares": "okuperbar",
    "okuperbarheten": "okuperbarhet",
    "okuperbarhetens": "okuperbarhet",
    "okuperbarhets": "okuperbarhet",
    "okuperbars": "okuperbar",
    "okuperbart": "okuperbar",
    "okuperbarts": "okuperbar",
    "okurade": "okurad",
    "okurades": "okurad",
    "okurads": "okurad",
    "okurat": "okurad",
    "okuraterade": "okuraterad",
    "okuraterades": "okuraterad",
    "okuraterads": "okuraterad",
    "okuraterat": "okuraterad",
    "okuraterats": "okuraterad",
    "okuraterbara": "okuraterbar",
    "okuraterbarare": "okuraterbar",
    "okuraterbarares": "okuraterbar",
    "okuraterbaras": "okuraterbar",
    "okuraterbarast": "okuraterbar",
    "okuraterbaraste": "okuraterbar",
    "okuraterbarastes": "okuraterbar",
    "okuraterbarasts": "okuraterbar",
    "okuraterbare": "okuraterbar",
    "okuraterbares": "okuraterbar",
    "okuraterbarheten": "okuraterbarhet",
    "okuraterbarhetens": "okuraterbarhet",
    "okuraterbarhets": "okuraterbarhet",
    "okuraterbars": "okuraterbar",
    "okuraterbart": "okuraterbar",
    "okuraterbarts": "okuraterbar",
    "okurats": "okurad",
    "okurerade": "okurerad",
    "okurerades": "okurerad",
    "okurerads": "okurerad",
    "okurerat": "okurerad",
    "okurerats": "okurerad",
    "okurerbara": "okurerbar",
    "okurerbarare": "okurerbar",
    "okurerbarares": "okurerbar",
    "okurerbaras": "okurerbar",
    "okurerbarast": "okurerbar",
    "okurerbaraste": "okurerbar",
    "okurerbarastes": "okurerbar",
    "okurerbarasts": "okurerbar",
    "okurerbare": "okurerbar",
    "okurerbares": "okurerbar",
    "okurerbarheten": "okurerbarhet",
    "okurerbarhetens": "okurerbarhet",
    "okurerbarhets": "okurerbarhet",
    "okurerbars": "okurerbar",
    "okurerbart": "okurerbar",
    "okurerbarts": "okurerbar",
    "okursade": "okursad",
    "okursades": "okursad",
    "okursads": "okursad",
    "okursat": "okursad",
    "okursats": "okursad",
    "okursiverade": "okursiverad",
    "okursiverades": "okursiverad",
    "okursiverads": "okursiverad",
    "okursiverat": "okursiverad",
    "okursiverats": "okursiverad",
    "okursiverbara": "okursiverbar",
    "okursiverbarare": "okursiverbar",
    "okursiverbarares": "okursiverbar",
    "okursiverbaras": "okursiverbar",
    "okursiverbarast": "okursiverbar",
    "okursiverbaraste": "okursiverbar",
    "okursiverbarastes": "okursiverbar",
    "okursiverbarasts": "okursiverbar",
    "okursiverbare": "okursiverbar",
    "okursiverbares": "okursiverbar",
    "okursiverbarheten": "okursiverbarhet",
    "okursiverbarhetens": "okursiverbarhet",
    "okursiverbarhets": "okursiverbarhet",
    "okursiverbars": "okursiverbar",
    "okursiverbart": "okursiverbar",
    "okursiverbarts": "okursiverbar",
    "okurtiserade": "okurtiserad",
    "okurtiserades": "okurtiserad",
    "okurtiserads": "okurtiserad",
    "okurtiserat": "okurtiserad",
    "okurtiserats": "okurtiserad",
    "okurtiserbara": "okurtiserbar",
    "okurtiserbarare": "okurtiserbar",
    "okurtiserbarares": "okurtiserbar",
    "okurtiserbaras": "okurtiserbar",
    "okurtiserbarast": "okurtiserbar",
    "okurtiserbaraste": "okurtiserbar",
    "okurtiserbarastes": "okurtiserbar",
    "okurtiserbarasts": "okurtiserbar",
    "okurtiserbare": "okurtiserbar",
    "okurtiserbares": "okurtiserbar",
    "okurtiserbarheten": "okurtiserbarhet",
    "okurtiserbarhetens": "okurtiserbarhet",
    "okurtiserbarhets": "okurtiserbarhet",
    "okurtiserbars": "okurtiserbar",
    "okurtiserbart": "okurtiserbar",
    "okurtiserbarts": "okurtiserbar",
    "okuschade": "okuschad",
    "okuschades": "okuschad",
    "okuschads": "okuschad",
    "okuschat": "okuschad",
    "okuschats": "okuschad",
    "okuvade": "okuvad",
    "okuvades": "okuvad",
    "okuvads": "okuvad",
    "okuvat": "okuvad",
    "okuvats": "okuvad",
    "okuverterade": "okuverterad",
    "okuverterades": "okuverterad",
    "okuverterads": "okuverterad",
    "okuverterat": "okuverterad",
    "okuverterats": "okuverterad",
    "okuverterbara": "okuverterbar",
    "okuverterbarare": "okuverterbar",
    "okuverterbarares": "okuverterbar",
    "okuverterbaras": "okuverterbar",
    "okuverterbarast": "okuverterbar",
    "okuverterbaraste": "okuverterbar",
    "okuverterbarastes": "okuverterbar",
    "okuverterbarasts": "okuverterbar",
    "okuverterbare": "okuverterbar",
    "okuverterbares": "okuverterbar",
    "okuverterbarheten": "okuverterbarhet",
    "okuverterbarhetens": "okuverterbarhet",
    "okuverterbarhets": "okuverterbarhet",
    "okuverterbars": "okuverterbar",
    "okuverterbart": "okuverterbar",
    "okuverterbarts": "okuverterbar",
    "okuvliga": "okuvlig",
    "okuvligare": "okuvlig",
    "okuvligares": "okuvlig",
    "okuvligas": "okuvlig",
    "okuvligast": "okuvlig",
    "okuvligaste": "okuvlig",
    "okuvligastes": "okuvlig",
    "okuvligasts": "okuvlig",
    "okuvlige": "okuvlig",
    "okuvliges": "okuvlig",
    "okuvligheten": "okuvlighet",
    "okuvlighetens": "okuvlighet",
    "okuvlighets": "okuvlighet",
    "okuvligs": "okuvlig",
    "okuvligt": "okuvlig",
    "okuvligts": "okuvlig",
    "okvaddade": "okvaddad",
    "okvaddades": "okvaddad",
    "okvaddads": "okvaddad",
    "okvaddat": "okvaddad",
    "okvaddats": "okvaddad",
    "okvadrerade": "okvadrerad",
    "okvadrerades": "okvadrerad",
    "okvadrerads": "okvadrerad",
    "okvadrerat": "okvadrerad",
    "okvadrerats": "okvadrerad",
    "okvadrerbara": "okvadrerbar",
    "okvadrerbarare": "okvadrerbar",
    "okvadrerbarares": "okvadrerbar",
    "okvadrerbaras": "okvadrerbar",
    "okvadrerbarast": "okvadrerbar",
    "okvadrerbaraste": "okvadrerbar",
    "okvadrerbarastes": "okvadrerbar",
    "okvadrerbarasts": "okvadrerbar",
    "okvadrerbare": "okvadrerbar",
    "okvadrerbares": "okvadrerbar",
    "okvadrerbarheten": "okvadrerbarhet",
    "okvadrerbarhetens": "okvadrerbarhet",
    "okvadrerbarhets": "okvadrerbarhet",
    "okvadrerbars": "okvadrerbar",
    "okvadrerbart": "okvadrerbar",
    "okvadrerbarts": "okvadrerbar",
    "okvalda": "okvald",
    "okvaldare": "okvald",
    "okvaldares": "okvald",
    "okvaldas": "okvald",
    "okvaldast": "okvald",
    "okvaldaste": "okvald",
    "okvaldastes": "okvald",
    "okvaldasts": "okvald",
    "okvalde": "okvald",
    "okvaldes": "okvald",
    "okvalds": "okvald",
    "okvalificerade": "okvalificerad",
    "okvalificerades": "okvalificerad",
    "okvalificerads": "okvalificerad",
    "okvalificerat": "okvalificerad",
    "okvalificerats": "okvalificerad",
    "okvalificerbara": "okvalificerbar",
    "okvalificerbarare": "okvalificerbar",
    "okvalificerbarares": "okvalificerbar",
    "okvalificerbaras": "okvalificerbar",
    "okvalificerbarast": "okvalificerbar",
    "okvalificerbaraste": "okvalificerbar",
    "okvalificerbarastes": "okvalificerbar",
    "okvalificerbarasts": "okvalificerbar",
    "okvalificerbare": "okvalificerbar",
    "okvalificerbares": "okvalificerbar",
    "okvalificerbarheten": "okvalificerbarhet",
    "okvalificerbarhetens": "okvalificerbarhet",
    "okvalificerbarhets": "okvalificerbarhet",
    "okvalificerbars": "okvalificerbar",
    "okvalificerbart": "okvalificerbar",
    "okvalificerbarts": "okvalificerbar",
    "okvalt": "okvald",
    "okvalts": "okvald",
    "okvantifierade": "okvantifierad",
    "okvantifierades": "okvantifierad",
    "okvantifierads": "okvantifierad",
    "okvantifierat": "okvantifierad",
    "okvantifierats": "okvantifierad",
    "okvantifierbara": "okvantifierbar",
    "okvantifierbarare": "okvantifierbar",
    "okvantifierbarares": "okvantifierbar",
    "okvantifierbaras": "okvantifierbar",
    "okvantifierbarast": "okvantifierbar",
    "okvantifierbaraste": "okvantifierbar",
    "okvantifierbarastes": "okvantifierbar",
    "okvantifierbarasts": "okvantifierbar",
    "okvantifierbare": "okvantifierbar",
    "okvantifierbares": "okvantifierbar",
    "okvantifierbarheten": "okvantifierbarhet",
    "okvantifierbarhetens": "okvantifierbarhet",
    "okvantifierbarhets": "okvantifierbarhet",
    "okvantifierbars": "okvantifierbar",
    "okvantifierbart": "okvantifierbar",
    "okvantifierbarts": "okvantifierbar",
    "okvardröjde": "okvardröjd",
    "okvardröjdes": "okvardröjd",
    "okvardröjds": "okvardröjd",
    "okvardröjt": "okvardröjd",
    "okvardröjts": "okvardröjd",
    "okvarlämnade": "okvarlämnad",
    "okvarlämnades": "okvarlämnad",
    "okvarlämnads": "okvarlämnad",
    "okvarlämnat": "okvarlämnad",
    "okvarlämnats": "okvarlämnad",
    "okvarstannade": "okvarstannad",
    "okvarstannades": "okvarstannad",
    "okvarstannads": "okvarstannad",
    "okvarstannat": "okvarstannad",
    "okvarstannats": "okvarstannad",
    "okviltade": "okviltad",
    "okviltades": "okviltad",
    "okviltads": "okviltad",
    "okviltat": "okviltad",
    "okviltats": "okviltad",
    "okvinnliga": "okvinnlig",
    "okvinnligare": "okvinnlig",
    "okvinnligares": "okvinnlig",
    "okvinnligas": "okvinnlig",
    "okvinnligast": "okvinnlig",
    "okvinnligaste": "okvinnlig",
    "okvinnligastes": "okvinnlig",
    "okvinnligasts": "okvinnlig",
    "okvinnlige": "okvinnlig",
    "okvinnliges": "okvinnlig",
    "okvinnligheten": "okvinnlighet",
    "okvinnlighetens": "okvinnlighet",
    "okvinnlighets": "okvinnlighet",
    "okvinnligs": "okvinnlig",
    "okvinnligt": "okvinnlig",
    "okvinnligts": "okvinnlig",
    "okvistade": "okvistad",
    "okvistades": "okvistad",
    "okvistads": "okvistad",
    "okvistat": "okvistad",
    "okvistats": "okvistad",
    "okvittade": "okvittad",
    "okvittades": "okvittad",
    "okvittads": "okvittad",
    "okvittat": "okvittad",
    "okvittats": "okvittad",
    "okvitterade": "okvitterad",
    "okvitterades": "okvitterad",
    "okvitterads": "okvitterad",
    "okvitterat": "okvitterad",
    "okvitterats": "okvitterad",
    "okvitterbara": "okvitterbar",
    "okvitterbarare": "okvitterbar",
    "okvitterbarares": "okvitterbar",
    "okvitterbaras": "okvitterbar",
    "okvitterbarast": "okvitterbar",
    "okvitterbaraste": "okvitterbar",
    "okvitterbarastes": "okvitterbar",
    "okvitterbarasts": "okvitterbar",
    "okvitterbare": "okvitterbar",
    "okvitterbares": "okvitterbar",
    "okvitterbarheten": "okvitterbarhet",
    "okvitterbarhetens": "okvitterbarhet",
    "okvitterbarhets": "okvitterbarhet",
    "okvitterbars": "okvitterbar",
    "okvitterbart": "okvitterbar",
    "okvitterbarts": "okvitterbar",
    "okvoterade": "okvoterad",
    "okvoterades": "okvoterad",
    "okvoterads": "okvoterad",
    "okvoterat": "okvoterad",
    "okvoterats": "okvoterad",
    "okvoterbara": "okvoterbar",
    "okvoterbarare": "okvoterbar",
    "okvoterbarares": "okvoterbar",
    "okvoterbaras": "okvoterbar",
    "okvoterbarast": "okvoterbar",
    "okvoterbaraste": "okvoterbar",
    "okvoterbarastes": "okvoterbar",
    "okvoterbarasts": "okvoterbar",
    "okvoterbare": "okvoterbar",
    "okvoterbares": "okvoterbar",
    "okvoterbarheten": "okvoterbarhet",
    "okvoterbarhetens": "okvoterbarhet",
    "okvoterbarhets": "okvoterbarhet",
    "okvoterbars": "okvoterbar",
    "okvoterbart": "okvoterbar",
    "okvoterbarts": "okvoterbar",
    "okväd": "okväda",
    "okvädad": "okväda",
    "okvädade": "okväda",
    "okvädades": "okväda",
    "okvädads": "okväda",
    "okvädande": "okväda",
    "okvädanden": "okvädande",
    "okvädandena": "okvädande",
    "okvädandenas": "okvädande",
    "okvädandens": "okvädande",
    "okvädandes": "okvädande",
    "okvädandet": "okvädande",
    "okvädandets": "okvädande",
    "okvädar": "okväda",
    "okvädas": "okväda",
    "okvädat": "okväda",
    "okvädats": "okväda",
    "okväden": "okväde",
    "okvädena": "okväde",
    "okvädenas": "okväde",
    "okvädens": "okväden",
    "okvädes": "okväde",
    "okvädet": "okväden",
    "okvädets": "okväden",
    "okvädingsorden": "okvädingsord",
    "okvädingsordens": "okvädingsord",
    "okvädingsordet": "okvädingsord",
    "okvädingsordets": "okvädingsord",
    "okvädingsords": "okvädingsord",
    "okvädinsorden": "okvädinsord",
    "okvädinsordens": "okvädinsord",
    "okvädinsordet": "okvädinsord",
    "okvädinsordets": "okvädinsord",
    "okvädinsords": "okvädinsord",
    "okvädna": "okväden",
    "okvädnare": "okväden",
    "okvädnares": "okväden",
    "okvädnas": "okväden",
    "okvädnast": "okväden",
    "okvädnaste": "okväden",
    "okvädnastes": "okväden",
    "okvädnasts": "okväden",
    "okvädne": "okväden",
    "okvädnes": "okväden",
    "okvästa": "okväst",
    "okvästas": "okväst",
    "okväste": "okväst",
    "okvästes": "okväst",
    "okvästs": "okväst",
    "okvävde": "okvävd",
    "okvävdes": "okvävd",
    "okvävds": "okvävd",
    "okvävt": "okvävd",
    "okvävts": "okvävd",
    "okylde": "okyld",
    "okyldes": "okyld",
    "okylds": "okyld",
    "okylt": "okyld",
    "okylts": "okyld",
    "okynnes": "okynne",
    "okynnesfäet": "okynnesfä",
    "okynnesfäets": "okynnesfä",
    "okynnesfän": "okynnesfä",
    "okynnesfäna": "okynnesfä",
    "okynnesfänas": "okynnesfä",
    "okynnesfäns": "okynnesfä",
    "okynnesfäs": "okynnesfä",
    "okynnesfät": "okynnesfä",
    "okynnesfäts": "okynnesfä",
    "okynneshundar": "okynneshund",
    "okynneshundarna": "okynneshund",
    "okynneshundarnas": "okynneshund",
    "okynneshundars": "okynneshund",
    "okynneshunden": "okynneshund",
    "okynneshundens": "okynneshund",
    "okynneshunds": "okynneshund",
    "okynnesjakten": "okynnesjakt",
    "okynnesjaktens": "okynnesjakt",
    "okynnesjakter": "okynnesjakt",
    "okynnesjakterna": "okynnesjakt",
    "okynnesjakternas": "okynnesjakt",
    "okynnesjakters": "okynnesjakt",
    "okynnesjakts": "okynnesjakt",
    "okynnet": "okynne",
    "okynnets": "okynne",
    "okynniga": "okynnig",
    "okynnigare": "okynnig",
    "okynnigares": "okynnig",
    "okynnigas": "okynnig",
    "okynnigast": "okynnig",
    "okynnigaste": "okynnig",
    "okynnigastes": "okynnig",
    "okynnigasts": "okynnig",
    "okynnige": "okynnig",
    "okynniges": "okynnig",
    "okynnigheten": "okynnighet",
    "okynnighetens": "okynnighet",
    "okynnighets": "okynnighet",
    "okynnigs": "okynnig",
    "okynnigt": "okynnig",
    "okynnigts": "okynnig",
    "okyprade": "okyprad",
    "okyprades": "okyprad",
    "okyprads": "okyprad",
    "okyprat": "okyprad",
    "okyprats": "okyprad",
    "okyrkliga": "okyrklig",
    "okyrkligare": "okyrklig",
    "okyrkligares": "okyrklig",
    "okyrkligas": "okyrklig",
    "okyrkligast": "okyrklig",
    "okyrkligaste": "okyrklig",
    "okyrkligastes": "okyrklig",
    "okyrkligasts": "okyrklig",
    "okyrklige": "okyrklig",
    "okyrkliges": "okyrklig",
    "okyrkligheten": "okyrklighet",
    "okyrklighetens": "okyrklighet",
    "okyrklighets": "okyrklighet",
    "okyrkligs": "okyrklig",
    "okyrkligt": "okyrklig",
    "okyrkligts": "okyrklig",
    "okyska": "okysk",
    "okyskare": "okysk",
    "okyskares": "okysk",
    "okyskas": "okysk",
    "okyskast": "okysk",
    "okyskaste": "okysk",
    "okyskastes": "okysk",
    "okyskasts": "okysk",
    "okyske": "okysk",
    "okyskes": "okysk",
    "okysks": "okysk",
    "okyskt": "okysk",
    "okyskts": "okysk",
    "okyssta": "okysst",
    "okysstare": "okysst",
    "okysstares": "okysst",
    "okysstas": "okysst",
    "okysstast": "okysst",
    "okysstaste": "okysst",
    "okysstastes": "okysst",
    "okysstasts": "okysst",
    "okysste": "okysst",
    "okysstes": "okysst",
    "okyssts": "okysst",
    "okäkade": "okäkad",
    "okäkades": "okäkad",
    "okäkads": "okäkad",
    "okäkat": "okäkad",
    "okäkats": "okäkad",
    "okälade": "okälad",
    "okälades": "okälad",
    "okälads": "okälad",
    "okälat": "okälad",
    "okälats": "okälad",
    "okända": "okänd",
    "okändare": "okänd",
    "okändares": "okänd",
    "okändas": "okänd",
    "okändast": "okänd",
    "okändaste": "okänd",
    "okändastes": "okänd",
    "okändasts": "okänd",
    "okände": "okänd",
    "okändes": "okänd",
    "okändheten": "okändhet",
    "okändhetens": "okändhet",
    "okändhets": "okändhet",
    "okänds": "okänd",
    "okänsliga": "okänslig",
    "okänsligare": "okänslig",
    "okänsligares": "okänslig",
    "okänsligas": "okänslig",
    "okänsligast": "okänslig",
    "okänsligaste": "okänslig",
    "okänsligastes": "okänslig",
    "okänsligasts": "okänslig",
    "okänslige": "okänslig",
    "okänsliges": "okänslig",
    "okänsligheten": "okänslighet",
    "okänslighetens": "okänslighet",
    "okänsligheter": "okänslighet",
    "okänsligheterna": "okänslighet",
    "okänsligheternas": "okänslighet",
    "okänsligheters": "okänslighet",
    "okänslighets": "okänslighet",
    "okänsligs": "okänslig",
    "okänsligt": "okänslig",
    "okänsligts": "okänslig",
    "okänt": "okänd",
    "okänts": "okänd",
    "okära": "okär",
    "okärade": "okärad",
    "okärades": "okärad",
    "okärads": "okärad",
    "okärare": "okär",
    "okärares": "okär",
    "okäras": "okär",
    "okärast": "okär",
    "okäraste": "okär",
    "okärastes": "okär",
    "okärasts": "okär",
    "okärat": "okärad",
    "okärats": "okärad",
    "okäre": "okär",
    "okäres": "okär",
    "okärnade": "okärnad",
    "okärnades": "okärnad",
    "okärnads": "okärnad",
    "okärnat": "okärnad",
    "okärnats": "okärnad",
    "okärs": "okär",
    "okärt": "okär",
    "okärts": "okär",
    "okånkade": "okånkad",
    "okånkades": "okånkad",
    "okånkads": "okånkad",
    "okånkat": "okånkad",
    "okånkats": "okånkad",
    "okårade": "okårad",
    "okårades": "okårad",
    "okårads": "okårad",
    "okårat": "okårad",
    "okårats": "okårad",
    "okönade": "okönad",
    "okönades": "okönad",
    "okönads": "okönad",
    "okönat": "okönad",
    "okönats": "okönad",
    "oköpta": "oköpt",
    "oköptas": "oköpt",
    "oköpte": "oköpt",
    "oköptes": "oköpt",
    "oköpts": "oköpt",
    "okörde": "okörd",
    "okördes": "okörd",
    "okörds": "okörd",
    "okörnade": "okörnad",
    "okörnades": "okörnad",
    "okörnads": "okörnad",
    "okörnat": "okörnad",
    "okörnats": "okörnad",
    "okört": "okörd",
    "okörts": "okörd",
    "okövde": "okövd",
    "okövdes": "okövd",
    "okövds": "okövd",
    "okövt": "okövd",
    "okövts": "okövd",
    "ol": "ola",
    "olabialiserade": "olabialiserad",
    "olabialiserades": "olabialiserad",
    "olabialiserads": "olabialiserad",
    "olabialiserat": "olabialiserad",
    "olabialiserats": "olabialiserad",
    "olabialiserbara": "olabialiserbar",
    "olabialiserbarare": "olabialiserbar",
    "olabialiserbarares": "olabialiserbar",
    "olabialiserbaras": "olabialiserbar",
    "olabialiserbarast": "olabialiserbar",
    "olabialiserbaraste": "olabialiserbar",
    "olabialiserbarastes": "olabialiserbar",
    "olabialiserbarasts": "olabialiserbar",
    "olabialiserbare": "olabialiserbar",
    "olabialiserbares": "olabialiserbar",
    "olabialiserbarheten": "olabialiserbarhet",
    "olabialiserbarhetens": "olabialiserbarhet",
    "olabialiserbarhets": "olabialiserbarhet",
    "olabialiserbars": "olabialiserbar",
    "olabialiserbart": "olabialiserbar",
    "olabialiserbarts": "olabialiserbar",
    "olackade": "olackad",
    "olackades": "olackad",
    "olackads": "olackad",
    "olackat": "olackad",
    "olackats": "olackad",
    "olackerade": "olackerad",
    "olackerades": "olackerad",
    "olackerads": "olackerad",
    "olackerat": "olackerad",
    "olackerats": "olackerad",
    "olackerbara": "olackerbar",
    "olackerbarare": "olackerbar",
    "olackerbarares": "olackerbar",
    "olackerbaras": "olackerbar",
    "olackerbarast": "olackerbar",
    "olackerbaraste": "olackerbar",
    "olackerbarastes": "olackerbar",
    "olackerbarasts": "olackerbar",
    "olackerbare": "olackerbar",
    "olackerbares": "olackerbar",
    "olackerbarheten": "olackerbarhet",
    "olackerbarhetens": "olackerbarhet",
    "olackerbarhets": "olackerbarhet",
    "olackerbars": "olackerbar",
    "olackerbart": "olackerbar",
    "olackerbarts": "olackerbar",
    "olad": "ola",
    "oladdade": "oladdad",
    "oladdades": "oladdad",
    "oladdads": "oladdad",
    "oladdat": "oladdad",
    "oladdats": "oladdad",
    "olade": "ola",
    "olades": "ola",
    "olads": "ola",
    "olagade": "olagad",
    "olagades": "olagad",
    "olagads": "olagad",
    "olagat": "olagad",
    "olagats": "olagad",
    "olaggade": "olaggad",
    "olaggades": "olaggad",
    "olaggads": "olaggad",
    "olaggat": "olaggad",
    "olaggats": "olaggad",
    "olagliga": "olaglig",
    "olagligare": "olaglig",
    "olagligares": "olaglig",
    "olagligas": "olaglig",
    "olagligast": "olaglig",
    "olagligaste": "olaglig",
    "olagligastes": "olaglig",
    "olagligasts": "olaglig",
    "olaglige": "olaglig",
    "olagliges": "olaglig",
    "olagligförklarad": "olagligförklara",
    "olagligförklarade": "olagligförklara",
    "olagligförklarades": "olagligförklara",
    "olagligförklarads": "olagligförklara",
    "olagligförklarande": "olagligförklara",
    "olagligförklarandes": "olagligförklara",
    "olagligförklarar": "olagligförklara",
    "olagligförklaras": "olagligförklara",
    "olagligförklarat": "olagligförklara",
    "olagligförklarats": "olagligförklara",
    "olagligheten": "olaglighet",
    "olaglighetens": "olaglighet",
    "olagligheter": "olaglighet",
    "olagligheterna": "olaglighet",
    "olagligheternas": "olaglighet",
    "olagligheters": "olaglighet",
    "olaglighets": "olaglighet",
    "olagligs": "olaglig",
    "olagligt": "olaglig",
    "olagligts": "olaglig",
    "olagrade": "olagrad",
    "olagrades": "olagrad",
    "olagrads": "olagrad",
    "olagrat": "olagrad",
    "olagrats": "olagrad",
    "olamenterade": "olamenterad",
    "olamenterades": "olamenterad",
    "olamenterads": "olamenterad",
    "olamenterat": "olamenterad",
    "olamenterats": "olamenterad",
    "olamenterbara": "olamenterbar",
    "olamenterbarare": "olamenterbar",
    "olamenterbarares": "olamenterbar",
    "olamenterbaras": "olamenterbar",
    "olamenterbarast": "olamenterbar",
    "olamenterbaraste": "olamenterbar",
    "olamenterbarastes": "olamenterbar",
    "olamenterbarasts": "olamenterbar",
    "olamenterbare": "olamenterbar",
    "olamenterbares": "olamenterbar",
    "olamenterbarheten": "olamenterbarhet",
    "olamenterbarhetens": "olamenterbarhet",
    "olamenterbarhets": "olamenterbarhet",
    "olamenterbars": "olamenterbar",
    "olamenterbart": "olamenterbar",
    "olamenterbarts": "olamenterbar",
    "olaminerade": "olaminerad",
    "olaminerades": "olaminerad",
    "olaminerads": "olaminerad",
    "olaminerat": "olaminerad",
    "olaminerats": "olaminerad",
    "olaminerbara": "olaminerbar",
    "olaminerbarare": "olaminerbar",
    "olaminerbarares": "olaminerbar",
    "olaminerbaras": "olaminerbar",
    "olaminerbarast": "olaminerbar",
    "olaminerbaraste": "olaminerbar",
    "olaminerbarastes": "olaminerbar",
    "olaminerbarasts": "olaminerbar",
    "olaminerbare": "olaminerbar",
    "olaminerbares": "olaminerbar",
    "olaminerbarheten": "olaminerbarhet",
    "olaminerbarhetens": "olaminerbarhet",
    "olaminerbarhets": "olaminerbarhet",
    "olaminerbars": "olaminerbar",
    "olaminerbart": "olaminerbar",
    "olaminerbarts": "olaminerbar",
    "olandade": "olandad",
    "olandades": "olandad",
    "olandads": "olandad",
    "olandat": "olandad",
    "olandats": "olandad",
    "olande": "ola",
    "olanden": "olande",
    "olandena": "olande",
    "olandenas": "olande",
    "olandens": "olande",
    "olandes": "olande",
    "olandet": "olande",
    "olandets": "olande",
    "olangade": "olangad",
    "olangades": "olangad",
    "olangads": "olangad",
    "olangat": "olangad",
    "olangats": "olangad",
    "olangetterade": "olangetterad",
    "olangetterades": "olangetterad",
    "olangetterads": "olangetterad",
    "olangetterat": "olangetterad",
    "olangetterats": "olangetterad",
    "olangetterbara": "olangetterbar",
    "olangetterbarare": "olangetterbar",
    "olangetterbarares": "olangetterbar",
    "olangetterbaras": "olangetterbar",
    "olangetterbarast": "olangetterbar",
    "olangetterbaraste": "olangetterbar",
    "olangetterbarastes": "olangetterbar",
    "olangetterbarasts": "olangetterbar",
    "olangetterbare": "olangetterbar",
    "olangetterbares": "olangetterbar",
    "olangetterbarheten": "olangetterbarhet",
    "olangetterbarhetens": "olangetterbarhet",
    "olangetterbarhets": "olangetterbarhet",
    "olangetterbars": "olangetterbar",
    "olangetterbart": "olangetterbar",
    "olangetterbarts": "olangetterbar",
    "olanserade": "olanserad",
    "olanserades": "olanserad",
    "olanserads": "olanserad",
    "olanserat": "olanserad",
    "olanserats": "olanserad",
    "olanserbara": "olanserbar",
    "olanserbarare": "olanserbar",
    "olanserbarares": "olanserbar",
    "olanserbaras": "olanserbar",
    "olanserbarast": "olanserbar",
    "olanserbaraste": "olanserbar",
    "olanserbarastes": "olanserbar",
    "olanserbarasts": "olanserbar",
    "olanserbare": "olanserbar",
    "olanserbares": "olanserbar",
    "olanserbarheten": "olanserbarhet",
    "olanserbarhetens": "olanserbarhet",
    "olanserbarhets": "olanserbarhet",
    "olanserbars": "olanserbar",
    "olanserbart": "olanserbar",
    "olanserbarts": "olanserbar",
    "olapade": "olapad",
    "olapades": "olapad",
    "olapads": "olapad",
    "olapat": "olapad",
    "olapats": "olapad",
    "olapiserade": "olapiserad",
    "olapiserades": "olapiserad",
    "olapiserads": "olapiserad",
    "olapiserat": "olapiserad",
    "olapiserats": "olapiserad",
    "olapiserbara": "olapiserbar",
    "olapiserbarare": "olapiserbar",
    "olapiserbarares": "olapiserbar",
    "olapiserbaras": "olapiserbar",
    "olapiserbarast": "olapiserbar",
    "olapiserbaraste": "olapiserbar",
    "olapiserbarastes": "olapiserbar",
    "olapiserbarasts": "olapiserbar",
    "olapiserbare": "olapiserbar",
    "olapiserbares": "olapiserbar",
    "olapiserbarheten": "olapiserbarhet",
    "olapiserbarhetens": "olapiserbarhet",
    "olapiserbarhets": "olapiserbarhet",
    "olapiserbars": "olapiserbar",
    "olapiserbart": "olapiserbar",
    "olapiserbarts": "olapiserbar",
    "olappade": "olappad",
    "olappades": "olappad",
    "olappads": "olappad",
    "olappat": "olappad",
    "olappats": "olappad",
    "olar": "ola",
    "olarmade": "olarmad",
    "olarmades": "olarmad",
    "olarmads": "olarmad",
    "olarmat": "olarmad",
    "olarmats": "olarmad",
    "olas": "ola",
    "olaserade": "olaserad",
    "olaserades": "olaserad",
    "olaserads": "olaserad",
    "olaserat": "olaserad",
    "olaserats": "olaserad",
    "olaserbara": "olaserbar",
    "olaserbarare": "olaserbar",
    "olaserbarares": "olaserbar",
    "olaserbaras": "olaserbar",
    "olaserbarast": "olaserbar",
    "olaserbaraste": "olaserbar",
    "olaserbarastes": "olaserbar",
    "olaserbarasts": "olaserbar",
    "olaserbare": "olaserbar",
    "olaserbares": "olaserbar",
    "olaserbarheten": "olaserbarhet",
    "olaserbarhetens": "olaserbarhet",
    "olaserbarhets": "olaserbarhet",
    "olaserbars": "olaserbar",
    "olaserbart": "olaserbar",
    "olaserbarts": "olaserbar",
    "olaskade": "olaskad",
    "olaskades": "olaskad",
    "olaskads": "olaskad",
    "olaskat": "olaskad",
    "olaskats": "olaskad",
    "olastade": "olastad",
    "olastades": "olastad",
    "olastads": "olastad",
    "olastat": "olastad",
    "olastats": "olastad",
    "olat": "ola",
    "olaten": "olat",
    "olatens": "olat",
    "olater": "olat",
    "olaterna": "olat",
    "olaternas": "olat",
    "olaters": "olat",
    "olatiniserade": "olatiniserad",
    "olatiniserades": "olatiniserad",
    "olatiniserads": "olatiniserad",
    "olatiniserat": "olatiniserad",
    "olatiniserats": "olatiniserad",
    "olatiniserbara": "olatiniserbar",
    "olatiniserbarare": "olatiniserbar",
    "olatiniserbarares": "olatiniserbar",
    "olatiniserbaras": "olatiniserbar",
    "olatiniserbarast": "olatiniserbar",
    "olatiniserbaraste": "olatiniserbar",
    "olatiniserbarastes": "olatiniserbar",
    "olatiniserbarasts": "olatiniserbar",
    "olatiniserbare": "olatiniserbar",
    "olatiniserbares": "olatiniserbar",
    "olatiniserbarheten": "olatiniserbarhet",
    "olatiniserbarhetens": "olatiniserbarhet",
    "olatiniserbarhets": "olatiniserbarhet",
    "olatiniserbars": "olatiniserbar",
    "olatiniserbart": "olatiniserbar",
    "olatiniserbarts": "olatiniserbar",
    "olats": "olat",
    "olaverade": "olaverad",
    "olaverades": "olaverad",
    "olaverads": "olaverad",
    "olaverat": "olaverad",
    "olaverats": "olaverad",
    "olaverbara": "olaverbar",
    "olaverbarare": "olaverbar",
    "olaverbarares": "olaverbar",
    "olaverbaras": "olaverbar",
    "olaverbarast": "olaverbar",
    "olaverbaraste": "olaverbar",
    "olaverbarastes": "olaverbar",
    "olaverbarasts": "olaverbar",
    "olaverbare": "olaverbar",
    "olaverbares": "olaverbar",
    "olaverbarheten": "olaverbarhet",
    "olaverbarhetens": "olaverbarhet",
    "olaverbarhets": "olaverbarhet",
    "olaverbars": "olaverbar",
    "olaverbart": "olaverbar",
    "olaverbarts": "olaverbar",
    "olaxade": "olaxad",
    "olaxades": "olaxad",
    "olaxads": "olaxad",
    "olaxat": "olaxad",
    "olaxats": "olaxad",
    "oldboyar": "oldboy",
    "oldboyarna": "oldboy",
    "oldboyarnas": "oldboy",
    "oldboyars": "oldboy",
    "oldboyen": "oldboy",
    "oldboyens": "oldboy",
    "oldboys": "oldboy",
    "oldboysarna": "oldboy",
    "oldboysarnas": "oldboy",
    "oldboysen": "oldboy",
    "oldboysens": "oldboy",
    "oldtimern": "oldtimer",
    "oldtimerns": "oldtimer",
    "oldtimers": "oldtimer",
    "oldtimersarna": "oldtimer",
    "oldtimersarnas": "oldtimer",
    "oldtimersen": "oldtimer",
    "oldtimersens": "oldtimer",
    "oleandern": "oleander",
    "oleanderns": "oleander",
    "oleanders": "oleander",
    "oleandrar": "oleander",
    "oleandrarna": "oleander",
    "oleandrarnas": "oleander",
    "oleandrars": "oleander",
    "oleasade": "oleasad",
    "oleasades": "oleasad",
    "oleasads": "oleasad",
    "oleasat": "oleasad",
    "oleasats": "oleasad",
    "oleaten": "oleat",
    "oleatens": "oleat",
    "oleater": "oleat",
    "oleaterna": "oleat",
    "oleaternas": "oleat",
    "oleaters": "oleat",
    "oleatet": "oleat",
    "oleatets": "oleat",
    "oleats": "oleat",
    "oledade": "oledad",
    "oledades": "oledad",
    "oledads": "oledad",
    "oledar": "oledare",
    "oledaren": "oledare",
    "oledarens": "oledare",
    "oledares": "oledare",
    "oledarna": "oledare",
    "oledarnas": "oledare",
    "oledat": "oledad",
    "oledats": "oledad",
    "oledsagade": "oledsagad",
    "oledsagades": "oledsagad",
    "oledsagads": "oledsagad",
    "oledsagat": "oledsagad",
    "oledsagats": "oledsagad",
    "olefinen": "olefin",
    "olefinens": "olefin",
    "olefiner": "olefin",
    "olefinerna": "olefin",
    "olefinernas": "olefin",
    "olefiners": "olefin",
    "olefinet": "olefin",
    "olefinets": "olefin",
    "olefins": "olefin",
    "olegaliserade": "olegaliserad",
    "olegaliserades": "olegaliserad",
    "olegaliserads": "olegaliserad",
    "olegaliserat": "olegaliserad",
    "olegaliserats": "olegaliserad",
    "olegaliserbara": "olegaliserbar",
    "olegaliserbarare": "olegaliserbar",
    "olegaliserbarares": "olegaliserbar",
    "olegaliserbaras": "olegaliserbar",
    "olegaliserbarast": "olegaliserbar",
    "olegaliserbaraste": "olegaliserbar",
    "olegaliserbarastes": "olegaliserbar",
    "olegaliserbarasts": "olegaliserbar",
    "olegaliserbare": "olegaliserbar",
    "olegaliserbares": "olegaliserbar",
    "olegaliserbarheten": "olegaliserbarhet",
    "olegaliserbarhetens": "olegaliserbarhet",
    "olegaliserbarhets": "olegaliserbarhet",
    "olegaliserbars": "olegaliserbar",
    "olegaliserbart": "olegaliserbar",
    "olegaliserbarts": "olegaliserbar",
    "olegerade": "olegerad",
    "olegerades": "olegerad",
    "olegerads": "olegerad",
    "olegerat": "olegerad",
    "olegerats": "olegerad",
    "olegerbara": "olegerbar",
    "olegerbarare": "olegerbar",
    "olegerbarares": "olegerbar",
    "olegerbaras": "olegerbar",
    "olegerbarast": "olegerbar",
    "olegerbaraste": "olegerbar",
    "olegerbarastes": "olegerbar",
    "olegerbarasts": "olegerbar",
    "olegerbare": "olegerbar",
    "olegerbares": "olegerbar",
    "olegerbarheten": "olegerbarhet",
    "olegerbarhetens": "olegerbarhet",
    "olegerbarhets": "olegerbarhet",
    "olegerbars": "olegerbar",
    "olegerbart": "olegerbar",
    "olegerbarts": "olegerbar",
    "olegitimerade": "olegitimerad",
    "olegitimerades": "olegitimerad",
    "olegitimerads": "olegitimerad",
    "olegitimerat": "olegitimerad",
    "olegitimerats": "olegitimerad",
    "olegitimerbara": "olegitimerbar",
    "olegitimerbarare": "olegitimerbar",
    "olegitimerbarares": "olegitimerbar",
    "olegitimerbaras": "olegitimerbar",
    "olegitimerbarast": "olegitimerbar",
    "olegitimerbaraste": "olegitimerbar",
    "olegitimerbarastes": "olegitimerbar",
    "olegitimerbarasts": "olegitimerbar",
    "olegitimerbare": "olegitimerbar",
    "olegitimerbares": "olegitimerbar",
    "olegitimerbarheten": "olegitimerbarhet",
    "olegitimerbarhetens": "olegitimerbarhet",
    "olegitimerbarhets": "olegitimerbarhet",
    "olegitimerbars": "olegitimerbar",
    "olegitimerbart": "olegitimerbar",
    "olegitimerbarts": "olegitimerbar",
    "oleinen": "olein",
    "oleinens": "olein",
    "oleinet": "olein",
    "oleinets": "olein",
    "oleins": "olein",
    "olejde": "olejd",
    "olejdes": "olejd",
    "olejdrade": "olejdrad",
    "olejdrades": "olejdrad",
    "olejdrads": "olejdrad",
    "olejdrat": "olejdrad",
    "olejdrats": "olejdrad",
    "olejds": "olejd",
    "olejt": "olejd",
    "olejts": "olejd",
    "olemlästade": "olemlästad",
    "olemlästades": "olemlästad",
    "olemlästads": "olemlästad",
    "olemlästat": "olemlästad",
    "olemlästats": "olemlästad",
    "olenade": "olenad",
    "olenades": "olenad",
    "olenads": "olenad",
    "olenat": "olenad",
    "olenats": "olenad",
    "oletade": "oletad",
    "oletades": "oletad",
    "oletads": "oletad",
    "oletat": "oletad",
    "oletats": "oletad",
    "olettrade": "olettrad",
    "olettrades": "olettrad",
    "olettrads": "olettrad",
    "olettrat": "olettrad",
    "olettrats": "olettrad",
    "olevererade": "olevererad",
    "olevererades": "olevererad",
    "olevererads": "olevererad",
    "olevererat": "olevererad",
    "olevererats": "olevererad",
    "olevererbara": "olevererbar",
    "olevererbarare": "olevererbar",
    "olevererbarares": "olevererbar",
    "olevererbaras": "olevererbar",
    "olevererbarast": "olevererbar",
    "olevererbaraste": "olevererbar",
    "olevererbarastes": "olevererbar",
    "olevererbarasts": "olevererbar",
    "olevererbare": "olevererbar",
    "olevererbares": "olevererbar",
    "olevererbarheten": "olevererbarhet",
    "olevererbarhetens": "olevererbarhet",
    "olevererbarhets": "olevererbarhet",
    "olevererbars": "olevererbar",
    "olevererbart": "olevererbar",
    "olevererbarts": "olevererbar",
    "oliberaliserade": "oliberaliserad",
    "oliberaliserades": "oliberaliserad",
    "oliberaliserads": "oliberaliserad",
    "oliberaliserat": "oliberaliserad",
    "oliberaliserats": "oliberaliserad",
    "oliberaliserbara": "oliberaliserbar",
    "oliberaliserbarare": "oliberaliserbar",
    "oliberaliserbarares": "oliberaliserbar",
    "oliberaliserbaras": "oliberaliserbar",
    "oliberaliserbarast": "oliberaliserbar",
    "oliberaliserbaraste": "oliberaliserbar",
    "oliberaliserbarastes": "oliberaliserbar",
    "oliberaliserbarasts": "oliberaliserbar",
    "oliberaliserbare": "oliberaliserbar",
    "oliberaliserbares": "oliberaliserbar",
    "oliberaliserbarheten": "oliberaliserbarhet",
    "oliberaliserbarhetens": "oliberaliserbarhet",
    "oliberaliserbarhets": "oliberaliserbarhet",
    "oliberaliserbars": "oliberaliserbar",
    "oliberaliserbart": "oliberaliserbar",
    "oliberaliserbarts": "oliberaliserbar",
    "olicenserade": "olicenserad",
    "olicenserades": "olicenserad",
    "olicenserads": "olicenserad",
    "olicenserat": "olicenserad",
    "olicenserats": "olicenserad",
    "olicenserbara": "olicenserbar",
    "olicenserbarare": "olicenserbar",
    "olicenserbarares": "olicenserbar",
    "olicenserbaras": "olicenserbar",
    "olicenserbarast": "olicenserbar",
    "olicenserbaraste": "olicenserbar",
    "olicenserbarastes": "olicenserbar",
    "olicenserbarasts": "olicenserbar",
    "olicenserbare": "olicenserbar",
    "olicenserbares": "olicenserbar",
    "olicenserbarheten": "olicenserbarhet",
    "olicenserbarhetens": "olicenserbarhet",
    "olicenserbarhets": "olicenserbarhet",
    "olicenserbars": "olicenserbar",
    "olicenserbart": "olicenserbar",
    "olicenserbarts": "olicenserbar",
    "olicensierade": "olicensierad",
    "olicensierades": "olicensierad",
    "olicensierads": "olicensierad",
    "olicensierat": "olicensierad",
    "olicensierats": "olicensierad",
    "olicensierbara": "olicensierbar",
    "olicensierbarare": "olicensierbar",
    "olicensierbarares": "olicensierbar",
    "olicensierbaras": "olicensierbar",
    "olicensierbarast": "olicensierbar",
    "olicensierbaraste": "olicensierbar",
    "olicensierbarastes": "olicensierbar",
    "olicensierbarasts": "olicensierbar",
    "olicensierbare": "olicensierbar",
    "olicensierbares": "olicensierbar",
    "olicensierbarheten": "olicensierbarhet",
    "olicensierbarhetens": "olicensierbarhet",
    "olicensierbarhets": "olicensierbarhet",
    "olicensierbars": "olicensierbar",
    "olicensierbart": "olicensierbar",
    "olicensierbarts": "olicensierbar",
    "olicentierade": "olicentierad",
    "olicentierades": "olicentierad",
    "olicentierads": "olicentierad",
    "olicentierat": "olicentierad",
    "olicentierats": "olicentierad",
    "olicentierbara": "olicentierbar",
    "olicentierbarare": "olicentierbar",
    "olicentierbarares": "olicentierbar",
    "olicentierbaras": "olicentierbar",
    "olicentierbarast": "olicentierbar",
    "olicentierbaraste": "olicentierbar",
    "olicentierbarastes": "olicentierbar",
    "olicentierbarasts": "olicentierbar",
    "olicentierbare": "olicentierbar",
    "olicentierbares": "olicentierbar",
    "olicentierbarheten": "olicentierbarhet",
    "olicentierbarhetens": "olicentierbarhet",
    "olicentierbarhets": "olicentierbarhet",
    "olicentierbars": "olicentierbar",
    "olicentierbart": "olicentierbar",
    "olicentierbarts": "olicentierbar",
    "olidliga": "olidlig",
    "olidligare": "olidlig",
    "olidligares": "olidlig",
    "olidligas": "olidlig",
    "olidligast": "olidlig",
    "olidligaste": "olidlig",
    "olidligastes": "olidlig",
    "olidligasts": "olidlig",
    "olidlige": "olidlig",
    "olidliges": "olidlig",
    "olidligheten": "olidlighet",
    "olidlighetens": "olidlighet",
    "olidligheter": "olidlighet",
    "olidligheterna": "olidlighet",
    "olidligheternas": "olidlighet",
    "olidligheters": "olidlighet",
    "olidlighets": "olidlighet",
    "olidligs": "olidlig",
    "olidligt": "olidlig",
    "olidligts": "olidlig",
    "olierade": "olierad",
    "olierades": "olierad",
    "olierads": "olierad",
    "olierat": "olierad",
    "olierats": "olierad",
    "olierbara": "olierbar",
    "olierbarare": "olierbar",
    "olierbarares": "olierbar",
    "olierbaras": "olierbar",
    "olierbarast": "olierbar",
    "olierbaraste": "olierbar",
    "olierbarastes": "olierbar",
    "olierbarasts": "olierbar",
    "olierbare": "olierbar",
    "olierbares": "olierbar",
    "olierbarheten": "olierbarhet",
    "olierbarhetens": "olierbarhet",
    "olierbarhets": "olierbarhet",
    "olierbars": "olierbar",
    "olierbart": "olierbar",
    "olierbarts": "olierbar",
    "oligarken": "oligark",
    "oligarkens": "oligark",
    "oligarker": "oligark",
    "oligarkerna": "oligark",
    "oligarkernas": "oligark",
    "oligarkers": "oligark",
    "oligarkien": "oligarki",
    "oligarkiens": "oligarki",
    "oligarkier": "oligarki",
    "oligarkierna": "oligarki",
    "oligarkiernas": "oligarki",
    "oligarkiers": "oligarki",
    "oligarkin": "oligarki",
    "oligarkins": "oligarki",
    "oligarkis": "oligarki",
    "oligarks": "oligark",
    "oligofaga": "oligofag",
    "oligofagare": "oligofag",
    "oligofagares": "oligofag",
    "oligofagas": "oligofag",
    "oligofagast": "oligofag",
    "oligofagaste": "oligofag",
    "oligofagastes": "oligofag",
    "oligofagasts": "oligofag",
    "oligofage": "oligofag",
    "oligofages": "oligofag",
    "oligofags": "oligofag",
    "oligofagt": "oligofag",
    "oligofagts": "oligofag",
    "oligofrenien": "oligofreni",
    "oligofreniens": "oligofreni",
    "oligofrenin": "oligofreni",
    "oligofrenins": "oligofreni",
    "oligofrenis": "oligofreni",
    "oligopolen": "oligopol",
    "oligopolens": "oligopol",
    "oligopolet": "oligopol",
    "oligopolets": "oligopol",
    "oligopols": "oligopol",
    "oligotrofa": "oligotrof",
    "oligotrofare": "oligotrof",
    "oligotrofares": "oligotrof",
    "oligotrofas": "oligotrof",
    "oligotrofast": "oligotrof",
    "oligotrofaste": "oligotrof",
    "oligotrofastes": "oligotrof",
    "oligotrofasts": "oligotrof",
    "oligotrofe": "oligotrof",
    "oligotrofes": "oligotrof",
    "oligotrofs": "oligotrof",
    "oligotroft": "oligotrof",
    "oligotrofts": "oligotrof",
    "olika": "olik",
    "olikade": "olikad",
    "olikades": "olikad",
    "olikads": "olikad",
    "olikare": "olik",
    "olikares": "olik",
    "olikartade": "olikartad",
    "olikartades": "olikartad",
    "olikartads": "olikartad",
    "olikartat": "olikartad",
    "olikartats": "olikartad",
    "olikas": "olik",
    "olikast": "olik",
    "olikaste": "olik",
    "olikastes": "olik",
    "olikasts": "olik",
    "olikat": "olikad",
    "olikats": "olikad",
    "olike": "olik",
    "olikes": "olik",
    "olikfärgade": "olikfärgad",
    "olikfärgades": "olikfärgad",
    "olikfärgads": "olikfärgad",
    "olikfärgat": "olikfärgad",
    "olikfärgats": "olikfärgad",
    "olikheten": "olikhet",
    "olikhetens": "olikhet",
    "olikheter": "olikhet",
    "olikheterna": "olikhet",
    "olikheternas": "olikhet",
    "olikheters": "olikhet",
    "olikhets": "olikhet",
    "oliks": "olik",
    "olikstora": "olikstor",
    "olikstorare": "olikstor",
    "olikstorares": "olikstor",
    "olikstoras": "olikstor",
    "olikstorast": "olikstor",
    "olikstoraste": "olikstor",
    "olikstorastes": "olikstor",
    "olikstorasts": "olikstor",
    "olikstore": "olikstor",
    "olikstores": "olikstor",
    "olikstors": "olikstor",
    "olikstort": "olikstor",
    "olikstorts": "olikstor",
    "olikt": "olik",
    "olikts": "olik",
    "olikviderade": "olikviderad",
    "olikviderades": "olikviderad",
    "olikviderads": "olikviderad",
    "olikviderat": "olikviderad",
    "olikviderats": "olikviderad",
    "olikviderbara": "olikviderbar",
    "olikviderbarare": "olikviderbar",
    "olikviderbarares": "olikviderbar",
    "olikviderbaras": "olikviderbar",
    "olikviderbarast": "olikviderbar",
    "olikviderbaraste": "olikviderbar",
    "olikviderbarastes": "olikviderbar",
    "olikviderbarasts": "olikviderbar",
    "olikviderbare": "olikviderbar",
    "olikviderbares": "olikviderbar",
    "olikviderbarheten": "olikviderbarhet",
    "olikviderbarhetens": "olikviderbarhet",
    "olikviderbarhets": "olikviderbarhet",
    "olikviderbars": "olikviderbar",
    "olikviderbart": "olikviderbar",
    "olikviderbarts": "olikviderbar",
    "olimmade": "olimmad",
    "olimmades": "olimmad",
    "olimmads": "olimmad",
    "olimmat": "olimmad",
    "olimmats": "olimmad",
    "olindade": "olindad",
    "olindades": "olindad",
    "olindads": "olindad",
    "olindat": "olindad",
    "olindats": "olindad",
    "olindrade": "olindrad",
    "olindrades": "olindrad",
    "olindrads": "olindrad",
    "olindrat": "olindrad",
    "olindrats": "olindrad",
    "olinjerade": "olinjerad",
    "olinjerades": "olinjerad",
    "olinjerads": "olinjerad",
    "olinjerat": "olinjerad",
    "olinjerats": "olinjerad",
    "olinjerbara": "olinjerbar",
    "olinjerbarare": "olinjerbar",
    "olinjerbarares": "olinjerbar",
    "olinjerbaras": "olinjerbar",
    "olinjerbarast": "olinjerbar",
    "olinjerbaraste": "olinjerbar",
    "olinjerbarastes": "olinjerbar",
    "olinjerbarasts": "olinjerbar",
    "olinjerbare": "olinjerbar",
    "olinjerbares": "olinjerbar",
    "olinjerbarheten": "olinjerbarhet",
    "olinjerbarhetens": "olinjerbarhet",
    "olinjerbarhets": "olinjerbarhet",
    "olinjerbars": "olinjerbar",
    "olinjerbart": "olinjerbar",
    "olinjerbarts": "olinjerbar",
    "olirade": "olirad",
    "olirades": "olirad",
    "olirads": "olirad",
    "olirat": "olirad",
    "olirats": "olirad",
    "olisserade": "olisserad",
    "olisserades": "olisserad",
    "olisserads": "olisserad",
    "olisserat": "olisserad",
    "olisserats": "olisserad",
    "olisserbara": "olisserbar",
    "olisserbarare": "olisserbar",
    "olisserbarares": "olisserbar",
    "olisserbaras": "olisserbar",
    "olisserbarast": "olisserbar",
    "olisserbaraste": "olisserbar",
    "olisserbarastes": "olisserbar",
    "olisserbarasts": "olisserbar",
    "olisserbare": "olisserbar",
    "olisserbares": "olisserbar",
    "olisserbarheten": "olisserbarhet",
    "olisserbarhetens": "olisserbarhet",
    "olisserbarhets": "olisserbarhet",
    "olisserbars": "olisserbar",
    "olisserbart": "olisserbar",
    "olisserbarts": "olisserbar",
    "olistade": "olistad",
    "olistades": "olistad",
    "olistads": "olistad",
    "olistat": "olistad",
    "olistats": "olistad",
    "olitograferade": "olitograferad",
    "olitograferades": "olitograferad",
    "olitograferads": "olitograferad",
    "olitograferat": "olitograferad",
    "olitograferats": "olitograferad",
    "olitograferbara": "olitograferbar",
    "olitograferbarare": "olitograferbar",
    "olitograferbarares": "olitograferbar",
    "olitograferbaras": "olitograferbar",
    "olitograferbarast": "olitograferbar",
    "olitograferbaraste": "olitograferbar",
    "olitograferbarastes": "olitograferbar",
    "olitograferbarasts": "olitograferbar",
    "olitograferbare": "olitograferbar",
    "olitograferbares": "olitograferbar",
    "olitograferbarheten": "olitograferbarhet",
    "olitograferbarhetens": "olitograferbarhet",
    "olitograferbarhets": "olitograferbarhet",
    "olitograferbars": "olitograferbar",
    "olitograferbart": "olitograferbar",
    "olitograferbarts": "olitograferbar",
    "olitsade": "olitsad",
    "olitsades": "olitsad",
    "olitsads": "olitsad",
    "olitsat": "olitsad",
    "olitsats": "olitsad",
    "olivade": "olivad",
    "olivades": "olivad",
    "olivads": "olivad",
    "olivat": "olivad",
    "olivats": "olivad",
    "oliven": "oliv",
    "olivens": "oliv",
    "oliver": "oliv",
    "oliverna": "oliv",
    "olivernas": "oliv",
    "olivers": "oliv",
    "olivfärgade": "olivfärgad",
    "olivfärgades": "olivfärgad",
    "olivfärgads": "olivfärgad",
    "olivfärgat": "olivfärgad",
    "olivfärgats": "olivfärgad",
    "olivgröna": "olivgrön",
    "olivgrönare": "olivgrön",
    "olivgrönares": "olivgrön",
    "olivgrönas": "olivgrön",
    "olivgrönast": "olivgrön",
    "olivgrönaste": "olivgrön",
    "olivgrönastes": "olivgrön",
    "olivgrönasts": "olivgrön",
    "olivgröne": "olivgrön",
    "olivgrönes": "olivgrön",
    "olivgröns": "olivgrön",
    "olivgrönt": "olivgrön",
    "olivgrönts": "olivgrön",
    "olivinen": "olivin",
    "olivinens": "olivin",
    "oliviner": "olivin",
    "olivinerna": "olivin",
    "olivinernas": "olivin",
    "oliviners": "olivin",
    "olivinet": "olivin",
    "olivinets": "olivin",
    "olivins": "olivin",
    "olivoljan": "olivolja",
    "olivoljans": "olivolja",
    "olivoljas": "olivolja",
    "olivolje": "olivolja",
    "olivoljor": "olivolja",
    "olivoljorna": "olivolja",
    "olivoljornas": "olivolja",
    "olivoljors": "olivolja",
    "olivs": "oliv",
    "olivträden": "olivträd",
    "olivträdens": "olivträd",
    "olivträdet": "olivträd",
    "olivträdets": "olivträd",
    "olivträds": "olivträd",
    "olivträn": "olivträd",
    "olivträna": "olivträd",
    "olivtränas": "olivträd",
    "olivträns": "olivträd",
    "olj": "olja",
    "oljad": "olja",
    "oljade": "olja",
    "oljades": "olja",
    "oljads": "olja",
    "oljan": "olja",
    "oljande": "olja",
    "oljanden": "oljande",
    "oljandena": "oljande",
    "oljandenas": "oljande",
    "oljandens": "oljande",
    "oljandes": "oljande",
    "oljandet": "oljande",
    "oljandets": "oljande",
    "oljans": "olja",
    "oljar": "olja",
    "oljas": "olja",
    "oljat": "olja",
    "oljats": "olja",
    "olje": "olja",
    "oljeaggregaten": "oljeaggregat",
    "oljeaggregatens": "oljeaggregat",
    "oljeaggregatet": "oljeaggregat",
    "oljeaggregatets": "oljeaggregat",
    "oljeaggregats": "oljeaggregat",
    "oljebaden": "oljebad",
    "oljebadens": "oljebad",
    "oljebadet": "oljebad",
    "oljebadets": "oljebad",
    "oljebads": "oljebad",
    "oljebaserade": "oljebaserad",
    "oljebaserades": "oljebaserad",
    "oljebaserads": "oljebaserad",
    "oljebaserat": "oljebaserad",
    "oljebaserats": "oljebaserad",
    "oljebekämpningar": "oljebekämpning",
    "oljebekämpningarna": "oljebekämpning",
    "oljebekämpningarnas": "oljebekämpning",
    "oljebekämpningars": "oljebekämpning",
    "oljebekämpningen": "oljebekämpning",
    "oljebekämpningens": "oljebekämpning",
    "oljebekämpnings": "oljebekämpning",
    "oljeberoendes": "oljeberoende",
    "oljeberoendet": "oljeberoende",
    "oljeberoendets": "oljeberoende",
    "oljebeständiga": "oljebeständig",
    "oljebeständigare": "oljebeständig",
    "oljebeständigares": "oljebeständig",
    "oljebeständigas": "oljebeständig",
    "oljebeständigast": "oljebeständig",
    "oljebeständigaste": "oljebeständig",
    "oljebeständigastes": "oljebeständig",
    "oljebeständigasts": "oljebeständig",
    "oljebeständige": "oljebeständig",
    "oljebeständiges": "oljebeständig",
    "oljebeständigheten": "oljebeständighet",
    "oljebeständighetens": "oljebeständighet",
    "oljebeständighets": "oljebeständighet",
    "oljebeständigs": "oljebeständig",
    "oljebeständigt": "oljebeständig",
    "oljebeständigts": "oljebeständig",
    "oljeblandade": "oljeblandad",
    "oljeblandades": "oljeblandad",
    "oljeblandads": "oljeblandad",
    "oljeblandat": "oljeblandad",
    "oljeblandats": "oljeblandad",
    "oljebolagen": "oljebolag",
    "oljebolagens": "oljebolag",
    "oljebolaget": "oljebolag",
    "oljebolagets": "oljebolag",
    "oljebolags": "oljebolag",
    "oljeborrningar": "oljeborrning",
    "oljeborrningarna": "oljeborrning",
    "oljeborrningarnas": "oljeborrning",
    "oljeborrningars": "oljeborrning",
    "oljeborrningen": "oljeborrning",
    "oljeborrningens": "oljeborrning",
    "oljeborrnings": "oljeborrning",
    "oljeborrtornen": "oljeborrtorn",
    "oljeborrtornens": "oljeborrtorn",
    "oljeborrtornet": "oljeborrtorn",
    "oljeborrtornets": "oljeborrtorn",
    "oljeborrtorns": "oljeborrtorn",
    "oljebranden": "oljebrand",
    "oljebrandens": "oljebrand",
    "oljebrands": "oljebrand",
    "oljebrunnar": "oljebrunn",
    "oljebrunnarna": "oljebrunn",
    "oljebrunnarnas": "oljebrunn",
    "oljebrunnars": "oljebrunn",
    "oljebrunnen": "oljebrunn",
    "oljebrunnens": "oljebrunn",
    "oljebrunns": "oljebrunn",
    "oljebränder": "oljebrand",
    "oljebränderna": "oljebrand",
    "oljebrändernas": "oljebrand",
    "oljebränders": "oljebrand",
    "oljebrännar": "oljebrännare",
    "oljebrännaren": "oljebrännare",
    "oljebrännarens": "oljebrännare",
    "oljebrännares": "oljebrännare",
    "oljebrännarna": "oljebrännare",
    "oljebrännarnas": "oljebrännare",
    "oljebytartrågen": "oljebytartråg",
    "oljebytartrågens": "oljebytartråg",
    "oljebytartråget": "oljebytartråg",
    "oljebytartrågets": "oljebytartråg",
    "oljebytartrågs": "oljebytartråg",
    "oljebyten": "oljebyte",
    "oljebytena": "oljebyte",
    "oljebytenas": "oljebyte",
    "oljebytens": "oljebyte",
    "oljebytes": "oljebyte",
    "oljebytet": "oljebyte",
    "oljebytets": "oljebyte",
    "oljebälten": "oljebälte",
    "oljebältena": "oljebälte",
    "oljebältenas": "oljebälte",
    "oljebältens": "oljebälte",
    "oljebältes": "oljebälte",
    "oljebältet": "oljebälte",
    "oljebältets": "oljebälte",
    "oljeduken": "oljeduk",
    "oljedukens": "oljeduk",
    "oljeduks": "oljeduk",
    "oljedådran": "oljedådra",
    "oljedådrans": "oljedådra",
    "oljedådras": "oljedådra",
    "oljedådre": "oljedådra",
    "oljedådror": "oljedådra",
    "oljedådrorna": "oljedådra",
    "oljedådrornas": "oljedådra",
    "oljedådrors": "oljedådra",
    "oljedöden": "oljedöd",
    "oljedödens": "oljedöd",
    "oljedöds": "oljedöd",
    "oljeeldningar": "oljeeldning",
    "oljeeldningarna": "oljeeldning",
    "oljeeldningarnas": "oljeeldning",
    "oljeeldningars": "oljeeldning",
    "oljeeldningen": "oljeeldning",
    "oljeeldningens": "oljeeldning",
    "oljeeldnings": "oljeeldning",
    "oljefilmen": "oljefilm",
    "oljefilmens": "oljefilm",
    "oljefilms": "oljefilm",
    "oljefilterna": "oljefilter",
    "oljefilternas": "oljefilter",
    "oljefilters": "oljefilter",
    "oljefiltren": "oljefilter",
    "oljefiltrens": "oljefilter",
    "oljefiltret": "oljefilter",
    "oljefiltrets": "oljefilter",
    "oljefälten": "oljefält",
    "oljefältens": "oljefält",
    "oljefältet": "oljefält",
    "oljefältets": "oljefält",
    "oljefälts": "oljefält",
    "oljefärgen": "oljefärg",
    "oljefärgens": "oljefärg",
    "oljefärger": "oljefärg",
    "oljefärgerna": "oljefärg",
    "oljefärgernas": "oljefärg",
    "oljefärgers": "oljefärg",
    "oljefärgs": "oljefärg",
    "oljegruset": "oljegrus",
    "oljegrusets": "oljegrus",
    "oljeinpackningar": "oljeinpackning",
    "oljeinpackningarna": "oljeinpackning",
    "oljeinpackningarnas": "oljeinpackning",
    "oljeinpackningars": "oljeinpackning",
    "oljeinpackningen": "oljeinpackning",
    "oljeinpackningens": "oljeinpackning",
    "oljeinpacknings": "oljeinpackning",
    "oljekak": "oljekaka",
    "oljekakan": "oljekaka",
    "oljekakans": "oljekaka",
    "oljekakas": "oljekaka",
    "oljekake": "oljekaka",
    "oljekakor": "oljekaka",
    "oljekakorna": "oljekaka",
    "oljekakornas": "oljekaka",
    "oljekakors": "oljekaka",
    "oljekaks": "oljekaka",
    "oljekannan": "oljekanna",
    "oljekannans": "oljekanna",
    "oljekannas": "oljekanna",
    "oljekanne": "oljekanna",
    "oljekannor": "oljekanna",
    "oljekannorna": "oljekanna",
    "oljekannornas": "oljekanna",
    "oljekannors": "oljekanna",
    "oljekläderna": "oljekläder",
    "oljeklädernas": "oljekläder",
    "oljekläders": "oljekläder",
    "oljeklädes": "oljekläder",
    "oljekläds": "oljekläder",
    "oljekonsumtionen": "oljekonsumtion",
    "oljekonsumtionens": "oljekonsumtion",
    "oljekonsumtions": "oljekonsumtion",
    "oljekraftfoders": "oljekraftfoder",
    "oljekraftfodret": "oljekraftfoder",
    "oljekraftfodrets": "oljekraftfoder",
    "oljekäll": "oljekälla",
    "oljekällan": "oljekälla",
    "oljekällans": "oljekälla",
    "oljekällas": "oljekälla",
    "oljekälle": "oljekälla",
    "oljekällor": "oljekälla",
    "oljekällorna": "oljekälla",
    "oljekällornas": "oljekälla",
    "oljekällors": "oljekälla",
    "oljekälls": "oljekälla",
    "oljelamp": "oljelampa",
    "oljelampan": "oljelampa",
    "oljelampans": "oljelampa",
    "oljelampas": "oljelampa",
    "oljelampe": "oljelampa",
    "oljelampor": "oljelampa",
    "oljelamporna": "oljelampa",
    "oljelampornas": "oljelampa",
    "oljelampors": "oljelampa",
    "oljelamps": "oljelampa",
    "oljelandet": "oljeland",
    "oljelandets": "oljeland",
    "oljelands": "oljeland",
    "oljeledningar": "oljeledning",
    "oljeledningarna": "oljeledning",
    "oljeledningarnas": "oljeledning",
    "oljeledningars": "oljeledning",
    "oljeledningen": "oljeledning",
    "oljeledningens": "oljeledning",
    "oljelednings": "oljeledning",
    "oljelykt": "oljelykta",
    "oljelyktan": "oljelykta",
    "oljelyktans": "oljelykta",
    "oljelyktas": "oljelykta",
    "oljelykte": "oljelykta",
    "oljelyktor": "oljelykta",
    "oljelyktorna": "oljelykta",
    "oljelyktornas": "oljelykta",
    "oljelyktors": "oljelykta",
    "oljelykts": "oljelykta",
    "oljeläck": "oljeläcka",
    "oljeläckagen": "oljeläckage",
    "oljeläckagens": "oljeläckage",
    "oljeläckages": "oljeläckage",
    "oljeläckaget": "oljeläckage",
    "oljeläckagets": "oljeläckage",
    "oljeläckan": "oljeläcka",
    "oljeläckans": "oljeläcka",
    "oljeläckas": "oljeläcka",
    "oljeläcke": "oljeläcka",
    "oljeläckor": "oljeläcka",
    "oljeläckorna": "oljeläcka",
    "oljeläckornas": "oljeläcka",
    "oljeläckors": "oljeläcka",
    "oljeläcks": "oljeläcka",
    "oljeländer": "oljeland",
    "oljeländerna": "oljeland",
    "oljeländernas": "oljeland",
    "oljeländers": "oljeland",
    "oljelåsen": "oljelås",
    "oljelåsens": "oljelås",
    "oljelåset": "oljelås",
    "oljelåsets": "oljelås",
    "oljemålningar": "oljemålning",
    "oljemålningarna": "oljemålning",
    "oljemålningarnas": "oljemålning",
    "oljemålningars": "oljemålning",
    "oljemålningen": "oljemålning",
    "oljemålningens": "oljemålning",
    "oljemålnings": "oljemålning",
    "oljenivåer": "oljenivå",
    "oljenivåerna": "oljenivå",
    "oljenivåernas": "oljenivå",
    "oljenivåers": "oljenivå",
    "oljenivåmätar": "oljenivåmätare",
    "oljenivåmätaren": "oljenivåmätare",
    "oljenivåmätarens": "oljenivåmätare",
    "oljenivåmätares": "oljenivåmätare",
    "oljenivåmätarna": "oljenivåmätare",
    "oljenivåmätarnas": "oljenivåmätare",
    "oljenivån": "oljenivå",
    "oljenivåns": "oljenivå",
    "oljenivås": "oljenivå",
    "oljenivåvakten": "oljenivåvakt",
    "oljenivåvaktens": "oljenivåvakt",
    "oljenivåvakter": "oljenivåvakt",
    "oljenivåvakterna": "oljenivåvakt",
    "oljenivåvakternas": "oljenivåvakt",
    "oljenivåvakters": "oljenivåvakt",
    "oljenivåvakts": "oljenivåvakt",
    "oljepalmen": "oljepalm",
    "oljepalmens": "oljepalm",
    "oljepalmer": "oljepalm",
    "oljepalmerna": "oljepalm",
    "oljepalmernas": "oljepalm",
    "oljepalmers": "oljepalm",
    "oljepalms": "oljepalm",
    "oljepapperet": "oljepapper",
    "oljepapperets": "oljepapper",
    "oljepappers": "oljepapper",
    "oljepappret": "oljepapper",
    "oljepapprets": "oljepapper",
    "oljeprisen": "oljepris",
    "oljeprisens": "oljepris",
    "oljepriser": "oljepris",
    "oljepriserna": "oljepris",
    "oljeprisernas": "oljepris",
    "oljeprisers": "oljepris",
    "oljepriset": "oljepris",
    "oljeprisets": "oljepris",
    "oljeraffinaderier": "oljeraffinaderi",
    "oljeraffinaderierna": "oljeraffinaderi",
    "oljeraffinaderiernas": "oljeraffinaderi",
    "oljeraffinaderiers": "oljeraffinaderi",
    "oljeraffinaderiet": "oljeraffinaderi",
    "oljeraffinaderiets": "oljeraffinaderi",
    "oljeraffinaderis": "oljeraffinaderi",
    "oljeraffinaderit": "oljeraffinaderi",
    "oljeraffinaderits": "oljeraffinaderi",
    "oljerika": "oljerik",
    "oljerikare": "oljerik",
    "oljerikares": "oljerik",
    "oljerikas": "oljerik",
    "oljerikast": "oljerik",
    "oljerikaste": "oljerik",
    "oljerikastes": "oljerik",
    "oljerikasts": "oljerik",
    "oljerike": "oljerik",
    "oljerikes": "oljerik",
    "oljerikheten": "oljerikhet",
    "oljerikhetens": "oljerikhet",
    "oljerikhets": "oljerikhet",
    "oljeriks": "oljerik",
    "oljerikt": "oljerik",
    "oljerikts": "oljerik",
    "oljeringar": "oljering",
    "oljeringarna": "oljering",
    "oljeringarnas": "oljering",
    "oljeringars": "oljering",
    "oljeringen": "oljering",
    "oljeringens": "oljering",
    "oljerings": "oljering",
    "oljerivens": "oljeriven",
    "oljerivet": "oljeriven",
    "oljerivets": "oljeriven",
    "oljerivna": "oljeriven",
    "oljerivnare": "oljeriven",
    "oljerivnares": "oljeriven",
    "oljerivnas": "oljeriven",
    "oljerivnast": "oljeriven",
    "oljerivnaste": "oljeriven",
    "oljerivnastes": "oljeriven",
    "oljerivnasts": "oljeriven",
    "oljerivne": "oljeriven",
    "oljerivnes": "oljeriven",
    "oljerockar": "oljerock",
    "oljerockarna": "oljerock",
    "oljerockarnas": "oljerock",
    "oljerockars": "oljerock",
    "oljerocken": "oljerock",
    "oljerockens": "oljerock",
    "oljerocks": "oljerock",
    "oljesaneringar": "oljesanering",
    "oljesaneringarna": "oljesanering",
    "oljesaneringarnas": "oljesanering",
    "oljesaneringars": "oljesanering",
    "oljesaneringen": "oljesanering",
    "oljesaneringens": "oljesanering",
    "oljesanerings": "oljesanering",
    "oljesanktionen": "oljesanktion",
    "oljesanktionens": "oljesanktion",
    "oljesanktioner": "oljesanktion",
    "oljesanktionerna": "oljesanktion",
    "oljesanktionernas": "oljesanktion",
    "oljesanktioners": "oljesanktion",
    "oljesanktions": "oljesanktion",
    "oljeskadade": "oljeskadad",
    "oljeskadades": "oljeskadad",
    "oljeskadads": "oljeskadad",
    "oljeskadat": "oljeskadad",
    "oljeskadats": "oljeskadad",
    "oljeskiffern": "oljeskiffer",
    "oljeskifferns": "oljeskiffer",
    "oljeskiffers": "oljeskiffer",
    "oljeskiffrar": "oljeskiffer",
    "oljeskiffrarna": "oljeskiffer",
    "oljeskiffrarnas": "oljeskiffer",
    "oljeskiffrars": "oljeskiffer",
    "oljeslagerier": "oljeslageri",
    "oljeslagerierna": "oljeslageri",
    "oljeslageriernas": "oljeslageri",
    "oljeslageriers": "oljeslageri",
    "oljeslageriet": "oljeslageri",
    "oljeslageriets": "oljeslageri",
    "oljeslageris": "oljeslageri",
    "oljeslagerit": "oljeslageri",
    "oljeslagerits": "oljeslageri",
    "oljespillet": "oljespill",
    "oljespillets": "oljespill",
    "oljespills": "oljespill",
    "oljestenen": "oljesten",
    "oljestenens": "oljesten",
    "oljestens": "oljesten",
    "oljestoppen": "oljestopp",
    "oljestoppens": "oljestopp",
    "oljestoppet": "oljestopp",
    "oljestoppets": "oljestopp",
    "oljestopps": "oljestopp",
    "oljeströmbrytar": "oljeströmbrytare",
    "oljeströmbrytaren": "oljeströmbrytare",
    "oljeströmbrytarens": "oljeströmbrytare",
    "oljeströmbrytares": "oljeströmbrytare",
    "oljeströmbrytarna": "oljeströmbrytare",
    "oljeströmbrytarnas": "oljeströmbrytare",
    "oljeställen": "oljeställ",
    "oljeställens": "oljeställ",
    "oljestället": "oljeställ",
    "oljeställets": "oljeställ",
    "oljeställs": "oljeställ",
    "oljesumpar": "oljesump",
    "oljesumparna": "oljesump",
    "oljesumparnas": "oljesump",
    "oljesumpars": "oljesump",
    "oljesumpen": "oljesump",
    "oljesumpens": "oljesump",
    "oljesumps": "oljesump",
    "oljesyran": "oljesyra",
    "oljesyrans": "oljesyra",
    "oljesyras": "oljesyra",
    "oljesyre": "oljesyra",
    "oljetankern": "oljetanker",
    "oljetankerna": "oljetanker",
    "oljetankernas": "oljetanker",
    "oljetankerns": "oljetanker",
    "oljetankers": "oljetanker",
    "oljetankersarna": "oljetanker",
    "oljetankersarnas": "oljetanker",
    "oljetankrar": "oljetanker",
    "oljetankrarna": "oljetanker",
    "oljetankrarnas": "oljetanker",
    "oljetankrars": "oljetanker",
    "oljetrycken": "oljetryck",
    "oljetryckens": "oljetryck",
    "oljetrycket": "oljetryck",
    "oljetryckets": "oljetryck",
    "oljetrycks": "oljetryck",
    "oljetrågen": "oljetråg",
    "oljetrågens": "oljetråg",
    "oljetråget": "oljetråg",
    "oljetrågets": "oljetråg",
    "oljetrågs": "oljetråg",
    "oljetyget": "oljetyg",
    "oljetygets": "oljetyg",
    "oljetygs": "oljetyg",
    "oljeutsläppen": "oljeutsläpp",
    "oljeutsläppens": "oljeutsläpp",
    "oljeutsläppet": "oljeutsläpp",
    "oljeutsläppets": "oljeutsläpp",
    "oljeutsläpps": "oljeutsläpp",
    "oljeutvinningar": "oljeutvinning",
    "oljeutvinningarna": "oljeutvinning",
    "oljeutvinningarnas": "oljeutvinning",
    "oljeutvinningars": "oljeutvinning",
    "oljeutvinningen": "oljeutvinning",
    "oljeutvinningens": "oljeutvinning",
    "oljeutvinnings": "oljeutvinning",
    "oljevävar": "oljeväv",
    "oljevävarna": "oljeväv",
    "oljevävarnas": "oljeväv",
    "oljevävars": "oljeväv",
    "oljeväven": "oljeväv",
    "oljevävens": "oljeväv",
    "oljevävs": "oljeväv",
    "oljeväxten": "oljeväxt",
    "oljeväxtens": "oljeväxt",
    "oljeväxter": "oljeväxt",
    "oljeväxterna": "oljeväxt",
    "oljeväxternas": "oljeväxt",
    "oljeväxters": "oljeväxt",
    "oljeväxts": "oljeväxt",
    "oljiga": "oljig",
    "oljigare": "oljig",
    "oljigares": "oljig",
    "oljigas": "oljig",
    "oljigast": "oljig",
    "oljigaste": "oljig",
    "oljigastes": "oljig",
    "oljigasts": "oljig",
    "oljige": "oljig",
    "oljiges": "oljig",
    "oljigheten": "oljighet",
    "oljighetens": "oljighet",
    "oljighets": "oljighet",
    "oljigs": "oljig",
    "oljigt": "oljig",
    "oljigts": "oljig",
    "oljor": "olja",
    "oljorna": "olja",
    "oljornas": "olja",
    "oljors": "olja",
    "oljudade": "oljudad",
    "oljudades": "oljudad",
    "oljudads": "oljudad",
    "oljudat": "oljudad",
    "oljudats": "oljudad",
    "oljuden": "oljud",
    "oljudens": "oljud",
    "oljudet": "oljud",
    "oljudets": "oljud",
    "oljuds": "oljud",
    "oljustrade": "oljustrad",
    "oljustrades": "oljustrad",
    "oljustrads": "oljustrad",
    "oljustrat": "oljustrad",
    "oljustrats": "oljustrad",
    "oll": "olle",
    "ollad": "olla",
    "ollade": "olla",
    "ollades": "olla",
    "ollads": "olla",
    "ollan": "olla",
    "ollande": "olla",
    "ollanden": "ollande",
    "ollandena": "ollande",
    "ollandenas": "ollande",
    "ollandens": "ollande",
    "ollandes": "ollande",
    "ollandet": "ollande",
    "ollandets": "ollande",
    "ollans": "olla",
    "ollar": "olla",
    "ollarna": "olle",
    "ollars": "olle",
    "ollas": "olla",
    "ollat": "olla",
    "ollats": "olla",
    "olle": "olla",
    "ollen": "olle",
    "ollens": "olle",
    "olles": "olle",
    "ollningar": "ollning",
    "ollningarna": "ollning",
    "ollningarnas": "ollning",
    "ollningars": "ollning",
    "ollningen": "ollning",
    "ollningens": "ollning",
    "ollnings": "ollning",
    "ollonborr": "ollonborre",
    "ollonborrar": "ollonborre",
    "ollonborrarna": "ollonborre",
    "ollonborrarnas": "ollonborre",
    "ollonborrars": "ollonborre",
    "ollonborren": "ollonborre",
    "ollonborrens": "ollonborre",
    "ollonborres": "ollonborre",
    "ollonborrs": "ollonborre",
    "ollondröppeln": "ollondröppel",
    "ollondröppelns": "ollondröppel",
    "ollondröppels": "ollondröppel",
    "ollonen": "ollon",
    "ollonens": "ollon",
    "ollonet": "ollon",
    "ollonets": "ollon",
    "ollonmaskar": "ollonmask",
    "ollonmaskarna": "ollonmask",
    "ollonmaskarnas": "ollonmask",
    "ollonmaskars": "ollonmask",
    "ollonmasken": "ollonmask",
    "ollonmaskens": "ollonmask",
    "ollonmasks": "ollonmask",
    "ollonpistolen": "ollonpistol",
    "ollonpistolens": "ollonpistol",
    "ollonpistoler": "ollonpistol",
    "ollonpistolerna": "ollonpistol",
    "ollonpistolernas": "ollonpistol",
    "ollonpistolers": "ollonpistol",
    "ollonpistols": "ollonpistol",
    "ollons": "ollon",
    "ollonskogar": "ollonskog",
    "ollonskogarna": "ollonskog",
    "ollonskogarnas": "ollonskog",
    "ollonskogars": "ollonskog",
    "ollonskogen": "ollonskog",
    "ollonskogens": "ollonskog",
    "ollonskogs": "ollonskog",
    "ollonskotten": "ollonskott",
    "ollonskottens": "ollonskott",
    "ollonskottet": "ollonskott",
    "ollonskottets": "ollonskott",
    "ollonskotts": "ollonskott",
    "ollonsvinen": "ollonsvin",
    "ollonsvinens": "ollonsvin",
    "ollonsvinet": "ollonsvin",
    "ollonsvinets": "ollonsvin",
    "ollonsvins": "ollonsvin",
    "ollonträden": "ollonträd",
    "ollonträdens": "ollonträd",
    "ollonträdet": "ollonträd",
    "ollonträdets": "ollonträd",
    "ollonträds": "ollonträd",
    "ollonträn": "ollonträd",
    "ollonträna": "ollonträd",
    "ollontränas": "ollonträd",
    "ollonträns": "ollonträd",
    "ollor": "olla",
    "ollorna": "olla",
    "ollornas": "olla",
    "ollors": "olla",
    "olls": "olle",
    "olmar": "olm",
    "olmarna": "olm",
    "olmarnas": "olm",
    "olmars": "olm",
    "olmen": "olm",
    "olmens": "olm",
    "olms": "olm",
    "olobbade": "olobbad",
    "olobbades": "olobbad",
    "olobbads": "olobbad",
    "olobbat": "olobbad",
    "olobbats": "olobbad",
    "olockade": "olockad",
    "olockades": "olockad",
    "olockads": "olockad",
    "olockat": "olockad",
    "olockats": "olockad",
    "olockoutade": "olockoutad",
    "olockoutades": "olockoutad",
    "olockoutads": "olockoutad",
    "olockoutat": "olockoutad",
    "olockoutats": "olockoutad",
    "olodade": "olodad",
    "olodades": "olodad",
    "olodads": "olodad",
    "olodat": "olodad",
    "olodats": "olodad",
    "olofsmäss": "olofsmässa",
    "olofsmässan": "olofsmässa",
    "olofsmässans": "olofsmässa",
    "olofsmässas": "olofsmässa",
    "olofsmässe": "olofsmässa",
    "olofsmässor": "olofsmässa",
    "olofsmässorna": "olofsmässa",
    "olofsmässornas": "olofsmässa",
    "olofsmässors": "olofsmässa",
    "ologerade": "ologerad",
    "ologerades": "ologerad",
    "ologerads": "ologerad",
    "ologerat": "ologerad",
    "ologerats": "ologerad",
    "ologerbara": "ologerbar",
    "ologerbarare": "ologerbar",
    "ologerbarares": "ologerbar",
    "ologerbaras": "ologerbar",
    "ologerbarast": "ologerbar",
    "ologerbaraste": "ologerbar",
    "ologerbarastes": "ologerbar",
    "ologerbarasts": "ologerbar",
    "ologerbare": "ologerbar",
    "ologerbares": "ologerbar",
    "ologerbarheten": "ologerbarhet",
    "ologerbarhetens": "ologerbarhet",
    "ologerbarhets": "ologerbarhet",
    "ologerbars": "ologerbar",
    "ologerbart": "ologerbar",
    "ologerbarts": "ologerbar",
    "ologgade": "ologgad",
    "ologgades": "ologgad",
    "ologgads": "ologgad",
    "ologgat": "ologgad",
    "ologgats": "ologgad",
    "ologiska": "ologisk",
    "ologiskare": "ologisk",
    "ologiskares": "ologisk",
    "ologiskas": "ologisk",
    "ologiskast": "ologisk",
    "ologiskaste": "ologisk",
    "ologiskastes": "ologisk",
    "ologiskasts": "ologisk",
    "ologiske": "ologisk",
    "ologiskes": "ologisk",
    "ologisks": "ologisk",
    "ologiskt": "ologisk",
    "ologiskts": "ologisk",
    "olokaliserade": "olokaliserad",
    "olokaliserades": "olokaliserad",
    "olokaliserads": "olokaliserad",
    "olokaliserat": "olokaliserad",
    "olokaliserats": "olokaliserad",
    "olokaliserbara": "olokaliserbar",
    "olokaliserbarare": "olokaliserbar",
    "olokaliserbarares": "olokaliserbar",
    "olokaliserbaras": "olokaliserbar",
    "olokaliserbarast": "olokaliserbar",
    "olokaliserbaraste": "olokaliserbar",
    "olokaliserbarastes": "olokaliserbar",
    "olokaliserbarasts": "olokaliserbar",
    "olokaliserbare": "olokaliserbar",
    "olokaliserbares": "olokaliserbar",
    "olokaliserbarheten": "olokaliserbarhet",
    "olokaliserbarhetens": "olokaliserbarhet",
    "olokaliserbarhets": "olokaliserbarhet",
    "olokaliserbars": "olokaliserbar",
    "olokaliserbart": "olokaliserbar",
    "olokaliserbarts": "olokaliserbar",
    "oloppade": "oloppad",
    "oloppades": "oloppad",
    "oloppads": "oloppad",
    "oloppat": "oloppad",
    "oloppats": "oloppad",
    "olossade": "olossad",
    "olossades": "olossad",
    "olossads": "olossad",
    "olossat": "olossad",
    "olossats": "olossad",
    "olotsade": "olotsad",
    "olotsades": "olotsad",
    "olotsads": "olotsad",
    "olotsat": "olotsad",
    "olotsats": "olotsad",
    "olottade": "olottad",
    "olottades": "olottad",
    "olottads": "olottad",
    "olottat": "olottad",
    "olottats": "olottad",
    "olovade": "olovad",
    "olovades": "olovad",
    "olovads": "olovad",
    "olovat": "olovad",
    "olovats": "olovad",
    "olovliga": "olovlig",
    "olovligare": "olovlig",
    "olovligares": "olovlig",
    "olovligas": "olovlig",
    "olovligast": "olovlig",
    "olovligaste": "olovlig",
    "olovligastes": "olovlig",
    "olovligasts": "olovlig",
    "olovlige": "olovlig",
    "olovliges": "olovlig",
    "olovligheten": "olovlighet",
    "olovlighetens": "olovlighet",
    "olovligheter": "olovlighet",
    "olovligheterna": "olovlighet",
    "olovligheternas": "olovlighet",
    "olovligheters": "olovlighet",
    "olovlighets": "olovlighet",
    "olovligs": "olovlig",
    "olovligt": "olovlig",
    "olovligts": "olovlig",
    "olsmäss": "olsmässa",
    "olsmässan": "olsmässa",
    "olsmässans": "olsmässa",
    "olsmässas": "olsmässa",
    "olsmässe": "olsmässa",
    "olsmässor": "olsmässa",
    "olsmässorna": "olsmässa",
    "olsmässornas": "olsmässa",
    "olsmässors": "olsmässa",
    "oluckrade": "oluckrad",
    "oluckrades": "oluckrad",
    "oluckrads": "oluckrad",
    "oluckrat": "oluckrad",
    "oluckrats": "oluckrad",
    "oluftade": "oluftad",
    "oluftades": "oluftad",
    "oluftads": "oluftad",
    "oluftat": "oluftad",
    "oluftats": "oluftad",
    "oluggade": "oluggad",
    "oluggades": "oluggad",
    "oluggads": "oluggad",
    "oluggat": "oluggad",
    "oluggats": "oluggad",
    "olugnade": "olugnad",
    "olugnades": "olugnad",
    "olugnads": "olugnad",
    "olugnat": "olugnad",
    "olugnats": "olugnad",
    "oluktade": "oluktad",
    "oluktades": "oluktad",
    "oluktads": "oluktad",
    "oluktat": "oluktad",
    "oluktats": "oluktad",
    "olunnade": "olunnad",
    "olunnades": "olunnad",
    "olunnads": "olunnad",
    "olunnat": "olunnad",
    "olunnats": "olunnad",
    "olurade": "olurad",
    "olurades": "olurad",
    "olurads": "olurad",
    "olurat": "olurad",
    "olurats": "olurad",
    "olusten": "olust",
    "olustens": "olust",
    "olustiga": "olustig",
    "olustigare": "olustig",
    "olustigares": "olustig",
    "olustigas": "olustig",
    "olustigast": "olustig",
    "olustigaste": "olustig",
    "olustigastes": "olustig",
    "olustigasts": "olustig",
    "olustige": "olustig",
    "olustiges": "olustig",
    "olustigheten": "olustighet",
    "olustighetens": "olustighet",
    "olustighets": "olustighet",
    "olustigs": "olustig",
    "olustigt": "olustig",
    "olustigts": "olustig",
    "olusts": "olust",
    "olutade": "olutad",
    "olutades": "olutad",
    "olutads": "olutad",
    "olutat": "olutad",
    "olutats": "olutad",
    "oluteiniserade": "oluteiniserad",
    "oluteiniserades": "oluteiniserad",
    "oluteiniserads": "oluteiniserad",
    "oluteiniserat": "oluteiniserad",
    "oluteiniserats": "oluteiniserad",
    "oluteiniserbara": "oluteiniserbar",
    "oluteiniserbarare": "oluteiniserbar",
    "oluteiniserbarares": "oluteiniserbar",
    "oluteiniserbaras": "oluteiniserbar",
    "oluteiniserbarast": "oluteiniserbar",
    "oluteiniserbaraste": "oluteiniserbar",
    "oluteiniserbarastes": "oluteiniserbar",
    "oluteiniserbarasts": "oluteiniserbar",
    "oluteiniserbare": "oluteiniserbar",
    "oluteiniserbares": "oluteiniserbar",
    "oluteiniserbarheten": "oluteiniserbarhet",
    "oluteiniserbarhetens": "oluteiniserbarhet",
    "oluteiniserbarhets": "oluteiniserbarhet",
    "oluteiniserbars": "oluteiniserbar",
    "oluteiniserbart": "oluteiniserbar",
    "oluteiniserbarts": "oluteiniserbar",
    "oluttrade": "oluttrad",
    "oluttrades": "oluttrad",
    "oluttrads": "oluttrad",
    "oluttrat": "oluttrad",
    "oluttrats": "oluttrad",
    "olvonen": "olvon",
    "olvonens": "olvon",
    "olvonet": "olvon",
    "olvonets": "olvon",
    "olvons": "olvon",
    "olvonväxten": "olvonväxt",
    "olvonväxtens": "olvonväxt",
    "olvonväxter": "olvonväxt",
    "olvonväxterna": "olvonväxt",
    "olvonväxternas": "olvonväxt",
    "olvonväxters": "olvonväxt",
    "olvonväxts": "olvonväxt",
    "olyck": "olycka",
    "olyckades": "olyckas",
    "olyckan": "olycka",
    "olyckans": "olycka",
    "olyckas": "olycka",
    "olyckats": "olyckas",
    "olycke": "olycka",
    "olyckliga": "olycklig",
    "olyckligare": "olycklig",
    "olyckligares": "olycklig",
    "olyckligas": "olycklig",
    "olyckligast": "olycklig",
    "olyckligaste": "olycklig",
    "olyckligastes": "olycklig",
    "olyckligasts": "olycklig",
    "olycklige": "olycklig",
    "olyckliges": "olycklig",
    "olyckligheten": "olycklighet",
    "olycklighetens": "olycklighet",
    "olycklighets": "olycklighet",
    "olyckligs": "olycklig",
    "olyckligt": "olycklig",
    "olyckligts": "olycklig",
    "olyckor": "olycka",
    "olyckorna": "olycka",
    "olyckornas": "olycka",
    "olyckors": "olycka",
    "olycks": "olycka",
    "olycksaliga": "olycksalig",
    "olycksaligare": "olycksalig",
    "olycksaligares": "olycksalig",
    "olycksaligas": "olycksalig",
    "olycksaligast": "olycksalig",
    "olycksaligaste": "olycksalig",
    "olycksaligastes": "olycksalig",
    "olycksaligasts": "olycksalig",
    "olycksalige": "olycksalig",
    "olycksaliges": "olycksalig",
    "olycksaligheten": "olycksalighet",
    "olycksalighetens": "olycksalighet",
    "olycksalighets": "olycksalighet",
    "olycksaligs": "olycksalig",
    "olycksaligt": "olycksalig",
    "olycksaligts": "olycksalig",
    "olycksbarnen": "olycksbarn",
    "olycksbarnens": "olycksbarn",
    "olycksbarnet": "olycksbarn",
    "olycksbarnets": "olycksbarn",
    "olycksbarns": "olycksbarn",
    "olycksbrodern": "olycksbroder",
    "olycksbroderns": "olycksbroder",
    "olycksbroders": "olycksbroder",
    "olycksbröder": "olycksbroder",
    "olycksbröderna": "olycksbroder",
    "olycksbrödernas": "olycksbroder",
    "olycksbröders": "olycksbroder",
    "olycksdagar": "olycksdag",
    "olycksdagarna": "olycksdag",
    "olycksdagarnas": "olycksdag",
    "olycksdagars": "olycksdag",
    "olycksdagen": "olycksdag",
    "olycksdagens": "olycksdag",
    "olycksdags": "olycksdag",
    "olycksdan": "olycksdag",
    "olycksdans": "olycksdag",
    "olycksdar": "olycksdag",
    "olycksdarna": "olycksdag",
    "olycksdarnas": "olycksdag",
    "olycksdars": "olycksdag",
    "olycksdigerheten": "olycksdigerhet",
    "olycksdigerhetens": "olycksdigerhet",
    "olycksdigerhets": "olycksdigerhet",
    "olycksdigers": "olycksdiger",
    "olycksdigert": "olycksdiger",
    "olycksdigerts": "olycksdiger",
    "olycksdigra": "olycksdiger",
    "olycksdigrare": "olycksdiger",
    "olycksdigrares": "olycksdiger",
    "olycksdigras": "olycksdiger",
    "olycksdigrast": "olycksdiger",
    "olycksdigraste": "olycksdiger",
    "olycksdigrastes": "olycksdiger",
    "olycksdigrasts": "olycksdiger",
    "olycksdigre": "olycksdiger",
    "olycksdigres": "olycksdiger",
    "olycksfallen": "olycksfall",
    "olycksfallens": "olycksfall",
    "olycksfallet": "olycksfall",
    "olycksfallets": "olycksfall",
    "olycksfalls": "olycksfall",
    "olycksfallsfrekvensen": "olycksfallsfrekvens",
    "olycksfallsfrekvensens": "olycksfallsfrekvens",
    "olycksfallsfrekvenser": "olycksfallsfrekvens",
    "olycksfallsfrekvenserna": "olycksfallsfrekvens",
    "olycksfallsfrekvensernas": "olycksfallsfrekvens",
    "olycksfallsfrekvensers": "olycksfallsfrekvens",
    "olycksfågeln": "olycksfågel",
    "olycksfågelns": "olycksfågel",
    "olycksfågels": "olycksfågel",
    "olycksfåglar": "olycksfågel",
    "olycksfåglarna": "olycksfågel",
    "olycksfåglarnas": "olycksfågel",
    "olycksfåglars": "olycksfågel",
    "olyckshändelsen": "olyckshändelse",
    "olyckshändelsens": "olyckshändelse",
    "olyckshändelser": "olyckshändelse",
    "olyckshändelserna": "olyckshändelse",
    "olyckshändelsernas": "olyckshändelse",
    "olyckshändelsers": "olyckshändelse",
    "olyckshändelses": "olyckshändelse",
    "olyckskamraten": "olyckskamrat",
    "olyckskamratens": "olyckskamrat",
    "olyckskamrater": "olyckskamrat",
    "olyckskamraterna": "olyckskamrat",
    "olyckskamraternas": "olyckskamrat",
    "olyckskamraters": "olyckskamrat",
    "olyckskamrats": "olyckskamrat",
    "olyckskatastrofen": "olyckskatastrof",
    "olyckskatastrofens": "olyckskatastrof",
    "olyckskatastrofer": "olyckskatastrof",
    "olyckskatastroferna": "olyckskatastrof",
    "olyckskatastrofernas": "olyckskatastrof",
    "olyckskatastrofers": "olyckskatastrof",
    "olyckskatastrofs": "olyckskatastrof",
    "olyckskorpar": "olyckskorp",
    "olyckskorparna": "olyckskorp",
    "olyckskorparnas": "olyckskorp",
    "olyckskorpars": "olyckskorp",
    "olyckskorpen": "olyckskorp",
    "olyckskorpens": "olyckskorp",
    "olyckskorps": "olyckskorp",
    "olycksplatsen": "olycksplats",
    "olycksplatsens": "olycksplats",
    "olycksplatser": "olycksplats",
    "olycksplatserna": "olycksplats",
    "olycksplatsernas": "olycksplats",
    "olycksplatsers": "olycksplats",
    "olycksprofeti": "olycksprofetia",
    "olycksprofetian": "olycksprofetia",
    "olycksprofetians": "olycksprofetia",
    "olycksprofetias": "olycksprofetia",
    "olycksprofetie": "olycksprofetia",
    "olycksprofetior": "olycksprofetia",
    "olycksprofetiorna": "olycksprofetia",
    "olycksprofetiornas": "olycksprofetia",
    "olycksprofetiors": "olycksprofetia",
    "olycksprofetis": "olycksprofetia",
    "olycksstatistiken": "olycksstatistik",
    "olycksstatistikens": "olycksstatistik",
    "olycksstatistiker": "olycksstatistik",
    "olycksstatistikerna": "olycksstatistik",
    "olycksstatistikernas": "olycksstatistik",
    "olycksstatistikers": "olycksstatistik",
    "olycksstatistiks": "olycksstatistik",
    "olyckstalen": "olyckstal",
    "olyckstalens": "olyckstal",
    "olyckstalet": "olyckstal",
    "olyckstalets": "olyckstal",
    "olyckstals": "olyckstal",
    "olyckstrenden": "olyckstrend",
    "olyckstrendens": "olyckstrend",
    "olyckstrender": "olyckstrend",
    "olyckstrenderna": "olyckstrend",
    "olyckstrendernas": "olyckstrend",
    "olyckstrenders": "olyckstrend",
    "olyckstrends": "olyckstrend",
    "olycksöden": "olycksöde",
    "olycksödena": "olycksöde",
    "olycksödenas": "olycksöde",
    "olycksödens": "olycksöde",
    "olycksödes": "olycksöde",
    "olycksödet": "olycksöde",
    "olycksödets": "olycksöde",
    "olydiga": "olydig",
    "olydigare": "olydig",
    "olydigares": "olydig",
    "olydigas": "olydig",
    "olydigast": "olydig",
    "olydigaste": "olydig",
    "olydigastes": "olydig",
    "olydigasts": "olydig",
    "olydige": "olydig",
    "olydiges": "olydig",
    "olydigheten": "olydighet",
    "olydighetens": "olydighet",
    "olydigheter": "olydighet",
    "olydigheterna": "olydighet",
    "olydigheternas": "olydighet",
    "olydigheters": "olydighet",
    "olydighets": "olydighet",
    "olydigs": "olydig",
    "olydigt": "olydig",
    "olydigts": "olydig",
    "olydnaden": "olydnad",
    "olydnadens": "olydnad",
    "olydnader": "olydnad",
    "olydnaderna": "olydnad",
    "olydnadernas": "olydnad",
    "olydnaders": "olydnad",
    "olydnads": "olydnad",
    "olyktade": "olyktad",
    "olyktades": "olyktad",
    "olyktads": "olyktad",
    "olyktat": "olyktad",
    "olyktats": "olyktad",
    "olympiaden": "olympiad",
    "olympiadens": "olympiad",
    "olympiader": "olympiad",
    "olympiaderna": "olympiad",
    "olympiadernas": "olympiad",
    "olympiaders": "olympiad",
    "olympiads": "olympiad",
    "olympiasegrar": "olympiasegrare",
    "olympiasegraren": "olympiasegrare",
    "olympiasegrarens": "olympiasegrare",
    "olympiasegrares": "olympiasegrare",
    "olympiasegrarna": "olympiasegrare",
    "olympiasegrarnas": "olympiasegrare",
    "olympiern": "olympier",
    "olympierna": "olympier",
    "olympiernas": "olympier",
    "olympierns": "olympier",
    "olympiers": "olympier",
    "olympiska": "olympisk",
    "olympiskare": "olympisk",
    "olympiskares": "olympisk",
    "olympiskas": "olympisk",
    "olympiskast": "olympisk",
    "olympiskaste": "olympisk",
    "olympiskastes": "olympisk",
    "olympiskasts": "olympisk",
    "olympiske": "olympisk",
    "olympiskes": "olympisk",
    "olympisks": "olympisk",
    "olympiskt": "olympisk",
    "olympiskts": "olympisk",
    "olynchade": "olynchad",
    "olynchades": "olynchad",
    "olynchads": "olynchad",
    "olynchat": "olynchad",
    "olynchats": "olynchad",
    "olyrade": "olyrad",
    "olyrades": "olyrad",
    "olyrads": "olyrad",
    "olyrat": "olyrad",
    "olyrats": "olyrad",
    "olysta": "olyst",
    "olystas": "olyst",
    "olyste": "olyst",
    "olystes": "olyst",
    "olysts": "olyst",
    "olyxrenoverade": "olyxrenoverad",
    "olyxrenoverades": "olyxrenoverad",
    "olyxrenoverads": "olyxrenoverad",
    "olyxrenoverat": "olyxrenoverad",
    "olyxrenoverats": "olyxrenoverad",
    "olyxrenoverbara": "olyxrenoverbar",
    "olyxrenoverbarare": "olyxrenoverbar",
    "olyxrenoverbarares": "olyxrenoverbar",
    "olyxrenoverbaras": "olyxrenoverbar",
    "olyxrenoverbarast": "olyxrenoverbar",
    "olyxrenoverbaraste": "olyxrenoverbar",
    "olyxrenoverbarastes": "olyxrenoverbar",
    "olyxrenoverbarasts": "olyxrenoverbar",
    "olyxrenoverbare": "olyxrenoverbar",
    "olyxrenoverbares": "olyxrenoverbar",
    "olyxrenoverbarheten": "olyxrenoverbarhet",
    "olyxrenoverbarhetens": "olyxrenoverbarhet",
    "olyxrenoverbarhets": "olyxrenoverbarhet",
    "olyxrenoverbars": "olyxrenoverbar",
    "olyxrenoverbart": "olyxrenoverbar",
    "olyxrenoverbarts": "olyxrenoverbar",
    "oläckta": "oläckt",
    "oläcktas": "oläckt",
    "oläckte": "oläckt",
    "oläcktes": "oläckt",
    "oläckts": "oläckt",
    "oläderade": "oläderad",
    "oläderades": "oläderad",
    "oläderads": "oläderad",
    "oläderat": "oläderad",
    "oläderats": "oläderad",
    "oläderbara": "oläderbar",
    "oläderbarare": "oläderbar",
    "oläderbarares": "oläderbar",
    "oläderbaras": "oläderbar",
    "oläderbarast": "oläderbar",
    "oläderbaraste": "oläderbar",
    "oläderbarastes": "oläderbar",
    "oläderbarasts": "oläderbar",
    "oläderbare": "oläderbar",
    "oläderbares": "oläderbar",
    "oläderbarheten": "oläderbarhet",
    "oläderbarhetens": "oläderbarhet",
    "oläderbarhets": "oläderbarhet",
    "oläderbars": "oläderbar",
    "oläderbart": "oläderbar",
    "oläderbarts": "oläderbar",
    "olägenheten": "olägenhet",
    "olägenhetens": "olägenhet",
    "olägenheter": "olägenhet",
    "olägenheterna": "olägenhet",
    "olägenheternas": "olägenhet",
    "olägenheters": "olägenhet",
    "olägenhets": "olägenhet",
    "olägliga": "oläglig",
    "olägligare": "oläglig",
    "olägligares": "oläglig",
    "olägligas": "oläglig",
    "olägligast": "oläglig",
    "olägligaste": "oläglig",
    "olägligastes": "oläglig",
    "olägligasts": "oläglig",
    "oläglige": "oläglig",
    "olägliges": "oläglig",
    "olägligheten": "oläglighet",
    "oläglighetens": "oläglighet",
    "olägligheter": "oläglighet",
    "olägligheterna": "oläglighet",
    "olägligheternas": "oläglighet",
    "olägligheters": "oläglighet",
    "oläglighets": "oläglighet",
    "olägligs": "oläglig",
    "olägligt": "oläglig",
    "olägligts": "oläglig",
    "olägrade": "olägrad",
    "olägrades": "olägrad",
    "olägrads": "olägrad",
    "olägrat": "olägrad",
    "olägrats": "olägrad",
    "oläkliga": "oläklig",
    "oläkligare": "oläklig",
    "oläkligares": "oläklig",
    "oläkligas": "oläklig",
    "oläkligast": "oläklig",
    "oläkligaste": "oläklig",
    "oläkligastes": "oläklig",
    "oläkligasts": "oläklig",
    "oläklige": "oläklig",
    "oläkliges": "oläklig",
    "oläkligheten": "oläklighet",
    "oläklighetens": "oläklighet",
    "oläklighets": "oläklighet",
    "oläkligs": "oläklig",
    "oläkligt": "oläklig",
    "oläkligts": "oläklig",
    "oläkta": "oläkt",
    "oläktas": "oläkt",
    "oläkte": "oläkt",
    "oläktes": "oläkt",
    "oläktrade": "oläktrad",
    "oläktrades": "oläktrad",
    "oläktrads": "oläktrad",
    "oläktrat": "oläktrad",
    "oläktrats": "oläktrad",
    "oläkts": "oläkt",
    "olämnade": "olämnad",
    "olämnades": "olämnad",
    "olämnads": "olämnad",
    "olämnat": "olämnad",
    "olämnats": "olämnad",
    "olämpade": "olämpad",
    "olämpades": "olämpad",
    "olämpads": "olämpad",
    "olämpat": "olämpad",
    "olämpats": "olämpad",
    "olämpliga": "olämplig",
    "olämpligare": "olämplig",
    "olämpligares": "olämplig",
    "olämpligas": "olämplig",
    "olämpligast": "olämplig",
    "olämpligaste": "olämplig",
    "olämpligastes": "olämplig",
    "olämpligasts": "olämplig",
    "olämplige": "olämplig",
    "olämpliges": "olämplig",
    "olämpligheten": "olämplighet",
    "olämplighetens": "olämplighet",
    "olämplighets": "olämplighet",
    "olämpligs": "olämplig",
    "olämpligt": "olämplig",
    "olämpligts": "olämplig",
    "olämporna": "olämpor",
    "olämpornas": "olämpor",
    "olämpors": "olämpor",
    "oländiga": "oländig",
    "oländigare": "oländig",
    "oländigares": "oländig",
    "oländigas": "oländig",
    "oländigast": "oländig",
    "oländigaste": "oländig",
    "oländigastes": "oländig",
    "oländigasts": "oländig",
    "oländige": "oländig",
    "oländiges": "oländig",
    "oländigheten": "oländighet",
    "oländighetens": "oländighet",
    "oländighets": "oländighet",
    "oländigs": "oländig",
    "oländigt": "oländig",
    "oländigts": "oländig",
    "olängde": "olängd",
    "olängdes": "olängd",
    "olängdheten": "olängdhet",
    "olängdhetens": "olängdhet",
    "olängdhets": "olängdhet",
    "olängds": "olängd",
    "olängt": "olängd",
    "olängts": "olängd",
    "olänkade": "olänkad",
    "olänkades": "olänkad",
    "olänkads": "olänkad",
    "olänkat": "olänkad",
    "olänkats": "olänkad",
    "olänsade": "olänsad",
    "olänsades": "olänsad",
    "olänsads": "olänsad",
    "olänsat": "olänsad",
    "olänsats": "olänsad",
    "olärda": "olärd",
    "olärdare": "olärd",
    "olärdares": "olärd",
    "olärdas": "olärd",
    "olärdast": "olärd",
    "olärdaste": "olärd",
    "olärdastes": "olärd",
    "olärdasts": "olärd",
    "olärde": "olärd",
    "olärdes": "olärd",
    "olärdheten": "olärdhet",
    "olärdhetens": "olärdhet",
    "olärdhets": "olärdhet",
    "olärds": "olärd",
    "olärt": "olärd",
    "olärts": "olärd",
    "oläsbara": "oläsbar",
    "oläsbarare": "oläsbar",
    "oläsbarares": "oläsbar",
    "oläsbaras": "oläsbar",
    "oläsbarast": "oläsbar",
    "oläsbaraste": "oläsbar",
    "oläsbarastes": "oläsbar",
    "oläsbarasts": "oläsbar",
    "oläsbare": "oläsbar",
    "oläsbares": "oläsbar",
    "oläsbarheten": "oläsbarhet",
    "oläsbarhetens": "oläsbarhet",
    "oläsbarhets": "oläsbarhet",
    "oläsbars": "oläsbar",
    "oläsbart": "oläsbar",
    "oläsbarts": "oläsbar",
    "oläskade": "oläskad",
    "oläskades": "oläskad",
    "oläskads": "oläskad",
    "oläskat": "oläskad",
    "oläskats": "oläskad",
    "oläsliga": "oläslig",
    "oläsligare": "oläslig",
    "oläsligares": "oläslig",
    "oläsligas": "oläslig",
    "oläsligast": "oläslig",
    "oläsligaste": "oläslig",
    "oläsligastes": "oläslig",
    "oläsligasts": "oläslig",
    "oläslige": "oläslig",
    "oläsliges": "oläslig",
    "oläsligheten": "oläslighet",
    "oläslighetens": "oläslighet",
    "oläslighets": "oläslighet",
    "oläsligs": "oläslig",
    "oläsligt": "oläslig",
    "oläsligts": "oläslig",
    "olästa": "oläst",
    "olästas": "oläst",
    "oläste": "oläst",
    "olästes": "oläst",
    "olästs": "oläst",
    "olättade": "olättad",
    "olättades": "olättad",
    "olättads": "olättad",
    "olättat": "olättad",
    "olättats": "olättad",
    "olättrade": "olättrad",
    "olättrades": "olättrad",
    "olättrads": "olättrad",
    "olättrat": "olättrad",
    "olättrats": "olättrad",
    "olånade": "olånad",
    "olånades": "olånad",
    "olånads": "olånad",
    "olånat": "olånad",
    "olånats": "olånad",
    "olåssade": "olåssad",
    "olåssades": "olåssad",
    "olåssads": "olåssad",
    "olåssat": "olåssad",
    "olåssats": "olåssad",
    "olåsta": "olåst",
    "olåstare": "olåst",
    "olåstares": "olåst",
    "olåstas": "olåst",
    "olåstast": "olåst",
    "olåstaste": "olåst",
    "olåstastes": "olåst",
    "olåstasts": "olåst",
    "olåste": "olåst",
    "olåstes": "olåst",
    "olåsts": "olåst",
    "olåten": "olåt",
    "olåtens": "olåt",
    "olåts": "olåt",
    "olåtsade": "olåtsad",
    "olåtsades": "olåtsad",
    "olåtsads": "olåtsad",
    "olåtsat": "olåtsad",
    "olåtsats": "olåtsad",
    "olögade": "olögad",
    "olögades": "olögad",
    "olögads": "olögad",
    "olögat": "olögad",
    "olögats": "olögad",
    "olönade": "olönad",
    "olönades": "olönad",
    "olönads": "olönad",
    "olönat": "olönad",
    "olönats": "olönad",
    "olönsamheten": "olönsamhet",
    "olönsamhetens": "olönsamhet",
    "olönsamhets": "olönsamhet",
    "olönsamma": "olönsam",
    "olönsammare": "olönsam",
    "olönsammares": "olönsam",
    "olönsammas": "olönsam",
    "olönsammast": "olönsam",
    "olönsammaste": "olönsam",
    "olönsammastes": "olönsam",
    "olönsammasts": "olönsam",
    "olönsamme": "olönsam",
    "olönsammes": "olönsam",
    "olönsams": "olönsam",
    "olönsamt": "olönsam",
    "olönsamts": "olönsam",
    "olönta": "olönt",
    "olöntare": "olönt",
    "olöntares": "olönt",
    "olöntas": "olönt",
    "olöntast": "olönt",
    "olöntaste": "olönt",
    "olöntastes": "olönt",
    "olöntasts": "olönt",
    "olönte": "olönt",
    "olöntes": "olönt",
    "olönts": "olönt",
    "olösbara": "olösbar",
    "olösbarare": "olösbar",
    "olösbarares": "olösbar",
    "olösbaras": "olösbar",
    "olösbarast": "olösbar",
    "olösbaraste": "olösbar",
    "olösbarastes": "olösbar",
    "olösbarasts": "olösbar",
    "olösbare": "olösbar",
    "olösbares": "olösbar",
    "olösbarheten": "olösbarhet",
    "olösbarhetens": "olösbarhet",
    "olösbarhets": "olösbarhet",
    "olösbars": "olösbar",
    "olösbart": "olösbar",
    "olösbarts": "olösbar",
    "olösliga": "olöslig",
    "olösligare": "olöslig",
    "olösligares": "olöslig",
    "olösligas": "olöslig",
    "olösligast": "olöslig",
    "olösligaste": "olöslig",
    "olösligastes": "olöslig",
    "olösligasts": "olöslig",
    "olöslige": "olöslig",
    "olösliges": "olöslig",
    "olösligheten": "olöslighet",
    "olöslighetens": "olöslighet",
    "olöslighets": "olöslighet",
    "olösligs": "olöslig",
    "olösligt": "olöslig",
    "olösligts": "olöslig",
    "olösta": "olöst",
    "olöstare": "olöst",
    "olöstares": "olöst",
    "olöstas": "olöst",
    "olöstast": "olöst",
    "olöstaste": "olöst",
    "olöstastes": "olöst",
    "olöstasts": "olöst",
    "olöste": "olöst",
    "olöstes": "olöst",
    "olösts": "olöst",
    "olövade": "olövad",
    "olövades": "olövad",
    "olövads": "olövad",
    "olövat": "olövad",
    "olövats": "olövad",
    "omadrasserade": "omadrasserad",
    "omadrasserades": "omadrasserad",
    "omadrasserads": "omadrasserad",
    "omadrasserat": "omadrasserad",
    "omadrasserats": "omadrasserad",
    "omadrasserbara": "omadrasserbar",
    "omadrasserbarare": "omadrasserbar",
    "omadrasserbarares": "omadrasserbar",
    "omadrasserbaras": "omadrasserbar",
    "omadrasserbarast": "omadrasserbar",
    "omadrasserbaraste": "omadrasserbar",
    "omadrasserbarastes": "omadrasserbar",
    "omadrasserbarasts": "omadrasserbar",
    "omadrasserbare": "omadrasserbar",
    "omadrasserbares": "omadrasserbar",
    "omadrasserbarheten": "omadrasserbarhet",
    "omadrasserbarhetens": "omadrasserbarhet",
    "omadrasserbarhets": "omadrasserbarhet",
    "omadrasserbars": "omadrasserbar",
    "omadrasserbart": "omadrasserbar",
    "omadrasserbarts": "omadrasserbar",
    "omagasinerade": "omagasinerad",
    "omagasinerades": "omagasinerad",
    "omagasinerads": "omagasinerad",
    "omagasinerat": "omagasinerad",
    "omagasinerats": "omagasinerad",
    "omagasinerbara": "omagasinerbar",
    "omagasinerbarare": "omagasinerbar",
    "omagasinerbarares": "omagasinerbar",
    "omagasinerbaras": "omagasinerbar",
    "omagasinerbarast": "omagasinerbar",
    "omagasinerbaraste": "omagasinerbar",
    "omagasinerbarastes": "omagasinerbar",
    "omagasinerbarasts": "omagasinerbar",
    "omagasinerbare": "omagasinerbar",
    "omagasinerbares": "omagasinerbar",
    "omagasinerbarheten": "omagasinerbarhet",
    "omagasinerbarhetens": "omagasinerbarhet",
    "omagasinerbarhets": "omagasinerbarhet",
    "omagasinerbars": "omagasinerbar",
    "omagasinerbart": "omagasinerbar",
    "omagasinerbarts": "omagasinerbar",
    "omagnetiserade": "omagnetiserad",
    "omagnetiserades": "omagnetiserad",
    "omagnetiserads": "omagnetiserad",
    "omagnetiserat": "omagnetiserad",
    "omagnetiserats": "omagnetiserad",
    "omagnetiserbara": "omagnetiserbar",
    "omagnetiserbarare": "omagnetiserbar",
    "omagnetiserbarares": "omagnetiserbar",
    "omagnetiserbaras": "omagnetiserbar",
    "omagnetiserbarast": "omagnetiserbar",
    "omagnetiserbaraste": "omagnetiserbar",
    "omagnetiserbarastes": "omagnetiserbar",
    "omagnetiserbarasts": "omagnetiserbar",
    "omagnetiserbare": "omagnetiserbar",
    "omagnetiserbares": "omagnetiserbar",
    "omagnetiserbarheten": "omagnetiserbarhet",
    "omagnetiserbarhetens": "omagnetiserbarhet",
    "omagnetiserbarhets": "omagnetiserbarhet",
    "omagnetiserbars": "omagnetiserbar",
    "omagnetiserbart": "omagnetiserbar",
    "omagnetiserbarts": "omagnetiserbar",
    "omailade": "omailad",
    "omailades": "omailad",
    "omailads": "omailad",
    "omailat": "omailad",
    "omailats": "omailad",
    "omajade": "omajad",
    "omajades": "omajad",
    "omajads": "omajad",
    "omajat": "omajad",
    "omajats": "omajad",
    "omakade": "omakad",
    "omakades": "omakad",
    "omakads": "omakad",
    "omakat": "omakad",
    "omakats": "omakad",
    "omaket": "omak",
    "omakets": "omak",
    "omaks": "omak",
    "omakulerade": "omakulerad",
    "omakulerades": "omakulerad",
    "omakulerads": "omakulerad",
    "omakulerat": "omakulerad",
    "omakulerats": "omakulerad",
    "omakulerbara": "omakulerbar",
    "omakulerbarare": "omakulerbar",
    "omakulerbarares": "omakulerbar",
    "omakulerbaras": "omakulerbar",
    "omakulerbarast": "omakulerbar",
    "omakulerbaraste": "omakulerbar",
    "omakulerbarastes": "omakulerbar",
    "omakulerbarasts": "omakulerbar",
    "omakulerbare": "omakulerbar",
    "omakulerbares": "omakulerbar",
    "omakulerbarheten": "omakulerbarhet",
    "omakulerbarhetens": "omakulerbarhet",
    "omakulerbarhets": "omakulerbarhet",
    "omakulerbars": "omakulerbar",
    "omakulerbart": "omakulerbar",
    "omakulerbarts": "omakulerbar",
    "omalfoberade": "omalfoberad",
    "omalfoberades": "omalfoberad",
    "omalfoberads": "omalfoberad",
    "omalfoberat": "omalfoberad",
    "omalfoberats": "omalfoberad",
    "omalfoberbara": "omalfoberbar",
    "omalfoberbarare": "omalfoberbar",
    "omalfoberbarares": "omalfoberbar",
    "omalfoberbaras": "omalfoberbar",
    "omalfoberbarast": "omalfoberbar",
    "omalfoberbaraste": "omalfoberbar",
    "omalfoberbarastes": "omalfoberbar",
    "omalfoberbarasts": "omalfoberbar",
    "omalfoberbare": "omalfoberbar",
    "omalfoberbares": "omalfoberbar",
    "omalfoberbarheten": "omalfoberbarhet",
    "omalfoberbarhetens": "omalfoberbarhet",
    "omalfoberbarhets": "omalfoberbarhet",
    "omalfoberbars": "omalfoberbar",
    "omalfoberbart": "omalfoberbar",
    "omalfoberbarts": "omalfoberbar",
    "omalmade": "omalmad",
    "omalmades": "omalmad",
    "omalmads": "omalmad",
    "omalmat": "omalmad",
    "omalmats": "omalmad",
    "omalträterade": "omalträterad",
    "omalträterades": "omalträterad",
    "omalträterads": "omalträterad",
    "omalträterat": "omalträterad",
    "omalträterats": "omalträterad",
    "omalträterbara": "omalträterbar",
    "omalträterbarare": "omalträterbar",
    "omalträterbarares": "omalträterbar",
    "omalträterbaras": "omalträterbar",
    "omalträterbarast": "omalträterbar",
    "omalträterbaraste": "omalträterbar",
    "omalträterbarastes": "omalträterbar",
    "omalträterbarasts": "omalträterbar",
    "omalträterbare": "omalträterbar",
    "omalträterbares": "omalträterbar",
    "omalträterbarheten": "omalträterbarhet",
    "omalträterbarhetens": "omalträterbarhet",
    "omalträterbarhets": "omalträterbarhet",
    "omalträterbars": "omalträterbar",
    "omalträterbart": "omalträterbar",
    "omalträterbarts": "omalträterbar",
    "omanade": "omanad",
    "omanades": "omanad",
    "omanads": "omanad",
    "omanat": "omanad",
    "omanats": "omanad",
    "omanglade": "omanglad",
    "omanglades": "omanglad",
    "omanglads": "omanglad",
    "omanglat": "omanglad",
    "omanglats": "omanglad",
    "omaniern": "omanier",
    "omanierna": "omanier",
    "omaniernas": "omanier",
    "omanierns": "omanier",
    "omaniers": "omanier",
    "omanifesterade": "omanifesterad",
    "omanifesterades": "omanifesterad",
    "omanifesterads": "omanifesterad",
    "omanifesterat": "omanifesterad",
    "omanifesterats": "omanifesterad",
    "omanifesterbara": "omanifesterbar",
    "omanifesterbarare": "omanifesterbar",
    "omanifesterbarares": "omanifesterbar",
    "omanifesterbaras": "omanifesterbar",
    "omanifesterbarast": "omanifesterbar",
    "omanifesterbaraste": "omanifesterbar",
    "omanifesterbarastes": "omanifesterbar",
    "omanifesterbarasts": "omanifesterbar",
    "omanifesterbare": "omanifesterbar",
    "omanifesterbares": "omanifesterbar",
    "omanifesterbarheten": "omanifesterbarhet",
    "omanifesterbarhetens": "omanifesterbarhet",
    "omanifesterbarhets": "omanifesterbarhet",
    "omanifesterbars": "omanifesterbar",
    "omanifesterbart": "omanifesterbar",
    "omanifesterbarts": "omanifesterbar",
    "omanikurerade": "omanikurerad",
    "omanikurerades": "omanikurerad",
    "omanikurerads": "omanikurerad",
    "omanikurerat": "omanikurerad",
    "omanikurerats": "omanikurerad",
    "omanikurerbara": "omanikurerbar",
    "omanikurerbarare": "omanikurerbar",
    "omanikurerbarares": "omanikurerbar",
    "omanikurerbaras": "omanikurerbar",
    "omanikurerbarast": "omanikurerbar",
    "omanikurerbaraste": "omanikurerbar",
    "omanikurerbarastes": "omanikurerbar",
    "omanikurerbarasts": "omanikurerbar",
    "omanikurerbare": "omanikurerbar",
    "omanikurerbares": "omanikurerbar",
    "omanikurerbarheten": "omanikurerbarhet",
    "omanikurerbarhetens": "omanikurerbarhet",
    "omanikurerbarhets": "omanikurerbarhet",
    "omanikurerbars": "omanikurerbar",
    "omanikurerbart": "omanikurerbar",
    "omanikurerbarts": "omanikurerbar",
    "omanikyrerade": "omanikyrerad",
    "omanikyrerades": "omanikyrerad",
    "omanikyrerads": "omanikyrerad",
    "omanikyrerat": "omanikyrerad",
    "omanikyrerats": "omanikyrerad",
    "omanikyrerbara": "omanikyrerbar",
    "omanikyrerbarare": "omanikyrerbar",
    "omanikyrerbarares": "omanikyrerbar",
    "omanikyrerbaras": "omanikyrerbar",
    "omanikyrerbarast": "omanikyrerbar",
    "omanikyrerbaraste": "omanikyrerbar",
    "omanikyrerbarastes": "omanikyrerbar",
    "omanikyrerbarasts": "omanikyrerbar",
    "omanikyrerbare": "omanikyrerbar",
    "omanikyrerbares": "omanikyrerbar",
    "omanikyrerbarheten": "omanikyrerbarhet",
    "omanikyrerbarhetens": "omanikyrerbarhet",
    "omanikyrerbarhets": "omanikyrerbarhet",
    "omanikyrerbars": "omanikyrerbar",
    "omanikyrerbart": "omanikyrerbar",
    "omanikyrerbarts": "omanikyrerbar",
    "omanipulerade": "omanipulerad",
    "omanipulerades": "omanipulerad",
    "omanipulerads": "omanipulerad",
    "omanipulerat": "omanipulerad",
    "omanipulerats": "omanipulerad",
    "omanipulerbara": "omanipulerbar",
    "omanipulerbarare": "omanipulerbar",
    "omanipulerbarares": "omanipulerbar",
    "omanipulerbaras": "omanipulerbar",
    "omanipulerbarast": "omanipulerbar",
    "omanipulerbaraste": "omanipulerbar",
    "omanipulerbarastes": "omanipulerbar",
    "omanipulerbarasts": "omanipulerbar",
    "omanipulerbare": "omanipulerbar",
    "omanipulerbares": "omanipulerbar",
    "omanipulerbarheten": "omanipulerbarhet",
    "omanipulerbarhetens": "omanipulerbarhet",
    "omanipulerbarhets": "omanipulerbarhet",
    "omanipulerbars": "omanipulerbar",
    "omanipulerbart": "omanipulerbar",
    "omanipulerbarts": "omanipulerbar",
    "omanliga": "omanlig",
    "omanligare": "omanlig",
    "omanligares": "omanlig",
    "omanligas": "omanlig",
    "omanligast": "omanlig",
    "omanligaste": "omanlig",
    "omanligastes": "omanlig",
    "omanligasts": "omanlig",
    "omanlige": "omanlig",
    "omanliges": "omanlig",
    "omanligheten": "omanlighet",
    "omanlighetens": "omanlighet",
    "omanlighets": "omanlighet",
    "omanligs": "omanlig",
    "omanligt": "omanlig",
    "omanligts": "omanlig",
    "omanska": "omansk",
    "omanskan": "omanska",
    "omanskans": "omanska",
    "omanskare": "omansk",
    "omanskares": "omansk",
    "omanskas": "omanska",
    "omanskast": "omansk",
    "omanskaste": "omansk",
    "omanskastes": "omansk",
    "omanskasts": "omansk",
    "omanske": "omanska",
    "omanskes": "omansk",
    "omanskor": "omanska",
    "omanskorna": "omanska",
    "omanskornas": "omanska",
    "omanskors": "omanska",
    "omansks": "omansk",
    "omanskt": "omansk",
    "omanskts": "omansk",
    "omantlade": "omantlad",
    "omantlades": "omantlad",
    "omantlads": "omantlad",
    "omantlat": "omantlad",
    "omantlats": "omantlad",
    "omanövrerade": "omanövrerad",
    "omanövrerades": "omanövrerad",
    "omanövrerads": "omanövrerad",
    "omanövrerat": "omanövrerad",
    "omanövrerats": "omanövrerad",
    "omanövrerbara": "omanövrerbar",
    "omanövrerbarare": "omanövrerbar",
    "omanövrerbarares": "omanövrerbar",
    "omanövrerbaras": "omanövrerbar",
    "omanövrerbarast": "omanövrerbar",
    "omanövrerbaraste": "omanövrerbar",
    "omanövrerbarastes": "omanövrerbar",
    "omanövrerbarasts": "omanövrerbar",
    "omanövrerbare": "omanövrerbar",
    "omanövrerbares": "omanövrerbar",
    "omanövrerbarheten": "omanövrerbarhet",
    "omanövrerbarhetens": "omanövrerbarhet",
    "omanövrerbarhets": "omanövrerbarhet",
    "omanövrerbars": "omanövrerbar",
    "omanövrerbart": "omanövrerbar",
    "omanövrerbarts": "omanövrerbar",
    "omarbet": "omarbeta",
    "omarbetad": "omarbeta",
    "omarbetade": "omarbeta",
    "omarbetades": "omarbeta",
    "omarbetads": "omarbeta",
    "omarbetande": "omarbeta",
    "omarbetanden": "omarbetande",
    "omarbetandena": "omarbetande",
    "omarbetandenas": "omarbetande",
    "omarbetandens": "omarbetande",
    "omarbetandes": "omarbetande",
    "omarbetandet": "omarbetande",
    "omarbetandets": "omarbetande",
    "omarbetar": "omarbeta",
    "omarbetas": "omarbeta",
    "omarbetat": "omarbeta",
    "omarbetats": "omarbeta",
    "omarbetningar": "omarbetning",
    "omarbetningarna": "omarbetning",
    "omarbetningarnas": "omarbetning",
    "omarbetningars": "omarbetning",
    "omarbetningen": "omarbetning",
    "omarbetningens": "omarbetning",
    "omarbetnings": "omarbetning",
    "omarginaliserade": "omarginaliserad",
    "omarginaliserades": "omarginaliserad",
    "omarginaliserads": "omarginaliserad",
    "omarginaliserat": "omarginaliserad",
    "omarginaliserats": "omarginaliserad",
    "omarginaliserbara": "omarginaliserbar",
    "omarginaliserbarare": "omarginaliserbar",
    "omarginaliserbarares": "omarginaliserbar",
    "omarginaliserbaras": "omarginaliserbar",
    "omarginaliserbarast": "omarginaliserbar",
    "omarginaliserbaraste": "omarginaliserbar",
    "omarginaliserbarastes": "omarginaliserbar",
    "omarginaliserbarasts": "omarginaliserbar",
    "omarginaliserbare": "omarginaliserbar",
    "omarginaliserbares": "omarginaliserbar",
    "omarginaliserbarheten": "omarginaliserbarhet",
    "omarginaliserbarhetens": "omarginaliserbarhet",
    "omarginaliserbarhets": "omarginaliserbarhet",
    "omarginaliserbars": "omarginaliserbar",
    "omarginaliserbart": "omarginaliserbar",
    "omarginaliserbarts": "omarginaliserbar",
    "omarinerade": "omarinerad",
    "omarinerades": "omarinerad",
    "omarinerads": "omarinerad",
    "omarinerat": "omarinerad",
    "omarinerats": "omarinerad",
    "omarinerbara": "omarinerbar",
    "omarinerbarare": "omarinerbar",
    "omarinerbarares": "omarinerbar",
    "omarinerbaras": "omarinerbar",
    "omarinerbarast": "omarinerbar",
    "omarinerbaraste": "omarinerbar",
    "omarinerbarastes": "omarinerbar",
    "omarinerbarasts": "omarinerbar",
    "omarinerbare": "omarinerbar",
    "omarinerbares": "omarinerbar",
    "omarinerbarheten": "omarinerbarhet",
    "omarinerbarhetens": "omarinerbarhet",
    "omarinerbarhets": "omarinerbarhet",
    "omarinerbars": "omarinerbar",
    "omarinerbart": "omarinerbar",
    "omarinerbarts": "omarinerbar",
    "omarkerade": "omarkerad",
    "omarkerades": "omarkerad",
    "omarkerads": "omarkerad",
    "omarkerat": "omarkerad",
    "omarkerats": "omarkerad",
    "omarkerbara": "omarkerbar",
    "omarkerbarare": "omarkerbar",
    "omarkerbarares": "omarkerbar",
    "omarkerbaras": "omarkerbar",
    "omarkerbarast": "omarkerbar",
    "omarkerbaraste": "omarkerbar",
    "omarkerbarastes": "omarkerbar",
    "omarkerbarasts": "omarkerbar",
    "omarkerbare": "omarkerbar",
    "omarkerbares": "omarkerbar",
    "omarkerbarheten": "omarkerbarhet",
    "omarkerbarhetens": "omarkerbarhet",
    "omarkerbarhets": "omarkerbarhet",
    "omarkerbars": "omarkerbar",
    "omarkerbart": "omarkerbar",
    "omarkerbarts": "omarkerbar",
    "omarmorerade": "omarmorerad",
    "omarmorerades": "omarmorerad",
    "omarmorerads": "omarmorerad",
    "omarmorerat": "omarmorerad",
    "omarmorerats": "omarmorerad",
    "omarmorerbara": "omarmorerbar",
    "omarmorerbarare": "omarmorerbar",
    "omarmorerbarares": "omarmorerbar",
    "omarmorerbaras": "omarmorerbar",
    "omarmorerbarast": "omarmorerbar",
    "omarmorerbaraste": "omarmorerbar",
    "omarmorerbarastes": "omarmorerbar",
    "omarmorerbarasts": "omarmorerbar",
    "omarmorerbare": "omarmorerbar",
    "omarmorerbares": "omarmorerbar",
    "omarmorerbarheten": "omarmorerbarhet",
    "omarmorerbarhetens": "omarmorerbarhet",
    "omarmorerbarhets": "omarmorerbarhet",
    "omarmorerbars": "omarmorerbar",
    "omarmorerbart": "omarmorerbar",
    "omarmorerbarts": "omarmorerbar",
    "omarscherbara": "omarscherbar",
    "omarscherbarare": "omarscherbar",
    "omarscherbarares": "omarscherbar",
    "omarscherbaras": "omarscherbar",
    "omarscherbarast": "omarscherbar",
    "omarscherbaraste": "omarscherbar",
    "omarscherbarastes": "omarscherbar",
    "omarscherbarasts": "omarscherbar",
    "omarscherbare": "omarscherbar",
    "omarscherbares": "omarscherbar",
    "omarscherbarheten": "omarscherbarhet",
    "omarscherbarhetens": "omarscherbarhet",
    "omarscherbarhets": "omarscherbarhet",
    "omarscherbars": "omarscherbar",
    "omarscherbart": "omarscherbar",
    "omarscherbarts": "omarscherbar",
    "omarterade": "omarterad",
    "omarterades": "omarterad",
    "omarterads": "omarterad",
    "omarterat": "omarterad",
    "omarterats": "omarterad",
    "omarterbara": "omarterbar",
    "omarterbarare": "omarterbar",
    "omarterbarares": "omarterbar",
    "omarterbaras": "omarterbar",
    "omarterbarast": "omarterbar",
    "omarterbaraste": "omarterbar",
    "omarterbarastes": "omarterbar",
    "omarterbarasts": "omarterbar",
    "omarterbare": "omarterbar",
    "omarterbares": "omarterbar",
    "omarterbarheten": "omarterbarhet",
    "omarterbarhetens": "omarterbarhet",
    "omarterbarhets": "omarterbarhet",
    "omarterbars": "omarterbar",
    "omarterbart": "omarterbar",
    "omarterbarts": "omarterbar",
    "omasade": "omasad",
    "omasades": "omasad",
    "omasads": "omasad",
    "omasat": "omasad",
    "omasats": "omasad",
    "omaskade": "omaskad",
    "omaskades": "omaskad",
    "omaskads": "omaskad",
    "omaskat": "omaskad",
    "omaskats": "omaskad",
    "omaskerade": "omaskerad",
    "omaskerades": "omaskerad",
    "omaskerads": "omaskerad",
    "omaskerat": "omaskerad",
    "omaskerats": "omaskerad",
    "omaskerbara": "omaskerbar",
    "omaskerbarare": "omaskerbar",
    "omaskerbarares": "omaskerbar",
    "omaskerbaras": "omaskerbar",
    "omaskerbarast": "omaskerbar",
    "omaskerbaraste": "omaskerbar",
    "omaskerbarastes": "omaskerbar",
    "omaskerbarasts": "omaskerbar",
    "omaskerbare": "omaskerbar",
    "omaskerbares": "omaskerbar",
    "omaskerbarheten": "omaskerbarhet",
    "omaskerbarhetens": "omaskerbarhet",
    "omaskerbarhets": "omaskerbarhet",
    "omaskerbars": "omaskerbar",
    "omaskerbart": "omaskerbar",
    "omaskerbarts": "omaskerbar",
    "omaskuliniserade": "omaskuliniserad",
    "omaskuliniserades": "omaskuliniserad",
    "omaskuliniserads": "omaskuliniserad",
    "omaskuliniserat": "omaskuliniserad",
    "omaskuliniserats": "omaskuliniserad",
    "omaskuliniserbara": "omaskuliniserbar",
    "omaskuliniserbarare": "omaskuliniserbar",
    "omaskuliniserbarares": "omaskuliniserbar",
    "omaskuliniserbaras": "omaskuliniserbar",
    "omaskuliniserbarast": "omaskuliniserbar",
    "omaskuliniserbaraste": "omaskuliniserbar",
    "omaskuliniserbarastes": "omaskuliniserbar",
    "omaskuliniserbarasts": "omaskuliniserbar",
    "omaskuliniserbare": "omaskuliniserbar",
    "omaskuliniserbares": "omaskuliniserbar",
    "omaskuliniserbarheten": "omaskuliniserbarhet",
    "omaskuliniserbarhetens": "omaskuliniserbarhet",
    "omaskuliniserbarhets": "omaskuliniserbarhet",
    "omaskuliniserbars": "omaskuliniserbar",
    "omaskuliniserbart": "omaskuliniserbar",
    "omaskuliniserbarts": "omaskuliniserbar",
    "omassakrerade": "omassakrerad",
    "omassakrerades": "omassakrerad",
    "omassakrerads": "omassakrerad",
    "omassakrerat": "omassakrerad",
    "omassakrerats": "omassakrerad",
    "omassakrerbara": "omassakrerbar",
    "omassakrerbarare": "omassakrerbar",
    "omassakrerbarares": "omassakrerbar",
    "omassakrerbaras": "omassakrerbar",
    "omassakrerbarast": "omassakrerbar",
    "omassakrerbaraste": "omassakrerbar",
    "omassakrerbarastes": "omassakrerbar",
    "omassakrerbarasts": "omassakrerbar",
    "omassakrerbare": "omassakrerbar",
    "omassakrerbares": "omassakrerbar",
    "omassakrerbarheten": "omassakrerbarhet",
    "omassakrerbarhetens": "omassakrerbarhet",
    "omassakrerbarhets": "omassakrerbarhet",
    "omassakrerbars": "omassakrerbar",
    "omassakrerbart": "omassakrerbar",
    "omassakrerbarts": "omassakrerbar",
    "omasserade": "omasserad",
    "omasserades": "omasserad",
    "omasserads": "omasserad",
    "omasserat": "omasserad",
    "omasserats": "omasserad",
    "omasserbara": "omasserbar",
    "omasserbarare": "omasserbar",
    "omasserbarares": "omasserbar",
    "omasserbaras": "omasserbar",
    "omasserbarast": "omasserbar",
    "omasserbaraste": "omasserbar",
    "omasserbarastes": "omasserbar",
    "omasserbarasts": "omasserbar",
    "omasserbare": "omasserbar",
    "omasserbares": "omasserbar",
    "omasserbarheten": "omasserbarhet",
    "omasserbarhetens": "omasserbarhet",
    "omasserbarhets": "omasserbarhet",
    "omasserbars": "omasserbar",
    "omasserbart": "omasserbar",
    "omasserbarts": "omasserbar",
    "omastade": "omastad",
    "omastades": "omastad",
    "omastads": "omastad",
    "omastat": "omastad",
    "omastats": "omastad",
    "omatade": "omatad",
    "omatades": "omatad",
    "omatads": "omatad",
    "omatat": "omatad",
    "omatats": "omatad",
    "omatchade": "omatchad",
    "omatchades": "omatchad",
    "omatchads": "omatchad",
    "omatchat": "omatchad",
    "omatchats": "omatchad",
    "omatelasserade": "omatelasserad",
    "omatelasserades": "omatelasserad",
    "omatelasserads": "omatelasserad",
    "omatelasserat": "omatelasserad",
    "omatelasserats": "omatelasserad",
    "omatelasserbara": "omatelasserbar",
    "omatelasserbarare": "omatelasserbar",
    "omatelasserbarares": "omatelasserbar",
    "omatelasserbaras": "omatelasserbar",
    "omatelasserbarast": "omatelasserbar",
    "omatelasserbaraste": "omatelasserbar",
    "omatelasserbarastes": "omatelasserbar",
    "omatelasserbarasts": "omatelasserbar",
    "omatelasserbare": "omatelasserbar",
    "omatelasserbares": "omatelasserbar",
    "omatelasserbarheten": "omatelasserbarhet",
    "omatelasserbarhetens": "omatelasserbarhet",
    "omatelasserbarhets": "omatelasserbarhet",
    "omatelasserbars": "omatelasserbar",
    "omatelasserbart": "omatelasserbar",
    "omatelasserbarts": "omatelasserbar",
    "omaterialiserade": "omaterialiserad",
    "omaterialiserades": "omaterialiserad",
    "omaterialiserads": "omaterialiserad",
    "omaterialiserat": "omaterialiserad",
    "omaterialiserats": "omaterialiserad",
    "omaterialiserbara": "omaterialiserbar",
    "omaterialiserbarare": "omaterialiserbar",
    "omaterialiserbarares": "omaterialiserbar",
    "omaterialiserbaras": "omaterialiserbar",
    "omaterialiserbarast": "omaterialiserbar",
    "omaterialiserbaraste": "omaterialiserbar",
    "omaterialiserbarastes": "omaterialiserbar",
    "omaterialiserbarasts": "omaterialiserbar",
    "omaterialiserbare": "omaterialiserbar",
    "omaterialiserbares": "omaterialiserbar",
    "omaterialiserbarheten": "omaterialiserbarhet",
    "omaterialiserbarhetens": "omaterialiserbarhet",
    "omaterialiserbarhets": "omaterialiserbarhet",
    "omaterialiserbars": "omaterialiserbar",
    "omaterialiserbart": "omaterialiserbar",
    "omaterialiserbarts": "omaterialiserbar",
    "omattade": "omattad",
    "omattades": "omattad",
    "omattads": "omattad",
    "omattat": "omattad",
    "omattats": "omattad",
    "omatterade": "omatterad",
    "omatterades": "omatterad",
    "omatterads": "omatterad",
    "omatterat": "omatterad",
    "omatterats": "omatterad",
    "omatterbara": "omatterbar",
    "omatterbarare": "omatterbar",
    "omatterbarares": "omatterbar",
    "omatterbaras": "omatterbar",
    "omatterbarast": "omatterbar",
    "omatterbaraste": "omatterbar",
    "omatterbarastes": "omatterbar",
    "omatterbarasts": "omatterbar",
    "omatterbare": "omatterbar",
    "omatterbares": "omatterbar",
    "omatterbarheten": "omatterbarhet",
    "omatterbarhetens": "omatterbarhet",
    "omatterbarhets": "omatterbarhet",
    "omatterbars": "omatterbar",
    "omatterbart": "omatterbar",
    "omatterbarts": "omatterbar",
    "omaxade": "omaxad",
    "omaxades": "omaxad",
    "omaxads": "omaxad",
    "omaxat": "omaxad",
    "omaxats": "omaxad",
    "omaximerade": "omaximerad",
    "omaximerades": "omaximerad",
    "omaximerads": "omaximerad",
    "omaximerat": "omaximerad",
    "omaximerats": "omaximerad",
    "omaximerbara": "omaximerbar",
    "omaximerbarare": "omaximerbar",
    "omaximerbarares": "omaximerbar",
    "omaximerbaras": "omaximerbar",
    "omaximerbarast": "omaximerbar",
    "omaximerbaraste": "omaximerbar",
    "omaximerbarastes": "omaximerbar",
    "omaximerbarasts": "omaximerbar",
    "omaximerbare": "omaximerbar",
    "omaximerbares": "omaximerbar",
    "omaximerbarheten": "omaximerbarhet",
    "omaximerbarhetens": "omaximerbarhet",
    "omaximerbarhets": "omaximerbarhet",
    "omaximerbars": "omaximerbar",
    "omaximerbart": "omaximerbar",
    "omaximerbarts": "omaximerbar",
    "ombad": "ombe",
    "ombade": "ombe",
    "ombades": "ombe",
    "ombads": "ombe",
    "ombed": "ombe",
    "ombeda": "ombe",
    "ombedande": "ombe",
    "ombedandes": "ombe",
    "ombedas": "ombe",
    "ombedd": "ombe",
    "ombedda": "ombe",
    "ombeddas": "ombe",
    "ombedde": "ombe",
    "ombeddes": "ombe",
    "ombedds": "ombe",
    "ombede": "ombe",
    "ombeder": "ombe",
    "ombedes": "ombe",
    "ombedj": "ombe",
    "ombedja": "ombe",
    "ombedjande": "ombe",
    "ombedjanden": "ombedjande",
    "ombedjandena": "ombedjande",
    "ombedjandenas": "ombedjande",
    "ombedjandens": "ombedjande",
    "ombedjandes": "ombedjande",
    "ombedjandet": "ombedjande",
    "ombedjandets": "ombedjande",
    "ombedjas": "ombe",
    "ombedje": "ombe",
    "ombedjer": "ombe",
    "ombedjes": "ombe",
    "ombeds": "ombe",
    "ombeende": "ombe",
    "ombeendes": "ombe",
    "omber": "ombe",
    "ombes": "ombe",
    "ombestyr": "ombestyra",
    "ombestyrande": "ombestyra",
    "ombestyranden": "ombestyrande",
    "ombestyrandena": "ombestyrande",
    "ombestyrandenas": "ombestyrande",
    "ombestyrandens": "ombestyrande",
    "ombestyrandes": "ombestyrande",
    "ombestyrandet": "ombestyrande",
    "ombestyrandets": "ombestyrande",
    "ombestyras": "ombestyra",
    "ombestyrd": "ombestyra",
    "ombestyrda": "ombestyra",
    "ombestyrdas": "ombestyra",
    "ombestyrde": "ombestyra",
    "ombestyrdes": "ombestyra",
    "ombestyrds": "ombestyra",
    "ombestyres": "ombestyra",
    "ombestyrs": "ombestyra",
    "ombestyrt": "ombestyra",
    "ombestyrts": "ombestyra",
    "ombesörj": "ombesörja",
    "ombesörjande": "ombesörja",
    "ombesörjanden": "ombesörjande",
    "ombesörjandena": "ombesörjande",
    "ombesörjandenas": "ombesörjande",
    "ombesörjandens": "ombesörjande",
    "ombesörjandes": "ombesörjande",
    "ombesörjandet": "ombesörjande",
    "ombesörjandets": "ombesörjande",
    "ombesörjas": "ombesörja",
    "ombesörjd": "ombesörja",
    "ombesörjda": "ombesörja",
    "ombesörjdas": "ombesörja",
    "ombesörjde": "ombesörja",
    "ombesörjdes": "ombesörja",
    "ombesörjds": "ombesörja",
    "ombesörjer": "ombesörja",
    "ombesörjes": "ombesörja",
    "ombesörjs": "ombesörja",
    "ombesörjt": "ombesörja",
    "ombesörjts": "ombesörja",
    "ombetrodd": "ombetro",
    "ombetrodda": "ombetro",
    "ombetroddas": "ombetro",
    "ombetrodde": "ombetro",
    "ombetroddes": "ombetro",
    "ombetrodds": "ombetro",
    "ombetroende": "ombetro",
    "ombetroenden": "ombetroende",
    "ombetroendena": "ombetroende",
    "ombetroendenas": "ombetroende",
    "ombetroendens": "ombetroende",
    "ombetroendes": "ombetroende",
    "ombetroendet": "ombetroende",
    "ombetroendets": "ombetroende",
    "ombetror": "ombetro",
    "ombetros": "ombetro",
    "ombetrott": "ombetro",
    "ombetrotts": "ombetro",
    "ombett": "ombe",
    "ombetts": "ombe",
    "ombild": "ombilda",
    "ombildad": "ombilda",
    "ombildade": "ombilda",
    "ombildades": "ombilda",
    "ombildads": "ombilda",
    "ombildande": "ombilda",
    "ombildanden": "ombildande",
    "ombildandena": "ombildande",
    "ombildandenas": "ombildande",
    "ombildandens": "ombildande",
    "ombildandes": "ombildande",
    "ombildandet": "ombildande",
    "ombildandets": "ombildande",
    "ombildar": "ombilda",
    "ombildas": "ombilda",
    "ombildat": "ombilda",
    "ombildats": "ombilda",
    "ombladen": "omblad",
    "ombladens": "omblad",
    "ombladet": "omblad",
    "ombladets": "omblad",
    "omblads": "omblad",
    "omblandningar": "omblandning",
    "omblandningarna": "omblandning",
    "omblandningarnas": "omblandning",
    "omblandningars": "omblandning",
    "omblandningen": "omblandning",
    "omblandningens": "omblandning",
    "omblandnings": "omblandning",
    "omblandningsprocessen": "omblandningsprocess",
    "omblandningsprocessens": "omblandningsprocess",
    "omblandningsprocesser": "omblandningsprocess",
    "omblandningsprocesserna": "omblandningsprocess",
    "omblandningsprocessernas": "omblandningsprocess",
    "omblandningsprocessers": "omblandningsprocess",
    "ombonade": "ombonad",
    "ombonades": "ombonad",
    "ombonads": "ombonad",
    "ombonat": "ombonad",
    "ombonats": "ombonad",
    "ombordläggningar": "ombordläggning",
    "ombordläggningarna": "ombordläggning",
    "ombordläggningarnas": "ombordläggning",
    "ombordläggningars": "ombordläggning",
    "ombordläggningen": "ombordläggning",
    "ombordläggningens": "ombordläggning",
    "ombordläggnings": "ombordläggning",
    "ombruten": "ombryta",
    "ombrutens": "ombryta",
    "ombrutet": "ombryta",
    "ombrutets": "ombryta",
    "ombrutit": "ombryta",
    "ombrutits": "ombryta",
    "ombrutna": "ombryta",
    "ombrutnas": "ombryta",
    "ombrutne": "ombryta",
    "ombrutnes": "ombryta",
    "ombryt": "ombryta",
    "ombrytande": "ombryta",
    "ombrytanden": "ombrytande",
    "ombrytandena": "ombrytande",
    "ombrytandenas": "ombrytande",
    "ombrytandens": "ombrytande",
    "ombrytandes": "ombrytande",
    "ombrytandet": "ombrytande",
    "ombrytandets": "ombrytande",
    "ombrytas": "ombryta",
    "ombryte": "ombryta",
    "ombryter": "ombryta",
    "ombrytes": "ombryta",
    "ombryts": "ombryta",
    "ombröt": "ombryta",
    "ombröte": "ombryta",
    "ombrötes": "ombryta",
    "ombröts": "ombryta",
    "ombuden": "ombud",
    "ombudens": "ombud",
    "ombudet": "ombud",
    "ombudets": "ombud",
    "ombuds": "ombud",
    "ombudsmannen": "ombudsman",
    "ombudsmannens": "ombudsman",
    "ombudsmans": "ombudsman",
    "ombudsmän": "ombudsman",
    "ombudsmännen": "ombudsman",
    "ombudsmännens": "ombudsman",
    "ombudsmäns": "ombudsman",
    "ombygganden": "ombyggande",
    "ombyggandena": "ombyggande",
    "ombyggandenas": "ombyggande",
    "ombyggandens": "ombyggande",
    "ombyggandes": "ombyggande",
    "ombyggandet": "ombyggande",
    "ombyggandets": "ombyggande",
    "ombyggnaden": "ombyggnad",
    "ombyggnadens": "ombyggnad",
    "ombyggnader": "ombyggnad",
    "ombyggnaderna": "ombyggnad",
    "ombyggnadernas": "ombyggnad",
    "ombyggnaders": "ombyggnad",
    "ombyggnads": "ombyggnad",
    "ombyggnationen": "ombyggnation",
    "ombyggnationens": "ombyggnation",
    "ombyggnationer": "ombyggnation",
    "ombyggnationerna": "ombyggnation",
    "ombyggnationernas": "ombyggnation",
    "ombyggnationers": "ombyggnation",
    "ombyggnations": "ombyggnation",
    "ombyten": "ombyte",
    "ombytena": "ombyte",
    "ombytenas": "ombyte",
    "ombytens": "ombyte",
    "ombytes": "ombyte",
    "ombytet": "ombyte",
    "ombytets": "ombyte",
    "ombytliga": "ombytlig",
    "ombytligare": "ombytlig",
    "ombytligares": "ombytlig",
    "ombytligas": "ombytlig",
    "ombytligast": "ombytlig",
    "ombytligaste": "ombytlig",
    "ombytligastes": "ombytlig",
    "ombytligasts": "ombytlig",
    "ombytlige": "ombytlig",
    "ombytliges": "ombytlig",
    "ombytligheten": "ombytlighet",
    "ombytlighetens": "ombytlighet",
    "ombytlighets": "ombytlighet",
    "ombytligs": "ombytlig",
    "ombytligt": "ombytlig",
    "ombytligts": "ombytlig",
    "ombytta": "ombytt",
    "ombyttare": "ombytt",
    "ombyttares": "ombytt",
    "ombyttas": "ombytt",
    "ombyttast": "ombytt",
    "ombyttaste": "ombytt",
    "ombyttastes": "ombytt",
    "ombyttasts": "ombytt",
    "ombytte": "ombytt",
    "ombyttes": "ombytt",
    "ombytts": "ombytt",
    "omdan": "omdana",
    "omdanad": "omdana",
    "omdanade": "omdana",
    "omdanades": "omdana",
    "omdanads": "omdana",
    "omdanande": "omdana",
    "omdananden": "omdanande",
    "omdanandena": "omdanande",
    "omdanandenas": "omdanande",
    "omdanandens": "omdanande",
    "omdanandes": "omdanande",
    "omdanandet": "omdanande",
    "omdanandets": "omdanande",
    "omdanar": "omdana",
    "omdanas": "omdana",
    "omdanat": "omdana",
    "omdanats": "omdana",
    "omdaningar": "omdaning",
    "omdaningarna": "omdaning",
    "omdaningarnas": "omdaning",
    "omdaningars": "omdaning",
    "omdaningen": "omdaning",
    "omdaningens": "omdaning",
    "omdanings": "omdaning",
    "omdebatterade": "omdebatterad",
    "omdebatterades": "omdebatterad",
    "omdebatterads": "omdebatterad",
    "omdebatterat": "omdebatterad",
    "omdebatterats": "omdebatterad",
    "omdirigerad": "omdirigera",
    "omdirigerade": "omdirigera",
    "omdirigerades": "omdirigera",
    "omdirigerads": "omdirigera",
    "omdirigerande": "omdirigera",
    "omdirigeranden": "omdirigerande",
    "omdirigerandena": "omdirigerande",
    "omdirigerandenas": "omdirigerande",
    "omdirigerandens": "omdirigerande",
    "omdirigerandes": "omdirigerande",
    "omdirigerandet": "omdirigerande",
    "omdirigerandets": "omdirigerande",
    "omdirigerar": "omdirigera",
    "omdirigeras": "omdirigera",
    "omdirigerat": "omdirigera",
    "omdirigerats": "omdirigera",
    "omdirigerbara": "omdirigerbar",
    "omdirigerbarare": "omdirigerbar",
    "omdirigerbarares": "omdirigerbar",
    "omdirigerbaras": "omdirigerbar",
    "omdirigerbarast": "omdirigerbar",
    "omdirigerbaraste": "omdirigerbar",
    "omdirigerbarastes": "omdirigerbar",
    "omdirigerbarasts": "omdirigerbar",
    "omdirigerbare": "omdirigerbar",
    "omdirigerbares": "omdirigerbar",
    "omdirigerbarheten": "omdirigerbarhet",
    "omdirigerbarhetens": "omdirigerbarhet",
    "omdirigerbarhets": "omdirigerbarhet",
    "omdirigerbars": "omdirigerbar",
    "omdirigerbart": "omdirigerbar",
    "omdirigerbarts": "omdirigerbar",
    "omdirigeringar": "omdirigering",
    "omdirigeringarna": "omdirigering",
    "omdirigeringarnas": "omdirigering",
    "omdirigeringars": "omdirigering",
    "omdirigeringen": "omdirigering",
    "omdirigeringens": "omdirigering",
    "omdirigerings": "omdirigering",
    "omdiskuterade": "omdiskuterad",
    "omdiskuterades": "omdiskuterad",
    "omdiskuterads": "omdiskuterad",
    "omdiskuterat": "omdiskuterad",
    "omdiskuterats": "omdiskuterad",
    "omdömen": "omdöme",
    "omdömena": "omdöme",
    "omdömenas": "omdöme",
    "omdömens": "omdöme",
    "omdömes": "omdöme",
    "omdömesfrågan": "omdömesfråga",
    "omdömesfrågans": "omdömesfråga",
    "omdömesfrågas": "omdömesfråga",
    "omdömesfråge": "omdömesfråga",
    "omdömesfrågor": "omdömesfråga",
    "omdömesfrågorna": "omdömesfråga",
    "omdömesfrågornas": "omdömesfråga",
    "omdömesfrågors": "omdömesfråga",
    "omdömesgilla": "omdömesgill",
    "omdömesgillare": "omdömesgill",
    "omdömesgillares": "omdömesgill",
    "omdömesgillas": "omdömesgill",
    "omdömesgillast": "omdömesgill",
    "omdömesgillaste": "omdömesgill",
    "omdömesgillastes": "omdömesgill",
    "omdömesgillasts": "omdömesgill",
    "omdömesgille": "omdömesgill",
    "omdömesgilles": "omdömesgill",
    "omdömesgillheten": "omdömesgillhet",
    "omdömesgillhetens": "omdömesgillhet",
    "omdömesgillheter": "omdömesgillhet",
    "omdömesgillheterna": "omdömesgillhet",
    "omdömesgillheternas": "omdömesgillhet",
    "omdömesgillheters": "omdömesgillhet",
    "omdömesgillhets": "omdömesgillhet",
    "omdömesgills": "omdömesgill",
    "omdömesgillt": "omdömesgill",
    "omdömesgillts": "omdömesgill",
    "omdömeslösa": "omdömeslös",
    "omdömeslösare": "omdömeslös",
    "omdömeslösares": "omdömeslös",
    "omdömeslösas": "omdömeslös",
    "omdömeslösast": "omdömeslös",
    "omdömeslösaste": "omdömeslös",
    "omdömeslösastes": "omdömeslös",
    "omdömeslösasts": "omdömeslös",
    "omdömeslöse": "omdömeslös",
    "omdömeslöses": "omdömeslös",
    "omdömeslösheten": "omdömeslöshet",
    "omdömeslöshetens": "omdömeslöshet",
    "omdömeslösheter": "omdömeslöshet",
    "omdömeslösheterna": "omdömeslöshet",
    "omdömeslösheternas": "omdömeslöshet",
    "omdömeslösheters": "omdömeslöshet",
    "omdömeslöshets": "omdömeslöshet",
    "omdömeslöst": "omdömeslös",
    "omdömeslösts": "omdömeslös",
    "omdömet": "omdöme",
    "omdömets": "omdöme",
    "omedaljerade": "omedaljerad",
    "omedaljerades": "omedaljerad",
    "omedaljerads": "omedaljerad",
    "omedaljerat": "omedaljerad",
    "omedaljerats": "omedaljerad",
    "omedaljerbara": "omedaljerbar",
    "omedaljerbarare": "omedaljerbar",
    "omedaljerbarares": "omedaljerbar",
    "omedaljerbaras": "omedaljerbar",
    "omedaljerbarast": "omedaljerbar",
    "omedaljerbaraste": "omedaljerbar",
    "omedaljerbarastes": "omedaljerbar",
    "omedaljerbarasts": "omedaljerbar",
    "omedaljerbare": "omedaljerbar",
    "omedaljerbares": "omedaljerbar",
    "omedaljerbarheten": "omedaljerbarhet",
    "omedaljerbarhetens": "omedaljerbarhet",
    "omedaljerbarhets": "omedaljerbarhet",
    "omedaljerbars": "omedaljerbar",
    "omedaljerbart": "omedaljerbar",
    "omedaljerbarts": "omedaljerbar",
    "omedelbara": "omedelbar",
    "omedelbarare": "omedelbar",
    "omedelbarares": "omedelbar",
    "omedelbaras": "omedelbar",
    "omedelbarast": "omedelbar",
    "omedelbaraste": "omedelbar",
    "omedelbarastes": "omedelbar",
    "omedelbarasts": "omedelbar",
    "omedelbare": "omedelbar",
    "omedelbares": "omedelbar",
    "omedelbarheten": "omedelbarhet",
    "omedelbarhetens": "omedelbarhet",
    "omedelbarhets": "omedelbarhet",
    "omedelbars": "omedelbar",
    "omedelbart": "omedelbar",
    "omedelbarts": "omedelbar",
    "omedförde": "omedförd",
    "omedfördes": "omedförd",
    "omedförds": "omedförd",
    "omedfört": "omedförd",
    "omedförts": "omedförd",
    "omedgörliga": "omedgörlig",
    "omedgörligare": "omedgörlig",
    "omedgörligares": "omedgörlig",
    "omedgörligas": "omedgörlig",
    "omedgörligast": "omedgörlig",
    "omedgörligaste": "omedgörlig",
    "omedgörligastes": "omedgörlig",
    "omedgörligasts": "omedgörlig",
    "omedgörlige": "omedgörlig",
    "omedgörliges": "omedgörlig",
    "omedgörligheten": "omedgörlighet",
    "omedgörlighetens": "omedgörlighet",
    "omedgörlighets": "omedgörlighet",
    "omedgörligs": "omedgörlig",
    "omedgörligt": "omedgörlig",
    "omedgörligts": "omedgörlig",
    "omedicinerade": "omedicinerad",
    "omedicinerades": "omedicinerad",
    "omedicinerads": "omedicinerad",
    "omedicinerat": "omedicinerad",
    "omedicinerats": "omedicinerad",
    "omedicinerbara": "omedicinerbar",
    "omedicinerbarare": "omedicinerbar",
    "omedicinerbarares": "omedicinerbar",
    "omedicinerbaras": "omedicinerbar",
    "omedicinerbarast": "omedicinerbar",
    "omedicinerbaraste": "omedicinerbar",
    "omedicinerbarastes": "omedicinerbar",
    "omedicinerbarasts": "omedicinerbar",
    "omedicinerbare": "omedicinerbar",
    "omedicinerbares": "omedicinerbar",
    "omedicinerbarheten": "omedicinerbarhet",
    "omedicinerbarhetens": "omedicinerbarhet",
    "omedicinerbarhets": "omedicinerbarhet",
    "omedicinerbars": "omedicinerbar",
    "omedicinerbart": "omedicinerbar",
    "omedicinerbarts": "omedicinerbar",
    "omedvetenheten": "omedvetenhet",
    "omedvetenhetens": "omedvetenhet",
    "omedvetenheter": "omedvetenhet",
    "omedvetenheterna": "omedvetenhet",
    "omedvetenheternas": "omedvetenhet",
    "omedvetenheters": "omedvetenhet",
    "omedvetenhets": "omedvetenhet",
    "omedvetens": "omedveten",
    "omedvetet": "omedveten",
    "omedvetets": "omedveten",
    "omedvetna": "omedveten",
    "omedvetnare": "omedveten",
    "omedvetnares": "omedveten",
    "omedvetnas": "omedveten",
    "omedvetnast": "omedveten",
    "omedvetnaste": "omedveten",
    "omedvetnastes": "omedveten",
    "omedvetnasts": "omedveten",
    "omedvetne": "omedveten",
    "omedvetnes": "omedveten",
    "omegan": "omega",
    "omegana": "omega",
    "omeganas": "omega",
    "omegans": "omega",
    "omegas": "omega",
    "omegat": "omega",
    "omegats": "omega",
    "omejade": "omejad",
    "omejades": "omejad",
    "omejads": "omejad",
    "omejat": "omejad",
    "omejats": "omejad",
    "omejlade": "omejlad",
    "omejlades": "omejlad",
    "omejlads": "omejlad",
    "omejlat": "omejlad",
    "omejlats": "omejlad",
    "omejslade": "omejslad",
    "omejslades": "omejslad",
    "omejslads": "omejslad",
    "omejslat": "omejslad",
    "omejslats": "omejslad",
    "omekaniserade": "omekaniserad",
    "omekaniserades": "omekaniserad",
    "omekaniserads": "omekaniserad",
    "omekaniserat": "omekaniserad",
    "omekaniserats": "omekaniserad",
    "omekaniserbara": "omekaniserbar",
    "omekaniserbarare": "omekaniserbar",
    "omekaniserbarares": "omekaniserbar",
    "omekaniserbaras": "omekaniserbar",
    "omekaniserbarast": "omekaniserbar",
    "omekaniserbaraste": "omekaniserbar",
    "omekaniserbarastes": "omekaniserbar",
    "omekaniserbarasts": "omekaniserbar",
    "omekaniserbare": "omekaniserbar",
    "omekaniserbares": "omekaniserbar",
    "omekaniserbarheten": "omekaniserbarhet",
    "omekaniserbarhetens": "omekaniserbarhet",
    "omekaniserbarhets": "omekaniserbarhet",
    "omekaniserbars": "omekaniserbar",
    "omekaniserbart": "omekaniserbar",
    "omekaniserbarts": "omekaniserbar",
    "omeletten": "omelett",
    "omelettens": "omelett",
    "omeletter": "omelett",
    "omeletterna": "omelett",
    "omeletternas": "omelett",
    "omeletters": "omelett",
    "omeletts": "omelett",
    "omemorerade": "omemorerad",
    "omemorerades": "omemorerad",
    "omemorerads": "omemorerad",
    "omemorerat": "omemorerad",
    "omemorerats": "omemorerad",
    "omemorerbara": "omemorerbar",
    "omemorerbarare": "omemorerbar",
    "omemorerbarares": "omemorerbar",
    "omemorerbaras": "omemorerbar",
    "omemorerbarast": "omemorerbar",
    "omemorerbaraste": "omemorerbar",
    "omemorerbarastes": "omemorerbar",
    "omemorerbarasts": "omemorerbar",
    "omemorerbare": "omemorerbar",
    "omemorerbares": "omemorerbar",
    "omemorerbarheten": "omemorerbarhet",
    "omemorerbarhetens": "omemorerbarhet",
    "omemorerbarhets": "omemorerbarhet",
    "omemorerbars": "omemorerbar",
    "omemorerbart": "omemorerbar",
    "omemorerbarts": "omemorerbar",
    "omenen": "omen",
    "omenens": "omen",
    "omenet": "omen",
    "omenets": "omen",
    "omens": "omen",
    "omerceriserade": "omerceriserad",
    "omerceriserades": "omerceriserad",
    "omerceriserads": "omerceriserad",
    "omerceriserat": "omerceriserad",
    "omerceriserats": "omerceriserad",
    "omerceriserbara": "omerceriserbar",
    "omerceriserbarare": "omerceriserbar",
    "omerceriserbarares": "omerceriserbar",
    "omerceriserbaras": "omerceriserbar",
    "omerceriserbarast": "omerceriserbar",
    "omerceriserbaraste": "omerceriserbar",
    "omerceriserbarastes": "omerceriserbar",
    "omerceriserbarasts": "omerceriserbar",
    "omerceriserbare": "omerceriserbar",
    "omerceriserbares": "omerceriserbar",
    "omerceriserbarheten": "omerceriserbarhet",
    "omerceriserbarhetens": "omerceriserbarhet",
    "omerceriserbarhets": "omerceriserbarhet",
    "omerceriserbars": "omerceriserbar",
    "omerceriserbart": "omerceriserbar",
    "omerceriserbarts": "omerceriserbar",
    "omeriterade": "omeriterad",
    "omeriterades": "omeriterad",
    "omeriterads": "omeriterad",
    "omeriterat": "omeriterad",
    "omeriterats": "omeriterad",
    "omeriterbara": "omeriterbar",
    "omeriterbarare": "omeriterbar",
    "omeriterbarares": "omeriterbar",
    "omeriterbaras": "omeriterbar",
    "omeriterbarast": "omeriterbar",
    "omeriterbaraste": "omeriterbar",
    "omeriterbarastes": "omeriterbar",
    "omeriterbarasts": "omeriterbar",
    "omeriterbare": "omeriterbar",
    "omeriterbares": "omeriterbar",
    "omeriterbarheten": "omeriterbarhet",
    "omeriterbarhetens": "omeriterbarhet",
    "omeriterbarhets": "omeriterbarhet",
    "omeriterbars": "omeriterbar",
    "omeriterbart": "omeriterbar",
    "omeriterbarts": "omeriterbar",
    "omessade": "omessad",
    "omessades": "omessad",
    "omessads": "omessad",
    "omessat": "omessad",
    "omessats": "omessad",
    "ometalliserade": "ometalliserad",
    "ometalliserades": "ometalliserad",
    "ometalliserads": "ometalliserad",
    "ometalliserat": "ometalliserad",
    "ometalliserats": "ometalliserad",
    "ometalliserbara": "ometalliserbar",
    "ometalliserbarare": "ometalliserbar",
    "ometalliserbarares": "ometalliserbar",
    "ometalliserbaras": "ometalliserbar",
    "ometalliserbarast": "ometalliserbar",
    "ometalliserbaraste": "ometalliserbar",
    "ometalliserbarastes": "ometalliserbar",
    "ometalliserbarasts": "ometalliserbar",
    "ometalliserbare": "ometalliserbar",
    "ometalliserbares": "ometalliserbar",
    "ometalliserbarheten": "ometalliserbarhet",
    "ometalliserbarhetens": "ometalliserbarhet",
    "ometalliserbarhets": "ometalliserbarhet",
    "ometalliserbars": "ometalliserbar",
    "ometalliserbart": "ometalliserbar",
    "ometalliserbarts": "ometalliserbar",
    "omfamn": "omfamna",
    "omfamnad": "omfamna",
    "omfamnade": "omfamna",
    "omfamnades": "omfamna",
    "omfamnads": "omfamna",
    "omfamnande": "omfamna",
    "omfamnanden": "omfamnande",
    "omfamnandena": "omfamnande",
    "omfamnandenas": "omfamnande",
    "omfamnandens": "omfamnande",
    "omfamnandes": "omfamnande",
    "omfamnandet": "omfamnande",
    "omfamnandets": "omfamnande",
    "omfamnar": "omfamna",
    "omfamnas": "omfamna",
    "omfamnat": "omfamna",
    "omfamnats": "omfamna",
    "omfamningar": "omfamning",
    "omfamningarna": "omfamning",
    "omfamningarnas": "omfamning",
    "omfamningars": "omfamning",
    "omfamningen": "omfamning",
    "omfamningens": "omfamning",
    "omfamnings": "omfamning",
    "omfatt": "omfatta",
    "omfattad": "omfatta",
    "omfattade": "omfatta",
    "omfattades": "omfatta",
    "omfattads": "omfatta",
    "omfattande": "omfatta",
    "omfattanden": "omfattande",
    "omfattandena": "omfattande",
    "omfattandenas": "omfattande",
    "omfattandens": "omfattande",
    "omfattandes": "omfattande",
    "omfattandet": "omfattande",
    "omfattandets": "omfattande",
    "omfattar": "omfatta",
    "omfattas": "omfatta",
    "omfattat": "omfatta",
    "omfattats": "omfatta",
    "omfattningar": "omfattning",
    "omfattningarna": "omfattning",
    "omfattningarnas": "omfattning",
    "omfattningars": "omfattning",
    "omfattningen": "omfattning",
    "omfattningens": "omfattning",
    "omfattnings": "omfattning",
    "omflytt": "omflytta",
    "omflyttad": "omflytta",
    "omflyttade": "omflytta",
    "omflyttades": "omflytta",
    "omflyttads": "omflytta",
    "omflyttande": "omflytta",
    "omflyttandes": "omflytta",
    "omflyttar": "omflytta",
    "omflyttas": "omflytta",
    "omflyttat": "omflytta",
    "omflyttats": "omflytta",
    "omform": "omforma",
    "omformad": "omforma",
    "omformade": "omforma",
    "omformades": "omforma",
    "omformads": "omforma",
    "omformande": "omforma",
    "omformanden": "omformande",
    "omformandena": "omformande",
    "omformandenas": "omformande",
    "omformandens": "omformande",
    "omformandes": "omformande",
    "omformandet": "omformande",
    "omformandets": "omformande",
    "omformar": "omformare",
    "omformaren": "omformare",
    "omformarens": "omformare",
    "omformares": "omformare",
    "omformarna": "omformare",
    "omformarnas": "omformare",
    "omformas": "omforma",
    "omformat": "omforma",
    "omformats": "omforma",
    "omfånget": "omfång",
    "omfångets": "omfång",
    "omfångs": "omfång",
    "omfångsrika": "omfångsrik",
    "omfångsrikare": "omfångsrik",
    "omfångsrikares": "omfångsrik",
    "omfångsrikas": "omfångsrik",
    "omfångsrikast": "omfångsrik",
    "omfångsrikaste": "omfångsrik",
    "omfångsrikastes": "omfångsrik",
    "omfångsrikasts": "omfångsrik",
    "omfångsrike": "omfångsrik",
    "omfångsrikes": "omfångsrik",
    "omfångsrikheten": "omfångsrikhet",
    "omfångsrikhetens": "omfångsrikhet",
    "omfångsrikhets": "omfångsrikhet",
    "omfångsriks": "omfångsrik",
    "omfångsrikt": "omfångsrik",
    "omfångsrikts": "omfångsrik",
    "omföderskan": "omföderska",
    "omföderskans": "omföderska",
    "omföderskas": "omföderska",
    "omföderske": "omföderska",
    "omföderskor": "omföderska",
    "omföderskorna": "omföderska",
    "omföderskornas": "omföderska",
    "omföderskors": "omföderska",
    "omför": "omföra",
    "omförande": "omföra",
    "omföranden": "omförande",
    "omförandena": "omförande",
    "omförandenas": "omförande",
    "omförandens": "omförande",
    "omförandes": "omförande",
    "omförandet": "omförande",
    "omförandets": "omförande",
    "omföras": "omföra",
    "omförd": "omföra",
    "omförda": "omföra",
    "omfördas": "omföra",
    "omförde": "omföra",
    "omfördel": "omfördela",
    "omfördelad": "omfördela",
    "omfördelade": "omfördela",
    "omfördelades": "omfördela",
    "omfördelads": "omfördela",
    "omfördelande": "omfördela",
    "omfördelanden": "omfördelande",
    "omfördelandena": "omfördelande",
    "omfördelandenas": "omfördelande",
    "omfördelandens": "omfördelande",
    "omfördelandes": "omfördelande",
    "omfördelandet": "omfördelande",
    "omfördelandets": "omfördelande",
    "omfördelar": "omfördela",
    "omfördelas": "omfördela",
    "omfördelat": "omfördela",
    "omfördelats": "omfördela",
    "omfördelningar": "omfördelning",
    "omfördelningarna": "omfördelning",
    "omfördelningarnas": "omfördelning",
    "omfördelningars": "omfördelning",
    "omfördelningen": "omfördelning",
    "omfördelningens": "omfördelning",
    "omfördelnings": "omfördelning",
    "omfördes": "omföra",
    "omförds": "omföra",
    "omföres": "omföra",
    "omförhandlad": "omförhandla",
    "omförhandlade": "omförhandla",
    "omförhandlades": "omförhandla",
    "omförhandlads": "omförhandla",
    "omförhandlande": "omförhandla",
    "omförhandlanden": "omförhandlande",
    "omförhandlandena": "omförhandlande",
    "omförhandlandenas": "omförhandlande",
    "omförhandlandens": "omförhandlande",
    "omförhandlandes": "omförhandlande",
    "omförhandlandet": "omförhandlande",
    "omförhandlandets": "omförhandlande",
    "omförhandlar": "omförhandla",
    "omförhandlas": "omförhandla",
    "omförhandlat": "omförhandla",
    "omförhandlats": "omförhandla",
    "omförmäl": "omförmäla",
    "omförmälande": "omförmäla",
    "omförmälanden": "omförmälande",
    "omförmälandena": "omförmälande",
    "omförmälandenas": "omförmälande",
    "omförmälandens": "omförmälande",
    "omförmälandes": "omförmälande",
    "omförmälandet": "omförmälande",
    "omförmälandets": "omförmälande",
    "omförmälas": "omförmäla",
    "omförmäld": "omförmäla",
    "omförmälda": "omförmäla",
    "omförmäldas": "omförmäla",
    "omförmälde": "omförmäla",
    "omförmäldes": "omförmäla",
    "omförmälds": "omförmäla",
    "omförmäler": "omförmäla",
    "omförmäles": "omförmäla",
    "omförmäls": "omförmäla",
    "omförmält": "omförmäla",
    "omförmälte": "omförmäla",
    "omförmältes": "omförmäla",
    "omförmälts": "omförmäla",
    "omförs": "omföra",
    "omfört": "omföra",
    "omförts": "omföra",
    "omgav": "omge",
    "omgavs": "omge",
    "omgeende": "omge",
    "omgeendes": "omge",
    "omger": "omge",
    "omges": "omge",
    "omgestalt": "omgestalta",
    "omgestaltad": "omgestalta",
    "omgestaltade": "omgestalta",
    "omgestaltades": "omgestalta",
    "omgestaltads": "omgestalta",
    "omgestaltande": "omgestalta",
    "omgestaltanden": "omgestaltande",
    "omgestaltandena": "omgestaltande",
    "omgestaltandenas": "omgestaltande",
    "omgestaltandens": "omgestaltande",
    "omgestaltandes": "omgestaltande",
    "omgestaltandet": "omgestaltande",
    "omgestaltandets": "omgestaltande",
    "omgestaltar": "omgestalta",
    "omgestaltas": "omgestalta",
    "omgestaltat": "omgestalta",
    "omgestaltats": "omgestalta",
    "omgestaltningar": "omgestaltning",
    "omgestaltningarna": "omgestaltning",
    "omgestaltningarnas": "omgestaltning",
    "omgestaltningars": "omgestaltning",
    "omgestaltningen": "omgestaltning",
    "omgestaltningens": "omgestaltning",
    "omgestaltnings": "omgestaltning",
    "omgett": "omge",
    "omgetts": "omge",
    "omgifta": "omgift",
    "omgiftare": "omgift",
    "omgiftares": "omgift",
    "omgiftas": "omgift",
    "omgiftast": "omgift",
    "omgiftaste": "omgift",
    "omgiftastes": "omgift",
    "omgiftasts": "omgift",
    "omgifte": "omgift",
    "omgiftes": "omgift",
    "omgifts": "omgift",
    "omgiv": "omge",
    "omgiva": "omge",
    "omgivande": "omge",
    "omgivanden": "omgivande",
    "omgivandena": "omgivande",
    "omgivandenas": "omgivande",
    "omgivandens": "omgivande",
    "omgivandes": "omgivande",
    "omgivandet": "omgivande",
    "omgivandets": "omgivande",
    "omgivar": "omgiv",
    "omgivarna": "omgiv",
    "omgivarnas": "omgiv",
    "omgivars": "omgiv",
    "omgivas": "omge",
    "omgive": "omge",
    "omgiven": "omgiv",
    "omgivens": "omgiv",
    "omgiver": "omge",
    "omgives": "omge",
    "omgivet": "omge",
    "omgivets": "omge",
    "omgivit": "omge",
    "omgivits": "omge",
    "omgivna": "omge",
    "omgivnas": "omge",
    "omgivne": "omge",
    "omgivnes": "omge",
    "omgivningar": "omgivning",
    "omgivningarna": "omgivning",
    "omgivningarnas": "omgivning",
    "omgivningars": "omgivning",
    "omgivningen": "omgivning",
    "omgivningens": "omgivning",
    "omgivnings": "omgivning",
    "omgivs": "omgiv",
    "omgjorda": "omgjord",
    "omgjordare": "omgjord",
    "omgjordares": "omgjord",
    "omgjordas": "omgjord",
    "omgjordast": "omgjord",
    "omgjordaste": "omgjord",
    "omgjordastes": "omgjord",
    "omgjordasts": "omgjord",
    "omgjorde": "omgjord",
    "omgjordes": "omgjord",
    "omgjords": "omgjord",
    "omgjort": "omgjord",
    "omgjorts": "omgjord",
    "omgrupperad": "omgruppera",
    "omgrupperade": "omgruppera",
    "omgrupperades": "omgruppera",
    "omgrupperads": "omgruppera",
    "omgrupperande": "omgruppera",
    "omgrupperandes": "omgruppera",
    "omgrupperar": "omgruppera",
    "omgrupperas": "omgruppera",
    "omgrupperat": "omgruppera",
    "omgrupperats": "omgruppera",
    "omgärd": "omgärda",
    "omgärdad": "omgärda",
    "omgärdade": "omgärda",
    "omgärdades": "omgärda",
    "omgärdads": "omgärda",
    "omgärdande": "omgärda",
    "omgärdanden": "omgärdande",
    "omgärdandena": "omgärdande",
    "omgärdandenas": "omgärdande",
    "omgärdandens": "omgärdande",
    "omgärdandes": "omgärdande",
    "omgärdandet": "omgärdande",
    "omgärdandets": "omgärdande",
    "omgärdar": "omgärda",
    "omgärdas": "omgärda",
    "omgärdat": "omgärda",
    "omgärdats": "omgärda",
    "omgångar": "omgång",
    "omgångarna": "omgång",
    "omgångarnas": "omgång",
    "omgångars": "omgång",
    "omgången": "omgång",
    "omgångens": "omgång",
    "omgångs": "omgång",
    "omgåve": "omge",
    "omgåves": "omge",
    "omhoppen": "omhopp",
    "omhoppens": "omhopp",
    "omhoppet": "omhopp",
    "omhoppets": "omhopp",
    "omhopps": "omhopp",
    "omhuld": "omhulda",
    "omhuldad": "omhulda",
    "omhuldade": "omhulda",
    "omhuldades": "omhulda",
    "omhuldads": "omhulda",
    "omhuldande": "omhulda",
    "omhuldanden": "omhuldande",
    "omhuldandena": "omhuldande",
    "omhuldandenas": "omhuldande",
    "omhuldandens": "omhuldande",
    "omhuldandes": "omhuldande",
    "omhuldandet": "omhuldande",
    "omhuldandets": "omhuldande",
    "omhuldar": "omhulda",
    "omhuldas": "omhulda",
    "omhuldat": "omhulda",
    "omhuldats": "omhulda",
    "omhägn": "omhägna",
    "omhägnad": "omhägna",
    "omhägnade": "omhägna",
    "omhägnades": "omhägna",
    "omhägnads": "omhägna",
    "omhägnande": "omhägna",
    "omhägnanden": "omhägnande",
    "omhägnandena": "omhägnande",
    "omhägnandenas": "omhägnande",
    "omhägnandens": "omhägnande",
    "omhägnandes": "omhägnande",
    "omhägnandet": "omhägnande",
    "omhägnandets": "omhägnande",
    "omhägnar": "omhägna",
    "omhägnas": "omhägna",
    "omhägnat": "omhägna",
    "omhägnats": "omhägna",
    "omhäkt": "omhäkta",
    "omhäktad": "omhäkta",
    "omhäktade": "omhäkta",
    "omhäktades": "omhäkta",
    "omhäktads": "omhäkta",
    "omhäktande": "omhäkta",
    "omhäktanden": "omhäktande",
    "omhäktandena": "omhäktande",
    "omhäktandenas": "omhäktande",
    "omhäktandens": "omhäktande",
    "omhäktandes": "omhäktande",
    "omhäktandet": "omhäktande",
    "omhäktandets": "omhäktande",
    "omhäktar": "omhäkta",
    "omhäktas": "omhäkta",
    "omhäktat": "omhäkta",
    "omhäktats": "omhäkta",
    "omhänderhade": "omhänderha",
    "omhänderhades": "omhänderha",
    "omhänderhaft": "omhänderha",
    "omhänderhafts": "omhänderha",
    "omhänderhande": "omhänderha",
    "omhänderhandes": "omhänderha",
    "omhänderhar": "omhänderha",
    "omhänderhas": "omhänderha",
    "omhänderhava": "omhänderha",
    "omhänderhavande": "omhänderha",
    "omhänderhavanden": "omhänderhavande",
    "omhänderhavandena": "omhänderhavande",
    "omhänderhavandenas": "omhänderhavande",
    "omhänderhavandens": "omhänderhavande",
    "omhänderhavandes": "omhänderhavande",
    "omhänderhavandet": "omhänderhavande",
    "omhänderhavandets": "omhänderhavande",
    "omhänderhavas": "omhänderha",
    "omhänderhaver": "omhänderha",
    "omhändertag": "omhänderta",
    "omhändertaga": "omhänderta",
    "omhändertagande": "omhänderta",
    "omhändertaganden": "omhändertagande",
    "omhändertagandena": "omhändertagande",
    "omhändertagandenas": "omhändertagande",
    "omhändertagandens": "omhändertagande",
    "omhändertagandes": "omhändertagande",
    "omhändertagandet": "omhändertagande",
    "omhändertagandets": "omhändertagande",
    "omhändertagas": "omhänderta",
    "omhändertage": "omhänderta",
    "omhändertagen": "omhänderta",
    "omhändertagens": "omhänderta",
    "omhändertager": "omhänderta",
    "omhändertages": "omhänderta",
    "omhändertaget": "omhänderta",
    "omhändertagets": "omhänderta",
    "omhändertagit": "omhänderta",
    "omhändertagits": "omhänderta",
    "omhändertagna": "omhänderta",
    "omhändertagnas": "omhänderta",
    "omhändertagne": "omhänderta",
    "omhändertagnes": "omhänderta",
    "omhändertags": "omhänderta",
    "omhändertar": "omhänderta",
    "omhändertas": "omhänderta",
    "omhändertog": "omhänderta",
    "omhändertoge": "omhänderta",
    "omhändertoges": "omhänderta",
    "omhändertogs": "omhänderta",
    "omhängen": "omhänge",
    "omhängena": "omhänge",
    "omhängenas": "omhänge",
    "omhängens": "omhänge",
    "omhänges": "omhänge",
    "omhänget": "omhänge",
    "omhängets": "omhänge",
    "omhängs": "omhänge",
    "omhölj": "omhölja",
    "omhöljande": "omhölja",
    "omhöljanden": "omhöljande",
    "omhöljandena": "omhöljande",
    "omhöljandenas": "omhöljande",
    "omhöljandens": "omhöljande",
    "omhöljandes": "omhöljande",
    "omhöljandet": "omhöljande",
    "omhöljandets": "omhöljande",
    "omhöljas": "omhölja",
    "omhöljd": "omhölja",
    "omhöljda": "omhölja",
    "omhöljdas": "omhölja",
    "omhöljde": "omhölja",
    "omhöljdes": "omhölja",
    "omhöljds": "omhölja",
    "omhöljer": "omhölja",
    "omhöljes": "omhölja",
    "omhöljs": "omhölja",
    "omhöljt": "omhölja",
    "omhöljts": "omhölja",
    "omicrade": "omicrad",
    "omicrades": "omicrad",
    "omicrads": "omicrad",
    "omicrat": "omicrad",
    "omicrats": "omicrad",
    "omikrade": "omikrad",
    "omikrades": "omikrad",
    "omikrads": "omikrad",
    "omikrat": "omikrad",
    "omikrats": "omikrad",
    "omikronen": "omikron",
    "omikronens": "omikron",
    "omikronet": "omikron",
    "omikronets": "omikron",
    "omikrons": "omikron",
    "omikroskoperade": "omikroskoperad",
    "omikroskoperades": "omikroskoperad",
    "omikroskoperads": "omikroskoperad",
    "omikroskoperat": "omikroskoperad",
    "omikroskoperats": "omikroskoperad",
    "omikroskoperbara": "omikroskoperbar",
    "omikroskoperbarare": "omikroskoperbar",
    "omikroskoperbarares": "omikroskoperbar",
    "omikroskoperbaras": "omikroskoperbar",
    "omikroskoperbarast": "omikroskoperbar",
    "omikroskoperbaraste": "omikroskoperbar",
    "omikroskoperbarastes": "omikroskoperbar",
    "omikroskoperbarasts": "omikroskoperbar",
    "omikroskoperbare": "omikroskoperbar",
    "omikroskoperbares": "omikroskoperbar",
    "omikroskoperbarheten": "omikroskoperbarhet",
    "omikroskoperbarhetens": "omikroskoperbarhet",
    "omikroskoperbarhets": "omikroskoperbarhet",
    "omikroskoperbars": "omikroskoperbar",
    "omikroskoperbart": "omikroskoperbar",
    "omikroskoperbarts": "omikroskoperbar",
    "omilda": "omild",
    "omildare": "omild",
    "omildares": "omild",
    "omildas": "omild",
    "omildast": "omild",
    "omildaste": "omild",
    "omildastes": "omild",
    "omildasts": "omild",
    "omilde": "omild",
    "omildes": "omild",
    "omildheten": "omildhet",
    "omildhetens": "omildhet",
    "omildhets": "omildhet",
    "omildrade": "omildrad",
    "omildrades": "omildrad",
    "omildrads": "omildrad",
    "omildrat": "omildrad",
    "omildrats": "omildrad",
    "omilds": "omild",
    "omilitariserade": "omilitariserad",
    "omilitariserades": "omilitariserad",
    "omilitariserads": "omilitariserad",
    "omilitariserat": "omilitariserad",
    "omilitariserats": "omilitariserad",
    "omilitariserbara": "omilitariserbar",
    "omilitariserbarare": "omilitariserbar",
    "omilitariserbarares": "omilitariserbar",
    "omilitariserbaras": "omilitariserbar",
    "omilitariserbarast": "omilitariserbar",
    "omilitariserbaraste": "omilitariserbar",
    "omilitariserbarastes": "omilitariserbar",
    "omilitariserbarasts": "omilitariserbar",
    "omilitariserbare": "omilitariserbar",
    "omilitariserbares": "omilitariserbar",
    "omilitariserbarheten": "omilitariserbarhet",
    "omilitariserbarhetens": "omilitariserbarhet",
    "omilitariserbarhets": "omilitariserbarhet",
    "omilitariserbars": "omilitariserbar",
    "omilitariserbart": "omilitariserbar",
    "omilitariserbarts": "omilitariserbar",
    "omilt": "omild",
    "omilts": "omild",
    "omimade": "omimad",
    "omimades": "omimad",
    "omimads": "omimad",
    "omimat": "omimad",
    "omimats": "omimad",
    "omina": "omen",
    "ominas": "omen",
    "ominerade": "ominerad",
    "ominerades": "ominerad",
    "ominerads": "ominerad",
    "omineraliserade": "omineraliserad",
    "omineraliserades": "omineraliserad",
    "omineraliserads": "omineraliserad",
    "omineraliserat": "omineraliserad",
    "omineraliserats": "omineraliserad",
    "omineraliserbara": "omineraliserbar",
    "omineraliserbarare": "omineraliserbar",
    "omineraliserbarares": "omineraliserbar",
    "omineraliserbaras": "omineraliserbar",
    "omineraliserbarast": "omineraliserbar",
    "omineraliserbaraste": "omineraliserbar",
    "omineraliserbarastes": "omineraliserbar",
    "omineraliserbarasts": "omineraliserbar",
    "omineraliserbare": "omineraliserbar",
    "omineraliserbares": "omineraliserbar",
    "omineraliserbarheten": "omineraliserbarhet",
    "omineraliserbarhetens": "omineraliserbarhet",
    "omineraliserbarhets": "omineraliserbarhet",
    "omineraliserbars": "omineraliserbar",
    "omineraliserbart": "omineraliserbar",
    "omineraliserbarts": "omineraliserbar",
    "ominerat": "ominerad",
    "ominerats": "ominerad",
    "ominerbara": "ominerbar",
    "ominerbarare": "ominerbar",
    "ominerbarares": "ominerbar",
    "ominerbaras": "ominerbar",
    "ominerbarast": "ominerbar",
    "ominerbaraste": "ominerbar",
    "ominerbarastes": "ominerbar",
    "ominerbarasts": "ominerbar",
    "ominerbare": "ominerbar",
    "ominerbares": "ominerbar",
    "ominerbarheten": "ominerbarhet",
    "ominerbarhetens": "ominerbarhet",
    "ominerbarhets": "ominerbarhet",
    "ominerbars": "ominerbar",
    "ominerbart": "ominerbar",
    "ominerbarts": "ominerbar",
    "ominet": "omen",
    "ominets": "omen",
    "ominiatyriserade": "ominiatyriserad",
    "ominiatyriserades": "ominiatyriserad",
    "ominiatyriserads": "ominiatyriserad",
    "ominiatyriserat": "ominiatyriserad",
    "ominiatyriserats": "ominiatyriserad",
    "ominiatyriserbara": "ominiatyriserbar",
    "ominiatyriserbarare": "ominiatyriserbar",
    "ominiatyriserbarares": "ominiatyriserbar",
    "ominiatyriserbaras": "ominiatyriserbar",
    "ominiatyriserbarast": "ominiatyriserbar",
    "ominiatyriserbaraste": "ominiatyriserbar",
    "ominiatyriserbarastes": "ominiatyriserbar",
    "ominiatyriserbarasts": "ominiatyriserbar",
    "ominiatyriserbare": "ominiatyriserbar",
    "ominiatyriserbares": "ominiatyriserbar",
    "ominiatyriserbarheten": "ominiatyriserbarhet",
    "ominiatyriserbarhetens": "ominiatyriserbarhet",
    "ominiatyriserbarhets": "ominiatyriserbarhet",
    "ominiatyriserbars": "ominiatyriserbar",
    "ominiatyriserbart": "ominiatyriserbar",
    "ominiatyriserbarts": "ominiatyriserbar",
    "ominimerade": "ominimerad",
    "ominimerades": "ominimerad",
    "ominimerads": "ominimerad",
    "ominimerat": "ominimerad",
    "ominimerats": "ominimerad",
    "ominimerbara": "ominimerbar",
    "ominimerbarare": "ominimerbar",
    "ominimerbarares": "ominimerbar",
    "ominimerbaras": "ominimerbar",
    "ominimerbarast": "ominimerbar",
    "ominimerbaraste": "ominimerbar",
    "ominimerbarastes": "ominimerbar",
    "ominimerbarasts": "ominimerbar",
    "ominimerbare": "ominimerbar",
    "ominimerbares": "ominimerbar",
    "ominimerbarheten": "ominimerbarhet",
    "ominimerbarhetens": "ominimerbarhet",
    "ominimerbarhets": "ominimerbarhet",
    "ominimerbars": "ominimerbar",
    "ominimerbart": "ominimerbar",
    "ominimerbarts": "ominimerbar",
    "ominskade": "ominskad",
    "ominskades": "ominskad",
    "ominskads": "ominskad",
    "ominskat": "ominskad",
    "ominskats": "ominskad",
    "omintetgjord": "omintetgöra",
    "omintetgjorda": "omintetgöra",
    "omintetgjordas": "omintetgöra",
    "omintetgjorde": "omintetgöra",
    "omintetgjordes": "omintetgöra",
    "omintetgjords": "omintetgöra",
    "omintetgjort": "omintetgöra",
    "omintetgjorts": "omintetgöra",
    "omintetgör": "omintetgöra",
    "omintetgörande": "omintetgöra",
    "omintetgöranden": "omintetgörande",
    "omintetgörandena": "omintetgörande",
    "omintetgörandenas": "omintetgörande",
    "omintetgörandens": "omintetgörande",
    "omintetgörandes": "omintetgörande",
    "omintetgörandet": "omintetgörande",
    "omintetgörandets": "omintetgörande",
    "omintetgöras": "omintetgöra",
    "omintetgöres": "omintetgöra",
    "omintetgörs": "omintetgöra",
    "ominösa": "ominös",
    "ominösare": "ominös",
    "ominösares": "ominös",
    "ominösas": "ominös",
    "ominösast": "ominös",
    "ominösaste": "ominös",
    "ominösastes": "ominös",
    "ominösasts": "ominös",
    "ominöse": "ominös",
    "ominöses": "ominös",
    "ominöst": "ominös",
    "ominösts": "ominös",
    "omissade": "omissad",
    "omissades": "omissad",
    "omissads": "omissad",
    "omissat": "omissad",
    "omissats": "omissad",
    "omissiverade": "omissiverad",
    "omissiverades": "omissiverad",
    "omissiverads": "omissiverad",
    "omissiverat": "omissiverad",
    "omissiverats": "omissiverad",
    "omissiverbara": "omissiverbar",
    "omissiverbarare": "omissiverbar",
    "omissiverbarares": "omissiverbar",
    "omissiverbaras": "omissiverbar",
    "omissiverbarast": "omissiverbar",
    "omissiverbaraste": "omissiverbar",
    "omissiverbarastes": "omissiverbar",
    "omissiverbarasts": "omissiverbar",
    "omissiverbare": "omissiverbar",
    "omissiverbares": "omissiverbar",
    "omissiverbarheten": "omissiverbarhet",
    "omissiverbarhetens": "omissiverbarhet",
    "omissiverbarhets": "omissiverbarhet",
    "omissiverbars": "omissiverbar",
    "omissiverbart": "omissiverbar",
    "omissiverbarts": "omissiverbar",
    "omisskrediterade": "omisskrediterad",
    "omisskrediterades": "omisskrediterad",
    "omisskrediterads": "omisskrediterad",
    "omisskrediterat": "omisskrediterad",
    "omisskrediterats": "omisskrediterad",
    "omisskrediterbara": "omisskrediterbar",
    "omisskrediterbarare": "omisskrediterbar",
    "omisskrediterbarares": "omisskrediterbar",
    "omisskrediterbaras": "omisskrediterbar",
    "omisskrediterbarast": "omisskrediterbar",
    "omisskrediterbaraste": "omisskrediterbar",
    "omisskrediterbarastes": "omisskrediterbar",
    "omisskrediterbarasts": "omisskrediterbar",
    "omisskrediterbare": "omisskrediterbar",
    "omisskrediterbares": "omisskrediterbar",
    "omisskrediterbarheten": "omisskrediterbarhet",
    "omisskrediterbarhetens": "omisskrediterbarhet",
    "omisskrediterbarhets": "omisskrediterbarhet",
    "omisskrediterbars": "omisskrediterbar",
    "omisskrediterbart": "omisskrediterbar",
    "omisskrediterbarts": "omisskrediterbar",
    "omisskänneliga": "omisskännelig",
    "omisskänneligare": "omisskännelig",
    "omisskänneligares": "omisskännelig",
    "omisskänneligas": "omisskännelig",
    "omisskänneligast": "omisskännelig",
    "omisskänneligaste": "omisskännelig",
    "omisskänneligastes": "omisskännelig",
    "omisskänneligasts": "omisskännelig",
    "omisskännelige": "omisskännelig",
    "omisskänneliges": "omisskännelig",
    "omisskänneligheten": "omisskännelighet",
    "omisskännelighetens": "omisskännelighet",
    "omisskännelighets": "omisskännelighet",
    "omisskänneligs": "omisskännelig",
    "omisskänneligt": "omisskännelig",
    "omisskänneligts": "omisskännelig",
    "omisskännliga": "omisskännlig",
    "omisskännligare": "omisskännlig",
    "omisskännligares": "omisskännlig",
    "omisskännligas": "omisskännlig",
    "omisskännligast": "omisskännlig",
    "omisskännligaste": "omisskännlig",
    "omisskännligastes": "omisskännlig",
    "omisskännligasts": "omisskännlig",
    "omisskännlige": "omisskännlig",
    "omisskännliges": "omisskännlig",
    "omisskännligheten": "omisskännlighet",
    "omisskännlighetens": "omisskännlighet",
    "omisskännlighets": "omisskännlighet",
    "omisskännligs": "omisskännlig",
    "omisskännligt": "omisskännlig",
    "omisskännligts": "omisskännlig",
    "omisstänksamheten": "omisstänksamhet",
    "omisstänksamhetens": "omisstänksamhet",
    "omisstänksamhets": "omisstänksamhet",
    "omisstänksamma": "omisstänksam",
    "omisstänksammare": "omisstänksam",
    "omisstänksammares": "omisstänksam",
    "omisstänksammas": "omisstänksam",
    "omisstänksammast": "omisstänksam",
    "omisstänksammaste": "omisstänksam",
    "omisstänksammastes": "omisstänksam",
    "omisstänksammasts": "omisstänksam",
    "omisstänksamme": "omisstänksam",
    "omisstänksammes": "omisstänksam",
    "omisstänksams": "omisstänksam",
    "omisstänksamt": "omisstänksam",
    "omisstänksamts": "omisstänksam",
    "omistliga": "omistlig",
    "omistligare": "omistlig",
    "omistligares": "omistlig",
    "omistligas": "omistlig",
    "omistligast": "omistlig",
    "omistligaste": "omistlig",
    "omistligastes": "omistlig",
    "omistligasts": "omistlig",
    "omistlige": "omistlig",
    "omistliges": "omistlig",
    "omistligheten": "omistlighet",
    "omistlighetens": "omistlighet",
    "omistligheter": "omistlighet",
    "omistligheterna": "omistlighet",
    "omistligheternas": "omistlighet",
    "omistligheters": "omistlighet",
    "omistlighets": "omistlighet",
    "omistligs": "omistlig",
    "omistligt": "omistlig",
    "omistligts": "omistlig",
    "omixade": "omixad",
    "omixades": "omixad",
    "omixads": "omixad",
    "omixat": "omixad",
    "omixats": "omixad",
    "omjukade": "omjukad",
    "omjukades": "omjukad",
    "omjukads": "omjukad",
    "omjukat": "omjukad",
    "omjukats": "omjukad",
    "omjölade": "omjölad",
    "omjölades": "omjölad",
    "omjölads": "omjölad",
    "omjölat": "omjölad",
    "omjölats": "omjölad",
    "omjölkade": "omjölkad",
    "omjölkades": "omjölkad",
    "omjölkads": "omjölkad",
    "omjölkat": "omjölkad",
    "omjölkats": "omjölkad",
    "omkast": "omkasta",
    "omkastad": "omkasta",
    "omkastade": "omkasta",
    "omkastades": "omkasta",
    "omkastads": "omkasta",
    "omkastande": "omkasta",
    "omkastanden": "omkastande",
    "omkastandena": "omkastande",
    "omkastandenas": "omkastande",
    "omkastandens": "omkastande",
    "omkastandes": "omkastande",
    "omkastandet": "omkastande",
    "omkastandets": "omkastande",
    "omkastar": "omkastare",
    "omkastaren": "omkastare",
    "omkastarens": "omkastare",
    "omkastares": "omkastare",
    "omkastarna": "omkastare",
    "omkastarnas": "omkastare",
    "omkastas": "omkasta",
    "omkastat": "omkasta",
    "omkastats": "omkasta",
    "omkasten": "omkast",
    "omkastens": "omkast",
    "omkastet": "omkast",
    "omkastets": "omkast",
    "omkasts": "omkast",
    "omkläd": "omklä",
    "omkläda": "omklä",
    "omklädande": "omklä",
    "omklädanden": "omklädande",
    "omklädandena": "omklädande",
    "omklädandenas": "omklädande",
    "omklädandens": "omklädande",
    "omklädandes": "omklädande",
    "omklädandet": "omklädande",
    "omklädandets": "omklädande",
    "omklädas": "omklä",
    "omklädd": "omklä",
    "omklädda": "omklä",
    "omkläddas": "omklä",
    "omklädde": "omklä",
    "omkläddes": "omklä",
    "omklädds": "omklä",
    "omkläder": "omklä",
    "omklädningar": "omklädning",
    "omklädningarna": "omklädning",
    "omklädningarnas": "omklädning",
    "omklädningars": "omklädning",
    "omklädningen": "omklädning",
    "omklädningens": "omklädning",
    "omklädnings": "omklädning",
    "omklädningsrummen": "omklädningsrum",
    "omklädningsrummens": "omklädningsrum",
    "omklädningsrummet": "omklädningsrum",
    "omklädningsrummets": "omklädningsrum",
    "omklädningsrums": "omklädningsrum",
    "omkläds": "omklä",
    "omkläende": "omklä",
    "omkläenden": "omkläende",
    "omkläendena": "omkläende",
    "omkläendenas": "omkläende",
    "omkläendens": "omkläende",
    "omkläendes": "omkläende",
    "omkläendet": "omkläende",
    "omkläendets": "omkläende",
    "omklär": "omklä",
    "omkläs": "omklä",
    "omklätt": "omklä",
    "omklätts": "omklä",
    "omkom": "omkomma",
    "omkomet": "omkomma",
    "omkomets": "omkomma",
    "omkommande": "omkomma",
    "omkommanden": "omkommande",
    "omkommandena": "omkommande",
    "omkommandenas": "omkommande",
    "omkommandens": "omkommande",
    "omkommandes": "omkommande",
    "omkommandet": "omkommande",
    "omkommandets": "omkommande",
    "omkommas": "omkomma",
    "omkomme": "omkomma",
    "omkommen": "omkomma",
    "omkommens": "omkomma",
    "omkommer": "omkomma",
    "omkommes": "omkomma",
    "omkommit": "omkomma",
    "omkommits": "omkomma",
    "omkomna": "omkomma",
    "omkomnas": "omkomma",
    "omkomne": "omkomma",
    "omkomnes": "omkomma",
    "omkoms": "omkomma",
    "omkopplar": "omkopplare",
    "omkopplaren": "omkopplare",
    "omkopplarens": "omkopplare",
    "omkopplares": "omkopplare",
    "omkopplarna": "omkopplare",
    "omkopplarnas": "omkopplare",
    "omkostnaderna": "omkostnader",
    "omkostnadernas": "omkostnader",
    "omkostnaders": "omkostnader",
    "omkostnads": "omkostnader",
    "omkrans": "omkransa",
    "omkransad": "omkransa",
    "omkransade": "omkransa",
    "omkransades": "omkransa",
    "omkransads": "omkransa",
    "omkransande": "omkransa",
    "omkransanden": "omkransande",
    "omkransandena": "omkransande",
    "omkransandenas": "omkransande",
    "omkransandens": "omkransande",
    "omkransandes": "omkransande",
    "omkransandet": "omkransande",
    "omkransandets": "omkransande",
    "omkransar": "omkransa",
    "omkransas": "omkransa",
    "omkransat": "omkransa",
    "omkransats": "omkransa",
    "omkrets": "omkretsa",
    "omkretsad": "omkretsa",
    "omkretsade": "omkretsa",
    "omkretsades": "omkretsa",
    "omkretsads": "omkretsa",
    "omkretsande": "omkretsa",
    "omkretsanden": "omkretsande",
    "omkretsandena": "omkretsande",
    "omkretsandenas": "omkretsande",
    "omkretsandens": "omkretsande",
    "omkretsandes": "omkretsande",
    "omkretsandet": "omkretsande",
    "omkretsandets": "omkretsande",
    "omkretsar": "omkretsa",
    "omkretsas": "omkretsa",
    "omkretsat": "omkretsa",
    "omkretsats": "omkretsa",
    "omkretsen": "omkrets",
    "omkretsens": "omkrets",
    "omkväden": "omkväde",
    "omkvädena": "omkväde",
    "omkvädenas": "omkväde",
    "omkvädens": "omkväde",
    "omkvädes": "omkväde",
    "omkvädet": "omkväde",
    "omkvädets": "omkväde",
    "omkväds": "omkväde",
    "omköpen": "omköp",
    "omköpens": "omköp",
    "omköpet": "omköp",
    "omköpets": "omköp",
    "omköps": "omköp",
    "omkör": "omköra",
    "omkörande": "omköra",
    "omköranden": "omkörande",
    "omkörandena": "omkörande",
    "omkörandenas": "omkörande",
    "omkörandens": "omkörande",
    "omkörandes": "omkörande",
    "omkörandet": "omkörande",
    "omkörandets": "omkörande",
    "omköras": "omköra",
    "omkörd": "omköra",
    "omkörda": "omköra",
    "omkördas": "omköra",
    "omkörde": "omköra",
    "omkördes": "omköra",
    "omkörds": "omköra",
    "omköres": "omköra",
    "omkörningar": "omkörning",
    "omkörningarna": "omkörning",
    "omkörningarnas": "omkörning",
    "omkörningars": "omkörning",
    "omkörningen": "omkörning",
    "omkörningens": "omkörning",
    "omkörnings": "omkörning",
    "omkörningsförbuden": "omkörningsförbud",
    "omkörningsförbudens": "omkörningsförbud",
    "omkörningsförbudet": "omkörningsförbud",
    "omkörningsförbudets": "omkörningsförbud",
    "omkörningsförbuds": "omkörningsförbud",
    "omkörs": "omköra",
    "omkört": "omköra",
    "omkörts": "omköra",
    "omlandet": "omland",
    "omlandets": "omland",
    "omlands": "omland",
    "omljudda": "omljudd",
    "omljuddare": "omljudd",
    "omljuddares": "omljudd",
    "omljuddas": "omljudd",
    "omljuddast": "omljudd",
    "omljuddaste": "omljudd",
    "omljuddastes": "omljudd",
    "omljuddasts": "omljudd",
    "omljudde": "omljudd",
    "omljuddes": "omljudd",
    "omljudds": "omljudd",
    "omljuden": "omljud",
    "omljudens": "omljud",
    "omljudet": "omljud",
    "omljudets": "omljud",
    "omljuds": "omljud",
    "omljutt": "omljudd",
    "omljutts": "omljudd",
    "omloppen": "omlopp",
    "omloppens": "omlopp",
    "omloppet": "omlopp",
    "omloppets": "omlopp",
    "omlopps": "omlopp",
    "omloppsbanan": "omloppsbana",
    "omloppsbanans": "omloppsbana",
    "omloppsbanas": "omloppsbana",
    "omloppsbane": "omloppsbana",
    "omloppsbanor": "omloppsbana",
    "omloppsbanorna": "omloppsbana",
    "omloppsbanornas": "omloppsbana",
    "omloppsbanors": "omloppsbana",
    "omloppstiden": "omloppstid",
    "omloppstidens": "omloppstid",
    "omloppstider": "omloppstid",
    "omloppstiderna": "omloppstid",
    "omloppstidernas": "omloppstid",
    "omloppstiders": "omloppstid",
    "omloppstids": "omloppstid",
    "omläggningar": "omläggning",
    "omläggningarna": "omläggning",
    "omläggningarnas": "omläggning",
    "omläggningars": "omläggning",
    "omläggningen": "omläggning",
    "omläggningens": "omläggning",
    "omläggnings": "omläggning",
    "ommöblerad": "ommöblera",
    "ommöblerade": "ommöblera",
    "ommöblerades": "ommöblera",
    "ommöblerads": "ommöblera",
    "ommöblerande": "ommöblera",
    "ommöbleranden": "ommöblerande",
    "ommöblerandena": "ommöblerande",
    "ommöblerandenas": "ommöblerande",
    "ommöblerandens": "ommöblerande",
    "ommöblerandes": "ommöblerande",
    "ommöblerandet": "ommöblerande",
    "ommöblerandets": "ommöblerande",
    "ommöblerar": "ommöblera",
    "ommöbleras": "ommöblera",
    "ommöblerat": "ommöblera",
    "ommöblerats": "ommöblera",
    "ommöblerbara": "ommöblerbar",
    "ommöblerbarare": "ommöblerbar",
    "ommöblerbarares": "ommöblerbar",
    "ommöblerbaras": "ommöblerbar",
    "ommöblerbarast": "ommöblerbar",
    "ommöblerbaraste": "ommöblerbar",
    "ommöblerbarastes": "ommöblerbar",
    "ommöblerbarasts": "ommöblerbar",
    "ommöblerbare": "ommöblerbar",
    "ommöblerbares": "ommöblerbar",
    "ommöblerbarheten": "ommöblerbarhet",
    "ommöblerbarhetens": "ommöblerbarhet",
    "ommöblerbarhets": "ommöblerbarhet",
    "ommöblerbars": "ommöblerbar",
    "ommöblerbart": "ommöblerbar",
    "ommöblerbarts": "ommöblerbar",
    "ommöbleringar": "ommöblering",
    "ommöbleringarna": "ommöblering",
    "ommöbleringarnas": "ommöblering",
    "ommöbleringars": "ommöblering",
    "ommöbleringen": "ommöblering",
    "ommöbleringens": "ommöblering",
    "ommöblerings": "ommöblering",
    "omnejden": "omnejd",
    "omnejdens": "omnejd",
    "omnejds": "omnejd",
    "omnibusar": "omnibus",
    "omnibusarna": "omnibus",
    "omnibusarnas": "omnibus",
    "omnibusars": "omnibus",
    "omnibusen": "omnibus",
    "omnibusens": "omnibus",
    "omnibussar": "omnibuss",
    "omnibussarna": "omnibuss",
    "omnibussarnas": "omnibuss",
    "omnibussars": "omnibuss",
    "omnibussen": "omnibuss",
    "omnibussens": "omnibuss",
    "omnifyrar": "omnifyr",
    "omnifyrarna": "omnifyr",
    "omnifyrarnas": "omnifyr",
    "omnifyrars": "omnifyr",
    "omnifyren": "omnifyr",
    "omnifyrens": "omnifyr",
    "omnifyrs": "omnifyr",
    "omnipotensen": "omnipotens",
    "omnipotensens": "omnipotens",
    "omnipotenta": "omnipotent",
    "omnipotentare": "omnipotent",
    "omnipotentares": "omnipotent",
    "omnipotentas": "omnipotent",
    "omnipotentast": "omnipotent",
    "omnipotentaste": "omnipotent",
    "omnipotentastes": "omnipotent",
    "omnipotentasts": "omnipotent",
    "omnipotente": "omnipotent",
    "omnipotentes": "omnipotent",
    "omnipotents": "omnipotent",
    "omnipotentt": "omnipotent",
    "omnipotentts": "omnipotent",
    "omnivoren": "omnivor",
    "omnivorens": "omnivor",
    "omnivorer": "omnivor",
    "omnivorerna": "omnivor",
    "omnivorernas": "omnivor",
    "omnivorers": "omnivor",
    "omnivors": "omnivor",
    "omnämn": "omnämna",
    "omnämnande": "omnämna",
    "omnämnanden": "omnämnande",
    "omnämnandena": "omnämnande",
    "omnämnandenas": "omnämnande",
    "omnämnandens": "omnämnande",
    "omnämnandes": "omnämnande",
    "omnämnandet": "omnämnande",
    "omnämnandets": "omnämnande",
    "omnämnas": "omnämna",
    "omnämnd": "omnämna",
    "omnämnda": "omnämna",
    "omnämndas": "omnämna",
    "omnämnde": "omnämna",
    "omnämndes": "omnämna",
    "omnämnds": "omnämna",
    "omnämner": "omnämna",
    "omnämnes": "omnämna",
    "omnämns": "omnämna",
    "omnämnt": "omnämna",
    "omnämnts": "omnämna",
    "omobbade": "omobbad",
    "omobbades": "omobbad",
    "omobbads": "omobbad",
    "omobbat": "omobbad",
    "omobbats": "omobbad",
    "omobiliserade": "omobiliserad",
    "omobiliserades": "omobiliserad",
    "omobiliserads": "omobiliserad",
    "omobiliserat": "omobiliserad",
    "omobiliserats": "omobiliserad",
    "omobiliserbara": "omobiliserbar",
    "omobiliserbarare": "omobiliserbar",
    "omobiliserbarares": "omobiliserbar",
    "omobiliserbaras": "omobiliserbar",
    "omobiliserbarast": "omobiliserbar",
    "omobiliserbaraste": "omobiliserbar",
    "omobiliserbarastes": "omobiliserbar",
    "omobiliserbarasts": "omobiliserbar",
    "omobiliserbare": "omobiliserbar",
    "omobiliserbares": "omobiliserbar",
    "omobiliserbarheten": "omobiliserbarhet",
    "omobiliserbarhetens": "omobiliserbarhet",
    "omobiliserbarhets": "omobiliserbarhet",
    "omobiliserbars": "omobiliserbar",
    "omobiliserbart": "omobiliserbar",
    "omobiliserbarts": "omobiliserbar",
    "omockade": "omockad",
    "omockades": "omockad",
    "omockads": "omockad",
    "omockat": "omockad",
    "omockats": "omockad",
    "omodellerade": "omodellerad",
    "omodellerades": "omodellerad",
    "omodellerads": "omodellerad",
    "omodellerat": "omodellerad",
    "omodellerats": "omodellerad",
    "omodellerbara": "omodellerbar",
    "omodellerbarare": "omodellerbar",
    "omodellerbarares": "omodellerbar",
    "omodellerbaras": "omodellerbar",
    "omodellerbarast": "omodellerbar",
    "omodellerbaraste": "omodellerbar",
    "omodellerbarastes": "omodellerbar",
    "omodellerbarasts": "omodellerbar",
    "omodellerbare": "omodellerbar",
    "omodellerbares": "omodellerbar",
    "omodellerbarheten": "omodellerbarhet",
    "omodellerbarhetens": "omodellerbarhet",
    "omodellerbarhets": "omodellerbarhet",
    "omodellerbars": "omodellerbar",
    "omodellerbart": "omodellerbar",
    "omodellerbarts": "omodellerbar",
    "omodererade": "omodererad",
    "omodererades": "omodererad",
    "omodererads": "omodererad",
    "omodererat": "omodererad",
    "omodererats": "omodererad",
    "omodererbara": "omodererbar",
    "omodererbarare": "omodererbar",
    "omodererbarares": "omodererbar",
    "omodererbaras": "omodererbar",
    "omodererbarast": "omodererbar",
    "omodererbaraste": "omodererbar",
    "omodererbarastes": "omodererbar",
    "omodererbarasts": "omodererbar",
    "omodererbare": "omodererbar",
    "omodererbares": "omodererbar",
    "omodererbarheten": "omodererbarhet",
    "omodererbarhetens": "omodererbarhet",
    "omodererbarhets": "omodererbarhet",
    "omodererbars": "omodererbar",
    "omodererbart": "omodererbar",
    "omodererbarts": "omodererbar",
    "omoderna": "omodern",
    "omodernare": "omodern",
    "omodernares": "omodern",
    "omodernas": "omodern",
    "omodernast": "omodern",
    "omodernaste": "omodern",
    "omodernastes": "omodern",
    "omodernasts": "omodern",
    "omoderne": "omodern",
    "omodernes": "omodern",
    "omoderniserade": "omoderniserad",
    "omoderniserades": "omoderniserad",
    "omoderniserads": "omoderniserad",
    "omoderniserat": "omoderniserad",
    "omoderniserats": "omoderniserad",
    "omoderniserbara": "omoderniserbar",
    "omoderniserbarare": "omoderniserbar",
    "omoderniserbarares": "omoderniserbar",
    "omoderniserbaras": "omoderniserbar",
    "omoderniserbarast": "omoderniserbar",
    "omoderniserbaraste": "omoderniserbar",
    "omoderniserbarastes": "omoderniserbar",
    "omoderniserbarasts": "omoderniserbar",
    "omoderniserbare": "omoderniserbar",
    "omoderniserbares": "omoderniserbar",
    "omoderniserbarheten": "omoderniserbarhet",
    "omoderniserbarhetens": "omoderniserbarhet",
    "omoderniserbarhets": "omoderniserbarhet",
    "omoderniserbars": "omoderniserbar",
    "omoderniserbart": "omoderniserbar",
    "omoderniserbarts": "omoderniserbar",
    "omoderns": "omodern",
    "omodernt": "omodern",
    "omodernts": "omodern",
    "omodifierade": "omodifierad",
    "omodifierades": "omodifierad",
    "omodifierads": "omodifierad",
    "omodifierat": "omodifierad",
    "omodifierats": "omodifierad",
    "omodifierbara": "omodifierbar",
    "omodifierbarare": "omodifierbar",
    "omodifierbarares": "omodifierbar",
    "omodifierbaras": "omodifierbar",
    "omodifierbarast": "omodifierbar",
    "omodifierbaraste": "omodifierbar",
    "omodifierbarastes": "omodifierbar",
    "omodifierbarasts": "omodifierbar",
    "omodifierbare": "omodifierbar",
    "omodifierbares": "omodifierbar",
    "omodifierbarheten": "omodifierbarhet",
    "omodifierbarhetens": "omodifierbarhet",
    "omodifierbarhets": "omodifierbarhet",
    "omodifierbars": "omodifierbar",
    "omodifierbart": "omodifierbar",
    "omodifierbarts": "omodifierbar",
    "omodulerade": "omodulerad",
    "omodulerades": "omodulerad",
    "omodulerads": "omodulerad",
    "omodulerat": "omodulerad",
    "omodulerats": "omodulerad",
    "omodulerbara": "omodulerbar",
    "omodulerbarare": "omodulerbar",
    "omodulerbarares": "omodulerbar",
    "omodulerbaras": "omodulerbar",
    "omodulerbarast": "omodulerbar",
    "omodulerbaraste": "omodulerbar",
    "omodulerbarastes": "omodulerbar",
    "omodulerbarasts": "omodulerbar",
    "omodulerbare": "omodulerbar",
    "omodulerbares": "omodulerbar",
    "omodulerbarheten": "omodulerbarhet",
    "omodulerbarhetens": "omodulerbarhet",
    "omodulerbarhets": "omodulerbarhet",
    "omodulerbars": "omodulerbar",
    "omodulerbart": "omodulerbar",
    "omodulerbarts": "omodulerbar",
    "omodärniserade": "omodärniserad",
    "omodärniserades": "omodärniserad",
    "omodärniserads": "omodärniserad",
    "omodärniserat": "omodärniserad",
    "omodärniserats": "omodärniserad",
    "omodärniserbara": "omodärniserbar",
    "omodärniserbarare": "omodärniserbar",
    "omodärniserbarares": "omodärniserbar",
    "omodärniserbaras": "omodärniserbar",
    "omodärniserbarast": "omodärniserbar",
    "omodärniserbaraste": "omodärniserbar",
    "omodärniserbarastes": "omodärniserbar",
    "omodärniserbarasts": "omodärniserbar",
    "omodärniserbare": "omodärniserbar",
    "omodärniserbares": "omodärniserbar",
    "omodärniserbarheten": "omodärniserbarhet",
    "omodärniserbarhetens": "omodärniserbarhet",
    "omodärniserbarhets": "omodärniserbarhet",
    "omodärniserbars": "omodärniserbar",
    "omodärniserbart": "omodärniserbar",
    "omodärniserbarts": "omodärniserbar",
    "omogens": "omogen",
    "omoget": "omogen",
    "omogets": "omogen",
    "omogna": "omogen",
    "omognare": "omogen",
    "omognares": "omogen",
    "omognas": "omogen",
    "omognast": "omogen",
    "omognaste": "omogen",
    "omognastes": "omogen",
    "omognasts": "omogen",
    "omogne": "omogen",
    "omognes": "omogen",
    "omonoftongerade": "omonoftongerad",
    "omonoftongerades": "omonoftongerad",
    "omonoftongerads": "omonoftongerad",
    "omonoftongerat": "omonoftongerad",
    "omonoftongerats": "omonoftongerad",
    "omonoftongerbara": "omonoftongerbar",
    "omonoftongerbarare": "omonoftongerbar",
    "omonoftongerbarares": "omonoftongerbar",
    "omonoftongerbaras": "omonoftongerbar",
    "omonoftongerbarast": "omonoftongerbar",
    "omonoftongerbaraste": "omonoftongerbar",
    "omonoftongerbarastes": "omonoftongerbar",
    "omonoftongerbarasts": "omonoftongerbar",
    "omonoftongerbare": "omonoftongerbar",
    "omonoftongerbares": "omonoftongerbar",
    "omonoftongerbarheten": "omonoftongerbarhet",
    "omonoftongerbarhetens": "omonoftongerbarhet",
    "omonoftongerbarhets": "omonoftongerbarhet",
    "omonoftongerbars": "omonoftongerbar",
    "omonoftongerbart": "omonoftongerbar",
    "omonoftongerbarts": "omonoftongerbar",
    "omonopoliserade": "omonopoliserad",
    "omonopoliserades": "omonopoliserad",
    "omonopoliserads": "omonopoliserad",
    "omonopoliserat": "omonopoliserad",
    "omonopoliserats": "omonopoliserad",
    "omonopoliserbara": "omonopoliserbar",
    "omonopoliserbarare": "omonopoliserbar",
    "omonopoliserbarares": "omonopoliserbar",
    "omonopoliserbaras": "omonopoliserbar",
    "omonopoliserbarast": "omonopoliserbar",
    "omonopoliserbaraste": "omonopoliserbar",
    "omonopoliserbarastes": "omonopoliserbar",
    "omonopoliserbarasts": "omonopoliserbar",
    "omonopoliserbare": "omonopoliserbar",
    "omonopoliserbares": "omonopoliserbar",
    "omonopoliserbarheten": "omonopoliserbarhet",
    "omonopoliserbarhetens": "omonopoliserbarhet",
    "omonopoliserbarhets": "omonopoliserbarhet",
    "omonopoliserbars": "omonopoliserbar",
    "omonopoliserbart": "omonopoliserbar",
    "omonopoliserbarts": "omonopoliserbar",
    "omonterade": "omonterad",
    "omonterades": "omonterad",
    "omonterads": "omonterad",
    "omonterat": "omonterad",
    "omonterats": "omonterad",
    "omonterbara": "omonterbar",
    "omonterbarare": "omonterbar",
    "omonterbarares": "omonterbar",
    "omonterbaras": "omonterbar",
    "omonterbarast": "omonterbar",
    "omonterbaraste": "omonterbar",
    "omonterbarastes": "omonterbar",
    "omonterbarasts": "omonterbar",
    "omonterbare": "omonterbar",
    "omonterbares": "omonterbar",
    "omonterbarheten": "omonterbarhet",
    "omonterbarhetens": "omonterbarhet",
    "omonterbarhets": "omonterbarhet",
    "omonterbars": "omonterbar",
    "omonterbart": "omonterbar",
    "omonterbarts": "omonterbar",
    "omoppade": "omoppad",
    "omoppades": "omoppad",
    "omoppads": "omoppad",
    "omoppat": "omoppad",
    "omoppats": "omoppad",
    "omoralen": "omoral",
    "omoralens": "omoral",
    "omoraliska": "omoralisk",
    "omoraliskare": "omoralisk",
    "omoraliskares": "omoralisk",
    "omoraliskas": "omoralisk",
    "omoraliskast": "omoralisk",
    "omoraliskaste": "omoralisk",
    "omoraliskastes": "omoralisk",
    "omoraliskasts": "omoralisk",
    "omoraliske": "omoralisk",
    "omoraliskes": "omoralisk",
    "omoralisks": "omoralisk",
    "omoraliskt": "omoralisk",
    "omoraliskts": "omoralisk",
    "omorals": "omoral",
    "omorganisationen": "omorganisation",
    "omorganisationens": "omorganisation",
    "omorganisations": "omorganisation",
    "omorganiserad": "omorganisera",
    "omorganiserade": "omorganisera",
    "omorganiserades": "omorganisera",
    "omorganiserads": "omorganisera",
    "omorganiserande": "omorganisera",
    "omorganiseranden": "omorganiserande",
    "omorganiserandena": "omorganiserande",
    "omorganiserandenas": "omorganiserande",
    "omorganiserandens": "omorganiserande",
    "omorganiserandes": "omorganiserande",
    "omorganiserandet": "omorganiserande",
    "omorganiserandets": "omorganiserande",
    "omorganiserar": "omorganisera",
    "omorganiseras": "omorganisera",
    "omorganiserat": "omorganisera",
    "omorganiserats": "omorganisera",
    "omorganiserbara": "omorganiserbar",
    "omorganiserbarare": "omorganiserbar",
    "omorganiserbarares": "omorganiserbar",
    "omorganiserbaras": "omorganiserbar",
    "omorganiserbarast": "omorganiserbar",
    "omorganiserbaraste": "omorganiserbar",
    "omorganiserbarastes": "omorganiserbar",
    "omorganiserbarasts": "omorganiserbar",
    "omorganiserbare": "omorganiserbar",
    "omorganiserbares": "omorganiserbar",
    "omorganiserbarheten": "omorganiserbarhet",
    "omorganiserbarhetens": "omorganiserbarhet",
    "omorganiserbarhets": "omorganiserbarhet",
    "omorganiserbars": "omorganiserbar",
    "omorganiserbart": "omorganiserbar",
    "omorganiserbarts": "omorganiserbar",
    "omorganiseringar": "omorganisering",
    "omorganiseringarna": "omorganisering",
    "omorganiseringarnas": "omorganisering",
    "omorganiseringars": "omorganisering",
    "omorganiseringen": "omorganisering",
    "omorganiseringens": "omorganisering",
    "omorganiserings": "omorganisering",
    "omorgnade": "omorgnad",
    "omorgnades": "omorgnad",
    "omorgnads": "omorgnad",
    "omorgnat": "omorgnad",
    "omorgnats": "omorgnad",
    "omornade": "omornad",
    "omornades": "omornad",
    "omornads": "omornad",
    "omornat": "omornad",
    "omornats": "omornad",
    "omorserade": "omorserad",
    "omorserades": "omorserad",
    "omorserads": "omorserad",
    "omorserat": "omorserad",
    "omorserats": "omorserad",
    "omorserbara": "omorserbar",
    "omorserbarare": "omorserbar",
    "omorserbarares": "omorserbar",
    "omorserbaras": "omorserbar",
    "omorserbarast": "omorserbar",
    "omorserbaraste": "omorserbar",
    "omorserbarastes": "omorserbar",
    "omorserbarasts": "omorserbar",
    "omorserbare": "omorserbar",
    "omorserbares": "omorserbar",
    "omorserbarheten": "omorserbarhet",
    "omorserbarhetens": "omorserbarhet",
    "omorserbarhets": "omorserbarhet",
    "omorserbars": "omorserbar",
    "omorserbart": "omorserbar",
    "omorserbarts": "omorserbar",
    "omortificerade": "omortificerad",
    "omortificerades": "omortificerad",
    "omortificerads": "omortificerad",
    "omortificerat": "omortificerad",
    "omortificerats": "omortificerad",
    "omortificerbara": "omortificerbar",
    "omortificerbarare": "omortificerbar",
    "omortificerbarares": "omortificerbar",
    "omortificerbaras": "omortificerbar",
    "omortificerbarast": "omortificerbar",
    "omortificerbaraste": "omortificerbar",
    "omortificerbarastes": "omortificerbar",
    "omortificerbarasts": "omortificerbar",
    "omortificerbare": "omortificerbar",
    "omortificerbares": "omortificerbar",
    "omortificerbarheten": "omortificerbarhet",
    "omortificerbarhetens": "omortificerbarhet",
    "omortificerbarhets": "omortificerbarhet",
    "omortificerbars": "omortificerbar",
    "omortificerbart": "omortificerbar",
    "omortificerbarts": "omortificerbar",
    "omortifierade": "omortifierad",
    "omortifierades": "omortifierad",
    "omortifierads": "omortifierad",
    "omortifierat": "omortifierad",
    "omortifierats": "omortifierad",
    "omortifierbara": "omortifierbar",
    "omortifierbarare": "omortifierbar",
    "omortifierbarares": "omortifierbar",
    "omortifierbaras": "omortifierbar",
    "omortifierbarast": "omortifierbar",
    "omortifierbaraste": "omortifierbar",
    "omortifierbarastes": "omortifierbar",
    "omortifierbarasts": "omortifierbar",
    "omortifierbare": "omortifierbar",
    "omortifierbares": "omortifierbar",
    "omortifierbarheten": "omortifierbarhet",
    "omortifierbarhetens": "omortifierbarhet",
    "omortifierbarhets": "omortifierbarhet",
    "omortifierbars": "omortifierbar",
    "omortifierbart": "omortifierbar",
    "omortifierbarts": "omortifierbar",
    "omosade": "omosad",
    "omosades": "omosad",
    "omosads": "omosad",
    "omosat": "omosad",
    "omosats": "omosad",
    "omotade": "omotad",
    "omotades": "omotad",
    "omotads": "omotad",
    "omotarbetade": "omotarbetad",
    "omotarbetades": "omotarbetad",
    "omotarbetads": "omotarbetad",
    "omotarbetat": "omotarbetad",
    "omotarbetats": "omotarbetad",
    "omotat": "omotad",
    "omotats": "omotad",
    "omotbevisade": "omotbevisad",
    "omotbevisades": "omotbevisad",
    "omotbevisads": "omotbevisad",
    "omotbevisat": "omotbevisad",
    "omotbevisats": "omotbevisad",
    "omotiverade": "omotiverad",
    "omotiverades": "omotiverad",
    "omotiverads": "omotiverad",
    "omotiverat": "omotiverad",
    "omotiverats": "omotiverad",
    "omotiverbara": "omotiverbar",
    "omotiverbarare": "omotiverbar",
    "omotiverbarares": "omotiverbar",
    "omotiverbaras": "omotiverbar",
    "omotiverbarast": "omotiverbar",
    "omotiverbaraste": "omotiverbar",
    "omotiverbarastes": "omotiverbar",
    "omotiverbarasts": "omotiverbar",
    "omotiverbare": "omotiverbar",
    "omotiverbares": "omotiverbar",
    "omotiverbarheten": "omotiverbarhet",
    "omotiverbarhetens": "omotiverbarhet",
    "omotiverbarhets": "omotiverbarhet",
    "omotiverbars": "omotiverbar",
    "omotiverbart": "omotiverbar",
    "omotiverbarts": "omotiverbar",
    "omotlästa": "omotläst",
    "omotlästas": "omotläst",
    "omotläste": "omotläst",
    "omotlästes": "omotläst",
    "omotlästs": "omotläst",
    "omotoriserade": "omotoriserad",
    "omotoriserades": "omotoriserad",
    "omotoriserads": "omotoriserad",
    "omotoriserat": "omotoriserad",
    "omotoriserats": "omotoriserad",
    "omotoriserbara": "omotoriserbar",
    "omotoriserbarare": "omotoriserbar",
    "omotoriserbarares": "omotoriserbar",
    "omotoriserbaras": "omotoriserbar",
    "omotoriserbarast": "omotoriserbar",
    "omotoriserbaraste": "omotoriserbar",
    "omotoriserbarastes": "omotoriserbar",
    "omotoriserbarasts": "omotoriserbar",
    "omotoriserbare": "omotoriserbar",
    "omotoriserbares": "omotoriserbar",
    "omotoriserbarheten": "omotoriserbarhet",
    "omotoriserbarhetens": "omotoriserbarhet",
    "omotoriserbarhets": "omotoriserbarhet",
    "omotoriserbars": "omotoriserbar",
    "omotoriserbart": "omotoriserbar",
    "omotoriserbarts": "omotoriserbar",
    "omotsagda": "omotsagd",
    "omotsagdare": "omotsagd",
    "omotsagdares": "omotsagd",
    "omotsagdas": "omotsagd",
    "omotsagdast": "omotsagd",
    "omotsagdaste": "omotsagd",
    "omotsagdastes": "omotsagd",
    "omotsagdasts": "omotsagd",
    "omotsagde": "omotsagd",
    "omotsagdes": "omotsagd",
    "omotsagds": "omotsagd",
    "omotsagt": "omotsagd",
    "omotsagts": "omotsagd",
    "omotståndliga": "omotståndlig",
    "omotståndligare": "omotståndlig",
    "omotståndligares": "omotståndlig",
    "omotståndligas": "omotståndlig",
    "omotståndligast": "omotståndlig",
    "omotståndligaste": "omotståndlig",
    "omotståndligastes": "omotståndlig",
    "omotståndligasts": "omotståndlig",
    "omotståndlige": "omotståndlig",
    "omotståndliges": "omotståndlig",
    "omotståndligheten": "omotståndlighet",
    "omotståndlighetens": "omotståndlighet",
    "omotståndlighets": "omotståndlighet",
    "omotståndligs": "omotståndlig",
    "omotståndligt": "omotståndlig",
    "omotståndligts": "omotståndlig",
    "omotsägliga": "omotsäglig",
    "omotsägligare": "omotsäglig",
    "omotsägligares": "omotsäglig",
    "omotsägligas": "omotsäglig",
    "omotsägligast": "omotsäglig",
    "omotsägligaste": "omotsäglig",
    "omotsägligastes": "omotsäglig",
    "omotsägligasts": "omotsäglig",
    "omotsäglige": "omotsäglig",
    "omotsägliges": "omotsäglig",
    "omotsägligheten": "omotsäglighet",
    "omotsäglighetens": "omotsäglighet",
    "omotsäglighets": "omotsäglighet",
    "omotsägligs": "omotsäglig",
    "omotsägligt": "omotsäglig",
    "omotsägligts": "omotsäglig",
    "omottagliga": "omottaglig",
    "omottagligare": "omottaglig",
    "omottagligares": "omottaglig",
    "omottagligas": "omottaglig",
    "omottagligast": "omottaglig",
    "omottagligaste": "omottaglig",
    "omottagligastes": "omottaglig",
    "omottagligasts": "omottaglig",
    "omottaglige": "omottaglig",
    "omottagliges": "omottaglig",
    "omottagligheten": "omottaglighet",
    "omottaglighetens": "omottaglighet",
    "omottaglighets": "omottaglighet",
    "omottagligs": "omottaglig",
    "omottagligt": "omottaglig",
    "omottagligts": "omottaglig",
    "omotverkade": "omotverkad",
    "omotverkades": "omotverkad",
    "omotverkads": "omotverkad",
    "omotverkat": "omotverkad",
    "omotverkats": "omotverkad",
    "omotvägde": "omotvägd",
    "omotvägdes": "omotvägd",
    "omotvägds": "omotvägd",
    "omotvägt": "omotvägd",
    "omotvägts": "omotvägd",
    "omplacerad": "omplacera",
    "omplacerade": "omplacera",
    "omplacerades": "omplacera",
    "omplacerads": "omplacera",
    "omplacerande": "omplacera",
    "omplaceranden": "omplacerande",
    "omplacerandena": "omplacerande",
    "omplacerandenas": "omplacerande",
    "omplacerandens": "omplacerande",
    "omplacerandes": "omplacerande",
    "omplacerandet": "omplacerande",
    "omplacerandets": "omplacerande",
    "omplacerar": "omplacera",
    "omplaceras": "omplacera",
    "omplacerat": "omplacera",
    "omplacerats": "omplacera",
    "omplacerbara": "omplacerbar",
    "omplacerbarare": "omplacerbar",
    "omplacerbarares": "omplacerbar",
    "omplacerbaras": "omplacerbar",
    "omplacerbarast": "omplacerbar",
    "omplacerbaraste": "omplacerbar",
    "omplacerbarastes": "omplacerbar",
    "omplacerbarasts": "omplacerbar",
    "omplacerbare": "omplacerbar",
    "omplacerbares": "omplacerbar",
    "omplacerbarheten": "omplacerbarhet",
    "omplacerbarhetens": "omplacerbarhet",
    "omplacerbarhets": "omplacerbarhet",
    "omplacerbars": "omplacerbar",
    "omplacerbart": "omplacerbar",
    "omplacerbarts": "omplacerbar",
    "omplaceringar": "omplacering",
    "omplaceringarna": "omplacering",
    "omplaceringarnas": "omplacering",
    "omplaceringars": "omplacering",
    "omplaceringen": "omplacering",
    "omplaceringens": "omplacering",
    "omplacerings": "omplacering",
    "omplåstrad": "omplåstra",
    "omplåstrade": "omplåstra",
    "omplåstrades": "omplåstra",
    "omplåstrads": "omplåstra",
    "omplåstrande": "omplåstra",
    "omplåstranden": "omplåstrande",
    "omplåstrandena": "omplåstrande",
    "omplåstrandenas": "omplåstrande",
    "omplåstrandens": "omplåstrande",
    "omplåstrandes": "omplåstrande",
    "omplåstrandet": "omplåstrande",
    "omplåstrandets": "omplåstrande",
    "omplåstrar": "omplåstra",
    "omplåstras": "omplåstra",
    "omplåstrat": "omplåstra",
    "omplåstrats": "omplåstra",
    "ompröv": "ompröva",
    "omprövad": "ompröva",
    "omprövade": "ompröva",
    "omprövades": "ompröva",
    "omprövads": "ompröva",
    "omprövande": "ompröva",
    "omprövanden": "omprövande",
    "omprövandena": "omprövande",
    "omprövandenas": "omprövande",
    "omprövandens": "omprövande",
    "omprövandes": "omprövande",
    "omprövandet": "omprövande",
    "omprövandets": "omprövande",
    "omprövar": "ompröva",
    "omprövas": "ompröva",
    "omprövat": "ompröva",
    "omprövats": "ompröva",
    "omprövningar": "omprövning",
    "omprövningarna": "omprövning",
    "omprövningarnas": "omprövning",
    "omprövningars": "omprövning",
    "omprövningen": "omprövning",
    "omprövningens": "omprövning",
    "omprövnings": "omprövning",
    "omram": "omrama",
    "omramad": "omrama",
    "omramade": "omrama",
    "omramades": "omrama",
    "omramads": "omrama",
    "omramande": "omrama",
    "omramanden": "omramande",
    "omramandena": "omramande",
    "omramandenas": "omramande",
    "omramandens": "omramande",
    "omramandes": "omramande",
    "omramandet": "omramande",
    "omramandets": "omramande",
    "omramar": "omrama",
    "omramas": "omrama",
    "omramat": "omrama",
    "omramats": "omrama",
    "omriktar": "omriktare",
    "omriktaren": "omriktare",
    "omriktarens": "omriktare",
    "omriktares": "omriktare",
    "omriktarna": "omriktare",
    "omriktarnas": "omriktare",
    "omring": "omringa",
    "omringad": "omringa",
    "omringade": "omringa",
    "omringades": "omringa",
    "omringads": "omringa",
    "omringande": "omringa",
    "omringanden": "omringande",
    "omringandena": "omringande",
    "omringandenas": "omringande",
    "omringandens": "omringande",
    "omringandes": "omringande",
    "omringandet": "omringande",
    "omringandets": "omringande",
    "omringar": "omringa",
    "omringas": "omringa",
    "omringat": "omringa",
    "omringats": "omringa",
    "omringningar": "omringning",
    "omringningarna": "omringning",
    "omringningarnas": "omringning",
    "omringningars": "omringning",
    "omringningen": "omringning",
    "omringningens": "omringning",
    "omringnings": "omringning",
    "omräknad": "omräkna",
    "omräknade": "omräkna",
    "omräknades": "omräkna",
    "omräknads": "omräkna",
    "omräknande": "omräkna",
    "omräknanden": "omräknande",
    "omräknandena": "omräknande",
    "omräknandenas": "omräknande",
    "omräknandens": "omräknande",
    "omräknandes": "omräknande",
    "omräknandet": "omräknande",
    "omräknandets": "omräknande",
    "omräknar": "omräkna",
    "omräknas": "omräkna",
    "omräknat": "omräkna",
    "omräknats": "omräkna",
    "omräkningar": "omräkning",
    "omräkningarna": "omräkning",
    "omräkningarnas": "omräkning",
    "omräkningars": "omräkning",
    "omräkningen": "omräkning",
    "omräkningens": "omräkning",
    "omräknings": "omräkning",
    "områden": "område",
    "områdena": "område",
    "områdenas": "område",
    "områdens": "område",
    "områdes": "område",
    "området": "område",
    "områdets": "område",
    "omröringar": "omröring",
    "omröringarna": "omröring",
    "omröringarnas": "omröring",
    "omröringars": "omröring",
    "omröringen": "omröring",
    "omröringens": "omröring",
    "omrörings": "omröring",
    "omrörningar": "omrörning",
    "omrörningarna": "omrörning",
    "omrörningarnas": "omrörning",
    "omrörningars": "omrörning",
    "omrörningen": "omrörning",
    "omrörningens": "omrörning",
    "omrörnings": "omrörning",
    "omröstningar": "omröstning",
    "omröstningarna": "omröstning",
    "omröstningarnas": "omröstning",
    "omröstningars": "omröstning",
    "omröstningen": "omröstning",
    "omröstningens": "omröstning",
    "omröstnings": "omröstning",
    "omsatt": "omsätta",
    "omsatta": "omsätta",
    "omsattas": "omsätta",
    "omsatte": "omsätta",
    "omsattes": "omsätta",
    "omsatts": "omsätta",
    "omsedd": "omse",
    "omsedda": "omse",
    "omseddas": "omse",
    "omsedde": "omse",
    "omseddes": "omse",
    "omsedds": "omse",
    "omseende": "omse",
    "omseenden": "omseende",
    "omseendena": "omseende",
    "omseendenas": "omseende",
    "omseendens": "omseende",
    "omseendes": "omseende",
    "omseendet": "omseende",
    "omseendets": "omseende",
    "omseglingar": "omsegling",
    "omseglingarna": "omsegling",
    "omseglingarnas": "omsegling",
    "omseglingars": "omsegling",
    "omseglingen": "omsegling",
    "omseglingens": "omsegling",
    "omseglings": "omsegling",
    "omsen": "oms",
    "omsens": "oms",
    "omser": "omse",
    "omses": "omse",
    "omsett": "omse",
    "omsetts": "omse",
    "omskakade": "omskakad",
    "omskakades": "omskakad",
    "omskakads": "omskakad",
    "omskakat": "omskakad",
    "omskakats": "omskakad",
    "omskap": "omskapa",
    "omskapad": "omskapa",
    "omskapade": "omskapa",
    "omskapades": "omskapa",
    "omskapads": "omskapa",
    "omskapande": "omskapa",
    "omskapanden": "omskapande",
    "omskapandena": "omskapande",
    "omskapandenas": "omskapande",
    "omskapandens": "omskapande",
    "omskapandes": "omskapande",
    "omskapandet": "omskapande",
    "omskapandets": "omskapande",
    "omskapar": "omskapa",
    "omskapas": "omskapa",
    "omskapat": "omskapa",
    "omskapats": "omskapa",
    "omskar": "omskära",
    "omskars": "omskära",
    "omskiftar": "omskiftare",
    "omskiftaren": "omskiftare",
    "omskiftarens": "omskiftare",
    "omskiftares": "omskiftare",
    "omskiftarna": "omskiftare",
    "omskiftarnas": "omskiftare",
    "omskiftartangenten": "omskiftartangent",
    "omskiftartangentens": "omskiftartangent",
    "omskiftartangenter": "omskiftartangent",
    "omskiftartangenterna": "omskiftartangent",
    "omskiftartangenternas": "omskiftartangent",
    "omskiftartangenters": "omskiftartangent",
    "omskiftartangents": "omskiftartangent",
    "omskol": "omskola",
    "omskolad": "omskola",
    "omskolade": "omskola",
    "omskolades": "omskola",
    "omskolads": "omskola",
    "omskolande": "omskola",
    "omskolanden": "omskolande",
    "omskolandena": "omskolande",
    "omskolandenas": "omskolande",
    "omskolandens": "omskolande",
    "omskolandes": "omskolande",
    "omskolandet": "omskolande",
    "omskolandets": "omskolande",
    "omskolar": "omskola",
    "omskolas": "omskola",
    "omskolat": "omskola",
    "omskolats": "omskola",
    "omskolningar": "omskolning",
    "omskolningarna": "omskolning",
    "omskolningarnas": "omskolning",
    "omskolningars": "omskolning",
    "omskolningen": "omskolning",
    "omskolningens": "omskolning",
    "omskolnings": "omskolning",
    "omskrev": "omskriva",
    "omskrevs": "omskriva",
    "omskriv": "omskriva",
    "omskrivande": "omskriva",
    "omskrivanden": "omskrivande",
    "omskrivandena": "omskrivande",
    "omskrivandenas": "omskrivande",
    "omskrivandens": "omskrivande",
    "omskrivandes": "omskrivande",
    "omskrivandet": "omskrivande",
    "omskrivandets": "omskrivande",
    "omskrivas": "omskriva",
    "omskrive": "omskriva",
    "omskriven": "omskriva",
    "omskrivens": "omskriven",
    "omskriver": "omskriva",
    "omskrives": "omskriva",
    "omskrivet": "omskriven",
    "omskrivets": "omskriven",
    "omskrivit": "omskriva",
    "omskrivits": "omskriva",
    "omskrivna": "omskriven",
    "omskrivnare": "omskriven",
    "omskrivnares": "omskriven",
    "omskrivnas": "omskriven",
    "omskrivnast": "omskriven",
    "omskrivnaste": "omskriven",
    "omskrivnastes": "omskriven",
    "omskrivnasts": "omskriven",
    "omskrivne": "omskriven",
    "omskrivnes": "omskriven",
    "omskrivningar": "omskrivning",
    "omskrivningarna": "omskrivning",
    "omskrivningarnas": "omskrivning",
    "omskrivningars": "omskrivning",
    "omskrivningen": "omskrivning",
    "omskrivningens": "omskrivning",
    "omskrivnings": "omskrivning",
    "omskrivs": "omskriva",
    "omskrutens": "omskruten",
    "omskrutet": "omskruten",
    "omskrutets": "omskruten",
    "omskrutna": "omskruten",
    "omskrutnare": "omskruten",
    "omskrutnares": "omskruten",
    "omskrutnas": "omskruten",
    "omskrutnast": "omskruten",
    "omskrutnaste": "omskruten",
    "omskrutnastes": "omskruten",
    "omskrutnasts": "omskruten",
    "omskrutne": "omskruten",
    "omskrutnes": "omskruten",
    "omskulpturerad": "omskulpturera",
    "omskulpturerade": "omskulpturera",
    "omskulpturerades": "omskulpturera",
    "omskulpturerads": "omskulpturera",
    "omskulpturerande": "omskulpturera",
    "omskulptureranden": "omskulpturerande",
    "omskulpturerandena": "omskulpturerande",
    "omskulpturerandenas": "omskulpturerande",
    "omskulpturerandens": "omskulpturerande",
    "omskulpturerandes": "omskulpturerande",
    "omskulpturerandet": "omskulpturerande",
    "omskulpturerandets": "omskulpturerande",
    "omskulpturerar": "omskulpturera",
    "omskulptureras": "omskulpturera",
    "omskulpturerat": "omskulpturera",
    "omskulpturerats": "omskulpturera",
    "omskulpturerbara": "omskulpturerbar",
    "omskulpturerbarare": "omskulpturerbar",
    "omskulpturerbarares": "omskulpturerbar",
    "omskulpturerbaras": "omskulpturerbar",
    "omskulpturerbarast": "omskulpturerbar",
    "omskulpturerbaraste": "omskulpturerbar",
    "omskulpturerbarastes": "omskulpturerbar",
    "omskulpturerbarasts": "omskulpturerbar",
    "omskulpturerbare": "omskulpturerbar",
    "omskulpturerbares": "omskulpturerbar",
    "omskulpturerbarheten": "omskulpturerbarhet",
    "omskulpturerbarhetens": "omskulpturerbarhet",
    "omskulpturerbarhets": "omskulpturerbarhet",
    "omskulpturerbars": "omskulpturerbar",
    "omskulpturerbart": "omskulpturerbar",
    "omskulpturerbarts": "omskulpturerbar",
    "omskulptureringar": "omskulpturering",
    "omskulptureringarna": "omskulpturering",
    "omskulptureringarnas": "omskulpturering",
    "omskulptureringars": "omskulpturering",
    "omskulptureringen": "omskulpturering",
    "omskulptureringens": "omskulpturering",
    "omskulpturerings": "omskulpturering",
    "omskure": "omskära",
    "omskuren": "omskära",
    "omskurens": "omskära",
    "omskures": "omskära",
    "omskuret": "omskära",
    "omskurets": "omskära",
    "omskurit": "omskära",
    "omskurits": "omskära",
    "omskurna": "omskära",
    "omskurnas": "omskära",
    "omskurne": "omskära",
    "omskurnes": "omskära",
    "omskär": "omskära",
    "omskärande": "omskära",
    "omskäranden": "omskärande",
    "omskärandena": "omskärande",
    "omskärandenas": "omskärande",
    "omskärandens": "omskärande",
    "omskärandes": "omskärande",
    "omskärandet": "omskärande",
    "omskärandets": "omskärande",
    "omskäras": "omskära",
    "omskäre": "omskära",
    "omskärelsen": "omskärelse",
    "omskärelsens": "omskärelse",
    "omskärelser": "omskärelse",
    "omskärelserna": "omskärelse",
    "omskärelsernas": "omskärelse",
    "omskärelsers": "omskärelse",
    "omskärelses": "omskärelse",
    "omskäres": "omskära",
    "omskärs": "omskära",
    "omsköt": "omsköta",
    "omskötande": "omsköta",
    "omskötanden": "omskötande",
    "omskötandena": "omskötande",
    "omskötandenas": "omskötande",
    "omskötandens": "omskötande",
    "omskötandes": "omskötande",
    "omskötandet": "omskötande",
    "omskötandets": "omskötande",
    "omskötas": "omsköta",
    "omsköter": "omsköta",
    "omskötes": "omsköta",
    "omsköts": "omsköta",
    "omskött": "omsköta",
    "omskötta": "omsköta",
    "omsköttas": "omsköta",
    "omskötte": "omsköta",
    "omsköttes": "omsköta",
    "omskötts": "omsköta",
    "omslagen": "omslag",
    "omslagens": "omslag",
    "omslaget": "omslag",
    "omslagets": "omslag",
    "omslags": "omslag",
    "omslagsbilden": "omslagsbild",
    "omslagsbildens": "omslagsbild",
    "omslagsbilder": "omslagsbild",
    "omslagsbilderna": "omslagsbild",
    "omslagsbildernas": "omslagsbild",
    "omslagsbilders": "omslagsbild",
    "omslagsbilds": "omslagsbild",
    "omslagspapperen": "omslagspapper",
    "omslagspapperens": "omslagspapper",
    "omslagspapperet": "omslagspapper",
    "omslagspapperets": "omslagspapper",
    "omslagspapperna": "omslagspapper",
    "omslagspappernas": "omslagspapper",
    "omslagspappers": "omslagspapper",
    "omslagspappren": "omslagspapper",
    "omslagspapprens": "omslagspapper",
    "omslagspappret": "omslagspapper",
    "omslagspapprets": "omslagspapper",
    "omslagsreversen": "omslagsrevers",
    "omslagsreversens": "omslagsrevers",
    "omslagsreverser": "omslagsrevers",
    "omslagsreverserna": "omslagsrevers",
    "omslagsreversernas": "omslagsrevers",
    "omslagsreversers": "omslagsrevers",
    "omslingrad": "omslingra",
    "omslingrade": "omslingra",
    "omslingrades": "omslingra",
    "omslingrads": "omslingra",
    "omslingrande": "omslingra",
    "omslingranden": "omslingrande",
    "omslingrandena": "omslingrande",
    "omslingrandenas": "omslingrande",
    "omslingrandens": "omslingrande",
    "omslingrandes": "omslingrande",
    "omslingrandet": "omslingrande",
    "omslingrandets": "omslingrande",
    "omslingrar": "omslingra",
    "omslingras": "omslingra",
    "omslingrat": "omslingra",
    "omslingrats": "omslingra",
    "omslut": "omsluta",
    "omslutande": "omsluta",
    "omslutanden": "omslutande",
    "omslutandena": "omslutande",
    "omslutandenas": "omslutande",
    "omslutandens": "omslutande",
    "omslutandes": "omslutande",
    "omslutandet": "omslutande",
    "omslutandets": "omslutande",
    "omslutas": "omsluta",
    "omslute": "omsluta",
    "omsluten": "omsluta",
    "omslutens": "omsluta",
    "omsluter": "omsluta",
    "omslutes": "omsluta",
    "omslutet": "omsluta",
    "omslutets": "omsluta",
    "omslutit": "omsluta",
    "omslutits": "omsluta",
    "omslutna": "omsluta",
    "omslutnas": "omsluta",
    "omslutne": "omsluta",
    "omslutnes": "omsluta",
    "omslutningar": "omslutning",
    "omslutningarna": "omslutning",
    "omslutningarnas": "omslutning",
    "omslutningars": "omslutning",
    "omslutningen": "omslutning",
    "omslutningens": "omslutning",
    "omslutnings": "omslutning",
    "omsluts": "omsluta",
    "omslöt": "omsluta",
    "omslöte": "omsluta",
    "omslötes": "omsluta",
    "omslöts": "omsluta",
    "omsorgen": "omsorg",
    "omsorgens": "omsorg",
    "omsorger": "omsorg",
    "omsorgerna": "omsorg",
    "omsorgernas": "omsorg",
    "omsorgers": "omsorg",
    "omsorgs": "omsorg",
    "omsorgsfulla": "omsorgsfull",
    "omsorgsfullare": "omsorgsfull",
    "omsorgsfullares": "omsorgsfull",
    "omsorgsfullas": "omsorgsfull",
    "omsorgsfullast": "omsorgsfull",
    "omsorgsfullaste": "omsorgsfull",
    "omsorgsfullastes": "omsorgsfull",
    "omsorgsfullasts": "omsorgsfull",
    "omsorgsfulle": "omsorgsfull",
    "omsorgsfulles": "omsorgsfull",
    "omsorgsfullheten": "omsorgsfullhet",
    "omsorgsfullhetens": "omsorgsfullhet",
    "omsorgsfullheter": "omsorgsfullhet",
    "omsorgsfullheterna": "omsorgsfullhet",
    "omsorgsfullheternas": "omsorgsfullhet",
    "omsorgsfullheters": "omsorgsfullhet",
    "omsorgsfullhets": "omsorgsfullhet",
    "omsorgsfulls": "omsorgsfull",
    "omsorgsfullt": "omsorgsfull",
    "omsorgsfullts": "omsorgsfull",
    "omsorgsvården": "omsorgsvård",
    "omsorgsvårdens": "omsorgsvård",
    "omsorgsvårds": "omsorgsvård",
    "omspann": "omspinna",
    "omspanns": "omspinna",
    "omspelen": "omspel",
    "omspelens": "omspel",
    "omspelet": "omspel",
    "omspelets": "omspel",
    "omspels": "omspel",
    "omspinn": "omspinna",
    "omspinnande": "omspinna",
    "omspinnanden": "omspinnande",
    "omspinnandena": "omspinnande",
    "omspinnandenas": "omspinnande",
    "omspinnandens": "omspinnande",
    "omspinnandes": "omspinnande",
    "omspinnandet": "omspinnande",
    "omspinnandets": "omspinnande",
    "omspinnas": "omspinna",
    "omspinne": "omspinna",
    "omspinner": "omspinna",
    "omspinnes": "omspinna",
    "omspinns": "omspinna",
    "omspunna": "omspinna",
    "omspunnas": "omspinna",
    "omspunne": "omspinna",
    "omspunnen": "omspinna",
    "omspunnens": "omspinna",
    "omspunnes": "omspinna",
    "omspunnet": "omspinna",
    "omspunnets": "omspinna",
    "omspunnit": "omspinna",
    "omspunnits": "omspinna",
    "omspänd": "omspänna",
    "omspända": "omspänna",
    "omspändas": "omspänna",
    "omspände": "omspänna",
    "omspändes": "omspänna",
    "omspänds": "omspänna",
    "omspänn": "omspänna",
    "omspännande": "omspänna",
    "omspännanden": "omspännande",
    "omspännandena": "omspännande",
    "omspännandenas": "omspännande",
    "omspännandens": "omspännande",
    "omspännandes": "omspännande",
    "omspännandet": "omspännande",
    "omspännandets": "omspännande",
    "omspännas": "omspänna",
    "omspänner": "omspänna",
    "omspännes": "omspänna",
    "omspänns": "omspänna",
    "omspänt": "omspänna",
    "omspänts": "omspänna",
    "omstarten": "omstart",
    "omstartens": "omstart",
    "omstarter": "omstart",
    "omstarterna": "omstart",
    "omstarternas": "omstart",
    "omstarters": "omstart",
    "omstarts": "omstart",
    "omstigningar": "omstigning",
    "omstigningarna": "omstigning",
    "omstigningarnas": "omstigning",
    "omstigningars": "omstigning",
    "omstigningen": "omstigning",
    "omstigningens": "omstigning",
    "omstignings": "omstigning",
    "omstridda": "omstridd",
    "omstriddare": "omstridd",
    "omstriddares": "omstridd",
    "omstriddas": "omstridd",
    "omstriddast": "omstridd",
    "omstriddaste": "omstridd",
    "omstriddastes": "omstridd",
    "omstriddasts": "omstridd",
    "omstridde": "omstridd",
    "omstriddes": "omstridd",
    "omstriddheten": "omstriddhet",
    "omstriddhetens": "omstriddhet",
    "omstriddhets": "omstriddhet",
    "omstridds": "omstridd",
    "omstritt": "omstridd",
    "omstritts": "omstridd",
    "omstrukturerad": "omstrukturera",
    "omstrukturerade": "omstrukturera",
    "omstrukturerades": "omstrukturera",
    "omstrukturerads": "omstrukturera",
    "omstrukturerande": "omstrukturera",
    "omstruktureranden": "omstrukturerande",
    "omstrukturerandena": "omstrukturerande",
    "omstrukturerandenas": "omstrukturerande",
    "omstrukturerandens": "omstrukturerande",
    "omstrukturerandes": "omstrukturerande",
    "omstrukturerandet": "omstrukturerande",
    "omstrukturerandets": "omstrukturerande",
    "omstrukturerar": "omstrukturera",
    "omstruktureras": "omstrukturera",
    "omstrukturerat": "omstrukturera",
    "omstrukturerats": "omstrukturera",
    "omstrukturerbara": "omstrukturerbar",
    "omstrukturerbarare": "omstrukturerbar",
    "omstrukturerbarares": "omstrukturerbar",
    "omstrukturerbaras": "omstrukturerbar",
    "omstrukturerbarast": "omstrukturerbar",
    "omstrukturerbaraste": "omstrukturerbar",
    "omstrukturerbarastes": "omstrukturerbar",
    "omstrukturerbarasts": "omstrukturerbar",
    "omstrukturerbare": "omstrukturerbar",
    "omstrukturerbares": "omstrukturerbar",
    "omstrukturerbarheten": "omstrukturerbarhet",
    "omstrukturerbarhetens": "omstrukturerbarhet",
    "omstrukturerbarhets": "omstrukturerbarhet",
    "omstrukturerbars": "omstrukturerbar",
    "omstrukturerbart": "omstrukturerbar",
    "omstrukturerbarts": "omstrukturerbar",
    "omstruktureringar": "omstrukturering",
    "omstruktureringarna": "omstrukturering",
    "omstruktureringarnas": "omstrukturering",
    "omstruktureringars": "omstrukturering",
    "omstruktureringen": "omstrukturering",
    "omstruktureringens": "omstrukturering",
    "omstrukturerings": "omstrukturering",
    "omstrål": "omstråla",
    "omstrålad": "omstråla",
    "omstrålade": "omstråla",
    "omstrålades": "omstråla",
    "omstrålads": "omstråla",
    "omstrålande": "omstråla",
    "omstrålanden": "omstrålande",
    "omstrålandena": "omstrålande",
    "omstrålandenas": "omstrålande",
    "omstrålandens": "omstrålande",
    "omstrålandes": "omstrålande",
    "omstrålandet": "omstrålande",
    "omstrålandets": "omstrålande",
    "omstrålar": "omstråla",
    "omstrålas": "omstråla",
    "omstrålat": "omstråla",
    "omstrålats": "omstråla",
    "omställ": "omställa",
    "omställande": "omställa",
    "omställanden": "omställande",
    "omställandena": "omställande",
    "omställandenas": "omställande",
    "omställandens": "omställande",
    "omställandes": "omställande",
    "omställandet": "omställande",
    "omställandets": "omställande",
    "omställas": "omställa",
    "omställd": "omställa",
    "omställda": "omställa",
    "omställdas": "omställa",
    "omställde": "omställa",
    "omställdes": "omställa",
    "omställds": "omställa",
    "omställer": "omställa",
    "omställes": "omställa",
    "omställningar": "omställning",
    "omställningarna": "omställning",
    "omställningarnas": "omställning",
    "omställningars": "omställning",
    "omställningen": "omställning",
    "omställningens": "omställning",
    "omställnings": "omställning",
    "omställningsbara": "omställningsbar",
    "omställningsbaras": "omställningsbar",
    "omställningsbare": "omställningsbar",
    "omställningsbares": "omställningsbar",
    "omställningsbars": "omställningsbar",
    "omställningsbart": "omställningsbar",
    "omställningsbarts": "omställningsbar",
    "omställs": "omställa",
    "omställt": "omställa",
    "omställts": "omställa",
    "omständiga": "omständig",
    "omständigare": "omständig",
    "omständigares": "omständig",
    "omständigas": "omständig",
    "omständigast": "omständig",
    "omständigaste": "omständig",
    "omständigastes": "omständig",
    "omständigasts": "omständig",
    "omständige": "omständig",
    "omständiges": "omständig",
    "omständigheten": "omständighet",
    "omständighetens": "omständighet",
    "omständigheter": "omständighet",
    "omständigheterna": "omständighet",
    "omständigheternas": "omständighet",
    "omständigheters": "omständighet",
    "omständighets": "omständighet",
    "omständigs": "omständig",
    "omständigt": "omständig",
    "omständigts": "omständig",
    "omständliga": "omständlig",
    "omständligare": "omständlig",
    "omständligares": "omständlig",
    "omständligas": "omständlig",
    "omständligast": "omständlig",
    "omständligaste": "omständlig",
    "omständligastes": "omständlig",
    "omständligasts": "omständlig",
    "omständlige": "omständlig",
    "omständliges": "omständlig",
    "omständligheten": "omständlighet",
    "omständlighetens": "omständlighet",
    "omständlighets": "omständlighet",
    "omständligs": "omständlig",
    "omständligt": "omständlig",
    "omständligts": "omständlig",
    "omstöp": "omstöpa",
    "omstöpande": "omstöpa",
    "omstöpanden": "omstöpande",
    "omstöpandena": "omstöpande",
    "omstöpandenas": "omstöpande",
    "omstöpandens": "omstöpande",
    "omstöpandes": "omstöpande",
    "omstöpandet": "omstöpande",
    "omstöpandets": "omstöpande",
    "omstöpas": "omstöpa",
    "omstöper": "omstöpa",
    "omstöpes": "omstöpa",
    "omstöps": "omstöpa",
    "omstöpt": "omstöpa",
    "omstöpta": "omstöpa",
    "omstöptas": "omstöpa",
    "omstöpte": "omstöpa",
    "omstöptes": "omstöpa",
    "omstöpts": "omstöpa",
    "omstört": "omstörta",
    "omstörtad": "omstörta",
    "omstörtade": "omstörta",
    "omstörtades": "omstörta",
    "omstörtads": "omstörta",
    "omstörtande": "omstörta",
    "omstörtanden": "omstörtande",
    "omstörtandena": "omstörtande",
    "omstörtandenas": "omstörtande",
    "omstörtandens": "omstörtande",
    "omstörtandes": "omstörtande",
    "omstörtandet": "omstörtande",
    "omstörtandets": "omstörtande",
    "omstörtar": "omstörta",
    "omstörtas": "omstörta",
    "omstörtat": "omstörta",
    "omstörtats": "omstörta",
    "omsusade": "omsusad",
    "omsusades": "omsusad",
    "omsusads": "omsusad",
    "omsusat": "omsusad",
    "omsusats": "omsusad",
    "omsvep": "omsvepa",
    "omsvepande": "omsvepa",
    "omsvepanden": "omsvepande",
    "omsvepandena": "omsvepande",
    "omsvepandenas": "omsvepande",
    "omsvepandens": "omsvepande",
    "omsvepandes": "omsvepande",
    "omsvepandet": "omsvepande",
    "omsvepandets": "omsvepande",
    "omsvepas": "omsvepa",
    "omsveper": "omsvepa",
    "omsvepes": "omsvepa",
    "omsveps": "omsvepa",
    "omsvept": "omsvepa",
    "omsvepta": "omsvepa",
    "omsveptas": "omsvepa",
    "omsvepte": "omsvepa",
    "omsveptes": "omsvepa",
    "omsvepts": "omsvepa",
    "omsvingar": "omsving",
    "omsvingarna": "omsving",
    "omsvingarnas": "omsving",
    "omsvingars": "omsving",
    "omsvingen": "omsving",
    "omsvingens": "omsving",
    "omsvings": "omsving",
    "omsvängningar": "omsvängning",
    "omsvängningarna": "omsvängning",
    "omsvängningarnas": "omsvängning",
    "omsvängningars": "omsvängning",
    "omsvängningen": "omsvängning",
    "omsvängningens": "omsvängning",
    "omsvängnings": "omsvängning",
    "omsvärm": "omsvärma",
    "omsvärmad": "omsvärma",
    "omsvärmade": "omsvärma",
    "omsvärmades": "omsvärma",
    "omsvärmads": "omsvärma",
    "omsvärmande": "omsvärma",
    "omsvärmanden": "omsvärmande",
    "omsvärmandena": "omsvärmande",
    "omsvärmandenas": "omsvärmande",
    "omsvärmandens": "omsvärmande",
    "omsvärmandes": "omsvärmande",
    "omsvärmandet": "omsvärmande",
    "omsvärmandets": "omsvärmande",
    "omsvärmar": "omsvärma",
    "omsvärmas": "omsvärma",
    "omsvärmat": "omsvärma",
    "omsvärmats": "omsvärma",
    "omsynen": "omsyn",
    "omsynens": "omsyn",
    "omsyns": "omsyn",
    "omsätt": "omsätta",
    "omsättande": "omsätta",
    "omsättanden": "omsättande",
    "omsättandena": "omsättande",
    "omsättandenas": "omsättande",
    "omsättandens": "omsättande",
    "omsättandes": "omsättande",
    "omsättandet": "omsättande",
    "omsättandets": "omsättande",
    "omsättas": "omsätta",
    "omsätter": "omsätta",
    "omsättes": "omsätta",
    "omsättningar": "omsättning",
    "omsättningarna": "omsättning",
    "omsättningarnas": "omsättning",
    "omsättningars": "omsättning",
    "omsättningen": "omsättning",
    "omsättningens": "omsättning",
    "omsättnings": "omsättning",
    "omsättningsskatten": "omsättningsskatt",
    "omsättningsskattens": "omsättningsskatt",
    "omsättningsskatter": "omsättningsskatt",
    "omsättningsskatterna": "omsättningsskatt",
    "omsättningsskatternas": "omsättningsskatt",
    "omsättningsskatters": "omsättningsskatt",
    "omsättningsskatts": "omsättningsskatt",
    "omsättningstillgångar": "omsättningstillgång",
    "omsättningstillgångarna": "omsättningstillgång",
    "omsättningstillgångarnas": "omsättningstillgång",
    "omsättningstillgångars": "omsättningstillgång",
    "omsättningstillgången": "omsättningstillgång",
    "omsättningstillgångens": "omsättningstillgång",
    "omsättningstillgångs": "omsättningstillgång",
    "omsätts": "omsätta",
    "omsåg": "omse",
    "omsåge": "omse",
    "omsåges": "omse",
    "omsågs": "omse",
    "omtag": "omta",
    "omtaga": "omta",
    "omtagande": "omta",
    "omtaganden": "omtagande",
    "omtagandena": "omtagande",
    "omtagandenas": "omtagande",
    "omtagandens": "omtagande",
    "omtagandes": "omtagande",
    "omtagandet": "omtagande",
    "omtagandets": "omtagande",
    "omtagas": "omta",
    "omtage": "omta",
    "omtagen": "omtag",
    "omtagens": "omtag",
    "omtager": "omta",
    "omtages": "omta",
    "omtaget": "omtag",
    "omtagets": "omtag",
    "omtagit": "omta",
    "omtagits": "omta",
    "omtagna": "omta",
    "omtagnas": "omta",
    "omtagne": "omta",
    "omtagnes": "omta",
    "omtagningar": "omtagning",
    "omtagningarna": "omtagning",
    "omtagningarnas": "omtagning",
    "omtagningars": "omtagning",
    "omtagningen": "omtagning",
    "omtagningens": "omtagning",
    "omtagnings": "omtagning",
    "omtags": "omtag",
    "omtalad": "omtala",
    "omtalade": "omtalad",
    "omtalades": "omtalad",
    "omtalads": "omtalad",
    "omtalande": "omtala",
    "omtalanden": "omtalande",
    "omtalandena": "omtalande",
    "omtalandenas": "omtalande",
    "omtalandens": "omtalande",
    "omtalandes": "omtalande",
    "omtalandet": "omtalande",
    "omtalandets": "omtalande",
    "omtalar": "omtala",
    "omtalas": "omtala",
    "omtalat": "omtalad",
    "omtalats": "omtalad",
    "omtalen": "omtal",
    "omtalens": "omtal",
    "omtalet": "omtal",
    "omtalets": "omtal",
    "omtals": "omtal",
    "omtanken": "omtanke",
    "omtankens": "omtanke",
    "omtankes": "omtanke",
    "omtar": "omta",
    "omtas": "omta",
    "omtog": "omta",
    "omtoge": "omta",
    "omtoges": "omta",
    "omtogs": "omta",
    "omtolk": "omtolka",
    "omtolkad": "omtolka",
    "omtolkade": "omtolka",
    "omtolkades": "omtolka",
    "omtolkads": "omtolka",
    "omtolkande": "omtolka",
    "omtolkanden": "omtolkande",
    "omtolkandena": "omtolkande",
    "omtolkandenas": "omtolkande",
    "omtolkandens": "omtolkande",
    "omtolkandes": "omtolkande",
    "omtolkandet": "omtolkande",
    "omtolkandets": "omtolkande",
    "omtolkar": "omtolka",
    "omtolkas": "omtolka",
    "omtolkat": "omtolka",
    "omtolkats": "omtolka",
    "omtrycken": "omtryck",
    "omtryckens": "omtryck",
    "omtrycket": "omtryck",
    "omtryckets": "omtryck",
    "omtrycks": "omtryck",
    "omtuggade": "omtuggad",
    "omtuggades": "omtuggad",
    "omtuggads": "omtuggad",
    "omtuggat": "omtuggad",
    "omtuggats": "omtuggad",
    "omtumlade": "omtumlad",
    "omtumlades": "omtumlad",
    "omtumlads": "omtumlad",
    "omtumlat": "omtumlad",
    "omtumlats": "omtumlad",
    "omtvistade": "omtvistad",
    "omtvistades": "omtvistad",
    "omtvistads": "omtvistad",
    "omtvistat": "omtvistad",
    "omtvistats": "omtvistad",
    "omtyckta": "omtyckt",
    "omtycktare": "omtyckt",
    "omtycktares": "omtyckt",
    "omtycktas": "omtyckt",
    "omtycktast": "omtyckt",
    "omtycktaste": "omtyckt",
    "omtycktastes": "omtyckt",
    "omtycktasts": "omtyckt",
    "omtyckte": "omtyckt",
    "omtycktes": "omtyckt",
    "omtycktheten": "omtyckthet",
    "omtyckthetens": "omtyckthet",
    "omtyckthets": "omtyckthet",
    "omtyckts": "omtyckt",
    "omtänksamheten": "omtänksamhet",
    "omtänksamhetens": "omtänksamhet",
    "omtänksamhets": "omtänksamhet",
    "omtänksamma": "omtänksam",
    "omtänksammare": "omtänksam",
    "omtänksammares": "omtänksam",
    "omtänksammas": "omtänksam",
    "omtänksammast": "omtänksam",
    "omtänksammaste": "omtänksam",
    "omtänksammastes": "omtänksam",
    "omtänksammasts": "omtänksam",
    "omtänksamme": "omtänksam",
    "omtänksammes": "omtänksam",
    "omtänksams": "omtänksam",
    "omtänksamt": "omtänksam",
    "omtänksamts": "omtänksam",
    "omtöcknade": "omtöcknad",
    "omtöcknades": "omtöcknad",
    "omtöcknads": "omtöcknad",
    "omtöcknat": "omtöcknad",
    "omtöcknats": "omtöcknad",
    "omuddrade": "omuddrad",
    "omuddrades": "omuddrad",
    "omuddrads": "omuddrad",
    "omuddrat": "omuddrad",
    "omuddrats": "omuddrad",
    "omuljerade": "omuljerad",
    "omuljerades": "omuljerad",
    "omuljerads": "omuljerad",
    "omuljerat": "omuljerad",
    "omuljerats": "omuljerad",
    "omuljerbara": "omuljerbar",
    "omuljerbarare": "omuljerbar",
    "omuljerbarares": "omuljerbar",
    "omuljerbaras": "omuljerbar",
    "omuljerbarast": "omuljerbar",
    "omuljerbaraste": "omuljerbar",
    "omuljerbarastes": "omuljerbar",
    "omuljerbarasts": "omuljerbar",
    "omuljerbare": "omuljerbar",
    "omuljerbares": "omuljerbar",
    "omuljerbarheten": "omuljerbarhet",
    "omuljerbarhetens": "omuljerbarhet",
    "omuljerbarhets": "omuljerbarhet",
    "omuljerbars": "omuljerbar",
    "omuljerbart": "omuljerbar",
    "omuljerbarts": "omuljerbar",
    "omultiplicerade": "omultiplicerad",
    "omultiplicerades": "omultiplicerad",
    "omultiplicerads": "omultiplicerad",
    "omultiplicerat": "omultiplicerad",
    "omultiplicerats": "omultiplicerad",
    "omultiplicerbara": "omultiplicerbar",
    "omultiplicerbarare": "omultiplicerbar",
    "omultiplicerbarares": "omultiplicerbar",
    "omultiplicerbaras": "omultiplicerbar",
    "omultiplicerbarast": "omultiplicerbar",
    "omultiplicerbaraste": "omultiplicerbar",
    "omultiplicerbarastes": "omultiplicerbar",
    "omultiplicerbarasts": "omultiplicerbar",
    "omultiplicerbare": "omultiplicerbar",
    "omultiplicerbares": "omultiplicerbar",
    "omultiplicerbarheten": "omultiplicerbarhet",
    "omultiplicerbarhetens": "omultiplicerbarhet",
    "omultiplicerbarhets": "omultiplicerbarhet",
    "omultiplicerbars": "omultiplicerbar",
    "omultiplicerbart": "omultiplicerbar",
    "omultiplicerbarts": "omultiplicerbar",
    "omumifierade": "omumifierad",
    "omumifierades": "omumifierad",
    "omumifierads": "omumifierad",
    "omumifierat": "omumifierad",
    "omumifierats": "omumifierad",
    "omumifierbara": "omumifierbar",
    "omumifierbarare": "omumifierbar",
    "omumifierbarares": "omumifierbar",
    "omumifierbaras": "omumifierbar",
    "omumifierbarast": "omumifierbar",
    "omumifierbaraste": "omumifierbar",
    "omumifierbarastes": "omumifierbar",
    "omumifierbarasts": "omumifierbar",
    "omumifierbare": "omumifierbar",
    "omumifierbares": "omumifierbar",
    "omumifierbarheten": "omumifierbarhet",
    "omumifierbarhetens": "omumifierbarhet",
    "omumifierbarhets": "omumifierbarhet",
    "omumifierbars": "omumifierbar",
    "omumifierbart": "omumifierbar",
    "omumifierbarts": "omumifierbar",
    "omurade": "omurad",
    "omurades": "omurad",
    "omurads": "omurad",
    "omurat": "omurad",
    "omurats": "omurad",
    "omusikaliska": "omusikalisk",
    "omusikaliskare": "omusikalisk",
    "omusikaliskares": "omusikalisk",
    "omusikaliskas": "omusikalisk",
    "omusikaliskast": "omusikalisk",
    "omusikaliskaste": "omusikalisk",
    "omusikaliskastes": "omusikalisk",
    "omusikaliskasts": "omusikalisk",
    "omusikaliske": "omusikalisk",
    "omusikaliskes": "omusikalisk",
    "omusikalisks": "omusikalisk",
    "omusikaliskt": "omusikalisk",
    "omusikaliskts": "omusikalisk",
    "omutade": "omutad",
    "omutades": "omutad",
    "omutads": "omutad",
    "omutat": "omutad",
    "omutats": "omutad",
    "omutbara": "omutbar",
    "omutbarare": "omutbar",
    "omutbarares": "omutbar",
    "omutbaras": "omutbar",
    "omutbarast": "omutbar",
    "omutbaraste": "omutbar",
    "omutbarastes": "omutbar",
    "omutbarasts": "omutbar",
    "omutbare": "omutbar",
    "omutbares": "omutbar",
    "omutbarheten": "omutbarhet",
    "omutbarhetens": "omutbarhet",
    "omutbarhets": "omutbarhet",
    "omutbars": "omutbar",
    "omutbart": "omutbar",
    "omutbarts": "omutbar",
    "omuterade": "omuterad",
    "omuterades": "omuterad",
    "omuterads": "omuterad",
    "omuterat": "omuterad",
    "omuterats": "omuterad",
    "omuterbara": "omuterbar",
    "omuterbarare": "omuterbar",
    "omuterbarares": "omuterbar",
    "omuterbaras": "omuterbar",
    "omuterbarast": "omuterbar",
    "omuterbaraste": "omuterbar",
    "omuterbarastes": "omuterbar",
    "omuterbarasts": "omuterbar",
    "omuterbare": "omuterbar",
    "omuterbares": "omuterbar",
    "omuterbarheten": "omuterbarhet",
    "omuterbarhetens": "omuterbarhet",
    "omuterbarhets": "omuterbarhet",
    "omuterbars": "omuterbar",
    "omuterbart": "omuterbar",
    "omuterbarts": "omuterbar",
    "omutliga": "omutlig",
    "omutligare": "omutlig",
    "omutligares": "omutlig",
    "omutligas": "omutlig",
    "omutligast": "omutlig",
    "omutligaste": "omutlig",
    "omutligastes": "omutlig",
    "omutligasts": "omutlig",
    "omutlige": "omutlig",
    "omutliges": "omutlig",
    "omutligheten": "omutlighet",
    "omutlighetens": "omutlighet",
    "omutlighets": "omutlighet",
    "omutligs": "omutlig",
    "omutligt": "omutlig",
    "omutligts": "omutlig",
    "omvald": "omvälja",
    "omvalda": "omvälja",
    "omvaldas": "omvälja",
    "omvalde": "omvälja",
    "omvaldes": "omvälja",
    "omvalds": "omvälja",
    "omvalen": "omval",
    "omvalens": "omval",
    "omvalet": "omval",
    "omvalets": "omval",
    "omvals": "omval",
    "omvalt": "omvälja",
    "omvalts": "omvälja",
    "omvandlad": "omvandla",
    "omvandlade": "omvandla",
    "omvandlades": "omvandla",
    "omvandlads": "omvandla",
    "omvandlande": "omvandla",
    "omvandlanden": "omvandlande",
    "omvandlandena": "omvandlande",
    "omvandlandenas": "omvandlande",
    "omvandlandens": "omvandlande",
    "omvandlandes": "omvandlande",
    "omvandlandet": "omvandlande",
    "omvandlandets": "omvandlande",
    "omvandlar": "omvandlare",
    "omvandlaren": "omvandlare",
    "omvandlarens": "omvandlare",
    "omvandlares": "omvandlare",
    "omvandlarna": "omvandlare",
    "omvandlarnas": "omvandlare",
    "omvandlas": "omvandla",
    "omvandlat": "omvandla",
    "omvandlats": "omvandla",
    "omvandlingar": "omvandling",
    "omvandlingarna": "omvandling",
    "omvandlingarnas": "omvandling",
    "omvandlingars": "omvandling",
    "omvandlingen": "omvandling",
    "omvandlingens": "omvandling",
    "omvandlings": "omvandling",
    "omvittn": "omvittna",
    "omvittnad": "omvittna",
    "omvittnade": "omvittna",
    "omvittnades": "omvittna",
    "omvittnads": "omvittna",
    "omvittnande": "omvittna",
    "omvittnanden": "omvittnande",
    "omvittnandena": "omvittnande",
    "omvittnandenas": "omvittnande",
    "omvittnandens": "omvittnande",
    "omvittnandes": "omvittnande",
    "omvittnandet": "omvittnande",
    "omvittnandets": "omvittnande",
    "omvittnar": "omvittna",
    "omvittnas": "omvittna",
    "omvittnat": "omvittna",
    "omvittnats": "omvittna",
    "omvägar": "omväg",
    "omvägarna": "omväg",
    "omvägarnas": "omväg",
    "omvägars": "omväg",
    "omvägen": "omväg",
    "omvägens": "omväg",
    "omvägs": "omväg",
    "omvälj": "omvälja",
    "omväljande": "omvälja",
    "omväljanden": "omväljande",
    "omväljandena": "omväljande",
    "omväljandenas": "omväljande",
    "omväljandens": "omväljande",
    "omväljandes": "omväljande",
    "omväljandet": "omväljande",
    "omväljandets": "omväljande",
    "omväljas": "omvälja",
    "omväljer": "omvälja",
    "omväljes": "omvälja",
    "omväljs": "omvälja",
    "omvälv": "omvälva",
    "omvälvande": "omvälva",
    "omvälvanden": "omvälvande",
    "omvälvandena": "omvälvande",
    "omvälvandenas": "omvälvande",
    "omvälvandens": "omvälvande",
    "omvälvandes": "omvälvande",
    "omvälvandet": "omvälvande",
    "omvälvandets": "omvälvande",
    "omvälvas": "omvälva",
    "omvälvd": "omvälva",
    "omvälvda": "omvälva",
    "omvälvdas": "omvälva",
    "omvälvde": "omvälva",
    "omvälvdes": "omvälva",
    "omvälvds": "omvälva",
    "omvälver": "omvälva",
    "omvälves": "omvälva",
    "omvälvningar": "omvälvning",
    "omvälvningarna": "omvälvning",
    "omvälvningarnas": "omvälvning",
    "omvälvningars": "omvälvning",
    "omvälvningen": "omvälvning",
    "omvälvningens": "omvälvning",
    "omvälvnings": "omvälvning",
    "omvälvs": "omvälva",
    "omvälvt": "omvälva",
    "omvälvts": "omvälva",
    "omvänd": "omvända",
    "omvända": "omvänd",
    "omvändande": "omvända",
    "omvändanden": "omvändande",
    "omvändandena": "omvändande",
    "omvändandenas": "omvändande",
    "omvändandens": "omvändande",
    "omvändandes": "omvändande",
    "omvändandet": "omvändande",
    "omvändandets": "omvändande",
    "omvändare": "omvänd",
    "omvändares": "omvänd",
    "omvändas": "omvända",
    "omvändast": "omvänd",
    "omvändaste": "omvänd",
    "omvändastes": "omvänd",
    "omvändasts": "omvänd",
    "omvändbara": "omvändbar",
    "omvändbarare": "omvändbar",
    "omvändbarares": "omvändbar",
    "omvändbaras": "omvändbar",
    "omvändbarast": "omvändbar",
    "omvändbaraste": "omvändbar",
    "omvändbarastes": "omvändbar",
    "omvändbarasts": "omvändbar",
    "omvändbare": "omvändbar",
    "omvändbares": "omvändbar",
    "omvändbarheten": "omvändbarhet",
    "omvändbarhetens": "omvändbarhet",
    "omvändbarhets": "omvändbarhet",
    "omvändbars": "omvändbar",
    "omvändbart": "omvändbar",
    "omvändbarts": "omvändbar",
    "omvände": "omvända",
    "omvändelsen": "omvändelse",
    "omvändelsens": "omvändelse",
    "omvändelser": "omvändelse",
    "omvändelserna": "omvändelse",
    "omvändelsernas": "omvändelse",
    "omvändelsers": "omvändelse",
    "omvändelses": "omvändelse",
    "omvänder": "omvända",
    "omvändes": "omvända",
    "omvändningar": "omvändning",
    "omvändningarna": "omvändning",
    "omvändningarnas": "omvändning",
    "omvändningars": "omvändning",
    "omvändningen": "omvändning",
    "omvändningens": "omvändning",
    "omvändnings": "omvändning",
    "omvändningsfilmen": "omvändningsfilm",
    "omvändningsfilmens": "omvändningsfilm",
    "omvändningsfilmer": "omvändningsfilm",
    "omvändningsfilmerna": "omvändningsfilm",
    "omvändningsfilmernas": "omvändningsfilm",
    "omvändningsfilmers": "omvändningsfilm",
    "omvändningsfilms": "omvändningsfilm",
    "omvändningsteckens": "omvändningstecken",
    "omvändningstecknen": "omvändningstecken",
    "omvändningstecknens": "omvändningstecken",
    "omvändningstecknet": "omvändningstecken",
    "omvändningstecknets": "omvändningstecken",
    "omvänds": "omvända",
    "omvänt": "omvända",
    "omvänts": "omvända",
    "omvärderad": "omvärdera",
    "omvärderade": "omvärdera",
    "omvärderades": "omvärdera",
    "omvärderads": "omvärdera",
    "omvärderande": "omvärdera",
    "omvärderanden": "omvärderande",
    "omvärderandena": "omvärderande",
    "omvärderandenas": "omvärderande",
    "omvärderandens": "omvärderande",
    "omvärderandes": "omvärderande",
    "omvärderandet": "omvärderande",
    "omvärderandets": "omvärderande",
    "omvärderar": "omvärdera",
    "omvärderas": "omvärdera",
    "omvärderat": "omvärdera",
    "omvärderats": "omvärdera",
    "omvärderbara": "omvärderbar",
    "omvärderbarare": "omvärderbar",
    "omvärderbarares": "omvärderbar",
    "omvärderbaras": "omvärderbar",
    "omvärderbarast": "omvärderbar",
    "omvärderbaraste": "omvärderbar",
    "omvärderbarastes": "omvärderbar",
    "omvärderbarasts": "omvärderbar",
    "omvärderbare": "omvärderbar",
    "omvärderbares": "omvärderbar",
    "omvärderbarheten": "omvärderbarhet",
    "omvärderbarhetens": "omvärderbarhet",
    "omvärderbarhets": "omvärderbarhet",
    "omvärderbars": "omvärderbar",
    "omvärderbart": "omvärderbar",
    "omvärderbarts": "omvärderbar",
    "omvärderingar": "omvärdering",
    "omvärderingarna": "omvärdering",
    "omvärderingarnas": "omvärdering",
    "omvärderingars": "omvärdering",
    "omvärderingen": "omvärdering",
    "omvärderingens": "omvärdering",
    "omvärderings": "omvärdering",
    "omvärldar": "omvärld",
    "omvärldarna": "omvärld",
    "omvärldarnas": "omvärld",
    "omvärldars": "omvärld",
    "omvärlden": "omvärld",
    "omvärldens": "omvärld",
    "omvärlds": "omvärld",
    "omvärv": "omvärva",
    "omvärvande": "omvärva",
    "omvärvanden": "omvärvande",
    "omvärvandena": "omvärvande",
    "omvärvandenas": "omvärvande",
    "omvärvandens": "omvärvande",
    "omvärvandes": "omvärvande",
    "omvärvandet": "omvärvande",
    "omvärvandets": "omvärvande",
    "omvärvas": "omvärva",
    "omvärvd": "omvärva",
    "omvärvda": "omvärva",
    "omvärvdas": "omvärva",
    "omvärvde": "omvärva",
    "omvärvdes": "omvärva",
    "omvärvds": "omvärva",
    "omvärver": "omvärva",
    "omvärves": "omvärva",
    "omvärvs": "omvärva",
    "omvärvt": "omvärva",
    "omvärvts": "omvärva",
    "omväxlade": "omväxla",
    "omväxlades": "omväxla",
    "omväxlande": "omväxla",
    "omväxlanden": "omväxlande",
    "omväxlandena": "omväxlande",
    "omväxlandenas": "omväxlande",
    "omväxlandens": "omväxlande",
    "omväxlandes": "omväxlande",
    "omväxlandet": "omväxlande",
    "omväxlandets": "omväxlande",
    "omväxlar": "omväxla",
    "omväxlas": "omväxla",
    "omväxlat": "omväxla",
    "omväxlats": "omväxla",
    "omväxlingar": "omväxling",
    "omväxlingarna": "omväxling",
    "omväxlingarnas": "omväxling",
    "omväxlingars": "omväxling",
    "omväxlingen": "omväxling",
    "omväxlingens": "omväxling",
    "omväxlings": "omväxling",
    "omvårdnaden": "omvårdnad",
    "omvårdnadens": "omvårdnad",
    "omvårdnader": "omvårdnad",
    "omvårdnaderna": "omvårdnad",
    "omvårdnadernas": "omvårdnad",
    "omvårdnaders": "omvårdnad",
    "omvårdnads": "omvårdnad",
    "omvårdnadsmässiga": "omvårdnadsmässig",
    "omvårdnadsmässigare": "omvårdnadsmässig",
    "omvårdnadsmässigares": "omvårdnadsmässig",
    "omvårdnadsmässigas": "omvårdnadsmässig",
    "omvårdnadsmässigast": "omvårdnadsmässig",
    "omvårdnadsmässigaste": "omvårdnadsmässig",
    "omvårdnadsmässigastes": "omvårdnadsmässig",
    "omvårdnadsmässigasts": "omvårdnadsmässig",
    "omvårdnadsmässige": "omvårdnadsmässig",
    "omvårdnadsmässiges": "omvårdnadsmässig",
    "omvårdnadsmässigs": "omvårdnadsmässig",
    "omvårdnadsmässigt": "omvårdnadsmässig",
    "omvårdnadsmässigts": "omvårdnadsmässig",
    "omyllade": "omyllad",
    "omyllades": "omyllad",
    "omyllads": "omyllad",
    "omyllat": "omyllad",
    "omyllats": "omyllad",
    "omyndiga": "omyndig",
    "omyndigare": "omyndig",
    "omyndigares": "omyndig",
    "omyndigas": "omyndig",
    "omyndigast": "omyndig",
    "omyndigaste": "omyndig",
    "omyndigastes": "omyndig",
    "omyndigasts": "omyndig",
    "omyndige": "omyndig",
    "omyndiges": "omyndig",
    "omyndigförklarad": "omyndigförklara",
    "omyndigförklarade": "omyndigförklara",
    "omyndigförklarades": "omyndigförklara",
    "omyndigförklarads": "omyndigförklara",
    "omyndigförklarande": "omyndigförklara",
    "omyndigförklaranden": "omyndigförklarande",
    "omyndigförklarandena": "omyndigförklarande",
    "omyndigförklarandenas": "omyndigförklarande",
    "omyndigförklarandens": "omyndigförklarande",
    "omyndigförklarandes": "omyndigförklarande",
    "omyndigförklarandet": "omyndigförklarande",
    "omyndigförklarandets": "omyndigförklarande",
    "omyndigförklarar": "omyndigförklara",
    "omyndigförklaras": "omyndigförklara",
    "omyndigförklarat": "omyndigförklara",
    "omyndigförklarats": "omyndigförklara",
    "omyndigförklaringar": "omyndigförklaring",
    "omyndigförklaringarna": "omyndigförklaring",
    "omyndigförklaringarnas": "omyndigförklaring",
    "omyndigförklaringars": "omyndigförklaring",
    "omyndigförklaringen": "omyndigförklaring",
    "omyndigförklaringens": "omyndigförklaring",
    "omyndigförklarings": "omyndigförklaring",
    "omyndigheten": "omyndighet",
    "omyndighetens": "omyndighet",
    "omyndighets": "omyndighet",
    "omyndighetsförklaringar": "omyndighetsförklaring",
    "omyndighetsförklaringarna": "omyndighetsförklaring",
    "omyndighetsförklaringarnas": "omyndighetsförklaring",
    "omyndighetsförklaringars": "omyndighetsförklaring",
    "omyndighetsförklaringen": "omyndighetsförklaring",
    "omyndighetsförklaringens": "omyndighetsförklaring",
    "omyndighetsförklarings": "omyndighetsförklaring",
    "omyndigs": "omyndig",
    "omyndigt": "omyndig",
    "omyndigts": "omyndig",
    "omyntade": "omyntad",
    "omyntades": "omyntad",
    "omyntads": "omyntad",
    "omyntat": "omyntad",
    "omyntats": "omyntad",
    "omystifierade": "omystifierad",
    "omystifierades": "omystifierad",
    "omystifierads": "omystifierad",
    "omystifierat": "omystifierad",
    "omystifierats": "omystifierad",
    "omystifierbara": "omystifierbar",
    "omystifierbarare": "omystifierbar",
    "omystifierbarares": "omystifierbar",
    "omystifierbaras": "omystifierbar",
    "omystifierbarast": "omystifierbar",
    "omystifierbaraste": "omystifierbar",
    "omystifierbarastes": "omystifierbar",
    "omystifierbarasts": "omystifierbar",
    "omystifierbare": "omystifierbar",
    "omystifierbares": "omystifierbar",
    "omystifierbarheten": "omystifierbarhet",
    "omystifierbarhetens": "omystifierbarhet",
    "omystifierbarhets": "omystifierbarhet",
    "omystifierbars": "omystifierbar",
    "omystifierbart": "omystifierbar",
    "omystifierbarts": "omystifierbar",
    "omäklade": "omäklad",
    "omäklades": "omäklad",
    "omäklads": "omäklad",
    "omäklat": "omäklad",
    "omäklats": "omäklad",
    "omältade": "omältad",
    "omältades": "omältad",
    "omältads": "omältad",
    "omältat": "omältad",
    "omältats": "omältad",
    "omändrad": "omändra",
    "omändrade": "omändra",
    "omändrades": "omändra",
    "omändrads": "omändra",
    "omändrande": "omändra",
    "omändranden": "omändrande",
    "omändrandena": "omändrande",
    "omändrandenas": "omändrande",
    "omändrandens": "omändrande",
    "omändrandes": "omändrande",
    "omändrandet": "omändrande",
    "omändrandets": "omändrande",
    "omändrar": "omändra",
    "omändras": "omändra",
    "omändrat": "omändra",
    "omändrats": "omändra",
    "omängde": "omängd",
    "omängdes": "omängd",
    "omängds": "omängd",
    "omängt": "omängd",
    "omängts": "omängd",
    "omänskliga": "omänsklig",
    "omänskligare": "omänsklig",
    "omänskligares": "omänsklig",
    "omänskligas": "omänsklig",
    "omänskligast": "omänsklig",
    "omänskligaste": "omänsklig",
    "omänskligastes": "omänsklig",
    "omänskligasts": "omänsklig",
    "omänsklige": "omänsklig",
    "omänskliges": "omänsklig",
    "omänskligheten": "omänsklighet",
    "omänsklighetens": "omänsklighet",
    "omänskligheter": "omänsklighet",
    "omänskligheterna": "omänsklighet",
    "omänskligheternas": "omänsklighet",
    "omänskligheters": "omänsklighet",
    "omänsklighets": "omänsklighet",
    "omänskligs": "omänsklig",
    "omänskligt": "omänsklig",
    "omänskligts": "omänsklig",
    "omärglade": "omärglad",
    "omärglades": "omärglad",
    "omärglads": "omärglad",
    "omärglat": "omärglad",
    "omärglats": "omärglad",
    "omärkliga": "omärklig",
    "omärkligare": "omärklig",
    "omärkligares": "omärklig",
    "omärkligas": "omärklig",
    "omärkligast": "omärklig",
    "omärkligaste": "omärklig",
    "omärkligastes": "omärklig",
    "omärkligasts": "omärklig",
    "omärklige": "omärklig",
    "omärkliges": "omärklig",
    "omärkligheten": "omärklighet",
    "omärklighetens": "omärklighet",
    "omärklighets": "omärklighet",
    "omärkligs": "omärklig",
    "omärkligt": "omärklig",
    "omärkligts": "omärklig",
    "omärkta": "omärkt",
    "omärktas": "omärkt",
    "omärkte": "omärkt",
    "omärktes": "omärkt",
    "omärkts": "omärkt",
    "omäskade": "omäskad",
    "omäskades": "omäskad",
    "omäskads": "omäskad",
    "omäskat": "omäskad",
    "omäskats": "omäskad",
    "omästrade": "omästrad",
    "omästrades": "omästrad",
    "omästrads": "omästrad",
    "omästrat": "omästrad",
    "omästrats": "omästrad",
    "omätliga": "omätlig",
    "omätligare": "omätlig",
    "omätligares": "omätlig",
    "omätligas": "omätlig",
    "omätligast": "omätlig",
    "omätligaste": "omätlig",
    "omätligastes": "omätlig",
    "omätligasts": "omätlig",
    "omätlige": "omätlig",
    "omätliges": "omätlig",
    "omätligheten": "omätlighet",
    "omätlighetens": "omätlighet",
    "omätlighets": "omätlighet",
    "omätligs": "omätlig",
    "omätligt": "omätlig",
    "omätligts": "omätlig",
    "omätta": "omätt",
    "omättade": "omättad",
    "omättades": "omättad",
    "omättads": "omättad",
    "omättas": "omätt",
    "omättat": "omättad",
    "omättats": "omättad",
    "omätte": "omätt",
    "omättes": "omätt",
    "omättliga": "omättlig",
    "omättligare": "omättlig",
    "omättligares": "omättlig",
    "omättligas": "omättlig",
    "omättligast": "omättlig",
    "omättligaste": "omättlig",
    "omättligastes": "omättlig",
    "omättligasts": "omättlig",
    "omättlige": "omättlig",
    "omättliges": "omättlig",
    "omättligheten": "omättlighet",
    "omättlighetens": "omättlighet",
    "omättlighets": "omättlighet",
    "omättligs": "omättlig",
    "omättligt": "omättlig",
    "omättligts": "omättlig",
    "omätts": "omätt",
    "omålade": "omålad",
    "omålades": "omålad",
    "omålads": "omålad",
    "omålat": "omålad",
    "omålats": "omålad",
    "omånglade": "omånglad",
    "omånglades": "omånglad",
    "omånglads": "omånglad",
    "omånglat": "omånglad",
    "omånglats": "omånglad",
    "omåttade": "omåttad",
    "omåttades": "omåttad",
    "omåttads": "omåttad",
    "omåttat": "omåttad",
    "omåttats": "omåttad",
    "omåttliga": "omåttlig",
    "omåttligare": "omåttlig",
    "omåttligares": "omåttlig",
    "omåttligas": "omåttlig",
    "omåttligast": "omåttlig",
    "omåttligaste": "omåttlig",
    "omåttligastes": "omåttlig",
    "omåttligasts": "omåttlig",
    "omåttlige": "omåttlig",
    "omåttliges": "omåttlig",
    "omåttligheten": "omåttlighet",
    "omåttlighetens": "omåttlighet",
    "omåttligheter": "omåttlighet",
    "omåttligheterna": "omåttlighet",
    "omåttligheternas": "omåttlighet",
    "omåttligheters": "omåttlighet",
    "omåttlighets": "omåttlighet",
    "omåttligs": "omåttlig",
    "omåttligt": "omåttlig",
    "omåttligts": "omåttlig",
    "omöblerade": "omöblerad",
    "omöblerades": "omöblerad",
    "omöblerads": "omöblerad",
    "omöblerat": "omöblerad",
    "omöblerats": "omöblerad",
    "omöblerbara": "omöblerbar",
    "omöblerbarare": "omöblerbar",
    "omöblerbarares": "omöblerbar",
    "omöblerbaras": "omöblerbar",
    "omöblerbarast": "omöblerbar",
    "omöblerbaraste": "omöblerbar",
    "omöblerbarastes": "omöblerbar",
    "omöblerbarasts": "omöblerbar",
    "omöblerbare": "omöblerbar",
    "omöblerbares": "omöblerbar",
    "omöblerbarheten": "omöblerbarhet",
    "omöblerbarhetens": "omöblerbarhet",
    "omöblerbarhets": "omöblerbarhet",
    "omöblerbars": "omöblerbar",
    "omöblerbart": "omöblerbar",
    "omöblerbarts": "omöblerbar",
    "omöjliga": "omöjlig",
    "omöjligare": "omöjlig",
    "omöjligares": "omöjlig",
    "omöjligas": "omöjlig",
    "omöjligast": "omöjlig",
    "omöjligaste": "omöjlig",
    "omöjligastes": "omöjlig",
    "omöjligasts": "omöjlig",
    "omöjlige": "omöjlig",
    "omöjliges": "omöjlig",
    "omöjliggjord": "omöjliggöra",
    "omöjliggjorda": "omöjliggöra",
    "omöjliggjordas": "omöjliggöra",
    "omöjliggjorde": "omöjliggöra",
    "omöjliggjordes": "omöjliggöra",
    "omöjliggjords": "omöjliggöra",
    "omöjliggjort": "omöjliggöra",
    "omöjliggjorts": "omöjliggöra",
    "omöjliggör": "omöjliggöra",
    "omöjliggörande": "omöjliggöra",
    "omöjliggöranden": "omöjliggörande",
    "omöjliggörandena": "omöjliggörande",
    "omöjliggörandenas": "omöjliggörande",
    "omöjliggörandens": "omöjliggörande",
    "omöjliggörandes": "omöjliggörande",
    "omöjliggörandet": "omöjliggörande",
    "omöjliggörandets": "omöjliggörande",
    "omöjliggöras": "omöjliggöra",
    "omöjliggöres": "omöjliggöra",
    "omöjliggörs": "omöjliggöra",
    "omöjligheten": "omöjlighet",
    "omöjlighetens": "omöjlighet",
    "omöjligheter": "omöjlighet",
    "omöjligheterna": "omöjlighet",
    "omöjligheternas": "omöjlighet",
    "omöjligheters": "omöjlighet",
    "omöjlighets": "omöjlighet",
    "omöjligs": "omöjlig",
    "omöjligt": "omöjlig",
    "omöjligts": "omöjlig",
    "omönstrade": "omönstrad",
    "omönstrades": "omönstrad",
    "omönstrads": "omönstrad",
    "omönstrat": "omönstrad",
    "omönstrats": "omönstrad",
    "omörade": "omörad",
    "omörades": "omörad",
    "omörads": "omörad",
    "omörat": "omörad",
    "omörats": "omörad",
    "omördade": "omördad",
    "omördades": "omördad",
    "omördads": "omördad",
    "omördat": "omördad",
    "omördats": "omördad",
    "omörkade": "omörkad",
    "omörkades": "omörkad",
    "omörkads": "omörkad",
    "omörkat": "omörkad",
    "omörkats": "omörkad",
    "omötta": "omött",
    "omöttas": "omött",
    "omötte": "omött",
    "omöttes": "omött",
    "omötts": "omött",
    "on": "o",
    "ona": "o",
    "onackade": "onackad",
    "onackades": "onackad",
    "onackads": "onackad",
    "onackat": "onackad",
    "onackats": "onackad",
    "onafsade": "onafsad",
    "onafsades": "onafsad",
    "onafsads": "onafsad",
    "onafsat": "onafsad",
    "onafsats": "onafsad",
    "onagern": "onager",
    "onagerns": "onager",
    "onagers": "onager",
    "onaggade": "onaggad",
    "onaggades": "onaggad",
    "onaggads": "onaggad",
    "onaggat": "onaggad",
    "onaggats": "onaggad",
    "onaglade": "onaglad",
    "onaglades": "onaglad",
    "onaglads": "onaglad",
    "onaglat": "onaglad",
    "onaglats": "onaglad",
    "onagrer": "onager",
    "onagrerna": "onager",
    "onagrernas": "onager",
    "onagrers": "onager",
    "onajade": "onajad",
    "onajades": "onajad",
    "onajads": "onajad",
    "onajat": "onajad",
    "onajats": "onajad",
    "onallade": "onallad",
    "onallades": "onallad",
    "onallads": "onallad",
    "onallat": "onallad",
    "onallats": "onallad",
    "onamnade": "onamnad",
    "onamnades": "onamnad",
    "onamnads": "onamnad",
    "onamnat": "onamnad",
    "onamnats": "onamnad",
    "onanerade": "onanera",
    "onanerades": "onanera",
    "onanerande": "onanera",
    "onaneranden": "onanerande",
    "onanerandena": "onanerande",
    "onanerandenas": "onanerande",
    "onanerandens": "onanerande",
    "onanerandes": "onanerande",
    "onanerandet": "onanerande",
    "onanerandets": "onanerande",
    "onanerar": "onanera",
    "onaneras": "onanera",
    "onanerat": "onanera",
    "onanerats": "onanera",
    "onaneringar": "onanering",
    "onaneringarna": "onanering",
    "onaneringarnas": "onanering",
    "onaneringars": "onanering",
    "onaneringen": "onanering",
    "onaneringens": "onanering",
    "onanerings": "onanering",
    "onanien": "onani",
    "onaniens": "onani",
    "onanin": "onani",
    "onanins": "onani",
    "onanis": "onani",
    "onaniserade": "onanisera",
    "onaniserades": "onanisera",
    "onaniserande": "onanisera",
    "onaniseranden": "onaniserande",
    "onaniserandena": "onaniserande",
    "onaniserandenas": "onaniserande",
    "onaniserandens": "onaniserande",
    "onaniserandes": "onaniserande",
    "onaniserandet": "onaniserande",
    "onaniserandets": "onaniserande",
    "onaniserar": "onanisera",
    "onaniseras": "onanisera",
    "onaniserat": "onanisera",
    "onaniserats": "onanisera",
    "onaniseringar": "onanisering",
    "onaniseringarna": "onanisering",
    "onaniseringarnas": "onanisering",
    "onaniseringars": "onanisering",
    "onaniseringen": "onanisering",
    "onaniseringens": "onanisering",
    "onaniserings": "onanisering",
    "onappade": "onappad",
    "onappades": "onappad",
    "onappads": "onappad",
    "onappat": "onappad",
    "onappats": "onappad",
    "onarade": "onarad",
    "onarades": "onarad",
    "onarads": "onarad",
    "onarat": "onarad",
    "onarats": "onarad",
    "onarrade": "onarrad",
    "onarrades": "onarrad",
    "onarrads": "onarrad",
    "onarrat": "onarrad",
    "onarrats": "onarrad",
    "onarvade": "onarvad",
    "onarvades": "onarvad",
    "onarvads": "onarvad",
    "onarvat": "onarvad",
    "onarvats": "onarvad",
    "onas": "o",
    "onasade": "onasad",
    "onasades": "onasad",
    "onasads": "onasad",
    "onasalerade": "onasalerad",
    "onasalerades": "onasalerad",
    "onasalerads": "onasalerad",
    "onasalerat": "onasalerad",
    "onasalerats": "onasalerad",
    "onasalerbara": "onasalerbar",
    "onasalerbarare": "onasalerbar",
    "onasalerbarares": "onasalerbar",
    "onasalerbaras": "onasalerbar",
    "onasalerbarast": "onasalerbar",
    "onasalerbaraste": "onasalerbar",
    "onasalerbarastes": "onasalerbar",
    "onasalerbarasts": "onasalerbar",
    "onasalerbare": "onasalerbar",
    "onasalerbares": "onasalerbar",
    "onasalerbarheten": "onasalerbarhet",
    "onasalerbarhetens": "onasalerbarhet",
    "onasalerbarhets": "onasalerbarhet",
    "onasalerbars": "onasalerbar",
    "onasalerbart": "onasalerbar",
    "onasalerbarts": "onasalerbar",
    "onasaliserade": "onasaliserad",
    "onasaliserades": "onasaliserad",
    "onasaliserads": "onasaliserad",
    "onasaliserat": "onasaliserad",
    "onasaliserats": "onasaliserad",
    "onasaliserbara": "onasaliserbar",
    "onasaliserbarare": "onasaliserbar",
    "onasaliserbarares": "onasaliserbar",
    "onasaliserbaras": "onasaliserbar",
    "onasaliserbarast": "onasaliserbar",
    "onasaliserbaraste": "onasaliserbar",
    "onasaliserbarastes": "onasaliserbar",
    "onasaliserbarasts": "onasaliserbar",
    "onasaliserbare": "onasaliserbar",
    "onasaliserbares": "onasaliserbar",
    "onasaliserbarheten": "onasaliserbarhet",
    "onasaliserbarhetens": "onasaliserbarhet",
    "onasaliserbarhets": "onasaliserbarhet",
    "onasaliserbars": "onasaliserbar",
    "onasaliserbart": "onasaliserbar",
    "onasaliserbarts": "onasaliserbar",
    "onasat": "onasad",
    "onasats": "onasad",
    "onationaliserade": "onationaliserad",
    "onationaliserades": "onationaliserad",
    "onationaliserads": "onationaliserad",
    "onationaliserat": "onationaliserad",
    "onationaliserats": "onationaliserad",
    "onationaliserbara": "onationaliserbar",
    "onationaliserbarare": "onationaliserbar",
    "onationaliserbarares": "onationaliserbar",
    "onationaliserbaras": "onationaliserbar",
    "onationaliserbarast": "onationaliserbar",
    "onationaliserbaraste": "onationaliserbar",
    "onationaliserbarastes": "onationaliserbar",
    "onationaliserbarasts": "onationaliserbar",
    "onationaliserbare": "onationaliserbar",
    "onationaliserbares": "onationaliserbar",
    "onationaliserbarheten": "onationaliserbarhet",
    "onationaliserbarhetens": "onationaliserbarhet",
    "onationaliserbarhets": "onationaliserbarhet",
    "onationaliserbars": "onationaliserbar",
    "onationaliserbart": "onationaliserbar",
    "onationaliserbarts": "onationaliserbar",
    "onattade": "onattad",
    "onattades": "onattad",
    "onattads": "onattad",
    "onattat": "onattad",
    "onattats": "onattad",
    "onaturaliserade": "onaturaliserad",
    "onaturaliserades": "onaturaliserad",
    "onaturaliserads": "onaturaliserad",
    "onaturaliserat": "onaturaliserad",
    "onaturaliserats": "onaturaliserad",
    "onaturaliserbara": "onaturaliserbar",
    "onaturaliserbarare": "onaturaliserbar",
    "onaturaliserbarares": "onaturaliserbar",
    "onaturaliserbaras": "onaturaliserbar",
    "onaturaliserbarast": "onaturaliserbar",
    "onaturaliserbaraste": "onaturaliserbar",
    "onaturaliserbarastes": "onaturaliserbar",
    "onaturaliserbarasts": "onaturaliserbar",
    "onaturaliserbare": "onaturaliserbar",
    "onaturaliserbares": "onaturaliserbar",
    "onaturaliserbarheten": "onaturaliserbarhet",
    "onaturaliserbarhetens": "onaturaliserbarhet",
    "onaturaliserbarhets": "onaturaliserbarhet",
    "onaturaliserbars": "onaturaliserbar",
    "onaturaliserbart": "onaturaliserbar",
    "onaturaliserbarts": "onaturaliserbar",
    "onaturen": "onatur",
    "onaturens": "onatur",
    "onaturliga": "onaturlig",
    "onaturligare": "onaturlig",
    "onaturligares": "onaturlig",
    "onaturligas": "onaturlig",
    "onaturligast": "onaturlig",
    "onaturligaste": "onaturlig",
    "onaturligastes": "onaturlig",
    "onaturligasts": "onaturlig",
    "onaturlige": "onaturlig",
    "onaturliges": "onaturlig",
    "onaturligheten": "onaturlighet",
    "onaturlighetens": "onaturlighet",
    "onaturligheter": "onaturlighet",
    "onaturligheterna": "onaturlighet",
    "onaturligheternas": "onaturlighet",
    "onaturligheters": "onaturlighet",
    "onaturlighets": "onaturlighet",
    "onaturligs": "onaturlig",
    "onaturligt": "onaturlig",
    "onaturligts": "onaturlig",
    "onaturs": "onatur",
    "onavigerade": "onavigerad",
    "onavigerades": "onavigerad",
    "onavigerads": "onavigerad",
    "onavigerat": "onavigerad",
    "onavigerats": "onavigerad",
    "onavigerbara": "onavigerbar",
    "onavigerbarare": "onavigerbar",
    "onavigerbarares": "onavigerbar",
    "onavigerbaras": "onavigerbar",
    "onavigerbarast": "onavigerbar",
    "onavigerbaraste": "onavigerbar",
    "onavigerbarastes": "onavigerbar",
    "onavigerbarasts": "onavigerbar",
    "onavigerbare": "onavigerbar",
    "onavigerbares": "onavigerbar",
    "onavigerbarheten": "onavigerbarhet",
    "onavigerbarhetens": "onavigerbarhet",
    "onavigerbarhets": "onavigerbarhet",
    "onavigerbars": "onavigerbar",
    "onavigerbart": "onavigerbar",
    "onavigerbarts": "onavigerbar",
    "onavlade": "onavlad",
    "onavlades": "onavlad",
    "onavlads": "onavlad",
    "onavlat": "onavlad",
    "onavlats": "onavlad",
    "onda": "ond",
    "ondare": "ond",
    "ondares": "ond",
    "ondas": "ond",
    "ondast": "ond",
    "ondaste": "ond",
    "ondastes": "ond",
    "ondasts": "ond",
    "onde": "ond",
    "ondes": "ond",
    "onds": "ond",
    "ondsinta": "ondsint",
    "ondsintare": "ondsint",
    "ondsintares": "ondsint",
    "ondsintas": "ondsint",
    "ondsintast": "ondsint",
    "ondsintaste": "ondsint",
    "ondsintastes": "ondsint",
    "ondsintasts": "ondsint",
    "ondsinte": "ondsint",
    "ondsintes": "ondsint",
    "ondsintheten": "ondsinthet",
    "ondsinthetens": "ondsinthet",
    "ondsinthets": "ondsinthet",
    "ondsints": "ondsint",
    "ondskan": "ondska",
    "ondskans": "ondska",
    "ondskas": "ondska",
    "ondskefulla": "ondskefull",
    "ondskefullare": "ondskefull",
    "ondskefullares": "ondskefull",
    "ondskefullas": "ondskefull",
    "ondskefullast": "ondskefull",
    "ondskefullaste": "ondskefull",
    "ondskefullastes": "ondskefull",
    "ondskefullasts": "ondskefull",
    "ondskefulle": "ondskefull",
    "ondskefulles": "ondskefull",
    "ondskefullheten": "ondskefullhet",
    "ondskefullhetens": "ondskefullhet",
    "ondskefullheter": "ondskefullhet",
    "ondskefullheterna": "ondskefullhet",
    "ondskefullheternas": "ondskefullhet",
    "ondskefullheters": "ondskefullhet",
    "ondskefullhets": "ondskefullhet",
    "ondskefulls": "ondskefull",
    "ondskefullt": "ondskefull",
    "ondskefullts": "ondskefull",
    "ondulerad": "ondulera",
    "ondulerade": "ondulera",
    "ondulerades": "ondulera",
    "ondulerads": "ondulera",
    "ondulerande": "ondulera",
    "onduleranden": "ondulerande",
    "ondulerandena": "ondulerande",
    "ondulerandenas": "ondulerande",
    "ondulerandens": "ondulerande",
    "ondulerandes": "ondulerande",
    "ondulerandet": "ondulerande",
    "ondulerandets": "ondulerande",
    "ondulerar": "ondulera",
    "onduleras": "ondulera",
    "ondulerat": "ondulera",
    "ondulerats": "ondulera",
    "ondulerbara": "ondulerbar",
    "ondulerbarare": "ondulerbar",
    "ondulerbarares": "ondulerbar",
    "ondulerbaras": "ondulerbar",
    "ondulerbarast": "ondulerbar",
    "ondulerbaraste": "ondulerbar",
    "ondulerbarastes": "ondulerbar",
    "ondulerbarasts": "ondulerbar",
    "ondulerbare": "ondulerbar",
    "ondulerbares": "ondulerbar",
    "ondulerbarheten": "ondulerbarhet",
    "ondulerbarhetens": "ondulerbarhet",
    "ondulerbarhets": "ondulerbarhet",
    "ondulerbars": "ondulerbar",
    "ondulerbart": "ondulerbar",
    "ondulerbarts": "ondulerbar",
    "onduleringar": "ondulering",
    "onduleringarna": "ondulering",
    "onduleringarnas": "ondulering",
    "onduleringars": "ondulering",
    "onduleringen": "ondulering",
    "onduleringens": "ondulering",
    "ondulerings": "ondulering",
    "one-stepen": "one-step",
    "one-stepens": "one-step",
    "one-steps": "one-step",
    "onedarbetade": "onedarbetad",
    "onedarbetades": "onedarbetad",
    "onedarbetads": "onedarbetad",
    "onedarbetat": "onedarbetad",
    "onedarbetats": "onedarbetad",
    "onedblåsta": "onedblåst",
    "onedblåstas": "onedblåst",
    "onedblåste": "onedblåst",
    "onedblåstes": "onedblåst",
    "onedblåsts": "onedblåst",
    "onedisade": "onedisad",
    "onedisades": "onedisad",
    "onedisads": "onedisad",
    "onedisat": "onedisad",
    "onedisats": "onedisad",
    "onedkallade": "onedkallad",
    "onedkallades": "onedkallad",
    "onedkallads": "onedkallad",
    "onedkallat": "onedkallad",
    "onedkallats": "onedkallad",
    "onedkastade": "onedkastad",
    "onedkastades": "onedkastad",
    "onedkastads": "onedkastad",
    "onedkastat": "onedkastad",
    "onedkastats": "onedkastad",
    "onedkavlade": "onedkavlad",
    "onedkavlades": "onedkavlad",
    "onedkavlads": "onedkavlad",
    "onedkavlat": "onedkavlad",
    "onedkavlats": "onedkavlad",
    "onedklassade": "onedklassad",
    "onedklassades": "onedklassad",
    "onedklassads": "onedklassad",
    "onedklassat": "onedklassad",
    "onedklassats": "onedklassad",
    "onedrustade": "onedrustad",
    "onedrustades": "onedrustad",
    "onedrustads": "onedrustad",
    "onedrustat": "onedrustad",
    "onedrustats": "onedrustad",
    "onedsänkta": "onedsänkt",
    "onedsänktas": "onedsänkt",
    "onedsänkte": "onedsänkt",
    "onedsänktes": "onedsänkt",
    "onedsänkts": "onedsänkt",
    "onedtecknade": "onedtecknad",
    "onedtecknades": "onedtecknad",
    "onedtecknads": "onedtecknad",
    "onedtecknat": "onedtecknad",
    "onedtecknats": "onedtecknad",
    "onedtransformerade": "onedtransformerad",
    "onedtransformerades": "onedtransformerad",
    "onedtransformerads": "onedtransformerad",
    "onedtransformerat": "onedtransformerad",
    "onedtransformerats": "onedtransformerad",
    "onedtransformerbara": "onedtransformerbar",
    "onedtransformerbarare": "onedtransformerbar",
    "onedtransformerbarares": "onedtransformerbar",
    "onedtransformerbaras": "onedtransformerbar",
    "onedtransformerbarast": "onedtransformerbar",
    "onedtransformerbaraste": "onedtransformerbar",
    "onedtransformerbarastes": "onedtransformerbar",
    "onedtransformerbarasts": "onedtransformerbar",
    "onedtransformerbare": "onedtransformerbar",
    "onedtransformerbares": "onedtransformerbar",
    "onedtransformerbarheten": "onedtransformerbarhet",
    "onedtransformerbarhetens": "onedtransformerbarhet",
    "onedtransformerbarhets": "onedtransformerbarhet",
    "onedtransformerbars": "onedtransformerbar",
    "onedtransformerbart": "onedtransformerbar",
    "onedtransformerbarts": "onedtransformerbar",
    "onedtransponerade": "onedtransponerad",
    "onedtransponerades": "onedtransponerad",
    "onedtransponerads": "onedtransponerad",
    "onedtransponerat": "onedtransponerad",
    "onedtransponerats": "onedtransponerad",
    "onedtransponerbara": "onedtransponerbar",
    "onedtransponerbarare": "onedtransponerbar",
    "onedtransponerbarares": "onedtransponerbar",
    "onedtransponerbaras": "onedtransponerbar",
    "onedtransponerbarast": "onedtransponerbar",
    "onedtransponerbaraste": "onedtransponerbar",
    "onedtransponerbarastes": "onedtransponerbar",
    "onedtransponerbarasts": "onedtransponerbar",
    "onedtransponerbare": "onedtransponerbar",
    "onedtransponerbares": "onedtransponerbar",
    "onedtransponerbarheten": "onedtransponerbarhet",
    "onedtransponerbarhetens": "onedtransponerbarhet",
    "onedtransponerbarhets": "onedtransponerbarhet",
    "onedtransponerbars": "onedtransponerbar",
    "onedtransponerbart": "onedtransponerbar",
    "onedtransponerbarts": "onedtransponerbar",
    "onedvärderade": "onedvärderad",
    "onedvärderades": "onedvärderad",
    "onedvärderads": "onedvärderad",
    "onedvärderat": "onedvärderad",
    "onedvärderats": "onedvärderad",
    "onedvärderbara": "onedvärderbar",
    "onedvärderbarare": "onedvärderbar",
    "onedvärderbarares": "onedvärderbar",
    "onedvärderbaras": "onedvärderbar",
    "onedvärderbarast": "onedvärderbar",
    "onedvärderbaraste": "onedvärderbar",
    "onedvärderbarastes": "onedvärderbar",
    "onedvärderbarasts": "onedvärderbar",
    "onedvärderbare": "onedvärderbar",
    "onedvärderbares": "onedvärderbar",
    "onedvärderbarheten": "onedvärderbarhet",
    "onedvärderbarhetens": "onedvärderbarhet",
    "onedvärderbarhets": "onedvärderbarhet",
    "onedvärderbars": "onedvärderbar",
    "onedvärderbart": "onedvärderbar",
    "onedvärderbarts": "onedvärderbar",
    "onegerade": "onegerad",
    "onegerades": "onegerad",
    "onegerads": "onegerad",
    "onegerat": "onegerad",
    "onegerats": "onegerad",
    "onegerbara": "onegerbar",
    "onegerbarare": "onegerbar",
    "onegerbarares": "onegerbar",
    "onegerbaras": "onegerbar",
    "onegerbarast": "onegerbar",
    "onegerbaraste": "onegerbar",
    "onegerbarastes": "onegerbar",
    "onegerbarasts": "onegerbar",
    "onegerbare": "onegerbar",
    "onegerbares": "onegerbar",
    "onegerbarheten": "onegerbarhet",
    "onegerbarhetens": "onegerbarhet",
    "onegerbarhets": "onegerbarhet",
    "onegerbars": "onegerbar",
    "onegerbart": "onegerbar",
    "onegerbarts": "onegerbar",
    "onegligerade": "onegligerad",
    "onegligerades": "onegligerad",
    "onegligerads": "onegligerad",
    "onegligerat": "onegligerad",
    "onegligerats": "onegligerad",
    "onegligerbara": "onegligerbar",
    "onegligerbarare": "onegligerbar",
    "onegligerbarares": "onegligerbar",
    "onegligerbaras": "onegligerbar",
    "onegligerbarast": "onegligerbar",
    "onegligerbaraste": "onegligerbar",
    "onegligerbarastes": "onegligerbar",
    "onegligerbarasts": "onegligerbar",
    "onegligerbare": "onegligerbar",
    "onegligerbares": "onegligerbar",
    "onegligerbarheten": "onegligerbarhet",
    "onegligerbarhetens": "onegligerbarhet",
    "onegligerbarhets": "onegligerbarhet",
    "onegligerbars": "onegligerbar",
    "onegligerbart": "onegligerbar",
    "onegligerbarts": "onegligerbar",
    "onegocierade": "onegocierad",
    "onegocierades": "onegocierad",
    "onegocierads": "onegocierad",
    "onegocierat": "onegocierad",
    "onegocierats": "onegocierad",
    "onegocierbara": "onegocierbar",
    "onegocierbarare": "onegocierbar",
    "onegocierbarares": "onegocierbar",
    "onegocierbaras": "onegocierbar",
    "onegocierbarast": "onegocierbar",
    "onegocierbaraste": "onegocierbar",
    "onegocierbarastes": "onegocierbar",
    "onegocierbarasts": "onegocierbar",
    "onegocierbare": "onegocierbar",
    "onegocierbares": "onegocierbar",
    "onegocierbarheten": "onegocierbarhet",
    "onegocierbarhetens": "onegocierbarhet",
    "onegocierbarhets": "onegocierbarhet",
    "onegocierbars": "onegocierbar",
    "onegocierbart": "onegocierbar",
    "onegocierbarts": "onegocierbar",
    "onegotierade": "onegotierad",
    "onegotierades": "onegotierad",
    "onegotierads": "onegotierad",
    "onegotierat": "onegotierad",
    "onegotierats": "onegotierad",
    "onegotierbara": "onegotierbar",
    "onegotierbarare": "onegotierbar",
    "onegotierbarares": "onegotierbar",
    "onegotierbaras": "onegotierbar",
    "onegotierbarast": "onegotierbar",
    "onegotierbaraste": "onegotierbar",
    "onegotierbarastes": "onegotierbar",
    "onegotierbarasts": "onegotierbar",
    "onegotierbare": "onegotierbar",
    "onegotierbares": "onegotierbar",
    "onegotierbarheten": "onegotierbarhet",
    "onegotierbarhetens": "onegotierbarhet",
    "onegotierbarhets": "onegotierbarhet",
    "onegotierbars": "onegotierbar",
    "onegotierbart": "onegotierbar",
    "onegotierbarts": "onegotierbar",
    "oneiromantien": "oneiromanti",
    "oneiromantiens": "oneiromanti",
    "oneiromantin": "oneiromanti",
    "oneiromantins": "oneiromanti",
    "oneiromantis": "oneiromanti",
    "onekade": "onekad",
    "onekades": "onekad",
    "onekads": "onekad",
    "onekat": "onekad",
    "onekats": "onekad",
    "onekliga": "oneklig",
    "onekligare": "oneklig",
    "onekligares": "oneklig",
    "onekligas": "oneklig",
    "onekligast": "oneklig",
    "onekligaste": "oneklig",
    "onekligastes": "oneklig",
    "onekligasts": "oneklig",
    "oneklige": "oneklig",
    "onekliges": "oneklig",
    "onekligheten": "oneklighet",
    "oneklighetens": "oneklighet",
    "oneklighets": "oneklighet",
    "onekligs": "oneklig",
    "onekligt": "oneklig",
    "onekligts": "oneklig",
    "onerarbetade": "onerarbetad",
    "onerarbetades": "onerarbetad",
    "onerarbetads": "onerarbetad",
    "onerarbetat": "onerarbetad",
    "onerarbetats": "onerarbetad",
    "onerblåsta": "onerblåst",
    "onerblåstas": "onerblåst",
    "onerblåste": "onerblåst",
    "onerblåstes": "onerblåst",
    "onerblåsts": "onerblåst",
    "onerisade": "onerisad",
    "onerisades": "onerisad",
    "onerisads": "onerisad",
    "onerisat": "onerisad",
    "onerisats": "onerisad",
    "onerkallade": "onerkallad",
    "onerkallades": "onerkallad",
    "onerkallads": "onerkallad",
    "onerkallat": "onerkallad",
    "onerkallats": "onerkallad",
    "onerkastade": "onerkastad",
    "onerkastades": "onerkastad",
    "onerkastads": "onerkastad",
    "onerkastat": "onerkastad",
    "onerkastats": "onerkastad",
    "onerkavlade": "onerkavlad",
    "onerkavlades": "onerkavlad",
    "onerkavlads": "onerkavlad",
    "onerkavlat": "onerkavlad",
    "onerkavlats": "onerkavlad",
    "onerklassade": "onerklassad",
    "onerklassades": "onerklassad",
    "onerklassads": "onerklassad",
    "onerklassat": "onerklassad",
    "onerklassats": "onerklassad",
    "onerrustade": "onerrustad",
    "onerrustades": "onerrustad",
    "onerrustads": "onerrustad",
    "onerrustat": "onerrustad",
    "onerrustats": "onerrustad",
    "onersänkta": "onersänkt",
    "onersänktas": "onersänkt",
    "onersänkte": "onersänkt",
    "onersänktes": "onersänkt",
    "onersänkts": "onersänkt",
    "onertecknade": "onertecknad",
    "onertecknades": "onertecknad",
    "onertecknads": "onertecknad",
    "onertecknat": "onertecknad",
    "onertecknats": "onertecknad",
    "onertransformerade": "onertransformerad",
    "onertransformerades": "onertransformerad",
    "onertransformerads": "onertransformerad",
    "onertransformerat": "onertransformerad",
    "onertransformerats": "onertransformerad",
    "onertransformerbara": "onertransformerbar",
    "onertransformerbarare": "onertransformerbar",
    "onertransformerbarares": "onertransformerbar",
    "onertransformerbaras": "onertransformerbar",
    "onertransformerbarast": "onertransformerbar",
    "onertransformerbaraste": "onertransformerbar",
    "onertransformerbarastes": "onertransformerbar",
    "onertransformerbarasts": "onertransformerbar",
    "onertransformerbare": "onertransformerbar",
    "onertransformerbares": "onertransformerbar",
    "onertransformerbarheten": "onertransformerbarhet",
    "onertransformerbarhetens": "onertransformerbarhet",
    "onertransformerbarhets": "onertransformerbarhet",
    "onertransformerbars": "onertransformerbar",
    "onertransformerbart": "onertransformerbar",
    "onertransformerbarts": "onertransformerbar",
    "onertransponerade": "onertransponerad",
    "onertransponerades": "onertransponerad",
    "onertransponerads": "onertransponerad",
    "onertransponerat": "onertransponerad",
    "onertransponerats": "onertransponerad",
    "onertransponerbara": "onertransponerbar",
    "onertransponerbarare": "onertransponerbar",
    "onertransponerbarares": "onertransponerbar",
    "onertransponerbaras": "onertransponerbar",
    "onertransponerbarast": "onertransponerbar",
    "onertransponerbaraste": "onertransponerbar",
    "onertransponerbarastes": "onertransponerbar",
    "onertransponerbarasts": "onertransponerbar",
    "onertransponerbare": "onertransponerbar",
    "onertransponerbares": "onertransponerbar",
    "onertransponerbarheten": "onertransponerbarhet",
    "onertransponerbarhetens": "onertransponerbarhet",
    "onertransponerbarhets": "onertransponerbarhet",
    "onertransponerbars": "onertransponerbar",
    "onertransponerbart": "onertransponerbar",
    "onertransponerbarts": "onertransponerbar",
    "onervärderade": "onervärderad",
    "onervärderades": "onervärderad",
    "onervärderads": "onervärderad",
    "onervärderat": "onervärderad",
    "onervärderats": "onervärderad",
    "onervärderbara": "onervärderbar",
    "onervärderbarare": "onervärderbar",
    "onervärderbarares": "onervärderbar",
    "onervärderbaras": "onervärderbar",
    "onervärderbarast": "onervärderbar",
    "onervärderbaraste": "onervärderbar",
    "onervärderbarastes": "onervärderbar",
    "onervärderbarasts": "onervärderbar",
    "onervärderbare": "onervärderbar",
    "onervärderbares": "onervärderbar",
    "onervärderbarheten": "onervärderbarhet",
    "onervärderbarhetens": "onervärderbarhet",
    "onervärderbarhets": "onervärderbarhet",
    "onervärderbars": "onervärderbar",
    "onervärderbart": "onervärderbar",
    "onervärderbarts": "onervärderbar",
    "onestepen": "onestep",
    "onestepens": "onestep",
    "onesteps": "onestep",
    "oneutraliserade": "oneutraliserad",
    "oneutraliserades": "oneutraliserad",
    "oneutraliserads": "oneutraliserad",
    "oneutraliserat": "oneutraliserad",
    "oneutraliserats": "oneutraliserad",
    "oneutraliserbara": "oneutraliserbar",
    "oneutraliserbarare": "oneutraliserbar",
    "oneutraliserbarares": "oneutraliserbar",
    "oneutraliserbaras": "oneutraliserbar",
    "oneutraliserbarast": "oneutraliserbar",
    "oneutraliserbaraste": "oneutraliserbar",
    "oneutraliserbarastes": "oneutraliserbar",
    "oneutraliserbarasts": "oneutraliserbar",
    "oneutraliserbare": "oneutraliserbar",
    "oneutraliserbares": "oneutraliserbar",
    "oneutraliserbarheten": "oneutraliserbarhet",
    "oneutraliserbarhetens": "oneutraliserbarhet",
    "oneutraliserbarhets": "oneutraliserbarhet",
    "oneutraliserbars": "oneutraliserbar",
    "oneutraliserbart": "oneutraliserbar",
    "oneutraliserbarts": "oneutraliserbar",
    "oniade": "oniad",
    "oniades": "oniad",
    "oniads": "oniad",
    "oniat": "oniad",
    "oniats": "oniad",
    "onickade": "onickad",
    "onickades": "onickad",
    "onickads": "onickad",
    "onickat": "onickad",
    "onickats": "onickad",
    "oniellerade": "oniellerad",
    "oniellerades": "oniellerad",
    "oniellerads": "oniellerad",
    "oniellerat": "oniellerad",
    "oniellerats": "oniellerad",
    "oniellerbara": "oniellerbar",
    "oniellerbarare": "oniellerbar",
    "oniellerbarares": "oniellerbar",
    "oniellerbaras": "oniellerbar",
    "oniellerbarast": "oniellerbar",
    "oniellerbaraste": "oniellerbar",
    "oniellerbarastes": "oniellerbar",
    "oniellerbarasts": "oniellerbar",
    "oniellerbare": "oniellerbar",
    "oniellerbares": "oniellerbar",
    "oniellerbarheten": "oniellerbarhet",
    "oniellerbarhetens": "oniellerbarhet",
    "oniellerbarhets": "oniellerbarhet",
    "oniellerbars": "oniellerbar",
    "oniellerbart": "oniellerbar",
    "oniellerbarts": "oniellerbar",
    "onitade": "onitad",
    "onitades": "onitad",
    "onitads": "onitad",
    "onitat": "onitad",
    "onitats": "onitad",
    "onitrerade": "onitrerad",
    "onitrerades": "onitrerad",
    "onitrerads": "onitrerad",
    "onitrerat": "onitrerad",
    "onitrerats": "onitrerad",
    "onitrerbara": "onitrerbar",
    "onitrerbarare": "onitrerbar",
    "onitrerbarares": "onitrerbar",
    "onitrerbaras": "onitrerbar",
    "onitrerbarast": "onitrerbar",
    "onitrerbaraste": "onitrerbar",
    "onitrerbarastes": "onitrerbar",
    "onitrerbarasts": "onitrerbar",
    "onitrerbare": "onitrerbar",
    "onitrerbares": "onitrerbar",
    "onitrerbarheten": "onitrerbarhet",
    "onitrerbarhetens": "onitrerbarhet",
    "onitrerbarhets": "onitrerbarhet",
    "onitrerbars": "onitrerbar",
    "onitrerbart": "onitrerbar",
    "onitrerbarts": "onitrerbar",
    "onivellerade": "onivellerad",
    "onivellerades": "onivellerad",
    "onivellerads": "onivellerad",
    "onivellerat": "onivellerad",
    "onivellerats": "onivellerad",
    "onivellerbara": "onivellerbar",
    "onivellerbarare": "onivellerbar",
    "onivellerbarares": "onivellerbar",
    "onivellerbaras": "onivellerbar",
    "onivellerbarast": "onivellerbar",
    "onivellerbaraste": "onivellerbar",
    "onivellerbarastes": "onivellerbar",
    "onivellerbarasts": "onivellerbar",
    "onivellerbare": "onivellerbar",
    "onivellerbares": "onivellerbar",
    "onivellerbarheten": "onivellerbarhet",
    "onivellerbarhetens": "onivellerbarhet",
    "onivellerbarhets": "onivellerbarhet",
    "onivellerbars": "onivellerbar",
    "onivellerbart": "onivellerbar",
    "onivellerbarts": "onivellerbar",
    "onkeln": "onkel",
    "onkelns": "onkel",
    "onkels": "onkel",
    "onklar": "onkel",
    "onklarna": "onkel",
    "onklarnas": "onkel",
    "onklars": "onkel",
    "onkologen": "onkolog",
    "onkologens": "onkolog",
    "onkologer": "onkolog",
    "onkologerna": "onkolog",
    "onkologernas": "onkolog",
    "onkologers": "onkolog",
    "onkologien": "onkologi",
    "onkologiens": "onkologi",
    "onkologin": "onkologi",
    "onkologins": "onkologi",
    "onkologis": "onkologi",
    "onkologs": "onkolog",
    "onobbade": "onobbad",
    "onobbades": "onobbad",
    "onobbads": "onobbad",
    "onobbat": "onobbad",
    "onobbats": "onobbad",
    "onobiliserade": "onobiliserad",
    "onobiliserades": "onobiliserad",
    "onobiliserads": "onobiliserad",
    "onobiliserat": "onobiliserad",
    "onobiliserats": "onobiliserad",
    "onobiliserbara": "onobiliserbar",
    "onobiliserbarare": "onobiliserbar",
    "onobiliserbarares": "onobiliserbar",
    "onobiliserbaras": "onobiliserbar",
    "onobiliserbarast": "onobiliserbar",
    "onobiliserbaraste": "onobiliserbar",
    "onobiliserbarastes": "onobiliserbar",
    "onobiliserbarasts": "onobiliserbar",
    "onobiliserbare": "onobiliserbar",
    "onobiliserbares": "onobiliserbar",
    "onobiliserbarheten": "onobiliserbarhet",
    "onobiliserbarhetens": "onobiliserbarhet",
    "onobiliserbarhets": "onobiliserbarhet",
    "onobiliserbars": "onobiliserbar",
    "onobiliserbart": "onobiliserbar",
    "onobiliserbarts": "onobiliserbar",
    "onockade": "onockad",
    "onockades": "onockad",
    "onockads": "onockad",
    "onockat": "onockad",
    "onockats": "onockad",
    "onollade": "onollad",
    "onollades": "onollad",
    "onollads": "onollad",
    "onollat": "onollad",
    "onollats": "onollad",
    "onomastiska": "onomastisk",
    "onomastiskare": "onomastisk",
    "onomastiskares": "onomastisk",
    "onomastiskas": "onomastisk",
    "onomastiskast": "onomastisk",
    "onomastiskaste": "onomastisk",
    "onomastiskastes": "onomastisk",
    "onomastiskasts": "onomastisk",
    "onomastiske": "onomastisk",
    "onomastiskes": "onomastisk",
    "onomastisks": "onomastisk",
    "onomastiskt": "onomastisk",
    "onomastiskts": "onomastisk",
    "onomatologien": "onomatologi",
    "onomatologiens": "onomatologi",
    "onomatologin": "onomatologi",
    "onomatologins": "onomatologi",
    "onomatologis": "onomatologi",
    "onomatopoetiska": "onomatopoetisk",
    "onomatopoetiskare": "onomatopoetisk",
    "onomatopoetiskares": "onomatopoetisk",
    "onomatopoetiskas": "onomatopoetisk",
    "onomatopoetiskast": "onomatopoetisk",
    "onomatopoetiskaste": "onomatopoetisk",
    "onomatopoetiskastes": "onomatopoetisk",
    "onomatopoetiskasts": "onomatopoetisk",
    "onomatopoetiske": "onomatopoetisk",
    "onomatopoetiskes": "onomatopoetisk",
    "onomatopoetisks": "onomatopoetisk",
    "onomatopoetiskt": "onomatopoetisk",
    "onomatopoetiskts": "onomatopoetisk",
    "onominerade": "onominerad",
    "onominerades": "onominerad",
    "onominerads": "onominerad",
    "onominerat": "onominerad",
    "onominerats": "onominerad",
    "onominerbara": "onominerbar",
    "onominerbarare": "onominerbar",
    "onominerbarares": "onominerbar",
    "onominerbaras": "onominerbar",
    "onominerbarast": "onominerbar",
    "onominerbaraste": "onominerbar",
    "onominerbarastes": "onominerbar",
    "onominerbarasts": "onominerbar",
    "onominerbare": "onominerbar",
    "onominerbares": "onominerbar",
    "onominerbarheten": "onominerbarhet",
    "onominerbarhetens": "onominerbarhet",
    "onominerbarhets": "onominerbarhet",
    "onominerbars": "onominerbar",
    "onominerbart": "onominerbar",
    "onominerbarts": "onominerbar",
    "ononchalerade": "ononchalerad",
    "ononchalerades": "ononchalerad",
    "ononchalerads": "ononchalerad",
    "ononchalerat": "ononchalerad",
    "ononchalerats": "ononchalerad",
    "ononchalerbara": "ononchalerbar",
    "ononchalerbarare": "ononchalerbar",
    "ononchalerbarares": "ononchalerbar",
    "ononchalerbaras": "ononchalerbar",
    "ononchalerbarast": "ononchalerbar",
    "ononchalerbaraste": "ononchalerbar",
    "ononchalerbarastes": "ononchalerbar",
    "ononchalerbarasts": "ononchalerbar",
    "ononchalerbare": "ononchalerbar",
    "ononchalerbares": "ononchalerbar",
    "ononchalerbarheten": "ononchalerbarhet",
    "ononchalerbarhetens": "ononchalerbarhet",
    "ononchalerbarhets": "ononchalerbarhet",
    "ononchalerbars": "ononchalerbar",
    "ononchalerbart": "ononchalerbar",
    "ononchalerbarts": "ononchalerbar",
    "onoppade": "onoppad",
    "onoppades": "onoppad",
    "onoppads": "onoppad",
    "onoppat": "onoppad",
    "onoppats": "onoppad",
    "onormala": "onormal",
    "onormalare": "onormal",
    "onormalares": "onormal",
    "onormalas": "onormal",
    "onormalast": "onormal",
    "onormalaste": "onormal",
    "onormalastes": "onormal",
    "onormalasts": "onormal",
    "onormale": "onormal",
    "onormales": "onormal",
    "onormaliserade": "onormaliserad",
    "onormaliserades": "onormaliserad",
    "onormaliserads": "onormaliserad",
    "onormaliserat": "onormaliserad",
    "onormaliserats": "onormaliserad",
    "onormaliserbara": "onormaliserbar",
    "onormaliserbarare": "onormaliserbar",
    "onormaliserbarares": "onormaliserbar",
    "onormaliserbaras": "onormaliserbar",
    "onormaliserbarast": "onormaliserbar",
    "onormaliserbaraste": "onormaliserbar",
    "onormaliserbarastes": "onormaliserbar",
    "onormaliserbarasts": "onormaliserbar",
    "onormaliserbare": "onormaliserbar",
    "onormaliserbares": "onormaliserbar",
    "onormaliserbarheten": "onormaliserbarhet",
    "onormaliserbarhetens": "onormaliserbarhet",
    "onormaliserbarhets": "onormaliserbarhet",
    "onormaliserbars": "onormaliserbar",
    "onormaliserbart": "onormaliserbar",
    "onormaliserbarts": "onormaliserbar",
    "onormals": "onormal",
    "onormalt": "onormal",
    "onormalts": "onormal",
    "onormerade": "onormerad",
    "onormerades": "onormerad",
    "onormerads": "onormerad",
    "onormerat": "onormerad",
    "onormerats": "onormerad",
    "onormerbara": "onormerbar",
    "onormerbarare": "onormerbar",
    "onormerbarares": "onormerbar",
    "onormerbaras": "onormerbar",
    "onormerbarast": "onormerbar",
    "onormerbaraste": "onormerbar",
    "onormerbarastes": "onormerbar",
    "onormerbarasts": "onormerbar",
    "onormerbare": "onormerbar",
    "onormerbares": "onormerbar",
    "onormerbarheten": "onormerbarhet",
    "onormerbarhetens": "onormerbarhet",
    "onormerbarhets": "onormerbarhet",
    "onormerbars": "onormerbar",
    "onormerbart": "onormerbar",
    "onormerbarts": "onormerbar",
    "onorpade": "onorpad",
    "onorpades": "onorpad",
    "onorpads": "onorpad",
    "onorpat": "onorpad",
    "onorpats": "onorpad",
    "onosliga": "onoslig",
    "onosligare": "onoslig",
    "onosligares": "onoslig",
    "onosligas": "onoslig",
    "onosligast": "onoslig",
    "onosligaste": "onoslig",
    "onosligastes": "onoslig",
    "onosligasts": "onoslig",
    "onoslige": "onoslig",
    "onosliges": "onoslig",
    "onosligheten": "onoslighet",
    "onoslighetens": "onoslighet",
    "onoslighets": "onoslighet",
    "onosligs": "onoslig",
    "onosligt": "onoslig",
    "onosligts": "onoslig",
    "onotade": "onotad",
    "onotades": "onotad",
    "onotads": "onotad",
    "onotat": "onotad",
    "onotats": "onotad",
    "onoterade": "onoterad",
    "onoterades": "onoterad",
    "onoterads": "onoterad",
    "onoterat": "onoterad",
    "onoterats": "onoterad",
    "onoterbara": "onoterbar",
    "onoterbarare": "onoterbar",
    "onoterbarares": "onoterbar",
    "onoterbaras": "onoterbar",
    "onoterbarast": "onoterbar",
    "onoterbaraste": "onoterbar",
    "onoterbarastes": "onoterbar",
    "onoterbarasts": "onoterbar",
    "onoterbare": "onoterbar",
    "onoterbares": "onoterbar",
    "onoterbarheten": "onoterbarhet",
    "onoterbarhetens": "onoterbarhet",
    "onoterbarhets": "onoterbarhet",
    "onoterbars": "onoterbar",
    "onoterbart": "onoterbar",
    "onoterbarts": "onoterbar",
    "onotificerade": "onotificerad",
    "onotificerades": "onotificerad",
    "onotificerads": "onotificerad",
    "onotificerat": "onotificerad",
    "onotificerats": "onotificerad",
    "onotificerbara": "onotificerbar",
    "onotificerbarare": "onotificerbar",
    "onotificerbarares": "onotificerbar",
    "onotificerbaras": "onotificerbar",
    "onotificerbarast": "onotificerbar",
    "onotificerbaraste": "onotificerbar",
    "onotificerbarastes": "onotificerbar",
    "onotificerbarasts": "onotificerbar",
    "onotificerbare": "onotificerbar",
    "onotificerbares": "onotificerbar",
    "onotificerbarheten": "onotificerbarhet",
    "onotificerbarhetens": "onotificerbarhet",
    "onotificerbarhets": "onotificerbarhet",
    "onotificerbars": "onotificerbar",
    "onotificerbart": "onotificerbar",
    "onotificerbarts": "onotificerbar",
    "onotifierade": "onotifierad",
    "onotifierades": "onotifierad",
    "onotifierads": "onotifierad",
    "onotifierat": "onotifierad",
    "onotifierats": "onotifierad",
    "onotifierbara": "onotifierbar",
    "onotifierbarare": "onotifierbar",
    "onotifierbarares": "onotifierbar",
    "onotifierbaras": "onotifierbar",
    "onotifierbarast": "onotifierbar",
    "onotifierbaraste": "onotifierbar",
    "onotifierbarastes": "onotifierbar",
    "onotifierbarasts": "onotifierbar",
    "onotifierbare": "onotifierbar",
    "onotifierbares": "onotifierbar",
    "onotifierbarheten": "onotifierbarhet",
    "onotifierbarhetens": "onotifierbarhet",
    "onotifierbarhets": "onotifierbarhet",
    "onotifierbars": "onotifierbar",
    "onotifierbart": "onotifierbar",
    "onotifierbarts": "onotifierbar",
    "onotiserade": "onotiserad",
    "onotiserades": "onotiserad",
    "onotiserads": "onotiserad",
    "onotiserat": "onotiserad",
    "onotiserats": "onotiserad",
    "onotiserbara": "onotiserbar",
    "onotiserbarare": "onotiserbar",
    "onotiserbarares": "onotiserbar",
    "onotiserbaras": "onotiserbar",
    "onotiserbarast": "onotiserbar",
    "onotiserbaraste": "onotiserbar",
    "onotiserbarastes": "onotiserbar",
    "onotiserbarasts": "onotiserbar",
    "onotiserbare": "onotiserbar",
    "onotiserbares": "onotiserbar",
    "onotiserbarheten": "onotiserbarhet",
    "onotiserbarhetens": "onotiserbarhet",
    "onotiserbarhets": "onotiserbarhet",
    "onotiserbars": "onotiserbar",
    "onotiserbart": "onotiserbar",
    "onotiserbarts": "onotiserbar",
    "ons": "o",
    "onsdagar": "onsdag",
    "onsdagarna": "onsdag",
    "onsdagarnas": "onsdag",
    "onsdagars": "onsdag",
    "onsdageftermiddagar": "onsdageftermiddag",
    "onsdageftermiddagarna": "onsdageftermiddag",
    "onsdageftermiddagarnas": "onsdageftermiddag",
    "onsdageftermiddagars": "onsdageftermiddag",
    "onsdageftermiddagen": "onsdageftermiddag",
    "onsdageftermiddagens": "onsdageftermiddag",
    "onsdageftermiddags": "onsdageftermiddag",
    "onsdagen": "onsdag",
    "onsdagens": "onsdag",
    "onsdagkvällar": "onsdagkväll",
    "onsdagkvällarna": "onsdagkväll",
    "onsdagkvällarnas": "onsdagkväll",
    "onsdagkvällars": "onsdagkväll",
    "onsdagkvällen": "onsdagkväll",
    "onsdagkvällens": "onsdagkväll",
    "onsdagkvälls": "onsdagkväll",
    "onsdagmorgnar": "onsdagmorgon",
    "onsdagmorgnarna": "onsdagmorgon",
    "onsdagmorgnarnas": "onsdagmorgon",
    "onsdagmorgnars": "onsdagmorgon",
    "onsdagmorgonen": "onsdagmorgon",
    "onsdagmorgonens": "onsdagmorgon",
    "onsdagmorgons": "onsdagmorgon",
    "onsdagmornar": "onsdagmorgon",
    "onsdagmornarna": "onsdagmorgon",
    "onsdagmornarnas": "onsdagmorgon",
    "onsdagmornars": "onsdagmorgon",
    "onsdags": "onsdag",
    "onsdagseftermiddagar": "onsdagseftermiddag",
    "onsdagseftermiddagarna": "onsdagseftermiddag",
    "onsdagseftermiddagarnas": "onsdagseftermiddag",
    "onsdagseftermiddagars": "onsdagseftermiddag",
    "onsdagseftermiddagen": "onsdagseftermiddag",
    "onsdagseftermiddagens": "onsdagseftermiddag",
    "onsdagseftermiddags": "onsdagseftermiddag",
    "onsdagskvällar": "onsdagskväll",
    "onsdagskvällarna": "onsdagskväll",
    "onsdagskvällarnas": "onsdagskväll",
    "onsdagskvällars": "onsdagskväll",
    "onsdagskvällen": "onsdagskväll",
    "onsdagskvällens": "onsdagskväll",
    "onsdagskvälls": "onsdagskväll",
    "onsdagsmorgnar": "onsdagsmorgon",
    "onsdagsmorgnarna": "onsdagsmorgon",
    "onsdagsmorgnarnas": "onsdagsmorgon",
    "onsdagsmorgnars": "onsdagsmorgon",
    "onsdagsmorgonen": "onsdagsmorgon",
    "onsdagsmorgonens": "onsdagsmorgon",
    "onsdagsmorgons": "onsdagsmorgon",
    "onsdagsmornar": "onsdagsmorgon",
    "onsdagsmornarna": "onsdagsmorgon",
    "onsdagsmornarnas": "onsdagsmorgon",
    "onsdagsmornars": "onsdagsmorgon",
    "ont": "ond",
    "onten": "ont",
    "ontens": "ont",
    "ontet": "ont",
    "ontets": "ont",
    "ontogenetiska": "ontogenetisk",
    "ontogenetiskare": "ontogenetisk",
    "ontogenetiskares": "ontogenetisk",
    "ontogenetiskas": "ontogenetisk",
    "ontogenetiskast": "ontogenetisk",
    "ontogenetiskaste": "ontogenetisk",
    "ontogenetiskastes": "ontogenetisk",
    "ontogenetiskasts": "ontogenetisk",
    "ontogenetiske": "ontogenetisk",
    "ontogenetiskes": "ontogenetisk",
    "ontogenetisks": "ontogenetisk",
    "ontogenetiskt": "ontogenetisk",
    "ontogenetiskts": "ontogenetisk",
    "ontogenien": "ontogeni",
    "ontogeniens": "ontogeni",
    "ontogenin": "ontogeni",
    "ontogenins": "ontogeni",
    "ontogenis": "ontogeni",
    "ontologien": "ontologi",
    "ontologiens": "ontologi",
    "ontologier": "ontologi",
    "ontologierna": "ontologi",
    "ontologiernas": "ontologi",
    "ontologiers": "ontologi",
    "ontologin": "ontologi",
    "ontologins": "ontologi",
    "ontologis": "ontologi",
    "ontologiska": "ontologisk",
    "ontologiskare": "ontologisk",
    "ontologiskares": "ontologisk",
    "ontologiskas": "ontologisk",
    "ontologiskast": "ontologisk",
    "ontologiskaste": "ontologisk",
    "ontologiskastes": "ontologisk",
    "ontologiskasts": "ontologisk",
    "ontologiske": "ontologisk",
    "ontologiskes": "ontologisk",
    "ontologisks": "ontologisk",
    "ontologiskt": "ontologisk",
    "ontologiskts": "ontologisk",
    "onts": "ont",
    "onubbade": "onubbad",
    "onubbades": "onubbad",
    "onubbads": "onubbad",
    "onubbat": "onubbad",
    "onubbats": "onubbad",
    "onuddade": "onuddad",
    "onuddades": "onuddad",
    "onuddads": "onuddad",
    "onuddat": "onuddad",
    "onuddats": "onuddad",
    "onumrerade": "onumrerad",
    "onumrerades": "onumrerad",
    "onumrerads": "onumrerad",
    "onumrerat": "onumrerad",
    "onumrerats": "onumrerad",
    "onumrerbara": "onumrerbar",
    "onumrerbarare": "onumrerbar",
    "onumrerbarares": "onumrerbar",
    "onumrerbaras": "onumrerbar",
    "onumrerbarast": "onumrerbar",
    "onumrerbaraste": "onumrerbar",
    "onumrerbarastes": "onumrerbar",
    "onumrerbarasts": "onumrerbar",
    "onumrerbare": "onumrerbar",
    "onumrerbares": "onumrerbar",
    "onumrerbarheten": "onumrerbarhet",
    "onumrerbarhetens": "onumrerbarhet",
    "onumrerbarhets": "onumrerbarhet",
    "onumrerbars": "onumrerbar",
    "onumrerbart": "onumrerbar",
    "onumrerbarts": "onumrerbar",
    "onusen": "onus",
    "onusens": "onus",
    "onuset": "onus",
    "onusets": "onus",
    "onyanserade": "onyanserad",
    "onyanserades": "onyanserad",
    "onyanserads": "onyanserad",
    "onyanserat": "onyanserad",
    "onyanserats": "onyanserad",
    "onyanserbara": "onyanserbar",
    "onyanserbarare": "onyanserbar",
    "onyanserbarares": "onyanserbar",
    "onyanserbaras": "onyanserbar",
    "onyanserbarast": "onyanserbar",
    "onyanserbaraste": "onyanserbar",
    "onyanserbarastes": "onyanserbar",
    "onyanserbarasts": "onyanserbar",
    "onyanserbare": "onyanserbar",
    "onyanserbares": "onyanserbar",
    "onyanserbarheten": "onyanserbarhet",
    "onyanserbarhetens": "onyanserbarhet",
    "onyanserbarhets": "onyanserbarhet",
    "onyanserbars": "onyanserbar",
    "onyanserbart": "onyanserbar",
    "onyanserbarts": "onyanserbar",
    "onykterheten": "onykterhet",
    "onykterhetens": "onykterhet",
    "onykterheter": "onykterhet",
    "onykterheterna": "onykterhet",
    "onykterheternas": "onykterhet",
    "onykterheters": "onykterhet",
    "onykterhets": "onykterhet",
    "onykters": "onykter",
    "onyktert": "onykter",
    "onykterts": "onykter",
    "onyktra": "onykter",
    "onyktrare": "onykter",
    "onyktrares": "onykter",
    "onyktras": "onykter",
    "onyktrast": "onykter",
    "onyktraste": "onykter",
    "onyktrastes": "onykter",
    "onyktrasts": "onykter",
    "onyktre": "onykter",
    "onyktres": "onykter",
    "onynnade": "onynnad",
    "onynnades": "onynnad",
    "onynnads": "onynnad",
    "onynnat": "onynnad",
    "onynnats": "onynnad",
    "onystade": "onystad",
    "onystades": "onystad",
    "onystads": "onystad",
    "onystat": "onystad",
    "onystats": "onystad",
    "onyttiga": "onyttig",
    "onyttigare": "onyttig",
    "onyttigares": "onyttig",
    "onyttigas": "onyttig",
    "onyttigast": "onyttig",
    "onyttigaste": "onyttig",
    "onyttigastes": "onyttig",
    "onyttigasts": "onyttig",
    "onyttige": "onyttig",
    "onyttiges": "onyttig",
    "onyttigheten": "onyttighet",
    "onyttighetens": "onyttighet",
    "onyttigheter": "onyttighet",
    "onyttigheterna": "onyttighet",
    "onyttigheternas": "onyttighet",
    "onyttigheters": "onyttighet",
    "onyttighets": "onyttighet",
    "onyttigs": "onyttig",
    "onyttigt": "onyttig",
    "onyttigts": "onyttig",
    "onyttjade": "onyttjad",
    "onyttjades": "onyttjad",
    "onyttjads": "onyttjad",
    "onyttjat": "onyttjad",
    "onyttjats": "onyttjad",
    "onyxar": "onyx",
    "onyxarna": "onyx",
    "onyxarnas": "onyx",
    "onyxars": "onyx",
    "onyxen": "onyx",
    "onyxens": "onyx",
    "onämnbara": "onämnbar",
    "onämnbarare": "onämnbar",
    "onämnbarares": "onämnbar",
    "onämnbaras": "onämnbar",
    "onämnbarast": "onämnbar",
    "onämnbaraste": "onämnbar",
    "onämnbarastes": "onämnbar",
    "onämnbarasts": "onämnbar",
    "onämnbare": "onämnbar",
    "onämnbares": "onämnbar",
    "onämnbarheten": "onämnbarhet",
    "onämnbarhetens": "onämnbarhet",
    "onämnbarhets": "onämnbarhet",
    "onämnbars": "onämnbar",
    "onämnbart": "onämnbar",
    "onämnbarts": "onämnbar",
    "onämnde": "onämnd",
    "onämndes": "onämnd",
    "onämnds": "onämnd",
    "onämnt": "onämnd",
    "onämnts": "onämnd",
    "onäpsta": "onäpst",
    "onäpstas": "onäpst",
    "onäpste": "onäpst",
    "onäpstes": "onäpst",
    "onäpsts": "onäpst",
    "onärde": "onärd",
    "onärdes": "onärd",
    "onärds": "onärd",
    "onärmade": "onärmad",
    "onärmades": "onärmad",
    "onärmads": "onärmad",
    "onärmat": "onärmad",
    "onärmats": "onärmad",
    "onärt": "onärd",
    "onärts": "onärd",
    "onätade": "onätad",
    "onätades": "onätad",
    "onätads": "onätad",
    "onätat": "onätad",
    "onätats": "onätad",
    "onåbara": "onåbar",
    "onåbarare": "onåbar",
    "onåbarares": "onåbar",
    "onåbaras": "onåbar",
    "onåbarast": "onåbar",
    "onåbaraste": "onåbar",
    "onåbarastes": "onåbar",
    "onåbarasts": "onåbar",
    "onåbare": "onåbar",
    "onåbares": "onåbar",
    "onåbarheten": "onåbarhet",
    "onåbarhetens": "onåbarhet",
    "onåbarhets": "onåbarhet",
    "onåbars": "onåbar",
    "onåbart": "onåbar",
    "onåbarts": "onåbar",
    "onådade": "onådad",
    "onådades": "onådad",
    "onådads": "onådad",
    "onådat": "onådad",
    "onådats": "onådad",
    "onåden": "onåd",
    "onådens": "onåd",
    "onådiga": "onådig",
    "onådigare": "onådig",
    "onådigares": "onådig",
    "onådigas": "onådig",
    "onådigast": "onådig",
    "onådigaste": "onådig",
    "onådigastes": "onådig",
    "onådigasts": "onådig",
    "onådige": "onådig",
    "onådiges": "onådig",
    "onådigheten": "onådighet",
    "onådighetens": "onådighet",
    "onådighets": "onådighet",
    "onådigs": "onådig",
    "onådigt": "onådig",
    "onådigts": "onådig",
    "onåds": "onåd",
    "onålade": "onålad",
    "onålades": "onålad",
    "onålads": "onålad",
    "onålat": "onålad",
    "onålats": "onålad",
    "onåtade": "onåtad",
    "onåtades": "onåtad",
    "onåtads": "onåtad",
    "onåtat": "onåtad",
    "onåtats": "onåtad",
    "onåtlade": "onåtlad",
    "onåtlades": "onåtlad",
    "onåtlads": "onåtlad",
    "onåtlat": "onåtlad",
    "onåtlats": "onåtlad",
    "onödgade": "onödgad",
    "onödgades": "onödgad",
    "onödgads": "onödgad",
    "onödgat": "onödgad",
    "onödgats": "onödgad",
    "onödiga": "onödig",
    "onödigare": "onödig",
    "onödigares": "onödig",
    "onödigas": "onödig",
    "onödigast": "onödig",
    "onödigaste": "onödig",
    "onödigastes": "onödig",
    "onödigasts": "onödig",
    "onödige": "onödig",
    "onödiges": "onödig",
    "onödigheten": "onödighet",
    "onödighetens": "onödighet",
    "onödigheter": "onödighet",
    "onödigheterna": "onödighet",
    "onödigheternas": "onödighet",
    "onödigheters": "onödighet",
    "onödighets": "onödighet",
    "onödigs": "onödig",
    "onödigt": "onödig",
    "onödigts": "onödig",
    "onöjaktiga": "onöjaktig",
    "onöjaktigare": "onöjaktig",
    "onöjaktigares": "onöjaktig",
    "onöjaktigas": "onöjaktig",
    "onöjaktigast": "onöjaktig",
    "onöjaktigaste": "onöjaktig",
    "onöjaktigastes": "onöjaktig",
    "onöjaktigasts": "onöjaktig",
    "onöjaktige": "onöjaktig",
    "onöjaktiges": "onöjaktig",
    "onöjaktigheten": "onöjaktighet",
    "onöjaktighetens": "onöjaktighet",
    "onöjaktighets": "onöjaktighet",
    "onöjaktigs": "onöjaktig",
    "onöjaktigt": "onöjaktig",
    "onöjaktigts": "onöjaktig",
    "onötta": "onött",
    "onöttas": "onött",
    "onötte": "onött",
    "onöttes": "onött",
    "onötts": "onött",
    "oobducerade": "oobducerad",
    "oobducerades": "oobducerad",
    "oobducerads": "oobducerad",
    "oobducerat": "oobducerad",
    "oobducerats": "oobducerad",
    "oobducerbara": "oobducerbar",
    "oobducerbarare": "oobducerbar",
    "oobducerbarares": "oobducerbar",
    "oobducerbaras": "oobducerbar",
    "oobducerbarast": "oobducerbar",
    "oobducerbaraste": "oobducerbar",
    "oobducerbarastes": "oobducerbar",
    "oobducerbarasts": "oobducerbar",
    "oobducerbare": "oobducerbar",
    "oobducerbares": "oobducerbar",
    "oobducerbarheten": "oobducerbarhet",
    "oobducerbarhetens": "oobducerbarhet",
    "oobducerbarhets": "oobducerbarhet",
    "oobducerbars": "oobducerbar",
    "oobducerbart": "oobducerbar",
    "oobducerbarts": "oobducerbar",
    "oobjektiverade": "oobjektiverad",
    "oobjektiverades": "oobjektiverad",
    "oobjektiverads": "oobjektiverad",
    "oobjektiverat": "oobjektiverad",
    "oobjektiverats": "oobjektiverad",
    "oobjektiverbara": "oobjektiverbar",
    "oobjektiverbarare": "oobjektiverbar",
    "oobjektiverbarares": "oobjektiverbar",
    "oobjektiverbaras": "oobjektiverbar",
    "oobjektiverbarast": "oobjektiverbar",
    "oobjektiverbaraste": "oobjektiverbar",
    "oobjektiverbarastes": "oobjektiverbar",
    "oobjektiverbarasts": "oobjektiverbar",
    "oobjektiverbare": "oobjektiverbar",
    "oobjektiverbares": "oobjektiverbar",
    "oobjektiverbarheten": "oobjektiverbarhet",
    "oobjektiverbarhetens": "oobjektiverbarhet",
    "oobjektiverbarhets": "oobjektiverbarhet",
    "oobjektiverbars": "oobjektiverbar",
    "oobjektiverbart": "oobjektiverbar",
    "oobjektiverbarts": "oobjektiverbar",
    "oobligerade": "oobligerad",
    "oobligerades": "oobligerad",
    "oobligerads": "oobligerad",
    "oobligerat": "oobligerad",
    "oobligerats": "oobligerad",
    "oobligerbara": "oobligerbar",
    "oobligerbarare": "oobligerbar",
    "oobligerbarares": "oobligerbar",
    "oobligerbaras": "oobligerbar",
    "oobligerbarast": "oobligerbar",
    "oobligerbaraste": "oobligerbar",
    "oobligerbarastes": "oobligerbar",
    "oobligerbarasts": "oobligerbar",
    "oobligerbare": "oobligerbar",
    "oobligerbares": "oobligerbar",
    "oobligerbarheten": "oobligerbarhet",
    "oobligerbarhetens": "oobligerbarhet",
    "oobligerbarhets": "oobligerbarhet",
    "oobligerbars": "oobligerbar",
    "oobligerbart": "oobligerbar",
    "oobligerbarts": "oobligerbar",
    "oobserverade": "oobserverad",
    "oobserverades": "oobserverad",
    "oobserverads": "oobserverad",
    "oobserverat": "oobserverad",
    "oobserverats": "oobserverad",
    "oobserverbara": "oobserverbar",
    "oobserverbarare": "oobserverbar",
    "oobserverbarares": "oobserverbar",
    "oobserverbaras": "oobserverbar",
    "oobserverbarast": "oobserverbar",
    "oobserverbaraste": "oobserverbar",
    "oobserverbarastes": "oobserverbar",
    "oobserverbarasts": "oobserverbar",
    "oobserverbare": "oobserverbar",
    "oobserverbares": "oobserverbar",
    "oobserverbarheten": "oobserverbarhet",
    "oobserverbarhetens": "oobserverbarhet",
    "oobserverbarhets": "oobserverbarhet",
    "oobserverbars": "oobserverbar",
    "oobserverbart": "oobserverbar",
    "oobserverbarts": "oobserverbar",
    "ooccidentaliserade": "ooccidentaliserad",
    "ooccidentaliserades": "ooccidentaliserad",
    "ooccidentaliserads": "ooccidentaliserad",
    "ooccidentaliserat": "ooccidentaliserad",
    "ooccidentaliserats": "ooccidentaliserad",
    "ooccidentaliserbara": "ooccidentaliserbar",
    "ooccidentaliserbarare": "ooccidentaliserbar",
    "ooccidentaliserbarares": "ooccidentaliserbar",
    "ooccidentaliserbaras": "ooccidentaliserbar",
    "ooccidentaliserbarast": "ooccidentaliserbar",
    "ooccidentaliserbaraste": "ooccidentaliserbar",
    "ooccidentaliserbarastes": "ooccidentaliserbar",
    "ooccidentaliserbarasts": "ooccidentaliserbar",
    "ooccidentaliserbare": "ooccidentaliserbar",
    "ooccidentaliserbares": "ooccidentaliserbar",
    "ooccidentaliserbarheten": "ooccidentaliserbarhet",
    "ooccidentaliserbarhetens": "ooccidentaliserbarhet",
    "ooccidentaliserbarhets": "ooccidentaliserbarhet",
    "ooccidentaliserbars": "ooccidentaliserbar",
    "ooccidentaliserbart": "ooccidentaliserbar",
    "ooccidentaliserbarts": "ooccidentaliserbar",
    "oockuperade": "oockuperad",
    "oockuperades": "oockuperad",
    "oockuperads": "oockuperad",
    "oockuperat": "oockuperad",
    "oockuperats": "oockuperad",
    "oockuperbara": "oockuperbar",
    "oockuperbarare": "oockuperbar",
    "oockuperbarares": "oockuperbar",
    "oockuperbaras": "oockuperbar",
    "oockuperbarast": "oockuperbar",
    "oockuperbaraste": "oockuperbar",
    "oockuperbarastes": "oockuperbar",
    "oockuperbarasts": "oockuperbar",
    "oockuperbare": "oockuperbar",
    "oockuperbares": "oockuperbar",
    "oockuperbarheten": "oockuperbarhet",
    "oockuperbarhetens": "oockuperbarhet",
    "oockuperbarhets": "oockuperbarhet",
    "oockuperbars": "oockuperbar",
    "oockuperbart": "oockuperbar",
    "oockuperbarts": "oockuperbar",
    "oodlade": "oodlad",
    "oodlades": "oodlad",
    "oodlads": "oodlad",
    "oodlat": "oodlad",
    "oodlats": "oodlad",
    "ooffererade": "ooffererad",
    "ooffererades": "ooffererad",
    "ooffererads": "ooffererad",
    "ooffererat": "ooffererad",
    "ooffererats": "ooffererad",
    "ooffererbara": "ooffererbar",
    "ooffererbarare": "ooffererbar",
    "ooffererbarares": "ooffererbar",
    "ooffererbaras": "ooffererbar",
    "ooffererbarast": "ooffererbar",
    "ooffererbaraste": "ooffererbar",
    "ooffererbarastes": "ooffererbar",
    "ooffererbarasts": "ooffererbar",
    "ooffererbare": "ooffererbar",
    "ooffererbares": "ooffererbar",
    "ooffererbarheten": "ooffererbarhet",
    "ooffererbarhetens": "ooffererbarhet",
    "ooffererbarhets": "ooffererbarhet",
    "ooffererbars": "ooffererbar",
    "ooffererbart": "ooffererbar",
    "ooffererbarts": "ooffererbar",
    "ooffrade": "ooffrad",
    "ooffrades": "ooffrad",
    "ooffrads": "ooffrad",
    "ooffrat": "ooffrad",
    "ooffrats": "ooffrad",
    "oogamien": "oogami",
    "oogamiens": "oogami",
    "oogamin": "oogami",
    "oogamins": "oogami",
    "oogamis": "oogami",
    "ookade": "ookad",
    "ookades": "ookad",
    "ookads": "ookad",
    "ookat": "ookad",
    "ookats": "ookad",
    "ooktrojerade": "ooktrojerad",
    "ooktrojerades": "ooktrojerad",
    "ooktrojerads": "ooktrojerad",
    "ooktrojerat": "ooktrojerad",
    "ooktrojerats": "ooktrojerad",
    "ooktrojerbara": "ooktrojerbar",
    "ooktrojerbarare": "ooktrojerbar",
    "ooktrojerbarares": "ooktrojerbar",
    "ooktrojerbaras": "ooktrojerbar",
    "ooktrojerbarast": "ooktrojerbar",
    "ooktrojerbaraste": "ooktrojerbar",
    "ooktrojerbarastes": "ooktrojerbar",
    "ooktrojerbarasts": "ooktrojerbar",
    "ooktrojerbare": "ooktrojerbar",
    "ooktrojerbares": "ooktrojerbar",
    "ooktrojerbarheten": "ooktrojerbarhet",
    "ooktrojerbarhetens": "ooktrojerbarhet",
    "ooktrojerbarhets": "ooktrojerbarhet",
    "ooktrojerbars": "ooktrojerbar",
    "ooktrojerbart": "ooktrojerbar",
    "ooktrojerbarts": "ooktrojerbar",
    "ookulerade": "ookulerad",
    "ookulerades": "ookulerad",
    "ookulerads": "ookulerad",
    "ookulerat": "ookulerad",
    "ookulerats": "ookulerad",
    "ookulerbara": "ookulerbar",
    "ookulerbarare": "ookulerbar",
    "ookulerbarares": "ookulerbar",
    "ookulerbaras": "ookulerbar",
    "ookulerbarast": "ookulerbar",
    "ookulerbaraste": "ookulerbar",
    "ookulerbarastes": "ookulerbar",
    "ookulerbarasts": "ookulerbar",
    "ookulerbare": "ookulerbar",
    "ookulerbares": "ookulerbar",
    "ookulerbarheten": "ookulerbarhet",
    "ookulerbarhetens": "ookulerbarhet",
    "ookulerbarhets": "ookulerbarhet",
    "ookulerbars": "ookulerbar",
    "ookulerbart": "ookulerbar",
    "ookulerbarts": "ookulerbar",
    "oolade": "oolad",
    "oolades": "oolad",
    "oolads": "oolad",
    "oolat": "oolad",
    "oolats": "oolad",
    "ooliten": "oolit",
    "oolitens": "oolit",
    "oolits": "oolit",
    "ooljade": "ooljad",
    "ooljades": "ooljad",
    "ooljads": "ooljad",
    "ooljat": "ooljad",
    "ooljats": "ooljad",
    "oollade": "oollad",
    "oollades": "oollad",
    "oollads": "oollad",
    "oollat": "oollad",
    "oollats": "oollad",
    "oomarbetade": "oomarbetad",
    "oomarbetades": "oomarbetad",
    "oomarbetads": "oomarbetad",
    "oomarbetat": "oomarbetad",
    "oomarbetats": "oomarbetad",
    "oombedda": "oombedd",
    "oombeddare": "oombedd",
    "oombeddares": "oombedd",
    "oombeddas": "oombedd",
    "oombeddast": "oombedd",
    "oombeddaste": "oombedd",
    "oombeddastes": "oombedd",
    "oombeddasts": "oombedd",
    "oombedde": "oombedd",
    "oombeddes": "oombedd",
    "oombeddheten": "oombeddhet",
    "oombeddhetens": "oombeddhet",
    "oombeddhets": "oombeddhet",
    "oombedds": "oombedd",
    "oombestyrde": "oombestyrd",
    "oombestyrdes": "oombestyrd",
    "oombestyrds": "oombestyrd",
    "oombestyrt": "oombestyrd",
    "oombestyrts": "oombestyrd",
    "oombesörjde": "oombesörjd",
    "oombesörjdes": "oombesörjd",
    "oombesörjds": "oombesörjd",
    "oombesörjt": "oombesörjd",
    "oombesörjts": "oombesörjd",
    "oombett": "oombedd",
    "oombetts": "oombedd",
    "oombildade": "oombildad",
    "oombildades": "oombildad",
    "oombildads": "oombildad",
    "oombildat": "oombildad",
    "oombildats": "oombildad",
    "oomdanade": "oomdanad",
    "oomdanades": "oomdanad",
    "oomdanads": "oomdanad",
    "oomdanat": "oomdanad",
    "oomdanats": "oomdanad",
    "oomdirigerade": "oomdirigerad",
    "oomdirigerades": "oomdirigerad",
    "oomdirigerads": "oomdirigerad",
    "oomdirigerat": "oomdirigerad",
    "oomdirigerats": "oomdirigerad",
    "oomdirigerbara": "oomdirigerbar",
    "oomdirigerbarare": "oomdirigerbar",
    "oomdirigerbarares": "oomdirigerbar",
    "oomdirigerbaras": "oomdirigerbar",
    "oomdirigerbarast": "oomdirigerbar",
    "oomdirigerbaraste": "oomdirigerbar",
    "oomdirigerbarastes": "oomdirigerbar",
    "oomdirigerbarasts": "oomdirigerbar",
    "oomdirigerbare": "oomdirigerbar",
    "oomdirigerbares": "oomdirigerbar",
    "oomdirigerbarheten": "oomdirigerbarhet",
    "oomdirigerbarhetens": "oomdirigerbarhet",
    "oomdirigerbarhets": "oomdirigerbarhet",
    "oomdirigerbars": "oomdirigerbar",
    "oomdirigerbart": "oomdirigerbar",
    "oomdirigerbarts": "oomdirigerbar",
    "oomfamnade": "oomfamnad",
    "oomfamnades": "oomfamnad",
    "oomfamnads": "oomfamnad",
    "oomfamnat": "oomfamnad",
    "oomfamnats": "oomfamnad",
    "oomfattade": "oomfattad",
    "oomfattades": "oomfattad",
    "oomfattads": "oomfattad",
    "oomfattat": "oomfattad",
    "oomfattats": "oomfattad",
    "oomflyttade": "oomflyttad",
    "oomflyttades": "oomflyttad",
    "oomflyttads": "oomflyttad",
    "oomflyttat": "oomflyttad",
    "oomflyttats": "oomflyttad",
    "oomformade": "oomformad",
    "oomformades": "oomformad",
    "oomformads": "oomformad",
    "oomformat": "oomformad",
    "oomformats": "oomformad",
    "oomförde": "oomförd",
    "oomfördelade": "oomfördelad",
    "oomfördelades": "oomfördelad",
    "oomfördelads": "oomfördelad",
    "oomfördelat": "oomfördelad",
    "oomfördelats": "oomfördelad",
    "oomfördes": "oomförd",
    "oomförds": "oomförd",
    "oomförhandlade": "oomförhandlad",
    "oomförhandlades": "oomförhandlad",
    "oomförhandlads": "oomförhandlad",
    "oomförhandlat": "oomförhandlad",
    "oomförhandlats": "oomförhandlad",
    "oomfört": "oomförd",
    "oomförts": "oomförd",
    "oomgestaltade": "oomgestaltad",
    "oomgestaltades": "oomgestaltad",
    "oomgestaltads": "oomgestaltad",
    "oomgestaltat": "oomgestaltad",
    "oomgestaltats": "oomgestaltad",
    "oomgrupperade": "oomgrupperad",
    "oomgrupperades": "oomgrupperad",
    "oomgrupperads": "oomgrupperad",
    "oomgrupperat": "oomgrupperad",
    "oomgrupperats": "oomgrupperad",
    "oomgärdade": "oomgärdad",
    "oomgärdades": "oomgärdad",
    "oomgärdads": "oomgärdad",
    "oomgärdat": "oomgärdad",
    "oomgärdats": "oomgärdad",
    "oomhuldade": "oomhuldad",
    "oomhuldades": "oomhuldad",
    "oomhuldads": "oomhuldad",
    "oomhuldat": "oomhuldad",
    "oomhuldats": "oomhuldad",
    "oomhägnade": "oomhägnad",
    "oomhägnades": "oomhägnad",
    "oomhägnads": "oomhägnad",
    "oomhägnat": "oomhägnad",
    "oomhägnats": "oomhägnad",
    "oomhäktade": "oomhäktad",
    "oomhäktades": "oomhäktad",
    "oomhäktads": "oomhäktad",
    "oomhäktat": "oomhäktad",
    "oomhäktats": "oomhäktad",
    "oomhöljde": "oomhöljd",
    "oomhöljdes": "oomhöljd",
    "oomhöljds": "oomhöljd",
    "oomhöljt": "oomhöljd",
    "oomhöljts": "oomhöljd",
    "oomkastade": "oomkastad",
    "oomkastades": "oomkastad",
    "oomkastads": "oomkastad",
    "oomkastat": "oomkastad",
    "oomkastats": "oomkastad",
    "oomkransade": "oomkransad",
    "oomkransades": "oomkransad",
    "oomkransads": "oomkransad",
    "oomkransat": "oomkransad",
    "oomkransats": "oomkransad",
    "oomkretsade": "oomkretsad",
    "oomkretsades": "oomkretsad",
    "oomkretsads": "oomkretsad",
    "oomkretsat": "oomkretsad",
    "oomkretsats": "oomkretsad",
    "oomkullkastliga": "oomkullkastlig",
    "oomkullkastligare": "oomkullkastlig",
    "oomkullkastligares": "oomkullkastlig",
    "oomkullkastligas": "oomkullkastlig",
    "oomkullkastligast": "oomkullkastlig",
    "oomkullkastligaste": "oomkullkastlig",
    "oomkullkastligastes": "oomkullkastlig",
    "oomkullkastligasts": "oomkullkastlig",
    "oomkullkastlige": "oomkullkastlig",
    "oomkullkastliges": "oomkullkastlig",
    "oomkullkastligheten": "oomkullkastlighet",
    "oomkullkastlighetens": "oomkullkastlighet",
    "oomkullkastlighets": "oomkullkastlighet",
    "oomkullkastligs": "oomkullkastlig",
    "oomkullkastligt": "oomkullkastlig",
    "oomkullkastligts": "oomkullkastlig",
    "oomkullrunkeliga": "oomkullrunkelig",
    "oomkullrunkeligare": "oomkullrunkelig",
    "oomkullrunkeligares": "oomkullrunkelig",
    "oomkullrunkeligas": "oomkullrunkelig",
    "oomkullrunkeligast": "oomkullrunkelig",
    "oomkullrunkeligaste": "oomkullrunkelig",
    "oomkullrunkeligastes": "oomkullrunkelig",
    "oomkullrunkeligasts": "oomkullrunkelig",
    "oomkullrunkelige": "oomkullrunkelig",
    "oomkullrunkeliges": "oomkullrunkelig",
    "oomkullrunkeligheten": "oomkullrunkelighet",
    "oomkullrunkelighetens": "oomkullrunkelighet",
    "oomkullrunkelighets": "oomkullrunkelighet",
    "oomkullrunkeligs": "oomkullrunkelig",
    "oomkullrunkeligt": "oomkullrunkelig",
    "oomkullrunkeligts": "oomkullrunkelig",
    "oomljudda": "oomljudd",
    "oomljuddare": "oomljudd",
    "oomljuddares": "oomljudd",
    "oomljuddas": "oomljudd",
    "oomljuddast": "oomljudd",
    "oomljuddaste": "oomljudd",
    "oomljuddastes": "oomljudd",
    "oomljuddasts": "oomljudd",
    "oomljudde": "oomljudd",
    "oomljuddes": "oomljudd",
    "oomljudds": "oomljudd",
    "oomljutt": "oomljudd",
    "oomljutts": "oomljudd",
    "oommöblerade": "oommöblerad",
    "oommöblerades": "oommöblerad",
    "oommöblerads": "oommöblerad",
    "oommöblerat": "oommöblerad",
    "oommöblerats": "oommöblerad",
    "oommöblerbara": "oommöblerbar",
    "oommöblerbarare": "oommöblerbar",
    "oommöblerbarares": "oommöblerbar",
    "oommöblerbaras": "oommöblerbar",
    "oommöblerbarast": "oommöblerbar",
    "oommöblerbaraste": "oommöblerbar",
    "oommöblerbarastes": "oommöblerbar",
    "oommöblerbarasts": "oommöblerbar",
    "oommöblerbare": "oommöblerbar",
    "oommöblerbares": "oommöblerbar",
    "oommöblerbarheten": "oommöblerbarhet",
    "oommöblerbarhetens": "oommöblerbarhet",
    "oommöblerbarhets": "oommöblerbarhet",
    "oommöblerbars": "oommöblerbar",
    "oommöblerbart": "oommöblerbar",
    "oommöblerbarts": "oommöblerbar",
    "oomnämnde": "oomnämnd",
    "oomnämndes": "oomnämnd",
    "oomnämnds": "oomnämnd",
    "oomnämnt": "oomnämnd",
    "oomnämnts": "oomnämnd",
    "oomorganiserade": "oomorganiserad",
    "oomorganiserades": "oomorganiserad",
    "oomorganiserads": "oomorganiserad",
    "oomorganiserat": "oomorganiserad",
    "oomorganiserats": "oomorganiserad",
    "oomorganiserbara": "oomorganiserbar",
    "oomorganiserbarare": "oomorganiserbar",
    "oomorganiserbarares": "oomorganiserbar",
    "oomorganiserbaras": "oomorganiserbar",
    "oomorganiserbarast": "oomorganiserbar",
    "oomorganiserbaraste": "oomorganiserbar",
    "oomorganiserbarastes": "oomorganiserbar",
    "oomorganiserbarasts": "oomorganiserbar",
    "oomorganiserbare": "oomorganiserbar",
    "oomorganiserbares": "oomorganiserbar",
    "oomorganiserbarheten": "oomorganiserbarhet",
    "oomorganiserbarhetens": "oomorganiserbarhet",
    "oomorganiserbarhets": "oomorganiserbarhet",
    "oomorganiserbars": "oomorganiserbar",
    "oomorganiserbart": "oomorganiserbar",
    "oomorganiserbarts": "oomorganiserbar",
    "oomplacerade": "oomplacerad",
    "oomplacerades": "oomplacerad",
    "oomplacerads": "oomplacerad",
    "oomplacerat": "oomplacerad",
    "oomplacerats": "oomplacerad",
    "oomplacerbara": "oomplacerbar",
    "oomplacerbarare": "oomplacerbar",
    "oomplacerbarares": "oomplacerbar",
    "oomplacerbaras": "oomplacerbar",
    "oomplacerbarast": "oomplacerbar",
    "oomplacerbaraste": "oomplacerbar",
    "oomplacerbarastes": "oomplacerbar",
    "oomplacerbarasts": "oomplacerbar",
    "oomplacerbare": "oomplacerbar",
    "oomplacerbares": "oomplacerbar",
    "oomplacerbarheten": "oomplacerbarhet",
    "oomplacerbarhetens": "oomplacerbarhet",
    "oomplacerbarhets": "oomplacerbarhet",
    "oomplacerbars": "oomplacerbar",
    "oomplacerbart": "oomplacerbar",
    "oomplacerbarts": "oomplacerbar",
    "oomplåstrade": "oomplåstrad",
    "oomplåstrades": "oomplåstrad",
    "oomplåstrads": "oomplåstrad",
    "oomplåstrat": "oomplåstrad",
    "oomplåstrats": "oomplåstrad",
    "oomprövade": "oomprövad",
    "oomprövades": "oomprövad",
    "oomprövads": "oomprövad",
    "oomprövat": "oomprövad",
    "oomprövats": "oomprövad",
    "oomramade": "oomramad",
    "oomramades": "oomramad",
    "oomramads": "oomramad",
    "oomramat": "oomramad",
    "oomramats": "oomramad",
    "oomringade": "oomringad",
    "oomringades": "oomringad",
    "oomringads": "oomringad",
    "oomringat": "oomringad",
    "oomringats": "oomringad",
    "oomräknade": "oomräknad",
    "oomräknades": "oomräknad",
    "oomräknads": "oomräknad",
    "oomräknat": "oomräknad",
    "oomräknats": "oomräknad",
    "oomskapade": "oomskapad",
    "oomskapades": "oomskapad",
    "oomskapads": "oomskapad",
    "oomskapat": "oomskapad",
    "oomskapats": "oomskapad",
    "oomskolade": "oomskolad",
    "oomskolades": "oomskolad",
    "oomskolads": "oomskolad",
    "oomskolat": "oomskolad",
    "oomskolats": "oomskolad",
    "oomskulpturerade": "oomskulpturerad",
    "oomskulpturerades": "oomskulpturerad",
    "oomskulpturerads": "oomskulpturerad",
    "oomskulpturerat": "oomskulpturerad",
    "oomskulpturerats": "oomskulpturerad",
    "oomskulpturerbara": "oomskulpturerbar",
    "oomskulpturerbarare": "oomskulpturerbar",
    "oomskulpturerbarares": "oomskulpturerbar",
    "oomskulpturerbaras": "oomskulpturerbar",
    "oomskulpturerbarast": "oomskulpturerbar",
    "oomskulpturerbaraste": "oomskulpturerbar",
    "oomskulpturerbarastes": "oomskulpturerbar",
    "oomskulpturerbarasts": "oomskulpturerbar",
    "oomskulpturerbare": "oomskulpturerbar",
    "oomskulpturerbares": "oomskulpturerbar",
    "oomskulpturerbarheten": "oomskulpturerbarhet",
    "oomskulpturerbarhetens": "oomskulpturerbarhet",
    "oomskulpturerbarhets": "oomskulpturerbarhet",
    "oomskulpturerbars": "oomskulpturerbar",
    "oomskulpturerbart": "oomskulpturerbar",
    "oomskulpturerbarts": "oomskulpturerbar",
    "oomskurens": "oomskuren",
    "oomskuret": "oomskuren",
    "oomskurets": "oomskuren",
    "oomskurna": "oomskuren",
    "oomskurnare": "oomskuren",
    "oomskurnares": "oomskuren",
    "oomskurnas": "oomskuren",
    "oomskurnast": "oomskuren",
    "oomskurnaste": "oomskuren",
    "oomskurnastes": "oomskuren",
    "oomskurnasts": "oomskuren",
    "oomskurne": "oomskuren",
    "oomskurnes": "oomskuren",
    "oomskötta": "oomskött",
    "oomsköttas": "oomskött",
    "oomskötte": "oomskött",
    "oomsköttes": "oomskött",
    "oomskötts": "oomskött",
    "oomslingrade": "oomslingrad",
    "oomslingrades": "oomslingrad",
    "oomslingrads": "oomslingrad",
    "oomslingrat": "oomslingrad",
    "oomslingrats": "oomslingrad",
    "oomspände": "oomspänd",
    "oomspändes": "oomspänd",
    "oomspänds": "oomspänd",
    "oomspänt": "oomspänd",
    "oomspänts": "oomspänd",
    "oomstridda": "oomstridd",
    "oomstriddare": "oomstridd",
    "oomstriddares": "oomstridd",
    "oomstriddas": "oomstridd",
    "oomstriddast": "oomstridd",
    "oomstriddaste": "oomstridd",
    "oomstriddastes": "oomstridd",
    "oomstriddasts": "oomstridd",
    "oomstridde": "oomstridd",
    "oomstriddes": "oomstridd",
    "oomstridds": "oomstridd",
    "oomstritt": "oomstridd",
    "oomstritts": "oomstridd",
    "oomstrukturerade": "oomstrukturerad",
    "oomstrukturerades": "oomstrukturerad",
    "oomstrukturerads": "oomstrukturerad",
    "oomstrukturerat": "oomstrukturerad",
    "oomstrukturerats": "oomstrukturerad",
    "oomstrukturerbara": "oomstrukturerbar",
    "oomstrukturerbarare": "oomstrukturerbar",
    "oomstrukturerbarares": "oomstrukturerbar",
    "oomstrukturerbaras": "oomstrukturerbar",
    "oomstrukturerbarast": "oomstrukturerbar",
    "oomstrukturerbaraste": "oomstrukturerbar",
    "oomstrukturerbarastes": "oomstrukturerbar",
    "oomstrukturerbarasts": "oomstrukturerbar",
    "oomstrukturerbare": "oomstrukturerbar",
    "oomstrukturerbares": "oomstrukturerbar",
    "oomstrukturerbarheten": "oomstrukturerbarhet",
    "oomstrukturerbarhetens": "oomstrukturerbarhet",
    "oomstrukturerbarhets": "oomstrukturerbarhet",
    "oomstrukturerbars": "oomstrukturerbar",
    "oomstrukturerbart": "oomstrukturerbar",
    "oomstrukturerbarts": "oomstrukturerbar",
    "oomstrålade": "oomstrålad",
    "oomstrålades": "oomstrålad",
    "oomstrålads": "oomstrålad",
    "oomstrålat": "oomstrålad",
    "oomstrålats": "oomstrålad",
    "oomstöpta": "oomstöpt",
    "oomstöptas": "oomstöpt",
    "oomstöpte": "oomstöpt",
    "oomstöptes": "oomstöpt",
    "oomstöpts": "oomstöpt",
    "oomstörtade": "oomstörtad",
    "oomstörtades": "oomstörtad",
    "oomstörtads": "oomstörtad",
    "oomstörtat": "oomstörtad",
    "oomstörtats": "oomstörtad",
    "oomsvepta": "oomsvept",
    "oomsveptas": "oomsvept",
    "oomsvepte": "oomsvept",
    "oomsveptes": "oomsvept",
    "oomsvepts": "oomsvept",
    "oomsvärmade": "oomsvärmad",
    "oomsvärmades": "oomsvärmad",
    "oomsvärmads": "oomsvärmad",
    "oomsvärmat": "oomsvärmad",
    "oomsvärmats": "oomsvärmad",
    "oomtalade": "oomtalad",
    "oomtalades": "oomtalad",
    "oomtalads": "oomtalad",
    "oomtalat": "oomtalad",
    "oomtalats": "oomtalad",
    "oomtolkade": "oomtolkad",
    "oomtolkades": "oomtolkad",
    "oomtolkads": "oomtolkad",
    "oomtolkat": "oomtolkad",
    "oomtolkats": "oomtolkad",
    "oomtvistade": "oomtvistad",
    "oomtvistades": "oomtvistad",
    "oomtvistads": "oomtvistad",
    "oomtvistat": "oomtvistad",
    "oomtvistats": "oomtvistad",
    "oomvandlade": "oomvandlad",
    "oomvandlades": "oomvandlad",
    "oomvandlads": "oomvandlad",
    "oomvandlat": "oomvandlad",
    "oomvandlats": "oomvandlad",
    "oomvittnade": "oomvittnad",
    "oomvittnades": "oomvittnad",
    "oomvittnads": "oomvittnad",
    "oomvittnat": "oomvittnad",
    "oomvittnats": "oomvittnad",
    "oomvälvde": "oomvälvd",
    "oomvälvdes": "oomvälvd",
    "oomvälvds": "oomvälvd",
    "oomvälvt": "oomvälvd",
    "oomvälvts": "oomvälvd",
    "oomvände": "oomvänd",
    "oomvändes": "oomvänd",
    "oomvänds": "oomvänd",
    "oomvänt": "oomvänd",
    "oomvänts": "oomvänd",
    "oomvärderade": "oomvärderad",
    "oomvärderades": "oomvärderad",
    "oomvärderads": "oomvärderad",
    "oomvärderat": "oomvärderad",
    "oomvärderats": "oomvärderad",
    "oomvärderbara": "oomvärderbar",
    "oomvärderbarare": "oomvärderbar",
    "oomvärderbarares": "oomvärderbar",
    "oomvärderbaras": "oomvärderbar",
    "oomvärderbarast": "oomvärderbar",
    "oomvärderbaraste": "oomvärderbar",
    "oomvärderbarastes": "oomvärderbar",
    "oomvärderbarasts": "oomvärderbar",
    "oomvärderbare": "oomvärderbar",
    "oomvärderbares": "oomvärderbar",
    "oomvärderbarheten": "oomvärderbarhet",
    "oomvärderbarhetens": "oomvärderbarhet",
    "oomvärderbarhets": "oomvärderbarhet",
    "oomvärderbars": "oomvärderbar",
    "oomvärderbart": "oomvärderbar",
    "oomvärderbarts": "oomvärderbar",
    "oomvärvde": "oomvärvd",
    "oomvärvdes": "oomvärvd",
    "oomvärvds": "oomvärvd",
    "oomvärvt": "oomvärvd",
    "oomvärvts": "oomvärvd",
    "oomändrade": "oomändrad",
    "oomändrades": "oomändrad",
    "oomändrads": "oomändrad",
    "oomändrat": "oomändrad",
    "oomändrats": "oomändrad",
    "oondulerade": "oondulerad",
    "oondulerades": "oondulerad",
    "oondulerads": "oondulerad",
    "oondulerat": "oondulerad",
    "oondulerats": "oondulerad",
    "oondulerbara": "oondulerbar",
    "oondulerbarare": "oondulerbar",
    "oondulerbarares": "oondulerbar",
    "oondulerbaras": "oondulerbar",
    "oondulerbarast": "oondulerbar",
    "oondulerbaraste": "oondulerbar",
    "oondulerbarastes": "oondulerbar",
    "oondulerbarasts": "oondulerbar",
    "oondulerbare": "oondulerbar",
    "oondulerbares": "oondulerbar",
    "oondulerbarheten": "oondulerbarhet",
    "oondulerbarhetens": "oondulerbarhet",
    "oondulerbarhets": "oondulerbarhet",
    "oondulerbars": "oondulerbar",
    "oondulerbart": "oondulerbar",
    "oondulerbarts": "oondulerbar",
    "ooperationaliserade": "ooperationaliserad",
    "ooperationaliserades": "ooperationaliserad",
    "ooperationaliserads": "ooperationaliserad",
    "ooperationaliserat": "ooperationaliserad",
    "ooperationaliserats": "ooperationaliserad",
    "ooperationaliserbara": "ooperationaliserbar",
    "ooperationaliserbarare": "ooperationaliserbar",
    "ooperationaliserbarares": "ooperationaliserbar",
    "ooperationaliserbaras": "ooperationaliserbar",
    "ooperationaliserbarast": "ooperationaliserbar",
    "ooperationaliserbaraste": "ooperationaliserbar",
    "ooperationaliserbarastes": "ooperationaliserbar",
    "ooperationaliserbarasts": "ooperationaliserbar",
    "ooperationaliserbare": "ooperationaliserbar",
    "ooperationaliserbares": "ooperationaliserbar",
    "ooperationaliserbarheten": "ooperationaliserbarhet",
    "ooperationaliserbarhetens": "ooperationaliserbarhet",
    "ooperationaliserbarhets": "ooperationaliserbarhet",
    "ooperationaliserbars": "ooperationaliserbar",
    "ooperationaliserbart": "ooperationaliserbar",
    "ooperationaliserbarts": "ooperationaliserbar",
    "oopererade": "oopererad",
    "oopererades": "oopererad",
    "oopererads": "oopererad",
    "oopererat": "oopererad",
    "oopererats": "oopererad",
    "oopererbara": "oopererbar",
    "oopererbarare": "oopererbar",
    "oopererbarares": "oopererbar",
    "oopererbaras": "oopererbar",
    "oopererbarast": "oopererbar",
    "oopererbaraste": "oopererbar",
    "oopererbarastes": "oopererbar",
    "oopererbarasts": "oopererbar",
    "oopererbare": "oopererbar",
    "oopererbares": "oopererbar",
    "oopererbarheten": "oopererbarhet",
    "oopererbarhetens": "oopererbarhet",
    "oopererbarhets": "oopererbarhet",
    "oopererbars": "oopererbar",
    "oopererbart": "oopererbar",
    "oopererbarts": "oopererbar",
    "ooppdaterade": "ooppdaterad",
    "ooppdaterades": "ooppdaterad",
    "ooppdaterads": "ooppdaterad",
    "ooppdaterat": "ooppdaterad",
    "ooppdaterats": "ooppdaterad",
    "ooppdaterbara": "ooppdaterbar",
    "ooppdaterbarare": "ooppdaterbar",
    "ooppdaterbarares": "ooppdaterbar",
    "ooppdaterbaras": "ooppdaterbar",
    "ooppdaterbarast": "ooppdaterbar",
    "ooppdaterbaraste": "ooppdaterbar",
    "ooppdaterbarastes": "ooppdaterbar",
    "ooppdaterbarasts": "ooppdaterbar",
    "ooppdaterbare": "ooppdaterbar",
    "ooppdaterbares": "ooppdaterbar",
    "ooppdaterbarheten": "ooppdaterbarhet",
    "ooppdaterbarhetens": "ooppdaterbarhet",
    "ooppdaterbarhets": "ooppdaterbarhet",
    "ooppdaterbars": "ooppdaterbar",
    "ooppdaterbart": "ooppdaterbar",
    "ooppdaterbarts": "ooppdaterbar",
    "ooppjusterade": "ooppjusterad",
    "ooppjusterades": "ooppjusterad",
    "ooppjusterads": "ooppjusterad",
    "ooppjusterat": "ooppjusterad",
    "ooppjusterats": "ooppjusterad",
    "ooppjusterbara": "ooppjusterbar",
    "ooppjusterbarare": "ooppjusterbar",
    "ooppjusterbarares": "ooppjusterbar",
    "ooppjusterbaras": "ooppjusterbar",
    "ooppjusterbarast": "ooppjusterbar",
    "ooppjusterbaraste": "ooppjusterbar",
    "ooppjusterbarastes": "ooppjusterbar",
    "ooppjusterbarasts": "ooppjusterbar",
    "ooppjusterbare": "ooppjusterbar",
    "ooppjusterbares": "ooppjusterbar",
    "ooppjusterbarheten": "ooppjusterbarhet",
    "ooppjusterbarhetens": "ooppjusterbarhet",
    "ooppjusterbarhets": "ooppjusterbarhet",
    "ooppjusterbars": "ooppjusterbar",
    "ooppjusterbart": "ooppjusterbar",
    "ooppjusterbarts": "ooppjusterbar",
    "oopponerade": "oopponerad",
    "oopponerades": "oopponerad",
    "oopponerads": "oopponerad",
    "oopponerat": "oopponerad",
    "oopponerats": "oopponerad",
    "oopponerbara": "oopponerbar",
    "oopponerbarare": "oopponerbar",
    "oopponerbarares": "oopponerbar",
    "oopponerbaras": "oopponerbar",
    "oopponerbarast": "oopponerbar",
    "oopponerbaraste": "oopponerbar",
    "oopponerbarastes": "oopponerbar",
    "oopponerbarasts": "oopponerbar",
    "oopponerbare": "oopponerbar",
    "oopponerbares": "oopponerbar",
    "oopponerbarheten": "oopponerbarhet",
    "oopponerbarhetens": "oopponerbarhet",
    "oopponerbarhets": "oopponerbarhet",
    "oopponerbars": "oopponerbar",
    "oopponerbart": "oopponerbar",
    "oopponerbarts": "oopponerbar",
    "ooppsummerade": "ooppsummerad",
    "ooppsummerades": "ooppsummerad",
    "ooppsummerads": "ooppsummerad",
    "ooppsummerat": "ooppsummerad",
    "ooppsummerats": "ooppsummerad",
    "ooppsummerbara": "ooppsummerbar",
    "ooppsummerbarare": "ooppsummerbar",
    "ooppsummerbarares": "ooppsummerbar",
    "ooppsummerbaras": "ooppsummerbar",
    "ooppsummerbarast": "ooppsummerbar",
    "ooppsummerbaraste": "ooppsummerbar",
    "ooppsummerbarastes": "ooppsummerbar",
    "ooppsummerbarasts": "ooppsummerbar",
    "ooppsummerbare": "ooppsummerbar",
    "ooppsummerbares": "ooppsummerbar",
    "ooppsummerbarheten": "ooppsummerbarhet",
    "ooppsummerbarhetens": "ooppsummerbarhet",
    "ooppsummerbarhets": "ooppsummerbarhet",
    "ooppsummerbars": "ooppsummerbar",
    "ooppsummerbart": "ooppsummerbar",
    "ooppsummerbarts": "ooppsummerbar",
    "ooppvärderade": "ooppvärderad",
    "ooppvärderades": "ooppvärderad",
    "ooppvärderads": "ooppvärderad",
    "ooppvärderat": "ooppvärderad",
    "ooppvärderats": "ooppvärderad",
    "ooppvärderbara": "ooppvärderbar",
    "ooppvärderbarare": "ooppvärderbar",
    "ooppvärderbarares": "ooppvärderbar",
    "ooppvärderbaras": "ooppvärderbar",
    "ooppvärderbarast": "ooppvärderbar",
    "ooppvärderbaraste": "ooppvärderbar",
    "ooppvärderbarastes": "ooppvärderbar",
    "ooppvärderbarasts": "ooppvärderbar",
    "ooppvärderbare": "ooppvärderbar",
    "ooppvärderbares": "ooppvärderbar",
    "ooppvärderbarheten": "ooppvärderbarhet",
    "ooppvärderbarhetens": "ooppvärderbarhet",
    "ooppvärderbarhets": "ooppvärderbarhet",
    "ooppvärderbars": "ooppvärderbar",
    "ooppvärderbart": "ooppvärderbar",
    "ooppvärderbarts": "ooppvärderbar",
    "ooptimerade": "ooptimerad",
    "ooptimerades": "ooptimerad",
    "ooptimerads": "ooptimerad",
    "ooptimerat": "ooptimerad",
    "ooptimerats": "ooptimerad",
    "ooptimerbara": "ooptimerbar",
    "ooptimerbarare": "ooptimerbar",
    "ooptimerbarares": "ooptimerbar",
    "ooptimerbaras": "ooptimerbar",
    "ooptimerbarast": "ooptimerbar",
    "ooptimerbaraste": "ooptimerbar",
    "ooptimerbarastes": "ooptimerbar",
    "ooptimerbarasts": "ooptimerbar",
    "ooptimerbare": "ooptimerbar",
    "ooptimerbares": "ooptimerbar",
    "ooptimerbarheten": "ooptimerbarhet",
    "ooptimerbarhetens": "ooptimerbarhet",
    "ooptimerbarhets": "ooptimerbarhet",
    "ooptimerbars": "ooptimerbar",
    "ooptimerbart": "ooptimerbar",
    "ooptimerbarts": "ooptimerbar",
    "oordentliga": "oordentlig",
    "oordentligare": "oordentlig",
    "oordentligares": "oordentlig",
    "oordentligas": "oordentlig",
    "oordentligast": "oordentlig",
    "oordentligaste": "oordentlig",
    "oordentligastes": "oordentlig",
    "oordentligasts": "oordentlig",
    "oordentlige": "oordentlig",
    "oordentliges": "oordentlig",
    "oordentligheten": "oordentlighet",
    "oordentlighetens": "oordentlighet",
    "oordentlighets": "oordentlighet",
    "oordentligs": "oordentlig",
    "oordentligt": "oordentlig",
    "oordentligts": "oordentlig",
    "oordinerade": "oordinerad",
    "oordinerades": "oordinerad",
    "oordinerads": "oordinerad",
    "oordinerat": "oordinerad",
    "oordinerats": "oordinerad",
    "oordinerbara": "oordinerbar",
    "oordinerbarare": "oordinerbar",
    "oordinerbarares": "oordinerbar",
    "oordinerbaras": "oordinerbar",
    "oordinerbarast": "oordinerbar",
    "oordinerbaraste": "oordinerbar",
    "oordinerbarastes": "oordinerbar",
    "oordinerbarasts": "oordinerbar",
    "oordinerbare": "oordinerbar",
    "oordinerbares": "oordinerbar",
    "oordinerbarheten": "oordinerbarhet",
    "oordinerbarhetens": "oordinerbarhet",
    "oordinerbarhets": "oordinerbarhet",
    "oordinerbars": "oordinerbar",
    "oordinerbart": "oordinerbar",
    "oordinerbarts": "oordinerbar",
    "oordnade": "oordnad",
    "oordnades": "oordnad",
    "oordnads": "oordnad",
    "oordnat": "oordnad",
    "oordnats": "oordnad",
    "oordningar": "oordning",
    "oordningarna": "oordning",
    "oordningarnas": "oordning",
    "oordningars": "oordning",
    "oordningen": "oordning",
    "oordningens": "oordning",
    "oordnings": "oordning",
    "oorganiserade": "oorganiserad",
    "oorganiserades": "oorganiserad",
    "oorganiserads": "oorganiserad",
    "oorganiserat": "oorganiserad",
    "oorganiserats": "oorganiserad",
    "oorganiserbara": "oorganiserbar",
    "oorganiserbarare": "oorganiserbar",
    "oorganiserbarares": "oorganiserbar",
    "oorganiserbaras": "oorganiserbar",
    "oorganiserbarast": "oorganiserbar",
    "oorganiserbaraste": "oorganiserbar",
    "oorganiserbarastes": "oorganiserbar",
    "oorganiserbarasts": "oorganiserbar",
    "oorganiserbare": "oorganiserbar",
    "oorganiserbares": "oorganiserbar",
    "oorganiserbarheten": "oorganiserbarhet",
    "oorganiserbarhetens": "oorganiserbarhet",
    "oorganiserbarhets": "oorganiserbarhet",
    "oorganiserbars": "oorganiserbar",
    "oorganiserbart": "oorganiserbar",
    "oorganiserbarts": "oorganiserbar",
    "oorganiska": "oorganisk",
    "oorganiskare": "oorganisk",
    "oorganiskares": "oorganisk",
    "oorganiskas": "oorganisk",
    "oorganiskast": "oorganisk",
    "oorganiskaste": "oorganisk",
    "oorganiskastes": "oorganisk",
    "oorganiskasts": "oorganisk",
    "oorganiske": "oorganisk",
    "oorganiskes": "oorganisk",
    "oorganisks": "oorganisk",
    "oorganiskt": "oorganisk",
    "oorganiskts": "oorganisk",
    "oorienterade": "oorienterad",
    "oorienterades": "oorienterad",
    "oorienterads": "oorienterad",
    "oorienterat": "oorienterad",
    "oorienterats": "oorienterad",
    "oorienterbara": "oorienterbar",
    "oorienterbarare": "oorienterbar",
    "oorienterbarares": "oorienterbar",
    "oorienterbaras": "oorienterbar",
    "oorienterbarast": "oorienterbar",
    "oorienterbaraste": "oorienterbar",
    "oorienterbarastes": "oorienterbar",
    "oorienterbarasts": "oorienterbar",
    "oorienterbare": "oorienterbar",
    "oorienterbares": "oorienterbar",
    "oorienterbarheten": "oorienterbarhet",
    "oorienterbarhetens": "oorienterbarhet",
    "oorienterbarhets": "oorienterbarhet",
    "oorienterbars": "oorienterbar",
    "oorienterbart": "oorienterbar",
    "oorienterbarts": "oorienterbar",
    "oorkestrerade": "oorkestrerad",
    "oorkestrerades": "oorkestrerad",
    "oorkestrerads": "oorkestrerad",
    "oorkestrerat": "oorkestrerad",
    "oorkestrerats": "oorkestrerad",
    "oorkestrerbara": "oorkestrerbar",
    "oorkestrerbarare": "oorkestrerbar",
    "oorkestrerbarares": "oorkestrerbar",
    "oorkestrerbaras": "oorkestrerbar",
    "oorkestrerbarast": "oorkestrerbar",
    "oorkestrerbaraste": "oorkestrerbar",
    "oorkestrerbarastes": "oorkestrerbar",
    "oorkestrerbarasts": "oorkestrerbar",
    "oorkestrerbare": "oorkestrerbar",
    "oorkestrerbares": "oorkestrerbar",
    "oorkestrerbarheten": "oorkestrerbarhet",
    "oorkestrerbarhetens": "oorkestrerbarhet",
    "oorkestrerbarhets": "oorkestrerbarhet",
    "oorkestrerbars": "oorkestrerbar",
    "oorkestrerbart": "oorkestrerbar",
    "oorkestrerbarts": "oorkestrerbar",
    "oornamenterade": "oornamenterad",
    "oornamenterades": "oornamenterad",
    "oornamenterads": "oornamenterad",
    "oornamenterat": "oornamenterad",
    "oornamenterats": "oornamenterad",
    "oornamenterbara": "oornamenterbar",
    "oornamenterbarare": "oornamenterbar",
    "oornamenterbarares": "oornamenterbar",
    "oornamenterbaras": "oornamenterbar",
    "oornamenterbarast": "oornamenterbar",
    "oornamenterbaraste": "oornamenterbar",
    "oornamenterbarastes": "oornamenterbar",
    "oornamenterbarasts": "oornamenterbar",
    "oornamenterbare": "oornamenterbar",
    "oornamenterbares": "oornamenterbar",
    "oornamenterbarheten": "oornamenterbarhet",
    "oornamenterbarhetens": "oornamenterbarhet",
    "oornamenterbarhets": "oornamenterbarhet",
    "oornamenterbars": "oornamenterbar",
    "oornamenterbart": "oornamenterbar",
    "oornamenterbarts": "oornamenterbar",
    "oornerade": "oornerad",
    "oornerades": "oornerad",
    "oornerads": "oornerad",
    "oornerat": "oornerad",
    "oornerats": "oornerad",
    "oornerbara": "oornerbar",
    "oornerbarare": "oornerbar",
    "oornerbarares": "oornerbar",
    "oornerbaras": "oornerbar",
    "oornerbarast": "oornerbar",
    "oornerbaraste": "oornerbar",
    "oornerbarastes": "oornerbar",
    "oornerbarasts": "oornerbar",
    "oornerbare": "oornerbar",
    "oornerbares": "oornerbar",
    "oornerbarheten": "oornerbarhet",
    "oornerbarhetens": "oornerbarhet",
    "oornerbarhets": "oornerbarhet",
    "oornerbars": "oornerbar",
    "oornerbart": "oornerbar",
    "oornerbarts": "oornerbar",
    "oorsakade": "oorsakad",
    "oorsakades": "oorsakad",
    "oorsakads": "oorsakad",
    "oorsakat": "oorsakad",
    "oorsakats": "oorsakad",
    "oortodoxa": "oortodox",
    "oortodoxare": "oortodox",
    "oortodoxares": "oortodox",
    "oortodoxas": "oortodox",
    "oortodoxast": "oortodox",
    "oortodoxaste": "oortodox",
    "oortodoxastes": "oortodox",
    "oortodoxasts": "oortodox",
    "oortodoxe": "oortodox",
    "oortodoxes": "oortodox",
    "oortodoxheten": "oortodoxhet",
    "oortodoxhetens": "oortodoxhet",
    "oortodoxhets": "oortodoxhet",
    "oortodoxt": "oortodox",
    "oortodoxts": "oortodox",
    "ooutade": "ooutad",
    "ooutades": "ooutad",
    "ooutads": "ooutad",
    "ooutat": "ooutad",
    "ooutats": "ooutad",
    "ooxiderade": "ooxiderad",
    "ooxiderades": "ooxiderad",
    "ooxiderads": "ooxiderad",
    "ooxiderat": "ooxiderad",
    "ooxiderats": "ooxiderad",
    "ooxiderbara": "ooxiderbar",
    "ooxiderbarare": "ooxiderbar",
    "ooxiderbarares": "ooxiderbar",
    "ooxiderbaras": "ooxiderbar",
    "ooxiderbarast": "ooxiderbar",
    "ooxiderbaraste": "ooxiderbar",
    "ooxiderbarastes": "ooxiderbar",
    "ooxiderbarasts": "ooxiderbar",
    "ooxiderbare": "ooxiderbar",
    "ooxiderbares": "ooxiderbar",
    "ooxiderbarheten": "ooxiderbarhet",
    "ooxiderbarhetens": "ooxiderbarhet",
    "ooxiderbarhets": "ooxiderbarhet",
    "ooxiderbars": "ooxiderbar",
    "ooxiderbart": "ooxiderbar",
    "ooxiderbarts": "ooxiderbar",
    "opacificerade": "opacificerad",
    "opacificerades": "opacificerad",
    "opacificerads": "opacificerad",
    "opacificerat": "opacificerad",
    "opacificerats": "opacificerad",
    "opacificerbara": "opacificerbar",
    "opacificerbarare": "opacificerbar",
    "opacificerbarares": "opacificerbar",
    "opacificerbaras": "opacificerbar",
    "opacificerbarast": "opacificerbar",
    "opacificerbaraste": "opacificerbar",
    "opacificerbarastes": "opacificerbar",
    "opacificerbarasts": "opacificerbar",
    "opacificerbare": "opacificerbar",
    "opacificerbares": "opacificerbar",
    "opacificerbarheten": "opacificerbarhet",
    "opacificerbarhetens": "opacificerbarhet",
    "opacificerbarhets": "opacificerbarhet",
    "opacificerbars": "opacificerbar",
    "opacificerbart": "opacificerbar",
    "opacificerbarts": "opacificerbar",
    "opaciteten": "opacitet",
    "opacitetens": "opacitet",
    "opaciteter": "opacitet",
    "opaciteterna": "opacitet",
    "opaciteternas": "opacitet",
    "opaciteters": "opacitet",
    "opacitets": "opacitet",
    "opackade": "opackad",
    "opackades": "opackad",
    "opackads": "opackad",
    "opackat": "opackad",
    "opackats": "opackad",
    "opaginerade": "opaginerad",
    "opaginerades": "opaginerad",
    "opaginerads": "opaginerad",
    "opaginerat": "opaginerad",
    "opaginerats": "opaginerad",
    "opaginerbara": "opaginerbar",
    "opaginerbarare": "opaginerbar",
    "opaginerbarares": "opaginerbar",
    "opaginerbaras": "opaginerbar",
    "opaginerbarast": "opaginerbar",
    "opaginerbaraste": "opaginerbar",
    "opaginerbarastes": "opaginerbar",
    "opaginerbarasts": "opaginerbar",
    "opaginerbare": "opaginerbar",
    "opaginerbares": "opaginerbar",
    "opaginerbarheten": "opaginerbarhet",
    "opaginerbarhetens": "opaginerbarhet",
    "opaginerbarhets": "opaginerbarhet",
    "opaginerbars": "opaginerbar",
    "opaginerbart": "opaginerbar",
    "opaginerbarts": "opaginerbar",
    "opajade": "opajad",
    "opajades": "opajad",
    "opajads": "opajad",
    "opajat": "opajad",
    "opajats": "opajad",
    "opaka": "opak",
    "opakare": "opak",
    "opakares": "opak",
    "opakas": "opak",
    "opakast": "opak",
    "opakaste": "opak",
    "opakastes": "opak",
    "opakasts": "opak",
    "opake": "opak",
    "opakes": "opak",
    "opaketerade": "opaketerad",
    "opaketerades": "opaketerad",
    "opaketerads": "opaketerad",
    "opaketerat": "opaketerad",
    "opaketerats": "opaketerad",
    "opaketerbara": "opaketerbar",
    "opaketerbarare": "opaketerbar",
    "opaketerbarares": "opaketerbar",
    "opaketerbaras": "opaketerbar",
    "opaketerbarast": "opaketerbar",
    "opaketerbaraste": "opaketerbar",
    "opaketerbarastes": "opaketerbar",
    "opaketerbarasts": "opaketerbar",
    "opaketerbare": "opaketerbar",
    "opaketerbares": "opaketerbar",
    "opaketerbarheten": "opaketerbarhet",
    "opaketerbarhetens": "opaketerbarhet",
    "opaketerbarhets": "opaketerbarhet",
    "opaketerbars": "opaketerbar",
    "opaketerbart": "opaketerbar",
    "opaketerbarts": "opaketerbar",
    "opaks": "opak",
    "opakt": "opak",
    "opakts": "opak",
    "opalataliserade": "opalataliserad",
    "opalataliserades": "opalataliserad",
    "opalataliserads": "opalataliserad",
    "opalataliserat": "opalataliserad",
    "opalataliserats": "opalataliserad",
    "opalataliserbara": "opalataliserbar",
    "opalataliserbarare": "opalataliserbar",
    "opalataliserbarares": "opalataliserbar",
    "opalataliserbaras": "opalataliserbar",
    "opalataliserbarast": "opalataliserbar",
    "opalataliserbaraste": "opalataliserbar",
    "opalataliserbarastes": "opalataliserbar",
    "opalataliserbarasts": "opalataliserbar",
    "opalataliserbare": "opalataliserbar",
    "opalataliserbares": "opalataliserbar",
    "opalataliserbarheten": "opalataliserbarhet",
    "opalataliserbarhetens": "opalataliserbarhet",
    "opalataliserbarhets": "opalataliserbarhet",
    "opalataliserbars": "opalataliserbar",
    "opalataliserbart": "opalataliserbar",
    "opalataliserbarts": "opalataliserbar",
    "opalen": "opal",
    "opalens": "opal",
    "opaler": "opal",
    "opalerna": "opal",
    "opalernas": "opal",
    "opalers": "opal",
    "opalescensen": "opalescens",
    "opalescensens": "opalescens",
    "opalfärgade": "opalfärgad",
    "opalfärgades": "opalfärgad",
    "opalfärgads": "opalfärgad",
    "opalfärgat": "opalfärgad",
    "opalfärgats": "opalfärgad",
    "opalglaset": "opalglas",
    "opalglasets": "opalglas",
    "opaljetterade": "opaljetterad",
    "opaljetterades": "opaljetterad",
    "opaljetterads": "opaljetterad",
    "opaljetterat": "opaljetterad",
    "opaljetterats": "opaljetterad",
    "opaljetterbara": "opaljetterbar",
    "opaljetterbarare": "opaljetterbar",
    "opaljetterbarares": "opaljetterbar",
    "opaljetterbaras": "opaljetterbar",
    "opaljetterbarast": "opaljetterbar",
    "opaljetterbaraste": "opaljetterbar",
    "opaljetterbarastes": "opaljetterbar",
    "opaljetterbarasts": "opaljetterbar",
    "opaljetterbare": "opaljetterbar",
    "opaljetterbares": "opaljetterbar",
    "opaljetterbarheten": "opaljetterbarhet",
    "opaljetterbarhetens": "opaljetterbarhet",
    "opaljetterbarhets": "opaljetterbarhet",
    "opaljetterbars": "opaljetterbar",
    "opaljetterbart": "opaljetterbar",
    "opaljetterbarts": "opaljetterbar",
    "opallade": "opallad",
    "opallades": "opallad",
    "opallads": "opallad",
    "opallat": "opallad",
    "opallats": "opallad",
    "opalmade": "opalmad",
    "opalmades": "opalmad",
    "opalmads": "opalmad",
    "opalmat": "opalmad",
    "opalmats": "opalmad",
    "opalperade": "opalperad",
    "opalperades": "opalperad",
    "opalperads": "opalperad",
    "opalperat": "opalperad",
    "opalperats": "opalperad",
    "opalperbara": "opalperbar",
    "opalperbarare": "opalperbar",
    "opalperbarares": "opalperbar",
    "opalperbaras": "opalperbar",
    "opalperbarast": "opalperbar",
    "opalperbaraste": "opalperbar",
    "opalperbarastes": "opalperbar",
    "opalperbarasts": "opalperbar",
    "opalperbare": "opalperbar",
    "opalperbares": "opalperbar",
    "opalperbarheten": "opalperbarhet",
    "opalperbarhetens": "opalperbarhet",
    "opalperbarhets": "opalperbarhet",
    "opalperbars": "opalperbar",
    "opalperbart": "opalperbar",
    "opalperbarts": "opalperbar",
    "opals": "opal",
    "opanelade": "opanelad",
    "opanelades": "opanelad",
    "opanelads": "opanelad",
    "opanelat": "opanelad",
    "opanelats": "opanelad",
    "opanerade": "opanerad",
    "opanerades": "opanerad",
    "opanerads": "opanerad",
    "opanerat": "opanerad",
    "opanerats": "opanerad",
    "opanerbara": "opanerbar",
    "opanerbarare": "opanerbar",
    "opanerbarares": "opanerbar",
    "opanerbaras": "opanerbar",
    "opanerbarast": "opanerbar",
    "opanerbaraste": "opanerbar",
    "opanerbarastes": "opanerbar",
    "opanerbarasts": "opanerbar",
    "opanerbare": "opanerbar",
    "opanerbares": "opanerbar",
    "opanerbarheten": "opanerbarhet",
    "opanerbarhetens": "opanerbarhet",
    "opanerbarhets": "opanerbarhet",
    "opanerbars": "opanerbar",
    "opanerbart": "opanerbar",
    "opanerbarts": "opanerbar",
    "opangade": "opangad",
    "opangades": "opangad",
    "opangads": "opangad",
    "opangat": "opangad",
    "opangats": "opangad",
    "opanorerade": "opanorerad",
    "opanorerades": "opanorerad",
    "opanorerads": "opanorerad",
    "opanorerat": "opanorerad",
    "opanorerats": "opanorerad",
    "opanorerbara": "opanorerbar",
    "opanorerbarare": "opanorerbar",
    "opanorerbarares": "opanorerbar",
    "opanorerbaras": "opanorerbar",
    "opanorerbarast": "opanorerbar",
    "opanorerbaraste": "opanorerbar",
    "opanorerbarastes": "opanorerbar",
    "opanorerbarasts": "opanorerbar",
    "opanorerbare": "opanorerbar",
    "opanorerbares": "opanorerbar",
    "opanorerbarheten": "opanorerbarhet",
    "opanorerbarhetens": "opanorerbarhet",
    "opanorerbarhets": "opanorerbarhet",
    "opanorerbars": "opanorerbar",
    "opanorerbart": "opanorerbar",
    "opanorerbarts": "opanorerbar",
    "opansrade": "opansrad",
    "opansrades": "opansrad",
    "opansrads": "opansrad",
    "opansrat": "opansrad",
    "opansrats": "opansrad",
    "opantade": "opantad",
    "opantades": "opantad",
    "opantads": "opantad",
    "opantat": "opantad",
    "opantats": "opantad",
    "opantograferade": "opantograferad",
    "opantograferades": "opantograferad",
    "opantograferads": "opantograferad",
    "opantograferat": "opantograferad",
    "opantograferats": "opantograferad",
    "opantograferbara": "opantograferbar",
    "opantograferbarare": "opantograferbar",
    "opantograferbarares": "opantograferbar",
    "opantograferbaras": "opantograferbar",
    "opantograferbarast": "opantograferbar",
    "opantograferbaraste": "opantograferbar",
    "opantograferbarastes": "opantograferbar",
    "opantograferbarasts": "opantograferbar",
    "opantograferbare": "opantograferbar",
    "opantograferbares": "opantograferbar",
    "opantograferbarheten": "opantograferbarhet",
    "opantograferbarhetens": "opantograferbarhet",
    "opantograferbarhets": "opantograferbarhet",
    "opantograferbars": "opantograferbar",
    "opantograferbart": "opantograferbar",
    "opantograferbarts": "opantograferbar",
    "oparade": "oparad",
    "oparaderade": "oparaderad",
    "oparaderades": "oparaderad",
    "oparaderads": "oparaderad",
    "oparaderat": "oparaderad",
    "oparaderats": "oparaderad",
    "oparaderbara": "oparaderbar",
    "oparaderbarare": "oparaderbar",
    "oparaderbarares": "oparaderbar",
    "oparaderbaras": "oparaderbar",
    "oparaderbarast": "oparaderbar",
    "oparaderbaraste": "oparaderbar",
    "oparaderbarastes": "oparaderbar",
    "oparaderbarasts": "oparaderbar",
    "oparaderbare": "oparaderbar",
    "oparaderbares": "oparaderbar",
    "oparaderbarheten": "oparaderbarhet",
    "oparaderbarhetens": "oparaderbarhet",
    "oparaderbarhets": "oparaderbarhet",
    "oparaderbars": "oparaderbar",
    "oparaderbart": "oparaderbar",
    "oparaderbarts": "oparaderbar",
    "oparades": "oparad",
    "oparads": "oparad",
    "oparaferade": "oparaferad",
    "oparaferades": "oparaferad",
    "oparaferads": "oparaferad",
    "oparaferat": "oparaferad",
    "oparaferats": "oparaferad",
    "oparaferbara": "oparaferbar",
    "oparaferbarare": "oparaferbar",
    "oparaferbarares": "oparaferbar",
    "oparaferbaras": "oparaferbar",
    "oparaferbarast": "oparaferbar",
    "oparaferbaraste": "oparaferbar",
    "oparaferbarastes": "oparaferbar",
    "oparaferbarasts": "oparaferbar",
    "oparaferbare": "oparaferbar",
    "oparaferbares": "oparaferbar",
    "oparaferbarheten": "oparaferbarhet",
    "oparaferbarhetens": "oparaferbarhet",
    "oparaferbarhets": "oparaferbarhet",
    "oparaferbars": "oparaferbar",
    "oparaferbart": "oparaferbar",
    "oparaferbarts": "oparaferbar",
    "oparaffinerade": "oparaffinerad",
    "oparaffinerades": "oparaffinerad",
    "oparaffinerads": "oparaffinerad",
    "oparaffinerat": "oparaffinerad",
    "oparaffinerats": "oparaffinerad",
    "oparaffinerbara": "oparaffinerbar",
    "oparaffinerbarare": "oparaffinerbar",
    "oparaffinerbarares": "oparaffinerbar",
    "oparaffinerbaras": "oparaffinerbar",
    "oparaffinerbarast": "oparaffinerbar",
    "oparaffinerbaraste": "oparaffinerbar",
    "oparaffinerbarastes": "oparaffinerbar",
    "oparaffinerbarasts": "oparaffinerbar",
    "oparaffinerbare": "oparaffinerbar",
    "oparaffinerbares": "oparaffinerbar",
    "oparaffinerbarheten": "oparaffinerbarhet",
    "oparaffinerbarhetens": "oparaffinerbarhet",
    "oparaffinerbarhets": "oparaffinerbarhet",
    "oparaffinerbars": "oparaffinerbar",
    "oparaffinerbart": "oparaffinerbar",
    "oparaffinerbarts": "oparaffinerbar",
    "oparafraserade": "oparafraserad",
    "oparafraserades": "oparafraserad",
    "oparafraserads": "oparafraserad",
    "oparafraserat": "oparafraserad",
    "oparafraserats": "oparafraserad",
    "oparafraserbara": "oparafraserbar",
    "oparafraserbarare": "oparafraserbar",
    "oparafraserbarares": "oparafraserbar",
    "oparafraserbaras": "oparafraserbar",
    "oparafraserbarast": "oparafraserbar",
    "oparafraserbaraste": "oparafraserbar",
    "oparafraserbarastes": "oparafraserbar",
    "oparafraserbarasts": "oparafraserbar",
    "oparafraserbare": "oparafraserbar",
    "oparafraserbares": "oparafraserbar",
    "oparafraserbarheten": "oparafraserbarhet",
    "oparafraserbarhetens": "oparafraserbarhet",
    "oparafraserbarhets": "oparafraserbarhet",
    "oparafraserbars": "oparafraserbar",
    "oparafraserbart": "oparafraserbar",
    "oparafraserbarts": "oparafraserbar",
    "oparallelliserade": "oparallelliserad",
    "oparallelliserades": "oparallelliserad",
    "oparallelliserads": "oparallelliserad",
    "oparallelliserat": "oparallelliserad",
    "oparallelliserats": "oparallelliserad",
    "oparallelliserbara": "oparallelliserbar",
    "oparallelliserbarare": "oparallelliserbar",
    "oparallelliserbarares": "oparallelliserbar",
    "oparallelliserbaras": "oparallelliserbar",
    "oparallelliserbarast": "oparallelliserbar",
    "oparallelliserbaraste": "oparallelliserbar",
    "oparallelliserbarastes": "oparallelliserbar",
    "oparallelliserbarasts": "oparallelliserbar",
    "oparallelliserbare": "oparallelliserbar",
    "oparallelliserbares": "oparallelliserbar",
    "oparallelliserbarheten": "oparallelliserbarhet",
    "oparallelliserbarhetens": "oparallelliserbarhet",
    "oparallelliserbarhets": "oparallelliserbarhet",
    "oparallelliserbars": "oparallelliserbar",
    "oparallelliserbart": "oparallelliserbar",
    "oparallelliserbarts": "oparallelliserbar",
    "oparalyserade": "oparalyserad",
    "oparalyserades": "oparalyserad",
    "oparalyserads": "oparalyserad",
    "oparalyserat": "oparalyserad",
    "oparalyserats": "oparalyserad",
    "oparalyserbara": "oparalyserbar",
    "oparalyserbarare": "oparalyserbar",
    "oparalyserbarares": "oparalyserbar",
    "oparalyserbaras": "oparalyserbar",
    "oparalyserbarast": "oparalyserbar",
    "oparalyserbaraste": "oparalyserbar",
    "oparalyserbarastes": "oparalyserbar",
    "oparalyserbarasts": "oparalyserbar",
    "oparalyserbare": "oparalyserbar",
    "oparalyserbares": "oparalyserbar",
    "oparalyserbarheten": "oparalyserbarhet",
    "oparalyserbarhetens": "oparalyserbarhet",
    "oparalyserbarhets": "oparalyserbarhet",
    "oparalyserbars": "oparalyserbar",
    "oparalyserbart": "oparalyserbar",
    "oparalyserbarts": "oparalyserbar",
    "oparat": "oparad",
    "oparats": "oparad",
    "oparerade": "oparerad",
    "oparerades": "oparerad",
    "oparerads": "oparerad",
    "oparerat": "oparerad",
    "oparerats": "oparerad",
    "oparerbara": "oparerbar",
    "oparerbarare": "oparerbar",
    "oparerbarares": "oparerbar",
    "oparerbaras": "oparerbar",
    "oparerbarast": "oparerbar",
    "oparerbaraste": "oparerbar",
    "oparerbarastes": "oparerbar",
    "oparerbarasts": "oparerbar",
    "oparerbare": "oparerbar",
    "oparerbares": "oparerbar",
    "oparerbarheten": "oparerbarhet",
    "oparerbarhetens": "oparerbarhet",
    "oparerbarhets": "oparerbarhet",
    "oparerbars": "oparerbar",
    "oparerbart": "oparerbar",
    "oparerbarts": "oparerbar",
    "oparfymerade": "oparfymerad",
    "oparfymerades": "oparfymerad",
    "oparfymerads": "oparfymerad",
    "oparfymerat": "oparfymerad",
    "oparfymerats": "oparfymerad",
    "oparfymerbara": "oparfymerbar",
    "oparfymerbarare": "oparfymerbar",
    "oparfymerbarares": "oparfymerbar",
    "oparfymerbaras": "oparfymerbar",
    "oparfymerbarast": "oparfymerbar",
    "oparfymerbaraste": "oparfymerbar",
    "oparfymerbarastes": "oparfymerbar",
    "oparfymerbarasts": "oparfymerbar",
    "oparfymerbare": "oparfymerbar",
    "oparfymerbares": "oparfymerbar",
    "oparfymerbarheten": "oparfymerbarhet",
    "oparfymerbarhetens": "oparfymerbarhet",
    "oparfymerbarhets": "oparfymerbarhet",
    "oparfymerbars": "oparfymerbar",
    "oparfymerbart": "oparfymerbar",
    "oparfymerbarts": "oparfymerbar",
    "oparkerade": "oparkerad",
    "oparkerades": "oparkerad",
    "oparkerads": "oparkerad",
    "oparkerat": "oparkerad",
    "oparkerats": "oparkerad",
    "oparkerbara": "oparkerbar",
    "oparkerbarare": "oparkerbar",
    "oparkerbarares": "oparkerbar",
    "oparkerbaras": "oparkerbar",
    "oparkerbarast": "oparkerbar",
    "oparkerbaraste": "oparkerbar",
    "oparkerbarastes": "oparkerbar",
    "oparkerbarasts": "oparkerbar",
    "oparkerbare": "oparkerbar",
    "oparkerbares": "oparkerbar",
    "oparkerbarheten": "oparkerbarhet",
    "oparkerbarhetens": "oparkerbarhet",
    "oparkerbarhets": "oparkerbarhet",
    "oparkerbars": "oparkerbar",
    "oparkerbart": "oparkerbar",
    "oparkerbarts": "oparkerbar",
    "oparketterade": "oparketterad",
    "oparketterades": "oparketterad",
    "oparketterads": "oparketterad",
    "oparketterat": "oparketterad",
    "oparketterats": "oparketterad",
    "oparketterbara": "oparketterbar",
    "oparketterbarare": "oparketterbar",
    "oparketterbarares": "oparketterbar",
    "oparketterbaras": "oparketterbar",
    "oparketterbarast": "oparketterbar",
    "oparketterbaraste": "oparketterbar",
    "oparketterbarastes": "oparketterbar",
    "oparketterbarasts": "oparketterbar",
    "oparketterbare": "oparketterbar",
    "oparketterbares": "oparketterbar",
    "oparketterbarheten": "oparketterbarhet",
    "oparketterbarhetens": "oparketterbarhet",
    "oparketterbarhets": "oparketterbarhet",
    "oparketterbars": "oparketterbar",
    "oparketterbart": "oparketterbar",
    "oparketterbarts": "oparketterbar",
    "oparlamentariska": "oparlamentarisk",
    "oparlamentariskare": "oparlamentarisk",
    "oparlamentariskares": "oparlamentarisk",
    "oparlamentariskas": "oparlamentarisk",
    "oparlamentariskast": "oparlamentarisk",
    "oparlamentariskaste": "oparlamentarisk",
    "oparlamentariskastes": "oparlamentarisk",
    "oparlamentariskasts": "oparlamentarisk",
    "oparlamentariske": "oparlamentarisk",
    "oparlamentariskes": "oparlamentarisk",
    "oparlamentarisks": "oparlamentarisk",
    "oparlamentariskt": "oparlamentarisk",
    "oparlamentariskts": "oparlamentarisk",
    "oparodierade": "oparodierad",
    "oparodierades": "oparodierad",
    "oparodierads": "oparodierad",
    "oparodierat": "oparodierad",
    "oparodierats": "oparodierad",
    "oparodierbara": "oparodierbar",
    "oparodierbarare": "oparodierbar",
    "oparodierbarares": "oparodierbar",
    "oparodierbaras": "oparodierbar",
    "oparodierbarast": "oparodierbar",
    "oparodierbaraste": "oparodierbar",
    "oparodierbarastes": "oparodierbar",
    "oparodierbarasts": "oparodierbar",
    "oparodierbare": "oparodierbar",
    "oparodierbares": "oparodierbar",
    "oparodierbarheten": "oparodierbarhet",
    "oparodierbarhetens": "oparodierbarhet",
    "oparodierbarhets": "oparodierbarhet",
    "oparodierbars": "oparodierbar",
    "oparodierbart": "oparodierbar",
    "oparodierbarts": "oparodierbar",
    "opartiska": "opartisk",
    "opartiskare": "opartisk",
    "opartiskares": "opartisk",
    "opartiskas": "opartisk",
    "opartiskast": "opartisk",
    "opartiskaste": "opartisk",
    "opartiskastes": "opartisk",
    "opartiskasts": "opartisk",
    "opartiske": "opartisk",
    "opartiskes": "opartisk",
    "opartisks": "opartisk",
    "opartiskt": "opartisk",
    "opartiskts": "opartisk",
    "opassade": "opassad",
    "opassades": "opassad",
    "opassads": "opassad",
    "opassat": "opassad",
    "opassats": "opassad",
    "opasserade": "opasserad",
    "opasserades": "opasserad",
    "opasserads": "opasserad",
    "opasserat": "opasserad",
    "opasserats": "opasserad",
    "opasserbara": "opasserbar",
    "opasserbarare": "opasserbar",
    "opasserbarares": "opasserbar",
    "opasserbaras": "opasserbar",
    "opasserbarast": "opasserbar",
    "opasserbaraste": "opasserbar",
    "opasserbarastes": "opasserbar",
    "opasserbarasts": "opasserbar",
    "opasserbare": "opasserbar",
    "opasserbares": "opasserbar",
    "opasserbarheten": "opasserbarhet",
    "opasserbarhetens": "opasserbarhet",
    "opasserbarhets": "opasserbarhet",
    "opasserbars": "opasserbar",
    "opasserbart": "opasserbar",
    "opasserbarts": "opasserbar",
    "opassiverade": "opassiverad",
    "opassiverades": "opassiverad",
    "opassiverads": "opassiverad",
    "opassiverat": "opassiverad",
    "opassiverats": "opassiverad",
    "opassiverbara": "opassiverbar",
    "opassiverbarare": "opassiverbar",
    "opassiverbarares": "opassiverbar",
    "opassiverbaras": "opassiverbar",
    "opassiverbarast": "opassiverbar",
    "opassiverbaraste": "opassiverbar",
    "opassiverbarastes": "opassiverbar",
    "opassiverbarasts": "opassiverbar",
    "opassiverbare": "opassiverbar",
    "opassiverbares": "opassiverbar",
    "opassiverbarheten": "opassiverbarhet",
    "opassiverbarhetens": "opassiverbarhet",
    "opassiverbarhets": "opassiverbarhet",
    "opassiverbars": "opassiverbar",
    "opassiverbart": "opassiverbar",
    "opassiverbarts": "opassiverbar",
    "opassiviserade": "opassiviserad",
    "opassiviserades": "opassiviserad",
    "opassiviserads": "opassiviserad",
    "opassiviserat": "opassiviserad",
    "opassiviserats": "opassiviserad",
    "opassiviserbara": "opassiviserbar",
    "opassiviserbarare": "opassiviserbar",
    "opassiviserbarares": "opassiviserbar",
    "opassiviserbaras": "opassiviserbar",
    "opassiviserbarast": "opassiviserbar",
    "opassiviserbaraste": "opassiviserbar",
    "opassiviserbarastes": "opassiviserbar",
    "opassiviserbarasts": "opassiviserbar",
    "opassiviserbare": "opassiviserbar",
    "opassiviserbares": "opassiviserbar",
    "opassiviserbarheten": "opassiviserbarhet",
    "opassiviserbarhetens": "opassiviserbarhet",
    "opassiviserbarhets": "opassiviserbarhet",
    "opassiviserbars": "opassiviserbar",
    "opassiviserbart": "opassiviserbar",
    "opassiviserbarts": "opassiviserbar",
    "opassliga": "opasslig",
    "opassligare": "opasslig",
    "opassligares": "opasslig",
    "opassligas": "opasslig",
    "opassligast": "opasslig",
    "opassligaste": "opasslig",
    "opassligastes": "opasslig",
    "opassligasts": "opasslig",
    "opasslige": "opasslig",
    "opassliges": "opasslig",
    "opassligheten": "opasslighet",
    "opasslighetens": "opasslighet",
    "opasslighets": "opasslighet",
    "opassligs": "opasslig",
    "opassligt": "opasslig",
    "opassligts": "opasslig",
    "opastöriserade": "opastöriserad",
    "opastöriserades": "opastöriserad",
    "opastöriserads": "opastöriserad",
    "opastöriserat": "opastöriserad",
    "opastöriserats": "opastöriserad",
    "opastöriserbara": "opastöriserbar",
    "opastöriserbarare": "opastöriserbar",
    "opastöriserbarares": "opastöriserbar",
    "opastöriserbaras": "opastöriserbar",
    "opastöriserbarast": "opastöriserbar",
    "opastöriserbaraste": "opastöriserbar",
    "opastöriserbarastes": "opastöriserbar",
    "opastöriserbarasts": "opastöriserbar",
    "opastöriserbare": "opastöriserbar",
    "opastöriserbares": "opastöriserbar",
    "opastöriserbarheten": "opastöriserbarhet",
    "opastöriserbarhetens": "opastöriserbarhet",
    "opastöriserbarhets": "opastöriserbarhet",
    "opastöriserbars": "opastöriserbar",
    "opastöriserbart": "opastöriserbar",
    "opastöriserbarts": "opastöriserbar",
    "opatenterade": "opatenterad",
    "opatenterades": "opatenterad",
    "opatenterads": "opatenterad",
    "opatenterat": "opatenterad",
    "opatenterats": "opatenterad",
    "opatenterbara": "opatenterbar",
    "opatenterbarare": "opatenterbar",
    "opatenterbarares": "opatenterbar",
    "opatenterbaras": "opatenterbar",
    "opatenterbarast": "opatenterbar",
    "opatenterbaraste": "opatenterbar",
    "opatenterbarastes": "opatenterbar",
    "opatenterbarasts": "opatenterbar",
    "opatenterbare": "opatenterbar",
    "opatenterbares": "opatenterbar",
    "opatenterbarheten": "opatenterbarhet",
    "opatenterbarhetens": "opatenterbarhet",
    "opatenterbarhets": "opatenterbarhet",
    "opatenterbars": "opatenterbar",
    "opatenterbart": "opatenterbar",
    "opatenterbarts": "opatenterbar",
    "opatinerade": "opatinerad",
    "opatinerades": "opatinerad",
    "opatinerads": "opatinerad",
    "opatinerat": "opatinerad",
    "opatinerats": "opatinerad",
    "opatinerbara": "opatinerbar",
    "opatinerbarare": "opatinerbar",
    "opatinerbarares": "opatinerbar",
    "opatinerbaras": "opatinerbar",
    "opatinerbarast": "opatinerbar",
    "opatinerbaraste": "opatinerbar",
    "opatinerbarastes": "opatinerbar",
    "opatinerbarasts": "opatinerbar",
    "opatinerbare": "opatinerbar",
    "opatinerbares": "opatinerbar",
    "opatinerbarheten": "opatinerbarhet",
    "opatinerbarhetens": "opatinerbarhet",
    "opatinerbarhets": "opatinerbarhet",
    "opatinerbars": "opatinerbar",
    "opatinerbart": "opatinerbar",
    "opatinerbarts": "opatinerbar",
    "opatrullerade": "opatrullerad",
    "opatrullerades": "opatrullerad",
    "opatrullerads": "opatrullerad",
    "opatrullerat": "opatrullerad",
    "opatrullerats": "opatrullerad",
    "opatrullerbara": "opatrullerbar",
    "opatrullerbarare": "opatrullerbar",
    "opatrullerbarares": "opatrullerbar",
    "opatrullerbaras": "opatrullerbar",
    "opatrullerbarast": "opatrullerbar",
    "opatrullerbaraste": "opatrullerbar",
    "opatrullerbarastes": "opatrullerbar",
    "opatrullerbarasts": "opatrullerbar",
    "opatrullerbare": "opatrullerbar",
    "opatrullerbares": "opatrullerbar",
    "opatrullerbarheten": "opatrullerbarhet",
    "opatrullerbarhetens": "opatrullerbarhet",
    "opatrullerbarhets": "opatrullerbarhet",
    "opatrullerbars": "opatrullerbar",
    "opatrullerbart": "opatrullerbar",
    "opatrullerbarts": "opatrullerbar",
    "opauperiserade": "opauperiserad",
    "opauperiserades": "opauperiserad",
    "opauperiserads": "opauperiserad",
    "opauperiserat": "opauperiserad",
    "opauperiserats": "opauperiserad",
    "opauperiserbara": "opauperiserbar",
    "opauperiserbarare": "opauperiserbar",
    "opauperiserbarares": "opauperiserbar",
    "opauperiserbaras": "opauperiserbar",
    "opauperiserbarast": "opauperiserbar",
    "opauperiserbaraste": "opauperiserbar",
    "opauperiserbarastes": "opauperiserbar",
    "opauperiserbarasts": "opauperiserbar",
    "opauperiserbare": "opauperiserbar",
    "opauperiserbares": "opauperiserbar",
    "opauperiserbarheten": "opauperiserbarhet",
    "opauperiserbarhetens": "opauperiserbarhet",
    "opauperiserbarhets": "opauperiserbarhet",
    "opauperiserbars": "opauperiserbar",
    "opauperiserbart": "opauperiserbar",
    "opauperiserbarts": "opauperiserbar",
    "opausade": "opausad",
    "opausades": "opausad",
    "opausads": "opausad",
    "opausat": "opausad",
    "opausats": "opausad",
    "opauserade": "opauserad",
    "opauserades": "opauserad",
    "opauserads": "opauserad",
    "opauserat": "opauserad",
    "opauserats": "opauserad",
    "opauserbara": "opauserbar",
    "opauserbarare": "opauserbar",
    "opauserbarares": "opauserbar",
    "opauserbaras": "opauserbar",
    "opauserbarast": "opauserbar",
    "opauserbaraste": "opauserbar",
    "opauserbarastes": "opauserbar",
    "opauserbarasts": "opauserbar",
    "opauserbare": "opauserbar",
    "opauserbares": "opauserbar",
    "opauserbarheten": "opauserbarhet",
    "opauserbarhetens": "opauserbarhet",
    "opauserbarhets": "opauserbarhet",
    "opauserbars": "opauserbar",
    "opauserbart": "opauserbar",
    "opauserbarts": "opauserbar",
    "opaxade": "opaxad",
    "opaxades": "opaxad",
    "opaxads": "opaxad",
    "opaxat": "opaxad",
    "opaxats": "opaxad",
    "opedagogiska": "opedagogisk",
    "opedagogiskare": "opedagogisk",
    "opedagogiskares": "opedagogisk",
    "opedagogiskas": "opedagogisk",
    "opedagogiskast": "opedagogisk",
    "opedagogiskaste": "opedagogisk",
    "opedagogiskastes": "opedagogisk",
    "opedagogiskasts": "opedagogisk",
    "opedagogiske": "opedagogisk",
    "opedagogiskes": "opedagogisk",
    "opedagogisks": "opedagogisk",
    "opedagogiskt": "opedagogisk",
    "opedagogiskts": "opedagogisk",
    "opejlade": "opejlad",
    "opejlades": "opejlad",
    "opejlads": "opejlad",
    "opejlat": "opejlad",
    "opejlats": "opejlad",
    "opelleterade": "opelleterad",
    "opelleterades": "opelleterad",
    "opelleterads": "opelleterad",
    "opelleterat": "opelleterad",
    "opelleterats": "opelleterad",
    "opelleterbara": "opelleterbar",
    "opelleterbarare": "opelleterbar",
    "opelleterbarares": "opelleterbar",
    "opelleterbaras": "opelleterbar",
    "opelleterbarast": "opelleterbar",
    "opelleterbaraste": "opelleterbar",
    "opelleterbarastes": "opelleterbar",
    "opelleterbarasts": "opelleterbar",
    "opelleterbare": "opelleterbar",
    "opelleterbares": "opelleterbar",
    "opelleterbarheten": "opelleterbarhet",
    "opelleterbarhetens": "opelleterbarhet",
    "opelleterbarhets": "opelleterbarhet",
    "opelleterbars": "opelleterbar",
    "opelleterbart": "opelleterbar",
    "opelleterbarts": "opelleterbar",
    "openetrerade": "openetrerad",
    "openetrerades": "openetrerad",
    "openetrerads": "openetrerad",
    "openetrerat": "openetrerad",
    "openetrerats": "openetrerad",
    "openetrerbara": "openetrerbar",
    "openetrerbarare": "openetrerbar",
    "openetrerbarares": "openetrerbar",
    "openetrerbaras": "openetrerbar",
    "openetrerbarast": "openetrerbar",
    "openetrerbaraste": "openetrerbar",
    "openetrerbarastes": "openetrerbar",
    "openetrerbarasts": "openetrerbar",
    "openetrerbare": "openetrerbar",
    "openetrerbares": "openetrerbar",
    "openetrerbarheten": "openetrerbarhet",
    "openetrerbarhetens": "openetrerbarhet",
    "openetrerbarhets": "openetrerbarhet",
    "openetrerbars": "openetrerbar",
    "openetrerbart": "openetrerbar",
    "openetrerbarts": "openetrerbar",
    "opensionerade": "opensionerad",
    "opensionerades": "opensionerad",
    "opensionerads": "opensionerad",
    "opensionerat": "opensionerad",
    "opensionerats": "opensionerad",
    "opensionerbara": "opensionerbar",
    "opensionerbarare": "opensionerbar",
    "opensionerbarares": "opensionerbar",
    "opensionerbaras": "opensionerbar",
    "opensionerbarast": "opensionerbar",
    "opensionerbaraste": "opensionerbar",
    "opensionerbarastes": "opensionerbar",
    "opensionerbarasts": "opensionerbar",
    "opensionerbare": "opensionerbar",
    "opensionerbares": "opensionerbar",
    "opensionerbarheten": "opensionerbarhet",
    "opensionerbarhetens": "opensionerbarhet",
    "opensionerbarhets": "opensionerbarhet",
    "opensionerbars": "opensionerbar",
    "opensionerbart": "opensionerbar",
    "opensionerbarts": "opensionerbar",
    "openslade": "openslad",
    "openslades": "openslad",
    "openslads": "openslad",
    "openslat": "openslad",
    "openslats": "openslad",
    "opeppade": "opeppad",
    "opeppades": "opeppad",
    "opeppads": "opeppad",
    "opeppat": "opeppad",
    "opeppats": "opeppad",
    "opepprade": "opepprad",
    "opepprades": "opepprad",
    "opepprads": "opepprad",
    "opepprat": "opepprad",
    "opepprats": "opepprad",
    "operabaletten": "operabalett",
    "operabalettens": "operabalett",
    "operabaletter": "operabalett",
    "operabaletterna": "operabalett",
    "operabaletternas": "operabalett",
    "operabaletters": "operabalett",
    "operabaletts": "operabalett",
    "operabels": "operabel",
    "operabelt": "operabel",
    "operabelts": "operabel",
    "operabiljetten": "operabiljett",
    "operabiljettens": "operabiljett",
    "operabiljetter": "operabiljett",
    "operabiljetterna": "operabiljett",
    "operabiljetternas": "operabiljett",
    "operabiljetters": "operabiljett",
    "operabiljetts": "operabiljett",
    "operabla": "operabel",
    "operablare": "operabel",
    "operablares": "operabel",
    "operablas": "operabel",
    "operablast": "operabel",
    "operablaste": "operabel",
    "operablastes": "operabel",
    "operablasts": "operabel",
    "operable": "operabel",
    "operables": "operabel",
    "operadiken": "operadike",
    "operadikena": "operadike",
    "operadikenas": "operadike",
    "operadikens": "operadike",
    "operadikes": "operadike",
    "operadiket": "operadike",
    "operadikets": "operadike",
    "operahusen": "operahus",
    "operahusens": "operahus",
    "operahuset": "operahus",
    "operahusets": "operahus",
    "operakompositören": "operakompositör",
    "operakompositörens": "operakompositör",
    "operakompositörer": "operakompositör",
    "operakompositörerna": "operakompositör",
    "operakompositörernas": "operakompositör",
    "operakompositörers": "operakompositör",
    "operakompositörs": "operakompositör",
    "operamässiga": "operamässig",
    "operamässigare": "operamässig",
    "operamässigares": "operamässig",
    "operamässigas": "operamässig",
    "operamässigast": "operamässig",
    "operamässigaste": "operamässig",
    "operamässigastes": "operamässig",
    "operamässigasts": "operamässig",
    "operamässige": "operamässig",
    "operamässiges": "operamässig",
    "operamässigs": "operamässig",
    "operamässigt": "operamässig",
    "operamässigts": "operamässig",
    "operan": "opera",
    "operans": "opera",
    "operas": "opera",
    "operationaliserad": "operationalisera",
    "operationaliserade": "operationalisera",
    "operationaliserades": "operationalisera",
    "operationaliserads": "operationalisera",
    "operationaliserande": "operationalisera",
    "operationaliseranden": "operationaliserande",
    "operationaliserandena": "operationaliserande",
    "operationaliserandenas": "operationaliserande",
    "operationaliserandens": "operationaliserande",
    "operationaliserandes": "operationaliserande",
    "operationaliserandet": "operationaliserande",
    "operationaliserandets": "operationaliserande",
    "operationaliserar": "operationalisera",
    "operationaliseras": "operationalisera",
    "operationaliserat": "operationalisera",
    "operationaliserats": "operationalisera",
    "operationaliserbara": "operationaliserbar",
    "operationaliserbarare": "operationaliserbar",
    "operationaliserbarares": "operationaliserbar",
    "operationaliserbaras": "operationaliserbar",
    "operationaliserbarast": "operationaliserbar",
    "operationaliserbaraste": "operationaliserbar",
    "operationaliserbarastes": "operationaliserbar",
    "operationaliserbarasts": "operationaliserbar",
    "operationaliserbare": "operationaliserbar",
    "operationaliserbares": "operationaliserbar",
    "operationaliserbarheten": "operationaliserbarhet",
    "operationaliserbarhetens": "operationaliserbarhet",
    "operationaliserbarhets": "operationaliserbarhet",
    "operationaliserbars": "operationaliserbar",
    "operationaliserbart": "operationaliserbar",
    "operationaliserbarts": "operationaliserbar",
    "operationaliseringar": "operationalisering",
    "operationaliseringarna": "operationalisering",
    "operationaliseringarnas": "operationalisering",
    "operationaliseringars": "operationalisering",
    "operationaliseringen": "operationalisering",
    "operationaliseringens": "operationalisering",
    "operationaliserings": "operationalisering",
    "operationalismen": "operationalism",
    "operationalismens": "operationalism",
    "operationalismer": "operationalism",
    "operationalismerna": "operationalism",
    "operationalismernas": "operationalism",
    "operationalismers": "operationalism",
    "operationalisms": "operationalism",
    "operationalistiska": "operationalistisk",
    "operationalistiskas": "operationalistisk",
    "operationalistiske": "operationalistisk",
    "operationalistiskes": "operationalistisk",
    "operationalistisks": "operationalistisk",
    "operationalistiskt": "operationalistisk",
    "operationalistiskts": "operationalistisk",
    "operationella": "operationell",
    "operationellare": "operationell",
    "operationellares": "operationell",
    "operationellas": "operationell",
    "operationellast": "operationell",
    "operationellaste": "operationell",
    "operationellastes": "operationell",
    "operationellasts": "operationell",
    "operationelle": "operationell",
    "operationelles": "operationell",
    "operationells": "operationell",
    "operationellt": "operationell",
    "operationellts": "operationell",
    "operationen": "operation",
    "operationens": "operation",
    "operationer": "operation",
    "operationerna": "operation",
    "operationernas": "operation",
    "operationers": "operation",
    "operations": "operation",
    "operationsanalysen": "operationsanalys",
    "operationsanalysens": "operationsanalys",
    "operationsbasen": "operationsbas",
    "operationsbasens": "operationsbas",
    "operationsbaser": "operationsbas",
    "operationsbaserna": "operationsbas",
    "operationsbasernas": "operationsbas",
    "operationsbasers": "operationsbas",
    "operationsbesticken": "operationsbestick",
    "operationsbestickens": "operationsbestick",
    "operationsbesticket": "operationsbestick",
    "operationsbestickets": "operationsbestick",
    "operationsbesticks": "operationsbestick",
    "operationslinjen": "operationslinje",
    "operationslinjens": "operationslinje",
    "operationslinjer": "operationslinje",
    "operationslinjerna": "operationslinje",
    "operationslinjernas": "operationslinje",
    "operationslinjers": "operationslinje",
    "operationslinjes": "operationslinje",
    "operationsringar": "operationsring",
    "operationsringarna": "operationsring",
    "operationsringarnas": "operationsring",
    "operationsringars": "operationsring",
    "operationsringen": "operationsring",
    "operationsringens": "operationsring",
    "operationsrings": "operationsring",
    "operationssalar": "operationssal",
    "operationssalarna": "operationssal",
    "operationssalarnas": "operationssal",
    "operationssalars": "operationssal",
    "operationssalen": "operationssal",
    "operationssalens": "operationssal",
    "operationssals": "operationssal",
    "operativa": "operativ",
    "operativare": "operativ",
    "operativares": "operativ",
    "operativas": "operativ",
    "operativast": "operativ",
    "operativaste": "operativ",
    "operativastes": "operativ",
    "operativasts": "operativ",
    "operative": "operativ",
    "operatives": "operativ",
    "operativs": "operativ",
    "operativsystemen": "operativsystem",
    "operativsystemens": "operativsystem",
    "operativsystemet": "operativsystem",
    "operativsystemets": "operativsystem",
    "operativsystems": "operativsystem",
    "operativt": "operativ",
    "operativts": "operativ",
    "operatorer": "operator",
    "operatorerna": "operator",
    "operatorernas": "operator",
    "operatorers": "operator",
    "operatorn": "operator",
    "operatorns": "operator",
    "operators": "operator",
    "operatrisen": "operatris",
    "operatrisens": "operatris",
    "operatriser": "operatris",
    "operatriserna": "operatris",
    "operatrisernas": "operatris",
    "operatrisers": "operatris",
    "operatören": "operatör",
    "operatörens": "operatör",
    "operatörer": "operatör",
    "operatörerna": "operatör",
    "operatörernas": "operatör",
    "operatörers": "operatör",
    "operatörs": "operatör",
    "opercipierade": "opercipierad",
    "opercipierades": "opercipierad",
    "opercipierads": "opercipierad",
    "opercipierat": "opercipierad",
    "opercipierats": "opercipierad",
    "opercipierbara": "opercipierbar",
    "opercipierbarare": "opercipierbar",
    "opercipierbarares": "opercipierbar",
    "opercipierbaras": "opercipierbar",
    "opercipierbarast": "opercipierbar",
    "opercipierbaraste": "opercipierbar",
    "opercipierbarastes": "opercipierbar",
    "opercipierbarasts": "opercipierbar",
    "opercipierbare": "opercipierbar",
    "opercipierbares": "opercipierbar",
    "opercipierbarheten": "opercipierbarhet",
    "opercipierbarhetens": "opercipierbarhet",
    "opercipierbarhets": "opercipierbarhet",
    "opercipierbars": "opercipierbar",
    "opercipierbart": "opercipierbar",
    "opercipierbarts": "opercipierbar",
    "opererad": "operera",
    "opererade": "operera",
    "opererades": "operera",
    "opererads": "operera",
    "opererande": "operera",
    "opereranden": "opererande",
    "opererandena": "opererande",
    "opererandenas": "opererande",
    "opererandens": "opererande",
    "opererandes": "opererande",
    "opererandet": "opererande",
    "opererandets": "opererande",
    "opererar": "operera",
    "opereras": "operera",
    "opererat": "operera",
    "opererats": "operera",
    "opererbara": "opererbar",
    "opererbarare": "opererbar",
    "opererbarares": "opererbar",
    "opererbaras": "opererbar",
    "opererbarast": "opererbar",
    "opererbaraste": "opererbar",
    "opererbarastes": "opererbar",
    "opererbarasts": "opererbar",
    "opererbare": "opererbar",
    "opererbares": "opererbar",
    "opererbarheten": "opererbarhet",
    "opererbarhetens": "opererbarhet",
    "opererbarhets": "opererbarhet",
    "opererbars": "opererbar",
    "opererbart": "opererbar",
    "opererbarts": "opererbar",
    "opereringar": "operering",
    "opereringarna": "operering",
    "opereringarnas": "operering",
    "opereringars": "operering",
    "opereringen": "operering",
    "opereringens": "operering",
    "opererings": "operering",
    "operetteatern": "operetteater",
    "operetteaterns": "operetteater",
    "operetteaters": "operetteater",
    "operetteatrar": "operetteater",
    "operetteatrarna": "operetteater",
    "operetteatrarnas": "operetteater",
    "operetteatrars": "operetteater",
    "operetten": "operett",
    "operettens": "operett",
    "operetter": "operett",
    "operetterna": "operett",
    "operetternas": "operett",
    "operetters": "operett",
    "operetts": "operett",
    "operforerade": "operforerad",
    "operforerades": "operforerad",
    "operforerads": "operforerad",
    "operforerat": "operforerad",
    "operforerats": "operforerad",
    "operforerbara": "operforerbar",
    "operforerbarare": "operforerbar",
    "operforerbarares": "operforerbar",
    "operforerbaras": "operforerbar",
    "operforerbarast": "operforerbar",
    "operforerbaraste": "operforerbar",
    "operforerbarastes": "operforerbar",
    "operforerbarasts": "operforerbar",
    "operforerbare": "operforerbar",
    "operforerbares": "operforerbar",
    "operforerbarheten": "operforerbarhet",
    "operforerbarhetens": "operforerbarhet",
    "operforerbarhets": "operforerbarhet",
    "operforerbars": "operforerbar",
    "operforerbart": "operforerbar",
    "operforerbarts": "operforerbar",
    "operiodiserade": "operiodiserad",
    "operiodiserades": "operiodiserad",
    "operiodiserads": "operiodiserad",
    "operiodiserat": "operiodiserad",
    "operiodiserats": "operiodiserad",
    "operiodiserbara": "operiodiserbar",
    "operiodiserbarare": "operiodiserbar",
    "operiodiserbarares": "operiodiserbar",
    "operiodiserbaras": "operiodiserbar",
    "operiodiserbarast": "operiodiserbar",
    "operiodiserbaraste": "operiodiserbar",
    "operiodiserbarastes": "operiodiserbar",
    "operiodiserbarasts": "operiodiserbar",
    "operiodiserbare": "operiodiserbar",
    "operiodiserbares": "operiodiserbar",
    "operiodiserbarheten": "operiodiserbarhet",
    "operiodiserbarhetens": "operiodiserbarhet",
    "operiodiserbarhets": "operiodiserbarhet",
    "operiodiserbars": "operiodiserbar",
    "operiodiserbart": "operiodiserbar",
    "operiodiserbarts": "operiodiserbar",
    "opermanentade": "opermanentad",
    "opermanentades": "opermanentad",
    "opermanentads": "opermanentad",
    "opermanentat": "opermanentad",
    "opermanentats": "opermanentad",
    "opermitterade": "opermitterad",
    "opermitterades": "opermitterad",
    "opermitterads": "opermitterad",
    "opermitterat": "opermitterad",
    "opermitterats": "opermitterad",
    "opermitterbara": "opermitterbar",
    "opermitterbarare": "opermitterbar",
    "opermitterbarares": "opermitterbar",
    "opermitterbaras": "opermitterbar",
    "opermitterbarast": "opermitterbar",
    "opermitterbaraste": "opermitterbar",
    "opermitterbarastes": "opermitterbar",
    "opermitterbarasts": "opermitterbar",
    "opermitterbare": "opermitterbar",
    "opermitterbares": "opermitterbar",
    "opermitterbarheten": "opermitterbarhet",
    "opermitterbarhetens": "opermitterbarhet",
    "opermitterbarhets": "opermitterbarhet",
    "opermitterbars": "opermitterbar",
    "opermitterbart": "opermitterbar",
    "opermitterbarts": "opermitterbar",
    "opermuterade": "opermuterad",
    "opermuterades": "opermuterad",
    "opermuterads": "opermuterad",
    "opermuterat": "opermuterad",
    "opermuterats": "opermuterad",
    "opermuterbara": "opermuterbar",
    "opermuterbarare": "opermuterbar",
    "opermuterbarares": "opermuterbar",
    "opermuterbaras": "opermuterbar",
    "opermuterbarast": "opermuterbar",
    "opermuterbaraste": "opermuterbar",
    "opermuterbarastes": "opermuterbar",
    "opermuterbarasts": "opermuterbar",
    "opermuterbare": "opermuterbar",
    "opermuterbares": "opermuterbar",
    "opermuterbarheten": "opermuterbarhet",
    "opermuterbarhetens": "opermuterbarhet",
    "opermuterbarhets": "opermuterbarhet",
    "opermuterbars": "opermuterbar",
    "opermuterbart": "opermuterbar",
    "opermuterbarts": "opermuterbar",
    "operor": "opera",
    "operorna": "opera",
    "operornas": "opera",
    "operors": "opera",
    "opersiflerade": "opersiflerad",
    "opersiflerades": "opersiflerad",
    "opersiflerads": "opersiflerad",
    "opersiflerat": "opersiflerad",
    "opersiflerats": "opersiflerad",
    "opersiflerbara": "opersiflerbar",
    "opersiflerbarare": "opersiflerbar",
    "opersiflerbarares": "opersiflerbar",
    "opersiflerbaras": "opersiflerbar",
    "opersiflerbarast": "opersiflerbar",
    "opersiflerbaraste": "opersiflerbar",
    "opersiflerbarastes": "opersiflerbar",
    "opersiflerbarasts": "opersiflerbar",
    "opersiflerbare": "opersiflerbar",
    "opersiflerbares": "opersiflerbar",
    "opersiflerbarheten": "opersiflerbarhet",
    "opersiflerbarhetens": "opersiflerbarhet",
    "opersiflerbarhets": "opersiflerbarhet",
    "opersiflerbars": "opersiflerbar",
    "opersiflerbart": "opersiflerbar",
    "opersiflerbarts": "opersiflerbar",
    "opersonifierade": "opersonifierad",
    "opersonifierades": "opersonifierad",
    "opersonifierads": "opersonifierad",
    "opersonifierat": "opersonifierad",
    "opersonifierats": "opersonifierad",
    "opersonifierbara": "opersonifierbar",
    "opersonifierbarare": "opersonifierbar",
    "opersonifierbarares": "opersonifierbar",
    "opersonifierbaras": "opersonifierbar",
    "opersonifierbarast": "opersonifierbar",
    "opersonifierbaraste": "opersonifierbar",
    "opersonifierbarastes": "opersonifierbar",
    "opersonifierbarasts": "opersonifierbar",
    "opersonifierbare": "opersonifierbar",
    "opersonifierbares": "opersonifierbar",
    "opersonifierbarheten": "opersonifierbarhet",
    "opersonifierbarhetens": "opersonifierbarhet",
    "opersonifierbarhets": "opersonifierbarhet",
    "opersonifierbars": "opersonifierbar",
    "opersonifierbart": "opersonifierbar",
    "opersonifierbarts": "opersonifierbar",
    "opersonliga": "opersonlig",
    "opersonligare": "opersonlig",
    "opersonligares": "opersonlig",
    "opersonligas": "opersonlig",
    "opersonligast": "opersonlig",
    "opersonligaste": "opersonlig",
    "opersonligastes": "opersonlig",
    "opersonligasts": "opersonlig",
    "opersonlige": "opersonlig",
    "opersonliges": "opersonlig",
    "opersonligheten": "opersonlighet",
    "opersonlighetens": "opersonlighet",
    "opersonlighets": "opersonlighet",
    "opersonligs": "opersonlig",
    "opersonligt": "opersonlig",
    "opersonligts": "opersonlig",
    "opersvaderade": "opersvaderad",
    "opersvaderades": "opersvaderad",
    "opersvaderads": "opersvaderad",
    "opersvaderat": "opersvaderad",
    "opersvaderats": "opersvaderad",
    "opersvaderbara": "opersvaderbar",
    "opersvaderbarare": "opersvaderbar",
    "opersvaderbarares": "opersvaderbar",
    "opersvaderbaras": "opersvaderbar",
    "opersvaderbarast": "opersvaderbar",
    "opersvaderbaraste": "opersvaderbar",
    "opersvaderbarastes": "opersvaderbar",
    "opersvaderbarasts": "opersvaderbar",
    "opersvaderbare": "opersvaderbar",
    "opersvaderbares": "opersvaderbar",
    "opersvaderbarheten": "opersvaderbarhet",
    "opersvaderbarhetens": "opersvaderbarhet",
    "opersvaderbarhets": "opersvaderbarhet",
    "opersvaderbars": "opersvaderbar",
    "opersvaderbart": "opersvaderbar",
    "opersvaderbarts": "opersvaderbar",
    "operverterade": "operverterad",
    "operverterades": "operverterad",
    "operverterads": "operverterad",
    "operverterat": "operverterad",
    "operverterats": "operverterad",
    "operverterbara": "operverterbar",
    "operverterbarare": "operverterbar",
    "operverterbarares": "operverterbar",
    "operverterbaras": "operverterbar",
    "operverterbarast": "operverterbar",
    "operverterbaraste": "operverterbar",
    "operverterbarastes": "operverterbar",
    "operverterbarasts": "operverterbar",
    "operverterbare": "operverterbar",
    "operverterbares": "operverterbar",
    "operverterbarheten": "operverterbarhet",
    "operverterbarhetens": "operverterbarhet",
    "operverterbarhets": "operverterbarhet",
    "operverterbars": "operverterbar",
    "operverterbart": "operverterbar",
    "operverterbarts": "operverterbar",
    "opetade": "opetad",
    "opetades": "opetad",
    "opetads": "opetad",
    "opetat": "opetad",
    "opetats": "opetad",
    "opetrifierade": "opetrifierad",
    "opetrifierades": "opetrifierad",
    "opetrifierads": "opetrifierad",
    "opetrifierat": "opetrifierad",
    "opetrifierats": "opetrifierad",
    "opetrifierbara": "opetrifierbar",
    "opetrifierbarare": "opetrifierbar",
    "opetrifierbarares": "opetrifierbar",
    "opetrifierbaras": "opetrifierbar",
    "opetrifierbarast": "opetrifierbar",
    "opetrifierbaraste": "opetrifierbar",
    "opetrifierbarastes": "opetrifierbar",
    "opetrifierbarasts": "opetrifierbar",
    "opetrifierbare": "opetrifierbar",
    "opetrifierbares": "opetrifierbar",
    "opetrifierbarheten": "opetrifierbarhet",
    "opetrifierbarhetens": "opetrifierbarhet",
    "opetrifierbarhets": "opetrifierbarhet",
    "opetrifierbars": "opetrifierbar",
    "opetrifierbart": "opetrifierbar",
    "opetrifierbarts": "opetrifierbar",
    "opiaten": "opiat",
    "opiatens": "opiat",
    "opiater": "opiat",
    "opiaterna": "opiat",
    "opiaternas": "opiat",
    "opiaters": "opiat",
    "opiatet": "opiat",
    "opiatets": "opiat",
    "opiats": "opiat",
    "opickade": "opickad",
    "opickades": "opickad",
    "opickads": "opickad",
    "opickat": "opickad",
    "opickats": "opickad",
    "opiet": "opium",
    "opiets": "opium",
    "opikade": "opikad",
    "opikades": "opikad",
    "opikads": "opikad",
    "opikat": "opikad",
    "opikats": "opikad",
    "opikerade": "opikerad",
    "opikerades": "opikerad",
    "opikerads": "opikerad",
    "opikerat": "opikerad",
    "opikerats": "opikerad",
    "opikerbara": "opikerbar",
    "opikerbarare": "opikerbar",
    "opikerbarares": "opikerbar",
    "opikerbaras": "opikerbar",
    "opikerbarast": "opikerbar",
    "opikerbaraste": "opikerbar",
    "opikerbarastes": "opikerbar",
    "opikerbarasts": "opikerbar",
    "opikerbare": "opikerbar",
    "opikerbares": "opikerbar",
    "opikerbarheten": "opikerbarhet",
    "opikerbarhetens": "opikerbarhet",
    "opikerbarhets": "opikerbarhet",
    "opikerbars": "opikerbar",
    "opikerbart": "opikerbar",
    "opikerbarts": "opikerbar",
    "opilkade": "opilkad",
    "opilkades": "opilkad",
    "opilkads": "opilkad",
    "opilkat": "opilkad",
    "opilkats": "opilkad",
    "opimpade": "opimpad",
    "opimpades": "opimpad",
    "opimpads": "opimpad",
    "opimpat": "opimpad",
    "opimpats": "opimpad",
    "opimplade": "opimplad",
    "opimplades": "opimplad",
    "opimplads": "opimplad",
    "opimplat": "opimplad",
    "opimplats": "opimplad",
    "opinade": "opinad",
    "opinades": "opinad",
    "opinads": "opinad",
    "opinat": "opinad",
    "opinats": "opinad",
    "opincerade": "opincerad",
    "opincerades": "opincerad",
    "opincerads": "opincerad",
    "opincerat": "opincerad",
    "opincerats": "opincerad",
    "opincerbara": "opincerbar",
    "opincerbarare": "opincerbar",
    "opincerbarares": "opincerbar",
    "opincerbaras": "opincerbar",
    "opincerbarast": "opincerbar",
    "opincerbaraste": "opincerbar",
    "opincerbarastes": "opincerbar",
    "opincerbarasts": "opincerbar",
    "opincerbare": "opincerbar",
    "opincerbares": "opincerbar",
    "opincerbarheten": "opincerbarhet",
    "opincerbarhetens": "opincerbarhet",
    "opincerbarhets": "opincerbarhet",
    "opincerbars": "opincerbar",
    "opincerbart": "opincerbar",
    "opincerbarts": "opincerbar",
    "opinerade": "opinera",
    "opinerades": "opinera",
    "opinerande": "opinera",
    "opineranden": "opinerande",
    "opinerandena": "opinerande",
    "opinerandenas": "opinerande",
    "opinerandens": "opinerande",
    "opinerandes": "opinerande",
    "opinerandet": "opinerande",
    "opinerandets": "opinerande",
    "opinerar": "opinera",
    "opineras": "opinera",
    "opinerat": "opinera",
    "opinerats": "opinera",
    "opineringar": "opinering",
    "opineringarna": "opinering",
    "opineringarnas": "opinering",
    "opineringars": "opinering",
    "opineringen": "opinering",
    "opineringens": "opinering",
    "opinerings": "opinering",
    "opinionen": "opinion",
    "opinionens": "opinion",
    "opinioner": "opinion",
    "opinionerna": "opinion",
    "opinionernas": "opinion",
    "opinioners": "opinion",
    "opinions": "opinion",
    "opinionsbildar": "opinionsbildare",
    "opinionsbildaren": "opinionsbildare",
    "opinionsbildarens": "opinionsbildare",
    "opinionsbildares": "opinionsbildare",
    "opinionsbildarna": "opinionsbildare",
    "opinionsbildarnas": "opinionsbildare",
    "opinionsbildningar": "opinionsbildning",
    "opinionsbildningarna": "opinionsbildning",
    "opinionsbildningarnas": "opinionsbildning",
    "opinionsbildningars": "opinionsbildning",
    "opinionsbildningen": "opinionsbildning",
    "opinionsbildningens": "opinionsbildning",
    "opinionsbildnings": "opinionsbildning",
    "opinionsmässiga": "opinionsmässig",
    "opinionsmässigare": "opinionsmässig",
    "opinionsmässigares": "opinionsmässig",
    "opinionsmässigas": "opinionsmässig",
    "opinionsmässigast": "opinionsmässig",
    "opinionsmässigaste": "opinionsmässig",
    "opinionsmässigastes": "opinionsmässig",
    "opinionsmässigasts": "opinionsmässig",
    "opinionsmässige": "opinionsmässig",
    "opinionsmässiges": "opinionsmässig",
    "opinionsmässigs": "opinionsmässig",
    "opinionsmässigt": "opinionsmässig",
    "opinionsmässigts": "opinionsmässig",
    "opinionsmätningar": "opinionsmätning",
    "opinionsmätningarna": "opinionsmätning",
    "opinionsmätningarnas": "opinionsmätning",
    "opinionsmätningars": "opinionsmätning",
    "opinionsmätningen": "opinionsmätning",
    "opinionsmätningens": "opinionsmätning",
    "opinionsmätnings": "opinionsmätning",
    "opinionsnämnden": "opinionsnämnd",
    "opinionsnämndens": "opinionsnämnd",
    "opinionsnämnder": "opinionsnämnd",
    "opinionsnämnderna": "opinionsnämnd",
    "opinionsnämndernas": "opinionsnämnd",
    "opinionsnämnders": "opinionsnämnd",
    "opinionsnämnds": "opinionsnämnd",
    "opinionsorganen": "opinionsorgan",
    "opinionsorganens": "opinionsorgan",
    "opinionsorganet": "opinionsorgan",
    "opinionsorganets": "opinionsorgan",
    "opinionsorgans": "opinionsorgan",
    "opinionssiffer": "opinionssiffra",
    "opinionssiffran": "opinionssiffra",
    "opinionssiffrans": "opinionssiffra",
    "opinionssiffras": "opinionssiffra",
    "opinionssiffre": "opinionssiffra",
    "opinionssiffror": "opinionssiffra",
    "opinionssiffrorna": "opinionssiffra",
    "opinionssiffrornas": "opinionssiffra",
    "opinionssiffrors": "opinionssiffra",
    "opinionssvängningar": "opinionssvängning",
    "opinionssvängningarna": "opinionssvängning",
    "opinionssvängningarnas": "opinionssvängning",
    "opinionssvängningars": "opinionssvängning",
    "opinionssvängningen": "opinionssvängning",
    "opinionssvängningens": "opinionssvängning",
    "opinionssvängnings": "opinionssvängning",
    "opinionsundersökningar": "opinionsundersökning",
    "opinionsundersökningarna": "opinionsundersökning",
    "opinionsundersökningarnas": "opinionsundersökning",
    "opinionsundersökningars": "opinionsundersökning",
    "opinionsundersökningen": "opinionsundersökning",
    "opinionsundersökningens": "opinionsundersökning",
    "opinionsundersöknings": "opinionsundersökning",
    "opinionsyttringar": "opinionsyttring",
    "opinionsyttringarna": "opinionsyttring",
    "opinionsyttringarnas": "opinionsyttring",
    "opinionsyttringars": "opinionsyttring",
    "opinionsyttringen": "opinionsyttring",
    "opinionsyttringens": "opinionsyttring",
    "opinionsyttrings": "opinionsyttring",
    "opinnade": "opinnad",
    "opinnades": "opinnad",
    "opinnads": "opinnad",
    "opinnat": "opinnad",
    "opinnats": "opinnad",
    "opippade": "opippad",
    "opippades": "opippad",
    "opippads": "opippad",
    "opippat": "opippad",
    "opippats": "opippad",
    "opirkade": "opirkad",
    "opirkades": "opirkad",
    "opirkads": "opirkad",
    "opirkat": "opirkad",
    "opirkats": "opirkad",
    "opiskade": "opiskad",
    "opiskades": "opiskad",
    "opiskads": "opiskad",
    "opiskat": "opiskad",
    "opiskats": "opiskad",
    "opiumet": "opium",
    "opiumets": "opium",
    "opiumhandeln": "opiumhandel",
    "opiumhandelns": "opiumhandel",
    "opiumhandels": "opiumhandel",
    "opiumhärvan": "opiumhärva",
    "opiumhärvans": "opiumhärva",
    "opiumhärvas": "opiumhärva",
    "opiumhärve": "opiumhärva",
    "opiumhärvor": "opiumhärva",
    "opiumhärvorna": "opiumhärva",
    "opiumhärvornas": "opiumhärva",
    "opiumhärvors": "opiumhärva",
    "opiumhålan": "opiumhåla",
    "opiumhålans": "opiumhåla",
    "opiumhålas": "opiumhåla",
    "opiumhåle": "opiumhåla",
    "opiumhålor": "opiumhåla",
    "opiumhålorna": "opiumhåla",
    "opiumhålornas": "opiumhåla",
    "opiumhålors": "opiumhåla",
    "opiumpip": "opiumpipa",
    "opiumpipan": "opiumpipa",
    "opiumpipans": "opiumpipa",
    "opiumpipas": "opiumpipa",
    "opiumpipe": "opiumpipa",
    "opiumpipor": "opiumpipa",
    "opiumpiporna": "opiumpipa",
    "opiumpipornas": "opiumpipa",
    "opiumpipors": "opiumpipa",
    "opiumpips": "opiumpipa",
    "opiumrökningen": "opiumrökning",
    "opiumrökningens": "opiumrökning",
    "opiumröknings": "opiumrökning",
    "opiums": "opium",
    "opkonsten": "opkonst",
    "opkonstens": "opkonst",
    "opkonsts": "opkonst",
    "oplacerade": "oplacerad",
    "oplacerades": "oplacerad",
    "oplacerads": "oplacerad",
    "oplacerat": "oplacerad",
    "oplacerats": "oplacerad",
    "oplacerbara": "oplacerbar",
    "oplacerbarare": "oplacerbar",
    "oplacerbarares": "oplacerbar",
    "oplacerbaras": "oplacerbar",
    "oplacerbarast": "oplacerbar",
    "oplacerbaraste": "oplacerbar",
    "oplacerbarastes": "oplacerbar",
    "oplacerbarasts": "oplacerbar",
    "oplacerbare": "oplacerbar",
    "oplacerbares": "oplacerbar",
    "oplacerbarheten": "oplacerbarhet",
    "oplacerbarhetens": "oplacerbarhet",
    "oplacerbarhets": "oplacerbarhet",
    "oplacerbars": "oplacerbar",
    "oplacerbart": "oplacerbar",
    "oplacerbarts": "oplacerbar",
    "oplagierade": "oplagierad",
    "oplagierades": "oplagierad",
    "oplagierads": "oplagierad",
    "oplagierat": "oplagierad",
    "oplagierats": "oplagierad",
    "oplagierbara": "oplagierbar",
    "oplagierbarare": "oplagierbar",
    "oplagierbarares": "oplagierbar",
    "oplagierbaras": "oplagierbar",
    "oplagierbarast": "oplagierbar",
    "oplagierbaraste": "oplagierbar",
    "oplagierbarastes": "oplagierbar",
    "oplagierbarasts": "oplagierbar",
    "oplagierbare": "oplagierbar",
    "oplagierbares": "oplagierbar",
    "oplagierbarheten": "oplagierbarhet",
    "oplagierbarhetens": "oplagierbarhet",
    "oplagierbarhets": "oplagierbarhet",
    "oplagierbars": "oplagierbar",
    "oplagierbart": "oplagierbar",
    "oplagierbarts": "oplagierbar",
    "oplanade": "oplanad",
    "oplanades": "oplanad",
    "oplanads": "oplanad",
    "oplanat": "oplanad",
    "oplanats": "oplanad",
    "oplanerade": "oplanerad",
    "oplanerades": "oplanerad",
    "oplanerads": "oplanerad",
    "oplanerat": "oplanerad",
    "oplanerats": "oplanerad",
    "oplanerbara": "oplanerbar",
    "oplanerbarare": "oplanerbar",
    "oplanerbarares": "oplanerbar",
    "oplanerbaras": "oplanerbar",
    "oplanerbarast": "oplanerbar",
    "oplanerbaraste": "oplanerbar",
    "oplanerbarastes": "oplanerbar",
    "oplanerbarasts": "oplanerbar",
    "oplanerbare": "oplanerbar",
    "oplanerbares": "oplanerbar",
    "oplanerbarheten": "oplanerbarhet",
    "oplanerbarhetens": "oplanerbarhet",
    "oplanerbarhets": "oplanerbarhet",
    "oplanerbars": "oplanerbar",
    "oplanerbart": "oplanerbar",
    "oplanerbarts": "oplanerbar",
    "oplankade": "oplankad",
    "oplankades": "oplankad",
    "oplankads": "oplankad",
    "oplankat": "oplankad",
    "oplankats": "oplankad",
    "oplantade": "oplantad",
    "oplantades": "oplantad",
    "oplantads": "oplantad",
    "oplantat": "oplantad",
    "oplantats": "oplantad",
    "oplanterade": "oplanterad",
    "oplanterades": "oplanterad",
    "oplanterads": "oplanterad",
    "oplanterat": "oplanterad",
    "oplanterats": "oplanterad",
    "oplanterbara": "oplanterbar",
    "oplanterbarare": "oplanterbar",
    "oplanterbarares": "oplanterbar",
    "oplanterbaras": "oplanterbar",
    "oplanterbarast": "oplanterbar",
    "oplanterbaraste": "oplanterbar",
    "oplanterbarastes": "oplanterbar",
    "oplanterbarasts": "oplanterbar",
    "oplanterbare": "oplanterbar",
    "oplanterbares": "oplanterbar",
    "oplanterbarheten": "oplanterbarhet",
    "oplanterbarhetens": "oplanterbarhet",
    "oplanterbarhets": "oplanterbarhet",
    "oplanterbars": "oplanterbar",
    "oplanterbart": "oplanterbar",
    "oplanterbarts": "oplanterbar",
    "oplastade": "oplastad",
    "oplastades": "oplastad",
    "oplastads": "oplastad",
    "oplastat": "oplastad",
    "oplastats": "oplastad",
    "oplatinerade": "oplatinerad",
    "oplatinerades": "oplatinerad",
    "oplatinerads": "oplatinerad",
    "oplatinerat": "oplatinerad",
    "oplatinerats": "oplatinerad",
    "oplatinerbara": "oplatinerbar",
    "oplatinerbarare": "oplatinerbar",
    "oplatinerbarares": "oplatinerbar",
    "oplatinerbaras": "oplatinerbar",
    "oplatinerbarast": "oplatinerbar",
    "oplatinerbaraste": "oplatinerbar",
    "oplatinerbarastes": "oplatinerbar",
    "oplatinerbarasts": "oplatinerbar",
    "oplatinerbare": "oplatinerbar",
    "oplatinerbares": "oplatinerbar",
    "oplatinerbarheten": "oplatinerbarhet",
    "oplatinerbarhetens": "oplatinerbarhet",
    "oplatinerbarhets": "oplatinerbarhet",
    "oplatinerbars": "oplatinerbar",
    "oplatinerbart": "oplatinerbar",
    "oplatinerbarts": "oplatinerbar",
    "opliggade": "opliggad",
    "opliggades": "opliggad",
    "opliggads": "opliggad",
    "opliggat": "opliggad",
    "opliggats": "opliggad",
    "oplisserade": "oplisserad",
    "oplisserades": "oplisserad",
    "oplisserads": "oplisserad",
    "oplisserat": "oplisserad",
    "oplisserats": "oplisserad",
    "oplisserbara": "oplisserbar",
    "oplisserbarare": "oplisserbar",
    "oplisserbarares": "oplisserbar",
    "oplisserbaras": "oplisserbar",
    "oplisserbarast": "oplisserbar",
    "oplisserbaraste": "oplisserbar",
    "oplisserbarastes": "oplisserbar",
    "oplisserbarasts": "oplisserbar",
    "oplisserbare": "oplisserbar",
    "oplisserbares": "oplisserbar",
    "oplisserbarheten": "oplisserbarhet",
    "oplisserbarhetens": "oplisserbarhet",
    "oplisserbarhets": "oplisserbarhet",
    "oplisserbars": "oplisserbar",
    "oplisserbart": "oplisserbar",
    "oplisserbarts": "oplisserbar",
    "oplockade": "oplockad",
    "oplockades": "oplockad",
    "oplockads": "oplockad",
    "oplockat": "oplockad",
    "oplockats": "oplockad",
    "oplogade": "oplogad",
    "oplogades": "oplogad",
    "oplogads": "oplogad",
    "oplogat": "oplogad",
    "oplogats": "oplogad",
    "oplomberade": "oplomberad",
    "oplomberades": "oplomberad",
    "oplomberads": "oplomberad",
    "oplomberat": "oplomberad",
    "oplomberats": "oplomberad",
    "oplomberbara": "oplomberbar",
    "oplomberbarare": "oplomberbar",
    "oplomberbarares": "oplomberbar",
    "oplomberbaras": "oplomberbar",
    "oplomberbarast": "oplomberbar",
    "oplomberbaraste": "oplomberbar",
    "oplomberbarastes": "oplomberbar",
    "oplomberbarasts": "oplomberbar",
    "oplomberbare": "oplomberbar",
    "oplomberbares": "oplomberbar",
    "oplomberbarheten": "oplomberbarhet",
    "oplomberbarhetens": "oplomberbarhet",
    "oplomberbarhets": "oplomberbarhet",
    "oplomberbars": "oplomberbar",
    "oplomberbart": "oplomberbar",
    "oplomberbarts": "oplomberbar",
    "oplottade": "oplottad",
    "oplottades": "oplottad",
    "oplottads": "oplottad",
    "oplottat": "oplottad",
    "oplottats": "oplottad",
    "opluggade": "opluggad",
    "opluggades": "opluggad",
    "opluggads": "opluggad",
    "opluggat": "opluggad",
    "opluggats": "opluggad",
    "oplundrade": "oplundrad",
    "oplundrades": "oplundrad",
    "oplundrads": "oplundrad",
    "oplundrat": "oplundrad",
    "oplundrats": "oplundrad",
    "oplysade": "oplysad",
    "oplysades": "oplysad",
    "oplysads": "oplysad",
    "oplysat": "oplysad",
    "oplysats": "oplysad",
    "opläterade": "opläterad",
    "opläterades": "opläterad",
    "opläterads": "opläterad",
    "opläterat": "opläterad",
    "opläterats": "opläterad",
    "opläterbara": "opläterbar",
    "opläterbarare": "opläterbar",
    "opläterbarares": "opläterbar",
    "opläterbaras": "opläterbar",
    "opläterbarast": "opläterbar",
    "opläterbaraste": "opläterbar",
    "opläterbarastes": "opläterbar",
    "opläterbarasts": "opläterbar",
    "opläterbare": "opläterbar",
    "opläterbares": "opläterbar",
    "opläterbarheten": "opläterbarhet",
    "opläterbarhetens": "opläterbarhet",
    "opläterbarhets": "opläterbarhet",
    "opläterbars": "opläterbar",
    "opläterbart": "opläterbar",
    "opläterbarts": "opläterbar",
    "oplåstrade": "oplåstrad",
    "oplåstrades": "oplåstrad",
    "oplåstrads": "oplåstrad",
    "oplåstrat": "oplåstrad",
    "oplåstrats": "oplåstrad",
    "oplåtade": "oplåtad",
    "oplåtades": "oplåtad",
    "oplåtads": "oplåtad",
    "oplåtat": "oplåtad",
    "oplåtats": "oplåtad",
    "oplöjde": "oplöjd",
    "oplöjdes": "oplöjd",
    "oplöjds": "oplöjd",
    "oplöjt": "oplöjd",
    "oplöjts": "oplöjd",
    "opocherade": "opocherad",
    "opocherades": "opocherad",
    "opocherads": "opocherad",
    "opocherat": "opocherad",
    "opocherats": "opocherad",
    "opocherbara": "opocherbar",
    "opocherbarare": "opocherbar",
    "opocherbarares": "opocherbar",
    "opocherbaras": "opocherbar",
    "opocherbarast": "opocherbar",
    "opocherbaraste": "opocherbar",
    "opocherbarastes": "opocherbar",
    "opocherbarasts": "opocherbar",
    "opocherbare": "opocherbar",
    "opocherbares": "opocherbar",
    "opocherbarheten": "opocherbarhet",
    "opocherbarhetens": "opocherbarhet",
    "opocherbarhets": "opocherbarhet",
    "opocherbars": "opocherbar",
    "opocherbart": "opocherbar",
    "opocherbarts": "opocherbar",
    "opointerade": "opointerad",
    "opointerades": "opointerad",
    "opointerads": "opointerad",
    "opointerat": "opointerad",
    "opointerats": "opointerad",
    "opointerbara": "opointerbar",
    "opointerbarare": "opointerbar",
    "opointerbarares": "opointerbar",
    "opointerbaras": "opointerbar",
    "opointerbarast": "opointerbar",
    "opointerbaraste": "opointerbar",
    "opointerbarastes": "opointerbar",
    "opointerbarasts": "opointerbar",
    "opointerbare": "opointerbar",
    "opointerbares": "opointerbar",
    "opointerbarheten": "opointerbarhet",
    "opointerbarhetens": "opointerbarhet",
    "opointerbarhets": "opointerbarhet",
    "opointerbars": "opointerbar",
    "opointerbart": "opointerbar",
    "opointerbarts": "opointerbar",
    "opolariserade": "opolariserad",
    "opolariserades": "opolariserad",
    "opolariserads": "opolariserad",
    "opolariserat": "opolariserad",
    "opolariserats": "opolariserad",
    "opolariserbara": "opolariserbar",
    "opolariserbarare": "opolariserbar",
    "opolariserbarares": "opolariserbar",
    "opolariserbaras": "opolariserbar",
    "opolariserbarast": "opolariserbar",
    "opolariserbaraste": "opolariserbar",
    "opolariserbarastes": "opolariserbar",
    "opolariserbarasts": "opolariserbar",
    "opolariserbare": "opolariserbar",
    "opolariserbares": "opolariserbar",
    "opolariserbarheten": "opolariserbarhet",
    "opolariserbarhetens": "opolariserbarhet",
    "opolariserbarhets": "opolariserbarhet",
    "opolariserbars": "opolariserbar",
    "opolariserbart": "opolariserbar",
    "opolariserbarts": "opolariserbar",
    "opolerade": "opolerad",
    "opolerades": "opolerad",
    "opolerads": "opolerad",
    "opolerat": "opolerad",
    "opolerats": "opolerad",
    "opolerbara": "opolerbar",
    "opolerbarare": "opolerbar",
    "opolerbarares": "opolerbar",
    "opolerbaras": "opolerbar",
    "opolerbarast": "opolerbar",
    "opolerbaraste": "opolerbar",
    "opolerbarastes": "opolerbar",
    "opolerbarasts": "opolerbar",
    "opolerbare": "opolerbar",
    "opolerbares": "opolerbar",
    "opolerbarheten": "opolerbarhet",
    "opolerbarhetens": "opolerbarhet",
    "opolerbarhets": "opolerbarhet",
    "opolerbars": "opolerbar",
    "opolerbart": "opolerbar",
    "opolerbarts": "opolerbar",
    "opolitiserade": "opolitiserad",
    "opolitiserades": "opolitiserad",
    "opolitiserads": "opolitiserad",
    "opolitiserat": "opolitiserad",
    "opolitiserats": "opolitiserad",
    "opolitiserbara": "opolitiserbar",
    "opolitiserbarare": "opolitiserbar",
    "opolitiserbarares": "opolitiserbar",
    "opolitiserbaras": "opolitiserbar",
    "opolitiserbarast": "opolitiserbar",
    "opolitiserbaraste": "opolitiserbar",
    "opolitiserbarastes": "opolitiserbar",
    "opolitiserbarasts": "opolitiserbar",
    "opolitiserbare": "opolitiserbar",
    "opolitiserbares": "opolitiserbar",
    "opolitiserbarheten": "opolitiserbarhet",
    "opolitiserbarhetens": "opolitiserbarhet",
    "opolitiserbarhets": "opolitiserbarhet",
    "opolitiserbars": "opolitiserbar",
    "opolitiserbart": "opolitiserbar",
    "opolitiserbarts": "opolitiserbar",
    "opolitiska": "opolitisk",
    "opolitiskare": "opolitisk",
    "opolitiskares": "opolitisk",
    "opolitiskas": "opolitisk",
    "opolitiskast": "opolitisk",
    "opolitiskaste": "opolitisk",
    "opolitiskastes": "opolitisk",
    "opolitiskasts": "opolitisk",
    "opolitiske": "opolitisk",
    "opolitiskes": "opolitisk",
    "opolitisks": "opolitisk",
    "opolitiskt": "opolitisk",
    "opolitiskts": "opolitisk",
    "opolletterade": "opolletterad",
    "opolletterades": "opolletterad",
    "opolletterads": "opolletterad",
    "opolletterat": "opolletterad",
    "opolletterats": "opolletterad",
    "opolletterbara": "opolletterbar",
    "opolletterbarare": "opolletterbar",
    "opolletterbarares": "opolletterbar",
    "opolletterbaras": "opolletterbar",
    "opolletterbarast": "opolletterbar",
    "opolletterbaraste": "opolletterbar",
    "opolletterbarastes": "opolletterbar",
    "opolletterbarasts": "opolletterbar",
    "opolletterbare": "opolletterbar",
    "opolletterbares": "opolletterbar",
    "opolletterbarheten": "opolletterbarhet",
    "opolletterbarhetens": "opolletterbarhet",
    "opolletterbarhets": "opolletterbarhet",
    "opolletterbars": "opolletterbar",
    "opolletterbart": "opolletterbar",
    "opolletterbarts": "opolletterbar",
    "opollinerade": "opollinerad",
    "opollinerades": "opollinerad",
    "opollinerads": "opollinerad",
    "opollinerat": "opollinerad",
    "opollinerats": "opollinerad",
    "opollinerbara": "opollinerbar",
    "opollinerbarare": "opollinerbar",
    "opollinerbarares": "opollinerbar",
    "opollinerbaras": "opollinerbar",
    "opollinerbarast": "opollinerbar",
    "opollinerbaraste": "opollinerbar",
    "opollinerbarastes": "opollinerbar",
    "opollinerbarasts": "opollinerbar",
    "opollinerbare": "opollinerbar",
    "opollinerbares": "opollinerbar",
    "opollinerbarheten": "opollinerbarhet",
    "opollinerbarhetens": "opollinerbarhet",
    "opollinerbarhets": "opollinerbarhet",
    "opollinerbars": "opollinerbar",
    "opollinerbart": "opollinerbar",
    "opollinerbarts": "opollinerbar",
    "opolstrade": "opolstrad",
    "opolstrades": "opolstrad",
    "opolstrads": "opolstrad",
    "opolstrat": "opolstrad",
    "opolstrats": "opolstrad",
    "opomaderade": "opomaderad",
    "opomaderades": "opomaderad",
    "opomaderads": "opomaderad",
    "opomaderat": "opomaderad",
    "opomaderats": "opomaderad",
    "opomaderbara": "opomaderbar",
    "opomaderbarare": "opomaderbar",
    "opomaderbarares": "opomaderbar",
    "opomaderbaras": "opomaderbar",
    "opomaderbarast": "opomaderbar",
    "opomaderbaraste": "opomaderbar",
    "opomaderbarastes": "opomaderbar",
    "opomaderbarasts": "opomaderbar",
    "opomaderbare": "opomaderbar",
    "opomaderbares": "opomaderbar",
    "opomaderbarheten": "opomaderbarhet",
    "opomaderbarhetens": "opomaderbarhet",
    "opomaderbarhets": "opomaderbarhet",
    "opomaderbars": "opomaderbar",
    "opomaderbart": "opomaderbar",
    "opomaderbarts": "opomaderbar",
    "opoppade": "opoppad",
    "opoppades": "opoppad",
    "opoppads": "opoppad",
    "opoppat": "opoppad",
    "opoppats": "opoppad",
    "opopulariserade": "opopulariserad",
    "opopulariserades": "opopulariserad",
    "opopulariserads": "opopulariserad",
    "opopulariserat": "opopulariserad",
    "opopulariserats": "opopulariserad",
    "opopulariserbara": "opopulariserbar",
    "opopulariserbarare": "opopulariserbar",
    "opopulariserbarares": "opopulariserbar",
    "opopulariserbaras": "opopulariserbar",
    "opopulariserbarast": "opopulariserbar",
    "opopulariserbaraste": "opopulariserbar",
    "opopulariserbarastes": "opopulariserbar",
    "opopulariserbarasts": "opopulariserbar",
    "opopulariserbare": "opopulariserbar",
    "opopulariserbares": "opopulariserbar",
    "opopulariserbarheten": "opopulariserbarhet",
    "opopulariserbarhetens": "opopulariserbarhet",
    "opopulariserbarhets": "opopulariserbarhet",
    "opopulariserbars": "opopulariserbar",
    "opopulariserbart": "opopulariserbar",
    "opopulariserbarts": "opopulariserbar",
    "oportade": "oportad",
    "oportades": "oportad",
    "oportads": "oportad",
    "oportat": "oportad",
    "oportats": "oportad",
    "oportionerade": "oportionerad",
    "oportionerades": "oportionerad",
    "oportionerads": "oportionerad",
    "oportionerat": "oportionerad",
    "oportionerats": "oportionerad",
    "oportionerbara": "oportionerbar",
    "oportionerbarare": "oportionerbar",
    "oportionerbarares": "oportionerbar",
    "oportionerbaras": "oportionerbar",
    "oportionerbarast": "oportionerbar",
    "oportionerbaraste": "oportionerbar",
    "oportionerbarastes": "oportionerbar",
    "oportionerbarasts": "oportionerbar",
    "oportionerbare": "oportionerbar",
    "oportionerbares": "oportionerbar",
    "oportionerbarheten": "oportionerbarhet",
    "oportionerbarhetens": "oportionerbarhet",
    "oportionerbarhets": "oportionerbarhet",
    "oportionerbars": "oportionerbar",
    "oportionerbart": "oportionerbar",
    "oportionerbarts": "oportionerbar",
    "oporträtterade": "oporträtterad",
    "oporträtterades": "oporträtterad",
    "oporträtterads": "oporträtterad",
    "oporträtterat": "oporträtterad",
    "oporträtterats": "oporträtterad",
    "oporträtterbara": "oporträtterbar",
    "oporträtterbarare": "oporträtterbar",
    "oporträtterbarares": "oporträtterbar",
    "oporträtterbaras": "oporträtterbar",
    "oporträtterbarast": "oporträtterbar",
    "oporträtterbaraste": "oporträtterbar",
    "oporträtterbarastes": "oporträtterbar",
    "oporträtterbarasts": "oporträtterbar",
    "oporträtterbare": "oporträtterbar",
    "oporträtterbares": "oporträtterbar",
    "oporträtterbarheten": "oporträtterbarhet",
    "oporträtterbarhetens": "oporträtterbarhet",
    "oporträtterbarhets": "oporträtterbarhet",
    "oporträtterbars": "oporträtterbar",
    "oporträtterbart": "oporträtterbar",
    "oporträtterbarts": "oporträtterbar",
    "opossumar": "opossum",
    "opossumarna": "opossum",
    "opossumarnas": "opossum",
    "opossumars": "opossum",
    "opossumen": "opossum",
    "opossumens": "opossum",
    "opossums": "opossum",
    "opostade": "opostad",
    "opostades": "opostad",
    "opostads": "opostad",
    "opostat": "opostad",
    "opostats": "opostad",
    "opostdaterade": "opostdaterad",
    "opostdaterades": "opostdaterad",
    "opostdaterads": "opostdaterad",
    "opostdaterat": "opostdaterad",
    "opostdaterats": "opostdaterad",
    "opostdaterbara": "opostdaterbar",
    "opostdaterbarare": "opostdaterbar",
    "opostdaterbarares": "opostdaterbar",
    "opostdaterbaras": "opostdaterbar",
    "opostdaterbarast": "opostdaterbar",
    "opostdaterbaraste": "opostdaterbar",
    "opostdaterbarastes": "opostdaterbar",
    "opostdaterbarasts": "opostdaterbar",
    "opostdaterbare": "opostdaterbar",
    "opostdaterbares": "opostdaterbar",
    "opostdaterbarheten": "opostdaterbarhet",
    "opostdaterbarhetens": "opostdaterbarhet",
    "opostdaterbarhets": "opostdaterbarhet",
    "opostdaterbars": "opostdaterbar",
    "opostdaterbart": "opostdaterbar",
    "opostdaterbarts": "opostdaterbar",
    "oposterade": "oposterad",
    "oposterades": "oposterad",
    "oposterads": "oposterad",
    "oposterat": "oposterad",
    "oposterats": "oposterad",
    "oposterbara": "oposterbar",
    "oposterbarare": "oposterbar",
    "oposterbarares": "oposterbar",
    "oposterbaras": "oposterbar",
    "oposterbarast": "oposterbar",
    "oposterbaraste": "oposterbar",
    "oposterbarastes": "oposterbar",
    "oposterbarasts": "oposterbar",
    "oposterbare": "oposterbar",
    "oposterbares": "oposterbar",
    "oposterbarheten": "oposterbarhet",
    "oposterbarhetens": "oposterbarhet",
    "oposterbarhets": "oposterbarhet",
    "oposterbars": "oposterbar",
    "oposterbart": "oposterbar",
    "oposterbarts": "oposterbar",
    "opostponerade": "opostponerad",
    "opostponerades": "opostponerad",
    "opostponerads": "opostponerad",
    "opostponerat": "opostponerad",
    "opostponerats": "opostponerad",
    "opostponerbara": "opostponerbar",
    "opostponerbarare": "opostponerbar",
    "opostponerbarares": "opostponerbar",
    "opostponerbaras": "opostponerbar",
    "opostponerbarast": "opostponerbar",
    "opostponerbaraste": "opostponerbar",
    "opostponerbarastes": "opostponerbar",
    "opostponerbarasts": "opostponerbar",
    "opostponerbare": "opostponerbar",
    "opostponerbares": "opostponerbar",
    "opostponerbarheten": "opostponerbarhet",
    "opostponerbarhetens": "opostponerbarhet",
    "opostponerbarhets": "opostponerbarhet",
    "opostponerbars": "opostponerbar",
    "opostponerbart": "opostponerbar",
    "opostponerbarts": "opostponerbar",
    "opostulerade": "opostulerad",
    "opostulerades": "opostulerad",
    "opostulerads": "opostulerad",
    "opostulerat": "opostulerad",
    "opostulerats": "opostulerad",
    "opostulerbara": "opostulerbar",
    "opostulerbarare": "opostulerbar",
    "opostulerbarares": "opostulerbar",
    "opostulerbaras": "opostulerbar",
    "opostulerbarast": "opostulerbar",
    "opostulerbaraste": "opostulerbar",
    "opostulerbarastes": "opostulerbar",
    "opostulerbarasts": "opostulerbar",
    "opostulerbare": "opostulerbar",
    "opostulerbares": "opostulerbar",
    "opostulerbarheten": "opostulerbarhet",
    "opostulerbarhetens": "opostulerbarhet",
    "opostulerbarhets": "opostulerbarhet",
    "opostulerbars": "opostulerbar",
    "opostulerbart": "opostulerbar",
    "opostulerbarts": "opostulerbar",
    "opoängterade": "opoängterad",
    "opoängterades": "opoängterad",
    "opoängterads": "opoängterad",
    "opoängterat": "opoängterad",
    "opoängterats": "opoängterad",
    "opoängterbara": "opoängterbar",
    "opoängterbarare": "opoängterbar",
    "opoängterbarares": "opoängterbar",
    "opoängterbaras": "opoängterbar",
    "opoängterbarast": "opoängterbar",
    "opoängterbaraste": "opoängterbar",
    "opoängterbarastes": "opoängterbar",
    "opoängterbarasts": "opoängterbar",
    "opoängterbare": "opoängterbar",
    "opoängterbares": "opoängterbar",
    "opoängterbarheten": "opoängterbarhet",
    "opoängterbarhetens": "opoängterbarhet",
    "opoängterbarhets": "opoängterbarhet",
    "opoängterbars": "opoängterbar",
    "opoängterbart": "opoängterbar",
    "opoängterbarts": "opoängterbar",
    "oppammad": "oppamma",
    "oppammade": "oppamma",
    "oppammades": "oppamma",
    "oppammads": "oppamma",
    "oppammande": "oppamma",
    "oppammanden": "oppammande",
    "oppammandena": "oppammande",
    "oppammandenas": "oppammande",
    "oppammandens": "oppammande",
    "oppammandes": "oppammande",
    "oppammandet": "oppammande",
    "oppammandets": "oppammande",
    "oppammar": "oppamma",
    "oppammas": "oppamma",
    "oppammat": "oppamma",
    "oppammats": "oppamma",
    "opparbet": "opparbeta",
    "opparbetad": "opparbeta",
    "opparbetade": "opparbeta",
    "opparbetades": "opparbeta",
    "opparbetads": "opparbeta",
    "opparbetande": "opparbeta",
    "opparbetanden": "opparbetande",
    "opparbetandena": "opparbetande",
    "opparbetandenas": "opparbetande",
    "opparbetandens": "opparbetande",
    "opparbetandes": "opparbetande",
    "opparbetandet": "opparbetande",
    "opparbetandets": "opparbetande",
    "opparbetar": "opparbeta",
    "opparbetas": "opparbeta",
    "opparbetat": "opparbeta",
    "opparbetats": "opparbeta",
    "opparbetningar": "opparbetning",
    "opparbetningarna": "opparbetning",
    "opparbetningarnas": "opparbetning",
    "opparbetningars": "opparbetning",
    "opparbetningen": "opparbetning",
    "opparbetningens": "opparbetning",
    "opparbetnings": "opparbetning",
    "oppass": "oppassa",
    "oppassad": "oppassa",
    "oppassade": "oppassa",
    "oppassades": "oppassa",
    "oppassads": "oppassa",
    "oppassande": "oppassa",
    "oppassanden": "oppassande",
    "oppassandena": "oppassande",
    "oppassandenas": "oppassande",
    "oppassandens": "oppassande",
    "oppassandes": "oppassande",
    "oppassandet": "oppassande",
    "oppassandets": "oppassande",
    "oppassar": "oppassare",
    "oppassaren": "oppassare",
    "oppassarens": "oppassare",
    "oppassares": "oppassare",
    "oppassarna": "oppassare",
    "oppassarnas": "oppassare",
    "oppassas": "oppassa",
    "oppassat": "oppassa",
    "oppassats": "oppassa",
    "oppassningar": "oppassning",
    "oppassningarna": "oppassning",
    "oppassningarnas": "oppassning",
    "oppassningars": "oppassning",
    "oppassningen": "oppassning",
    "oppassningens": "oppassning",
    "oppassnings": "oppassning",
    "oppassningsställen": "oppassningsställe",
    "oppassningsställena": "oppassningsställe",
    "oppassningsställenas": "oppassningsställe",
    "oppassningsställens": "oppassningsställe",
    "oppassningsställes": "oppassningsställe",
    "oppassningsstället": "oppassningsställe",
    "oppassningsställets": "oppassningsställe",
    "oppbackar": "oppbackare",
    "oppbackaren": "oppbackare",
    "oppbackarens": "oppbackare",
    "oppbackares": "oppbackare",
    "oppbackarna": "oppbackare",
    "oppbackarnas": "oppbackare",
    "oppbackningar": "oppbackning",
    "oppbackningarna": "oppbackning",
    "oppbackningarnas": "oppbackning",
    "oppbackningars": "oppbackning",
    "oppbackningen": "oppbackning",
    "oppbackningens": "oppbackning",
    "oppbacknings": "oppbackning",
    "oppbar": "oppbära",
    "oppbars": "oppbära",
    "oppbindningar": "oppbindning",
    "oppbindningarna": "oppbindning",
    "oppbindningarnas": "oppbindning",
    "oppbindningars": "oppbindning",
    "oppbindningen": "oppbindning",
    "oppbindningens": "oppbindning",
    "oppbindnings": "oppbindning",
    "oppbland": "oppblanda",
    "oppblandad": "oppblanda",
    "oppblandade": "oppblandad",
    "oppblandades": "oppblandad",
    "oppblandads": "oppblandad",
    "oppblandande": "oppblanda",
    "oppblandanden": "oppblandande",
    "oppblandandena": "oppblandande",
    "oppblandandenas": "oppblandande",
    "oppblandandens": "oppblandande",
    "oppblandandes": "oppblandande",
    "oppblandandet": "oppblandande",
    "oppblandandets": "oppblandande",
    "oppblandar": "oppblanda",
    "oppblandas": "oppblanda",
    "oppblandat": "oppblandad",
    "oppblandats": "oppblandad",
    "oppblåsningar": "oppblåsning",
    "oppblåsningarna": "oppblåsning",
    "oppblåsningarnas": "oppblåsning",
    "oppblåsningars": "oppblåsning",
    "oppblåsningen": "oppblåsning",
    "oppblåsningens": "oppblåsning",
    "oppblåsnings": "oppblåsning",
    "oppblåsningsfasen": "oppblåsningsfas",
    "oppblåsningsfasens": "oppblåsningsfas",
    "oppblåsningsfaser": "oppblåsningsfas",
    "oppblåsningsfaserna": "oppblåsningsfas",
    "oppblåsningsfasernas": "oppblåsningsfas",
    "oppblåsningsfasers": "oppblåsningsfas",
    "oppbring": "oppbringa",
    "oppbringad": "oppbringa",
    "oppbringade": "oppbringa",
    "oppbringades": "oppbringa",
    "oppbringads": "oppbringa",
    "oppbringande": "oppbringa",
    "oppbringanden": "oppbringande",
    "oppbringandena": "oppbringande",
    "oppbringandenas": "oppbringande",
    "oppbringandens": "oppbringande",
    "oppbringandes": "oppbringande",
    "oppbringandet": "oppbringande",
    "oppbringandets": "oppbringande",
    "oppbringar": "oppbringa",
    "oppbringas": "oppbringa",
    "oppbringat": "oppbringa",
    "oppbringats": "oppbringa",
    "oppbundens": "oppbunden",
    "oppbundet": "oppbunden",
    "oppbundets": "oppbunden",
    "oppbundna": "oppbunden",
    "oppbundnare": "oppbunden",
    "oppbundnares": "oppbunden",
    "oppbundnas": "oppbunden",
    "oppbundnast": "oppbunden",
    "oppbundnaste": "oppbunden",
    "oppbundnastes": "oppbunden",
    "oppbundnasts": "oppbunden",
    "oppbundne": "oppbunden",
    "oppbundnes": "oppbunden",
    "oppbure": "oppbära",
    "oppburen": "oppbära",
    "oppburens": "oppbära",
    "oppbures": "oppbära",
    "oppburet": "oppbära",
    "oppburets": "oppbära",
    "oppburit": "oppbära",
    "oppburits": "oppbära",
    "oppburna": "oppbära",
    "oppburnas": "oppbära",
    "oppburne": "oppbära",
    "oppburnes": "oppbära",
    "oppbyggnaden": "oppbyggnad",
    "oppbyggnadens": "oppbyggnad",
    "oppbyggnader": "oppbyggnad",
    "oppbyggnaderna": "oppbyggnad",
    "oppbyggnadernas": "oppbyggnad",
    "oppbyggnaders": "oppbyggnad",
    "oppbyggnads": "oppbyggnad",
    "oppbär": "oppbära",
    "oppbärande": "oppbära",
    "oppbäranden": "oppbärande",
    "oppbärandena": "oppbärande",
    "oppbärandenas": "oppbärande",
    "oppbärandens": "oppbärande",
    "oppbärandes": "oppbärande",
    "oppbärandet": "oppbärande",
    "oppbärandets": "oppbärande",
    "oppbäras": "oppbära",
    "oppbäre": "oppbära",
    "oppbäres": "oppbära",
    "oppbärs": "oppbära",
    "oppdag": "oppdaga",
    "oppdagad": "oppdaga",
    "oppdagade": "oppdaga",
    "oppdagades": "oppdaga",
    "oppdagads": "oppdaga",
    "oppdagande": "oppdaga",
    "oppdaganden": "oppdagande",
    "oppdagandena": "oppdagande",
    "oppdagandenas": "oppdagande",
    "oppdagandens": "oppdagande",
    "oppdagandes": "oppdagande",
    "oppdagandet": "oppdagande",
    "oppdagandets": "oppdagande",
    "oppdagar": "oppdaga",
    "oppdagas": "oppdaga",
    "oppdagat": "oppdaga",
    "oppdagats": "oppdaga",
    "oppdaterad": "oppdatera",
    "oppdaterade": "oppdatera",
    "oppdaterades": "oppdatera",
    "oppdaterads": "oppdatera",
    "oppdaterande": "oppdatera",
    "oppdateranden": "oppdaterande",
    "oppdaterandena": "oppdaterande",
    "oppdaterandenas": "oppdaterande",
    "oppdaterandens": "oppdaterande",
    "oppdaterandes": "oppdaterande",
    "oppdaterandet": "oppdaterande",
    "oppdaterandets": "oppdaterande",
    "oppdaterar": "oppdatera",
    "oppdateras": "oppdatera",
    "oppdaterat": "oppdatera",
    "oppdaterats": "oppdatera",
    "oppdaterbara": "oppdaterbar",
    "oppdaterbarare": "oppdaterbar",
    "oppdaterbarares": "oppdaterbar",
    "oppdaterbaras": "oppdaterbar",
    "oppdaterbarast": "oppdaterbar",
    "oppdaterbaraste": "oppdaterbar",
    "oppdaterbarastes": "oppdaterbar",
    "oppdaterbarasts": "oppdaterbar",
    "oppdaterbare": "oppdaterbar",
    "oppdaterbares": "oppdaterbar",
    "oppdaterbarheten": "oppdaterbarhet",
    "oppdaterbarhetens": "oppdaterbarhet",
    "oppdaterbarhets": "oppdaterbarhet",
    "oppdaterbars": "oppdaterbar",
    "oppdaterbart": "oppdaterbar",
    "oppdaterbarts": "oppdaterbar",
    "oppdateringar": "oppdatering",
    "oppdateringarna": "oppdatering",
    "oppdateringarnas": "oppdatering",
    "oppdateringars": "oppdatering",
    "oppdateringen": "oppdatering",
    "oppdateringens": "oppdatering",
    "oppdaterings": "oppdatering",
    "oppdel": "oppdela",
    "oppdelad": "oppdela",
    "oppdelade": "oppdela",
    "oppdelades": "oppdela",
    "oppdelads": "oppdela",
    "oppdelande": "oppdela",
    "oppdelanden": "oppdelande",
    "oppdelandena": "oppdelande",
    "oppdelandenas": "oppdelande",
    "oppdelandens": "oppdelande",
    "oppdelandes": "oppdelande",
    "oppdelandet": "oppdelande",
    "oppdelandets": "oppdelande",
    "oppdelar": "oppdela",
    "oppdelas": "oppdela",
    "oppdelat": "oppdela",
    "oppdelats": "oppdela",
    "oppdelningar": "oppdelning",
    "oppdelningarna": "oppdelning",
    "oppdelningarnas": "oppdelning",
    "oppdelningars": "oppdelning",
    "oppdelningen": "oppdelning",
    "oppdelningens": "oppdelning",
    "oppdelnings": "oppdelning",
    "oppdiktade": "oppdiktad",
    "oppdiktades": "oppdiktad",
    "oppdiktads": "oppdiktad",
    "oppdiktat": "oppdiktad",
    "oppdiktats": "oppdiktad",
    "oppdrev": "oppdriva",
    "oppdrevs": "oppdriva",
    "oppdriv": "oppdriva",
    "oppdrivande": "oppdriva",
    "oppdrivanden": "oppdrivande",
    "oppdrivandena": "oppdrivande",
    "oppdrivandenas": "oppdrivande",
    "oppdrivandens": "oppdrivande",
    "oppdrivandes": "oppdrivande",
    "oppdrivandet": "oppdrivande",
    "oppdrivandets": "oppdrivande",
    "oppdrivas": "oppdriva",
    "oppdrive": "oppdriva",
    "oppdriven": "oppdriva",
    "oppdrivens": "oppdriva",
    "oppdriver": "oppdriva",
    "oppdrives": "oppdriva",
    "oppdrivet": "oppdriva",
    "oppdrivets": "oppdriva",
    "oppdrivit": "oppdriva",
    "oppdrivits": "oppdriva",
    "oppdrivna": "oppdriva",
    "oppdrivnas": "oppdriva",
    "oppdrivne": "oppdriva",
    "oppdrivnes": "oppdriva",
    "oppdrivs": "oppdriva",
    "oppdukningar": "oppdukning",
    "oppdukningarna": "oppdukning",
    "oppdukningarnas": "oppdukning",
    "oppdukningars": "oppdukning",
    "oppdukningen": "oppdukning",
    "oppdukningens": "oppdukning",
    "oppduknings": "oppdukning",
    "oppegg": "oppegga",
    "oppeggad": "oppegga",
    "oppeggade": "oppegga",
    "oppeggades": "oppegga",
    "oppeggads": "oppegga",
    "oppeggande": "oppegga",
    "oppegganden": "oppeggande",
    "oppeggandena": "oppeggande",
    "oppeggandenas": "oppeggande",
    "oppeggandens": "oppeggande",
    "oppeggandes": "oppeggande",
    "oppeggandet": "oppeggande",
    "oppeggandets": "oppeggande",
    "oppeggar": "oppegga",
    "oppeggas": "oppegga",
    "oppeggat": "oppegga",
    "oppeggats": "oppegga",
    "oppeldade": "oppeldad",
    "oppeldades": "oppeldad",
    "oppeldads": "oppeldad",
    "oppeldat": "oppeldad",
    "oppeldats": "oppeldad",
    "oppfann": "oppfinna",
    "oppfanns": "oppfinna",
    "oppfarten": "oppfart",
    "oppfartens": "oppfart",
    "oppfarter": "oppfart",
    "oppfarterna": "oppfart",
    "oppfarternas": "oppfart",
    "oppfarters": "oppfart",
    "oppfarts": "oppfart",
    "oppfatt": "oppfatta",
    "oppfattad": "oppfatta",
    "oppfattade": "oppfatta",
    "oppfattades": "oppfatta",
    "oppfattads": "oppfatta",
    "oppfattande": "oppfatta",
    "oppfattanden": "oppfattande",
    "oppfattandena": "oppfattande",
    "oppfattandenas": "oppfattande",
    "oppfattandens": "oppfattande",
    "oppfattandes": "oppfattande",
    "oppfattandet": "oppfattande",
    "oppfattandets": "oppfattande",
    "oppfattar": "oppfatta",
    "oppfattas": "oppfatta",
    "oppfattat": "oppfatta",
    "oppfattats": "oppfatta",
    "oppfattningar": "oppfattning",
    "oppfattningarna": "oppfattning",
    "oppfattningarnas": "oppfattning",
    "oppfattningars": "oppfattning",
    "oppfattningen": "oppfattning",
    "oppfattningens": "oppfattning",
    "oppfattnings": "oppfattning",
    "oppfattningsförmågan": "oppfattningsförmåga",
    "oppfattningsförmågans": "oppfattningsförmåga",
    "oppfattningsförmågas": "oppfattningsförmåga",
    "oppfattningsförmåge": "oppfattningsförmåga",
    "oppfinn": "oppfinna",
    "oppfinnande": "oppfinna",
    "oppfinnanden": "oppfinnande",
    "oppfinnandena": "oppfinnande",
    "oppfinnandenas": "oppfinnande",
    "oppfinnandens": "oppfinnande",
    "oppfinnandes": "oppfinnande",
    "oppfinnandet": "oppfinnande",
    "oppfinnandets": "oppfinnande",
    "oppfinnar": "oppfinnare",
    "oppfinnaren": "oppfinnare",
    "oppfinnarens": "oppfinnare",
    "oppfinnares": "oppfinnare",
    "oppfinnarna": "oppfinnare",
    "oppfinnarnas": "oppfinnare",
    "oppfinnas": "oppfinna",
    "oppfinne": "oppfinna",
    "oppfinner": "oppfinna",
    "oppfinnes": "oppfinna",
    "oppfinningar": "oppfinning",
    "oppfinningarna": "oppfinning",
    "oppfinningarnas": "oppfinning",
    "oppfinningars": "oppfinning",
    "oppfinningen": "oppfinning",
    "oppfinningens": "oppfinning",
    "oppfinnings": "oppfinning",
    "oppfinningsförmågan": "oppfinningsförmåga",
    "oppfinningsförmågans": "oppfinningsförmåga",
    "oppfinningsförmågas": "oppfinningsförmåga",
    "oppfinningsförmåge": "oppfinningsförmåga",
    "oppfinningsrika": "oppfinningsrik",
    "oppfinningsrikare": "oppfinningsrik",
    "oppfinningsrikares": "oppfinningsrik",
    "oppfinningsrikas": "oppfinningsrik",
    "oppfinningsrikast": "oppfinningsrik",
    "oppfinningsrikaste": "oppfinningsrik",
    "oppfinningsrikastes": "oppfinningsrik",
    "oppfinningsrikasts": "oppfinningsrik",
    "oppfinningsrike": "oppfinningsrik",
    "oppfinningsrikes": "oppfinningsrik",
    "oppfinningsrikheten": "oppfinningsrikhet",
    "oppfinningsrikhetens": "oppfinningsrikhet",
    "oppfinningsrikhets": "oppfinningsrikhet",
    "oppfinningsriks": "oppfinningsrik",
    "oppfinningsrikt": "oppfinningsrik",
    "oppfinningsrikts": "oppfinningsrik",
    "oppfinns": "oppfinna",
    "oppflogen": "oppflog",
    "oppflogens": "oppflog",
    "oppfloget": "oppflog",
    "oppflogets": "oppflog",
    "oppflogs": "oppflog",
    "oppflugens": "oppflugen",
    "oppfluget": "oppflugen",
    "oppflugets": "oppflugen",
    "oppflugna": "oppflugen",
    "oppflugnare": "oppflugen",
    "oppflugnares": "oppflugen",
    "oppflugnas": "oppflugen",
    "oppflugnast": "oppflugen",
    "oppflugnaste": "oppflugen",
    "oppflugnastes": "oppflugen",
    "oppflugnasts": "oppflugen",
    "oppflugne": "oppflugen",
    "oppflugnes": "oppflugen",
    "oppflågen": "oppflåg",
    "oppflågens": "oppflåg",
    "oppflåget": "oppflåg",
    "oppflågets": "oppflåg",
    "oppflågs": "oppflåg",
    "oppfostrad": "oppfostra",
    "oppfostrade": "oppfostra",
    "oppfostrades": "oppfostra",
    "oppfostrads": "oppfostra",
    "oppfostrande": "oppfostra",
    "oppfostranden": "oppfostrande",
    "oppfostrandena": "oppfostrande",
    "oppfostrandenas": "oppfostrande",
    "oppfostrandens": "oppfostrande",
    "oppfostrandes": "oppfostrande",
    "oppfostrandet": "oppfostrande",
    "oppfostrandets": "oppfostrande",
    "oppfostrans": "oppfostran",
    "oppfostrar": "oppfostrare",
    "oppfostraren": "oppfostrare",
    "oppfostrarens": "oppfostrare",
    "oppfostrares": "oppfostrare",
    "oppfostrarna": "oppfostrare",
    "oppfostrarnas": "oppfostrare",
    "oppfostras": "oppfostra",
    "oppfostrat": "oppfostra",
    "oppfostrats": "oppfostra",
    "oppfostringar": "oppfostring",
    "oppfostringarna": "oppfostring",
    "oppfostringarnas": "oppfostring",
    "oppfostringars": "oppfostring",
    "oppfostringen": "oppfostring",
    "oppfostringens": "oppfostring",
    "oppfostrings": "oppfostring",
    "oppfostringsanstalten": "oppfostringsanstalt",
    "oppfostringsanstaltens": "oppfostringsanstalt",
    "oppfostringsanstalter": "oppfostringsanstalt",
    "oppfostringsanstalterna": "oppfostringsanstalt",
    "oppfostringsanstalternas": "oppfostringsanstalt",
    "oppfostringsanstalters": "oppfostringsanstalt",
    "oppfostringsanstalts": "oppfostringsanstalt",
    "oppfostringshemmen": "oppfostringshem",
    "oppfostringshemmens": "oppfostringshem",
    "oppfostringshemmet": "oppfostringshem",
    "oppfostringshemmets": "oppfostringshem",
    "oppfostringshems": "oppfostringshem",
    "oppfrisk": "oppfriska",
    "oppfriskad": "oppfriska",
    "oppfriskade": "oppfriska",
    "oppfriskades": "oppfriska",
    "oppfriskads": "oppfriska",
    "oppfriskande": "oppfriska",
    "oppfriskanden": "oppfriskande",
    "oppfriskandena": "oppfriskande",
    "oppfriskandenas": "oppfriskande",
    "oppfriskandens": "oppfriskande",
    "oppfriskandes": "oppfriskande",
    "oppfriskandet": "oppfriskande",
    "oppfriskandets": "oppfriskande",
    "oppfriskar": "oppfriska",
    "oppfriskas": "oppfriska",
    "oppfriskat": "oppfriska",
    "oppfriskats": "oppfriska",
    "oppfunna": "oppfinna",
    "oppfunnas": "oppfinna",
    "oppfunne": "oppfinna",
    "oppfunnen": "oppfinna",
    "oppfunnens": "oppfinna",
    "oppfunnes": "oppfinna",
    "oppfunnet": "oppfinna",
    "oppfunnets": "oppfinna",
    "oppfunnit": "oppfinna",
    "oppfunnits": "oppfinna",
    "oppfyll": "oppfylla",
    "oppfyllande": "oppfylla",
    "oppfyllanden": "oppfyllande",
    "oppfyllandena": "oppfyllande",
    "oppfyllandenas": "oppfyllande",
    "oppfyllandens": "oppfyllande",
    "oppfyllandes": "oppfyllande",
    "oppfyllandet": "oppfyllande",
    "oppfyllandets": "oppfyllande",
    "oppfyllas": "oppfylla",
    "oppfylld": "oppfylla",
    "oppfyllda": "oppfylla",
    "oppfylldas": "oppfylla",
    "oppfyllde": "oppfylla",
    "oppfylldes": "oppfylla",
    "oppfyllds": "oppfylla",
    "oppfyllelsen": "oppfyllelse",
    "oppfyllelsens": "oppfyllelse",
    "oppfyllelses": "oppfyllelse",
    "oppfyller": "oppfylla",
    "oppfylles": "oppfylla",
    "oppfylls": "oppfylla",
    "oppfyllt": "oppfylla",
    "oppfyllts": "oppfylla",
    "oppfällbara": "oppfällbar",
    "oppfällbarare": "oppfällbar",
    "oppfällbarares": "oppfällbar",
    "oppfällbaras": "oppfällbar",
    "oppfällbarast": "oppfällbar",
    "oppfällbaraste": "oppfällbar",
    "oppfällbarastes": "oppfällbar",
    "oppfällbarasts": "oppfällbar",
    "oppfällbare": "oppfällbar",
    "oppfällbares": "oppfällbar",
    "oppfällbarheten": "oppfällbarhet",
    "oppfällbarhetens": "oppfällbarhet",
    "oppfällbarhets": "oppfällbarhet",
    "oppfällbars": "oppfällbar",
    "oppfällbart": "oppfällbar",
    "oppfällbarts": "oppfällbar",
    "oppfällde": "oppfälld",
    "oppfälldes": "oppfälld",
    "oppfällds": "oppfälld",
    "oppfällt": "oppfälld",
    "oppfällts": "oppfälld",
    "oppfång": "oppfånga",
    "oppfångad": "oppfånga",
    "oppfångade": "oppfånga",
    "oppfångades": "oppfånga",
    "oppfångads": "oppfånga",
    "oppfångande": "oppfånga",
    "oppfånganden": "oppfångande",
    "oppfångandena": "oppfångande",
    "oppfångandenas": "oppfångande",
    "oppfångandens": "oppfångande",
    "oppfångandes": "oppfångande",
    "oppfångandet": "oppfångande",
    "oppfångandets": "oppfångande",
    "oppfångar": "oppfånga",
    "oppfångas": "oppfånga",
    "oppfångat": "oppfånga",
    "oppfångats": "oppfånga",
    "oppföd": "oppföda",
    "oppfödande": "oppföda",
    "oppfödanden": "oppfödande",
    "oppfödandena": "oppfödande",
    "oppfödandenas": "oppfödande",
    "oppfödandens": "oppfödande",
    "oppfödandes": "oppfödande",
    "oppfödandet": "oppfödande",
    "oppfödandets": "oppfödande",
    "oppfödar": "oppfödare",
    "oppfödaren": "oppfödare",
    "oppfödarens": "oppfödare",
    "oppfödares": "oppfödare",
    "oppfödarna": "oppfödare",
    "oppfödarnas": "oppfödare",
    "oppfödas": "oppföda",
    "oppfödd": "oppföda",
    "oppfödda": "oppföda",
    "oppföddas": "oppföda",
    "oppfödde": "oppföda",
    "oppföddes": "oppföda",
    "oppfödds": "oppföda",
    "oppföder": "oppföda",
    "oppfödes": "oppföda",
    "oppfödningar": "oppfödning",
    "oppfödningarna": "oppfödning",
    "oppfödningarnas": "oppfödning",
    "oppfödningars": "oppfödning",
    "oppfödningen": "oppfödning",
    "oppfödningens": "oppfödning",
    "oppfödnings": "oppfödning",
    "oppföds": "oppföda",
    "oppföljningar": "oppföljning",
    "oppföljningarna": "oppföljning",
    "oppföljningarnas": "oppföljning",
    "oppföljningars": "oppföljning",
    "oppföljningen": "oppföljning",
    "oppföljningens": "oppföljning",
    "oppföljnings": "oppföljning",
    "oppfött": "oppföda",
    "oppfötts": "oppföda",
    "oppgav": "oppge",
    "oppgavs": "oppge",
    "oppgeende": "oppge",
    "oppgeendes": "oppge",
    "oppger": "oppge",
    "oppges": "oppge",
    "oppgett": "oppge",
    "oppgetts": "oppge",
    "oppgiv": "oppge",
    "oppgiva": "oppge",
    "oppgivande": "oppge",
    "oppgivanden": "oppgivande",
    "oppgivandena": "oppgivande",
    "oppgivandenas": "oppgivande",
    "oppgivandens": "oppgivande",
    "oppgivandes": "oppgivande",
    "oppgivandet": "oppgivande",
    "oppgivandets": "oppgivande",
    "oppgivas": "oppge",
    "oppgive": "oppge",
    "oppgivelsen": "oppgivelse",
    "oppgivelsens": "oppgivelse",
    "oppgivelses": "oppgivelse",
    "oppgiven": "oppge",
    "oppgivenheten": "oppgivenhet",
    "oppgivenhetens": "oppgivenhet",
    "oppgivenheter": "oppgivenhet",
    "oppgivenheterna": "oppgivenhet",
    "oppgivenheternas": "oppgivenhet",
    "oppgivenheters": "oppgivenhet",
    "oppgivenhets": "oppgivenhet",
    "oppgivens": "oppgiven",
    "oppgiver": "oppge",
    "oppgives": "oppge",
    "oppgivet": "oppgiven",
    "oppgivets": "oppgiven",
    "oppgivit": "oppge",
    "oppgivits": "oppge",
    "oppgivna": "oppgiven",
    "oppgivnare": "oppgiven",
    "oppgivnares": "oppgiven",
    "oppgivnas": "oppgiven",
    "oppgivnast": "oppgiven",
    "oppgivnaste": "oppgiven",
    "oppgivnastes": "oppgiven",
    "oppgivnasts": "oppgiven",
    "oppgivne": "oppgiven",
    "oppgivnes": "oppgiven",
    "oppgivs": "oppge",
    "oppgjorda": "oppgjord",
    "oppgjordare": "oppgjord",
    "oppgjordares": "oppgjord",
    "oppgjordas": "oppgjord",
    "oppgjordast": "oppgjord",
    "oppgjordaste": "oppgjord",
    "oppgjordastes": "oppgjord",
    "oppgjordasts": "oppgjord",
    "oppgjorde": "oppgjord",
    "oppgjordes": "oppgjord",
    "oppgjords": "oppgjord",
    "oppgjort": "oppgjord",
    "oppgjorts": "oppgjord",
    "oppgångar": "oppgång",
    "oppgångarna": "oppgång",
    "oppgångarnas": "oppgång",
    "oppgångars": "oppgång",
    "oppgången": "oppgång",
    "oppgångens": "oppgång",
    "oppgångs": "oppgång",
    "oppgåve": "oppge",
    "oppgåves": "oppge",
    "oppgörelsen": "oppgörelse",
    "oppgörelsens": "oppgörelse",
    "oppgörelser": "oppgörelse",
    "oppgörelserna": "oppgörelse",
    "oppgörelsernas": "oppgörelse",
    "oppgörelsers": "oppgörelse",
    "oppgörelses": "oppgörelse",
    "opphets": "opphetsa",
    "opphetsad": "opphetsa",
    "opphetsade": "opphetsad",
    "opphetsades": "opphetsad",
    "opphetsads": "opphetsad",
    "opphetsande": "opphetsa",
    "opphetsanden": "opphetsande",
    "opphetsandena": "opphetsande",
    "opphetsandenas": "opphetsande",
    "opphetsandens": "opphetsande",
    "opphetsandes": "opphetsande",
    "opphetsandet": "opphetsande",
    "opphetsandets": "opphetsande",
    "opphetsar": "opphetsa",
    "opphetsas": "opphetsa",
    "opphetsat": "opphetsad",
    "opphetsats": "opphetsad",
    "opphetsningar": "opphetsning",
    "opphetsningarna": "opphetsning",
    "opphetsningarnas": "opphetsning",
    "opphetsningars": "opphetsning",
    "opphetsningen": "opphetsning",
    "opphetsningens": "opphetsning",
    "opphetsnings": "opphetsning",
    "opphett": "opphetta",
    "opphettad": "opphetta",
    "opphettade": "opphetta",
    "opphettades": "opphetta",
    "opphettads": "opphetta",
    "opphettande": "opphetta",
    "opphettanden": "opphettande",
    "opphettandena": "opphettande",
    "opphettandenas": "opphettande",
    "opphettandens": "opphettande",
    "opphettandes": "opphettande",
    "opphettandet": "opphettande",
    "opphettandets": "opphettande",
    "opphettar": "opphetta",
    "opphettas": "opphetta",
    "opphettat": "opphetta",
    "opphettats": "opphetta",
    "opphettningar": "opphettning",
    "opphettningarna": "opphettning",
    "opphettningarnas": "opphettning",
    "opphettningars": "opphettning",
    "opphettningen": "opphettning",
    "opphettningens": "opphettning",
    "opphettnings": "opphettning",
    "opphinneliga": "opphinnelig",
    "opphinneligare": "opphinnelig",
    "opphinneligares": "opphinnelig",
    "opphinneligas": "opphinnelig",
    "opphinneligast": "opphinnelig",
    "opphinneligaste": "opphinnelig",
    "opphinneligastes": "opphinnelig",
    "opphinneligasts": "opphinnelig",
    "opphinnelige": "opphinnelig",
    "opphinneliges": "opphinnelig",
    "opphinneligheten": "opphinnelighet",
    "opphinnelighetens": "opphinnelighet",
    "opphinnelighets": "opphinnelighet",
    "opphinneligs": "opphinnelig",
    "opphinneligt": "opphinnelig",
    "opphinneligts": "opphinnelig",
    "opphitt": "opphitta",
    "opphittad": "opphitta",
    "opphittade": "opphitta",
    "opphittades": "opphitta",
    "opphittads": "opphitta",
    "opphittande": "opphitta",
    "opphittanden": "opphittande",
    "opphittandena": "opphittande",
    "opphittandenas": "opphittande",
    "opphittandens": "opphittande",
    "opphittandes": "opphittande",
    "opphittandet": "opphittande",
    "opphittandets": "opphittande",
    "opphittar": "opphitta",
    "opphittas": "opphitta",
    "opphittat": "opphitta",
    "opphittats": "opphitta",
    "opphostningar": "opphostning",
    "opphostningarna": "opphostning",
    "opphostningarnas": "opphostning",
    "opphostningars": "opphostning",
    "opphostningen": "opphostning",
    "opphostningens": "opphostning",
    "opphostnings": "opphostning",
    "opphottanden": "opphottande",
    "opphottandena": "opphottande",
    "opphottandenas": "opphottande",
    "opphottandens": "opphottande",
    "opphottandes": "opphottande",
    "opphottandet": "opphottande",
    "opphottandets": "opphottande",
    "opphottningar": "opphottning",
    "opphottningarna": "opphottning",
    "opphottningarnas": "opphottning",
    "opphottningars": "opphottning",
    "opphottningen": "opphottning",
    "opphottningens": "opphottning",
    "opphottnings": "opphottning",
    "opphov": "opphäva",
    "opphove": "opphäva",
    "opphoves": "opphäva",
    "opphovs": "opphäva",
    "opphämt": "opphämta",
    "opphämtad": "opphämta",
    "opphämtade": "opphämta",
    "opphämtades": "opphämta",
    "opphämtads": "opphämta",
    "opphämtan": "opphämta",
    "opphämtande": "opphämta",
    "opphämtanden": "opphämtande",
    "opphämtandena": "opphämtande",
    "opphämtandenas": "opphämtande",
    "opphämtandens": "opphämtande",
    "opphämtandes": "opphämtande",
    "opphämtandet": "opphämtande",
    "opphämtandets": "opphämtande",
    "opphämtans": "opphämta",
    "opphämtar": "opphämta",
    "opphämtas": "opphämta",
    "opphämtat": "opphämta",
    "opphämtats": "opphämta",
    "opphämtningar": "opphämtning",
    "opphämtningarna": "opphämtning",
    "opphämtningarnas": "opphämtning",
    "opphämtningars": "opphämtning",
    "opphämtningen": "opphämtning",
    "opphämtningens": "opphämtning",
    "opphämtnings": "opphämtning",
    "opphängningar": "opphängning",
    "opphängningarna": "opphängning",
    "opphängningarnas": "opphängning",
    "opphängningars": "opphängning",
    "opphängningen": "opphängning",
    "opphängningens": "opphängning",
    "opphängnings": "opphängning",
    "opphäv": "opphäva",
    "opphävande": "opphäva",
    "opphävanden": "opphävande",
    "opphävandena": "opphävande",
    "opphävandenas": "opphävande",
    "opphävandens": "opphävande",
    "opphävandes": "opphävande",
    "opphävandet": "opphävande",
    "opphävandets": "opphävande",
    "opphävas": "opphäva",
    "opphävd": "opphäva",
    "opphävda": "opphäva",
    "opphävdas": "opphäva",
    "opphävde": "opphäva",
    "opphävdes": "opphäva",
    "opphävds": "opphäva",
    "opphäve": "opphäva",
    "opphäver": "opphäva",
    "opphäves": "opphäva",
    "opphävs": "opphäva",
    "opphävt": "opphäva",
    "opphävts": "opphäva",
    "opphöj": "opphöja",
    "opphöjande": "opphöja",
    "opphöjanden": "opphöjande",
    "opphöjandena": "opphöjande",
    "opphöjandenas": "opphöjande",
    "opphöjandens": "opphöjande",
    "opphöjandes": "opphöjande",
    "opphöjandet": "opphöjande",
    "opphöjandets": "opphöjande",
    "opphöjas": "opphöja",
    "opphöjd": "opphöja",
    "opphöjda": "opphöjd",
    "opphöjdare": "opphöjd",
    "opphöjdares": "opphöjd",
    "opphöjdas": "opphöjd",
    "opphöjdast": "opphöjd",
    "opphöjdaste": "opphöjd",
    "opphöjdastes": "opphöjd",
    "opphöjdasts": "opphöjd",
    "opphöjde": "opphöjd",
    "opphöjdes": "opphöjd",
    "opphöjdheten": "opphöjdhet",
    "opphöjdhetens": "opphöjdhet",
    "opphöjdheter": "opphöjdhet",
    "opphöjdheterna": "opphöjdhet",
    "opphöjdheternas": "opphöjdhet",
    "opphöjdheters": "opphöjdhet",
    "opphöjdhets": "opphöjdhet",
    "opphöjds": "opphöjd",
    "opphöjelsen": "opphöjelse",
    "opphöjelsens": "opphöjelse",
    "opphöjelser": "opphöjelse",
    "opphöjelserna": "opphöjelse",
    "opphöjelsernas": "opphöjelse",
    "opphöjelsers": "opphöjelse",
    "opphöjelses": "opphöjelse",
    "opphöjer": "opphöja",
    "opphöjes": "opphöja",
    "opphöjningar": "opphöjning",
    "opphöjningarna": "opphöjning",
    "opphöjningarnas": "opphöjning",
    "opphöjningars": "opphöjning",
    "opphöjningen": "opphöjning",
    "opphöjningens": "opphöjning",
    "opphöjnings": "opphöjning",
    "opphöjs": "opphöja",
    "opphöjt": "opphöjd",
    "opphöjts": "opphöjd",
    "opphör": "opphöra",
    "opphörande": "opphöra",
    "opphöranden": "opphörande",
    "opphörandena": "opphörande",
    "opphörandenas": "opphörande",
    "opphörandens": "opphörande",
    "opphörandes": "opphörande",
    "opphörandet": "opphörande",
    "opphörandets": "opphörande",
    "opphöras": "opphöra",
    "opphörd": "opphöra",
    "opphörda": "opphöra",
    "opphördas": "opphöra",
    "opphörde": "opphöra",
    "opphördes": "opphöra",
    "opphörds": "opphöra",
    "opphöres": "opphöra",
    "opphörs": "opphöra",
    "opphört": "opphöra",
    "opphörts": "opphöra",
    "oppigganden": "oppiggande",
    "oppiggandena": "oppiggande",
    "oppiggandenas": "oppiggande",
    "oppiggandens": "oppiggande",
    "oppiggandes": "oppiggande",
    "oppiggandet": "oppiggande",
    "oppiggandets": "oppiggande",
    "oppjagade": "oppjagad",
    "oppjagades": "oppjagad",
    "oppjagads": "oppjagad",
    "oppjagat": "oppjagad",
    "oppjagats": "oppjagad",
    "oppjusterad": "oppjustera",
    "oppjusterade": "oppjustera",
    "oppjusterades": "oppjustera",
    "oppjusterads": "oppjustera",
    "oppjusterande": "oppjustera",
    "oppjusteranden": "oppjusterande",
    "oppjusterandena": "oppjusterande",
    "oppjusterandenas": "oppjusterande",
    "oppjusterandens": "oppjusterande",
    "oppjusterandes": "oppjusterande",
    "oppjusterandet": "oppjusterande",
    "oppjusterandets": "oppjusterande",
    "oppjusterar": "oppjustera",
    "oppjusteras": "oppjustera",
    "oppjusterat": "oppjustera",
    "oppjusterats": "oppjustera",
    "oppjusterbara": "oppjusterbar",
    "oppjusterbarare": "oppjusterbar",
    "oppjusterbarares": "oppjusterbar",
    "oppjusterbaras": "oppjusterbar",
    "oppjusterbarast": "oppjusterbar",
    "oppjusterbaraste": "oppjusterbar",
    "oppjusterbarastes": "oppjusterbar",
    "oppjusterbarasts": "oppjusterbar",
    "oppjusterbare": "oppjusterbar",
    "oppjusterbares": "oppjusterbar",
    "oppjusterbarheten": "oppjusterbarhet",
    "oppjusterbarhetens": "oppjusterbarhet",
    "oppjusterbarhets": "oppjusterbarhet",
    "oppjusterbars": "oppjusterbar",
    "oppjusterbart": "oppjusterbar",
    "oppjusterbarts": "oppjusterbar",
    "oppjusteringar": "oppjustering",
    "oppjusteringarna": "oppjustering",
    "oppjusteringarnas": "oppjustering",
    "oppjusteringars": "oppjustering",
    "oppjusteringen": "oppjustering",
    "oppjusteringens": "oppjustering",
    "oppjusterings": "oppjustering",
    "oppkall": "oppkalla",
    "oppkallad": "oppkalla",
    "oppkallade": "oppkalla",
    "oppkallades": "oppkalla",
    "oppkallads": "oppkalla",
    "oppkallande": "oppkalla",
    "oppkallanden": "oppkallande",
    "oppkallandena": "oppkallande",
    "oppkallandenas": "oppkallande",
    "oppkallandens": "oppkallande",
    "oppkallandes": "oppkallande",
    "oppkallandet": "oppkallande",
    "oppkallandets": "oppkallande",
    "oppkallar": "oppkalla",
    "oppkallas": "oppkalla",
    "oppkallat": "oppkalla",
    "oppkallats": "oppkalla",
    "oppkammade": "oppkammad",
    "oppkammades": "oppkammad",
    "oppkammads": "oppkammad",
    "oppkammat": "oppkammad",
    "oppkammats": "oppkammad",
    "oppkasten": "oppkast",
    "oppkastens": "oppkast",
    "oppkastet": "oppkast",
    "oppkastets": "oppkast",
    "oppkastningar": "oppkastning",
    "oppkastningarna": "oppkastning",
    "oppkastningarnas": "oppkastning",
    "oppkastningars": "oppkastning",
    "oppkastningen": "oppkastning",
    "oppkastningens": "oppkastning",
    "oppkastnings": "oppkastning",
    "oppkasts": "oppkast",
    "oppkavlade": "oppkavlad",
    "oppkavlades": "oppkavlad",
    "oppkavlads": "oppkavlad",
    "oppkavlat": "oppkavlad",
    "oppkavlats": "oppkavlad",
    "oppklar": "oppklara",
    "oppklarad": "oppklara",
    "oppklarade": "oppklara",
    "oppklarades": "oppklara",
    "oppklarads": "oppklara",
    "oppklarande": "oppklara",
    "oppklaranden": "oppklarande",
    "oppklarandena": "oppklarande",
    "oppklarandenas": "oppklarande",
    "oppklarandens": "oppklarande",
    "oppklarandes": "oppklarande",
    "oppklarandet": "oppklarande",
    "oppklarandets": "oppklarande",
    "oppklarar": "oppklara",
    "oppklaras": "oppklara",
    "oppklarat": "oppklara",
    "oppklarats": "oppklara",
    "oppklippta": "oppklippt",
    "oppklipptare": "oppklippt",
    "oppklipptares": "oppklippt",
    "oppklipptas": "oppklippt",
    "oppklipptast": "oppklippt",
    "oppklipptaste": "oppklippt",
    "oppklipptastes": "oppklippt",
    "oppklipptasts": "oppklippt",
    "oppklippte": "oppklippt",
    "oppklipptes": "oppklippt",
    "oppklippts": "oppklippt",
    "oppklädda": "oppklädd",
    "oppkläddare": "oppklädd",
    "oppkläddares": "oppklädd",
    "oppkläddas": "oppklädd",
    "oppkläddast": "oppklädd",
    "oppkläddaste": "oppklädd",
    "oppkläddastes": "oppklädd",
    "oppkläddasts": "oppklädd",
    "oppklädde": "oppklädd",
    "oppkläddes": "oppklädd",
    "oppkläddheten": "oppkläddhet",
    "oppkläddhetens": "oppkläddhet",
    "oppkläddhets": "oppkläddhet",
    "oppklädds": "oppklädd",
    "oppklätt": "oppklädd",
    "oppklätts": "oppklädd",
    "oppknutens": "oppknuten",
    "oppknutet": "oppknuten",
    "oppknutets": "oppknuten",
    "oppknutna": "oppknuten",
    "oppknutnare": "oppknuten",
    "oppknutnares": "oppknuten",
    "oppknutnas": "oppknuten",
    "oppknutnast": "oppknuten",
    "oppknutnaste": "oppknuten",
    "oppknutnastes": "oppknuten",
    "oppknutnasts": "oppknuten",
    "oppknutne": "oppknuten",
    "oppknutnes": "oppknuten",
    "oppknäppta": "oppknäppt",
    "oppknäpptare": "oppknäppt",
    "oppknäpptares": "oppknäppt",
    "oppknäpptas": "oppknäppt",
    "oppknäpptast": "oppknäppt",
    "oppknäpptaste": "oppknäppt",
    "oppknäpptastes": "oppknäppt",
    "oppknäpptasts": "oppknäppt",
    "oppknäppte": "oppknäppt",
    "oppknäpptes": "oppknäppt",
    "oppknäpptheten": "oppknäppthet",
    "oppknäppthetens": "oppknäppthet",
    "oppknäppthets": "oppknäppthet",
    "oppknäppts": "oppknäppt",
    "oppkäftiga": "oppkäftig",
    "oppkäftigare": "oppkäftig",
    "oppkäftigares": "oppkäftig",
    "oppkäftigas": "oppkäftig",
    "oppkäftigast": "oppkäftig",
    "oppkäftigaste": "oppkäftig",
    "oppkäftigastes": "oppkäftig",
    "oppkäftigasts": "oppkäftig",
    "oppkäftige": "oppkäftig",
    "oppkäftiges": "oppkäftig",
    "oppkäftigheten": "oppkäftighet",
    "oppkäftighetens": "oppkäftighet",
    "oppkäftigheter": "oppkäftighet",
    "oppkäftigheterna": "oppkäftighet",
    "oppkäftigheternas": "oppkäftighet",
    "oppkäftigheters": "oppkäftighet",
    "oppkäftighets": "oppkäftighet",
    "oppkäftigs": "oppkäftig",
    "oppkäftigt": "oppkäftig",
    "oppkäftigts": "oppkäftig",
    "oppkörda": "oppkörd",
    "oppkördare": "oppkörd",
    "oppkördares": "oppkörd",
    "oppkördas": "oppkörd",
    "oppkördast": "oppkörd",
    "oppkördaste": "oppkörd",
    "oppkördastes": "oppkörd",
    "oppkördasts": "oppkörd",
    "oppkörde": "oppkörd",
    "oppkördes": "oppkörd",
    "oppkördheten": "oppkördhet",
    "oppkördhetens": "oppkördhet",
    "oppkördhets": "oppkördhet",
    "oppkörds": "oppkörd",
    "oppkörningar": "oppkörning",
    "oppkörningarna": "oppkörning",
    "oppkörningarnas": "oppkörning",
    "oppkörningars": "oppkörning",
    "oppkörningen": "oppkörning",
    "oppkörningens": "oppkörning",
    "oppkörnings": "oppkörning",
    "oppkörsvägar": "oppkörsväg",
    "oppkörsvägarna": "oppkörsväg",
    "oppkörsvägarnas": "oppkörsväg",
    "oppkörsvägars": "oppkörsväg",
    "oppkörsvägen": "oppkörsväg",
    "oppkörsvägens": "oppkörsväg",
    "oppkörsvägs": "oppkörsväg",
    "oppkört": "oppkörd",
    "oppkörts": "oppkörd",
    "oppla": "opplägga",
    "oppladdade": "oppladdad",
    "oppladdades": "oppladdad",
    "oppladdads": "oppladdad",
    "oppladdat": "oppladdad",
    "oppladdats": "oppladdad",
    "oppladdningar": "oppladdning",
    "oppladdningarna": "oppladdning",
    "oppladdningarnas": "oppladdning",
    "oppladdningars": "oppladdning",
    "oppladdningen": "oppladdning",
    "oppladdningens": "oppladdning",
    "oppladdnings": "oppladdning",
    "opplade": "opplägga",
    "opplades": "opplägga",
    "opplagd": "opplägga",
    "opplagda": "opplägga",
    "opplagdare": "opplagd",
    "opplagdares": "opplagd",
    "opplagdas": "opplägga",
    "opplagdast": "opplagd",
    "opplagdaste": "opplagd",
    "opplagdastes": "opplagd",
    "opplagdasts": "opplagd",
    "opplagde": "opplägga",
    "opplagdes": "opplägga",
    "opplagds": "opplägga",
    "opplagt": "opplägga",
    "opplagts": "opplägga",
    "opplas": "opplägga",
    "oppliv": "oppliva",
    "opplivad": "oppliva",
    "opplivade": "oppliva",
    "opplivades": "oppliva",
    "opplivads": "oppliva",
    "opplivande": "oppliva",
    "opplivanden": "opplivande",
    "opplivandena": "opplivande",
    "opplivandenas": "opplivande",
    "opplivandens": "opplivande",
    "opplivandes": "opplivande",
    "opplivandet": "opplivande",
    "opplivandets": "opplivande",
    "opplivar": "oppliva",
    "opplivas": "oppliva",
    "opplivat": "oppliva",
    "opplivats": "oppliva",
    "opplägg": "opplägga",
    "oppläggande": "opplägga",
    "opplägganden": "oppläggande",
    "oppläggandena": "oppläggande",
    "oppläggandenas": "oppläggande",
    "oppläggandens": "oppläggande",
    "oppläggandes": "oppläggande",
    "oppläggandet": "oppläggande",
    "oppläggandets": "oppläggande",
    "oppläggas": "opplägga",
    "oppläggen": "opplägg",
    "oppläggens": "opplägg",
    "opplägger": "opplägga",
    "opplägges": "opplägga",
    "opplägget": "opplägg",
    "oppläggets": "opplägg",
    "oppläggningar": "oppläggning",
    "oppläggningarna": "oppläggning",
    "oppläggningarnas": "oppläggning",
    "oppläggningars": "oppläggning",
    "oppläggningen": "oppläggning",
    "oppläggningens": "oppläggning",
    "oppläggnings": "oppläggning",
    "oppläggs": "opplägga",
    "oppläs": "oppläsa",
    "oppläsande": "oppläsa",
    "oppläsanden": "oppläsande",
    "oppläsandena": "oppläsande",
    "oppläsandenas": "oppläsande",
    "oppläsandens": "oppläsande",
    "oppläsandes": "oppläsande",
    "oppläsandet": "oppläsande",
    "oppläsandets": "oppläsande",
    "oppläsas": "oppläsa",
    "oppläser": "oppläsa",
    "oppläses": "oppläsa",
    "oppläst": "oppläsa",
    "opplästa": "oppläsa",
    "opplästas": "oppläsa",
    "oppläste": "oppläsa",
    "opplästes": "oppläsa",
    "opplästs": "oppläsa",
    "oppmuntrad": "oppmuntra",
    "oppmuntrade": "oppmuntra",
    "oppmuntrades": "oppmuntra",
    "oppmuntrads": "oppmuntra",
    "oppmuntrande": "oppmuntra",
    "oppmuntranden": "oppmuntrande",
    "oppmuntrandena": "oppmuntrande",
    "oppmuntrandenas": "oppmuntrande",
    "oppmuntrandens": "oppmuntrande",
    "oppmuntrandes": "oppmuntrande",
    "oppmuntrandet": "oppmuntrande",
    "oppmuntrandets": "oppmuntrande",
    "oppmuntrar": "oppmuntra",
    "oppmuntras": "oppmuntra",
    "oppmuntrat": "oppmuntra",
    "oppmuntrats": "oppmuntra",
    "oppochnedvända": "oppochnedvänd",
    "oppochnedvändare": "oppochnedvänd",
    "oppochnedvändares": "oppochnedvänd",
    "oppochnedvändas": "oppochnedvänd",
    "oppochnedvändast": "oppochnedvänd",
    "oppochnedvändaste": "oppochnedvänd",
    "oppochnedvändastes": "oppochnedvänd",
    "oppochnedvändasts": "oppochnedvänd",
    "oppochnedvände": "oppochnedvänd",
    "oppochnedvändes": "oppochnedvänd",
    "oppochnedvändheten": "oppochnedvändhet",
    "oppochnedvändhetens": "oppochnedvändhet",
    "oppochnedvändhets": "oppochnedvändhet",
    "oppochnedvänds": "oppochnedvänd",
    "oppochnedvänt": "oppochnedvänd",
    "oppochnedvänts": "oppochnedvänd",
    "oppochnervända": "oppochnervänd",
    "oppochnervändare": "oppochnervänd",
    "oppochnervändares": "oppochnervänd",
    "oppochnervändas": "oppochnervänd",
    "oppochnervändast": "oppochnervänd",
    "oppochnervändaste": "oppochnervänd",
    "oppochnervändastes": "oppochnervänd",
    "oppochnervändasts": "oppochnervänd",
    "oppochnervände": "oppochnervänd",
    "oppochnervändes": "oppochnervänd",
    "oppochnervändheten": "oppochnervändhet",
    "oppochnervändhetens": "oppochnervändhet",
    "oppochnervändhets": "oppochnervändhet",
    "oppochnervänds": "oppochnervänd",
    "oppochnervänt": "oppochnervänd",
    "oppochnervänts": "oppochnervänd",
    "opponenten": "opponent",
    "opponentens": "opponent",
    "opponenter": "opponent",
    "opponenterna": "opponent",
    "opponenternas": "opponent",
    "opponenters": "opponent",
    "opponents": "opponent",
    "opponerad": "opponera",
    "opponerade": "opponera",
    "opponerades": "opponera",
    "opponerads": "opponera",
    "opponerande": "opponera",
    "opponeranden": "opponerande",
    "opponerandena": "opponerande",
    "opponerandenas": "opponerande",
    "opponerandens": "opponerande",
    "opponerandes": "opponerande",
    "opponerandet": "opponerande",
    "opponerandets": "opponerande",
    "opponerar": "opponera",
    "opponeras": "opponera",
    "opponerat": "opponera",
    "opponerats": "opponera",
    "opponerbara": "opponerbar",
    "opponerbarare": "opponerbar",
    "opponerbarares": "opponerbar",
    "opponerbaras": "opponerbar",
    "opponerbarast": "opponerbar",
    "opponerbaraste": "opponerbar",
    "opponerbarastes": "opponerbar",
    "opponerbarasts": "opponerbar",
    "opponerbare": "opponerbar",
    "opponerbares": "opponerbar",
    "opponerbarheten": "opponerbarhet",
    "opponerbarhetens": "opponerbarhet",
    "opponerbarhets": "opponerbarhet",
    "opponerbars": "opponerbar",
    "opponerbart": "opponerbar",
    "opponerbarts": "opponerbar",
    "opponeringar": "opponering",
    "opponeringarna": "opponering",
    "opponeringarnas": "opponering",
    "opponeringars": "opponering",
    "opponeringen": "opponering",
    "opponeringens": "opponering",
    "opponerings": "opponering",
    "opportuna": "opportun",
    "opportunare": "opportun",
    "opportunares": "opportun",
    "opportunas": "opportun",
    "opportunast": "opportun",
    "opportunaste": "opportun",
    "opportunastes": "opportun",
    "opportunasts": "opportun",
    "opportune": "opportun",
    "opportunes": "opportun",
    "opportunheten": "opportunhet",
    "opportunhetens": "opportunhet",
    "opportunhets": "opportunhet",
    "opportunismen": "opportunism",
    "opportunismens": "opportunism",
    "opportunismer": "opportunism",
    "opportunismerna": "opportunism",
    "opportunismernas": "opportunism",
    "opportunismers": "opportunism",
    "opportunisms": "opportunism",
    "opportunisten": "opportunist",
    "opportunistens": "opportunist",
    "opportunister": "opportunist",
    "opportunisterna": "opportunist",
    "opportunisternas": "opportunist",
    "opportunisters": "opportunist",
    "opportunistiska": "opportunistisk",
    "opportunistiskare": "opportunistisk",
    "opportunistiskares": "opportunistisk",
    "opportunistiskas": "opportunistisk",
    "opportunistiskast": "opportunistisk",
    "opportunistiskaste": "opportunistisk",
    "opportunistiskastes": "opportunistisk",
    "opportunistiskasts": "opportunistisk",
    "opportunistiske": "opportunistisk",
    "opportunistiskes": "opportunistisk",
    "opportunistisks": "opportunistisk",
    "opportunistiskt": "opportunistisk",
    "opportunistiskts": "opportunistisk",
    "opportunists": "opportunist",
    "opportunitetsprincipen": "opportunitetsprincip",
    "opportunitetsprincipens": "opportunitetsprincip",
    "opportunitetsprincips": "opportunitetsprincip",
    "opportuns": "opportun",
    "opportunt": "opportun",
    "opportunts": "opportun",
    "oppositionella": "oppositionell",
    "oppositionellare": "oppositionell",
    "oppositionellares": "oppositionell",
    "oppositionellas": "oppositionell",
    "oppositionellast": "oppositionell",
    "oppositionellaste": "oppositionell",
    "oppositionellastes": "oppositionell",
    "oppositionellasts": "oppositionell",
    "oppositionelle": "oppositionell",
    "oppositionelles": "oppositionell",
    "oppositionells": "oppositionell",
    "oppositionellt": "oppositionell",
    "oppositionellts": "oppositionell",
    "oppositionen": "opposition",
    "oppositionens": "opposition",
    "oppositioner": "opposition",
    "oppositionerna": "opposition",
    "oppositionernas": "opposition",
    "oppositioners": "opposition",
    "oppositions": "opposition",
    "oppositionsaktivisten": "oppositionsaktivist",
    "oppositionsaktivistens": "oppositionsaktivist",
    "oppositionsaktivister": "oppositionsaktivist",
    "oppositionsaktivisterna": "oppositionsaktivist",
    "oppositionsaktivisternas": "oppositionsaktivist",
    "oppositionsaktivisters": "oppositionsaktivist",
    "oppositionsaktivists": "oppositionsaktivist",
    "oppositionsledar": "oppositionsledare",
    "oppositionsledaren": "oppositionsledare",
    "oppositionsledarens": "oppositionsledare",
    "oppositionsledares": "oppositionsledare",
    "oppositionsledarna": "oppositionsledare",
    "oppositionsledarnas": "oppositionsledare",
    "oppositionspartier": "oppositionsparti",
    "oppositionspartierna": "oppositionsparti",
    "oppositionspartiernas": "oppositionsparti",
    "oppositionspartiers": "oppositionsparti",
    "oppositionspartiet": "oppositionsparti",
    "oppositionspartiets": "oppositionsparti",
    "oppositionspartis": "oppositionsparti",
    "oppositionspartit": "oppositionsparti",
    "oppositionspartits": "oppositionsparti",
    "opprad": "opprada",
    "oppradad": "opprada",
    "oppradade": "opprada",
    "oppradades": "opprada",
    "oppradads": "opprada",
    "oppradande": "opprada",
    "oppradanden": "oppradande",
    "oppradandena": "oppradande",
    "oppradandenas": "oppradande",
    "oppradandens": "oppradande",
    "oppradandes": "oppradande",
    "oppradandet": "oppradande",
    "oppradandets": "oppradande",
    "oppradar": "opprada",
    "oppradas": "opprada",
    "oppradat": "opprada",
    "oppradats": "opprada",
    "opprens": "opprensa",
    "opprensad": "opprensa",
    "opprensade": "opprensa",
    "opprensades": "opprensa",
    "opprensads": "opprensa",
    "opprensande": "opprensa",
    "opprensanden": "opprensande",
    "opprensandena": "opprensande",
    "opprensandenas": "opprensande",
    "opprensandens": "opprensande",
    "opprensandes": "opprensande",
    "opprensandet": "opprensande",
    "opprensandets": "opprensande",
    "opprensar": "opprensa",
    "opprensas": "opprensa",
    "opprensat": "opprensa",
    "opprensats": "opprensa",
    "oppretade": "oppretad",
    "oppretades": "oppretad",
    "oppretads": "oppretad",
    "oppretat": "oppretad",
    "oppretats": "oppretad",
    "oppräknad": "oppräkna",
    "oppräknade": "oppräkna",
    "oppräknades": "oppräkna",
    "oppräknads": "oppräkna",
    "oppräknande": "oppräkna",
    "oppräknanden": "oppräknande",
    "oppräknandena": "oppräknande",
    "oppräknandenas": "oppräknande",
    "oppräknandens": "oppräknande",
    "oppräknandes": "oppräknande",
    "oppräknandet": "oppräknande",
    "oppräknandets": "oppräknande",
    "oppräknar": "oppräkna",
    "oppräknas": "oppräkna",
    "oppräknat": "oppräkna",
    "oppräknats": "oppräkna",
    "oppräkningar": "oppräkning",
    "oppräkningarna": "oppräkning",
    "oppräkningarnas": "oppräkning",
    "oppräkningars": "oppräkning",
    "oppräkningen": "oppräkning",
    "oppräkningens": "oppräkning",
    "oppräknings": "oppräkning",
    "opprätt": "opprätta",
    "opprätta": "opprätt",
    "opprättad": "opprätta",
    "opprättade": "opprätta",
    "opprättades": "opprätta",
    "opprättads": "opprätta",
    "opprättande": "opprätta",
    "opprättanden": "opprättande",
    "opprättandena": "opprättande",
    "opprättandenas": "opprättande",
    "opprättandens": "opprättande",
    "opprättandes": "opprättande",
    "opprättandet": "opprättande",
    "opprättandets": "opprättande",
    "opprättar": "opprätta",
    "opprättare": "opprätt",
    "opprättares": "opprätt",
    "opprättas": "opprätta",
    "opprättast": "opprätt",
    "opprättaste": "opprätt",
    "opprättastes": "opprätt",
    "opprättasts": "opprätt",
    "opprättat": "opprätta",
    "opprättats": "opprätta",
    "opprätte": "opprätt",
    "opprättes": "opprätt",
    "opprätts": "opprätt",
    "oppsamlad": "oppsamla",
    "oppsamlade": "oppsamla",
    "oppsamlades": "oppsamla",
    "oppsamlads": "oppsamla",
    "oppsamlande": "oppsamla",
    "oppsamlanden": "oppsamlande",
    "oppsamlandena": "oppsamlande",
    "oppsamlandenas": "oppsamlande",
    "oppsamlandens": "oppsamlande",
    "oppsamlandes": "oppsamlande",
    "oppsamlandet": "oppsamlande",
    "oppsamlandets": "oppsamlande",
    "oppsamlar": "oppsamla",
    "oppsamlas": "oppsamla",
    "oppsamlat": "oppsamla",
    "oppsamlats": "oppsamla",
    "oppsatt": "oppsätta",
    "oppsatta": "oppsätta",
    "oppsattas": "oppsätta",
    "oppsatte": "oppsätta",
    "oppsattes": "oppsätta",
    "oppsatts": "oppsätta",
    "oppskjut": "oppskjuta",
    "oppskjutande": "oppskjuta",
    "oppskjutanden": "oppskjutande",
    "oppskjutandena": "oppskjutande",
    "oppskjutandenas": "oppskjutande",
    "oppskjutandens": "oppskjutande",
    "oppskjutandes": "oppskjutande",
    "oppskjutandet": "oppskjutande",
    "oppskjutandets": "oppskjutande",
    "oppskjutas": "oppskjuta",
    "oppskjute": "oppskjuta",
    "oppskjuten": "oppskjuta",
    "oppskjutens": "oppskjuta",
    "oppskjuter": "oppskjuta",
    "oppskjutes": "oppskjuta",
    "oppskjutet": "oppskjuta",
    "oppskjutets": "oppskjuta",
    "oppskjutit": "oppskjuta",
    "oppskjutits": "oppskjuta",
    "oppskjutna": "oppskjuta",
    "oppskjutnas": "oppskjuta",
    "oppskjutne": "oppskjuta",
    "oppskjutnes": "oppskjuta",
    "oppskjutningar": "oppskjutning",
    "oppskjutningarna": "oppskjutning",
    "oppskjutningarnas": "oppskjutning",
    "oppskjutningars": "oppskjutning",
    "oppskjutningen": "oppskjutning",
    "oppskjutningens": "oppskjutning",
    "oppskjutnings": "oppskjutning",
    "oppskjuts": "oppskjuta",
    "oppskojade": "oppskojad",
    "oppskojades": "oppskojad",
    "oppskojads": "oppskojad",
    "oppskojat": "oppskojad",
    "oppskojats": "oppskojad",
    "oppskrivningar": "oppskrivning",
    "oppskrivningarna": "oppskrivning",
    "oppskrivningarnas": "oppskrivning",
    "oppskrivningars": "oppskrivning",
    "oppskrivningen": "oppskrivning",
    "oppskrivningens": "oppskrivning",
    "oppskrivnings": "oppskrivning",
    "oppsköt": "oppskjuta",
    "oppsköte": "oppskjuta",
    "oppskötes": "oppskjuta",
    "oppsköts": "oppskjuta",
    "oppsnabb": "oppsnabba",
    "oppsnabbad": "oppsnabba",
    "oppsnabbade": "oppsnabba",
    "oppsnabbades": "oppsnabba",
    "oppsnabbads": "oppsnabba",
    "oppsnabbande": "oppsnabba",
    "oppsnabbanden": "oppsnabbande",
    "oppsnabbandena": "oppsnabbande",
    "oppsnabbandenas": "oppsnabbande",
    "oppsnabbandens": "oppsnabbande",
    "oppsnabbandes": "oppsnabbande",
    "oppsnabbandet": "oppsnabbande",
    "oppsnabbandets": "oppsnabbande",
    "oppsnabbar": "oppsnabba",
    "oppsnabbas": "oppsnabba",
    "oppsnabbat": "oppsnabba",
    "oppsnabbats": "oppsnabba",
    "oppspärrade": "oppspärrad",
    "oppspärrades": "oppspärrad",
    "oppspärrads": "oppspärrad",
    "oppspärrat": "oppspärrad",
    "oppspärrats": "oppspärrad",
    "oppströmmar": "oppström",
    "oppströmmarna": "oppström",
    "oppströmmarnas": "oppström",
    "oppströmmars": "oppström",
    "oppströmmen": "oppström",
    "oppströmmens": "oppström",
    "oppströms": "oppström",
    "oppställ": "oppställa",
    "oppställande": "oppställa",
    "oppställanden": "oppställande",
    "oppställandena": "oppställande",
    "oppställandenas": "oppställande",
    "oppställandens": "oppställande",
    "oppställandes": "oppställande",
    "oppställandet": "oppställande",
    "oppställandets": "oppställande",
    "oppställas": "oppställa",
    "oppställd": "oppställa",
    "oppställda": "oppställa",
    "oppställdas": "oppställa",
    "oppställde": "oppställa",
    "oppställdes": "oppställa",
    "oppställds": "oppställa",
    "oppställer": "oppställa",
    "oppställes": "oppställa",
    "oppställningar": "oppställning",
    "oppställningarna": "oppställning",
    "oppställningarnas": "oppställning",
    "oppställningars": "oppställning",
    "oppställningen": "oppställning",
    "oppställningens": "oppställning",
    "oppställnings": "oppställning",
    "oppställningsplatsen": "oppställningsplats",
    "oppställningsplatsens": "oppställningsplats",
    "oppställningsplatser": "oppställningsplats",
    "oppställningsplatserna": "oppställningsplats",
    "oppställningsplatsernas": "oppställningsplats",
    "oppställningsplatsers": "oppställningsplats",
    "oppställningssignalen": "oppställningssignal",
    "oppställningssignalens": "oppställningssignal",
    "oppställningssignaler": "oppställningssignal",
    "oppställningssignalerna": "oppställningssignal",
    "oppställningssignalernas": "oppställningssignal",
    "oppställningssignalers": "oppställningssignal",
    "oppställningssignals": "oppställningssignal",
    "oppställningsspåren": "oppställningsspår",
    "oppställningsspårens": "oppställningsspår",
    "oppställningsspåret": "oppställningsspår",
    "oppställningsspårets": "oppställningsspår",
    "oppställningsspårs": "oppställningsspår",
    "oppställs": "oppställa",
    "oppställt": "oppställa",
    "oppställts": "oppställa",
    "oppstötningar": "oppstötning",
    "oppstötningarna": "oppstötning",
    "oppstötningarnas": "oppstötning",
    "oppstötningars": "oppstötning",
    "oppstötningen": "oppstötning",
    "oppstötningens": "oppstötning",
    "oppstötnings": "oppstötning",
    "oppsug": "oppsuga",
    "oppsugande": "oppsuga",
    "oppsuganden": "oppsugande",
    "oppsugandena": "oppsugande",
    "oppsugandenas": "oppsugande",
    "oppsugandens": "oppsugande",
    "oppsugandes": "oppsugande",
    "oppsugandet": "oppsugande",
    "oppsugandets": "oppsugande",
    "oppsugas": "oppsuga",
    "oppsuge": "oppsuga",
    "oppsugen": "oppsuga",
    "oppsugens": "oppsuga",
    "oppsuger": "oppsuga",
    "oppsuges": "oppsuga",
    "oppsuget": "oppsuga",
    "oppsugets": "oppsuga",
    "oppsugit": "oppsuga",
    "oppsugits": "oppsuga",
    "oppsugna": "oppsuga",
    "oppsugnas": "oppsuga",
    "oppsugne": "oppsuga",
    "oppsugnes": "oppsuga",
    "oppsugningar": "oppsugning",
    "oppsugningarna": "oppsugning",
    "oppsugningarnas": "oppsugning",
    "oppsugningars": "oppsugning",
    "oppsugningen": "oppsugning",
    "oppsugningens": "oppsugning",
    "oppsugnings": "oppsugning",
    "oppsugs": "oppsuga",
    "oppsummerad": "oppsummera",
    "oppsummerade": "oppsummera",
    "oppsummerades": "oppsummera",
    "oppsummerads": "oppsummera",
    "oppsummerande": "oppsummera",
    "oppsummeranden": "oppsummerande",
    "oppsummerandena": "oppsummerande",
    "oppsummerandenas": "oppsummerande",
    "oppsummerandens": "oppsummerande",
    "oppsummerandes": "oppsummerande",
    "oppsummerandet": "oppsummerande",
    "oppsummerandets": "oppsummerande",
    "oppsummerar": "oppsummera",
    "oppsummeras": "oppsummera",
    "oppsummerat": "oppsummera",
    "oppsummerats": "oppsummera",
    "oppsummerbara": "oppsummerbar",
    "oppsummerbarare": "oppsummerbar",
    "oppsummerbarares": "oppsummerbar",
    "oppsummerbaras": "oppsummerbar",
    "oppsummerbarast": "oppsummerbar",
    "oppsummerbaraste": "oppsummerbar",
    "oppsummerbarastes": "oppsummerbar",
    "oppsummerbarasts": "oppsummerbar",
    "oppsummerbare": "oppsummerbar",
    "oppsummerbares": "oppsummerbar",
    "oppsummerbarheten": "oppsummerbarhet",
    "oppsummerbarhetens": "oppsummerbarhet",
    "oppsummerbarhets": "oppsummerbarhet",
    "oppsummerbars": "oppsummerbar",
    "oppsummerbart": "oppsummerbar",
    "oppsummerbarts": "oppsummerbar",
    "oppsummeringar": "oppsummering",
    "oppsummeringarna": "oppsummering",
    "oppsummeringarnas": "oppsummering",
    "oppsummeringars": "oppsummering",
    "oppsummeringen": "oppsummering",
    "oppsummeringens": "oppsummering",
    "oppsummerings": "oppsummering",
    "oppsuttens": "oppsutten",
    "oppsuttet": "oppsutten",
    "oppsuttets": "oppsutten",
    "oppsuttna": "oppsutten",
    "oppsuttnas": "oppsutten",
    "oppsuttne": "oppsutten",
    "oppsuttnes": "oppsutten",
    "oppsvingen": "oppsving",
    "oppsvingens": "oppsving",
    "oppsvinget": "oppsving",
    "oppsvingets": "oppsving",
    "oppsvings": "oppsving",
    "oppsätt": "oppsätta",
    "oppsättande": "oppsätta",
    "oppsättanden": "oppsättande",
    "oppsättandena": "oppsättande",
    "oppsättandenas": "oppsättande",
    "oppsättandens": "oppsättande",
    "oppsättandes": "oppsättande",
    "oppsättandet": "oppsättande",
    "oppsättandets": "oppsättande",
    "oppsättas": "oppsätta",
    "oppsätter": "oppsätta",
    "oppsättes": "oppsätta",
    "oppsätts": "oppsätta",
    "oppsög": "oppsuga",
    "oppsöge": "oppsuga",
    "oppsöges": "oppsuga",
    "oppsögs": "oppsuga",
    "oppsök": "oppsöka",
    "oppsökande": "oppsöka",
    "oppsökanden": "oppsökande",
    "oppsökandena": "oppsökande",
    "oppsökandenas": "oppsökande",
    "oppsökandens": "oppsökande",
    "oppsökandes": "oppsökande",
    "oppsökandet": "oppsökande",
    "oppsökandets": "oppsökande",
    "oppsökas": "oppsöka",
    "oppsöker": "oppsöka",
    "oppsökes": "oppsöka",
    "oppsöks": "oppsöka",
    "oppsökt": "oppsöka",
    "oppsökta": "oppsöka",
    "oppsöktas": "oppsöka",
    "oppsökte": "oppsöka",
    "oppsöktes": "oppsöka",
    "oppsökts": "oppsöka",
    "opptag": "oppta",
    "opptaga": "oppta",
    "opptagande": "oppta",
    "opptaganden": "opptagande",
    "opptagandena": "opptagande",
    "opptagandenas": "opptagande",
    "opptagandens": "opptagande",
    "opptagandes": "opptagande",
    "opptagandet": "opptagande",
    "opptagandets": "opptagande",
    "opptagas": "oppta",
    "opptage": "oppta",
    "opptagen": "oppta",
    "opptagenheten": "opptagenhet",
    "opptagenhetens": "opptagenhet",
    "opptagenheter": "opptagenhet",
    "opptagenheterna": "opptagenhet",
    "opptagenheternas": "opptagenhet",
    "opptagenheters": "opptagenhet",
    "opptagenhets": "opptagenhet",
    "opptagens": "opptagen",
    "opptager": "oppta",
    "opptages": "oppta",
    "opptaget": "opptagen",
    "opptagets": "opptagen",
    "opptagit": "oppta",
    "opptagits": "oppta",
    "opptagna": "opptagen",
    "opptagnare": "opptagen",
    "opptagnares": "opptagen",
    "opptagnas": "opptagen",
    "opptagnast": "opptagen",
    "opptagnaste": "opptagen",
    "opptagnastes": "opptagen",
    "opptagnasts": "opptagen",
    "opptagne": "opptagen",
    "opptagnes": "opptagen",
    "opptagningar": "opptagning",
    "opptagningarna": "opptagning",
    "opptagningarnas": "opptagning",
    "opptagningars": "opptagning",
    "opptagningen": "opptagning",
    "opptagningens": "opptagning",
    "opptagnings": "opptagning",
    "opptags": "opptag",
    "opptar": "oppta",
    "opptas": "oppta",
    "opptog": "oppta",
    "opptoge": "oppta",
    "opptoges": "oppta",
    "opptogs": "oppta",
    "opptorn": "opptorna",
    "opptornad": "opptorna",
    "opptornade": "opptorna",
    "opptornades": "opptorna",
    "opptornads": "opptorna",
    "opptornande": "opptorna",
    "opptornanden": "opptornande",
    "opptornandena": "opptornande",
    "opptornandenas": "opptornande",
    "opptornandens": "opptornande",
    "opptornandes": "opptornande",
    "opptornandet": "opptornande",
    "opptornandets": "opptornande",
    "opptornar": "opptorna",
    "opptornas": "opptorna",
    "opptornat": "opptorna",
    "opptornats": "opptorna",
    "opptrapp": "opptrappa",
    "opptrappad": "opptrappa",
    "opptrappade": "opptrappa",
    "opptrappades": "opptrappa",
    "opptrappads": "opptrappa",
    "opptrappande": "opptrappa",
    "opptrappanden": "opptrappande",
    "opptrappandena": "opptrappande",
    "opptrappandenas": "opptrappande",
    "opptrappandens": "opptrappande",
    "opptrappandes": "opptrappande",
    "opptrappandet": "opptrappande",
    "opptrappandets": "opptrappande",
    "opptrappar": "opptrappa",
    "opptrappas": "opptrappa",
    "opptrappat": "opptrappa",
    "opptrappats": "opptrappa",
    "opptriss": "opptrissa",
    "opptrissad": "opptrissa",
    "opptrissade": "opptrissa",
    "opptrissades": "opptrissa",
    "opptrissads": "opptrissa",
    "opptrissande": "opptrissa",
    "opptrissanden": "opptrissande",
    "opptrissandena": "opptrissande",
    "opptrissandenas": "opptrissande",
    "opptrissandens": "opptrissande",
    "opptrissandes": "opptrissande",
    "opptrissandet": "opptrissande",
    "opptrissandets": "opptrissande",
    "opptrissar": "opptrissa",
    "opptrissas": "opptrissa",
    "opptrissat": "opptrissa",
    "opptrissats": "opptrissa",
    "oppvaknandes": "oppvaknande",
    "oppvaknandet": "oppvaknande",
    "oppvaknandets": "oppvaknande",
    "oppvakt": "oppvakta",
    "oppvaktad": "oppvakta",
    "oppvaktade": "oppvakta",
    "oppvaktades": "oppvakta",
    "oppvaktads": "oppvakta",
    "oppvaktande": "oppvakta",
    "oppvaktanden": "oppvaktande",
    "oppvaktandena": "oppvaktande",
    "oppvaktandenas": "oppvaktande",
    "oppvaktandens": "oppvaktande",
    "oppvaktandes": "oppvaktande",
    "oppvaktandet": "oppvaktande",
    "oppvaktandets": "oppvaktande",
    "oppvaktar": "oppvakta",
    "oppvaktas": "oppvakta",
    "oppvaktat": "oppvakta",
    "oppvaktats": "oppvakta",
    "oppvaktningar": "oppvaktning",
    "oppvaktningarna": "oppvaktning",
    "oppvaktningarnas": "oppvaktning",
    "oppvaktningars": "oppvaktning",
    "oppvaktningen": "oppvaktning",
    "oppvaktningens": "oppvaktning",
    "oppvaktnings": "oppvaktning",
    "oppvikta": "oppvikt",
    "oppviktas": "oppvikt",
    "oppvikte": "oppvikt",
    "oppviktes": "oppvikt",
    "oppvikts": "oppvikt",
    "oppvilade": "oppvilad",
    "oppvilades": "oppvilad",
    "oppvilads": "oppvilad",
    "oppvilat": "oppvilad",
    "oppvilats": "oppvilad",
    "oppvisad": "oppvisa",
    "oppvisade": "oppvisa",
    "oppvisades": "oppvisa",
    "oppvisads": "oppvisa",
    "oppvisande": "oppvisa",
    "oppvisanden": "oppvisande",
    "oppvisandena": "oppvisande",
    "oppvisandenas": "oppvisande",
    "oppvisandens": "oppvisande",
    "oppvisandes": "oppvisande",
    "oppvisandet": "oppvisande",
    "oppvisandets": "oppvisande",
    "oppvisar": "oppvisa",
    "oppvisas": "oppvisa",
    "oppvisat": "oppvisa",
    "oppvisats": "oppvisa",
    "oppvisningar": "oppvisning",
    "oppvisningarna": "oppvisning",
    "oppvisningarnas": "oppvisning",
    "oppvisningars": "oppvisning",
    "oppvisningen": "oppvisning",
    "oppvisningens": "oppvisning",
    "oppvisnings": "oppvisning",
    "oppvuxe": "oppväxa",
    "oppvuxen": "oppväxa",
    "oppvuxens": "oppvuxen",
    "oppvuxet": "oppvuxen",
    "oppvuxets": "oppvuxen",
    "oppvuxit": "oppväxa",
    "oppvuxna": "oppvuxen",
    "oppvuxnare": "oppvuxen",
    "oppvuxnares": "oppvuxen",
    "oppvuxnas": "oppvuxen",
    "oppvuxnast": "oppvuxen",
    "oppvuxnaste": "oppvuxen",
    "oppvuxnastes": "oppvuxen",
    "oppvuxnasts": "oppvuxen",
    "oppvuxne": "oppvuxen",
    "oppvuxnes": "oppvuxen",
    "oppväg": "oppväga",
    "oppvägande": "oppväga",
    "oppväganden": "oppvägande",
    "oppvägandena": "oppvägande",
    "oppvägandenas": "oppvägande",
    "oppvägandens": "oppvägande",
    "oppvägandes": "oppvägande",
    "oppvägandet": "oppvägande",
    "oppvägandets": "oppvägande",
    "oppvägas": "oppväga",
    "oppvägd": "oppväga",
    "oppvägda": "oppväga",
    "oppvägdas": "oppväga",
    "oppvägde": "oppväga",
    "oppvägdes": "oppväga",
    "oppvägds": "oppväga",
    "oppväger": "oppväga",
    "oppväges": "oppväga",
    "oppvägningar": "oppvägning",
    "oppvägningarna": "oppvägning",
    "oppvägningarnas": "oppvägning",
    "oppvägningars": "oppvägning",
    "oppvägningen": "oppvägning",
    "oppvägningens": "oppvägning",
    "oppvägnings": "oppvägning",
    "oppvägs": "oppväga",
    "oppvägt": "oppväga",
    "oppvägts": "oppväga",
    "oppvärderad": "oppvärdera",
    "oppvärderade": "oppvärdera",
    "oppvärderades": "oppvärdera",
    "oppvärderads": "oppvärdera",
    "oppvärderande": "oppvärdera",
    "oppvärderanden": "oppvärderande",
    "oppvärderandena": "oppvärderande",
    "oppvärderandenas": "oppvärderande",
    "oppvärderandens": "oppvärderande",
    "oppvärderandes": "oppvärderande",
    "oppvärderandet": "oppvärderande",
    "oppvärderandets": "oppvärderande",
    "oppvärderar": "oppvärdera",
    "oppvärderas": "oppvärdera",
    "oppvärderat": "oppvärdera",
    "oppvärderats": "oppvärdera",
    "oppvärderbara": "oppvärderbar",
    "oppvärderbarare": "oppvärderbar",
    "oppvärderbarares": "oppvärderbar",
    "oppvärderbaras": "oppvärderbar",
    "oppvärderbarast": "oppvärderbar",
    "oppvärderbaraste": "oppvärderbar",
    "oppvärderbarastes": "oppvärderbar",
    "oppvärderbarasts": "oppvärderbar",
    "oppvärderbare": "oppvärderbar",
    "oppvärderbares": "oppvärderbar",
    "oppvärderbarheten": "oppvärderbarhet",
    "oppvärderbarhetens": "oppvärderbarhet",
    "oppvärderbarhets": "oppvärderbarhet",
    "oppvärderbars": "oppvärderbar",
    "oppvärderbart": "oppvärderbar",
    "oppvärderbarts": "oppvärderbar",
    "oppvärderingar": "oppvärdering",
    "oppvärderingarna": "oppvärdering",
    "oppvärderingarnas": "oppvärdering",
    "oppvärderingars": "oppvärdering",
    "oppvärderingen": "oppvärdering",
    "oppvärderingens": "oppvärdering",
    "oppvärderings": "oppvärdering",
    "oppvärm": "oppvärma",
    "oppvärmande": "oppvärma",
    "oppvärmanden": "oppvärmande",
    "oppvärmandena": "oppvärmande",
    "oppvärmandenas": "oppvärmande",
    "oppvärmandens": "oppvärmande",
    "oppvärmandes": "oppvärmande",
    "oppvärmandet": "oppvärmande",
    "oppvärmandets": "oppvärmande",
    "oppvärmas": "oppvärma",
    "oppvärmd": "oppvärma",
    "oppvärmda": "oppvärma",
    "oppvärmdas": "oppvärma",
    "oppvärmde": "oppvärma",
    "oppvärmdes": "oppvärma",
    "oppvärmds": "oppvärma",
    "oppvärmer": "oppvärma",
    "oppvärmningar": "oppvärmning",
    "oppvärmningarna": "oppvärmning",
    "oppvärmningarnas": "oppvärmning",
    "oppvärmningars": "oppvärmning",
    "oppvärmningen": "oppvärmning",
    "oppvärmningens": "oppvärmning",
    "oppvärmnings": "oppvärmning",
    "oppvärms": "oppvärma",
    "oppvärmt": "oppvärma",
    "oppvärmts": "oppvärma",
    "oppväx": "oppväxa",
    "oppväxande": "oppväxa",
    "oppväxanden": "oppväxande",
    "oppväxandena": "oppväxande",
    "oppväxandenas": "oppväxande",
    "oppväxandens": "oppväxande",
    "oppväxandes": "oppväxande",
    "oppväxandet": "oppväxande",
    "oppväxandets": "oppväxande",
    "oppväxe": "oppväxa",
    "oppväxer": "oppväxa",
    "oppväxt": "oppväxa",
    "oppväxte": "oppväxa",
    "oppväxten": "oppväxt",
    "oppväxtens": "oppväxt",
    "oppväxts": "oppväxt",
    "oppät": "oppäta",
    "oppätande": "oppäta",
    "oppätanden": "oppätande",
    "oppätandena": "oppätande",
    "oppätandenas": "oppätande",
    "oppätandens": "oppätande",
    "oppätandes": "oppätande",
    "oppätandet": "oppätande",
    "oppätandets": "oppätande",
    "oppätas": "oppäta",
    "oppäte": "oppäta",
    "oppäten": "oppäta",
    "oppätens": "oppäta",
    "oppäter": "oppäta",
    "oppätes": "oppäta",
    "oppätet": "oppäta",
    "oppätets": "oppäta",
    "oppätit": "oppäta",
    "oppätits": "oppäta",
    "oppätna": "oppäta",
    "oppätnas": "oppäta",
    "oppätne": "oppäta",
    "oppätnes": "oppäta",
    "oppäts": "oppäta",
    "oppåkta": "oppåkt",
    "oppåktas": "oppåkt",
    "oppåkte": "oppåkt",
    "oppåktes": "oppåkt",
    "oppåkts": "oppåkt",
    "oppånedvända": "oppånedvänd",
    "oppånedvändare": "oppånedvänd",
    "oppånedvändares": "oppånedvänd",
    "oppånedvändas": "oppånedvänd",
    "oppånedvändast": "oppånedvänd",
    "oppånedvändaste": "oppånedvänd",
    "oppånedvändastes": "oppånedvänd",
    "oppånedvändasts": "oppånedvänd",
    "oppånedvände": "oppånedvänd",
    "oppånedvändes": "oppånedvänd",
    "oppånedvändheten": "oppånedvändhet",
    "oppånedvändhetens": "oppånedvändhet",
    "oppånedvändhets": "oppånedvändhet",
    "oppånedvänds": "oppånedvänd",
    "oppånedvänt": "oppånedvänd",
    "oppånedvänts": "oppånedvänd",
    "oppånervända": "oppånervänd",
    "oppånervändare": "oppånervänd",
    "oppånervändares": "oppånervänd",
    "oppånervändas": "oppånervänd",
    "oppånervändast": "oppånervänd",
    "oppånervändaste": "oppånervänd",
    "oppånervändastes": "oppånervänd",
    "oppånervändasts": "oppånervänd",
    "oppånervände": "oppånervänd",
    "oppånervändes": "oppånervänd",
    "oppånervändheten": "oppånervändhet",
    "oppånervändhetens": "oppånervändhet",
    "oppånervändhets": "oppånervändhet",
    "oppånervänds": "oppånervänd",
    "oppånervänt": "oppånervänd",
    "oppånervänts": "oppånervänd",
    "oppåt": "oppäta",
    "oppåte": "oppäta",
    "oppåtes": "oppäta",
    "oppåtgåendes": "oppåtgående",
    "oppåtgåendet": "oppåtgående",
    "oppåtgåendets": "oppåtgående",
    "oppåtkammade": "oppåtkammad",
    "oppåtkammades": "oppåtkammad",
    "oppåtkammads": "oppåtkammad",
    "oppåtkammat": "oppåtkammad",
    "oppåtkammats": "oppåtkammad",
    "oppåtriktade": "oppåtriktad",
    "oppåtriktades": "oppåtriktad",
    "oppåtriktads": "oppåtriktad",
    "oppåtriktat": "oppåtriktad",
    "oppåtriktats": "oppåtriktad",
    "oppåts": "oppäta",
    "oppåtsträvar": "oppåtsträvare",
    "oppåtsträvaren": "oppåtsträvare",
    "oppåtsträvarens": "oppåtsträvare",
    "oppåtsträvares": "oppåtsträvare",
    "oppåtsträvarna": "oppåtsträvare",
    "oppåtsträvarnas": "oppåtsträvare",
    "oppöv": "oppöva",
    "oppövad": "oppöva",
    "oppövade": "oppöva",
    "oppövades": "oppöva",
    "oppövads": "oppöva",
    "oppövande": "oppöva",
    "oppövanden": "oppövande",
    "oppövandena": "oppövande",
    "oppövandenas": "oppövande",
    "oppövandens": "oppövande",
    "oppövandes": "oppövande",
    "oppövandet": "oppövande",
    "oppövandets": "oppövande",
    "oppövar": "oppöva",
    "oppövas": "oppöva",
    "oppövat": "oppöva",
    "oppövats": "oppöva",
    "opraktiserade": "opraktiserad",
    "opraktiserades": "opraktiserad",
    "opraktiserads": "opraktiserad",
    "opraktiserat": "opraktiserad",
    "opraktiserats": "opraktiserad",
    "opraktiserbara": "opraktiserbar",
    "opraktiserbarare": "opraktiserbar",
    "opraktiserbarares": "opraktiserbar",
    "opraktiserbaras": "opraktiserbar",
    "opraktiserbarast": "opraktiserbar",
    "opraktiserbaraste": "opraktiserbar",
    "opraktiserbarastes": "opraktiserbar",
    "opraktiserbarasts": "opraktiserbar",
    "opraktiserbare": "opraktiserbar",
    "opraktiserbares": "opraktiserbar",
    "opraktiserbarheten": "opraktiserbarhet",
    "opraktiserbarhetens": "opraktiserbarhet",
    "opraktiserbarhets": "opraktiserbarhet",
    "opraktiserbars": "opraktiserbar",
    "opraktiserbart": "opraktiserbar",
    "opraktiserbarts": "opraktiserbar",
    "opraktiska": "opraktisk",
    "opraktiskare": "opraktisk",
    "opraktiskares": "opraktisk",
    "opraktiskas": "opraktisk",
    "opraktiskast": "opraktisk",
    "opraktiskaste": "opraktisk",
    "opraktiskastes": "opraktisk",
    "opraktiskasts": "opraktisk",
    "opraktiske": "opraktisk",
    "opraktiskes": "opraktisk",
    "opraktisks": "opraktisk",
    "opraktiskt": "opraktisk",
    "opraktiskts": "opraktisk",
    "oprecisa": "oprecis",
    "oprecisare": "oprecis",
    "oprecisares": "oprecis",
    "oprecisas": "oprecis",
    "oprecisast": "oprecis",
    "oprecisaste": "oprecis",
    "oprecisastes": "oprecis",
    "oprecisasts": "oprecis",
    "oprecise": "oprecis",
    "opreciserade": "opreciserad",
    "opreciserades": "opreciserad",
    "opreciserads": "opreciserad",
    "opreciserat": "opreciserad",
    "opreciserats": "opreciserad",
    "opreciserbara": "opreciserbar",
    "opreciserbarare": "opreciserbar",
    "opreciserbarares": "opreciserbar",
    "opreciserbaras": "opreciserbar",
    "opreciserbarast": "opreciserbar",
    "opreciserbaraste": "opreciserbar",
    "opreciserbarastes": "opreciserbar",
    "opreciserbarasts": "opreciserbar",
    "opreciserbare": "opreciserbar",
    "opreciserbares": "opreciserbar",
    "opreciserbarheten": "opreciserbarhet",
    "opreciserbarhetens": "opreciserbarhet",
    "opreciserbarhets": "opreciserbarhet",
    "opreciserbars": "opreciserbar",
    "opreciserbart": "opreciserbar",
    "opreciserbarts": "opreciserbar",
    "oprecises": "oprecis",
    "oprecisheten": "oprecishet",
    "oprecishetens": "oprecishet",
    "oprecishets": "oprecishet",
    "oprecist": "oprecis",
    "oprecists": "oprecis",
    "opredestinerade": "opredestinerad",
    "opredestinerades": "opredestinerad",
    "opredestinerads": "opredestinerad",
    "opredestinerat": "opredestinerad",
    "opredestinerats": "opredestinerad",
    "opredestinerbara": "opredestinerbar",
    "opredestinerbarare": "opredestinerbar",
    "opredestinerbarares": "opredestinerbar",
    "opredestinerbaras": "opredestinerbar",
    "opredestinerbarast": "opredestinerbar",
    "opredestinerbaraste": "opredestinerbar",
    "opredestinerbarastes": "opredestinerbar",
    "opredestinerbarasts": "opredestinerbar",
    "opredestinerbare": "opredestinerbar",
    "opredestinerbares": "opredestinerbar",
    "opredestinerbarheten": "opredestinerbarhet",
    "opredestinerbarhetens": "opredestinerbarhet",
    "opredestinerbarhets": "opredestinerbarhet",
    "opredestinerbars": "opredestinerbar",
    "opredestinerbart": "opredestinerbar",
    "opredestinerbarts": "opredestinerbar",
    "opredicerade": "opredicerad",
    "opredicerades": "opredicerad",
    "opredicerads": "opredicerad",
    "opredicerat": "opredicerad",
    "opredicerats": "opredicerad",
    "opredicerbara": "opredicerbar",
    "opredicerbarare": "opredicerbar",
    "opredicerbarares": "opredicerbar",
    "opredicerbaras": "opredicerbar",
    "opredicerbarast": "opredicerbar",
    "opredicerbaraste": "opredicerbar",
    "opredicerbarastes": "opredicerbar",
    "opredicerbarasts": "opredicerbar",
    "opredicerbare": "opredicerbar",
    "opredicerbares": "opredicerbar",
    "opredicerbarheten": "opredicerbarhet",
    "opredicerbarhetens": "opredicerbarhet",
    "opredicerbarhets": "opredicerbarhet",
    "opredicerbars": "opredicerbar",
    "opredicerbart": "opredicerbar",
    "opredicerbarts": "opredicerbar",
    "opredisponerade": "opredisponerad",
    "opredisponerades": "opredisponerad",
    "opredisponerads": "opredisponerad",
    "opredisponerat": "opredisponerad",
    "opredisponerats": "opredisponerad",
    "opredisponerbara": "opredisponerbar",
    "opredisponerbarare": "opredisponerbar",
    "opredisponerbarares": "opredisponerbar",
    "opredisponerbaras": "opredisponerbar",
    "opredisponerbarast": "opredisponerbar",
    "opredisponerbaraste": "opredisponerbar",
    "opredisponerbarastes": "opredisponerbar",
    "opredisponerbarasts": "opredisponerbar",
    "opredisponerbare": "opredisponerbar",
    "opredisponerbares": "opredisponerbar",
    "opredisponerbarheten": "opredisponerbarhet",
    "opredisponerbarhetens": "opredisponerbarhet",
    "opredisponerbarhets": "opredisponerbarhet",
    "opredisponerbars": "opredisponerbar",
    "opredisponerbart": "opredisponerbar",
    "opredisponerbarts": "opredisponerbar",
    "oprefabricerade": "oprefabricerad",
    "oprefabricerades": "oprefabricerad",
    "oprefabricerads": "oprefabricerad",
    "oprefabricerat": "oprefabricerad",
    "oprefabricerats": "oprefabricerad",
    "oprefabricerbara": "oprefabricerbar",
    "oprefabricerbarare": "oprefabricerbar",
    "oprefabricerbarares": "oprefabricerbar",
    "oprefabricerbaras": "oprefabricerbar",
    "oprefabricerbarast": "oprefabricerbar",
    "oprefabricerbaraste": "oprefabricerbar",
    "oprefabricerbarastes": "oprefabricerbar",
    "oprefabricerbarasts": "oprefabricerbar",
    "oprefabricerbare": "oprefabricerbar",
    "oprefabricerbares": "oprefabricerbar",
    "oprefabricerbarheten": "oprefabricerbarhet",
    "oprefabricerbarhetens": "oprefabricerbarhet",
    "oprefabricerbarhets": "oprefabricerbarhet",
    "oprefabricerbars": "oprefabricerbar",
    "oprefabricerbart": "oprefabricerbar",
    "oprefabricerbarts": "oprefabricerbar",
    "oprefererade": "oprefererad",
    "oprefererades": "oprefererad",
    "oprefererads": "oprefererad",
    "oprefererat": "oprefererad",
    "oprefererats": "oprefererad",
    "oprefererbara": "oprefererbar",
    "oprefererbarare": "oprefererbar",
    "oprefererbarares": "oprefererbar",
    "oprefererbaras": "oprefererbar",
    "oprefererbarast": "oprefererbar",
    "oprefererbaraste": "oprefererbar",
    "oprefererbarastes": "oprefererbar",
    "oprefererbarasts": "oprefererbar",
    "oprefererbare": "oprefererbar",
    "oprefererbares": "oprefererbar",
    "oprefererbarheten": "oprefererbarhet",
    "oprefererbarhetens": "oprefererbarhet",
    "oprefererbarhets": "oprefererbarhet",
    "oprefererbars": "oprefererbar",
    "oprefererbart": "oprefererbar",
    "oprefererbarts": "oprefererbar",
    "oprefigerade": "oprefigerad",
    "oprefigerades": "oprefigerad",
    "oprefigerads": "oprefigerad",
    "oprefigerat": "oprefigerad",
    "oprefigerats": "oprefigerad",
    "oprefigerbara": "oprefigerbar",
    "oprefigerbarare": "oprefigerbar",
    "oprefigerbarares": "oprefigerbar",
    "oprefigerbaras": "oprefigerbar",
    "oprefigerbarast": "oprefigerbar",
    "oprefigerbaraste": "oprefigerbar",
    "oprefigerbarastes": "oprefigerbar",
    "oprefigerbarasts": "oprefigerbar",
    "oprefigerbare": "oprefigerbar",
    "oprefigerbares": "oprefigerbar",
    "oprefigerbarheten": "oprefigerbarhet",
    "oprefigerbarhetens": "oprefigerbarhet",
    "oprefigerbarhets": "oprefigerbarhet",
    "oprefigerbars": "oprefigerbar",
    "oprefigerbart": "oprefigerbar",
    "oprefigerbarts": "oprefigerbar",
    "oprejade": "oprejad",
    "oprejades": "oprejad",
    "oprejads": "oprejad",
    "oprejat": "oprejad",
    "oprejats": "oprejad",
    "opreludierade": "opreludierad",
    "opreludierades": "opreludierad",
    "opreludierads": "opreludierad",
    "opreludierat": "opreludierad",
    "opreludierats": "opreludierad",
    "opreludierbara": "opreludierbar",
    "opreludierbarare": "opreludierbar",
    "opreludierbarares": "opreludierbar",
    "opreludierbaras": "opreludierbar",
    "opreludierbarast": "opreludierbar",
    "opreludierbaraste": "opreludierbar",
    "opreludierbarastes": "opreludierbar",
    "opreludierbarasts": "opreludierbar",
    "opreludierbare": "opreludierbar",
    "opreludierbares": "opreludierbar",
    "opreludierbarheten": "opreludierbarhet",
    "opreludierbarhetens": "opreludierbarhet",
    "opreludierbarhets": "opreludierbarhet",
    "opreludierbars": "opreludierbar",
    "opreludierbart": "opreludierbar",
    "opreludierbarts": "opreludierbar",
    "opremierade": "opremierad",
    "opremierades": "opremierad",
    "opremierads": "opremierad",
    "opremierat": "opremierad",
    "opremierats": "opremierad",
    "opremierbara": "opremierbar",
    "opremierbarare": "opremierbar",
    "opremierbarares": "opremierbar",
    "opremierbaras": "opremierbar",
    "opremierbarast": "opremierbar",
    "opremierbaraste": "opremierbar",
    "opremierbarastes": "opremierbar",
    "opremierbarasts": "opremierbar",
    "opremierbare": "opremierbar",
    "opremierbares": "opremierbar",
    "opremierbarheten": "opremierbarhet",
    "opremierbarhetens": "opremierbarhet",
    "opremierbarhets": "opremierbarhet",
    "opremierbars": "opremierbar",
    "opremierbart": "opremierbar",
    "opremierbarts": "opremierbar",
    "opreparerade": "opreparerad",
    "opreparerades": "opreparerad",
    "opreparerads": "opreparerad",
    "opreparerat": "opreparerad",
    "opreparerats": "opreparerad",
    "opreparerbara": "opreparerbar",
    "opreparerbarare": "opreparerbar",
    "opreparerbarares": "opreparerbar",
    "opreparerbaras": "opreparerbar",
    "opreparerbarast": "opreparerbar",
    "opreparerbaraste": "opreparerbar",
    "opreparerbarastes": "opreparerbar",
    "opreparerbarasts": "opreparerbar",
    "opreparerbare": "opreparerbar",
    "opreparerbares": "opreparerbar",
    "opreparerbarheten": "opreparerbarhet",
    "opreparerbarhetens": "opreparerbarhet",
    "opreparerbarhets": "opreparerbarhet",
    "opreparerbars": "opreparerbar",
    "opreparerbart": "opreparerbar",
    "opreparerbarts": "opreparerbar",
    "opresentade": "opresentad",
    "opresentades": "opresentad",
    "opresentads": "opresentad",
    "opresentat": "opresentad",
    "opresentats": "opresentad",
    "opresenterade": "opresenterad",
    "opresenterades": "opresenterad",
    "opresenterads": "opresenterad",
    "opresenterat": "opresenterad",
    "opresenterats": "opresenterad",
    "opresenterbara": "opresenterbar",
    "opresenterbarare": "opresenterbar",
    "opresenterbarares": "opresenterbar",
    "opresenterbaras": "opresenterbar",
    "opresenterbarast": "opresenterbar",
    "opresenterbaraste": "opresenterbar",
    "opresenterbarastes": "opresenterbar",
    "opresenterbarasts": "opresenterbar",
    "opresenterbare": "opresenterbar",
    "opresenterbares": "opresenterbar",
    "opresenterbarheten": "opresenterbarhet",
    "opresenterbarhetens": "opresenterbarhet",
    "opresenterbarhets": "opresenterbarhet",
    "opresenterbars": "opresenterbar",
    "opresenterbart": "opresenterbar",
    "opresenterbarts": "opresenterbar",
    "opreserverade": "opreserverad",
    "opreserverades": "opreserverad",
    "opreserverads": "opreserverad",
    "opreserverat": "opreserverad",
    "opreserverats": "opreserverad",
    "opreserverbara": "opreserverbar",
    "opreserverbarare": "opreserverbar",
    "opreserverbarares": "opreserverbar",
    "opreserverbaras": "opreserverbar",
    "opreserverbarast": "opreserverbar",
    "opreserverbaraste": "opreserverbar",
    "opreserverbarastes": "opreserverbar",
    "opreserverbarasts": "opreserverbar",
    "opreserverbare": "opreserverbar",
    "opreserverbares": "opreserverbar",
    "opreserverbarheten": "opreserverbarhet",
    "opreserverbarhetens": "opreserverbarhet",
    "opreserverbarhets": "opreserverbarhet",
    "opreserverbars": "opreserverbar",
    "opreserverbart": "opreserverbar",
    "opreserverbarts": "opreserverbar",
    "opreskriberade": "opreskriberad",
    "opreskriberades": "opreskriberad",
    "opreskriberads": "opreskriberad",
    "opreskriberat": "opreskriberad",
    "opreskriberats": "opreskriberad",
    "opreskriberbara": "opreskriberbar",
    "opreskriberbarare": "opreskriberbar",
    "opreskriberbarares": "opreskriberbar",
    "opreskriberbaras": "opreskriberbar",
    "opreskriberbarast": "opreskriberbar",
    "opreskriberbaraste": "opreskriberbar",
    "opreskriberbarastes": "opreskriberbar",
    "opreskriberbarasts": "opreskriberbar",
    "opreskriberbare": "opreskriberbar",
    "opreskriberbares": "opreskriberbar",
    "opreskriberbarheten": "opreskriberbarhet",
    "opreskriberbarhetens": "opreskriberbarhet",
    "opreskriberbarhets": "opreskriberbarhet",
    "opreskriberbars": "opreskriberbar",
    "opreskriberbart": "opreskriberbar",
    "opreskriberbarts": "opreskriberbar",
    "opressade": "opressad",
    "opressades": "opressad",
    "opressads": "opressad",
    "opressat": "opressad",
    "opressats": "opressad",
    "opresterade": "opresterad",
    "opresterades": "opresterad",
    "opresterads": "opresterad",
    "opresterat": "opresterad",
    "opresterats": "opresterad",
    "opresterbara": "opresterbar",
    "opresterbarare": "opresterbar",
    "opresterbarares": "opresterbar",
    "opresterbaras": "opresterbar",
    "opresterbarast": "opresterbar",
    "opresterbaraste": "opresterbar",
    "opresterbarastes": "opresterbar",
    "opresterbarasts": "opresterbar",
    "opresterbare": "opresterbar",
    "opresterbares": "opresterbar",
    "opresterbarheten": "opresterbarhet",
    "opresterbarhetens": "opresterbarhet",
    "opresterbarhets": "opresterbarhet",
    "opresterbars": "opresterbar",
    "opresterbart": "opresterbar",
    "opresterbarts": "opresterbar",
    "opresumerade": "opresumerad",
    "opresumerades": "opresumerad",
    "opresumerads": "opresumerad",
    "opresumerat": "opresumerad",
    "opresumerats": "opresumerad",
    "opresumerbara": "opresumerbar",
    "opresumerbarare": "opresumerbar",
    "opresumerbarares": "opresumerbar",
    "opresumerbaras": "opresumerbar",
    "opresumerbarast": "opresumerbar",
    "opresumerbaraste": "opresumerbar",
    "opresumerbarastes": "opresumerbar",
    "opresumerbarasts": "opresumerbar",
    "opresumerbare": "opresumerbar",
    "opresumerbares": "opresumerbar",
    "opresumerbarheten": "opresumerbarhet",
    "opresumerbarhetens": "opresumerbarhet",
    "opresumerbarhets": "opresumerbarhet",
    "opresumerbars": "opresumerbar",
    "opresumerbart": "opresumerbar",
    "opresumerbarts": "opresumerbar",
    "opretentiösa": "opretentiös",
    "opretentiösare": "opretentiös",
    "opretentiösares": "opretentiös",
    "opretentiösas": "opretentiös",
    "opretentiösast": "opretentiös",
    "opretentiösaste": "opretentiös",
    "opretentiösastes": "opretentiös",
    "opretentiösasts": "opretentiös",
    "opretentiöse": "opretentiös",
    "opretentiöses": "opretentiös",
    "opretentiöst": "opretentiös",
    "opretentiösts": "opretentiös",
    "oprickade": "oprickad",
    "oprickades": "oprickad",
    "oprickads": "oprickad",
    "oprickat": "oprickad",
    "oprickats": "oprickad",
    "oprioriterade": "oprioriterad",
    "oprioriterades": "oprioriterad",
    "oprioriterads": "oprioriterad",
    "oprioriterat": "oprioriterad",
    "oprioriterats": "oprioriterad",
    "oprioriterbara": "oprioriterbar",
    "oprioriterbarare": "oprioriterbar",
    "oprioriterbarares": "oprioriterbar",
    "oprioriterbaras": "oprioriterbar",
    "oprioriterbarast": "oprioriterbar",
    "oprioriterbaraste": "oprioriterbar",
    "oprioriterbarastes": "oprioriterbar",
    "oprioriterbarasts": "oprioriterbar",
    "oprioriterbare": "oprioriterbar",
    "oprioriterbares": "oprioriterbar",
    "oprioriterbarheten": "oprioriterbarhet",
    "oprioriterbarhetens": "oprioriterbarhet",
    "oprioriterbarhets": "oprioriterbarhet",
    "oprioriterbars": "oprioriterbar",
    "oprioriterbart": "oprioriterbar",
    "oprioriterbarts": "oprioriterbar",
    "oprisade": "oprisad",
    "oprisades": "oprisad",
    "oprisads": "oprisad",
    "oprisat": "oprisad",
    "oprisats": "oprisad",
    "opriset": "opris",
    "oprisets": "opris",
    "oprivatiserade": "oprivatiserad",
    "oprivatiserades": "oprivatiserad",
    "oprivatiserads": "oprivatiserad",
    "oprivatiserat": "oprivatiserad",
    "oprivatiserats": "oprivatiserad",
    "oprivatiserbara": "oprivatiserbar",
    "oprivatiserbarare": "oprivatiserbar",
    "oprivatiserbarares": "oprivatiserbar",
    "oprivatiserbaras": "oprivatiserbar",
    "oprivatiserbarast": "oprivatiserbar",
    "oprivatiserbaraste": "oprivatiserbar",
    "oprivatiserbarastes": "oprivatiserbar",
    "oprivatiserbarasts": "oprivatiserbar",
    "oprivatiserbare": "oprivatiserbar",
    "oprivatiserbares": "oprivatiserbar",
    "oprivatiserbarheten": "oprivatiserbarhet",
    "oprivatiserbarhetens": "oprivatiserbarhet",
    "oprivatiserbarhets": "oprivatiserbarhet",
    "oprivatiserbars": "oprivatiserbar",
    "oprivatiserbart": "oprivatiserbar",
    "oprivatiserbarts": "oprivatiserbar",
    "oprivilegierade": "oprivilegierad",
    "oprivilegierades": "oprivilegierad",
    "oprivilegierads": "oprivilegierad",
    "oprivilegierat": "oprivilegierad",
    "oprivilegierats": "oprivilegierad",
    "oprivilegierbara": "oprivilegierbar",
    "oprivilegierbarare": "oprivilegierbar",
    "oprivilegierbarares": "oprivilegierbar",
    "oprivilegierbaras": "oprivilegierbar",
    "oprivilegierbarast": "oprivilegierbar",
    "oprivilegierbaraste": "oprivilegierbar",
    "oprivilegierbarastes": "oprivilegierbar",
    "oprivilegierbarasts": "oprivilegierbar",
    "oprivilegierbare": "oprivilegierbar",
    "oprivilegierbares": "oprivilegierbar",
    "oprivilegierbarheten": "oprivilegierbarhet",
    "oprivilegierbarhetens": "oprivilegierbarhet",
    "oprivilegierbarhets": "oprivilegierbarhet",
    "oprivilegierbars": "oprivilegierbar",
    "oprivilegierbart": "oprivilegierbar",
    "oprivilegierbarts": "oprivilegierbar",
    "oproberade": "oproberad",
    "oproberades": "oproberad",
    "oproberads": "oproberad",
    "oproberat": "oproberad",
    "oproberats": "oproberad",
    "oproberbara": "oproberbar",
    "oproberbarare": "oproberbar",
    "oproberbarares": "oproberbar",
    "oproberbaras": "oproberbar",
    "oproberbarast": "oproberbar",
    "oproberbaraste": "oproberbar",
    "oproberbarastes": "oproberbar",
    "oproberbarasts": "oproberbar",
    "oproberbare": "oproberbar",
    "oproberbares": "oproberbar",
    "oproberbarheten": "oproberbarhet",
    "oproberbarhetens": "oproberbarhet",
    "oproberbarhets": "oproberbarhet",
    "oproberbars": "oproberbar",
    "oproberbart": "oproberbar",
    "oproberbarts": "oproberbar",
    "oproblematiserade": "oproblematiserad",
    "oproblematiserades": "oproblematiserad",
    "oproblematiserads": "oproblematiserad",
    "oproblematiserat": "oproblematiserad",
    "oproblematiserats": "oproblematiserad",
    "oproblematiserbara": "oproblematiserbar",
    "oproblematiserbarare": "oproblematiserbar",
    "oproblematiserbarares": "oproblematiserbar",
    "oproblematiserbaras": "oproblematiserbar",
    "oproblematiserbarast": "oproblematiserbar",
    "oproblematiserbaraste": "oproblematiserbar",
    "oproblematiserbarastes": "oproblematiserbar",
    "oproblematiserbarasts": "oproblematiserbar",
    "oproblematiserbare": "oproblematiserbar",
    "oproblematiserbares": "oproblematiserbar",
    "oproblematiserbarheten": "oproblematiserbarhet",
    "oproblematiserbarhetens": "oproblematiserbarhet",
    "oproblematiserbarhets": "oproblematiserbarhet",
    "oproblematiserbars": "oproblematiserbar",
    "oproblematiserbart": "oproblematiserbar",
    "oproblematiserbarts": "oproblematiserbar",
    "oprocessade": "oprocessad",
    "oprocessades": "oprocessad",
    "oprocessads": "oprocessad",
    "oprocessat": "oprocessad",
    "oprocessats": "oprocessad",
    "oproducerade": "oproducerad",
    "oproducerades": "oproducerad",
    "oproducerads": "oproducerad",
    "oproducerat": "oproducerad",
    "oproducerats": "oproducerad",
    "oproducerbara": "oproducerbar",
    "oproducerbarare": "oproducerbar",
    "oproducerbarares": "oproducerbar",
    "oproducerbaras": "oproducerbar",
    "oproducerbarast": "oproducerbar",
    "oproducerbaraste": "oproducerbar",
    "oproducerbarastes": "oproducerbar",
    "oproducerbarasts": "oproducerbar",
    "oproducerbare": "oproducerbar",
    "oproducerbares": "oproducerbar",
    "oproducerbarheten": "oproducerbarhet",
    "oproducerbarhetens": "oproducerbarhet",
    "oproducerbarhets": "oproducerbarhet",
    "oproducerbars": "oproducerbar",
    "oproducerbart": "oproducerbar",
    "oproducerbarts": "oproducerbar",
    "oprofanerade": "oprofanerad",
    "oprofanerades": "oprofanerad",
    "oprofanerads": "oprofanerad",
    "oprofanerat": "oprofanerad",
    "oprofanerats": "oprofanerad",
    "oprofanerbara": "oprofanerbar",
    "oprofanerbarare": "oprofanerbar",
    "oprofanerbarares": "oprofanerbar",
    "oprofanerbaras": "oprofanerbar",
    "oprofanerbarast": "oprofanerbar",
    "oprofanerbaraste": "oprofanerbar",
    "oprofanerbarastes": "oprofanerbar",
    "oprofanerbarasts": "oprofanerbar",
    "oprofanerbare": "oprofanerbar",
    "oprofanerbares": "oprofanerbar",
    "oprofanerbarheten": "oprofanerbarhet",
    "oprofanerbarhetens": "oprofanerbarhet",
    "oprofanerbarhets": "oprofanerbarhet",
    "oprofanerbars": "oprofanerbar",
    "oprofanerbart": "oprofanerbar",
    "oprofanerbarts": "oprofanerbar",
    "oprofessionaliserade": "oprofessionaliserad",
    "oprofessionaliserades": "oprofessionaliserad",
    "oprofessionaliserads": "oprofessionaliserad",
    "oprofessionaliserat": "oprofessionaliserad",
    "oprofessionaliserats": "oprofessionaliserad",
    "oprofessionaliserbara": "oprofessionaliserbar",
    "oprofessionaliserbarare": "oprofessionaliserbar",
    "oprofessionaliserbarares": "oprofessionaliserbar",
    "oprofessionaliserbaras": "oprofessionaliserbar",
    "oprofessionaliserbarast": "oprofessionaliserbar",
    "oprofessionaliserbaraste": "oprofessionaliserbar",
    "oprofessionaliserbarastes": "oprofessionaliserbar",
    "oprofessionaliserbarasts": "oprofessionaliserbar",
    "oprofessionaliserbare": "oprofessionaliserbar",
    "oprofessionaliserbares": "oprofessionaliserbar",
    "oprofessionaliserbarheten": "oprofessionaliserbarhet",
    "oprofessionaliserbarhetens": "oprofessionaliserbarhet",
    "oprofessionaliserbarhets": "oprofessionaliserbarhet",
    "oprofessionaliserbars": "oprofessionaliserbar",
    "oprofessionaliserbart": "oprofessionaliserbar",
    "oprofessionaliserbarts": "oprofessionaliserbar",
    "oprofilerade": "oprofilerad",
    "oprofilerades": "oprofilerad",
    "oprofilerads": "oprofilerad",
    "oprofilerat": "oprofilerad",
    "oprofilerats": "oprofilerad",
    "oprofilerbara": "oprofilerbar",
    "oprofilerbarare": "oprofilerbar",
    "oprofilerbarares": "oprofilerbar",
    "oprofilerbaras": "oprofilerbar",
    "oprofilerbarast": "oprofilerbar",
    "oprofilerbaraste": "oprofilerbar",
    "oprofilerbarastes": "oprofilerbar",
    "oprofilerbarasts": "oprofilerbar",
    "oprofilerbare": "oprofilerbar",
    "oprofilerbares": "oprofilerbar",
    "oprofilerbarheten": "oprofilerbarhet",
    "oprofilerbarhetens": "oprofilerbarhet",
    "oprofilerbarhets": "oprofilerbarhet",
    "oprofilerbars": "oprofilerbar",
    "oprofilerbart": "oprofilerbar",
    "oprofilerbarts": "oprofilerbar",
    "oprognostiserade": "oprognostiserad",
    "oprognostiserades": "oprognostiserad",
    "oprognostiserads": "oprognostiserad",
    "oprognostiserat": "oprognostiserad",
    "oprognostiserats": "oprognostiserad",
    "oprognostiserbara": "oprognostiserbar",
    "oprognostiserbarare": "oprognostiserbar",
    "oprognostiserbarares": "oprognostiserbar",
    "oprognostiserbaras": "oprognostiserbar",
    "oprognostiserbarast": "oprognostiserbar",
    "oprognostiserbaraste": "oprognostiserbar",
    "oprognostiserbarastes": "oprognostiserbar",
    "oprognostiserbarasts": "oprognostiserbar",
    "oprognostiserbare": "oprognostiserbar",
    "oprognostiserbares": "oprognostiserbar",
    "oprognostiserbarheten": "oprognostiserbarhet",
    "oprognostiserbarhetens": "oprognostiserbarhet",
    "oprognostiserbarhets": "oprognostiserbarhet",
    "oprognostiserbars": "oprognostiserbar",
    "oprognostiserbart": "oprognostiserbar",
    "oprognostiserbarts": "oprognostiserbar",
    "oprogrammerade": "oprogrammerad",
    "oprogrammerades": "oprogrammerad",
    "oprogrammerads": "oprogrammerad",
    "oprogrammerat": "oprogrammerad",
    "oprogrammerats": "oprogrammerad",
    "oprogrammerbara": "oprogrammerbar",
    "oprogrammerbarare": "oprogrammerbar",
    "oprogrammerbarares": "oprogrammerbar",
    "oprogrammerbaras": "oprogrammerbar",
    "oprogrammerbarast": "oprogrammerbar",
    "oprogrammerbaraste": "oprogrammerbar",
    "oprogrammerbarastes": "oprogrammerbar",
    "oprogrammerbarasts": "oprogrammerbar",
    "oprogrammerbare": "oprogrammerbar",
    "oprogrammerbares": "oprogrammerbar",
    "oprogrammerbarheten": "oprogrammerbarhet",
    "oprogrammerbarhetens": "oprogrammerbarhet",
    "oprogrammerbarhets": "oprogrammerbarhet",
    "oprogrammerbars": "oprogrammerbar",
    "oprogrammerbart": "oprogrammerbar",
    "oprogrammerbarts": "oprogrammerbar",
    "oprojekterade": "oprojekterad",
    "oprojekterades": "oprojekterad",
    "oprojekterads": "oprojekterad",
    "oprojekterat": "oprojekterad",
    "oprojekterats": "oprojekterad",
    "oprojekterbara": "oprojekterbar",
    "oprojekterbarare": "oprojekterbar",
    "oprojekterbarares": "oprojekterbar",
    "oprojekterbaras": "oprojekterbar",
    "oprojekterbarast": "oprojekterbar",
    "oprojekterbaraste": "oprojekterbar",
    "oprojekterbarastes": "oprojekterbar",
    "oprojekterbarasts": "oprojekterbar",
    "oprojekterbare": "oprojekterbar",
    "oprojekterbares": "oprojekterbar",
    "oprojekterbarheten": "oprojekterbarhet",
    "oprojekterbarhetens": "oprojekterbarhet",
    "oprojekterbarhets": "oprojekterbarhet",
    "oprojekterbars": "oprojekterbar",
    "oprojekterbart": "oprojekterbar",
    "oprojekterbarts": "oprojekterbar",
    "oprojicerade": "oprojicerad",
    "oprojicerades": "oprojicerad",
    "oprojicerads": "oprojicerad",
    "oprojicerat": "oprojicerad",
    "oprojicerats": "oprojicerad",
    "oprojicerbara": "oprojicerbar",
    "oprojicerbarare": "oprojicerbar",
    "oprojicerbarares": "oprojicerbar",
    "oprojicerbaras": "oprojicerbar",
    "oprojicerbarast": "oprojicerbar",
    "oprojicerbaraste": "oprojicerbar",
    "oprojicerbarastes": "oprojicerbar",
    "oprojicerbarasts": "oprojicerbar",
    "oprojicerbare": "oprojicerbar",
    "oprojicerbares": "oprojicerbar",
    "oprojicerbarheten": "oprojicerbarhet",
    "oprojicerbarhetens": "oprojicerbarhet",
    "oprojicerbarhets": "oprojicerbarhet",
    "oprojicerbars": "oprojicerbar",
    "oprojicerbart": "oprojicerbar",
    "oprojicerbarts": "oprojicerbar",
    "oproklamerade": "oproklamerad",
    "oproklamerades": "oproklamerad",
    "oproklamerads": "oproklamerad",
    "oproklamerat": "oproklamerad",
    "oproklamerats": "oproklamerad",
    "oproklamerbara": "oproklamerbar",
    "oproklamerbarare": "oproklamerbar",
    "oproklamerbarares": "oproklamerbar",
    "oproklamerbaras": "oproklamerbar",
    "oproklamerbarast": "oproklamerbar",
    "oproklamerbaraste": "oproklamerbar",
    "oproklamerbarastes": "oproklamerbar",
    "oproklamerbarasts": "oproklamerbar",
    "oproklamerbare": "oproklamerbar",
    "oproklamerbares": "oproklamerbar",
    "oproklamerbarheten": "oproklamerbarhet",
    "oproklamerbarhetens": "oproklamerbarhet",
    "oproklamerbarhets": "oproklamerbarhet",
    "oproklamerbars": "oproklamerbar",
    "oproklamerbart": "oproklamerbar",
    "oproklamerbarts": "oproklamerbar",
    "oproletariserade": "oproletariserad",
    "oproletariserades": "oproletariserad",
    "oproletariserads": "oproletariserad",
    "oproletariserat": "oproletariserad",
    "oproletariserats": "oproletariserad",
    "oproletariserbara": "oproletariserbar",
    "oproletariserbarare": "oproletariserbar",
    "oproletariserbarares": "oproletariserbar",
    "oproletariserbaras": "oproletariserbar",
    "oproletariserbarast": "oproletariserbar",
    "oproletariserbaraste": "oproletariserbar",
    "oproletariserbarastes": "oproletariserbar",
    "oproletariserbarasts": "oproletariserbar",
    "oproletariserbare": "oproletariserbar",
    "oproletariserbares": "oproletariserbar",
    "oproletariserbarheten": "oproletariserbarhet",
    "oproletariserbarhetens": "oproletariserbarhet",
    "oproletariserbarhets": "oproletariserbarhet",
    "oproletariserbars": "oproletariserbar",
    "oproletariserbart": "oproletariserbar",
    "oproletariserbarts": "oproletariserbar",
    "oprolongerade": "oprolongerad",
    "oprolongerades": "oprolongerad",
    "oprolongerads": "oprolongerad",
    "oprolongerat": "oprolongerad",
    "oprolongerats": "oprolongerad",
    "oprolongerbara": "oprolongerbar",
    "oprolongerbarare": "oprolongerbar",
    "oprolongerbarares": "oprolongerbar",
    "oprolongerbaras": "oprolongerbar",
    "oprolongerbarast": "oprolongerbar",
    "oprolongerbaraste": "oprolongerbar",
    "oprolongerbarastes": "oprolongerbar",
    "oprolongerbarasts": "oprolongerbar",
    "oprolongerbare": "oprolongerbar",
    "oprolongerbares": "oprolongerbar",
    "oprolongerbarheten": "oprolongerbarhet",
    "oprolongerbarhetens": "oprolongerbarhet",
    "oprolongerbarhets": "oprolongerbarhet",
    "oprolongerbars": "oprolongerbar",
    "oprolongerbart": "oprolongerbar",
    "oprolongerbarts": "oprolongerbar",
    "opromoverade": "opromoverad",
    "opromoverades": "opromoverad",
    "opromoverads": "opromoverad",
    "opromoverat": "opromoverad",
    "opromoverats": "opromoverad",
    "opromoverbara": "opromoverbar",
    "opromoverbarare": "opromoverbar",
    "opromoverbarares": "opromoverbar",
    "opromoverbaras": "opromoverbar",
    "opromoverbarast": "opromoverbar",
    "opromoverbaraste": "opromoverbar",
    "opromoverbarastes": "opromoverbar",
    "opromoverbarasts": "opromoverbar",
    "opromoverbare": "opromoverbar",
    "opromoverbares": "opromoverbar",
    "opromoverbarheten": "opromoverbarhet",
    "opromoverbarhetens": "opromoverbarhet",
    "opromoverbarhets": "opromoverbarhet",
    "opromoverbars": "opromoverbar",
    "opromoverbart": "opromoverbar",
    "opromoverbarts": "opromoverbar",
    "opromulgerade": "opromulgerad",
    "opromulgerades": "opromulgerad",
    "opromulgerads": "opromulgerad",
    "opromulgerat": "opromulgerad",
    "opromulgerats": "opromulgerad",
    "opromulgerbara": "opromulgerbar",
    "opromulgerbarare": "opromulgerbar",
    "opromulgerbarares": "opromulgerbar",
    "opromulgerbaras": "opromulgerbar",
    "opromulgerbarast": "opromulgerbar",
    "opromulgerbaraste": "opromulgerbar",
    "opromulgerbarastes": "opromulgerbar",
    "opromulgerbarasts": "opromulgerbar",
    "opromulgerbare": "opromulgerbar",
    "opromulgerbares": "opromulgerbar",
    "opromulgerbarheten": "opromulgerbarhet",
    "opromulgerbarhetens": "opromulgerbarhet",
    "opromulgerbarhets": "opromulgerbarhet",
    "opromulgerbars": "opromulgerbar",
    "opromulgerbart": "opromulgerbar",
    "opromulgerbarts": "opromulgerbar",
    "oprononcerade": "oprononcerad",
    "oprononcerades": "oprononcerad",
    "oprononcerads": "oprononcerad",
    "oprononcerat": "oprononcerad",
    "oprononcerats": "oprononcerad",
    "oprononcerbara": "oprononcerbar",
    "oprononcerbarare": "oprononcerbar",
    "oprononcerbarares": "oprononcerbar",
    "oprononcerbaras": "oprononcerbar",
    "oprononcerbarast": "oprononcerbar",
    "oprononcerbaraste": "oprononcerbar",
    "oprononcerbarastes": "oprononcerbar",
    "oprononcerbarasts": "oprononcerbar",
    "oprononcerbare": "oprononcerbar",
    "oprononcerbares": "oprononcerbar",
    "oprononcerbarheten": "oprononcerbarhet",
    "oprononcerbarhetens": "oprononcerbarhet",
    "oprononcerbarhets": "oprononcerbarhet",
    "oprononcerbars": "oprononcerbar",
    "oprononcerbart": "oprononcerbar",
    "oprononcerbarts": "oprononcerbar",
    "oproponerade": "oproponerad",
    "oproponerades": "oproponerad",
    "oproponerads": "oproponerad",
    "oproponerat": "oproponerad",
    "oproponerats": "oproponerad",
    "oproponerbara": "oproponerbar",
    "oproponerbarare": "oproponerbar",
    "oproponerbarares": "oproponerbar",
    "oproponerbaras": "oproponerbar",
    "oproponerbarast": "oproponerbar",
    "oproponerbaraste": "oproponerbar",
    "oproponerbarastes": "oproponerbar",
    "oproponerbarasts": "oproponerbar",
    "oproponerbare": "oproponerbar",
    "oproponerbares": "oproponerbar",
    "oproponerbarheten": "oproponerbarhet",
    "oproponerbarhetens": "oproponerbarhet",
    "oproponerbarhets": "oproponerbarhet",
    "oproponerbars": "oproponerbar",
    "oproponerbart": "oproponerbar",
    "oproponerbarts": "oproponerbar",
    "oproportionerade": "oproportionerad",
    "oproportionerades": "oproportionerad",
    "oproportionerads": "oproportionerad",
    "oproportionerat": "oproportionerad",
    "oproportionerats": "oproportionerad",
    "oproportionerbara": "oproportionerbar",
    "oproportionerbarare": "oproportionerbar",
    "oproportionerbarares": "oproportionerbar",
    "oproportionerbaras": "oproportionerbar",
    "oproportionerbarast": "oproportionerbar",
    "oproportionerbaraste": "oproportionerbar",
    "oproportionerbarastes": "oproportionerbar",
    "oproportionerbarasts": "oproportionerbar",
    "oproportionerbare": "oproportionerbar",
    "oproportionerbares": "oproportionerbar",
    "oproportionerbarheten": "oproportionerbarhet",
    "oproportionerbarhetens": "oproportionerbarhet",
    "oproportionerbarhets": "oproportionerbarhet",
    "oproportionerbars": "oproportionerbar",
    "oproportionerbart": "oproportionerbar",
    "oproportionerbarts": "oproportionerbar",
    "oproportionerliga": "oproportionerlig",
    "oproportionerligare": "oproportionerlig",
    "oproportionerligares": "oproportionerlig",
    "oproportionerligas": "oproportionerlig",
    "oproportionerligast": "oproportionerlig",
    "oproportionerligaste": "oproportionerlig",
    "oproportionerligastes": "oproportionerlig",
    "oproportionerligasts": "oproportionerlig",
    "oproportionerlige": "oproportionerlig",
    "oproportionerliges": "oproportionerlig",
    "oproportionerligheten": "oproportionerlighet",
    "oproportionerlighetens": "oproportionerlighet",
    "oproportionerlighets": "oproportionerlighet",
    "oproportionerligs": "oproportionerlig",
    "oproportionerligt": "oproportionerlig",
    "oproportionerligts": "oproportionerlig",
    "oproppade": "oproppad",
    "oproppades": "oproppad",
    "oproppads": "oproppad",
    "oproppat": "oproppad",
    "oproppats": "oproppad",
    "oproskriberade": "oproskriberad",
    "oproskriberades": "oproskriberad",
    "oproskriberads": "oproskriberad",
    "oproskriberat": "oproskriberad",
    "oproskriberats": "oproskriberad",
    "oproskriberbara": "oproskriberbar",
    "oproskriberbarare": "oproskriberbar",
    "oproskriberbarares": "oproskriberbar",
    "oproskriberbaras": "oproskriberbar",
    "oproskriberbarast": "oproskriberbar",
    "oproskriberbaraste": "oproskriberbar",
    "oproskriberbarastes": "oproskriberbar",
    "oproskriberbarasts": "oproskriberbar",
    "oproskriberbare": "oproskriberbar",
    "oproskriberbares": "oproskriberbar",
    "oproskriberbarheten": "oproskriberbarhet",
    "oproskriberbarhetens": "oproskriberbarhet",
    "oproskriberbarhets": "oproskriberbarhet",
    "oproskriberbars": "oproskriberbar",
    "oproskriberbart": "oproskriberbar",
    "oproskriberbarts": "oproskriberbar",
    "oprospekterade": "oprospekterad",
    "oprospekterades": "oprospekterad",
    "oprospekterads": "oprospekterad",
    "oprospekterat": "oprospekterad",
    "oprospekterats": "oprospekterad",
    "oprospekterbara": "oprospekterbar",
    "oprospekterbarare": "oprospekterbar",
    "oprospekterbarares": "oprospekterbar",
    "oprospekterbaras": "oprospekterbar",
    "oprospekterbarast": "oprospekterbar",
    "oprospekterbaraste": "oprospekterbar",
    "oprospekterbarastes": "oprospekterbar",
    "oprospekterbarasts": "oprospekterbar",
    "oprospekterbare": "oprospekterbar",
    "oprospekterbares": "oprospekterbar",
    "oprospekterbarheten": "oprospekterbarhet",
    "oprospekterbarhetens": "oprospekterbarhet",
    "oprospekterbarhets": "oprospekterbarhet",
    "oprospekterbars": "oprospekterbar",
    "oprospekterbart": "oprospekterbar",
    "oprospekterbarts": "oprospekterbar",
    "oprotegerade": "oprotegerad",
    "oprotegerades": "oprotegerad",
    "oprotegerads": "oprotegerad",
    "oprotegerat": "oprotegerad",
    "oprotegerats": "oprotegerad",
    "oprotegerbara": "oprotegerbar",
    "oprotegerbarare": "oprotegerbar",
    "oprotegerbarares": "oprotegerbar",
    "oprotegerbaras": "oprotegerbar",
    "oprotegerbarast": "oprotegerbar",
    "oprotegerbaraste": "oprotegerbar",
    "oprotegerbarastes": "oprotegerbar",
    "oprotegerbarasts": "oprotegerbar",
    "oprotegerbare": "oprotegerbar",
    "oprotegerbares": "oprotegerbar",
    "oprotegerbarheten": "oprotegerbarhet",
    "oprotegerbarhetens": "oprotegerbarhet",
    "oprotegerbarhets": "oprotegerbarhet",
    "oprotegerbars": "oprotegerbar",
    "oprotegerbart": "oprotegerbar",
    "oprotegerbarts": "oprotegerbar",
    "oprotesterade": "oprotesterad",
    "oprotesterades": "oprotesterad",
    "oprotesterads": "oprotesterad",
    "oprotesterat": "oprotesterad",
    "oprotesterats": "oprotesterad",
    "oprotokollerade": "oprotokollerad",
    "oprotokollerades": "oprotokollerad",
    "oprotokollerads": "oprotokollerad",
    "oprotokollerat": "oprotokollerad",
    "oprotokollerats": "oprotokollerad",
    "oprotokollerbara": "oprotokollerbar",
    "oprotokollerbarare": "oprotokollerbar",
    "oprotokollerbarares": "oprotokollerbar",
    "oprotokollerbaras": "oprotokollerbar",
    "oprotokollerbarast": "oprotokollerbar",
    "oprotokollerbaraste": "oprotokollerbar",
    "oprotokollerbarastes": "oprotokollerbar",
    "oprotokollerbarasts": "oprotokollerbar",
    "oprotokollerbare": "oprotokollerbar",
    "oprotokollerbares": "oprotokollerbar",
    "oprotokollerbarheten": "oprotokollerbarhet",
    "oprotokollerbarhetens": "oprotokollerbarhet",
    "oprotokollerbarhets": "oprotokollerbarhet",
    "oprotokollerbars": "oprotokollerbar",
    "oprotokollerbart": "oprotokollerbar",
    "oprotokollerbarts": "oprotokollerbar",
    "oprovade": "oprovad",
    "oprovades": "oprovad",
    "oprovads": "oprovad",
    "oprovat": "oprovad",
    "oprovats": "oprovad",
    "oprovocerade": "oprovocerad",
    "oprovocerades": "oprovocerad",
    "oprovocerads": "oprovocerad",
    "oprovocerat": "oprovocerad",
    "oprovocerats": "oprovocerad",
    "oprovocerbara": "oprovocerbar",
    "oprovocerbarare": "oprovocerbar",
    "oprovocerbarares": "oprovocerbar",
    "oprovocerbaras": "oprovocerbar",
    "oprovocerbarast": "oprovocerbar",
    "oprovocerbaraste": "oprovocerbar",
    "oprovocerbarastes": "oprovocerbar",
    "oprovocerbarasts": "oprovocerbar",
    "oprovocerbare": "oprovocerbar",
    "oprovocerbares": "oprovocerbar",
    "oprovocerbarheten": "oprovocerbarhet",
    "oprovocerbarhetens": "oprovocerbarhet",
    "oprovocerbarhets": "oprovocerbarhet",
    "oprovocerbars": "oprovocerbar",
    "oprovocerbart": "oprovocerbar",
    "oprovocerbarts": "oprovocerbar",
    "oprutade": "oprutad",
    "oprutades": "oprutad",
    "oprutads": "oprutad",
    "oprutat": "oprutad",
    "oprutats": "oprutad",
    "opryglade": "opryglad",
    "opryglades": "opryglad",
    "opryglads": "opryglad",
    "opryglat": "opryglad",
    "opryglats": "opryglad",
    "opräglade": "opräglad",
    "opräglades": "opräglad",
    "opräglads": "opräglad",
    "opräglat": "opräglad",
    "opräglats": "opräglad",
    "opräntade": "opräntad",
    "opräntades": "opräntad",
    "opräntads": "opräntad",
    "opräntat": "opräntad",
    "opräntats": "opräntad",
    "opråmade": "opråmad",
    "opråmades": "opråmad",
    "opråmads": "opråmad",
    "opråmat": "opråmad",
    "opråmats": "opråmad",
    "opröjsade": "opröjsad",
    "opröjsades": "opröjsad",
    "opröjsads": "opröjsad",
    "opröjsat": "opröjsad",
    "opröjsats": "opröjsad",
    "oprövade": "oprövad",
    "oprövades": "oprövad",
    "oprövads": "oprövad",
    "oprövat": "oprövad",
    "oprövats": "oprövad",
    "opsykade": "opsykad",
    "opsykades": "opsykad",
    "opsykads": "opsykad",
    "opsykat": "opsykad",
    "opsykats": "opsykad",
    "opsykologiserade": "opsykologiserad",
    "opsykologiserades": "opsykologiserad",
    "opsykologiserads": "opsykologiserad",
    "opsykologiserat": "opsykologiserad",
    "opsykologiserats": "opsykologiserad",
    "opsykologiserbara": "opsykologiserbar",
    "opsykologiserbarare": "opsykologiserbar",
    "opsykologiserbarares": "opsykologiserbar",
    "opsykologiserbaras": "opsykologiserbar",
    "opsykologiserbarast": "opsykologiserbar",
    "opsykologiserbaraste": "opsykologiserbar",
    "opsykologiserbarastes": "opsykologiserbar",
    "opsykologiserbarasts": "opsykologiserbar",
    "opsykologiserbare": "opsykologiserbar",
    "opsykologiserbares": "opsykologiserbar",
    "opsykologiserbarheten": "opsykologiserbarhet",
    "opsykologiserbarhetens": "opsykologiserbarhet",
    "opsykologiserbarhets": "opsykologiserbarhet",
    "opsykologiserbars": "opsykologiserbar",
    "opsykologiserbart": "opsykologiserbar",
    "opsykologiserbarts": "opsykologiserbar",
    "opsykologiska": "opsykologisk",
    "opsykologiskare": "opsykologisk",
    "opsykologiskares": "opsykologisk",
    "opsykologiskas": "opsykologisk",
    "opsykologiskast": "opsykologisk",
    "opsykologiskaste": "opsykologisk",
    "opsykologiskastes": "opsykologisk",
    "opsykologiskasts": "opsykologisk",
    "opsykologiske": "opsykologisk",
    "opsykologiskes": "opsykologisk",
    "opsykologisks": "opsykologisk",
    "opsykologiskt": "opsykologisk",
    "opsykologiskts": "opsykologisk",
    "optanten": "optant",
    "optantens": "optant",
    "optanter": "optant",
    "optanterna": "optant",
    "optanternas": "optant",
    "optanters": "optant",
    "optants": "optant",
    "optativa": "optativ",
    "optativare": "optativ",
    "optativares": "optativ",
    "optativas": "optativ",
    "optativast": "optativ",
    "optativaste": "optativ",
    "optativastes": "optativ",
    "optativasts": "optativ",
    "optative": "optativ",
    "optativen": "optativ",
    "optativens": "optativ",
    "optativer": "optativ",
    "optativerna": "optativ",
    "optativernas": "optativ",
    "optativers": "optativ",
    "optatives": "optativ",
    "optativs": "optativ",
    "optativt": "optativ",
    "optativts": "optativ",
    "opterade": "optera",
    "opterades": "optera",
    "opterande": "optera",
    "opteranden": "opterande",
    "opterandena": "opterande",
    "opterandenas": "opterande",
    "opterandens": "opterande",
    "opterandes": "opterande",
    "opterandet": "opterande",
    "opterandets": "opterande",
    "opterar": "optera",
    "opteras": "optera",
    "opterat": "optera",
    "opterats": "optera",
    "opteringar": "optering",
    "opteringarna": "optering",
    "opteringarnas": "optering",
    "opteringars": "optering",
    "opteringen": "optering",
    "opteringens": "optering",
    "opterings": "optering",
    "optiken": "optik",
    "optikens": "optik",
    "optikern": "optiker",
    "optikerna": "optiker",
    "optikernas": "optiker",
    "optikerns": "optiker",
    "optikers": "optiker",
    "optiks": "optik",
    "optima": "optimum",
    "optimala": "optimal",
    "optimalare": "optimal",
    "optimalares": "optimal",
    "optimalas": "optimal",
    "optimalast": "optimal",
    "optimalaste": "optimal",
    "optimalastes": "optimal",
    "optimalasts": "optimal",
    "optimale": "optimal",
    "optimales": "optimal",
    "optimals": "optimal",
    "optimalt": "optimal",
    "optimalts": "optimal",
    "optimana": "optimum",
    "optimanas": "optimum",
    "optimas": "optimum",
    "optimerad": "optimera",
    "optimerade": "optimera",
    "optimerades": "optimera",
    "optimerads": "optimera",
    "optimerande": "optimera",
    "optimeranden": "optimerande",
    "optimerandena": "optimerande",
    "optimerandenas": "optimerande",
    "optimerandens": "optimerande",
    "optimerandes": "optimerande",
    "optimerandet": "optimerande",
    "optimerandets": "optimerande",
    "optimerar": "optimera",
    "optimeras": "optimera",
    "optimerat": "optimera",
    "optimerats": "optimera",
    "optimerbara": "optimerbar",
    "optimerbarare": "optimerbar",
    "optimerbarares": "optimerbar",
    "optimerbaras": "optimerbar",
    "optimerbarast": "optimerbar",
    "optimerbaraste": "optimerbar",
    "optimerbarastes": "optimerbar",
    "optimerbarasts": "optimerbar",
    "optimerbare": "optimerbar",
    "optimerbares": "optimerbar",
    "optimerbarheten": "optimerbarhet",
    "optimerbarhetens": "optimerbarhet",
    "optimerbarhets": "optimerbarhet",
    "optimerbars": "optimerbar",
    "optimerbart": "optimerbar",
    "optimerbarts": "optimerbar",
    "optimeringar": "optimering",
    "optimeringarna": "optimering",
    "optimeringarnas": "optimering",
    "optimeringars": "optimering",
    "optimeringen": "optimering",
    "optimeringens": "optimering",
    "optimerings": "optimering",
    "optimet": "optimum",
    "optimets": "optimum",
    "optimismen": "optimism",
    "optimismens": "optimism",
    "optimismer": "optimism",
    "optimismerna": "optimism",
    "optimismernas": "optimism",
    "optimismers": "optimism",
    "optimisms": "optimism",
    "optimisten": "optimist",
    "optimistens": "optimist",
    "optimister": "optimist",
    "optimisterna": "optimist",
    "optimisternas": "optimist",
    "optimisters": "optimist",
    "optimistiska": "optimistisk",
    "optimistiskare": "optimistisk",
    "optimistiskares": "optimistisk",
    "optimistiskas": "optimistisk",
    "optimistiskast": "optimistisk",
    "optimistiskaste": "optimistisk",
    "optimistiskastes": "optimistisk",
    "optimistiskasts": "optimistisk",
    "optimistiske": "optimistisk",
    "optimistiskes": "optimistisk",
    "optimistisks": "optimistisk",
    "optimistiskt": "optimistisk",
    "optimistiskts": "optimistisk",
    "optimistjoll": "optimistjolle",
    "optimistjollar": "optimistjolle",
    "optimistjollarna": "optimistjolle",
    "optimistjollarnas": "optimistjolle",
    "optimistjollars": "optimistjolle",
    "optimistjollen": "optimistjolle",
    "optimistjollens": "optimistjolle",
    "optimistjolles": "optimistjolle",
    "optimistjolls": "optimistjolle",
    "optimists": "optimist",
    "optimumen": "optimum",
    "optimumens": "optimum",
    "optimumet": "optimum",
    "optimumets": "optimum",
    "optimums": "optimum",
    "optionen": "option",
    "optionens": "option",
    "optioner": "option",
    "optionerna": "option",
    "optionernas": "option",
    "optioners": "option",
    "options": "option",
    "optionsskandalen": "optionsskandal",
    "optionsskandalens": "optionsskandal",
    "optionsskandaler": "optionsskandal",
    "optionsskandalerna": "optionsskandal",
    "optionsskandalernas": "optionsskandal",
    "optionsskandalers": "optionsskandal",
    "optionsskandals": "optionsskandal",
    "optiska": "optisk",
    "optiskare": "optisk",
    "optiskares": "optisk",
    "optiskas": "optisk",
    "optiskast": "optisk",
    "optiskaste": "optisk",
    "optiskastes": "optisk",
    "optiskasts": "optisk",
    "optiske": "optisk",
    "optiskes": "optisk",
    "optisks": "optisk",
    "optiskt": "optisk",
    "optiskts": "optisk",
    "optoelektroniken": "optoelektronik",
    "optoelektronikens": "optoelektronik",
    "optoelektroniks": "optoelektronik",
    "optokomponenten": "optokomponent",
    "optokomponentens": "optokomponent",
    "optokomponenter": "optokomponent",
    "optokomponenterna": "optokomponent",
    "optokomponenternas": "optokomponent",
    "optokomponenters": "optokomponent",
    "optokomponents": "optokomponent",
    "opublicerade": "opublicerad",
    "opublicerades": "opublicerad",
    "opublicerads": "opublicerad",
    "opublicerat": "opublicerad",
    "opublicerats": "opublicerad",
    "opublicerbara": "opublicerbar",
    "opublicerbarare": "opublicerbar",
    "opublicerbarares": "opublicerbar",
    "opublicerbaras": "opublicerbar",
    "opublicerbarast": "opublicerbar",
    "opublicerbaraste": "opublicerbar",
    "opublicerbarastes": "opublicerbar",
    "opublicerbarasts": "opublicerbar",
    "opublicerbare": "opublicerbar",
    "opublicerbares": "opublicerbar",
    "opublicerbarheten": "opublicerbarhet",
    "opublicerbarhetens": "opublicerbarhet",
    "opublicerbarhets": "opublicerbarhet",
    "opublicerbars": "opublicerbar",
    "opublicerbart": "opublicerbar",
    "opublicerbarts": "opublicerbar",
    "opuddlade": "opuddlad",
    "opuddlades": "opuddlad",
    "opuddlads": "opuddlad",
    "opuddlat": "opuddlad",
    "opuddlats": "opuddlad",
    "opudrade": "opudrad",
    "opudrades": "opudrad",
    "opudrads": "opudrad",
    "opudrat": "opudrad",
    "opudrats": "opudrad",
    "opuffade": "opuffad",
    "opuffades": "opuffad",
    "opuffads": "opuffad",
    "opuffat": "opuffad",
    "opuffats": "opuffad",
    "opulensen": "opulens",
    "opulensens": "opulens",
    "opulenta": "opulent",
    "opulentare": "opulent",
    "opulentares": "opulent",
    "opulentas": "opulent",
    "opulentast": "opulent",
    "opulentaste": "opulent",
    "opulentastes": "opulent",
    "opulentasts": "opulent",
    "opulente": "opulent",
    "opulentes": "opulent",
    "opulents": "opulent",
    "opulveriserade": "opulveriserad",
    "opulveriserades": "opulveriserad",
    "opulveriserads": "opulveriserad",
    "opulveriserat": "opulveriserad",
    "opulveriserats": "opulveriserad",
    "opulveriserbara": "opulveriserbar",
    "opulveriserbarare": "opulveriserbar",
    "opulveriserbarares": "opulveriserbar",
    "opulveriserbaras": "opulveriserbar",
    "opulveriserbarast": "opulveriserbar",
    "opulveriserbaraste": "opulveriserbar",
    "opulveriserbarastes": "opulveriserbar",
    "opulveriserbarasts": "opulveriserbar",
    "opulveriserbare": "opulveriserbar",
    "opulveriserbares": "opulveriserbar",
    "opulveriserbarheten": "opulveriserbarhet",
    "opulveriserbarhetens": "opulveriserbarhet",
    "opulveriserbarhets": "opulveriserbarhet",
    "opulveriserbars": "opulveriserbar",
    "opulveriserbart": "opulveriserbar",
    "opulveriserbarts": "opulveriserbar",
    "opulvriserade": "opulvriserad",
    "opulvriserades": "opulvriserad",
    "opulvriserads": "opulvriserad",
    "opulvriserat": "opulvriserad",
    "opulvriserats": "opulvriserad",
    "opulvriserbara": "opulvriserbar",
    "opulvriserbarare": "opulvriserbar",
    "opulvriserbarares": "opulvriserbar",
    "opulvriserbaras": "opulvriserbar",
    "opulvriserbarast": "opulvriserbar",
    "opulvriserbaraste": "opulvriserbar",
    "opulvriserbarastes": "opulvriserbar",
    "opulvriserbarasts": "opulvriserbar",
    "opulvriserbare": "opulvriserbar",
    "opulvriserbares": "opulvriserbar",
    "opulvriserbarheten": "opulvriserbarhet",
    "opulvriserbarhetens": "opulvriserbarhet",
    "opulvriserbarhets": "opulvriserbarhet",
    "opulvriserbars": "opulvriserbar",
    "opulvriserbart": "opulvriserbar",
    "opulvriserbarts": "opulvriserbar",
    "opumpade": "opumpad",
    "opumpades": "opumpad",
    "opumpads": "opumpad",
    "opumpat": "opumpad",
    "opumpats": "opumpad",
    "opunktade": "opunktad",
    "opunktades": "opunktad",
    "opunktads": "opunktad",
    "opunktat": "opunktad",
    "opunktats": "opunktad",
    "opunkterade": "opunkterad",
    "opunkterades": "opunkterad",
    "opunkterads": "opunkterad",
    "opunkterat": "opunkterad",
    "opunkterats": "opunkterad",
    "opunkterbara": "opunkterbar",
    "opunkterbarare": "opunkterbar",
    "opunkterbarares": "opunkterbar",
    "opunkterbaras": "opunkterbar",
    "opunkterbarast": "opunkterbar",
    "opunkterbaraste": "opunkterbar",
    "opunkterbarastes": "opunkterbar",
    "opunkterbarasts": "opunkterbar",
    "opunkterbare": "opunkterbar",
    "opunkterbares": "opunkterbar",
    "opunkterbarheten": "opunkterbarhet",
    "opunkterbarhetens": "opunkterbarhet",
    "opunkterbarhets": "opunkterbarhet",
    "opunkterbars": "opunkterbar",
    "opunkterbart": "opunkterbar",
    "opunkterbarts": "opunkterbar",
    "opunsade": "opunsad",
    "opunsades": "opunsad",
    "opunsads": "opunsad",
    "opunsat": "opunsad",
    "opunsats": "opunsad",
    "opurgerade": "opurgerad",
    "opurgerades": "opurgerad",
    "opurgerads": "opurgerad",
    "opurgerat": "opurgerad",
    "opurgerats": "opurgerad",
    "opurgerbara": "opurgerbar",
    "opurgerbarare": "opurgerbar",
    "opurgerbarares": "opurgerbar",
    "opurgerbaras": "opurgerbar",
    "opurgerbarast": "opurgerbar",
    "opurgerbaraste": "opurgerbar",
    "opurgerbarastes": "opurgerbar",
    "opurgerbarasts": "opurgerbar",
    "opurgerbare": "opurgerbar",
    "opurgerbares": "opurgerbar",
    "opurgerbarheten": "opurgerbarhet",
    "opurgerbarhetens": "opurgerbarhet",
    "opurgerbarhets": "opurgerbarhet",
    "opurgerbars": "opurgerbar",
    "opurgerbart": "opurgerbar",
    "opurgerbarts": "opurgerbar",
    "opurprade": "opurprad",
    "opurprades": "opurprad",
    "opurprads": "opurprad",
    "opurprat": "opurprad",
    "opurprats": "opurprad",
    "opurrade": "opurrad",
    "opurrades": "opurrad",
    "opurrads": "opurrad",
    "opurrat": "opurrad",
    "opurrats": "opurrad",
    "opusen": "opus",
    "opusens": "opus",
    "opuset": "opus",
    "opusets": "opus",
    "opushade": "opushad",
    "opushades": "opushad",
    "opushads": "opushad",
    "opushat": "opushad",
    "opushats": "opushad",
    "opussade": "opussad",
    "opussades": "opussad",
    "opussads": "opussad",
    "opussat": "opussad",
    "opussats": "opussad",
    "oputsade": "oputsad",
    "oputsades": "oputsad",
    "oputsads": "oputsad",
    "oputsat": "oputsad",
    "oputsats": "oputsad",
    "oputtade": "oputtad",
    "oputtades": "oputtad",
    "oputtads": "oputtad",
    "oputtat": "oputtad",
    "oputtats": "oputtad",
    "opyntade": "opyntad",
    "opyntades": "opyntad",
    "opyntads": "opyntad",
    "opyntat": "opyntad",
    "opyntats": "opyntad",
    "opytsade": "opytsad",
    "opytsades": "opytsad",
    "opytsads": "opytsad",
    "opytsat": "opytsad",
    "opytsats": "opytsad",
    "opälade": "opälad",
    "opälades": "opälad",
    "opälads": "opälad",
    "opälat": "opälad",
    "opälats": "opälad",
    "opåade": "opåad",
    "opåades": "opåad",
    "opåads": "opåad",
    "opåannonserbara": "opåannonserbar",
    "opåannonserbarare": "opåannonserbar",
    "opåannonserbarares": "opåannonserbar",
    "opåannonserbaras": "opåannonserbar",
    "opåannonserbarast": "opåannonserbar",
    "opåannonserbaraste": "opåannonserbar",
    "opåannonserbarastes": "opåannonserbar",
    "opåannonserbarasts": "opåannonserbar",
    "opåannonserbare": "opåannonserbar",
    "opåannonserbares": "opåannonserbar",
    "opåannonserbarheten": "opåannonserbarhet",
    "opåannonserbarhetens": "opåannonserbarhet",
    "opåannonserbarhets": "opåannonserbarhet",
    "opåannonserbars": "opåannonserbar",
    "opåannonserbart": "opåannonserbar",
    "opåannonserbarts": "opåannonserbar",
    "opåat": "opåad",
    "opåats": "opåad",
    "opåbördade": "opåbördad",
    "opåbördades": "opåbördad",
    "opåbördads": "opåbördad",
    "opåbördat": "opåbördad",
    "opåbördats": "opåbördad",
    "opåbörjade": "opåbörjad",
    "opåbörjades": "opåbörjad",
    "opåbörjads": "opåbörjad",
    "opåbörjat": "opåbörjad",
    "opåbörjats": "opåbörjad",
    "opådyvlade": "opådyvlad",
    "opådyvlades": "opådyvlad",
    "opådyvlads": "opådyvlad",
    "opådyvlat": "opådyvlad",
    "opådyvlats": "opådyvlad",
    "opåfordrade": "opåfordrad",
    "opåfordrades": "opåfordrad",
    "opåfordrads": "opåfordrad",
    "opåfordrat": "opåfordrad",
    "opåfordrats": "opåfordrad",
    "opåförde": "opåförd",
    "opåfördes": "opåförd",
    "opåförds": "opåförd",
    "opåfört": "opåförd",
    "opåförts": "opåförd",
    "opåkallade": "opåkallad",
    "opåkallades": "opåkallad",
    "opåkallads": "opåkallad",
    "opåkallat": "opåkallad",
    "opåkallats": "opåkallad",
    "opålade": "opålad",
    "opålades": "opålad",
    "opålads": "opålad",
    "opålat": "opålad",
    "opålats": "opålad",
    "opålitliga": "opålitlig",
    "opålitligare": "opålitlig",
    "opålitligares": "opålitlig",
    "opålitligas": "opålitlig",
    "opålitligast": "opålitlig",
    "opålitligaste": "opålitlig",
    "opålitligastes": "opålitlig",
    "opålitligasts": "opålitlig",
    "opålitlige": "opålitlig",
    "opålitliges": "opålitlig",
    "opålitligheten": "opålitlighet",
    "opålitlighetens": "opålitlighet",
    "opålitlighets": "opålitlighet",
    "opålitligs": "opålitlig",
    "opålitligt": "opålitlig",
    "opålitligts": "opålitlig",
    "opåminde": "opåmind",
    "opåmindes": "opåmind",
    "opåminds": "opåmind",
    "opåmint": "opåmind",
    "opåmints": "opåmind",
    "opåpekade": "opåpekad",
    "opåpekades": "opåpekad",
    "opåpekads": "opåpekad",
    "opåpekat": "opåpekad",
    "opåpekats": "opåpekad",
    "opåropade": "opåropad",
    "opåropades": "opåropad",
    "opåropads": "opåropad",
    "opåropat": "opåropad",
    "opåropats": "opåropad",
    "opåräknade": "opåräknad",
    "opåräknades": "opåräknad",
    "opåräknads": "opåräknad",
    "opåräknat": "opåräknad",
    "opåräknats": "opåräknad",
    "opåskyndade": "opåskyndad",
    "opåskyndades": "opåskyndad",
    "opåskyndads": "opåskyndad",
    "opåskyndat": "opåskyndad",
    "opåskyndats": "opåskyndad",
    "opåtalade": "opåtalad",
    "opåtalades": "opåtalad",
    "opåtalads": "opåtalad",
    "opåtalat": "opåtalad",
    "opåtalats": "opåtalad",
    "opåtalda": "opåtald",
    "opåtaldare": "opåtald",
    "opåtaldares": "opåtald",
    "opåtaldas": "opåtald",
    "opåtaldast": "opåtald",
    "opåtaldaste": "opåtald",
    "opåtaldastes": "opåtald",
    "opåtaldasts": "opåtald",
    "opåtalde": "opåtald",
    "opåtaldes": "opåtald",
    "opåtalds": "opåtald",
    "opåtalt": "opåtald",
    "opåtalts": "opåtald",
    "opåträffade": "opåträffad",
    "opåträffades": "opåträffad",
    "opåträffads": "opåträffad",
    "opåträffat": "opåträffad",
    "opåträffats": "opåträffad",
    "opåverkade": "opåverkad",
    "opåverkades": "opåverkad",
    "opåverkads": "opåverkad",
    "opåverkat": "opåverkad",
    "opåverkats": "opåverkad",
    "opåverkbara": "opåverkbar",
    "opåverkbarare": "opåverkbar",
    "opåverkbarares": "opåverkbar",
    "opåverkbaras": "opåverkbar",
    "opåverkbarast": "opåverkbar",
    "opåverkbaraste": "opåverkbar",
    "opåverkbarastes": "opåverkbar",
    "opåverkbarasts": "opåverkbar",
    "opåverkbare": "opåverkbar",
    "opåverkbares": "opåverkbar",
    "opåverkbarheten": "opåverkbarhet",
    "opåverkbarhetens": "opåverkbarhet",
    "opåverkbarhets": "opåverkbarhet",
    "opåverkbars": "opåverkbar",
    "opåverkbart": "opåverkbar",
    "opåverkbarts": "opåverkbar",
    "opåvisade": "opåvisad",
    "opåvisades": "opåvisad",
    "opåvisads": "opåvisad",
    "opåvisat": "opåvisad",
    "opåvisats": "opåvisad",
    "opåyrkade": "opåyrkad",
    "opåyrkades": "opåyrkad",
    "opåyrkads": "opåyrkad",
    "opåyrkat": "opåyrkad",
    "opåyrkats": "opåyrkad",
    "oquiltade": "oquiltad",
    "oquiltades": "oquiltad",
    "oquiltads": "oquiltad",
    "oquiltat": "oquiltad",
    "oquiltats": "oquiltad",
    "orabatterade": "orabatterad",
    "orabatterades": "orabatterad",
    "orabatterads": "orabatterad",
    "orabatterat": "orabatterad",
    "orabatterats": "orabatterad",
    "orabatterbara": "orabatterbar",
    "orabatterbarare": "orabatterbar",
    "orabatterbarares": "orabatterbar",
    "orabatterbaras": "orabatterbar",
    "orabatterbarast": "orabatterbar",
    "orabatterbaraste": "orabatterbar",
    "orabatterbarastes": "orabatterbar",
    "orabatterbarasts": "orabatterbar",
    "orabatterbare": "orabatterbar",
    "orabatterbares": "orabatterbar",
    "orabatterbarheten": "orabatterbarhet",
    "orabatterbarhetens": "orabatterbarhet",
    "orabatterbarhets": "orabatterbarhet",
    "orabatterbars": "orabatterbar",
    "orabatterbart": "orabatterbar",
    "orabatterbarts": "orabatterbar",
    "orabblade": "orabblad",
    "orabblades": "orabblad",
    "orabblads": "orabblad",
    "orabblat": "orabblad",
    "orabblats": "orabblad",
    "orackade": "orackad",
    "orackades": "orackad",
    "orackads": "orackad",
    "orackat": "orackad",
    "orackats": "orackad",
    "oraderade": "oraderad",
    "oraderades": "oraderad",
    "oraderads": "oraderad",
    "oraderat": "oraderad",
    "oraderats": "oraderad",
    "oraderbara": "oraderbar",
    "oraderbarare": "oraderbar",
    "oraderbarares": "oraderbar",
    "oraderbaras": "oraderbar",
    "oraderbarast": "oraderbar",
    "oraderbaraste": "oraderbar",
    "oraderbarastes": "oraderbar",
    "oraderbarasts": "oraderbar",
    "oraderbare": "oraderbar",
    "oraderbares": "oraderbar",
    "oraderbarheten": "oraderbarhet",
    "oraderbarhetens": "oraderbarhet",
    "oraderbarhets": "oraderbarhet",
    "oraderbars": "oraderbar",
    "oraderbart": "oraderbar",
    "oraderbarts": "oraderbar",
    "oradierade": "oradierad",
    "oradierades": "oradierad",
    "oradierads": "oradierad",
    "oradierat": "oradierad",
    "oradierats": "oradierad",
    "oradierbara": "oradierbar",
    "oradierbarare": "oradierbar",
    "oradierbarares": "oradierbar",
    "oradierbaras": "oradierbar",
    "oradierbarast": "oradierbar",
    "oradierbaraste": "oradierbar",
    "oradierbarastes": "oradierbar",
    "oradierbarasts": "oradierbar",
    "oradierbare": "oradierbar",
    "oradierbares": "oradierbar",
    "oradierbarheten": "oradierbarhet",
    "oradierbarhetens": "oradierbarhet",
    "oradierbarhets": "oradierbarhet",
    "oradierbars": "oradierbar",
    "oradierbart": "oradierbar",
    "oradierbarts": "oradierbar",
    "oradikaliserade": "oradikaliserad",
    "oradikaliserades": "oradikaliserad",
    "oradikaliserads": "oradikaliserad",
    "oradikaliserat": "oradikaliserad",
    "oradikaliserats": "oradikaliserad",
    "oradikaliserbara": "oradikaliserbar",
    "oradikaliserbarare": "oradikaliserbar",
    "oradikaliserbarares": "oradikaliserbar",
    "oradikaliserbaras": "oradikaliserbar",
    "oradikaliserbarast": "oradikaliserbar",
    "oradikaliserbaraste": "oradikaliserbar",
    "oradikaliserbarastes": "oradikaliserbar",
    "oradikaliserbarasts": "oradikaliserbar",
    "oradikaliserbare": "oradikaliserbar",
    "oradikaliserbares": "oradikaliserbar",
    "oradikaliserbarheten": "oradikaliserbarhet",
    "oradikaliserbarhetens": "oradikaliserbarhet",
    "oradikaliserbarhets": "oradikaliserbarhet",
    "oradikaliserbars": "oradikaliserbar",
    "oradikaliserbart": "oradikaliserbar",
    "oradikaliserbarts": "oradikaliserbar",
    "oraffinerade": "oraffinerad",
    "oraffinerades": "oraffinerad",
    "oraffinerads": "oraffinerad",
    "oraffinerat": "oraffinerad",
    "oraffinerats": "oraffinerad",
    "oraffinerbara": "oraffinerbar",
    "oraffinerbarare": "oraffinerbar",
    "oraffinerbarares": "oraffinerbar",
    "oraffinerbaras": "oraffinerbar",
    "oraffinerbarast": "oraffinerbar",
    "oraffinerbaraste": "oraffinerbar",
    "oraffinerbarastes": "oraffinerbar",
    "oraffinerbarasts": "oraffinerbar",
    "oraffinerbare": "oraffinerbar",
    "oraffinerbares": "oraffinerbar",
    "oraffinerbarheten": "oraffinerbarhet",
    "oraffinerbarhetens": "oraffinerbarhet",
    "oraffinerbarhets": "oraffinerbarhet",
    "oraffinerbars": "oraffinerbar",
    "oraffinerbart": "oraffinerbar",
    "oraffinerbarts": "oraffinerbar",
    "oraggade": "oraggad",
    "oraggades": "oraggad",
    "oraggads": "oraggad",
    "oraggat": "oraggad",
    "oraggats": "oraggad",
    "orakade": "orakad",
    "orakades": "orakad",
    "orakads": "orakad",
    "orakat": "orakad",
    "orakats": "orakad",
    "orakelmässiga": "orakelmässig",
    "orakelmässigare": "orakelmässig",
    "orakelmässigares": "orakelmässig",
    "orakelmässigas": "orakelmässig",
    "orakelmässigast": "orakelmässig",
    "orakelmässigaste": "orakelmässig",
    "orakelmässigastes": "orakelmässig",
    "orakelmässigasts": "orakelmässig",
    "orakelmässige": "orakelmässig",
    "orakelmässiges": "orakelmässig",
    "orakelmässigs": "orakelmässig",
    "orakelmässigt": "orakelmässig",
    "orakelmässigts": "orakelmässig",
    "orakels": "orakel",
    "oraklen": "orakel",
    "oraklens": "orakel",
    "orakler": "orakel",
    "oraklerna": "orakel",
    "oraklernas": "orakel",
    "oraklers": "orakel",
    "oraklet": "orakel",
    "oraklets": "orakel",
    "orala": "oral",
    "oralare": "oral",
    "oralares": "oral",
    "oralas": "oral",
    "oralast": "oral",
    "oralaste": "oral",
    "oralastes": "oral",
    "oralasts": "oral",
    "orale": "oral",
    "orales": "oral",
    "orals": "oral",
    "oralsexet": "oralsex",
    "oralsexets": "oralsex",
    "oralt": "oral",
    "oralts": "oral",
    "oramade": "oramad",
    "oramades": "oramad",
    "oramads": "oramad",
    "oramat": "oramad",
    "oramats": "oramad",
    "orammade": "orammad",
    "orammades": "orammad",
    "orammads": "orammad",
    "orammat": "orammad",
    "orammats": "orammad",
    "oramponerade": "oramponerad",
    "oramponerades": "oramponerad",
    "oramponerads": "oramponerad",
    "oramponerat": "oramponerad",
    "oramponerats": "oramponerad",
    "oramponerbara": "oramponerbar",
    "oramponerbarare": "oramponerbar",
    "oramponerbarares": "oramponerbar",
    "oramponerbaras": "oramponerbar",
    "oramponerbarast": "oramponerbar",
    "oramponerbaraste": "oramponerbar",
    "oramponerbarastes": "oramponerbar",
    "oramponerbarasts": "oramponerbar",
    "oramponerbare": "oramponerbar",
    "oramponerbares": "oramponerbar",
    "oramponerbarheten": "oramponerbarhet",
    "oramponerbarhetens": "oramponerbarhet",
    "oramponerbarhets": "oramponerbarhet",
    "oramponerbars": "oramponerbar",
    "oramponerbart": "oramponerbar",
    "oramponerbarts": "oramponerbar",
    "oramsade": "oramsad",
    "oramsades": "oramsad",
    "oramsads": "oramsad",
    "oramsat": "oramsad",
    "oramsats": "oramsad",
    "orandade": "orandad",
    "orandades": "orandad",
    "orandads": "orandad",
    "orandat": "orandad",
    "orandats": "orandad",
    "orandomiserade": "orandomiserad",
    "orandomiserades": "orandomiserad",
    "orandomiserads": "orandomiserad",
    "orandomiserat": "orandomiserad",
    "orandomiserats": "orandomiserad",
    "oranga": "orange",
    "orangare": "orange",
    "orangares": "orange",
    "orangas": "orange",
    "orangast": "orange",
    "orangaste": "orange",
    "orangastes": "orange",
    "orangasts": "orange",
    "orangea": "orange",
    "orangeare": "orange",
    "orangeares": "orange",
    "orangeas": "orange",
    "orangeast": "orange",
    "orangeaste": "orange",
    "orangeastes": "orange",
    "orangeasts": "orange",
    "orangefärgade": "orangefärgad",
    "orangefärgades": "orangefärgad",
    "orangefärgads": "orangefärgad",
    "orangefärgat": "orangefärgad",
    "orangefärgats": "orangefärgad",
    "orangemålade": "orangemålad",
    "orangemålades": "orangemålad",
    "orangemålads": "orangemålad",
    "orangemålat": "orangemålad",
    "orangemålats": "orangemålad",
    "orangen": "orange",
    "orangens": "orange",
    "oranger": "orange",
    "orangerade": "orangerad",
    "orangerades": "orangerad",
    "orangerads": "orangerad",
    "orangerat": "orangerad",
    "orangerats": "orangerad",
    "orangerbara": "orangerbar",
    "orangerbarare": "orangerbar",
    "orangerbarares": "orangerbar",
    "orangerbaras": "orangerbar",
    "orangerbarast": "orangerbar",
    "orangerbaraste": "orangerbar",
    "orangerbarastes": "orangerbar",
    "orangerbarasts": "orangerbar",
    "orangerbare": "orangerbar",
    "orangerbares": "orangerbar",
    "orangerbarheten": "orangerbarhet",
    "orangerbarhetens": "orangerbarhet",
    "orangerbarhets": "orangerbarhet",
    "orangerbars": "orangerbar",
    "orangerbart": "orangerbar",
    "orangerbarts": "orangerbar",
    "orangerier": "orangeri",
    "orangerierna": "orangeri",
    "orangeriernas": "orangeri",
    "orangeriers": "orangeri",
    "orangeriet": "orangeri",
    "orangeriets": "orangeri",
    "orangeris": "orangeri",
    "orangerit": "orangeri",
    "orangerits": "orangeri",
    "orangerna": "orange",
    "orangernas": "orange",
    "orangers": "orange",
    "oranges": "orange",
    "oranget": "orange",
    "orangets": "orange",
    "orangt": "orange",
    "orangts": "orange",
    "orangutangen": "orangutang",
    "orangutangens": "orangutang",
    "orangutanger": "orangutang",
    "orangutangerna": "orangutang",
    "orangutangernas": "orangutang",
    "orangutangers": "orangutang",
    "orangutangs": "orangutang",
    "orankade": "orankad",
    "orankades": "orankad",
    "orankads": "orankad",
    "orankat": "orankad",
    "orankats": "orankad",
    "orannsakade": "orannsakad",
    "orannsakades": "orannsakad",
    "orannsakads": "orannsakad",
    "orannsakat": "orannsakad",
    "orannsakats": "orannsakad",
    "oransonerade": "oransonerad",
    "oransonerades": "oransonerad",
    "oransonerads": "oransonerad",
    "oransonerat": "oransonerad",
    "oransonerats": "oransonerad",
    "oransonerbara": "oransonerbar",
    "oransonerbarare": "oransonerbar",
    "oransonerbarares": "oransonerbar",
    "oransonerbaras": "oransonerbar",
    "oransonerbarast": "oransonerbar",
    "oransonerbaraste": "oransonerbar",
    "oransonerbarastes": "oransonerbar",
    "oransonerbarasts": "oransonerbar",
    "oransonerbare": "oransonerbar",
    "oransonerbares": "oransonerbar",
    "oransonerbarheten": "oransonerbarhet",
    "oransonerbarhetens": "oransonerbarhet",
    "oransonerbarhets": "oransonerbarhet",
    "oransonerbars": "oransonerbar",
    "oransonerbart": "oransonerbar",
    "oransonerbarts": "oransonerbar",
    "oranten": "orant",
    "orantens": "orant",
    "oranter": "orant",
    "oranterna": "orant",
    "oranternas": "orant",
    "oranters": "orant",
    "orants": "orant",
    "orappade": "orappad",
    "orappades": "orappad",
    "orappads": "orappad",
    "orappat": "orappad",
    "orappats": "orappad",
    "orappellerade": "orappellerad",
    "orappellerades": "orappellerad",
    "orappellerads": "orappellerad",
    "orappellerat": "orappellerad",
    "orappellerats": "orappellerad",
    "orappellerbara": "orappellerbar",
    "orappellerbarare": "orappellerbar",
    "orappellerbarares": "orappellerbar",
    "orappellerbaras": "orappellerbar",
    "orappellerbarast": "orappellerbar",
    "orappellerbaraste": "orappellerbar",
    "orappellerbarastes": "orappellerbar",
    "orappellerbarasts": "orappellerbar",
    "orappellerbare": "orappellerbar",
    "orappellerbares": "orappellerbar",
    "orappellerbarheten": "orappellerbarhet",
    "orappellerbarhetens": "orappellerbarhet",
    "orappellerbarhets": "orappellerbarhet",
    "orappellerbars": "orappellerbar",
    "orappellerbart": "orappellerbar",
    "orappellerbarts": "orappellerbar",
    "orapporterade": "orapporterad",
    "orapporterades": "orapporterad",
    "orapporterads": "orapporterad",
    "orapporterat": "orapporterad",
    "orapporterats": "orapporterad",
    "orapporterbara": "orapporterbar",
    "orapporterbarare": "orapporterbar",
    "orapporterbarares": "orapporterbar",
    "orapporterbaras": "orapporterbar",
    "orapporterbarast": "orapporterbar",
    "orapporterbaraste": "orapporterbar",
    "orapporterbarastes": "orapporterbar",
    "orapporterbarasts": "orapporterbar",
    "orapporterbare": "orapporterbar",
    "orapporterbares": "orapporterbar",
    "orapporterbarheten": "orapporterbarhet",
    "orapporterbarhetens": "orapporterbarhet",
    "orapporterbarhets": "orapporterbarhet",
    "orapporterbars": "orapporterbar",
    "orapporterbart": "orapporterbar",
    "orapporterbarts": "orapporterbar",
    "oraserade": "oraserad",
    "oraserades": "oraserad",
    "oraserads": "oraserad",
    "oraserat": "oraserad",
    "oraserats": "oraserad",
    "oraserbara": "oraserbar",
    "oraserbarare": "oraserbar",
    "oraserbarares": "oraserbar",
    "oraserbaras": "oraserbar",
    "oraserbarast": "oraserbar",
    "oraserbaraste": "oraserbar",
    "oraserbarastes": "oraserbar",
    "oraserbarasts": "oraserbar",
    "oraserbare": "oraserbar",
    "oraserbares": "oraserbar",
    "oraserbarheten": "oraserbarhet",
    "oraserbarhetens": "oraserbarhet",
    "oraserbarhets": "oraserbarhet",
    "oraserbars": "oraserbar",
    "oraserbart": "oraserbar",
    "oraserbarts": "oraserbar",
    "oraspade": "oraspad",
    "oraspades": "oraspad",
    "oraspads": "oraspad",
    "oraspat": "oraspad",
    "oraspats": "oraspad",
    "orastade": "orastad",
    "orastades": "orastad",
    "orastads": "orastad",
    "orastat": "orastad",
    "orastats": "orastad",
    "oratade": "oratad",
    "oratades": "oratad",
    "oratads": "oratad",
    "oratat": "oratad",
    "oratats": "oratad",
    "oratificerade": "oratificerad",
    "oratificerades": "oratificerad",
    "oratificerads": "oratificerad",
    "oratificerat": "oratificerad",
    "oratificerats": "oratificerad",
    "oratificerbara": "oratificerbar",
    "oratificerbarare": "oratificerbar",
    "oratificerbarares": "oratificerbar",
    "oratificerbaras": "oratificerbar",
    "oratificerbarast": "oratificerbar",
    "oratificerbaraste": "oratificerbar",
    "oratificerbarastes": "oratificerbar",
    "oratificerbarasts": "oratificerbar",
    "oratificerbare": "oratificerbar",
    "oratificerbares": "oratificerbar",
    "oratificerbarheten": "oratificerbarhet",
    "oratificerbarhetens": "oratificerbarhet",
    "oratificerbarhets": "oratificerbarhet",
    "oratificerbars": "oratificerbar",
    "oratificerbart": "oratificerbar",
    "oratificerbarts": "oratificerbar",
    "orationaliserade": "orationaliserad",
    "orationaliserades": "orationaliserad",
    "orationaliserads": "orationaliserad",
    "orationaliserat": "orationaliserad",
    "orationaliserats": "orationaliserad",
    "orationaliserbara": "orationaliserbar",
    "orationaliserbarare": "orationaliserbar",
    "orationaliserbarares": "orationaliserbar",
    "orationaliserbaras": "orationaliserbar",
    "orationaliserbarast": "orationaliserbar",
    "orationaliserbaraste": "orationaliserbar",
    "orationaliserbarastes": "orationaliserbar",
    "orationaliserbarasts": "orationaliserbar",
    "orationaliserbare": "orationaliserbar",
    "orationaliserbares": "orationaliserbar",
    "orationaliserbarheten": "orationaliserbarhet",
    "orationaliserbarhetens": "orationaliserbarhet",
    "orationaliserbarhets": "orationaliserbarhet",
    "orationaliserbars": "orationaliserbar",
    "orationaliserbart": "orationaliserbar",
    "orationaliserbarts": "orationaliserbar",
    "orationella": "orationell",
    "orationellare": "orationell",
    "orationellares": "orationell",
    "orationellas": "orationell",
    "orationellast": "orationell",
    "orationellaste": "orationell",
    "orationellastes": "orationell",
    "orationellasts": "orationell",
    "orationelle": "orationell",
    "orationelles": "orationell",
    "orationells": "orationell",
    "orationellt": "orationell",
    "orationellts": "orationell",
    "orationen": "oration",
    "orationens": "oration",
    "orationer": "oration",
    "orationerna": "oration",
    "orationernas": "oration",
    "orationers": "oration",
    "orations": "oration",
    "oratorer": "orator",
    "oratorerna": "orator",
    "oratorernas": "orator",
    "oratorers": "orator",
    "oratorie": "oratorium",
    "oratorier": "oratorium",
    "oratorierna": "oratorium",
    "oratoriernas": "oratorium",
    "oratoriers": "oratorium",
    "oratoriet": "oratorium",
    "oratoriets": "oratorium",
    "oratoriska": "oratorisk",
    "oratoriskare": "oratorisk",
    "oratoriskares": "oratorisk",
    "oratoriskas": "oratorisk",
    "oratoriskast": "oratorisk",
    "oratoriskaste": "oratorisk",
    "oratoriskastes": "oratorisk",
    "oratoriskasts": "oratorisk",
    "oratoriske": "oratorisk",
    "oratoriskes": "oratorisk",
    "oratorisks": "oratorisk",
    "oratoriskt": "oratorisk",
    "oratoriskts": "oratorisk",
    "oratoriums": "oratorium",
    "oratorn": "orator",
    "oratorns": "orator",
    "orators": "orator",
    "orattade": "orattad",
    "orattades": "orattad",
    "orattads": "orattad",
    "orattat": "orattad",
    "orattats": "orattad",
    "orbitalen": "orbital",
    "orbitalens": "orbital",
    "orbitaler": "orbital",
    "orbitalerna": "orbital",
    "orbitalernas": "orbital",
    "orbitalers": "orbital",
    "orbitals": "orbital",
    "orchestran": "orchestra",
    "orchestrans": "orchestra",
    "orchestras": "orchestra",
    "orchestror": "orchestra",
    "orchestrorna": "orchestra",
    "orchestrornas": "orchestra",
    "orchestrors": "orchestra",
    "ordaccenten": "ordaccent",
    "ordaccentens": "ordaccent",
    "ordaccenter": "ordaccent",
    "ordaccenterna": "ordaccent",
    "ordaccenternas": "ordaccent",
    "ordaccenters": "ordaccent",
    "ordaccents": "ordaccent",
    "ordade": "orda",
    "ordades": "orda",
    "ordagranna": "ordagrann",
    "ordagrannare": "ordagrann",
    "ordagrannares": "ordagrann",
    "ordagrannas": "ordagrann",
    "ordagrannast": "ordagrann",
    "ordagrannaste": "ordagrann",
    "ordagrannastes": "ordagrann",
    "ordagrannasts": "ordagrann",
    "ordagranne": "ordagrann",
    "ordagrannes": "ordagrann",
    "ordagranns": "ordagrann",
    "ordagrant": "ordagrann",
    "ordagrants": "ordagrann",
    "ordalagen": "ordalag",
    "ordalagens": "ordalag",
    "ordalags": "ordalag",
    "ordalen": "ordal",
    "ordalens": "ordal",
    "ordalet": "ordal",
    "ordalets": "ordal",
    "ordalier": "ordal",
    "ordalierna": "ordal",
    "ordaliernas": "ordal",
    "ordaliers": "ordal",
    "ordals": "ordal",
    "ordalydelsen": "ordalydelse",
    "ordalydelsens": "ordalydelse",
    "ordalydelser": "ordalydelse",
    "ordalydelserna": "ordalydelse",
    "ordalydelsernas": "ordalydelse",
    "ordalydelsers": "ordalydelse",
    "ordalydelses": "ordalydelse",
    "ordande": "orda",
    "ordanden": "ordande",
    "ordandena": "ordande",
    "ordandenas": "ordande",
    "ordandens": "ordande",
    "ordandes": "ordande",
    "ordandet": "ordande",
    "ordandets": "ordande",
    "ordar": "orda",
    "ordas": "orda",
    "ordat": "orda",
    "ordats": "orda",
    "ordbehandlar": "ordbehandlare",
    "ordbehandlaren": "ordbehandlare",
    "ordbehandlarens": "ordbehandlare",
    "ordbehandlares": "ordbehandlare",
    "ordbehandlarna": "ordbehandlare",
    "ordbehandlarnas": "ordbehandlare",
    "ordbehandlingar": "ordbehandling",
    "ordbehandlingarna": "ordbehandling",
    "ordbehandlingarnas": "ordbehandling",
    "ordbehandlingars": "ordbehandling",
    "ordbehandlingen": "ordbehandling",
    "ordbehandlingens": "ordbehandling",
    "ordbehandlings": "ordbehandling",
    "ordbilden": "ordbild",
    "ordbildens": "ordbild",
    "ordbilder": "ordbild",
    "ordbilderna": "ordbild",
    "ordbildernas": "ordbild",
    "ordbilders": "ordbild",
    "ordbildningar": "ordbildning",
    "ordbildningarna": "ordbildning",
    "ordbildningarnas": "ordbildning",
    "ordbildningars": "ordbildning",
    "ordbildningen": "ordbildning",
    "ordbildningens": "ordbildning",
    "ordbildnings": "ordbildning",
    "ordbilds": "ordbild",
    "ordblinda": "ordblind",
    "ordblindare": "ordblind",
    "ordblindares": "ordblind",
    "ordblindas": "ordblind",
    "ordblindast": "ordblind",
    "ordblindaste": "ordblind",
    "ordblindastes": "ordblind",
    "ordblindasts": "ordblind",
    "ordblinde": "ordblind",
    "ordblindes": "ordblind",
    "ordblindheten": "ordblindhet",
    "ordblindhetens": "ordblindhet",
    "ordblindheter": "ordblindhet",
    "ordblindheterna": "ordblindhet",
    "ordblindheternas": "ordblindhet",
    "ordblindheters": "ordblindhet",
    "ordblindhets": "ordblindhet",
    "ordblinds": "ordblind",
    "ordblint": "ordblind",
    "ordblints": "ordblind",
    "ordboken": "ordbok",
    "ordbokens": "ordbok",
    "ordboks": "ordbok",
    "ordbredden": "ordbredd",
    "ordbreddens": "ordbredd",
    "ordbredder": "ordbredd",
    "ordbredderna": "ordbredd",
    "ordbreddernas": "ordbredd",
    "ordbredders": "ordbredd",
    "ordbredds": "ordbredd",
    "ordbyten": "ordbyte",
    "ordbytena": "ordbyte",
    "ordbytenas": "ordbyte",
    "ordbytens": "ordbyte",
    "ordbytes": "ordbyte",
    "ordbytet": "ordbyte",
    "ordbytets": "ordbyte",
    "ordböcker": "ordbok",
    "ordböckerna": "ordbok",
    "ordböckernas": "ordbok",
    "ordböckers": "ordbok",
    "ordböjningar": "ordböjning",
    "ordböjningarna": "ordböjning",
    "ordböjningarnas": "ordböjning",
    "ordböjningars": "ordböjning",
    "ordböjningen": "ordböjning",
    "ordböjningens": "ordböjning",
    "ordböjnings": "ordböjning",
    "orddelar": "orddelare",
    "orddelaren": "orddelare",
    "orddelarens": "orddelare",
    "orddelares": "orddelare",
    "orddelarna": "orddelare",
    "orddelarnas": "orddelare",
    "orddelars": "orddel",
    "orddelen": "orddel",
    "orddelens": "orddel",
    "orddels": "orddel",
    "orddöva": "orddöv",
    "orddövare": "orddöv",
    "orddövares": "orddöv",
    "orddövas": "orddöv",
    "orddövast": "orddöv",
    "orddövaste": "orddöv",
    "orddövastes": "orddöv",
    "orddövasts": "orddöv",
    "orddöve": "orddöv",
    "orddöves": "orddöv",
    "orddövheten": "orddövhet",
    "orddövhetens": "orddövhet",
    "orddövhets": "orddövhet",
    "orddövs": "orddöv",
    "orddövt": "orddöv",
    "orddövts": "orddöv",
    "orden": "ord",
    "ordens": "orden",
    "ordenskapitels": "ordenskapitel",
    "ordenskapitlen": "ordenskapitel",
    "ordenskapitlens": "ordenskapitel",
    "ordenskapitlet": "ordenskapitel",
    "ordenskapitlets": "ordenskapitel",
    "ordensmedlemmar": "ordensmedlem",
    "ordensmedlemmarna": "ordensmedlem",
    "ordensmedlemmarnas": "ordensmedlem",
    "ordensmedlemmars": "ordensmedlem",
    "ordensmedlemmen": "ordensmedlem",
    "ordensmedlemmens": "ordensmedlem",
    "ordensmedlems": "ordensmedlem",
    "ordensstjärnan": "ordensstjärna",
    "ordensstjärnans": "ordensstjärna",
    "ordensstjärnas": "ordensstjärna",
    "ordensstjärne": "ordensstjärna",
    "ordensstjärnor": "ordensstjärna",
    "ordensstjärnorna": "ordensstjärna",
    "ordensstjärnornas": "ordensstjärna",
    "ordensstjärnors": "ordensstjärna",
    "ordenssällskapen": "ordenssällskap",
    "ordenssällskapens": "ordenssällskap",
    "ordenssällskapet": "ordenssällskap",
    "ordenssällskapets": "ordenssällskap",
    "ordenssällskaps": "ordenssällskap",
    "ordentliga": "ordentlig",
    "ordentligare": "ordentlig",
    "ordentligares": "ordentlig",
    "ordentligas": "ordentlig",
    "ordentligast": "ordentlig",
    "ordentligaste": "ordentlig",
    "ordentligastes": "ordentlig",
    "ordentligasts": "ordentlig",
    "ordentlige": "ordentlig",
    "ordentliges": "ordentlig",
    "ordentligheten": "ordentlighet",
    "ordentlighetens": "ordentlighet",
    "ordentlighets": "ordentlighet",
    "ordentligs": "ordentlig",
    "ordentligt": "ordentlig",
    "ordentligts": "ordentlig",
    "ordern": "order",
    "orderna": "order",
    "ordernas": "order",
    "orderns": "order",
    "orders": "order",
    "orderstockar": "orderstock",
    "orderstockarna": "orderstock",
    "orderstockarnas": "orderstock",
    "orderstockars": "orderstock",
    "orderstocken": "orderstock",
    "orderstockens": "orderstock",
    "orderstocks": "orderstock",
    "ordet": "ord",
    "ordets": "ord",
    "ordfattiga": "ordfattig",
    "ordfattigare": "ordfattig",
    "ordfattigares": "ordfattig",
    "ordfattigas": "ordfattig",
    "ordfattigast": "ordfattig",
    "ordfattigaste": "ordfattig",
    "ordfattigastes": "ordfattig",
    "ordfattigasts": "ordfattig",
    "ordfattige": "ordfattig",
    "ordfattiges": "ordfattig",
    "ordfattigheten": "ordfattighet",
    "ordfattighetens": "ordfattighet",
    "ordfattighets": "ordfattighet",
    "ordfattigs": "ordfattig",
    "ordfattigt": "ordfattig",
    "ordfattigts": "ordfattig",
    "ordflät": "ordfläta",
    "ordflätan": "ordfläta",
    "ordflätans": "ordfläta",
    "ordflätas": "ordfläta",
    "ordfläte": "ordfläta",
    "ordflätor": "ordfläta",
    "ordflätorna": "ordfläta",
    "ordflätornas": "ordfläta",
    "ordflätors": "ordfläta",
    "ordfläts": "ordfläta",
    "ordflöden": "ordflöde",
    "ordflödena": "ordflöde",
    "ordflödenas": "ordflöde",
    "ordflödens": "ordflöde",
    "ordflödes": "ordflöde",
    "ordflödet": "ordflöde",
    "ordflödets": "ordflöde",
    "ordfogningar": "ordfogning",
    "ordfogningarna": "ordfogning",
    "ordfogningarnas": "ordfogning",
    "ordfogningars": "ordfogning",
    "ordfogningen": "ordfogning",
    "ordfogningens": "ordfogning",
    "ordfognings": "ordfogning",
    "ordformen": "ordform",
    "ordformens": "ordform",
    "ordformer": "ordform",
    "ordformerna": "ordform",
    "ordformernas": "ordform",
    "ordformers": "ordform",
    "ordforms": "ordform",
    "ordfoten": "ordfot",
    "ordfotens": "ordfot",
    "ordfots": "ordfot",
    "ordfragmenten": "ordfragment",
    "ordfragmentens": "ordfragment",
    "ordfragmentet": "ordfragment",
    "ordfragmentets": "ordfragment",
    "ordfragments": "ordfragment",
    "ordföljden": "ordföljd",
    "ordföljdens": "ordföljd",
    "ordföljder": "ordföljd",
    "ordföljderna": "ordföljd",
    "ordföljdernas": "ordföljd",
    "ordföljders": "ordföljd",
    "ordföljds": "ordföljd",
    "ordförandeklubb": "ordförandeklubba",
    "ordförandeklubban": "ordförandeklubba",
    "ordförandeklubbans": "ordförandeklubba",
    "ordförandeklubbas": "ordförandeklubba",
    "ordförandeklubbe": "ordförandeklubba",
    "ordförandeklubbor": "ordförandeklubba",
    "ordförandeklubborna": "ordförandeklubba",
    "ordförandeklubbornas": "ordförandeklubba",
    "ordförandeklubbors": "ordförandeklubba",
    "ordförandeklubbs": "ordförandeklubba",
    "ordförandelandet": "ordförandeland",
    "ordförandelandets": "ordförandeland",
    "ordförandelands": "ordförandeland",
    "ordförandeländer": "ordförandeland",
    "ordförandeländerna": "ordförandeland",
    "ordförandeländernas": "ordförandeland",
    "ordförandeländers": "ordförandeland",
    "ordföranden": "ordförande",
    "ordförandena": "ordförande",
    "ordförandenas": "ordförande",
    "ordförandens": "ordförande",
    "ordförandes": "ordförande",
    "ordförandeskapen": "ordförandeskap",
    "ordförandeskapens": "ordförandeskap",
    "ordförandeskapet": "ordförandeskap",
    "ordförandeskapets": "ordförandeskap",
    "ordförandeskaps": "ordförandeskap",
    "ordförekomsten": "ordförekomst",
    "ordförekomstens": "ordförekomst",
    "ordförekomster": "ordförekomst",
    "ordförekomsterna": "ordförekomst",
    "ordförekomsternas": "ordförekomst",
    "ordförekomsters": "ordförekomst",
    "ordförekomsts": "ordförekomst",
    "ordförklaringar": "ordförklaring",
    "ordförklaringarna": "ordförklaring",
    "ordförklaringarnas": "ordförklaring",
    "ordförklaringars": "ordförklaring",
    "ordförklaringen": "ordförklaring",
    "ordförklaringens": "ordförklaring",
    "ordförklarings": "ordförklaring",
    "ordförråden": "ordförråd",
    "ordförrådens": "ordförråd",
    "ordförrådet": "ordförråd",
    "ordförrådets": "ordförråd",
    "ordförråds": "ordförråd",
    "ordfötter": "ordfot",
    "ordfötterna": "ordfot",
    "ordfötternas": "ordfot",
    "ordfötters": "ordfot",
    "ordgeografien": "ordgeografi",
    "ordgeografiens": "ordgeografi",
    "ordgeografin": "ordgeografi",
    "ordgeografins": "ordgeografi",
    "ordgeografis": "ordgeografi",
    "ordgruppen": "ordgrupp",
    "ordgruppens": "ordgrupp",
    "ordgrupper": "ordgrupp",
    "ordgrupperna": "ordgrupp",
    "ordgruppernas": "ordgrupp",
    "ordgruppers": "ordgrupp",
    "ordgrupps": "ordgrupp",
    "ordgåt": "ordgåta",
    "ordgåtan": "ordgåta",
    "ordgåtans": "ordgåta",
    "ordgåtas": "ordgåta",
    "ordgåte": "ordgåta",
    "ordgåtor": "ordgåta",
    "ordgåtorna": "ordgåta",
    "ordgåtornas": "ordgåta",
    "ordgåtors": "ordgåta",
    "ordgåts": "ordgåta",
    "ordhålliga": "ordhållig",
    "ordhålligare": "ordhållig",
    "ordhålligares": "ordhållig",
    "ordhålligas": "ordhållig",
    "ordhålligast": "ordhållig",
    "ordhålligaste": "ordhållig",
    "ordhålligastes": "ordhållig",
    "ordhålligasts": "ordhållig",
    "ordhållige": "ordhållig",
    "ordhålliges": "ordhållig",
    "ordhålligheten": "ordhållighet",
    "ordhållighetens": "ordhållighet",
    "ordhållighets": "ordhållighet",
    "ordhålligs": "ordhållig",
    "ordhålligt": "ordhållig",
    "ordhålligts": "ordhållig",
    "ordinanden": "ordinand",
    "ordinandens": "ordinand",
    "ordinander": "ordinand",
    "ordinanderna": "ordinand",
    "ordinandernas": "ordinand",
    "ordinanders": "ordinand",
    "ordinands": "ordinand",
    "ordinariesatt": "ordinariesätta",
    "ordinariesatta": "ordinariesätta",
    "ordinariesattas": "ordinariesätta",
    "ordinariesatte": "ordinariesätta",
    "ordinariesattes": "ordinariesätta",
    "ordinariesatts": "ordinariesätta",
    "ordinariesätt": "ordinariesätta",
    "ordinariesättande": "ordinariesätta",
    "ordinariesättanden": "ordinariesättande",
    "ordinariesättandena": "ordinariesättande",
    "ordinariesättandenas": "ordinariesättande",
    "ordinariesättandens": "ordinariesättande",
    "ordinariesättandes": "ordinariesättande",
    "ordinariesättandet": "ordinariesättande",
    "ordinariesättandets": "ordinariesättande",
    "ordinariesättas": "ordinariesätta",
    "ordinariesätter": "ordinariesätta",
    "ordinariesättes": "ordinariesätta",
    "ordinariesätts": "ordinariesätta",
    "ordinat": "ordinata",
    "ordinatan": "ordinata",
    "ordinatans": "ordinata",
    "ordinatas": "ordinata",
    "ordinate": "ordinata",
    "ordinationen": "ordination",
    "ordinationens": "ordination",
    "ordinationer": "ordination",
    "ordinationerna": "ordination",
    "ordinationernas": "ordination",
    "ordinationers": "ordination",
    "ordinations": "ordination",
    "ordinator": "ordinata",
    "ordinatorna": "ordinata",
    "ordinatornas": "ordinata",
    "ordinators": "ordinata",
    "ordinats": "ordinata",
    "ordinerad": "ordinera",
    "ordinerade": "ordinera",
    "ordinerades": "ordinera",
    "ordinerads": "ordinera",
    "ordinerande": "ordinera",
    "ordineranden": "ordinerande",
    "ordinerandena": "ordinerande",
    "ordinerandenas": "ordinerande",
    "ordinerandens": "ordinerande",
    "ordinerandes": "ordinerande",
    "ordinerandet": "ordinerande",
    "ordinerandets": "ordinerande",
    "ordinerar": "ordinera",
    "ordineras": "ordinera",
    "ordinerat": "ordinera",
    "ordinerats": "ordinera",
    "ordinerbara": "ordinerbar",
    "ordinerbarare": "ordinerbar",
    "ordinerbarares": "ordinerbar",
    "ordinerbaras": "ordinerbar",
    "ordinerbarast": "ordinerbar",
    "ordinerbaraste": "ordinerbar",
    "ordinerbarastes": "ordinerbar",
    "ordinerbarasts": "ordinerbar",
    "ordinerbare": "ordinerbar",
    "ordinerbares": "ordinerbar",
    "ordinerbarheten": "ordinerbarhet",
    "ordinerbarhetens": "ordinerbarhet",
    "ordinerbarhets": "ordinerbarhet",
    "ordinerbars": "ordinerbar",
    "ordinerbart": "ordinerbar",
    "ordinerbarts": "ordinerbar",
    "ordineringar": "ordinering",
    "ordineringarna": "ordinering",
    "ordineringarnas": "ordinering",
    "ordineringars": "ordinering",
    "ordineringen": "ordinering",
    "ordineringens": "ordinering",
    "ordinerings": "ordinering",
    "ordinära": "ordinär",
    "ordinärare": "ordinär",
    "ordinärares": "ordinär",
    "ordinäras": "ordinär",
    "ordinärast": "ordinär",
    "ordinäraste": "ordinär",
    "ordinärastes": "ordinär",
    "ordinärasts": "ordinär",
    "ordinäre": "ordinär",
    "ordinäres": "ordinär",
    "ordinärs": "ordinär",
    "ordinärt": "ordinär",
    "ordinärts": "ordinär",
    "ordkarga": "ordkarg",
    "ordkargare": "ordkarg",
    "ordkargares": "ordkarg",
    "ordkargas": "ordkarg",
    "ordkargast": "ordkarg",
    "ordkargaste": "ordkarg",
    "ordkargastes": "ordkarg",
    "ordkargasts": "ordkarg",
    "ordkarge": "ordkarg",
    "ordkarges": "ordkarg",
    "ordkargheten": "ordkarghet",
    "ordkarghetens": "ordkarghet",
    "ordkarghets": "ordkarghet",
    "ordkargs": "ordkarg",
    "ordkargt": "ordkarg",
    "ordkargts": "ordkarg",
    "ordklassen": "ordklass",
    "ordklassens": "ordklass",
    "ordklasser": "ordklass",
    "ordklasserna": "ordklass",
    "ordklassernas": "ordklass",
    "ordklassers": "ordklass",
    "ordklasstaggar": "ordklasstaggare",
    "ordklasstaggaren": "ordklasstaggare",
    "ordklasstaggarens": "ordklasstaggare",
    "ordklasstaggares": "ordklasstaggare",
    "ordklasstaggarna": "ordklasstaggare",
    "ordklasstaggarnas": "ordklasstaggare",
    "ordklyverier": "ordklyveri",
    "ordklyverierna": "ordklyveri",
    "ordklyveriernas": "ordklyveri",
    "ordklyveriers": "ordklyveri",
    "ordklyveriet": "ordklyveri",
    "ordklyveriets": "ordklyveri",
    "ordklyveris": "ordklyveri",
    "ordklyverit": "ordklyveri",
    "ordklyverits": "ordklyveri",
    "ordknappa": "ordknapp",
    "ordknappare": "ordknapp",
    "ordknappares": "ordknapp",
    "ordknappas": "ordknapp",
    "ordknappast": "ordknapp",
    "ordknappaste": "ordknapp",
    "ordknappastes": "ordknapp",
    "ordknappasts": "ordknapp",
    "ordknappe": "ordknapp",
    "ordknappes": "ordknapp",
    "ordknappheten": "ordknapphet",
    "ordknapphetens": "ordknapphet",
    "ordknapphets": "ordknapphet",
    "ordknapps": "ordknapp",
    "ordknappt": "ordknapp",
    "ordknappts": "ordknapp",
    "ordkonstnären": "ordkonstnär",
    "ordkonstnärens": "ordkonstnär",
    "ordkonstnärer": "ordkonstnär",
    "ordkonstnärerna": "ordkonstnär",
    "ordkonstnärernas": "ordkonstnär",
    "ordkonstnärers": "ordkonstnär",
    "ordkonstnärs": "ordkonstnär",
    "ordkonstruktionen": "ordkonstruktion",
    "ordkonstruktionens": "ordkonstruktion",
    "ordkonstruktioner": "ordkonstruktion",
    "ordkonstruktionerna": "ordkonstruktion",
    "ordkonstruktionernas": "ordkonstruktion",
    "ordkonstruktioners": "ordkonstruktion",
    "ordkonstruktions": "ordkonstruktion",
    "ordlekar": "ordlek",
    "ordlekarna": "ordlek",
    "ordlekarnas": "ordlek",
    "ordlekars": "ordlek",
    "ordleken": "ordlek",
    "ordlekens": "ordlek",
    "ordleks": "ordlek",
    "ordlistan": "ordlista",
    "ordlistans": "ordlista",
    "ordlistas": "ordlista",
    "ordliste": "ordlista",
    "ordlistor": "ordlista",
    "ordlistorna": "ordlista",
    "ordlistornas": "ordlista",
    "ordlistors": "ordlista",
    "ordlängden": "ordlängd",
    "ordlängdens": "ordlängd",
    "ordlängder": "ordlängd",
    "ordlängderna": "ordlängd",
    "ordlängdernas": "ordlängd",
    "ordlängders": "ordlängd",
    "ordlängds": "ordlängd",
    "ordlösa": "ordlös",
    "ordlösare": "ordlös",
    "ordlösares": "ordlös",
    "ordlösas": "ordlös",
    "ordlösast": "ordlös",
    "ordlösaste": "ordlös",
    "ordlösastes": "ordlös",
    "ordlösasts": "ordlös",
    "ordlöse": "ordlös",
    "ordlöses": "ordlös",
    "ordlösheten": "ordlöshet",
    "ordlöshetens": "ordlöshet",
    "ordlöshets": "ordlöshet",
    "ordlöst": "ordlös",
    "ordlösts": "ordlös",
    "ordnad": "ordna",
    "ordnade": "ordna",
    "ordnades": "ordna",
    "ordnads": "ordna",
    "ordnande": "ordna",
    "ordnanden": "ordnande",
    "ordnandena": "ordnande",
    "ordnandenas": "ordnande",
    "ordnandens": "ordnande",
    "ordnandes": "ordnande",
    "ordnandet": "ordnande",
    "ordnandets": "ordnande",
    "ordnar": "ordna",
    "ordnarna": "orden",
    "ordnarnas": "orden",
    "ordnars": "orden",
    "ordnas": "ordna",
    "ordnat": "ordna",
    "ordnats": "ordna",
    "ordnen": "orden",
    "ordnens": "orden",
    "ordningar": "ordning",
    "ordningarna": "ordning",
    "ordningarnas": "ordning",
    "ordningars": "ordning",
    "ordningen": "ordning",
    "ordningens": "ordning",
    "ordnings": "ordning",
    "ordningsamheten": "ordningsamhet",
    "ordningsamhetens": "ordningsamhet",
    "ordningsamhets": "ordningsamhet",
    "ordningsamma": "ordningsam",
    "ordningsammare": "ordningsam",
    "ordningsammares": "ordningsam",
    "ordningsammas": "ordningsam",
    "ordningsammast": "ordningsam",
    "ordningsammaste": "ordningsam",
    "ordningsammastes": "ordningsam",
    "ordningsammasts": "ordningsam",
    "ordningsamme": "ordningsam",
    "ordningsammes": "ordningsam",
    "ordningsams": "ordningsam",
    "ordningsamt": "ordningsam",
    "ordningsamts": "ordningsam",
    "ordningsbestämmelsen": "ordningsbestämmelse",
    "ordningsbestämmelsens": "ordningsbestämmelse",
    "ordningsbestämmelser": "ordningsbestämmelse",
    "ordningsbestämmelserna": "ordningsbestämmelse",
    "ordningsbestämmelsernas": "ordningsbestämmelse",
    "ordningsbestämmelsers": "ordningsbestämmelse",
    "ordningsbestämmelses": "ordningsbestämmelse",
    "ordningsboten": "ordningsbot",
    "ordningsbotens": "ordningsbot",
    "ordningsbots": "ordningsbot",
    "ordningsfrågan": "ordningsfråga",
    "ordningsfrågans": "ordningsfråga",
    "ordningsfrågas": "ordningsfråga",
    "ordningsfråge": "ordningsfråga",
    "ordningsfrågor": "ordningsfråga",
    "ordningsfrågorna": "ordningsfråga",
    "ordningsfrågornas": "ordningsfråga",
    "ordningsfrågors": "ordningsfråga",
    "ordningsföljden": "ordningsföljd",
    "ordningsföljdens": "ordningsföljd",
    "ordningsföljder": "ordningsföljd",
    "ordningsföljderna": "ordningsföljd",
    "ordningsföljdernas": "ordningsföljd",
    "ordningsföljders": "ordningsföljd",
    "ordningsföljds": "ordningsföljd",
    "ordningsförseelsen": "ordningsförseelse",
    "ordningsförseelsens": "ordningsförseelse",
    "ordningsförseelser": "ordningsförseelse",
    "ordningsförseelserna": "ordningsförseelse",
    "ordningsförseelsernas": "ordningsförseelse",
    "ordningsförseelsers": "ordningsförseelse",
    "ordningsförseelses": "ordningsförseelse",
    "ordningsmakten": "ordningsmakt",
    "ordningsmaktens": "ordningsmakt",
    "ordningsmakts": "ordningsmakt",
    "ordningsmannen": "ordningsman",
    "ordningsmannens": "ordningsman",
    "ordningsmans": "ordningsman",
    "ordningsmän": "ordningsman",
    "ordningsmännen": "ordningsman",
    "ordningsmännens": "ordningsman",
    "ordningsmäns": "ordningsman",
    "ordningspolisen": "ordningspolis",
    "ordningspolisens": "ordningspolis",
    "ordningspoliser": "ordningspolis",
    "ordningspoliserna": "ordningspolis",
    "ordningspolisernas": "ordningspolis",
    "ordningspolisers": "ordningspolis",
    "ordningsprincipen": "ordningsprincip",
    "ordningsprincipens": "ordningsprincip",
    "ordningsprinciper": "ordningsprincip",
    "ordningsprinciperna": "ordningsprincip",
    "ordningsprincipernas": "ordningsprincip",
    "ordningsprincipers": "ordningsprincip",
    "ordningsprincips": "ordningsprincip",
    "ordningsstadgan": "ordningsstadga",
    "ordningsstadgans": "ordningsstadga",
    "ordningsstadgas": "ordningsstadga",
    "ordningsstadge": "ordningsstadga",
    "ordningsstadgor": "ordningsstadga",
    "ordningsstadgorna": "ordningsstadga",
    "ordningsstadgornas": "ordningsstadga",
    "ordningsstadgors": "ordningsstadga",
    "ordningstalen": "ordningstal",
    "ordningstalens": "ordningstal",
    "ordningstalet": "ordningstal",
    "ordningstalets": "ordningstal",
    "ordningstals": "ordningstal",
    "ordningsvakten": "ordningsvakt",
    "ordningsvaktens": "ordningsvakt",
    "ordningsvakter": "ordningsvakt",
    "ordningsvakterna": "ordningsvakt",
    "ordningsvakternas": "ordningsvakt",
    "ordningsvakters": "ordningsvakt",
    "ordningsvakts": "ordningsvakt",
    "ordnäten": "ordnät",
    "ordnätens": "ordnät",
    "ordnätet": "ordnät",
    "ordnätets": "ordnät",
    "ordnäts": "ordnät",
    "ordonnansen": "ordonnans",
    "ordonnansens": "ordonnans",
    "ordonnanser": "ordonnans",
    "ordonnanserna": "ordonnans",
    "ordonnansernas": "ordonnans",
    "ordonnansers": "ordonnans",
    "ordovicia": "ordovicium",
    "ordoviciana": "ordovicium",
    "ordovicianas": "ordovicium",
    "ordovicias": "ordovicium",
    "ordoviciumet": "ordovicium",
    "ordoviciumets": "ordovicium",
    "ordoviciums": "ordovicium",
    "ordrar": "order",
    "ordrarna": "order",
    "ordrarnas": "order",
    "ordrars": "order",
    "ordrika": "ordrik",
    "ordrikare": "ordrik",
    "ordrikares": "ordrik",
    "ordrikas": "ordrik",
    "ordrikast": "ordrik",
    "ordrikaste": "ordrik",
    "ordrikastes": "ordrik",
    "ordrikasts": "ordrik",
    "ordrike": "ordrik",
    "ordrikes": "ordrik",
    "ordrikheten": "ordrikhet",
    "ordrikhetens": "ordrikhet",
    "ordrikhets": "ordrikhet",
    "ordriks": "ordrik",
    "ordrikt": "ordrik",
    "ordrikts": "ordrik",
    "ordrosen": "ordros",
    "ordrosens": "ordros",
    "ordrosor": "ordros",
    "ordrosorna": "ordros",
    "ordrosornas": "ordros",
    "ordrosors": "ordros",
    "ordroten": "ordrot",
    "ordrotens": "ordrot",
    "ordrots": "ordrot",
    "ordryttar": "ordryttare",
    "ordryttaren": "ordryttare",
    "ordryttarens": "ordryttare",
    "ordryttares": "ordryttare",
    "ordryttarna": "ordryttare",
    "ordryttarnas": "ordryttare",
    "ordrätta": "ordrätt",
    "ordrättare": "ordrätt",
    "ordrättares": "ordrätt",
    "ordrättas": "ordrätt",
    "ordrättast": "ordrätt",
    "ordrättaste": "ordrätt",
    "ordrättastes": "ordrätt",
    "ordrättasts": "ordrätt",
    "ordrätte": "ordrätt",
    "ordrättes": "ordrätt",
    "ordrätts": "ordrätt",
    "ordrötter": "ordrot",
    "ordrötterna": "ordrot",
    "ordrötternas": "ordrot",
    "ordrötters": "ordrot",
    "ords": "ord",
    "ordsemantiken": "ordsemantik",
    "ordsemantikens": "ordsemantik",
    "ordsemantiks": "ordsemantik",
    "ordskiften": "ordskifte",
    "ordskiftena": "ordskifte",
    "ordskiftenas": "ordskifte",
    "ordskiftens": "ordskifte",
    "ordskiftes": "ordskifte",
    "ordskiftet": "ordskifte",
    "ordskiftets": "ordskifte",
    "ordskillnaden": "ordskillnad",
    "ordskillnadens": "ordskillnad",
    "ordskillnader": "ordskillnad",
    "ordskillnaderna": "ordskillnad",
    "ordskillnadernas": "ordskillnad",
    "ordskillnaders": "ordskillnad",
    "ordskillnads": "ordskillnad",
    "ordskriften": "ordskrift",
    "ordskriftens": "ordskrift",
    "ordskrifter": "ordskrift",
    "ordskrifterna": "ordskrift",
    "ordskrifternas": "ordskrift",
    "ordskrifters": "ordskrift",
    "ordskrifts": "ordskrift",
    "ordsluten": "ordslut",
    "ordslutens": "ordslut",
    "ordslutet": "ordslut",
    "ordslutets": "ordslut",
    "ordsluts": "ordslut",
    "ordspillans": "ordspillan",
    "ordspråken": "ordspråk",
    "ordspråkens": "ordspråk",
    "ordspråket": "ordspråk",
    "ordspråkets": "ordspråk",
    "ordspråks": "ordspråk",
    "ordspråksmässiga": "ordspråksmässig",
    "ordspråksmässigare": "ordspråksmässig",
    "ordspråksmässigares": "ordspråksmässig",
    "ordspråksmässigas": "ordspråksmässig",
    "ordspråksmässigast": "ordspråksmässig",
    "ordspråksmässigaste": "ordspråksmässig",
    "ordspråksmässigastes": "ordspråksmässig",
    "ordspråksmässigasts": "ordspråksmässig",
    "ordspråksmässige": "ordspråksmässig",
    "ordspråksmässiges": "ordspråksmässig",
    "ordspråksmässigs": "ordspråksmässig",
    "ordspråksmässigt": "ordspråksmässig",
    "ordspråksmässigts": "ordspråksmässig",
    "ordstammar": "ordstam",
    "ordstammarna": "ordstam",
    "ordstammarnas": "ordstam",
    "ordstammars": "ordstam",
    "ordstammen": "ordstam",
    "ordstammens": "ordstam",
    "ordstams": "ordstam",
    "ordstumheten": "ordstumhet",
    "ordstumhetens": "ordstumhet",
    "ordstumhets": "ordstumhet",
    "ordstumma": "ordstum",
    "ordstummare": "ordstum",
    "ordstummares": "ordstum",
    "ordstummas": "ordstum",
    "ordstummast": "ordstum",
    "ordstummaste": "ordstum",
    "ordstummastes": "ordstum",
    "ordstummasts": "ordstum",
    "ordstumme": "ordstum",
    "ordstummes": "ordstum",
    "ordstums": "ordstum",
    "ordstumt": "ordstum",
    "ordstumts": "ordstum",
    "ordstäven": "ordstäv",
    "ordstävens": "ordstäv",
    "ordstävet": "ordstäv",
    "ordstävets": "ordstäv",
    "ordstävs": "ordstäv",
    "ordtrogens": "ordtrogen",
    "ordtroget": "ordtrogen",
    "ordtrogets": "ordtrogen",
    "ordtrogna": "ordtrogen",
    "ordtrognare": "ordtrogen",
    "ordtrognares": "ordtrogen",
    "ordtrognas": "ordtrogen",
    "ordtrognast": "ordtrogen",
    "ordtrognaste": "ordtrogen",
    "ordtrognastes": "ordtrogen",
    "ordtrognasts": "ordtrogen",
    "ordtrogne": "ordtrogen",
    "ordtrognes": "ordtrogen",
    "ordvalen": "ordval",
    "ordvalens": "ordval",
    "ordvalet": "ordval",
    "ordvalets": "ordval",
    "ordvals": "ordval",
    "ordvirveln": "ordvirvel",
    "ordvirvelns": "ordvirvel",
    "ordvirvels": "ordvirvel",
    "ordvirvlar": "ordvirvel",
    "ordvirvlarna": "ordvirvel",
    "ordvirvlarnas": "ordvirvel",
    "ordvirvlars": "ordvirvel",
    "ordvitsar": "ordvits",
    "ordvitsarna": "ordvits",
    "ordvitsarnas": "ordvits",
    "ordvitsars": "ordvits",
    "ordvitsen": "ordvits",
    "ordvitsens": "ordvits",
    "ordvrängar": "ordvrängare",
    "ordvrängaren": "ordvrängare",
    "ordvrängarens": "ordvrängare",
    "ordvrängares": "ordvrängare",
    "ordvrängarna": "ordvrängare",
    "ordvrängarnas": "ordvrängare",
    "ordvändningar": "ordvändning",
    "ordvändningarna": "ordvändning",
    "ordvändningarnas": "ordvändning",
    "ordvändningars": "ordvändning",
    "ordvändningen": "ordvändning",
    "ordvändningens": "ordvändning",
    "ordvändnings": "ordvändning",
    "ordväxlingar": "ordväxling",
    "ordväxlingarna": "ordväxling",
    "ordväxlingarnas": "ordväxling",
    "ordväxlingars": "ordväxling",
    "ordväxlingen": "ordväxling",
    "ordväxlingens": "ordväxling",
    "ordväxlings": "ordväxling",
    "oreaden": "oread",
    "oreadens": "oread",
    "oreader": "oread",
    "oreaderna": "oread",
    "oreadernas": "oread",
    "oreaders": "oread",
    "oreads": "oread",
    "oreaktiverade": "oreaktiverad",
    "oreaktiverades": "oreaktiverad",
    "oreaktiverads": "oreaktiverad",
    "oreaktiverat": "oreaktiverad",
    "oreaktiverats": "oreaktiverad",
    "oreaktiverbara": "oreaktiverbar",
    "oreaktiverbarare": "oreaktiverbar",
    "oreaktiverbarares": "oreaktiverbar",
    "oreaktiverbaras": "oreaktiverbar",
    "oreaktiverbarast": "oreaktiverbar",
    "oreaktiverbaraste": "oreaktiverbar",
    "oreaktiverbarastes": "oreaktiverbar",
    "oreaktiverbarasts": "oreaktiverbar",
    "oreaktiverbare": "oreaktiverbar",
    "oreaktiverbares": "oreaktiverbar",
    "oreaktiverbarheten": "oreaktiverbarhet",
    "oreaktiverbarhetens": "oreaktiverbarhet",
    "oreaktiverbarhets": "oreaktiverbarhet",
    "oreaktiverbars": "oreaktiverbar",
    "oreaktiverbart": "oreaktiverbar",
    "oreaktiverbarts": "oreaktiverbar",
    "orealiserade": "orealiserad",
    "orealiserades": "orealiserad",
    "orealiserads": "orealiserad",
    "orealiserat": "orealiserad",
    "orealiserats": "orealiserad",
    "orealiserbara": "orealiserbar",
    "orealiserbarare": "orealiserbar",
    "orealiserbarares": "orealiserbar",
    "orealiserbaras": "orealiserbar",
    "orealiserbarast": "orealiserbar",
    "orealiserbaraste": "orealiserbar",
    "orealiserbarastes": "orealiserbar",
    "orealiserbarasts": "orealiserbar",
    "orealiserbare": "orealiserbar",
    "orealiserbares": "orealiserbar",
    "orealiserbarheten": "orealiserbarhet",
    "orealiserbarhetens": "orealiserbarhet",
    "orealiserbarhets": "orealiserbarhet",
    "orealiserbars": "orealiserbar",
    "orealiserbart": "orealiserbar",
    "orealiserbarts": "orealiserbar",
    "orealistiska": "orealistisk",
    "orealistiskare": "orealistisk",
    "orealistiskares": "orealistisk",
    "orealistiskas": "orealistisk",
    "orealistiskast": "orealistisk",
    "orealistiskaste": "orealistisk",
    "orealistiskastes": "orealistisk",
    "orealistiskasts": "orealistisk",
    "orealistiske": "orealistisk",
    "orealistiskes": "orealistisk",
    "orealistisks": "orealistisk",
    "orealistiskt": "orealistisk",
    "orealistiskts": "orealistisk",
    "oreassurerade": "oreassurerad",
    "oreassurerades": "oreassurerad",
    "oreassurerads": "oreassurerad",
    "oreassurerat": "oreassurerad",
    "oreassurerats": "oreassurerad",
    "oreassurerbara": "oreassurerbar",
    "oreassurerbarare": "oreassurerbar",
    "oreassurerbarares": "oreassurerbar",
    "oreassurerbaras": "oreassurerbar",
    "oreassurerbarast": "oreassurerbar",
    "oreassurerbaraste": "oreassurerbar",
    "oreassurerbarastes": "oreassurerbar",
    "oreassurerbarasts": "oreassurerbar",
    "oreassurerbare": "oreassurerbar",
    "oreassurerbares": "oreassurerbar",
    "oreassurerbarheten": "oreassurerbarhet",
    "oreassurerbarhetens": "oreassurerbarhet",
    "oreassurerbarhets": "oreassurerbarhet",
    "oreassurerbars": "oreassurerbar",
    "oreassurerbart": "oreassurerbar",
    "oreassurerbarts": "oreassurerbar",
    "orecenserade": "orecenserad",
    "orecenserades": "orecenserad",
    "orecenserads": "orecenserad",
    "orecenserat": "orecenserad",
    "orecenserats": "orecenserad",
    "orecenserbara": "orecenserbar",
    "orecenserbarare": "orecenserbar",
    "orecenserbarares": "orecenserbar",
    "orecenserbaras": "orecenserbar",
    "orecenserbarast": "orecenserbar",
    "orecenserbaraste": "orecenserbar",
    "orecenserbarastes": "orecenserbar",
    "orecenserbarasts": "orecenserbar",
    "orecenserbare": "orecenserbar",
    "orecenserbares": "orecenserbar",
    "orecenserbarheten": "orecenserbarhet",
    "orecenserbarhetens": "orecenserbarhet",
    "orecenserbarhets": "orecenserbarhet",
    "orecenserbars": "orecenserbar",
    "orecenserbart": "orecenserbar",
    "orecenserbarts": "orecenserbar",
    "orecipierade": "orecipierad",
    "orecipierades": "orecipierad",
    "orecipierads": "orecipierad",
    "orecipierat": "orecipierad",
    "orecipierats": "orecipierad",
    "orecipierbara": "orecipierbar",
    "orecipierbarare": "orecipierbar",
    "orecipierbarares": "orecipierbar",
    "orecipierbaras": "orecipierbar",
    "orecipierbarast": "orecipierbar",
    "orecipierbaraste": "orecipierbar",
    "orecipierbarastes": "orecipierbar",
    "orecipierbarasts": "orecipierbar",
    "orecipierbare": "orecipierbar",
    "orecipierbares": "orecipierbar",
    "orecipierbarheten": "orecipierbarhet",
    "orecipierbarhetens": "orecipierbarhet",
    "orecipierbarhets": "orecipierbarhet",
    "orecipierbars": "orecipierbar",
    "orecipierbart": "orecipierbar",
    "orecipierbarts": "orecipierbar",
    "oreciterade": "oreciterad",
    "oreciterades": "oreciterad",
    "oreciterads": "oreciterad",
    "oreciterat": "oreciterad",
    "oreciterats": "oreciterad",
    "oreciterbara": "oreciterbar",
    "oreciterbarare": "oreciterbar",
    "oreciterbarares": "oreciterbar",
    "oreciterbaras": "oreciterbar",
    "oreciterbarast": "oreciterbar",
    "oreciterbaraste": "oreciterbar",
    "oreciterbarastes": "oreciterbar",
    "oreciterbarasts": "oreciterbar",
    "oreciterbare": "oreciterbar",
    "oreciterbares": "oreciterbar",
    "oreciterbarheten": "oreciterbarhet",
    "oreciterbarhetens": "oreciterbarhet",
    "oreciterbarhets": "oreciterbarhet",
    "oreciterbars": "oreciterbar",
    "oreciterbart": "oreciterbar",
    "oreciterbarts": "oreciterbar",
    "ored": "oreda",
    "oredad": "oreda",
    "oredade": "oreda",
    "oredades": "oreda",
    "oredads": "oreda",
    "oredan": "oreda",
    "oredande": "oreda",
    "oredanden": "oredande",
    "oredandena": "oredande",
    "oredandenas": "oredande",
    "oredandens": "oredande",
    "oredandes": "oredande",
    "oredandet": "oredande",
    "oredandets": "oredande",
    "oredans": "oreda",
    "oredar": "oreda",
    "oredas": "oreda",
    "oredat": "oreda",
    "oredats": "oreda",
    "orediga": "oredig",
    "oredigare": "oredig",
    "oredigares": "oredig",
    "oredigas": "oredig",
    "oredigast": "oredig",
    "oredigaste": "oredig",
    "oredigastes": "oredig",
    "oredigasts": "oredig",
    "oredige": "oredig",
    "oredigerade": "oredigerad",
    "oredigerades": "oredigerad",
    "oredigerads": "oredigerad",
    "oredigerat": "oredigerad",
    "oredigerats": "oredigerad",
    "oredigerbara": "oredigerbar",
    "oredigerbarare": "oredigerbar",
    "oredigerbarares": "oredigerbar",
    "oredigerbaras": "oredigerbar",
    "oredigerbarast": "oredigerbar",
    "oredigerbaraste": "oredigerbar",
    "oredigerbarastes": "oredigerbar",
    "oredigerbarasts": "oredigerbar",
    "oredigerbare": "oredigerbar",
    "oredigerbares": "oredigerbar",
    "oredigerbarheten": "oredigerbarhet",
    "oredigerbarhetens": "oredigerbarhet",
    "oredigerbarhets": "oredigerbarhet",
    "oredigerbars": "oredigerbar",
    "oredigerbart": "oredigerbar",
    "oredigerbarts": "oredigerbar",
    "orediges": "oredig",
    "oredigheten": "oredighet",
    "oredighetens": "oredighet",
    "oredighets": "oredighet",
    "oredigs": "oredig",
    "oredigt": "oredig",
    "oredigts": "oredig",
    "oredliga": "oredlig",
    "oredligare": "oredlig",
    "oredligares": "oredlig",
    "oredligas": "oredlig",
    "oredligast": "oredlig",
    "oredligaste": "oredlig",
    "oredligastes": "oredlig",
    "oredligasts": "oredlig",
    "oredlige": "oredlig",
    "oredliges": "oredlig",
    "oredligheten": "oredlighet",
    "oredlighetens": "oredlighet",
    "oredligheter": "oredlighet",
    "oredligheterna": "oredlighet",
    "oredligheternas": "oredlighet",
    "oredligheters": "oredlighet",
    "oredlighets": "oredlighet",
    "oredligs": "oredlig",
    "oredligt": "oredlig",
    "oredligts": "oredlig",
    "oredovisade": "oredovisad",
    "oredovisades": "oredovisad",
    "oredovisads": "oredovisad",
    "oredovisat": "oredovisad",
    "oredovisats": "oredovisad",
    "oredubblade": "oredubblad",
    "oredubblades": "oredubblad",
    "oredubblads": "oredubblad",
    "oredubblat": "oredubblad",
    "oredubblats": "oredubblad",
    "oreducerade": "oreducerad",
    "oreducerades": "oreducerad",
    "oreducerads": "oreducerad",
    "oreducerat": "oreducerad",
    "oreducerats": "oreducerad",
    "oreducerbara": "oreducerbar",
    "oreducerbarare": "oreducerbar",
    "oreducerbarares": "oreducerbar",
    "oreducerbaras": "oreducerbar",
    "oreducerbarast": "oreducerbar",
    "oreducerbaraste": "oreducerbar",
    "oreducerbarastes": "oreducerbar",
    "oreducerbarasts": "oreducerbar",
    "oreducerbare": "oreducerbar",
    "oreducerbares": "oreducerbar",
    "oreducerbarheten": "oreducerbarhet",
    "oreducerbarhetens": "oreducerbarhet",
    "oreducerbarhets": "oreducerbarhet",
    "oreducerbars": "oreducerbar",
    "oreducerbart": "oreducerbar",
    "oreducerbarts": "oreducerbar",
    "orefererade": "orefererad",
    "orefererades": "orefererad",
    "orefererads": "orefererad",
    "orefererat": "orefererad",
    "orefererats": "orefererad",
    "orefererbara": "orefererbar",
    "orefererbarare": "orefererbar",
    "orefererbarares": "orefererbar",
    "orefererbaras": "orefererbar",
    "orefererbarast": "orefererbar",
    "orefererbaraste": "orefererbar",
    "orefererbarastes": "orefererbar",
    "orefererbarasts": "orefererbar",
    "orefererbare": "orefererbar",
    "orefererbares": "orefererbar",
    "orefererbarheten": "orefererbarhet",
    "orefererbarhetens": "orefererbarhet",
    "orefererbarhets": "orefererbarhet",
    "orefererbars": "orefererbar",
    "orefererbart": "orefererbar",
    "orefererbarts": "orefererbar",
    "oreflekterade": "oreflekterad",
    "oreflekterades": "oreflekterad",
    "oreflekterads": "oreflekterad",
    "oreflekterat": "oreflekterad",
    "oreflekterats": "oreflekterad",
    "oreflekterbara": "oreflekterbar",
    "oreflekterbarare": "oreflekterbar",
    "oreflekterbarares": "oreflekterbar",
    "oreflekterbaras": "oreflekterbar",
    "oreflekterbarast": "oreflekterbar",
    "oreflekterbaraste": "oreflekterbar",
    "oreflekterbarastes": "oreflekterbar",
    "oreflekterbarasts": "oreflekterbar",
    "oreflekterbare": "oreflekterbar",
    "oreflekterbares": "oreflekterbar",
    "oreflekterbarheten": "oreflekterbarhet",
    "oreflekterbarhetens": "oreflekterbarhet",
    "oreflekterbarhets": "oreflekterbarhet",
    "oreflekterbars": "oreflekterbar",
    "oreflekterbart": "oreflekterbar",
    "oreflekterbarts": "oreflekterbar",
    "oreformerade": "oreformerad",
    "oreformerades": "oreformerad",
    "oreformerads": "oreformerad",
    "oreformerat": "oreformerad",
    "oreformerats": "oreformerad",
    "oreformerbara": "oreformerbar",
    "oreformerbarare": "oreformerbar",
    "oreformerbarares": "oreformerbar",
    "oreformerbaras": "oreformerbar",
    "oreformerbarast": "oreformerbar",
    "oreformerbaraste": "oreformerbar",
    "oreformerbarastes": "oreformerbar",
    "oreformerbarasts": "oreformerbar",
    "oreformerbare": "oreformerbar",
    "oreformerbares": "oreformerbar",
    "oreformerbarheten": "oreformerbarhet",
    "oreformerbarhetens": "oreformerbarhet",
    "oreformerbarhets": "oreformerbarhet",
    "oreformerbars": "oreformerbar",
    "oreformerbart": "oreformerbar",
    "oreformerbarts": "oreformerbar",
    "orefuserade": "orefuserad",
    "orefuserades": "orefuserad",
    "orefuserads": "orefuserad",
    "orefuserat": "orefuserad",
    "orefuserats": "orefuserad",
    "orefuserbara": "orefuserbar",
    "orefuserbarare": "orefuserbar",
    "orefuserbarares": "orefuserbar",
    "orefuserbaras": "orefuserbar",
    "orefuserbarast": "orefuserbar",
    "orefuserbaraste": "orefuserbar",
    "orefuserbarastes": "orefuserbar",
    "orefuserbarasts": "orefuserbar",
    "orefuserbare": "orefuserbar",
    "orefuserbares": "orefuserbar",
    "orefuserbarheten": "orefuserbarhet",
    "orefuserbarhetens": "orefuserbarhet",
    "orefuserbarhets": "orefuserbarhet",
    "orefuserbars": "orefuserbar",
    "orefuserbart": "orefuserbar",
    "orefuserbarts": "orefuserbar",
    "oregalerade": "oregalerad",
    "oregalerades": "oregalerad",
    "oregalerads": "oregalerad",
    "oregalerat": "oregalerad",
    "oregalerats": "oregalerad",
    "oregalerbara": "oregalerbar",
    "oregalerbarare": "oregalerbar",
    "oregalerbarares": "oregalerbar",
    "oregalerbaras": "oregalerbar",
    "oregalerbarast": "oregalerbar",
    "oregalerbaraste": "oregalerbar",
    "oregalerbarastes": "oregalerbar",
    "oregalerbarasts": "oregalerbar",
    "oregalerbare": "oregalerbar",
    "oregalerbares": "oregalerbar",
    "oregalerbarheten": "oregalerbarhet",
    "oregalerbarhetens": "oregalerbarhet",
    "oregalerbarhets": "oregalerbarhet",
    "oregalerbars": "oregalerbar",
    "oregalerbart": "oregalerbar",
    "oregalerbarts": "oregalerbar",
    "oreganon": "oregano",
    "oreganons": "oregano",
    "oreganos": "oregano",
    "oregelbundenheten": "oregelbundenhet",
    "oregelbundenhetens": "oregelbundenhet",
    "oregelbundenheter": "oregelbundenhet",
    "oregelbundenheterna": "oregelbundenhet",
    "oregelbundenheternas": "oregelbundenhet",
    "oregelbundenheters": "oregelbundenhet",
    "oregelbundenhets": "oregelbundenhet",
    "oregelbundens": "oregelbunden",
    "oregelbundet": "oregelbunden",
    "oregelbundets": "oregelbunden",
    "oregelbundna": "oregelbunden",
    "oregelbundnare": "oregelbunden",
    "oregelbundnares": "oregelbunden",
    "oregelbundnas": "oregelbunden",
    "oregelbundnast": "oregelbunden",
    "oregelbundnaste": "oregelbunden",
    "oregelbundnastes": "oregelbunden",
    "oregelbundnasts": "oregelbunden",
    "oregelbundne": "oregelbunden",
    "oregelbundnes": "oregelbunden",
    "oregelmässiga": "oregelmässig",
    "oregelmässigare": "oregelmässig",
    "oregelmässigares": "oregelmässig",
    "oregelmässigas": "oregelmässig",
    "oregelmässigast": "oregelmässig",
    "oregelmässigaste": "oregelmässig",
    "oregelmässigastes": "oregelmässig",
    "oregelmässigasts": "oregelmässig",
    "oregelmässige": "oregelmässig",
    "oregelmässiges": "oregelmässig",
    "oregelmässigheten": "oregelmässighet",
    "oregelmässighetens": "oregelmässighet",
    "oregelmässigheter": "oregelmässighet",
    "oregelmässigheterna": "oregelmässighet",
    "oregelmässigheternas": "oregelmässighet",
    "oregelmässigheters": "oregelmässighet",
    "oregelmässighets": "oregelmässighet",
    "oregelmässigs": "oregelmässig",
    "oregelmässigt": "oregelmässig",
    "oregelmässigts": "oregelmässig",
    "oregenererade": "oregenererad",
    "oregenererades": "oregenererad",
    "oregenererads": "oregenererad",
    "oregenererat": "oregenererad",
    "oregenererats": "oregenererad",
    "oregenererbara": "oregenererbar",
    "oregenererbarare": "oregenererbar",
    "oregenererbarares": "oregenererbar",
    "oregenererbaras": "oregenererbar",
    "oregenererbarast": "oregenererbar",
    "oregenererbaraste": "oregenererbar",
    "oregenererbarastes": "oregenererbar",
    "oregenererbarasts": "oregenererbar",
    "oregenererbare": "oregenererbar",
    "oregenererbares": "oregenererbar",
    "oregenererbarheten": "oregenererbarhet",
    "oregenererbarhetens": "oregenererbarhet",
    "oregenererbarhets": "oregenererbarhet",
    "oregenererbars": "oregenererbar",
    "oregenererbart": "oregenererbar",
    "oregenererbarts": "oregenererbar",
    "oregerade": "oregerad",
    "oregerades": "oregerad",
    "oregerads": "oregerad",
    "oregerat": "oregerad",
    "oregerats": "oregerad",
    "oregerbara": "oregerbar",
    "oregerbarare": "oregerbar",
    "oregerbarares": "oregerbar",
    "oregerbaras": "oregerbar",
    "oregerbarast": "oregerbar",
    "oregerbaraste": "oregerbar",
    "oregerbarastes": "oregerbar",
    "oregerbarasts": "oregerbar",
    "oregerbare": "oregerbar",
    "oregerbares": "oregerbar",
    "oregerbarheten": "oregerbarhet",
    "oregerbarhetens": "oregerbarhet",
    "oregerbarhets": "oregerbarhet",
    "oregerbars": "oregerbar",
    "oregerbart": "oregerbar",
    "oregerbarts": "oregerbar",
    "oregerliga": "oregerlig",
    "oregerligare": "oregerlig",
    "oregerligares": "oregerlig",
    "oregerligas": "oregerlig",
    "oregerligast": "oregerlig",
    "oregerligaste": "oregerlig",
    "oregerligastes": "oregerlig",
    "oregerligasts": "oregerlig",
    "oregerlige": "oregerlig",
    "oregerliges": "oregerlig",
    "oregerligheten": "oregerlighet",
    "oregerlighetens": "oregerlighet",
    "oregerlighets": "oregerlighet",
    "oregerligs": "oregerlig",
    "oregerligt": "oregerlig",
    "oregerligts": "oregerlig",
    "oregisserade": "oregisserad",
    "oregisserades": "oregisserad",
    "oregisserads": "oregisserad",
    "oregisserat": "oregisserad",
    "oregisserats": "oregisserad",
    "oregisserbara": "oregisserbar",
    "oregisserbarare": "oregisserbar",
    "oregisserbarares": "oregisserbar",
    "oregisserbaras": "oregisserbar",
    "oregisserbarast": "oregisserbar",
    "oregisserbaraste": "oregisserbar",
    "oregisserbarastes": "oregisserbar",
    "oregisserbarasts": "oregisserbar",
    "oregisserbare": "oregisserbar",
    "oregisserbares": "oregisserbar",
    "oregisserbarheten": "oregisserbarhet",
    "oregisserbarhetens": "oregisserbarhet",
    "oregisserbarhets": "oregisserbarhet",
    "oregisserbars": "oregisserbar",
    "oregisserbart": "oregisserbar",
    "oregisserbarts": "oregisserbar",
    "oregistrerade": "oregistrerad",
    "oregistrerades": "oregistrerad",
    "oregistrerads": "oregistrerad",
    "oregistrerat": "oregistrerad",
    "oregistrerats": "oregistrerad",
    "oregistrerbara": "oregistrerbar",
    "oregistrerbarare": "oregistrerbar",
    "oregistrerbarares": "oregistrerbar",
    "oregistrerbaras": "oregistrerbar",
    "oregistrerbarast": "oregistrerbar",
    "oregistrerbaraste": "oregistrerbar",
    "oregistrerbarastes": "oregistrerbar",
    "oregistrerbarasts": "oregistrerbar",
    "oregistrerbare": "oregistrerbar",
    "oregistrerbares": "oregistrerbar",
    "oregistrerbarheten": "oregistrerbarhet",
    "oregistrerbarhetens": "oregistrerbarhet",
    "oregistrerbarhets": "oregistrerbarhet",
    "oregistrerbars": "oregistrerbar",
    "oregistrerbart": "oregistrerbar",
    "oregistrerbarts": "oregistrerbar",
    "oreglade": "oreglad",
    "oreglades": "oreglad",
    "oreglads": "oreglad",
    "oreglat": "oreglad",
    "oreglats": "oreglad",
    "oreglementerade": "oreglementerad",
    "oreglementerades": "oreglementerad",
    "oreglementerads": "oreglementerad",
    "oreglementerat": "oreglementerad",
    "oreglementerats": "oreglementerad",
    "oreglementerbara": "oreglementerbar",
    "oreglementerbarare": "oreglementerbar",
    "oreglementerbarares": "oreglementerbar",
    "oreglementerbaras": "oreglementerbar",
    "oreglementerbarast": "oreglementerbar",
    "oreglementerbaraste": "oreglementerbar",
    "oreglementerbarastes": "oreglementerbar",
    "oreglementerbarasts": "oreglementerbar",
    "oreglementerbare": "oreglementerbar",
    "oreglementerbares": "oreglementerbar",
    "oreglementerbarheten": "oreglementerbarhet",
    "oreglementerbarhetens": "oreglementerbarhet",
    "oreglementerbarhets": "oreglementerbarhet",
    "oreglementerbars": "oreglementerbar",
    "oreglementerbart": "oreglementerbar",
    "oreglementerbarts": "oreglementerbar",
    "oreglerade": "oreglerad",
    "oreglerades": "oreglerad",
    "oreglerads": "oreglerad",
    "oreglerat": "oreglerad",
    "oreglerats": "oreglerad",
    "oreglerbara": "oreglerbar",
    "oreglerbarare": "oreglerbar",
    "oreglerbarares": "oreglerbar",
    "oreglerbaras": "oreglerbar",
    "oreglerbarast": "oreglerbar",
    "oreglerbaraste": "oreglerbar",
    "oreglerbarastes": "oreglerbar",
    "oreglerbarasts": "oreglerbar",
    "oreglerbare": "oreglerbar",
    "oreglerbares": "oreglerbar",
    "oreglerbarheten": "oreglerbarhet",
    "oreglerbarhetens": "oreglerbarhet",
    "oreglerbarhets": "oreglerbarhet",
    "oreglerbars": "oreglerbar",
    "oreglerbart": "oreglerbar",
    "oreglerbarts": "oreglerbar",
    "oregummerade": "oregummerad",
    "oregummerades": "oregummerad",
    "oregummerads": "oregummerad",
    "oregummerat": "oregummerad",
    "oregummerats": "oregummerad",
    "oregummerbara": "oregummerbar",
    "oregummerbarare": "oregummerbar",
    "oregummerbarares": "oregummerbar",
    "oregummerbaras": "oregummerbar",
    "oregummerbarast": "oregummerbar",
    "oregummerbaraste": "oregummerbar",
    "oregummerbarastes": "oregummerbar",
    "oregummerbarasts": "oregummerbar",
    "oregummerbare": "oregummerbar",
    "oregummerbares": "oregummerbar",
    "oregummerbarheten": "oregummerbarhet",
    "oregummerbarhetens": "oregummerbarhet",
    "oregummerbarhets": "oregummerbarhet",
    "oregummerbars": "oregummerbar",
    "oregummerbart": "oregummerbar",
    "oregummerbarts": "oregummerbar",
    "orehabiliterade": "orehabiliterad",
    "orehabiliterades": "orehabiliterad",
    "orehabiliterads": "orehabiliterad",
    "orehabiliterat": "orehabiliterad",
    "orehabiliterats": "orehabiliterad",
    "orehabiliterbara": "orehabiliterbar",
    "orehabiliterbarare": "orehabiliterbar",
    "orehabiliterbarares": "orehabiliterbar",
    "orehabiliterbaras": "orehabiliterbar",
    "orehabiliterbarast": "orehabiliterbar",
    "orehabiliterbaraste": "orehabiliterbar",
    "orehabiliterbarastes": "orehabiliterbar",
    "orehabiliterbarasts": "orehabiliterbar",
    "orehabiliterbare": "orehabiliterbar",
    "orehabiliterbares": "orehabiliterbar",
    "orehabiliterbarheten": "orehabiliterbarhet",
    "orehabiliterbarhetens": "orehabiliterbarhet",
    "orehabiliterbarhets": "orehabiliterbarhet",
    "orehabiliterbars": "orehabiliterbar",
    "orehabiliterbart": "orehabiliterbar",
    "orehabiliterbarts": "orehabiliterbar",
    "oreinkarnerade": "oreinkarnerad",
    "oreinkarnerades": "oreinkarnerad",
    "oreinkarnerads": "oreinkarnerad",
    "oreinkarnerat": "oreinkarnerad",
    "oreinkarnerats": "oreinkarnerad",
    "oreinkarnerbara": "oreinkarnerbar",
    "oreinkarnerbarare": "oreinkarnerbar",
    "oreinkarnerbarares": "oreinkarnerbar",
    "oreinkarnerbaras": "oreinkarnerbar",
    "oreinkarnerbarast": "oreinkarnerbar",
    "oreinkarnerbaraste": "oreinkarnerbar",
    "oreinkarnerbarastes": "oreinkarnerbar",
    "oreinkarnerbarasts": "oreinkarnerbar",
    "oreinkarnerbare": "oreinkarnerbar",
    "oreinkarnerbares": "oreinkarnerbar",
    "oreinkarnerbarheten": "oreinkarnerbarhet",
    "oreinkarnerbarhetens": "oreinkarnerbarhet",
    "oreinkarnerbarhets": "oreinkarnerbarhet",
    "oreinkarnerbars": "oreinkarnerbar",
    "oreinkarnerbart": "oreinkarnerbar",
    "oreinkarnerbarts": "oreinkarnerbar",
    "orekade": "orekad",
    "orekades": "orekad",
    "orekads": "orekad",
    "orekapitulerade": "orekapitulerad",
    "orekapitulerades": "orekapitulerad",
    "orekapitulerads": "orekapitulerad",
    "orekapitulerat": "orekapitulerad",
    "orekapitulerats": "orekapitulerad",
    "orekapitulerbara": "orekapitulerbar",
    "orekapitulerbarare": "orekapitulerbar",
    "orekapitulerbarares": "orekapitulerbar",
    "orekapitulerbaras": "orekapitulerbar",
    "orekapitulerbarast": "orekapitulerbar",
    "orekapitulerbaraste": "orekapitulerbar",
    "orekapitulerbarastes": "orekapitulerbar",
    "orekapitulerbarasts": "orekapitulerbar",
    "orekapitulerbare": "orekapitulerbar",
    "orekapitulerbares": "orekapitulerbar",
    "orekapitulerbarheten": "orekapitulerbarhet",
    "orekapitulerbarhetens": "orekapitulerbarhet",
    "orekapitulerbarhets": "orekapitulerbarhet",
    "orekapitulerbars": "orekapitulerbar",
    "orekapitulerbart": "orekapitulerbar",
    "orekapitulerbarts": "orekapitulerbar",
    "orekat": "orekad",
    "orekats": "orekad",
    "oreklamerade": "oreklamerad",
    "oreklamerades": "oreklamerad",
    "oreklamerads": "oreklamerad",
    "oreklamerat": "oreklamerad",
    "oreklamerats": "oreklamerad",
    "oreklamerbara": "oreklamerbar",
    "oreklamerbarare": "oreklamerbar",
    "oreklamerbarares": "oreklamerbar",
    "oreklamerbaras": "oreklamerbar",
    "oreklamerbarast": "oreklamerbar",
    "oreklamerbaraste": "oreklamerbar",
    "oreklamerbarastes": "oreklamerbar",
    "oreklamerbarasts": "oreklamerbar",
    "oreklamerbare": "oreklamerbar",
    "oreklamerbares": "oreklamerbar",
    "oreklamerbarheten": "oreklamerbarhet",
    "oreklamerbarhetens": "oreklamerbarhet",
    "oreklamerbarhets": "oreklamerbarhet",
    "oreklamerbars": "oreklamerbar",
    "oreklamerbart": "oreklamerbar",
    "oreklamerbarts": "oreklamerbar",
    "orekognoscerade": "orekognoscerad",
    "orekognoscerades": "orekognoscerad",
    "orekognoscerads": "orekognoscerad",
    "orekognoscerat": "orekognoscerad",
    "orekognoscerats": "orekognoscerad",
    "orekognoscerbara": "orekognoscerbar",
    "orekognoscerbarare": "orekognoscerbar",
    "orekognoscerbarares": "orekognoscerbar",
    "orekognoscerbaras": "orekognoscerbar",
    "orekognoscerbarast": "orekognoscerbar",
    "orekognoscerbaraste": "orekognoscerbar",
    "orekognoscerbarastes": "orekognoscerbar",
    "orekognoscerbarasts": "orekognoscerbar",
    "orekognoscerbare": "orekognoscerbar",
    "orekognoscerbares": "orekognoscerbar",
    "orekognoscerbarheten": "orekognoscerbarhet",
    "orekognoscerbarhetens": "orekognoscerbarhet",
    "orekognoscerbarhets": "orekognoscerbarhet",
    "orekognoscerbars": "orekognoscerbar",
    "orekognoscerbart": "orekognoscerbar",
    "orekognoscerbarts": "orekognoscerbar",
    "orekognoserade": "orekognoserad",
    "orekognoserades": "orekognoserad",
    "orekognoserads": "orekognoserad",
    "orekognoserat": "orekognoserad",
    "orekognoserats": "orekognoserad",
    "orekognoserbara": "orekognoserbar",
    "orekognoserbarare": "orekognoserbar",
    "orekognoserbarares": "orekognoserbar",
    "orekognoserbaras": "orekognoserbar",
    "orekognoserbarast": "orekognoserbar",
    "orekognoserbaraste": "orekognoserbar",
    "orekognoserbarastes": "orekognoserbar",
    "orekognoserbarasts": "orekognoserbar",
    "orekognoserbare": "orekognoserbar",
    "orekognoserbares": "orekognoserbar",
    "orekognoserbarheten": "orekognoserbarhet",
    "orekognoserbarhetens": "orekognoserbarhet",
    "orekognoserbarhets": "orekognoserbarhet",
    "orekognoserbars": "orekognoserbar",
    "orekognoserbart": "orekognoserbar",
    "orekognoserbarts": "orekognoserbar",
    "orekommenderade": "orekommenderad",
    "orekommenderades": "orekommenderad",
    "orekommenderads": "orekommenderad",
    "orekommenderat": "orekommenderad",
    "orekommenderats": "orekommenderad",
    "orekommenderbara": "orekommenderbar",
    "orekommenderbarare": "orekommenderbar",
    "orekommenderbarares": "orekommenderbar",
    "orekommenderbaras": "orekommenderbar",
    "orekommenderbarast": "orekommenderbar",
    "orekommenderbaraste": "orekommenderbar",
    "orekommenderbarastes": "orekommenderbar",
    "orekommenderbarasts": "orekommenderbar",
    "orekommenderbare": "orekommenderbar",
    "orekommenderbares": "orekommenderbar",
    "orekommenderbarheten": "orekommenderbarhet",
    "orekommenderbarhetens": "orekommenderbarhet",
    "orekommenderbarhets": "orekommenderbarhet",
    "orekommenderbars": "orekommenderbar",
    "orekommenderbart": "orekommenderbar",
    "orekommenderbarts": "orekommenderbar",
    "orekompenserade": "orekompenserad",
    "orekompenserades": "orekompenserad",
    "orekompenserads": "orekompenserad",
    "orekompenserat": "orekompenserad",
    "orekompenserats": "orekompenserad",
    "orekompenserbara": "orekompenserbar",
    "orekompenserbarare": "orekompenserbar",
    "orekompenserbarares": "orekompenserbar",
    "orekompenserbaras": "orekompenserbar",
    "orekompenserbarast": "orekompenserbar",
    "orekompenserbaraste": "orekompenserbar",
    "orekompenserbarastes": "orekompenserbar",
    "orekompenserbarasts": "orekompenserbar",
    "orekompenserbare": "orekompenserbar",
    "orekompenserbares": "orekompenserbar",
    "orekompenserbarheten": "orekompenserbarhet",
    "orekompenserbarhetens": "orekompenserbarhet",
    "orekompenserbarhets": "orekompenserbarhet",
    "orekompenserbars": "orekompenserbar",
    "orekompenserbart": "orekompenserbar",
    "orekompenserbarts": "orekompenserbar",
    "orekonstruerade": "orekonstruerad",
    "orekonstruerades": "orekonstruerad",
    "orekonstruerads": "orekonstruerad",
    "orekonstruerat": "orekonstruerad",
    "orekonstruerats": "orekonstruerad",
    "orekonstruerbara": "orekonstruerbar",
    "orekonstruerbarare": "orekonstruerbar",
    "orekonstruerbarares": "orekonstruerbar",
    "orekonstruerbaras": "orekonstruerbar",
    "orekonstruerbarast": "orekonstruerbar",
    "orekonstruerbaraste": "orekonstruerbar",
    "orekonstruerbarastes": "orekonstruerbar",
    "orekonstruerbarasts": "orekonstruerbar",
    "orekonstruerbare": "orekonstruerbar",
    "orekonstruerbares": "orekonstruerbar",
    "orekonstruerbarheten": "orekonstruerbarhet",
    "orekonstruerbarhetens": "orekonstruerbarhet",
    "orekonstruerbarhets": "orekonstruerbarhet",
    "orekonstruerbars": "orekonstruerbar",
    "orekonstruerbart": "orekonstruerbar",
    "orekonstruerbarts": "orekonstruerbar",
    "orekryterade": "orekryterad",
    "orekryterades": "orekryterad",
    "orekryterads": "orekryterad",
    "orekryterat": "orekryterad",
    "orekryterats": "orekryterad",
    "orekryterbara": "orekryterbar",
    "orekryterbarare": "orekryterbar",
    "orekryterbarares": "orekryterbar",
    "orekryterbaras": "orekryterbar",
    "orekryterbarast": "orekryterbar",
    "orekryterbaraste": "orekryterbar",
    "orekryterbarastes": "orekryterbar",
    "orekryterbarasts": "orekryterbar",
    "orekryterbare": "orekryterbar",
    "orekryterbares": "orekryterbar",
    "orekryterbarheten": "orekryterbarhet",
    "orekryterbarhetens": "orekryterbarhet",
    "orekryterbarhets": "orekryterbarhet",
    "orekryterbars": "orekryterbar",
    "orekryterbart": "orekryterbar",
    "orekryterbarts": "orekryterbar",
    "orektificerade": "orektificerad",
    "orektificerades": "orektificerad",
    "orektificerads": "orektificerad",
    "orektificerat": "orektificerad",
    "orektificerats": "orektificerad",
    "orektificerbara": "orektificerbar",
    "orektificerbarare": "orektificerbar",
    "orektificerbarares": "orektificerbar",
    "orektificerbaras": "orektificerbar",
    "orektificerbarast": "orektificerbar",
    "orektificerbaraste": "orektificerbar",
    "orektificerbarastes": "orektificerbar",
    "orektificerbarasts": "orektificerbar",
    "orektificerbare": "orektificerbar",
    "orektificerbares": "orektificerbar",
    "orektificerbarheten": "orektificerbarhet",
    "orektificerbarhetens": "orektificerbarhet",
    "orektificerbarhets": "orektificerbarhet",
    "orektificerbars": "orektificerbar",
    "orektificerbart": "orektificerbar",
    "orektificerbarts": "orektificerbar",
    "orektifierade": "orektifierad",
    "orektifierades": "orektifierad",
    "orektifierads": "orektifierad",
    "orektifierat": "orektifierad",
    "orektifierats": "orektifierad",
    "orektifierbara": "orektifierbar",
    "orektifierbarare": "orektifierbar",
    "orektifierbarares": "orektifierbar",
    "orektifierbaras": "orektifierbar",
    "orektifierbarast": "orektifierbar",
    "orektifierbaraste": "orektifierbar",
    "orektifierbarastes": "orektifierbar",
    "orektifierbarasts": "orektifierbar",
    "orektifierbare": "orektifierbar",
    "orektifierbares": "orektifierbar",
    "orektifierbarheten": "orektifierbarhet",
    "orektifierbarhetens": "orektifierbarhet",
    "orektifierbarhets": "orektifierbarhet",
    "orektifierbars": "orektifierbar",
    "orektifierbart": "orektifierbar",
    "orektifierbarts": "orektifierbar",
    "orekvirerade": "orekvirerad",
    "orekvirerades": "orekvirerad",
    "orekvirerads": "orekvirerad",
    "orekvirerat": "orekvirerad",
    "orekvirerats": "orekvirerad",
    "orekvirerbara": "orekvirerbar",
    "orekvirerbarare": "orekvirerbar",
    "orekvirerbarares": "orekvirerbar",
    "orekvirerbaras": "orekvirerbar",
    "orekvirerbarast": "orekvirerbar",
    "orekvirerbaraste": "orekvirerbar",
    "orekvirerbarastes": "orekvirerbar",
    "orekvirerbarasts": "orekvirerbar",
    "orekvirerbare": "orekvirerbar",
    "orekvirerbares": "orekvirerbar",
    "orekvirerbarheten": "orekvirerbarhet",
    "orekvirerbarhetens": "orekvirerbarhet",
    "orekvirerbarhets": "orekvirerbarhet",
    "orekvirerbars": "orekvirerbar",
    "orekvirerbart": "orekvirerbar",
    "orekvirerbarts": "orekvirerbar",
    "orelaterade": "orelaterad",
    "orelaterades": "orelaterad",
    "orelaterads": "orelaterad",
    "orelaterat": "orelaterad",
    "orelaterats": "orelaterad",
    "orelaterbara": "orelaterbar",
    "orelaterbarare": "orelaterbar",
    "orelaterbarares": "orelaterbar",
    "orelaterbaras": "orelaterbar",
    "orelaterbarast": "orelaterbar",
    "orelaterbaraste": "orelaterbar",
    "orelaterbarastes": "orelaterbar",
    "orelaterbarasts": "orelaterbar",
    "orelaterbare": "orelaterbar",
    "orelaterbares": "orelaterbar",
    "orelaterbarheten": "orelaterbarhet",
    "orelaterbarhetens": "orelaterbarhet",
    "orelaterbarhets": "orelaterbarhet",
    "orelaterbars": "orelaterbar",
    "orelaterbart": "orelaterbar",
    "orelaterbarts": "orelaterbar",
    "orelegerade": "orelegerad",
    "orelegerades": "orelegerad",
    "orelegerads": "orelegerad",
    "orelegerat": "orelegerad",
    "orelegerats": "orelegerad",
    "orelegerbara": "orelegerbar",
    "orelegerbarare": "orelegerbar",
    "orelegerbarares": "orelegerbar",
    "orelegerbaras": "orelegerbar",
    "orelegerbarast": "orelegerbar",
    "orelegerbaraste": "orelegerbar",
    "orelegerbarastes": "orelegerbar",
    "orelegerbarasts": "orelegerbar",
    "orelegerbare": "orelegerbar",
    "orelegerbares": "orelegerbar",
    "orelegerbarheten": "orelegerbarhet",
    "orelegerbarhetens": "orelegerbarhet",
    "orelegerbarhets": "orelegerbarhet",
    "orelegerbars": "orelegerbar",
    "orelegerbart": "orelegerbar",
    "orelegerbarts": "orelegerbar",
    "oreläade": "oreläad",
    "oreläades": "oreläad",
    "oreläads": "oreläad",
    "oreläat": "oreläad",
    "oreläats": "oreläad",
    "oremitterade": "oremitterad",
    "oremitterades": "oremitterad",
    "oremitterads": "oremitterad",
    "oremitterat": "oremitterad",
    "oremitterats": "oremitterad",
    "oremitterbara": "oremitterbar",
    "oremitterbarare": "oremitterbar",
    "oremitterbarares": "oremitterbar",
    "oremitterbaras": "oremitterbar",
    "oremitterbarast": "oremitterbar",
    "oremitterbaraste": "oremitterbar",
    "oremitterbarastes": "oremitterbar",
    "oremitterbarasts": "oremitterbar",
    "oremitterbare": "oremitterbar",
    "oremitterbares": "oremitterbar",
    "oremitterbarheten": "oremitterbarhet",
    "oremitterbarhetens": "oremitterbarhet",
    "oremitterbarhets": "oremitterbarhet",
    "oremitterbars": "oremitterbar",
    "oremitterbart": "oremitterbar",
    "oremitterbarts": "oremitterbar",
    "oremmade": "oremmad",
    "oremmades": "oremmad",
    "oremmads": "oremmad",
    "oremmat": "oremmad",
    "oremmats": "oremmad",
    "oremplacerade": "oremplacerad",
    "oremplacerades": "oremplacerad",
    "oremplacerads": "oremplacerad",
    "oremplacerat": "oremplacerad",
    "oremplacerats": "oremplacerad",
    "oremplacerbara": "oremplacerbar",
    "oremplacerbarare": "oremplacerbar",
    "oremplacerbarares": "oremplacerbar",
    "oremplacerbaras": "oremplacerbar",
    "oremplacerbarast": "oremplacerbar",
    "oremplacerbaraste": "oremplacerbar",
    "oremplacerbarastes": "oremplacerbar",
    "oremplacerbarasts": "oremplacerbar",
    "oremplacerbare": "oremplacerbar",
    "oremplacerbares": "oremplacerbar",
    "oremplacerbarheten": "oremplacerbarhet",
    "oremplacerbarhetens": "oremplacerbarhet",
    "oremplacerbarhets": "oremplacerbarhet",
    "oremplacerbars": "oremplacerbar",
    "oremplacerbart": "oremplacerbar",
    "oremplacerbarts": "oremplacerbar",
    "oren": "orena",
    "orena": "oren",
    "orenad": "orena",
    "orenade": "orenad",
    "orenades": "orenad",
    "orenads": "orenad",
    "orenande": "orena",
    "orenanden": "orenande",
    "orenandena": "orenande",
    "orenandenas": "orenande",
    "orenandens": "orenande",
    "orenandes": "orenande",
    "orenandet": "orenande",
    "orenandets": "orenande",
    "orenar": "orena",
    "orenare": "oren",
    "orenares": "oren",
    "orenas": "orena",
    "orenast": "oren",
    "orenaste": "oren",
    "orenastes": "oren",
    "orenasts": "oren",
    "orenat": "orenad",
    "orenats": "orenad",
    "orenderade": "orenderad",
    "orenderades": "orenderad",
    "orenderads": "orenderad",
    "orenderat": "orenderad",
    "orenderats": "orenderad",
    "orenderbara": "orenderbar",
    "orenderbarare": "orenderbar",
    "orenderbarares": "orenderbar",
    "orenderbaras": "orenderbar",
    "orenderbarast": "orenderbar",
    "orenderbaraste": "orenderbar",
    "orenderbarastes": "orenderbar",
    "orenderbarasts": "orenderbar",
    "orenderbare": "orenderbar",
    "orenderbares": "orenderbar",
    "orenderbarheten": "orenderbarhet",
    "orenderbarhetens": "orenderbarhet",
    "orenderbarhets": "orenderbarhet",
    "orenderbars": "orenderbar",
    "orenderbart": "orenderbar",
    "orenderbarts": "orenderbar",
    "orene": "oren",
    "orenes": "oren",
    "orenheten": "orenhet",
    "orenhetens": "orenhet",
    "orenheter": "orenhet",
    "orenheterna": "orenhet",
    "orenheternas": "orenhet",
    "orenheters": "orenhet",
    "orenhets": "orenhet",
    "orenliga": "orenlig",
    "orenligare": "orenlig",
    "orenligares": "orenlig",
    "orenligas": "orenlig",
    "orenligast": "orenlig",
    "orenligaste": "orenlig",
    "orenligastes": "orenlig",
    "orenligasts": "orenlig",
    "orenlige": "orenlig",
    "orenliges": "orenlig",
    "orenligheten": "orenlighet",
    "orenlighetens": "orenlighet",
    "orenligheter": "orenlighet",
    "orenligheterna": "orenlighet",
    "orenligheternas": "orenlighet",
    "orenligheters": "orenlighet",
    "orenlighets": "orenlighet",
    "orenligs": "orenlig",
    "orenligt": "orenlig",
    "orenligts": "orenlig",
    "orenoverade": "orenoverad",
    "orenoverades": "orenoverad",
    "orenoverads": "orenoverad",
    "orenoverat": "orenoverad",
    "orenoverats": "orenoverad",
    "orenoverbara": "orenoverbar",
    "orenoverbarare": "orenoverbar",
    "orenoverbarares": "orenoverbar",
    "orenoverbaras": "orenoverbar",
    "orenoverbarast": "orenoverbar",
    "orenoverbaraste": "orenoverbar",
    "orenoverbarastes": "orenoverbar",
    "orenoverbarasts": "orenoverbar",
    "orenoverbare": "orenoverbar",
    "orenoverbares": "orenoverbar",
    "orenoverbarheten": "orenoverbarhet",
    "orenoverbarhetens": "orenoverbarhet",
    "orenoverbarhets": "orenoverbarhet",
    "orenoverbars": "orenoverbar",
    "orenoverbart": "orenoverbar",
    "orenoverbarts": "orenoverbar",
    "orens": "oren",
    "orensade": "orensad",
    "orensades": "orensad",
    "orensads": "orensad",
    "orensat": "orensad",
    "orensats": "orensad",
    "orent": "oren",
    "orents": "oren",
    "oreorganiserade": "oreorganiserad",
    "oreorganiserades": "oreorganiserad",
    "oreorganiserads": "oreorganiserad",
    "oreorganiserat": "oreorganiserad",
    "oreorganiserats": "oreorganiserad",
    "oreorganiserbara": "oreorganiserbar",
    "oreorganiserbarare": "oreorganiserbar",
    "oreorganiserbarares": "oreorganiserbar",
    "oreorganiserbaras": "oreorganiserbar",
    "oreorganiserbarast": "oreorganiserbar",
    "oreorganiserbaraste": "oreorganiserbar",
    "oreorganiserbarastes": "oreorganiserbar",
    "oreorganiserbarasts": "oreorganiserbar",
    "oreorganiserbare": "oreorganiserbar",
    "oreorganiserbares": "oreorganiserbar",
    "oreorganiserbarheten": "oreorganiserbarhet",
    "oreorganiserbarhetens": "oreorganiserbarhet",
    "oreorganiserbarhets": "oreorganiserbarhet",
    "oreorganiserbars": "oreorganiserbar",
    "oreorganiserbart": "oreorganiserbar",
    "oreorganiserbarts": "oreorganiserbar",
    "orepade": "orepad",
    "orepades": "orepad",
    "orepads": "orepad",
    "oreparerade": "oreparerad",
    "oreparerades": "oreparerad",
    "oreparerads": "oreparerad",
    "oreparerat": "oreparerad",
    "oreparerats": "oreparerad",
    "oreparerbara": "oreparerbar",
    "oreparerbarare": "oreparerbar",
    "oreparerbarares": "oreparerbar",
    "oreparerbaras": "oreparerbar",
    "oreparerbarast": "oreparerbar",
    "oreparerbaraste": "oreparerbar",
    "oreparerbarastes": "oreparerbar",
    "oreparerbarasts": "oreparerbar",
    "oreparerbare": "oreparerbar",
    "oreparerbares": "oreparerbar",
    "oreparerbarheten": "oreparerbarhet",
    "oreparerbarhetens": "oreparerbarhet",
    "oreparerbarhets": "oreparerbarhet",
    "oreparerbars": "oreparerbar",
    "oreparerbart": "oreparerbar",
    "oreparerbarts": "oreparerbar",
    "orepartiserade": "orepartiserad",
    "orepartiserades": "orepartiserad",
    "orepartiserads": "orepartiserad",
    "orepartiserat": "orepartiserad",
    "orepartiserats": "orepartiserad",
    "orepartiserbara": "orepartiserbar",
    "orepartiserbarare": "orepartiserbar",
    "orepartiserbarares": "orepartiserbar",
    "orepartiserbaras": "orepartiserbar",
    "orepartiserbarast": "orepartiserbar",
    "orepartiserbaraste": "orepartiserbar",
    "orepartiserbarastes": "orepartiserbar",
    "orepartiserbarasts": "orepartiserbar",
    "orepartiserbare": "orepartiserbar",
    "orepartiserbares": "orepartiserbar",
    "orepartiserbarheten": "orepartiserbarhet",
    "orepartiserbarhetens": "orepartiserbarhet",
    "orepartiserbarhets": "orepartiserbarhet",
    "orepartiserbars": "orepartiserbar",
    "orepartiserbart": "orepartiserbar",
    "orepartiserbarts": "orepartiserbar",
    "orepat": "orepad",
    "orepatrierade": "orepatrierad",
    "orepatrierades": "orepatrierad",
    "orepatrierads": "orepatrierad",
    "orepatrierat": "orepatrierad",
    "orepatrierats": "orepatrierad",
    "orepatrierbara": "orepatrierbar",
    "orepatrierbarare": "orepatrierbar",
    "orepatrierbarares": "orepatrierbar",
    "orepatrierbaras": "orepatrierbar",
    "orepatrierbarast": "orepatrierbar",
    "orepatrierbaraste": "orepatrierbar",
    "orepatrierbarastes": "orepatrierbar",
    "orepatrierbarasts": "orepatrierbar",
    "orepatrierbare": "orepatrierbar",
    "orepatrierbares": "orepatrierbar",
    "orepatrierbarheten": "orepatrierbarhet",
    "orepatrierbarhetens": "orepatrierbarhet",
    "orepatrierbarhets": "orepatrierbarhet",
    "orepatrierbars": "orepatrierbar",
    "orepatrierbart": "orepatrierbar",
    "orepatrierbarts": "orepatrierbar",
    "orepats": "orepad",
    "orepellerade": "orepellerad",
    "orepellerades": "orepellerad",
    "orepellerads": "orepellerad",
    "orepellerat": "orepellerad",
    "orepellerats": "orepellerad",
    "orepellerbara": "orepellerbar",
    "orepellerbarare": "orepellerbar",
    "orepellerbarares": "orepellerbar",
    "orepellerbaras": "orepellerbar",
    "orepellerbarast": "orepellerbar",
    "orepellerbaraste": "orepellerbar",
    "orepellerbarastes": "orepellerbar",
    "orepellerbarasts": "orepellerbar",
    "orepellerbare": "orepellerbar",
    "orepellerbares": "orepellerbar",
    "orepellerbarheten": "orepellerbarhet",
    "orepellerbarhetens": "orepellerbarhet",
    "orepellerbarhets": "orepellerbarhet",
    "orepellerbars": "orepellerbar",
    "orepellerbart": "orepellerbar",
    "orepellerbarts": "orepellerbar",
    "orepeterade": "orepeterad",
    "orepeterades": "orepeterad",
    "orepeterads": "orepeterad",
    "orepeterat": "orepeterad",
    "orepeterats": "orepeterad",
    "orepeterbara": "orepeterbar",
    "orepeterbarare": "orepeterbar",
    "orepeterbarares": "orepeterbar",
    "orepeterbaras": "orepeterbar",
    "orepeterbarast": "orepeterbar",
    "orepeterbaraste": "orepeterbar",
    "orepeterbarastes": "orepeterbar",
    "orepeterbarasts": "orepeterbar",
    "orepeterbare": "orepeterbar",
    "orepeterbares": "orepeterbar",
    "orepeterbarheten": "orepeterbarhet",
    "orepeterbarhetens": "orepeterbarhet",
    "orepeterbarhets": "orepeterbarhet",
    "orepeterbars": "orepeterbar",
    "orepeterbart": "orepeterbar",
    "orepeterbarts": "orepeterbar",
    "orepresenterade": "orepresenterad",
    "orepresenterades": "orepresenterad",
    "orepresenterads": "orepresenterad",
    "orepresenterat": "orepresenterad",
    "orepresenterats": "orepresenterad",
    "orepresenterbara": "orepresenterbar",
    "orepresenterbarare": "orepresenterbar",
    "orepresenterbarares": "orepresenterbar",
    "orepresenterbaras": "orepresenterbar",
    "orepresenterbarast": "orepresenterbar",
    "orepresenterbaraste": "orepresenterbar",
    "orepresenterbarastes": "orepresenterbar",
    "orepresenterbarasts": "orepresenterbar",
    "orepresenterbare": "orepresenterbar",
    "orepresenterbares": "orepresenterbar",
    "orepresenterbarheten": "orepresenterbarhet",
    "orepresenterbarhetens": "orepresenterbarhet",
    "orepresenterbarhets": "orepresenterbarhet",
    "orepresenterbars": "orepresenterbar",
    "orepresenterbart": "orepresenterbar",
    "orepresenterbarts": "orepresenterbar",
    "orepriserade": "orepriserad",
    "orepriserades": "orepriserad",
    "orepriserads": "orepriserad",
    "orepriserat": "orepriserad",
    "orepriserats": "orepriserad",
    "orepriserbara": "orepriserbar",
    "orepriserbarare": "orepriserbar",
    "orepriserbarares": "orepriserbar",
    "orepriserbaras": "orepriserbar",
    "orepriserbarast": "orepriserbar",
    "orepriserbaraste": "orepriserbar",
    "orepriserbarastes": "orepriserbar",
    "orepriserbarasts": "orepriserbar",
    "orepriserbare": "orepriserbar",
    "orepriserbares": "orepriserbar",
    "orepriserbarheten": "orepriserbarhet",
    "orepriserbarhetens": "orepriserbarhet",
    "orepriserbarhets": "orepriserbarhet",
    "orepriserbars": "orepriserbar",
    "orepriserbart": "orepriserbar",
    "orepriserbarts": "orepriserbar",
    "oreproducerade": "oreproducerad",
    "oreproducerades": "oreproducerad",
    "oreproducerads": "oreproducerad",
    "oreproducerat": "oreproducerad",
    "oreproducerats": "oreproducerad",
    "oreproducerbara": "oreproducerbar",
    "oreproducerbarare": "oreproducerbar",
    "oreproducerbarares": "oreproducerbar",
    "oreproducerbaras": "oreproducerbar",
    "oreproducerbarast": "oreproducerbar",
    "oreproducerbaraste": "oreproducerbar",
    "oreproducerbarastes": "oreproducerbar",
    "oreproducerbarasts": "oreproducerbar",
    "oreproducerbare": "oreproducerbar",
    "oreproducerbares": "oreproducerbar",
    "oreproducerbarheten": "oreproducerbarhet",
    "oreproducerbarhetens": "oreproducerbarhet",
    "oreproducerbarhets": "oreproducerbarhet",
    "oreproducerbars": "oreproducerbar",
    "oreproducerbart": "oreproducerbar",
    "oreproducerbarts": "oreproducerbar",
    "orerade": "orera",
    "orerades": "orera",
    "orerande": "orera",
    "oreranden": "orerande",
    "orerandena": "orerande",
    "orerandenas": "orerande",
    "orerandens": "orerande",
    "orerandes": "orerande",
    "orerandet": "orerande",
    "orerandets": "orerande",
    "orerar": "orera",
    "oreras": "orera",
    "orerat": "orera",
    "orerats": "orera",
    "oreringar": "orering",
    "oreringarna": "orering",
    "oreringarnas": "orering",
    "oreringars": "orering",
    "oreringen": "orering",
    "oreringens": "orering",
    "orerings": "orering",
    "oreserverade": "oreserverad",
    "oreserverades": "oreserverad",
    "oreserverads": "oreserverad",
    "oreserverat": "oreserverad",
    "oreserverats": "oreserverad",
    "oreserverbara": "oreserverbar",
    "oreserverbarare": "oreserverbar",
    "oreserverbarares": "oreserverbar",
    "oreserverbaras": "oreserverbar",
    "oreserverbarast": "oreserverbar",
    "oreserverbaraste": "oreserverbar",
    "oreserverbarastes": "oreserverbar",
    "oreserverbarasts": "oreserverbar",
    "oreserverbare": "oreserverbar",
    "oreserverbares": "oreserverbar",
    "oreserverbarheten": "oreserverbarhet",
    "oreserverbarhetens": "oreserverbarhet",
    "oreserverbarhets": "oreserverbarhet",
    "oreserverbars": "oreserverbar",
    "oreserverbart": "oreserverbar",
    "oreserverbarts": "oreserverbar",
    "oresolverade": "oresolverad",
    "oresolverades": "oresolverad",
    "oresolverads": "oresolverad",
    "oresolverat": "oresolverad",
    "oresolverats": "oresolverad",
    "oresolverbara": "oresolverbar",
    "oresolverbarare": "oresolverbar",
    "oresolverbarares": "oresolverbar",
    "oresolverbaras": "oresolverbar",
    "oresolverbarast": "oresolverbar",
    "oresolverbaraste": "oresolverbar",
    "oresolverbarastes": "oresolverbar",
    "oresolverbarasts": "oresolverbar",
    "oresolverbare": "oresolverbar",
    "oresolverbares": "oresolverbar",
    "oresolverbarheten": "oresolverbarhet",
    "oresolverbarhetens": "oresolverbarhet",
    "oresolverbarhets": "oresolverbarhet",
    "oresolverbars": "oresolverbar",
    "oresolverbart": "oresolverbar",
    "oresolverbarts": "oresolverbar",
    "oresonabela": "oresonabel",
    "oresonabelare": "oresonabel",
    "oresonabelares": "oresonabel",
    "oresonabelas": "oresonabel",
    "oresonabelast": "oresonabel",
    "oresonabelaste": "oresonabel",
    "oresonabelastes": "oresonabel",
    "oresonabelasts": "oresonabel",
    "oresonabele": "oresonabel",
    "oresonabeles": "oresonabel",
    "oresonabels": "oresonabel",
    "oresonabelt": "oresonabel",
    "oresonabelts": "oresonabel",
    "oresonliga": "oresonlig",
    "oresonligare": "oresonlig",
    "oresonligares": "oresonlig",
    "oresonligas": "oresonlig",
    "oresonligast": "oresonlig",
    "oresonligaste": "oresonlig",
    "oresonligastes": "oresonlig",
    "oresonligasts": "oresonlig",
    "oresonlige": "oresonlig",
    "oresonliges": "oresonlig",
    "oresonligheten": "oresonlighet",
    "oresonlighetens": "oresonlighet",
    "oresonlighets": "oresonlighet",
    "oresonligs": "oresonlig",
    "oresonligt": "oresonlig",
    "oresonligts": "oresonlig",
    "oresorberade": "oresorberad",
    "oresorberades": "oresorberad",
    "oresorberads": "oresorberad",
    "oresorberat": "oresorberad",
    "oresorberats": "oresorberad",
    "oresorberbara": "oresorberbar",
    "oresorberbarare": "oresorberbar",
    "oresorberbarares": "oresorberbar",
    "oresorberbaras": "oresorberbar",
    "oresorberbarast": "oresorberbar",
    "oresorberbaraste": "oresorberbar",
    "oresorberbarastes": "oresorberbar",
    "oresorberbarasts": "oresorberbar",
    "oresorberbare": "oresorberbar",
    "oresorberbares": "oresorberbar",
    "oresorberbarheten": "oresorberbarhet",
    "oresorberbarhetens": "oresorberbarhet",
    "oresorberbarhets": "oresorberbarhet",
    "oresorberbars": "oresorberbar",
    "oresorberbart": "oresorberbar",
    "oresorberbarts": "oresorberbar",
    "orespekterade": "orespekterad",
    "orespekterades": "orespekterad",
    "orespekterads": "orespekterad",
    "orespekterat": "orespekterad",
    "orespekterats": "orespekterad",
    "orespekterbara": "orespekterbar",
    "orespekterbarare": "orespekterbar",
    "orespekterbarares": "orespekterbar",
    "orespekterbaras": "orespekterbar",
    "orespekterbarast": "orespekterbar",
    "orespekterbaraste": "orespekterbar",
    "orespekterbarastes": "orespekterbar",
    "orespekterbarasts": "orespekterbar",
    "orespekterbare": "orespekterbar",
    "orespekterbares": "orespekterbar",
    "orespekterbarheten": "orespekterbarhet",
    "orespekterbarhetens": "orespekterbarhet",
    "orespekterbarhets": "orespekterbarhet",
    "orespekterbars": "orespekterbar",
    "orespekterbart": "orespekterbar",
    "orespekterbarts": "orespekterbar",
    "orespirerade": "orespirerad",
    "orespirerades": "orespirerad",
    "orespirerads": "orespirerad",
    "orespirerat": "orespirerad",
    "orespirerats": "orespirerad",
    "orespirerbara": "orespirerbar",
    "orespirerbarare": "orespirerbar",
    "orespirerbarares": "orespirerbar",
    "orespirerbaras": "orespirerbar",
    "orespirerbarast": "orespirerbar",
    "orespirerbaraste": "orespirerbar",
    "orespirerbarastes": "orespirerbar",
    "orespirerbarasts": "orespirerbar",
    "orespirerbare": "orespirerbar",
    "orespirerbares": "orespirerbar",
    "orespirerbarheten": "orespirerbarhet",
    "orespirerbarhetens": "orespirerbarhet",
    "orespirerbarhets": "orespirerbarhet",
    "orespirerbars": "orespirerbar",
    "orespirerbart": "orespirerbar",
    "orespirerbarts": "orespirerbar",
    "oresta": "orest",
    "orestas": "orest",
    "orestaurerade": "orestaurerad",
    "orestaurerades": "orestaurerad",
    "orestaurerads": "orestaurerad",
    "orestaurerat": "orestaurerad",
    "orestaurerats": "orestaurerad",
    "orestaurerbara": "orestaurerbar",
    "orestaurerbarare": "orestaurerbar",
    "orestaurerbarares": "orestaurerbar",
    "orestaurerbaras": "orestaurerbar",
    "orestaurerbarast": "orestaurerbar",
    "orestaurerbaraste": "orestaurerbar",
    "orestaurerbarastes": "orestaurerbar",
    "orestaurerbarasts": "orestaurerbar",
    "orestaurerbare": "orestaurerbar",
    "orestaurerbares": "orestaurerbar",
    "orestaurerbarheten": "orestaurerbarhet",
    "orestaurerbarhetens": "orestaurerbarhet",
    "orestaurerbarhets": "orestaurerbarhet",
    "orestaurerbars": "orestaurerbar",
    "orestaurerbart": "orestaurerbar",
    "orestaurerbarts": "orestaurerbar",
    "oreste": "orest",
    "orestes": "orest",
    "orestituerade": "orestituerad",
    "orestituerades": "orestituerad",
    "orestituerads": "orestituerad",
    "orestituerat": "orestituerad",
    "orestituerats": "orestituerad",
    "orestituerbara": "orestituerbar",
    "orestituerbarare": "orestituerbar",
    "orestituerbarares": "orestituerbar",
    "orestituerbaras": "orestituerbar",
    "orestituerbarast": "orestituerbar",
    "orestituerbaraste": "orestituerbar",
    "orestituerbarastes": "orestituerbar",
    "orestituerbarasts": "orestituerbar",
    "orestituerbare": "orestituerbar",
    "orestituerbares": "orestituerbar",
    "orestituerbarheten": "orestituerbarhet",
    "orestituerbarhetens": "orestituerbarhet",
    "orestituerbarhets": "orestituerbarhet",
    "orestituerbars": "orestituerbar",
    "orestituerbart": "orestituerbar",
    "orestituerbarts": "orestituerbar",
    "orests": "orest",
    "oresumerade": "oresumerad",
    "oresumerades": "oresumerad",
    "oresumerads": "oresumerad",
    "oresumerat": "oresumerad",
    "oresumerats": "oresumerad",
    "oresumerbara": "oresumerbar",
    "oresumerbarare": "oresumerbar",
    "oresumerbarares": "oresumerbar",
    "oresumerbaras": "oresumerbar",
    "oresumerbarast": "oresumerbar",
    "oresumerbaraste": "oresumerbar",
    "oresumerbarastes": "oresumerbar",
    "oresumerbarasts": "oresumerbar",
    "oresumerbare": "oresumerbar",
    "oresumerbares": "oresumerbar",
    "oresumerbarheten": "oresumerbarhet",
    "oresumerbarhetens": "oresumerbarhet",
    "oresumerbarhets": "oresumerbarhet",
    "oresumerbars": "oresumerbar",
    "oresumerbart": "oresumerbar",
    "oresumerbarts": "oresumerbar",
    "oret": "or",
    "oretablerade": "oretablerad",
    "oretablerades": "oretablerad",
    "oretablerads": "oretablerad",
    "oretablerat": "oretablerad",
    "oretablerats": "oretablerad",
    "oretablerbara": "oretablerbar",
    "oretablerbarare": "oretablerbar",
    "oretablerbarares": "oretablerbar",
    "oretablerbaras": "oretablerbar",
    "oretablerbarast": "oretablerbar",
    "oretablerbaraste": "oretablerbar",
    "oretablerbarastes": "oretablerbar",
    "oretablerbarasts": "oretablerbar",
    "oretablerbare": "oretablerbar",
    "oretablerbares": "oretablerbar",
    "oretablerbarheten": "oretablerbarhet",
    "oretablerbarhetens": "oretablerbarhet",
    "oretablerbarhets": "oretablerbarhet",
    "oretablerbars": "oretablerbar",
    "oretablerbart": "oretablerbar",
    "oretablerbarts": "oretablerbar",
    "oretade": "oretad",
    "oretades": "oretad",
    "oretads": "oretad",
    "oretarderade": "oretarderad",
    "oretarderades": "oretarderad",
    "oretarderads": "oretarderad",
    "oretarderat": "oretarderad",
    "oretarderats": "oretarderad",
    "oretarderbara": "oretarderbar",
    "oretarderbarare": "oretarderbar",
    "oretarderbarares": "oretarderbar",
    "oretarderbaras": "oretarderbar",
    "oretarderbarast": "oretarderbar",
    "oretarderbaraste": "oretarderbar",
    "oretarderbarastes": "oretarderbar",
    "oretarderbarasts": "oretarderbar",
    "oretarderbare": "oretarderbar",
    "oretarderbares": "oretarderbar",
    "oretarderbarheten": "oretarderbarhet",
    "oretarderbarhetens": "oretarderbarhet",
    "oretarderbarhets": "oretarderbarhet",
    "oretarderbars": "oretarderbar",
    "oretarderbart": "oretarderbar",
    "oretarderbarts": "oretarderbar",
    "oretat": "oretad",
    "oretats": "oretad",
    "orets": "or",
    "oreturnerade": "oreturnerad",
    "oreturnerades": "oreturnerad",
    "oreturnerads": "oreturnerad",
    "oreturnerat": "oreturnerad",
    "oreturnerats": "oreturnerad",
    "oreturnerbara": "oreturnerbar",
    "oreturnerbarare": "oreturnerbar",
    "oreturnerbarares": "oreturnerbar",
    "oreturnerbaras": "oreturnerbar",
    "oreturnerbarast": "oreturnerbar",
    "oreturnerbaraste": "oreturnerbar",
    "oreturnerbarastes": "oreturnerbar",
    "oreturnerbarasts": "oreturnerbar",
    "oreturnerbare": "oreturnerbar",
    "oreturnerbares": "oreturnerbar",
    "oreturnerbarheten": "oreturnerbarhet",
    "oreturnerbarhetens": "oreturnerbarhet",
    "oreturnerbarhets": "oreturnerbarhet",
    "oreturnerbars": "oreturnerbar",
    "oreturnerbart": "oreturnerbar",
    "oreturnerbarts": "oreturnerbar",
    "oretuscherade": "oretuscherad",
    "oretuscherades": "oretuscherad",
    "oretuscherads": "oretuscherad",
    "oretuscherat": "oretuscherad",
    "oretuscherats": "oretuscherad",
    "oretuscherbara": "oretuscherbar",
    "oretuscherbarare": "oretuscherbar",
    "oretuscherbarares": "oretuscherbar",
    "oretuscherbaras": "oretuscherbar",
    "oretuscherbarast": "oretuscherbar",
    "oretuscherbaraste": "oretuscherbar",
    "oretuscherbarastes": "oretuscherbar",
    "oretuscherbarasts": "oretuscherbar",
    "oretuscherbare": "oretuscherbar",
    "oretuscherbares": "oretuscherbar",
    "oretuscherbarheten": "oretuscherbarhet",
    "oretuscherbarhetens": "oretuscherbarhet",
    "oretuscherbarhets": "oretuscherbarhet",
    "oretuscherbars": "oretuscherbar",
    "oretuscherbart": "oretuscherbar",
    "oretuscherbarts": "oretuscherbar",
    "orevade": "orevad",
    "orevades": "orevad",
    "orevads": "orevad",
    "orevalverade": "orevalverad",
    "orevalverades": "orevalverad",
    "orevalverads": "orevalverad",
    "orevalverat": "orevalverad",
    "orevalverats": "orevalverad",
    "orevalverbara": "orevalverbar",
    "orevalverbarare": "orevalverbar",
    "orevalverbarares": "orevalverbar",
    "orevalverbaras": "orevalverbar",
    "orevalverbarast": "orevalverbar",
    "orevalverbaraste": "orevalverbar",
    "orevalverbarastes": "orevalverbar",
    "orevalverbarasts": "orevalverbar",
    "orevalverbare": "orevalverbar",
    "orevalverbares": "orevalverbar",
    "orevalverbarheten": "orevalverbarhet",
    "orevalverbarhetens": "orevalverbarhet",
    "orevalverbarhets": "orevalverbarhet",
    "orevalverbars": "orevalverbar",
    "orevalverbart": "orevalverbar",
    "orevalverbarts": "orevalverbar",
    "orevat": "orevad",
    "orevats": "orevad",
    "oreveterade": "oreveterad",
    "oreveterades": "oreveterad",
    "oreveterads": "oreveterad",
    "oreveterat": "oreveterad",
    "oreveterats": "oreveterad",
    "oreveterbara": "oreveterbar",
    "oreveterbarare": "oreveterbar",
    "oreveterbarares": "oreveterbar",
    "oreveterbaras": "oreveterbar",
    "oreveterbarast": "oreveterbar",
    "oreveterbaraste": "oreveterbar",
    "oreveterbarastes": "oreveterbar",
    "oreveterbarasts": "oreveterbar",
    "oreveterbare": "oreveterbar",
    "oreveterbares": "oreveterbar",
    "oreveterbarheten": "oreveterbarhet",
    "oreveterbarhetens": "oreveterbarhet",
    "oreveterbarhets": "oreveterbarhet",
    "oreveterbars": "oreveterbar",
    "oreveterbart": "oreveterbar",
    "oreveterbarts": "oreveterbar",
    "oreviderade": "oreviderad",
    "oreviderades": "oreviderad",
    "oreviderads": "oreviderad",
    "oreviderat": "oreviderad",
    "oreviderats": "oreviderad",
    "oreviderbara": "oreviderbar",
    "oreviderbarare": "oreviderbar",
    "oreviderbarares": "oreviderbar",
    "oreviderbaras": "oreviderbar",
    "oreviderbarast": "oreviderbar",
    "oreviderbaraste": "oreviderbar",
    "oreviderbarastes": "oreviderbar",
    "oreviderbarasts": "oreviderbar",
    "oreviderbare": "oreviderbar",
    "oreviderbares": "oreviderbar",
    "oreviderbarheten": "oreviderbarhet",
    "oreviderbarhetens": "oreviderbarhet",
    "oreviderbarhets": "oreviderbarhet",
    "oreviderbars": "oreviderbar",
    "oreviderbart": "oreviderbar",
    "oreviderbarts": "oreviderbar",
    "orevolutionerade": "orevolutionerad",
    "orevolutionerades": "orevolutionerad",
    "orevolutionerads": "orevolutionerad",
    "orevolutionerat": "orevolutionerad",
    "orevolutionerats": "orevolutionerad",
    "orevolutionerbara": "orevolutionerbar",
    "orevolutionerbarare": "orevolutionerbar",
    "orevolutionerbarares": "orevolutionerbar",
    "orevolutionerbaras": "orevolutionerbar",
    "orevolutionerbarast": "orevolutionerbar",
    "orevolutionerbaraste": "orevolutionerbar",
    "orevolutionerbarastes": "orevolutionerbar",
    "orevolutionerbarasts": "orevolutionerbar",
    "orevolutionerbare": "orevolutionerbar",
    "orevolutionerbares": "orevolutionerbar",
    "orevolutionerbarheten": "orevolutionerbarhet",
    "orevolutionerbarhetens": "orevolutionerbarhet",
    "orevolutionerbarhets": "orevolutionerbarhet",
    "orevolutionerbars": "orevolutionerbar",
    "orevolutionerbart": "orevolutionerbar",
    "orevolutionerbarts": "orevolutionerbar",
    "orficismen": "orficism",
    "orficismens": "orficism",
    "orficismer": "orficism",
    "orficismerna": "orficism",
    "orficismernas": "orficism",
    "orficismers": "orficism",
    "orficisms": "orficism",
    "orfiska": "orfisk",
    "orfiskare": "orfisk",
    "orfiskares": "orfisk",
    "orfiskas": "orfisk",
    "orfiskast": "orfisk",
    "orfiskaste": "orfisk",
    "orfiskastes": "orfisk",
    "orfiskasts": "orfisk",
    "orfiske": "orfisk",
    "orfiskes": "orfisk",
    "orfisks": "orfisk",
    "orfiskt": "orfisk",
    "orfiskts": "orfisk",
    "orfismen": "orfism",
    "orfismens": "orfism",
    "orfismer": "orfism",
    "orfismerna": "orfism",
    "orfismernas": "orfism",
    "orfismers": "orfism",
    "orfisms": "orfism",
    "orfistiska": "orfistisk",
    "orfistiskas": "orfistisk",
    "orfistiske": "orfistisk",
    "orfistiskes": "orfistisk",
    "orfistisks": "orfistisk",
    "orfistiskt": "orfistisk",
    "orfistiskts": "orfistisk",
    "organcellen": "organcell",
    "organcellens": "organcell",
    "organceller": "organcell",
    "organcellerna": "organcell",
    "organcellernas": "organcell",
    "organcellers": "organcell",
    "organcells": "organcell",
    "organdien": "organdi",
    "organdiens": "organdi",
    "organdin": "organdi",
    "organdins": "organdi",
    "organdis": "organdi",
    "organdonationen": "organdonation",
    "organdonationens": "organdonation",
    "organdonationer": "organdonation",
    "organdonationerna": "organdonation",
    "organdonationernas": "organdonation",
    "organdonationers": "organdonation",
    "organdonations": "organdonation",
    "organellen": "organell",
    "organellens": "organell",
    "organeller": "organell",
    "organellerna": "organell",
    "organellernas": "organell",
    "organellers": "organell",
    "organells": "organell",
    "organen": "organ",
    "organens": "organ",
    "organet": "organ",
    "organets": "organ",
    "organisationen": "organisation",
    "organisationens": "organisation",
    "organisationer": "organisation",
    "organisationerna": "organisation",
    "organisationernas": "organisation",
    "organisationers": "organisation",
    "organisations": "organisation",
    "organisationsarbeten": "organisationsarbete",
    "organisationsarbetena": "organisationsarbete",
    "organisationsarbetenas": "organisationsarbete",
    "organisationsarbetens": "organisationsarbete",
    "organisationsarbetes": "organisationsarbete",
    "organisationsarbetet": "organisationsarbete",
    "organisationsarbetets": "organisationsarbete",
    "organisationsarbets": "organisationsarbete",
    "organisationskommittéer": "organisationskommitté",
    "organisationskommittéerna": "organisationskommitté",
    "organisationskommittéernas": "organisationskommitté",
    "organisationskommittéers": "organisationskommitté",
    "organisationskommittén": "organisationskommitté",
    "organisationskommitténs": "organisationskommitté",
    "organisationskommittés": "organisationskommitté",
    "organisationsmässiga": "organisationsmässig",
    "organisationsmässigare": "organisationsmässig",
    "organisationsmässigares": "organisationsmässig",
    "organisationsmässigas": "organisationsmässig",
    "organisationsmässigast": "organisationsmässig",
    "organisationsmässigaste": "organisationsmässig",
    "organisationsmässigastes": "organisationsmässig",
    "organisationsmässigasts": "organisationsmässig",
    "organisationsmässige": "organisationsmässig",
    "organisationsmässiges": "organisationsmässig",
    "organisationsmässigs": "organisationsmässig",
    "organisationsmässigt": "organisationsmässig",
    "organisationsmässigts": "organisationsmässig",
    "organisationsstrukturen": "organisationsstruktur",
    "organisationsstrukturens": "organisationsstruktur",
    "organisationsstrukturer": "organisationsstruktur",
    "organisationsstrukturerna": "organisationsstruktur",
    "organisationsstrukturernas": "organisationsstruktur",
    "organisationsstrukturers": "organisationsstruktur",
    "organisationsstrukturs": "organisationsstruktur",
    "organisatoriska": "organisatorisk",
    "organisatoriskare": "organisatorisk",
    "organisatoriskares": "organisatorisk",
    "organisatoriskas": "organisatorisk",
    "organisatoriskast": "organisatorisk",
    "organisatoriskaste": "organisatorisk",
    "organisatoriskastes": "organisatorisk",
    "organisatoriskasts": "organisatorisk",
    "organisatoriske": "organisatorisk",
    "organisatoriskes": "organisatorisk",
    "organisatorisks": "organisatorisk",
    "organisatoriskt": "organisatorisk",
    "organisatoriskts": "organisatorisk",
    "organisatören": "organisatör",
    "organisatörens": "organisatör",
    "organisatörer": "organisatör",
    "organisatörerna": "organisatör",
    "organisatörernas": "organisatör",
    "organisatörers": "organisatör",
    "organisatörs": "organisatör",
    "organiserad": "organisera",
    "organiserade": "organiserad",
    "organiserades": "organiserad",
    "organiserads": "organiserad",
    "organiserande": "organisera",
    "organiseranden": "organiserande",
    "organiserandena": "organiserande",
    "organiserandenas": "organiserande",
    "organiserandens": "organiserande",
    "organiserandes": "organiserande",
    "organiserandet": "organiserande",
    "organiserandets": "organiserande",
    "organiserar": "organisera",
    "organiseras": "organisera",
    "organiserat": "organiserad",
    "organiserats": "organiserad",
    "organiserbara": "organiserbar",
    "organiserbarare": "organiserbar",
    "organiserbarares": "organiserbar",
    "organiserbaras": "organiserbar",
    "organiserbarast": "organiserbar",
    "organiserbaraste": "organiserbar",
    "organiserbarastes": "organiserbar",
    "organiserbarasts": "organiserbar",
    "organiserbare": "organiserbar",
    "organiserbares": "organiserbar",
    "organiserbarheten": "organiserbarhet",
    "organiserbarhetens": "organiserbarhet",
    "organiserbarhets": "organiserbarhet",
    "organiserbars": "organiserbar",
    "organiserbart": "organiserbar",
    "organiserbarts": "organiserbar",
    "organiseringar": "organisering",
    "organiseringarna": "organisering",
    "organiseringarnas": "organisering",
    "organiseringars": "organisering",
    "organiseringen": "organisering",
    "organiseringens": "organisering",
    "organiserings": "organisering",
    "organiska": "organisk",
    "organiskare": "organisk",
    "organiskares": "organisk",
    "organiskas": "organisk",
    "organiskast": "organisk",
    "organiskaste": "organisk",
    "organiskastes": "organisk",
    "organiskasts": "organisk",
    "organiske": "organisk",
    "organiskes": "organisk",
    "organisks": "organisk",
    "organiskt": "organisk",
    "organiskts": "organisk",
    "organismen": "organism",
    "organismens": "organism",
    "organismer": "organism",
    "organismerna": "organism",
    "organismernas": "organism",
    "organismers": "organism",
    "organisms": "organism",
    "organisten": "organist",
    "organistens": "organist",
    "organister": "organist",
    "organisterna": "organist",
    "organisternas": "organist",
    "organisters": "organist",
    "organists": "organist",
    "organmen": "organum",
    "organmens": "organum",
    "organmet": "organum",
    "organmets": "organum",
    "organogena": "organogen",
    "organogenare": "organogen",
    "organogenares": "organogen",
    "organogenas": "organogen",
    "organogenast": "organogen",
    "organogenaste": "organogen",
    "organogenastes": "organogen",
    "organogenasts": "organogen",
    "organogene": "organogen",
    "organogenes": "organogen",
    "organogens": "organogen",
    "organogent": "organogen",
    "organogents": "organogen",
    "organs": "organ",
    "organumen": "organum",
    "organumens": "organum",
    "organumet": "organum",
    "organumets": "organum",
    "organums": "organum",
    "organzan": "organza",
    "organzans": "organza",
    "organzas": "organza",
    "orgasmen": "orgasm",
    "orgasmens": "orgasm",
    "orgasmer": "orgasm",
    "orgasmerna": "orgasm",
    "orgasmernas": "orgasm",
    "orgasmers": "orgasm",
    "orgasms": "orgasm",
    "orgastiska": "orgastisk",
    "orgastiskare": "orgastisk",
    "orgastiskares": "orgastisk",
    "orgastiskas": "orgastisk",
    "orgastiskast": "orgastisk",
    "orgastiskaste": "orgastisk",
    "orgastiskastes": "orgastisk",
    "orgastiskasts": "orgastisk",
    "orgastiske": "orgastisk",
    "orgastiskes": "orgastisk",
    "orgastisks": "orgastisk",
    "orgastiskt": "orgastisk",
    "orgastiskts": "orgastisk",
    "orgelharmonie": "orgelharmonium",
    "orgelharmonier": "orgelharmonium",
    "orgelharmonierna": "orgelharmonium",
    "orgelharmoniernas": "orgelharmonium",
    "orgelharmoniers": "orgelharmonium",
    "orgelharmoniet": "orgelharmonium",
    "orgelharmoniets": "orgelharmonium",
    "orgelharmoniums": "orgelharmonium",
    "orgelmusiken": "orgelmusik",
    "orgelmusikens": "orgelmusik",
    "orgelmusiks": "orgelmusik",
    "orgelmässiga": "orgelmässig",
    "orgelmässigare": "orgelmässig",
    "orgelmässigares": "orgelmässig",
    "orgelmässigas": "orgelmässig",
    "orgelmässigast": "orgelmässig",
    "orgelmässigaste": "orgelmässig",
    "orgelmässigastes": "orgelmässig",
    "orgelmässigasts": "orgelmässig",
    "orgelmässige": "orgelmässig",
    "orgelmässiges": "orgelmässig",
    "orgelmässigs": "orgelmässig",
    "orgelmässigt": "orgelmässig",
    "orgelmässigts": "orgelmässig",
    "orgeln": "orgel",
    "orgelns": "orgel",
    "orgelpip": "orgelpipa",
    "orgelpipan": "orgelpipa",
    "orgelpipans": "orgelpipa",
    "orgelpipas": "orgelpipa",
    "orgelpipe": "orgelpipa",
    "orgelpipor": "orgelpipa",
    "orgelpiporna": "orgelpipa",
    "orgelpipornas": "orgelpipa",
    "orgelpipors": "orgelpipa",
    "orgelpips": "orgelpipa",
    "orgelpunkten": "orgelpunkt",
    "orgelpunktens": "orgelpunkt",
    "orgelpunkts": "orgelpunkt",
    "orgelregisterna": "orgelregister",
    "orgelregisternas": "orgelregister",
    "orgelregisters": "orgelregister",
    "orgelregistren": "orgelregister",
    "orgelregistrens": "orgelregister",
    "orgelregistret": "orgelregister",
    "orgelregistrets": "orgelregister",
    "orgels": "orgel",
    "orgelstycken": "orgelstycke",
    "orgelstyckena": "orgelstycke",
    "orgelstyckenas": "orgelstycke",
    "orgelstyckens": "orgelstycke",
    "orgelstyckes": "orgelstycke",
    "orgelstycket": "orgelstycke",
    "orgelstyckets": "orgelstycke",
    "orgelstycks": "orgelstycke",
    "orgelstämman": "orgelstämma",
    "orgelstämmans": "orgelstämma",
    "orgelstämmas": "orgelstämma",
    "orgelstämme": "orgelstämma",
    "orgelstämmo": "orgelstämma",
    "orgelstämmor": "orgelstämma",
    "orgelstämmorna": "orgelstämma",
    "orgelstämmornas": "orgelstämma",
    "orgelstämmors": "orgelstämma",
    "orgeltrampar": "orgeltrampare",
    "orgeltramparen": "orgeltrampare",
    "orgeltramparens": "orgeltrampare",
    "orgeltrampares": "orgeltrampare",
    "orgeltramparna": "orgeltrampare",
    "orgeltramparnas": "orgeltrampare",
    "orgiasmen": "orgiasm",
    "orgiasmens": "orgiasm",
    "orgiasms": "orgiasm",
    "orgiastiska": "orgiastisk",
    "orgiastiskare": "orgiastisk",
    "orgiastiskares": "orgiastisk",
    "orgiastiskas": "orgiastisk",
    "orgiastiskast": "orgiastisk",
    "orgiastiskaste": "orgiastisk",
    "orgiastiskastes": "orgiastisk",
    "orgiastiskasts": "orgiastisk",
    "orgiastiske": "orgiastisk",
    "orgiastiskes": "orgiastisk",
    "orgiastisks": "orgiastisk",
    "orgiastiskt": "orgiastisk",
    "orgiastiskts": "orgiastisk",
    "orgien": "orgie",
    "orgiens": "orgie",
    "orgier": "orgie",
    "orgierna": "orgie",
    "orgiernas": "orgie",
    "orgiers": "orgie",
    "orgies": "orgie",
    "orglar": "orgel",
    "orglarna": "orgel",
    "orglarnas": "orgel",
    "orglars": "orgel",
    "oriade": "oriad",
    "oriades": "oriad",
    "oriads": "oriad",
    "oriat": "oriad",
    "oriats": "oriad",
    "orientalen": "oriental",
    "orientalens": "oriental",
    "orientaler": "oriental",
    "orientalerna": "oriental",
    "orientalernas": "oriental",
    "orientalers": "oriental",
    "orientaliska": "orientalisk",
    "orientaliskare": "orientalisk",
    "orientaliskares": "orientalisk",
    "orientaliskas": "orientalisk",
    "orientaliskast": "orientalisk",
    "orientaliskaste": "orientalisk",
    "orientaliskastes": "orientalisk",
    "orientaliskasts": "orientalisk",
    "orientaliske": "orientalisk",
    "orientaliskes": "orientalisk",
    "orientalisks": "orientalisk",
    "orientaliskt": "orientalisk",
    "orientaliskts": "orientalisk",
    "orientalismen": "orientalism",
    "orientalismens": "orientalism",
    "orientalismer": "orientalism",
    "orientalismerna": "orientalism",
    "orientalismernas": "orientalism",
    "orientalismers": "orientalism",
    "orientalisms": "orientalism",
    "orientalisten": "orientalist",
    "orientalistens": "orientalist",
    "orientalister": "orientalist",
    "orientalisterna": "orientalist",
    "orientalisternas": "orientalist",
    "orientalisters": "orientalist",
    "orientalistiken": "orientalistik",
    "orientalistikens": "orientalistik",
    "orientalistiks": "orientalistik",
    "orientalistiska": "orientalistisk",
    "orientalistiskas": "orientalistisk",
    "orientalistiske": "orientalistisk",
    "orientalistiskes": "orientalistisk",
    "orientalistisks": "orientalistisk",
    "orientalistiskt": "orientalistisk",
    "orientalistiskts": "orientalistisk",
    "orientalists": "orientalist",
    "orientals": "oriental",
    "orienten": "orient",
    "orientens": "orient",
    "orienterad": "orientera",
    "orienterade": "orientera",
    "orienterades": "orientera",
    "orienterads": "orientera",
    "orienterande": "orientera",
    "orienteranden": "orienterande",
    "orienterandena": "orienterande",
    "orienterandenas": "orienterande",
    "orienterandens": "orienterande",
    "orienterandes": "orienterande",
    "orienterandet": "orienterande",
    "orienterandets": "orienterande",
    "orienterar": "orienterare",
    "orienteraren": "orienterare",
    "orienterarens": "orienterare",
    "orienterares": "orienterare",
    "orienterarna": "orienterare",
    "orienterarnas": "orienterare",
    "orienteras": "orientera",
    "orienterat": "orientera",
    "orienterats": "orientera",
    "orienterbara": "orienterbar",
    "orienterbarare": "orienterbar",
    "orienterbarares": "orienterbar",
    "orienterbaras": "orienterbar",
    "orienterbarast": "orienterbar",
    "orienterbaraste": "orienterbar",
    "orienterbarastes": "orienterbar",
    "orienterbarasts": "orienterbar",
    "orienterbare": "orienterbar",
    "orienterbares": "orienterbar",
    "orienterbarheten": "orienterbarhet",
    "orienterbarhetens": "orienterbarhet",
    "orienterbarhets": "orienterbarhet",
    "orienterbars": "orienterbar",
    "orienterbart": "orienterbar",
    "orienterbarts": "orienterbar",
    "orienteringar": "orientering",
    "orienteringarna": "orientering",
    "orienteringarnas": "orientering",
    "orienteringars": "orientering",
    "orienteringen": "orientering",
    "orienteringens": "orientering",
    "orienterings": "orientering",
    "orienteringslamp": "orienteringslampa",
    "orienteringslampan": "orienteringslampa",
    "orienteringslampans": "orienteringslampa",
    "orienteringslampas": "orienteringslampa",
    "orienteringslampe": "orienteringslampa",
    "orienteringslampor": "orienteringslampa",
    "orienteringslamporna": "orienteringslampa",
    "orienteringslampornas": "orienteringslampa",
    "orienteringslampors": "orienteringslampa",
    "orienteringslamps": "orienteringslampa",
    "orienteringspunkten": "orienteringspunkt",
    "orienteringspunktens": "orienteringspunkt",
    "orienteringspunkter": "orienteringspunkt",
    "orienteringspunkterna": "orienteringspunkt",
    "orienteringspunkternas": "orienteringspunkt",
    "orienteringspunkters": "orienteringspunkt",
    "orienteringspunkts": "orienteringspunkt",
    "orienteringstavel": "orienteringstavla",
    "orienteringstavlan": "orienteringstavla",
    "orienteringstavlans": "orienteringstavla",
    "orienteringstavlas": "orienteringstavla",
    "orienteringstavle": "orienteringstavla",
    "orienteringstavlor": "orienteringstavla",
    "orienteringstavlorna": "orienteringstavla",
    "orienteringstavlornas": "orienteringstavla",
    "orienteringstavlors": "orienteringstavla",
    "orienteringstävlingar": "orienteringstävling",
    "orienteringstävlingarna": "orienteringstävling",
    "orienteringstävlingarnas": "orienteringstävling",
    "orienteringstävlingars": "orienteringstävling",
    "orienteringstävlingen": "orienteringstävling",
    "orienteringstävlingens": "orienteringstävling",
    "orienteringstävlings": "orienteringstävling",
    "orienteringsämnen": "orienteringsämne",
    "orienteringsämnena": "orienteringsämne",
    "orienteringsämnenas": "orienteringsämne",
    "orienteringsämnens": "orienteringsämne",
    "orienteringsämnes": "orienteringsämne",
    "orienteringsämnet": "orienteringsämne",
    "orienteringsämnets": "orienteringsämne",
    "orients": "orient",
    "origamin": "origami",
    "origamins": "origami",
    "origamis": "origami",
    "origgade": "origgad",
    "origgades": "origgad",
    "origgads": "origgad",
    "origgat": "origgad",
    "origgats": "origgad",
    "originaldokumenten": "originaldokument",
    "originaldokumentens": "originaldokument",
    "originaldokumentet": "originaldokument",
    "originaldokumentets": "originaldokument",
    "originaldokuments": "originaldokument",
    "originalen": "original",
    "originalens": "original",
    "originalet": "original",
    "originalets": "original",
    "originaliteten": "originalitet",
    "originalitetens": "originalitet",
    "originaliteter": "originalitet",
    "originaliteterna": "originalitet",
    "originaliteternas": "originalitet",
    "originaliteters": "originalitet",
    "originalitets": "originalitet",
    "originalitetskraven": "originalitetskrav",
    "originalitetskravens": "originalitetskrav",
    "originalitetskravet": "originalitetskrav",
    "originalitetskravets": "originalitetskrav",
    "originalitetskravs": "originalitetskrav",
    "originals": "original",
    "originalspråken": "originalspråk",
    "originalspråkens": "originalspråk",
    "originalspråket": "originalspråk",
    "originalspråkets": "originalspråk",
    "originalspråks": "originalspråk",
    "originaltexten": "originaltext",
    "originaltextens": "originaltext",
    "originaltexter": "originaltext",
    "originaltexterna": "originaltext",
    "originaltexternas": "originaltext",
    "originaltexters": "originaltext",
    "originaltexts": "originaltext",
    "originella": "originell",
    "originellare": "originell",
    "originellares": "originell",
    "originellas": "originell",
    "originellast": "originell",
    "originellaste": "originell",
    "originellastes": "originell",
    "originellasts": "originell",
    "originelle": "originell",
    "originelles": "originell",
    "originells": "originell",
    "originellt": "originell",
    "originellts": "originell",
    "origlade": "origlad",
    "origlades": "origlad",
    "origlads": "origlad",
    "origlat": "origlad",
    "origlats": "origlad",
    "origon": "origo",
    "origons": "origo",
    "origos": "origo",
    "orikoschetterade": "orikoschetterad",
    "orikoschetterades": "orikoschetterad",
    "orikoschetterads": "orikoschetterad",
    "orikoschetterat": "orikoschetterad",
    "orikoschetterats": "orikoschetterad",
    "oriktade": "oriktad",
    "oriktades": "oriktad",
    "oriktads": "oriktad",
    "oriktat": "oriktad",
    "oriktats": "oriktad",
    "oriktiga": "oriktig",
    "oriktigare": "oriktig",
    "oriktigares": "oriktig",
    "oriktigas": "oriktig",
    "oriktigast": "oriktig",
    "oriktigaste": "oriktig",
    "oriktigastes": "oriktig",
    "oriktigasts": "oriktig",
    "oriktige": "oriktig",
    "oriktiges": "oriktig",
    "oriktigheten": "oriktighet",
    "oriktighetens": "oriktighet",
    "oriktigheter": "oriktighet",
    "oriktigheterna": "oriktighet",
    "oriktigheternas": "oriktighet",
    "oriktigheters": "oriktighet",
    "oriktighets": "oriktighet",
    "oriktigs": "oriktig",
    "oriktigt": "oriktig",
    "oriktigts": "oriktig",
    "orimliga": "orimlig",
    "orimligare": "orimlig",
    "orimligares": "orimlig",
    "orimligas": "orimlig",
    "orimligast": "orimlig",
    "orimligaste": "orimlig",
    "orimligastes": "orimlig",
    "orimligasts": "orimlig",
    "orimlige": "orimlig",
    "orimliges": "orimlig",
    "orimligheten": "orimlighet",
    "orimlighetens": "orimlighet",
    "orimligheter": "orimlighet",
    "orimligheterna": "orimlighet",
    "orimligheternas": "orimlighet",
    "orimligheters": "orimlighet",
    "orimlighets": "orimlighet",
    "orimligs": "orimlig",
    "orimligt": "orimlig",
    "orimligts": "orimlig",
    "orimmade": "orimmad",
    "orimmades": "orimmad",
    "orimmads": "orimmad",
    "orimmat": "orimmad",
    "orimmats": "orimmad",
    "oringade": "oringad",
    "oringades": "oringad",
    "oringads": "oringad",
    "oringat": "oringad",
    "oringats": "oringad",
    "oringde": "oringd",
    "oringdes": "oringd",
    "oringds": "oringd",
    "oringt": "oringd",
    "oringts": "oringd",
    "orisade": "orisad",
    "orisades": "orisad",
    "orisads": "orisad",
    "orisat": "orisad",
    "orisats": "orisad",
    "orispade": "orispad",
    "orispades": "orispad",
    "orispads": "orispad",
    "orispat": "orispad",
    "orispats": "orispad",
    "orisslade": "orisslad",
    "orisslades": "orisslad",
    "orisslads": "orisslad",
    "orisslat": "orisslad",
    "orisslats": "orisslad",
    "oristade": "oristad",
    "oristades": "oristad",
    "oristads": "oristad",
    "oristat": "oristad",
    "oristats": "oristad",
    "oritade": "oritad",
    "oritades": "oritad",
    "oritads": "oritad",
    "oritat": "oritad",
    "oritats": "oritad",
    "oritsade": "oritsad",
    "oritsades": "oritsad",
    "oritsads": "oritsad",
    "oritsat": "oritsad",
    "oritsats": "oritsad",
    "oritualiserade": "oritualiserad",
    "oritualiserades": "oritualiserad",
    "oritualiserads": "oritualiserad",
    "oritualiserat": "oritualiserad",
    "oritualiserats": "oritualiserad",
    "oritualiserbara": "oritualiserbar",
    "oritualiserbarare": "oritualiserbar",
    "oritualiserbarares": "oritualiserbar",
    "oritualiserbaras": "oritualiserbar",
    "oritualiserbarast": "oritualiserbar",
    "oritualiserbaraste": "oritualiserbar",
    "oritualiserbarastes": "oritualiserbar",
    "oritualiserbarasts": "oritualiserbar",
    "oritualiserbare": "oritualiserbar",
    "oritualiserbares": "oritualiserbar",
    "oritualiserbarheten": "oritualiserbarhet",
    "oritualiserbarhetens": "oritualiserbarhet",
    "oritualiserbarhets": "oritualiserbarhet",
    "oritualiserbars": "oritualiserbar",
    "oritualiserbart": "oritualiserbar",
    "oritualiserbarts": "oritualiserbar",
    "orkade": "orka",
    "orkades": "orka",
    "orkande": "orka",
    "orkanden": "orkande",
    "orkandena": "orkande",
    "orkandenas": "orkande",
    "orkandens": "orkande",
    "orkandes": "orkande",
    "orkandet": "orkande",
    "orkandets": "orkande",
    "orkanen": "orkan",
    "orkanens": "orkan",
    "orkaner": "orkan",
    "orkanerna": "orkan",
    "orkanernas": "orkan",
    "orkaners": "orkan",
    "orkans": "orkan",
    "orkar": "orka",
    "orkas": "orka",
    "orkat": "orka",
    "orkats": "orka",
    "orken": "ork",
    "orkens": "ork",
    "orkeslösa": "orkeslös",
    "orkeslösare": "orkeslös",
    "orkeslösares": "orkeslös",
    "orkeslösas": "orkeslös",
    "orkeslösast": "orkeslös",
    "orkeslösaste": "orkeslös",
    "orkeslösastes": "orkeslös",
    "orkeslösasts": "orkeslös",
    "orkeslöse": "orkeslös",
    "orkeslöses": "orkeslös",
    "orkeslösheten": "orkeslöshet",
    "orkeslöshetens": "orkeslöshet",
    "orkeslöshets": "orkeslöshet",
    "orkeslöst": "orkeslös",
    "orkeslösts": "orkeslös",
    "orkesterdiken": "orkesterdike",
    "orkesterdikena": "orkesterdike",
    "orkesterdikenas": "orkesterdike",
    "orkesterdikens": "orkesterdike",
    "orkesterdikes": "orkesterdike",
    "orkesterdiket": "orkesterdike",
    "orkesterdikets": "orkesterdike",
    "orkesterföreningar": "orkesterförening",
    "orkesterföreningarna": "orkesterförening",
    "orkesterföreningarnas": "orkesterförening",
    "orkesterföreningars": "orkesterförening",
    "orkesterföreningen": "orkesterförening",
    "orkesterföreningens": "orkesterförening",
    "orkesterförenings": "orkesterförening",
    "orkestermedlemmar": "orkestermedlem",
    "orkestermedlemmarna": "orkestermedlem",
    "orkestermedlemmarnas": "orkestermedlem",
    "orkestermedlemmars": "orkestermedlem",
    "orkestermedlemmen": "orkestermedlem",
    "orkestermedlemmens": "orkestermedlem",
    "orkestermedlems": "orkestermedlem",
    "orkestern": "orkester",
    "orkesterns": "orkester",
    "orkesterplatsen": "orkesterplats",
    "orkesterplatsens": "orkesterplats",
    "orkesterplatser": "orkesterplats",
    "orkesterplatserna": "orkesterplats",
    "orkesterplatsernas": "orkesterplats",
    "orkesterplatsers": "orkesterplats",
    "orkesters": "orkester",
    "orkesterstycken": "orkesterstycke",
    "orkesterstyckena": "orkesterstycke",
    "orkesterstyckenas": "orkesterstycke",
    "orkesterstyckens": "orkesterstycke",
    "orkesterstyckes": "orkesterstycke",
    "orkesterstycket": "orkesterstycke",
    "orkesterstyckets": "orkesterstycke",
    "orkesterstycks": "orkesterstycke",
    "orkestiken": "orkestik",
    "orkestikens": "orkestik",
    "orkestiks": "orkestik",
    "orkestrala": "orkestral",
    "orkestralare": "orkestral",
    "orkestralares": "orkestral",
    "orkestralas": "orkestral",
    "orkestralast": "orkestral",
    "orkestralaste": "orkestral",
    "orkestralastes": "orkestral",
    "orkestralasts": "orkestral",
    "orkestrale": "orkestral",
    "orkestrales": "orkestral",
    "orkestrals": "orkestral",
    "orkestralt": "orkestral",
    "orkestralts": "orkestral",
    "orkestran": "orkestra",
    "orkestrans": "orkestra",
    "orkestrar": "orkester",
    "orkestrarna": "orkester",
    "orkestrarnas": "orkester",
    "orkestrars": "orkester",
    "orkestras": "orkestra",
    "orkestrerad": "orkestrera",
    "orkestrerade": "orkestrera",
    "orkestrerades": "orkestrera",
    "orkestrerads": "orkestrera",
    "orkestrerande": "orkestrera",
    "orkestreranden": "orkestrerande",
    "orkestrerandena": "orkestrerande",
    "orkestrerandenas": "orkestrerande",
    "orkestrerandens": "orkestrerande",
    "orkestrerandes": "orkestrerande",
    "orkestrerandet": "orkestrerande",
    "orkestrerandets": "orkestrerande",
    "orkestrerar": "orkestrera",
    "orkestreras": "orkestrera",
    "orkestrerat": "orkestrera",
    "orkestrerats": "orkestrera",
    "orkestrerbara": "orkestrerbar",
    "orkestrerbarare": "orkestrerbar",
    "orkestrerbarares": "orkestrerbar",
    "orkestrerbaras": "orkestrerbar",
    "orkestrerbarast": "orkestrerbar",
    "orkestrerbaraste": "orkestrerbar",
    "orkestrerbarastes": "orkestrerbar",
    "orkestrerbarasts": "orkestrerbar",
    "orkestrerbare": "orkestrerbar",
    "orkestrerbares": "orkestrerbar",
    "orkestrerbarheten": "orkestrerbarhet",
    "orkestrerbarhetens": "orkestrerbarhet",
    "orkestrerbarhets": "orkestrerbarhet",
    "orkestrerbars": "orkestrerbar",
    "orkestrerbart": "orkestrerbar",
    "orkestrerbarts": "orkestrerbar",
    "orkestreringar": "orkestrering",
    "orkestreringarna": "orkestrering",
    "orkestreringarnas": "orkestrering",
    "orkestreringars": "orkestrering",
    "orkestreringen": "orkestrering",
    "orkestreringens": "orkestrering",
    "orkestrerings": "orkestrering",
    "orkestror": "orkestra",
    "orkestrorna": "orkestra",
    "orkestrornas": "orkestra",
    "orkestrors": "orkestra",
    "orkidéer": "orkidé",
    "orkidéerna": "orkidé",
    "orkidéernas": "orkidé",
    "orkidéers": "orkidé",
    "orkidén": "orkidé",
    "orkidéns": "orkidé",
    "orkidés": "orkidé",
    "orkidéväxten": "orkidéväxt",
    "orkidéväxtens": "orkidéväxt",
    "orkidéväxter": "orkidéväxt",
    "orkidéväxterna": "orkidéväxt",
    "orkidéväxternas": "orkidéväxt",
    "orkidéväxters": "orkidéväxt",
    "orkidéväxts": "orkidéväxt",
    "orks": "ork",
    "orlovet": "orlov",
    "orlovets": "orlov",
    "orlovs": "orlov",
    "orlovssedeln": "orlovssedel",
    "orlovssedelns": "orlovssedel",
    "orlovssedels": "orlovssedel",
    "orlovssedlar": "orlovssedel",
    "orlovssedlarna": "orlovssedel",
    "orlovssedlarnas": "orlovssedel",
    "orlovssedlars": "orlovssedel",
    "ormade": "orma",
    "ormades": "orma",
    "ormande": "orma",
    "ormanden": "ormande",
    "ormandena": "ormande",
    "ormandenas": "ormande",
    "ormandens": "ormande",
    "ormandes": "ormande",
    "ormandet": "ormande",
    "ormandets": "ormande",
    "ormar": "orma",
    "ormarna": "orm",
    "ormarnas": "orm",
    "ormars": "orm",
    "ormas": "orma",
    "ormat": "orma",
    "ormats": "orma",
    "ormblåsan": "ormblåsa",
    "ormblåsans": "ormblåsa",
    "ormblåsas": "ormblåsa",
    "ormblåse": "ormblåsa",
    "ormblåsor": "ormblåsa",
    "ormblåsorna": "ormblåsa",
    "ormblåsornas": "ormblåsa",
    "ormblåsors": "ormblåsa",
    "ormboen": "ormbo",
    "ormboens": "ormbo",
    "ormboet": "ormbo",
    "ormboets": "ormbo",
    "ormbon": "ormbo",
    "ormbona": "ormbo",
    "ormbonas": "ormbo",
    "ormbons": "ormbo",
    "ormbos": "ormbo",
    "ormbot": "ormbo",
    "ormbots": "ormbo",
    "ormbunk": "ormbunke",
    "ormbunkar": "ormbunke",
    "ormbunkarna": "ormbunke",
    "ormbunkarnas": "ormbunke",
    "ormbunkars": "ormbunke",
    "ormbunken": "ormbunke",
    "ormbunkens": "ormbunke",
    "ormbunkes": "ormbunke",
    "ormbunks": "ormbunke",
    "ormbunksväxten": "ormbunksväxt",
    "ormbunksväxtens": "ormbunksväxt",
    "ormbunksväxter": "ormbunksväxt",
    "ormbunksväxterna": "ormbunksväxt",
    "ormbunksväxternas": "ormbunksväxt",
    "ormbunksväxters": "ormbunksväxt",
    "ormbunksväxts": "ormbunksväxt",
    "ormbären": "ormbär",
    "ormbärens": "ormbär",
    "ormbäret": "ormbär",
    "ormbärets": "ormbär",
    "ormbärs": "ormbär",
    "ormdödar": "ormdödare",
    "ormdödaren": "ormdödare",
    "ormdödarens": "ormdödare",
    "ormdödares": "ormdödare",
    "ormdödarna": "ormdödare",
    "ormdödarnas": "ormdödare",
    "ormen": "orm",
    "ormens": "orm",
    "ormetters": "ormetter",
    "ormettret": "ormetter",
    "ormettrets": "ormetter",
    "ormgifter": "ormgift",
    "ormgifterna": "ormgift",
    "ormgifternas": "ormgift",
    "ormgifters": "ormgift",
    "ormgiftet": "ormgift",
    "ormgiftets": "ormgift",
    "ormgifts": "ormgift",
    "ormgranar": "ormgran",
    "ormgranarna": "ormgran",
    "ormgranarnas": "ormgran",
    "ormgranars": "ormgran",
    "ormgranen": "ormgran",
    "ormgranens": "ormgran",
    "ormgrans": "ormgran",
    "ormgropar": "ormgrop",
    "ormgroparna": "ormgrop",
    "ormgroparnas": "ormgrop",
    "ormgropars": "ormgrop",
    "ormgropen": "ormgrop",
    "ormgropens": "ormgrop",
    "ormgrops": "ormgrop",
    "ormhåren": "ormhår",
    "ormhårens": "ormhår",
    "ormhåret": "ormhår",
    "ormhårets": "ormhår",
    "ormhårs": "ormhår",
    "ormknutar": "ormknut",
    "ormknutarna": "ormknut",
    "ormknutarnas": "ormknut",
    "ormknutars": "ormknut",
    "ormknuten": "ormknut",
    "ormknutens": "ormknut",
    "ormknuts": "ormknut",
    "ormmänniskan": "ormmänniska",
    "ormmänniskans": "ormmänniska",
    "ormmänniskas": "ormmänniska",
    "ormmännisko": "ormmänniska",
    "ormmänniskor": "ormmänniska",
    "ormmänniskorna": "ormmänniska",
    "ormmänniskornas": "ormmänniska",
    "ormmänniskors": "ormmänniska",
    "ormroten": "ormrot",
    "ormrotens": "ormrot",
    "ormrots": "ormrot",
    "orms": "orm",
    "ormserumet": "ormserum",
    "ormserumets": "ormserum",
    "ormserums": "ormserum",
    "ormskinnen": "ormskinn",
    "ormskinnens": "ormskinn",
    "ormskinnet": "ormskinn",
    "ormskinnets": "ormskinn",
    "ormskinns": "ormskinn",
    "ormsling": "ormslinga",
    "ormslingan": "ormslinga",
    "ormslingans": "ormslinga",
    "ormslingas": "ormslinga",
    "ormslinge": "ormslinga",
    "ormslingor": "ormslinga",
    "ormslingorna": "ormslinga",
    "ormslingornas": "ormslinga",
    "ormslingors": "ormslinga",
    "ormslings": "ormslinga",
    "ormslån": "ormslå",
    "ormslåns": "ormslå",
    "ormslår": "ormslå",
    "ormslårna": "ormslå",
    "ormslårnas": "ormslå",
    "ormslårs": "ormslå",
    "ormslås": "ormslå",
    "ormspottet": "ormspott",
    "ormspottets": "ormspott",
    "ormspotts": "ormspott",
    "ormstjärnan": "ormstjärna",
    "ormstjärnans": "ormstjärna",
    "ormstjärnas": "ormstjärna",
    "ormstjärne": "ormstjärna",
    "ormstjärnor": "ormstjärna",
    "ormstjärnorna": "ormstjärna",
    "ormstjärnornas": "ormstjärna",
    "ormstjärnors": "ormstjärna",
    "ormtjusar": "ormtjusare",
    "ormtjusaren": "ormtjusare",
    "ormtjusarens": "ormtjusare",
    "ormtjusares": "ormtjusare",
    "ormtjusarna": "ormtjusare",
    "ormtjusarnas": "ormtjusare",
    "ormtungan": "ormtunga",
    "ormtungans": "ormtunga",
    "ormtungas": "ormtunga",
    "ormtunge": "ormtunga",
    "ormtungo": "ormtunga",
    "ormtungor": "ormtunga",
    "ormtungorna": "ormtunga",
    "ormtungornas": "ormtunga",
    "ormtungors": "ormtunga",
    "ormvråkar": "ormvråk",
    "ormvråkarna": "ormvråk",
    "ormvråkarnas": "ormvråk",
    "ormvråkars": "ormvråk",
    "ormvråken": "ormvråk",
    "ormvråkens": "ormvråk",
    "ormvråks": "ormvråk",
    "ormyngels": "ormyngel",
    "ormynglen": "ormyngel",
    "ormynglens": "ormyngel",
    "ormynglet": "ormyngel",
    "ormynglets": "ormyngel",
    "ormörnar": "ormörn",
    "ormörnarna": "ormörn",
    "ormörnarnas": "ormörn",
    "ormörnars": "ormörn",
    "ormörnen": "ormörn",
    "ormörnens": "ormörn",
    "ormörns": "ormörn",
    "orn": "orne",
    "ornamentala": "ornamental",
    "ornamentalare": "ornamental",
    "ornamentalares": "ornamental",
    "ornamentalas": "ornamental",
    "ornamentalast": "ornamental",
    "ornamentalaste": "ornamental",
    "ornamentalastes": "ornamental",
    "ornamentalasts": "ornamental",
    "ornamentale": "ornamental",
    "ornamentales": "ornamental",
    "ornamentals": "ornamental",
    "ornamentalt": "ornamental",
    "ornamentalts": "ornamental",
    "ornamenten": "ornament",
    "ornamentens": "ornament",
    "ornamenterad": "ornamentera",
    "ornamenterade": "ornamentera",
    "ornamenterades": "ornamentera",
    "ornamenterads": "ornamentera",
    "ornamenterande": "ornamentera",
    "ornamenteranden": "ornamenterande",
    "ornamenterandena": "ornamenterande",
    "ornamenterandenas": "ornamenterande",
    "ornamenterandens": "ornamenterande",
    "ornamenterandes": "ornamenterande",
    "ornamenterandet": "ornamenterande",
    "ornamenterandets": "ornamenterande",
    "ornamenterar": "ornamentera",
    "ornamenteras": "ornamentera",
    "ornamenterat": "ornamentera",
    "ornamenterats": "ornamentera",
    "ornamenterbara": "ornamenterbar",
    "ornamenterbarare": "ornamenterbar",
    "ornamenterbarares": "ornamenterbar",
    "ornamenterbaras": "ornamenterbar",
    "ornamenterbarast": "ornamenterbar",
    "ornamenterbaraste": "ornamenterbar",
    "ornamenterbarastes": "ornamenterbar",
    "ornamenterbarasts": "ornamenterbar",
    "ornamenterbare": "ornamenterbar",
    "ornamenterbares": "ornamenterbar",
    "ornamenterbarheten": "ornamenterbarhet",
    "ornamenterbarhetens": "ornamenterbarhet",
    "ornamenterbarhets": "ornamenterbarhet",
    "ornamenterbars": "ornamenterbar",
    "ornamenterbart": "ornamenterbar",
    "ornamenterbarts": "ornamenterbar",
    "ornamenteringar": "ornamentering",
    "ornamenteringarna": "ornamentering",
    "ornamenteringarnas": "ornamentering",
    "ornamenteringars": "ornamentering",
    "ornamenteringen": "ornamentering",
    "ornamenteringens": "ornamentering",
    "ornamenterings": "ornamentering",
    "ornamentet": "ornament",
    "ornamentets": "ornament",
    "ornamentiken": "ornamentik",
    "ornamentikens": "ornamentik",
    "ornamentiks": "ornamentik",
    "ornamentisten": "ornamentist",
    "ornamentistens": "ornamentist",
    "ornamentister": "ornamentist",
    "ornamentisterna": "ornamentist",
    "ornamentisternas": "ornamentist",
    "ornamentisters": "ornamentist",
    "ornamentists": "ornamentist",
    "ornaments": "ornament",
    "ornar": "orne",
    "ornarna": "orne",
    "ornarnas": "orne",
    "ornars": "orne",
    "ornaten": "ornat",
    "ornatens": "ornat",
    "ornater": "ornat",
    "ornaterna": "ornat",
    "ornaternas": "ornat",
    "ornaters": "ornat",
    "ornats": "ornat",
    "ornen": "orne",
    "ornens": "orne",
    "ornerad": "ornera",
    "ornerade": "ornera",
    "ornerades": "ornera",
    "ornerads": "ornera",
    "ornerande": "ornera",
    "orneranden": "ornerande",
    "ornerandena": "ornerande",
    "ornerandenas": "ornerande",
    "ornerandens": "ornerande",
    "ornerandes": "ornerande",
    "ornerandet": "ornerande",
    "ornerandets": "ornerande",
    "ornerar": "ornera",
    "orneras": "ornera",
    "ornerat": "ornera",
    "ornerats": "ornera",
    "ornerbara": "ornerbar",
    "ornerbarare": "ornerbar",
    "ornerbarares": "ornerbar",
    "ornerbaras": "ornerbar",
    "ornerbarast": "ornerbar",
    "ornerbaraste": "ornerbar",
    "ornerbarastes": "ornerbar",
    "ornerbarasts": "ornerbar",
    "ornerbare": "ornerbar",
    "ornerbares": "ornerbar",
    "ornerbarheten": "ornerbarhet",
    "ornerbarhetens": "ornerbarhet",
    "ornerbarhets": "ornerbarhet",
    "ornerbars": "ornerbar",
    "ornerbart": "ornerbar",
    "ornerbarts": "ornerbar",
    "orneringar": "ornering",
    "orneringarna": "ornering",
    "orneringarnas": "ornering",
    "orneringars": "ornering",
    "orneringen": "ornering",
    "orneringens": "ornering",
    "ornerings": "ornering",
    "ornes": "orne",
    "ornitologen": "ornitolog",
    "ornitologens": "ornitolog",
    "ornitologer": "ornitolog",
    "ornitologerna": "ornitolog",
    "ornitologernas": "ornitolog",
    "ornitologers": "ornitolog",
    "ornitologien": "ornitologi",
    "ornitologiens": "ornitologi",
    "ornitologin": "ornitologi",
    "ornitologins": "ornitologi",
    "ornitologis": "ornitologi",
    "ornitologiska": "ornitologisk",
    "ornitologiskare": "ornitologisk",
    "ornitologiskares": "ornitologisk",
    "ornitologiskas": "ornitologisk",
    "ornitologiskast": "ornitologisk",
    "ornitologiskaste": "ornitologisk",
    "ornitologiskastes": "ornitologisk",
    "ornitologiskasts": "ornitologisk",
    "ornitologiske": "ornitologisk",
    "ornitologiskes": "ornitologisk",
    "ornitologisks": "ornitologisk",
    "ornitologiskt": "ornitologisk",
    "ornitologiskts": "ornitologisk",
    "ornitologs": "ornitolog",
    "orns": "orne",
    "ornäsbjörkar": "ornäsbjörk",
    "ornäsbjörkarna": "ornäsbjörk",
    "ornäsbjörkarnas": "ornäsbjörk",
    "ornäsbjörkars": "ornäsbjörk",
    "ornäsbjörken": "ornäsbjörk",
    "ornäsbjörkens": "ornäsbjörk",
    "ornäsbjörks": "ornäsbjörk",
    "oro": "oroa",
    "oroad": "oroa",
    "oroade": "oroa",
    "oroades": "oroa",
    "oroads": "oroa",
    "oroande": "oroa",
    "oroanden": "oroande",
    "oroandena": "oroande",
    "oroandenas": "oroande",
    "oroandens": "oroande",
    "oroandes": "oroande",
    "oroandet": "oroande",
    "oroandets": "oroande",
    "oroar": "oroa",
    "oroarna": "oro",
    "oroarnas": "oro",
    "oroars": "oro",
    "oroas": "oroa",
    "oroat": "oroa",
    "oroats": "oroa",
    "orobotiserade": "orobotiserad",
    "orobotiserades": "orobotiserad",
    "orobotiserads": "orobotiserad",
    "orobotiserat": "orobotiserad",
    "orobotiserats": "orobotiserad",
    "orobotiserbara": "orobotiserbar",
    "orobotiserbarare": "orobotiserbar",
    "orobotiserbarares": "orobotiserbar",
    "orobotiserbaras": "orobotiserbar",
    "orobotiserbarast": "orobotiserbar",
    "orobotiserbaraste": "orobotiserbar",
    "orobotiserbarastes": "orobotiserbar",
    "orobotiserbarasts": "orobotiserbar",
    "orobotiserbare": "orobotiserbar",
    "orobotiserbares": "orobotiserbar",
    "orobotiserbarheten": "orobotiserbarhet",
    "orobotiserbarhetens": "orobotiserbarhet",
    "orobotiserbarhets": "orobotiserbarhet",
    "orobotiserbars": "orobotiserbar",
    "orobotiserbart": "orobotiserbar",
    "orobotiserbarts": "orobotiserbar",
    "orockerade": "orockerad",
    "orockerades": "orockerad",
    "orockerads": "orockerad",
    "orockerat": "orockerad",
    "orockerats": "orockerad",
    "orockerbara": "orockerbar",
    "orockerbarare": "orockerbar",
    "orockerbarares": "orockerbar",
    "orockerbaras": "orockerbar",
    "orockerbarast": "orockerbar",
    "orockerbaraste": "orockerbar",
    "orockerbarastes": "orockerbar",
    "orockerbarasts": "orockerbar",
    "orockerbare": "orockerbar",
    "orockerbares": "orockerbar",
    "orockerbarheten": "orockerbarhet",
    "orockerbarhetens": "orockerbarhet",
    "orockerbarhets": "orockerbarhet",
    "orockerbars": "orockerbar",
    "orockerbart": "orockerbar",
    "orockerbarts": "orockerbar",
    "oroffade": "oroffad",
    "oroffades": "oroffad",
    "oroffads": "oroffad",
    "oroffat": "oroffad",
    "oroffats": "oroffad",
    "orogenesen": "orogenes",
    "orogenesens": "orogenes",
    "orogenetiska": "orogenetisk",
    "orogenetiskare": "orogenetisk",
    "orogenetiskares": "orogenetisk",
    "orogenetiskas": "orogenetisk",
    "orogenetiskast": "orogenetisk",
    "orogenetiskaste": "orogenetisk",
    "orogenetiskastes": "orogenetisk",
    "orogenetiskasts": "orogenetisk",
    "orogenetiske": "orogenetisk",
    "orogenetiskes": "orogenetisk",
    "orogenetisks": "orogenetisk",
    "orogenetiskt": "orogenetisk",
    "orogenetiskts": "orogenetisk",
    "orografien": "orografi",
    "orografiens": "orografi",
    "orografin": "orografi",
    "orografins": "orografi",
    "orografis": "orografi",
    "oroliga": "orolig",
    "oroligare": "orolig",
    "oroligares": "orolig",
    "oroligas": "orolig",
    "oroligast": "orolig",
    "oroligaste": "orolig",
    "oroligastes": "orolig",
    "oroligasts": "orolig",
    "orolige": "orolig",
    "oroliges": "orolig",
    "oroligheten": "orolighet",
    "orolighetens": "orolighet",
    "oroligheter": "orolighet",
    "oroligheterna": "orolighet",
    "oroligheternas": "orolighet",
    "oroligheters": "orolighet",
    "orolighets": "orolighet",
    "oroligs": "orolig",
    "oroligt": "orolig",
    "oroligts": "orolig",
    "orollade": "orollad",
    "orollades": "orollad",
    "orollads": "orollad",
    "orollat": "orollad",
    "orollats": "orollad",
    "oromantiserade": "oromantiserad",
    "oromantiserades": "oromantiserad",
    "oromantiserads": "oromantiserad",
    "oromantiserat": "oromantiserad",
    "oromantiserats": "oromantiserad",
    "oromantiserbara": "oromantiserbar",
    "oromantiserbarare": "oromantiserbar",
    "oromantiserbarares": "oromantiserbar",
    "oromantiserbaras": "oromantiserbar",
    "oromantiserbarast": "oromantiserbar",
    "oromantiserbaraste": "oromantiserbar",
    "oromantiserbarastes": "oromantiserbar",
    "oromantiserbarasts": "oromantiserbar",
    "oromantiserbare": "oromantiserbar",
    "oromantiserbares": "oromantiserbar",
    "oromantiserbarheten": "oromantiserbarhet",
    "oromantiserbarhetens": "oromantiserbarhet",
    "oromantiserbarhets": "oromantiserbarhet",
    "oromantiserbars": "oromantiserbar",
    "oromantiserbart": "oromantiserbar",
    "oromantiserbarts": "oromantiserbar",
    "oron": "oro",
    "orons": "oro",
    "oror": "oro",
    "ororna": "oro",
    "orornas": "oro",
    "orors": "oro",
    "oros": "oro",
    "orosade": "orosad",
    "orosades": "orosad",
    "orosads": "orosad",
    "orosat": "orosad",
    "orosats": "orosad",
    "oroscentra": "oroscentrum",
    "oroscentrana": "oroscentrum",
    "oroscentranas": "oroscentrum",
    "oroscentras": "oroscentrum",
    "oroscentrumen": "oroscentrum",
    "oroscentrumens": "oroscentrum",
    "oroscentrumet": "oroscentrum",
    "oroscentrumets": "oroscentrum",
    "oroscentrums": "oroscentrum",
    "oroshärdar": "oroshärd",
    "oroshärdarna": "oroshärd",
    "oroshärdarnas": "oroshärd",
    "oroshärdars": "oroshärd",
    "oroshärden": "oroshärd",
    "oroshärdens": "oroshärd",
    "oroshärds": "oroshärd",
    "orosmolnen": "orosmoln",
    "orosmolnens": "orosmoln",
    "orosmolnet": "orosmoln",
    "orosmolnets": "orosmoln",
    "orosmolns": "orosmoln",
    "orosmomenten": "orosmoment",
    "orosmomentens": "orosmoment",
    "orosmomentet": "orosmoment",
    "orosmomentets": "orosmoment",
    "orosmoments": "orosmoment",
    "orosstiftar": "orosstiftare",
    "orosstiftaren": "orosstiftare",
    "orosstiftarens": "orosstiftare",
    "orosstiftares": "orosstiftare",
    "orosstiftarna": "orosstiftare",
    "orosstiftarnas": "orosstiftare",
    "orostade": "orostad",
    "orostades": "orostad",
    "orostads": "orostad",
    "orostat": "orostad",
    "orostats": "orostad",
    "orosåren": "orosår",
    "orosårens": "orosår",
    "orosåret": "orosår",
    "orosårets": "orosår",
    "orosårs": "orosår",
    "oroterade": "oroterad",
    "oroterades": "oroterad",
    "oroterads": "oroterad",
    "oroterat": "oroterad",
    "oroterats": "oroterad",
    "oroterbara": "oroterbar",
    "oroterbarare": "oroterbar",
    "oroterbarares": "oroterbar",
    "oroterbaras": "oroterbar",
    "oroterbarast": "oroterbar",
    "oroterbaraste": "oroterbar",
    "oroterbarastes": "oroterbar",
    "oroterbarasts": "oroterbar",
    "oroterbare": "oroterbar",
    "oroterbares": "oroterbar",
    "oroterbarheten": "oroterbarhet",
    "oroterbarhetens": "oroterbarhet",
    "oroterbarhets": "oroterbarhet",
    "oroterbars": "oroterbar",
    "oroterbart": "oroterbar",
    "oroterbarts": "oroterbar",
    "orr": "orre",
    "orrar": "orre",
    "orrarna": "orre",
    "orrarnas": "orre",
    "orrars": "orre",
    "orren": "orre",
    "orrens": "orre",
    "orres": "orre",
    "orrfågeln": "orrfågel",
    "orrfågelns": "orrfågel",
    "orrfågels": "orrfågel",
    "orrfåglar": "orrfågel",
    "orrfåglarna": "orrfågel",
    "orrfåglarnas": "orrfågel",
    "orrfåglars": "orrfågel",
    "orrs": "orre",
    "orrspelen": "orrspel",
    "orrspelens": "orrspel",
    "orrspelet": "orrspel",
    "orrspelets": "orrspel",
    "orrspels": "orrspel",
    "ors": "or",
    "orsak": "orsaka",
    "orsakad": "orsaka",
    "orsakade": "orsaka",
    "orsakades": "orsaka",
    "orsakads": "orsaka",
    "orsakande": "orsaka",
    "orsakanden": "orsakande",
    "orsakandena": "orsakande",
    "orsakandenas": "orsakande",
    "orsakandens": "orsakande",
    "orsakandes": "orsakande",
    "orsakandet": "orsakande",
    "orsakandets": "orsakande",
    "orsakar": "orsaka",
    "orsakas": "orsaka",
    "orsakat": "orsaka",
    "orsakats": "orsaka",
    "orsaken": "orsak",
    "orsakens": "orsak",
    "orsaker": "orsak",
    "orsakerna": "orsak",
    "orsakernas": "orsak",
    "orsakers": "orsak",
    "orsakliga": "orsaklig",
    "orsakligare": "orsaklig",
    "orsakligares": "orsaklig",
    "orsakligas": "orsaklig",
    "orsakligast": "orsaklig",
    "orsakligaste": "orsaklig",
    "orsakligastes": "orsaklig",
    "orsakligasts": "orsaklig",
    "orsaklige": "orsaklig",
    "orsakliges": "orsaklig",
    "orsakligheten": "orsaklighet",
    "orsaklighetens": "orsaklighet",
    "orsaklighets": "orsaklighet",
    "orsakligs": "orsaklig",
    "orsakligt": "orsaklig",
    "orsakligts": "orsaklig",
    "orsaks": "orsak",
    "orsaksadverbialen": "orsaksadverbial",
    "orsaksadverbialens": "orsaksadverbial",
    "orsaksadverbialet": "orsaksadverbial",
    "orsaksadverbialets": "orsaksadverbial",
    "orsaksadverbials": "orsaksadverbial",
    "orsaksbestämda": "orsaksbestämd",
    "orsaksbestämdare": "orsaksbestämd",
    "orsaksbestämdares": "orsaksbestämd",
    "orsaksbestämdas": "orsaksbestämd",
    "orsaksbestämdast": "orsaksbestämd",
    "orsaksbestämdaste": "orsaksbestämd",
    "orsaksbestämdastes": "orsaksbestämd",
    "orsaksbestämdasts": "orsaksbestämd",
    "orsaksbestämde": "orsaksbestämd",
    "orsaksbestämdes": "orsaksbestämd",
    "orsaksbestämdheten": "orsaksbestämdhet",
    "orsaksbestämdhetens": "orsaksbestämdhet",
    "orsaksbestämdhets": "orsaksbestämdhet",
    "orsaksbestämds": "orsaksbestämd",
    "orsaksbestämt": "orsaksbestämd",
    "orsaksbestämts": "orsaksbestämd",
    "orsakskedjan": "orsakskedja",
    "orsakskedjans": "orsakskedja",
    "orsakskedjas": "orsakskedja",
    "orsakskedje": "orsakskedja",
    "orsakskedjor": "orsakskedja",
    "orsakskedjorna": "orsakskedja",
    "orsakskedjornas": "orsakskedja",
    "orsakskedjors": "orsakskedja",
    "orsakskomplexen": "orsakskomplex",
    "orsakskomplexens": "orsakskomplex",
    "orsakskomplexet": "orsakskomplex",
    "orsakskomplexets": "orsakskomplex",
    "orsaksmässiga": "orsaksmässig",
    "orsaksmässigare": "orsaksmässig",
    "orsaksmässigares": "orsaksmässig",
    "orsaksmässigas": "orsaksmässig",
    "orsaksmässigast": "orsaksmässig",
    "orsaksmässigaste": "orsaksmässig",
    "orsaksmässigastes": "orsaksmässig",
    "orsaksmässigasts": "orsaksmässig",
    "orsaksmässige": "orsaksmässig",
    "orsaksmässiges": "orsaksmässig",
    "orsaksmässigheten": "orsaksmässighet",
    "orsaksmässighetens": "orsaksmässighet",
    "orsaksmässighets": "orsaksmässighet",
    "orsaksmässigs": "orsaksmässig",
    "orsaksmässigt": "orsaksmässig",
    "orsaksmässigts": "orsaksmässig",
    "orsakssambanden": "orsakssamband",
    "orsakssambandens": "orsakssamband",
    "orsakssambandet": "orsakssamband",
    "orsakssambandets": "orsakssamband",
    "orsakssambands": "orsakssamband",
    "orsakssammanhangen": "orsakssammanhang",
    "orsakssammanhangens": "orsakssammanhang",
    "orsakssammanhanget": "orsakssammanhang",
    "orsakssammanhangets": "orsakssammanhang",
    "orsakssammanhangs": "orsakssammanhang",
    "orseljen": "orselj",
    "orseljens": "orselj",
    "orseljs": "orselj",
    "orstenen": "orsten",
    "orstenens": "orsten",
    "orstens": "orsten",
    "ortar": "ort",
    "ortarna": "ort",
    "ortarnas": "ort",
    "ortars": "ort",
    "ortdrivar": "ortdrivare",
    "ortdrivaren": "ortdrivare",
    "ortdrivarens": "ortdrivare",
    "ortdrivares": "ortdrivare",
    "ortdrivarna": "ortdrivare",
    "ortdrivarnas": "ortdrivare",
    "orten": "ort",
    "ortens": "ort",
    "orter": "ort",
    "orterna": "ort",
    "orternas": "ort",
    "orters": "ort",
    "ortet": "ort",
    "ortets": "ort",
    "ortikonen": "ortikon",
    "ortikonens": "ortikon",
    "ortikoner": "ortikon",
    "ortikonerna": "ortikon",
    "ortikonernas": "ortikon",
    "ortikoners": "ortikon",
    "ortikons": "ortikon",
    "ortliga": "ortlig",
    "ortligare": "ortlig",
    "ortligares": "ortlig",
    "ortligas": "ortlig",
    "ortligast": "ortlig",
    "ortligaste": "ortlig",
    "ortligastes": "ortlig",
    "ortligasts": "ortlig",
    "ortlige": "ortlig",
    "ortliges": "ortlig",
    "ortligs": "ortlig",
    "ortligt": "ortlig",
    "ortligts": "ortlig",
    "ortlinjen": "ortlinje",
    "ortlinjens": "ortlinje",
    "ortlinjer": "ortlinje",
    "ortlinjerna": "ortlinje",
    "ortlinjernas": "ortlinje",
    "ortlinjers": "ortlinje",
    "ortlinjes": "ortlinje",
    "ortnamnen": "ortnamn",
    "ortnamnens": "ortnamn",
    "ortnamnet": "ortnamn",
    "ortnamnets": "ortnamn",
    "ortnamns": "ortnamn",
    "ortnamnsforskningar": "ortnamnsforskning",
    "ortnamnsforskningarna": "ortnamnsforskning",
    "ortnamnsforskningarnas": "ortnamnsforskning",
    "ortnamnsforskningars": "ortnamnsforskning",
    "ortnamnsforskningen": "ortnamnsforskning",
    "ortnamnsforskningens": "ortnamnsforskning",
    "ortnamnsforsknings": "ortnamnsforskning",
    "ortoceratiten": "ortoceratit",
    "ortoceratitens": "ortoceratit",
    "ortoceratiter": "ortoceratit",
    "ortoceratiterna": "ortoceratit",
    "ortoceratiternas": "ortoceratit",
    "ortoceratiters": "ortoceratit",
    "ortoceratits": "ortoceratit",
    "ortodontien": "ortodonti",
    "ortodontiens": "ortodonti",
    "ortodontin": "ortodonti",
    "ortodontins": "ortodonti",
    "ortodontis": "ortodonti",
    "ortodoxa": "ortodox",
    "ortodoxare": "ortodox",
    "ortodoxares": "ortodox",
    "ortodoxas": "ortodox",
    "ortodoxast": "ortodox",
    "ortodoxaste": "ortodox",
    "ortodoxastes": "ortodox",
    "ortodoxasts": "ortodox",
    "ortodoxe": "ortodox",
    "ortodoxes": "ortodox",
    "ortodoxheten": "ortodoxhet",
    "ortodoxhetens": "ortodoxhet",
    "ortodoxhets": "ortodoxhet",
    "ortodoxien": "ortodoxi",
    "ortodoxiens": "ortodoxi",
    "ortodoxier": "ortodoxi",
    "ortodoxierna": "ortodoxi",
    "ortodoxiernas": "ortodoxi",
    "ortodoxiers": "ortodoxi",
    "ortodoxin": "ortodoxi",
    "ortodoxins": "ortodoxi",
    "ortodoxis": "ortodoxi",
    "ortodoxismen": "ortodoxism",
    "ortodoxismens": "ortodoxism",
    "ortodoxismer": "ortodoxism",
    "ortodoxismerna": "ortodoxism",
    "ortodoxismernas": "ortodoxism",
    "ortodoxismers": "ortodoxism",
    "ortodoxisms": "ortodoxism",
    "ortodoxt": "ortodox",
    "ortodoxts": "ortodox",
    "ortodromen": "ortodrom",
    "ortodromens": "ortodrom",
    "ortodromer": "ortodrom",
    "ortodromerna": "ortodrom",
    "ortodromernas": "ortodrom",
    "ortodromers": "ortodrom",
    "ortodroms": "ortodrom",
    "ortogonala": "ortogonal",
    "ortogonalare": "ortogonal",
    "ortogonalares": "ortogonal",
    "ortogonalas": "ortogonal",
    "ortogonalast": "ortogonal",
    "ortogonalaste": "ortogonal",
    "ortogonalastes": "ortogonal",
    "ortogonalasts": "ortogonal",
    "ortogonale": "ortogonal",
    "ortogonales": "ortogonal",
    "ortogonals": "ortogonal",
    "ortogonalt": "ortogonal",
    "ortogonalts": "ortogonal",
    "ortografien": "ortografi",
    "ortografiens": "ortografi",
    "ortografier": "ortografi",
    "ortografierna": "ortografi",
    "ortografiernas": "ortografi",
    "ortografiers": "ortografi",
    "ortografin": "ortografi",
    "ortografins": "ortografi",
    "ortografis": "ortografi",
    "ortoklasen": "ortoklas",
    "ortoklasens": "ortoklas",
    "ortokromatiska": "ortokromatisk",
    "ortokromatiskare": "ortokromatisk",
    "ortokromatiskares": "ortokromatisk",
    "ortokromatiskas": "ortokromatisk",
    "ortokromatiskast": "ortokromatisk",
    "ortokromatiskaste": "ortokromatisk",
    "ortokromatiskastes": "ortokromatisk",
    "ortokromatiskasts": "ortokromatisk",
    "ortokromatiske": "ortokromatisk",
    "ortokromatiskes": "ortokromatisk",
    "ortokromatisks": "ortokromatisk",
    "ortokromatiskt": "ortokromatisk",
    "ortokromatiskts": "ortokromatisk",
    "ortolanen": "ortolan",
    "ortolanens": "ortolan",
    "ortolaner": "ortolan",
    "ortolanerna": "ortolan",
    "ortolanernas": "ortolan",
    "ortolaners": "ortolan",
    "ortolans": "ortolan",
    "ortolansparvar": "ortolansparv",
    "ortolansparvarna": "ortolansparv",
    "ortolansparvarnas": "ortolansparv",
    "ortolansparvars": "ortolansparv",
    "ortolansparven": "ortolansparv",
    "ortolansparvens": "ortolansparv",
    "ortolansparvs": "ortolansparv",
    "ortopeden": "ortoped",
    "ortopedens": "ortoped",
    "ortopeder": "ortoped",
    "ortopederna": "ortoped",
    "ortopedernas": "ortoped",
    "ortopeders": "ortoped",
    "ortopedien": "ortopedi",
    "ortopediens": "ortopedi",
    "ortopedin": "ortopedi",
    "ortopedins": "ortopedi",
    "ortopedis": "ortopedi",
    "ortopeds": "ortoped",
    "ortoptisten": "ortoptist",
    "ortoptistens": "ortoptist",
    "ortoptister": "ortoptist",
    "ortoptisterna": "ortoptist",
    "ortoptisternas": "ortoptist",
    "ortoptisters": "ortoptist",
    "ortoptists": "ortoptist",
    "ortoptrisen": "ortoptris",
    "ortoptrisens": "ortoptris",
    "ortoptriser": "ortoptris",
    "ortoptriserna": "ortoptris",
    "ortoptrisernas": "ortoptris",
    "ortoptrisers": "ortoptris",
    "orts": "ort",
    "ortsavdragen": "ortsavdrag",
    "ortsavdragens": "ortsavdrag",
    "ortsavdraget": "ortsavdrag",
    "ortsavdragets": "ortsavdrag",
    "ortsavdrags": "ortsavdrag",
    "ortsgruppen": "ortsgrupp",
    "ortsgruppens": "ortsgrupp",
    "ortsgrupper": "ortsgrupp",
    "ortsgrupperna": "ortsgrupp",
    "ortsgruppernas": "ortsgrupp",
    "ortsgruppers": "ortsgrupp",
    "ortsgrupps": "ortsgrupp",
    "ortstenen": "ortsten",
    "ortstenens": "ortsten",
    "ortstens": "ortsten",
    "ortstiden": "ortstid",
    "ortstidens": "ortstid",
    "ortstider": "ortstid",
    "ortstiderna": "ortstid",
    "ortstidernas": "ortstid",
    "ortstiders": "ortstid",
    "ortstids": "ortstid",
    "ortstilläggen": "ortstillägg",
    "ortstilläggens": "ortstillägg",
    "ortstillägget": "ortstillägg",
    "ortstilläggets": "ortstillägg",
    "ortstilläggs": "ortstillägg",
    "ortsul": "ortsula",
    "ortsulan": "ortsula",
    "ortsulans": "ortsula",
    "ortsulas": "ortsula",
    "ortsule": "ortsula",
    "ortsulor": "ortsula",
    "ortsulorna": "ortsula",
    "ortsulornas": "ortsula",
    "ortsulors": "ortsula",
    "ortsuls": "ortsula",
    "orubbade": "orubbad",
    "orubbades": "orubbad",
    "orubbads": "orubbad",
    "orubbat": "orubbad",
    "orubbats": "orubbad",
    "orubbliga": "orubblig",
    "orubbligare": "orubblig",
    "orubbligares": "orubblig",
    "orubbligas": "orubblig",
    "orubbligast": "orubblig",
    "orubbligaste": "orubblig",
    "orubbligastes": "orubblig",
    "orubbligasts": "orubblig",
    "orubblige": "orubblig",
    "orubbliges": "orubblig",
    "orubbligheten": "orubblighet",
    "orubblighetens": "orubblighet",
    "orubblighets": "orubblighet",
    "orubbligs": "orubblig",
    "orubbligt": "orubblig",
    "orubbligts": "orubblig",
    "orubricerade": "orubricerad",
    "orubricerades": "orubricerad",
    "orubricerads": "orubricerad",
    "orubricerat": "orubricerad",
    "orubricerats": "orubricerad",
    "orubricerbara": "orubricerbar",
    "orubricerbarare": "orubricerbar",
    "orubricerbarares": "orubricerbar",
    "orubricerbaras": "orubricerbar",
    "orubricerbarast": "orubricerbar",
    "orubricerbaraste": "orubricerbar",
    "orubricerbarastes": "orubricerbar",
    "orubricerbarasts": "orubricerbar",
    "orubricerbare": "orubricerbar",
    "orubricerbares": "orubricerbar",
    "orubricerbarheten": "orubricerbarhet",
    "orubricerbarhetens": "orubricerbarhet",
    "orubricerbarhets": "orubricerbarhet",
    "orubricerbars": "orubricerbar",
    "orubricerbart": "orubricerbar",
    "orubricerbarts": "orubricerbar",
    "oruckade": "oruckad",
    "oruckades": "oruckad",
    "oruckads": "oruckad",
    "oruckat": "oruckad",
    "oruckats": "oruckad",
    "oruggade": "oruggad",
    "oruggades": "oruggad",
    "oruggads": "oruggad",
    "oruggat": "oruggad",
    "oruggats": "oruggad",
    "oruinerade": "oruinerad",
    "oruinerades": "oruinerad",
    "oruinerads": "oruinerad",
    "oruinerat": "oruinerad",
    "oruinerats": "oruinerad",
    "oruinerbara": "oruinerbar",
    "oruinerbarare": "oruinerbar",
    "oruinerbarares": "oruinerbar",
    "oruinerbaras": "oruinerbar",
    "oruinerbarast": "oruinerbar",
    "oruinerbaraste": "oruinerbar",
    "oruinerbarastes": "oruinerbar",
    "oruinerbarasts": "oruinerbar",
    "oruinerbare": "oruinerbar",
    "oruinerbares": "oruinerbar",
    "oruinerbarheten": "oruinerbarhet",
    "oruinerbarhetens": "oruinerbarhet",
    "oruinerbarhets": "oruinerbarhet",
    "oruinerbars": "oruinerbar",
    "oruinerbart": "oruinerbar",
    "oruinerbarts": "oruinerbar",
    "orullade": "orullad",
    "orullades": "orullad",
    "orullads": "orullad",
    "orullat": "orullad",
    "orullats": "orullad",
    "orunda": "orund",
    "orundade": "orundad",
    "orundades": "orundad",
    "orundads": "orundad",
    "orundare": "orund",
    "orundares": "orund",
    "orundas": "orund",
    "orundast": "orund",
    "orundaste": "orund",
    "orundastes": "orund",
    "orundasts": "orund",
    "orundat": "orundad",
    "orundats": "orundad",
    "orunde": "orund",
    "orundes": "orund",
    "orundheten": "orundhet",
    "orundhetens": "orundhet",
    "orundhets": "orundhet",
    "orunds": "orund",
    "orunkade": "orunkad",
    "orunkades": "orunkad",
    "orunkads": "orunkad",
    "orunkat": "orunkad",
    "orunkats": "orunkad",
    "orunt": "orund",
    "orunts": "orund",
    "orusade": "orusad",
    "orusades": "orusad",
    "orusads": "orusad",
    "orusat": "orusad",
    "orusats": "orusad",
    "oruskade": "oruskad",
    "oruskades": "oruskad",
    "oruskads": "oruskad",
    "oruskat": "oruskad",
    "oruskats": "oruskad",
    "orussificerade": "orussificerad",
    "orussificerades": "orussificerad",
    "orussificerads": "orussificerad",
    "orussificerat": "orussificerad",
    "orussificerats": "orussificerad",
    "orussificerbara": "orussificerbar",
    "orussificerbarare": "orussificerbar",
    "orussificerbarares": "orussificerbar",
    "orussificerbaras": "orussificerbar",
    "orussificerbarast": "orussificerbar",
    "orussificerbaraste": "orussificerbar",
    "orussificerbarastes": "orussificerbar",
    "orussificerbarasts": "orussificerbar",
    "orussificerbare": "orussificerbar",
    "orussificerbares": "orussificerbar",
    "orussificerbarheten": "orussificerbarhet",
    "orussificerbarhetens": "orussificerbarhet",
    "orussificerbarhets": "orussificerbarhet",
    "orussificerbars": "orussificerbar",
    "orussificerbart": "orussificerbar",
    "orussificerbarts": "orussificerbar",
    "orussifierade": "orussifierad",
    "orussifierades": "orussifierad",
    "orussifierads": "orussifierad",
    "orussifierat": "orussifierad",
    "orussifierats": "orussifierad",
    "orussifierbara": "orussifierbar",
    "orussifierbarare": "orussifierbar",
    "orussifierbarares": "orussifierbar",
    "orussifierbaras": "orussifierbar",
    "orussifierbarast": "orussifierbar",
    "orussifierbaraste": "orussifierbar",
    "orussifierbarastes": "orussifierbar",
    "orussifierbarasts": "orussifierbar",
    "orussifierbare": "orussifierbar",
    "orussifierbares": "orussifierbar",
    "orussifierbarheten": "orussifierbarhet",
    "orussifierbarhetens": "orussifierbarhet",
    "orussifierbarhets": "orussifierbarhet",
    "orussifierbars": "orussifierbar",
    "orussifierbart": "orussifierbar",
    "orussifierbarts": "orussifierbar",
    "orustade": "orustad",
    "orustades": "orustad",
    "orustads": "orustad",
    "orustat": "orustad",
    "orustats": "orustad",
    "orutinerade": "orutinerad",
    "orutinerades": "orutinerad",
    "orutinerads": "orutinerad",
    "orutinerat": "orutinerad",
    "orutinerats": "orutinerad",
    "oruvade": "oruvad",
    "oruvades": "oruvad",
    "oruvads": "oruvad",
    "oruvat": "oruvad",
    "oruvats": "oruvad",
    "orven": "orv",
    "orvens": "orv",
    "orvet": "orv",
    "orvets": "orv",
    "orvs": "orv",
    "oryggliga": "orygglig",
    "oryggligare": "orygglig",
    "oryggligares": "orygglig",
    "oryggligas": "orygglig",
    "oryggligast": "orygglig",
    "oryggligaste": "orygglig",
    "oryggligastes": "orygglig",
    "oryggligasts": "orygglig",
    "orygglige": "orygglig",
    "oryggliges": "orygglig",
    "oryggligheten": "orygglighet",
    "orygglighetens": "orygglighet",
    "orygglighets": "orygglighet",
    "oryggligs": "orygglig",
    "oryggligt": "orygglig",
    "oryggligts": "orygglig",
    "oryktade": "oryktad",
    "oryktades": "oryktad",
    "oryktads": "oryktad",
    "oryktat": "oryktad",
    "oryktats": "oryktad",
    "orymde": "orymd",
    "orymdes": "orymd",
    "orymds": "orymd",
    "orymt": "orymd",
    "orymts": "orymd",
    "orynkade": "orynkad",
    "orynkades": "orynkad",
    "orynkads": "orynkad",
    "orynkat": "orynkad",
    "orynkats": "orynkad",
    "orytmiserade": "orytmiserad",
    "orytmiserades": "orytmiserad",
    "orytmiserads": "orytmiserad",
    "orytmiserat": "orytmiserad",
    "orytmiserats": "orytmiserad",
    "orytmiserbara": "orytmiserbar",
    "orytmiserbarare": "orytmiserbar",
    "orytmiserbarares": "orytmiserbar",
    "orytmiserbaras": "orytmiserbar",
    "orytmiserbarast": "orytmiserbar",
    "orytmiserbaraste": "orytmiserbar",
    "orytmiserbarastes": "orytmiserbar",
    "orytmiserbarasts": "orytmiserbar",
    "orytmiserbare": "orytmiserbar",
    "orytmiserbares": "orytmiserbar",
    "orytmiserbarheten": "orytmiserbarhet",
    "orytmiserbarhetens": "orytmiserbarhet",
    "orytmiserbarhets": "orytmiserbarhet",
    "orytmiserbars": "orytmiserbar",
    "orytmiserbart": "orytmiserbar",
    "orytmiserbarts": "orytmiserbar",
    "orytmiska": "orytmisk",
    "orytmiskare": "orytmisk",
    "orytmiskares": "orytmisk",
    "orytmiskas": "orytmisk",
    "orytmiskast": "orytmisk",
    "orytmiskaste": "orytmisk",
    "orytmiskastes": "orytmisk",
    "orytmiskasts": "orytmisk",
    "orytmiske": "orytmisk",
    "orytmiskes": "orytmisk",
    "orytmisks": "orytmisk",
    "orytmiskt": "orytmisk",
    "orytmiskts": "orytmisk",
    "oryxen": "oryx",
    "oryxens": "oryx",
    "oryxer": "oryx",
    "oryxerna": "oryx",
    "oryxernas": "oryx",
    "oryxers": "oryx",
    "oräckta": "oräckt",
    "oräcktas": "oräckt",
    "oräckte": "oräckt",
    "oräcktes": "oräckt",
    "oräckts": "oräckt",
    "orädda": "orädd",
    "oräddade": "oräddad",
    "oräddades": "oräddad",
    "oräddads": "oräddad",
    "oräddare": "orädd",
    "oräddares": "orädd",
    "oräddas": "orädd",
    "oräddast": "orädd",
    "oräddaste": "orädd",
    "oräddastes": "orädd",
    "oräddasts": "orädd",
    "oräddat": "oräddad",
    "oräddats": "oräddad",
    "orädde": "orädd",
    "oräddes": "orädd",
    "oräddheten": "oräddhet",
    "oräddhetens": "oräddhet",
    "oräddhets": "oräddhet",
    "orädds": "orädd",
    "oräfflade": "oräfflad",
    "oräfflades": "oräfflad",
    "oräfflads": "oräfflad",
    "oräfflat": "oräfflad",
    "oräfflats": "oräfflad",
    "oräfsade": "oräfsad",
    "oräfsades": "oräfsad",
    "oräfsads": "oräfsad",
    "oräfsat": "oräfsad",
    "oräfsats": "oräfsad",
    "oräknade": "oräknad",
    "oräknades": "oräknad",
    "oräknads": "oräknad",
    "oräknat": "oräknad",
    "oräknats": "oräknad",
    "oräkneliga": "oräknelig",
    "oräkneligare": "oräknelig",
    "oräkneligares": "oräknelig",
    "oräkneligas": "oräknelig",
    "oräkneligast": "oräknelig",
    "oräkneligaste": "oräknelig",
    "oräkneligastes": "oräknelig",
    "oräkneligasts": "oräknelig",
    "oräknelige": "oräknelig",
    "oräkneliges": "oräknelig",
    "oräkneligheten": "oräknelighet",
    "oräknelighetens": "oräknelighet",
    "oräknelighets": "oräknelighet",
    "oräkneligs": "oräknelig",
    "oräkneligt": "oräknelig",
    "oräkneligts": "oräknelig",
    "orämnade": "orämnad",
    "orämnades": "orämnad",
    "orämnads": "orämnad",
    "orämnat": "orämnad",
    "orämnats": "orämnad",
    "orätade": "orätad",
    "orätades": "orätad",
    "orätads": "orätad",
    "orätat": "orätad",
    "orätats": "orätad",
    "orätta": "orätt",
    "orättade": "orättad",
    "orättades": "orättad",
    "orättads": "orättad",
    "orättare": "orätt",
    "orättares": "orätt",
    "orättas": "orätt",
    "orättast": "orätt",
    "orättaste": "orätt",
    "orättastes": "orätt",
    "orättasts": "orätt",
    "orättat": "orättad",
    "orättats": "orättad",
    "orätte": "orätt",
    "orätten": "orätt",
    "orättens": "orätt",
    "orätter": "orätt",
    "orätterna": "orätt",
    "orätternas": "orätt",
    "orätters": "orätt",
    "orättes": "orätt",
    "orättfärdiga": "orättfärdig",
    "orättfärdigade": "orättfärdigad",
    "orättfärdigades": "orättfärdigad",
    "orättfärdigads": "orättfärdigad",
    "orättfärdigare": "orättfärdig",
    "orättfärdigares": "orättfärdig",
    "orättfärdigas": "orättfärdig",
    "orättfärdigast": "orättfärdig",
    "orättfärdigaste": "orättfärdig",
    "orättfärdigastes": "orättfärdig",
    "orättfärdigasts": "orättfärdig",
    "orättfärdigat": "orättfärdigad",
    "orättfärdigats": "orättfärdigad",
    "orättfärdige": "orättfärdig",
    "orättfärdiges": "orättfärdig",
    "orättfärdigheten": "orättfärdighet",
    "orättfärdighetens": "orättfärdighet",
    "orättfärdigheter": "orättfärdighet",
    "orättfärdigheterna": "orättfärdighet",
    "orättfärdigheternas": "orättfärdighet",
    "orättfärdigheters": "orättfärdighet",
    "orättfärdighets": "orättfärdighet",
    "orättfärdigs": "orättfärdig",
    "orättfärdigt": "orättfärdig",
    "orättfärdigts": "orättfärdig",
    "orättfångens": "orättfången",
    "orättfånget": "orättfången",
    "orättfångets": "orättfången",
    "orättfångna": "orättfången",
    "orättfångnare": "orättfången",
    "orättfångnares": "orättfången",
    "orättfångnas": "orättfången",
    "orättfångnast": "orättfången",
    "orättfångnaste": "orättfången",
    "orättfångnastes": "orättfången",
    "orättfångnasts": "orättfången",
    "orättfångne": "orättfången",
    "orättfångnes": "orättfången",
    "orättmätiga": "orättmätig",
    "orättmätigare": "orättmätig",
    "orättmätigares": "orättmätig",
    "orättmätigas": "orättmätig",
    "orättmätigast": "orättmätig",
    "orättmätigaste": "orättmätig",
    "orättmätigastes": "orättmätig",
    "orättmätigasts": "orättmätig",
    "orättmätige": "orättmätig",
    "orättmätiges": "orättmätig",
    "orättmätigheten": "orättmätighet",
    "orättmätighetens": "orättmätighet",
    "orättmätighets": "orättmätighet",
    "orättmätigs": "orättmätig",
    "orättmätigt": "orättmätig",
    "orättmätigts": "orättmätig",
    "orättrådiga": "orättrådig",
    "orättrådigare": "orättrådig",
    "orättrådigares": "orättrådig",
    "orättrådigas": "orättrådig",
    "orättrådigast": "orättrådig",
    "orättrådigaste": "orättrådig",
    "orättrådigastes": "orättrådig",
    "orättrådigasts": "orättrådig",
    "orättrådige": "orättrådig",
    "orättrådiges": "orättrådig",
    "orättrådigheten": "orättrådighet",
    "orättrådighetens": "orättrådighet",
    "orättrådighets": "orättrådighet",
    "orättrådigs": "orättrådig",
    "orättrådigt": "orättrådig",
    "orättrådigts": "orättrådig",
    "orätts": "orätt",
    "orättvisa": "orättvis",
    "orättvisan": "orättvisa",
    "orättvisans": "orättvisa",
    "orättvisare": "orättvis",
    "orättvisares": "orättvis",
    "orättvisas": "orättvisa",
    "orättvisast": "orättvis",
    "orättvisaste": "orättvis",
    "orättvisastes": "orättvis",
    "orättvisasts": "orättvis",
    "orättvise": "orättvisa",
    "orättvises": "orättvis",
    "orättvisor": "orättvisa",
    "orättvisorna": "orättvisa",
    "orättvisornas": "orättvisa",
    "orättvisors": "orättvisa",
    "orättvist": "orättvis",
    "orättvists": "orättvis",
    "orågade": "orågad",
    "orågades": "orågad",
    "orågads": "orågad",
    "orågat": "orågad",
    "orågats": "orågad",
    "oråkade": "oråkad",
    "oråkades": "oråkad",
    "oråkads": "oråkad",
    "oråkat": "oråkad",
    "oråkats": "oråkad",
    "oråmade": "oråmad",
    "oråmades": "oråmad",
    "oråmads": "oråmad",
    "oråmat": "oråmad",
    "oråmats": "oråmad",
    "orånade": "orånad",
    "orånades": "orånad",
    "orånads": "orånad",
    "orånat": "orånad",
    "orånats": "orånad",
    "oröjde": "oröjd",
    "oröjdes": "oröjd",
    "oröjds": "oröjd",
    "oröjt": "oröjd",
    "oröjts": "oröjd",
    "orökta": "orökt",
    "oröktas": "orökt",
    "orökte": "orökt",
    "oröktes": "orökt",
    "orökts": "orökt",
    "orönta": "orönt",
    "oröntas": "orönt",
    "orönte": "orönt",
    "oröntes": "orönt",
    "oröntgade": "oröntgad",
    "oröntgades": "oröntgad",
    "oröntgads": "oröntgad",
    "oröntgat": "oröntgad",
    "oröntgats": "oröntgad",
    "orönts": "orönt",
    "orörbara": "orörbar",
    "orörbarare": "orörbar",
    "orörbarares": "orörbar",
    "orörbaras": "orörbar",
    "orörbarast": "orörbar",
    "orörbaraste": "orörbar",
    "orörbarastes": "orörbar",
    "orörbarasts": "orörbar",
    "orörbare": "orörbar",
    "orörbares": "orörbar",
    "orörbarheten": "orörbarhet",
    "orörbarhetens": "orörbarhet",
    "orörbarhets": "orörbarhet",
    "orörbars": "orörbar",
    "orörbart": "orörbar",
    "orörbarts": "orörbar",
    "orörda": "orörd",
    "orördare": "orörd",
    "orördares": "orörd",
    "orördas": "orörd",
    "orördast": "orörd",
    "orördaste": "orörd",
    "orördastes": "orörd",
    "orördasts": "orörd",
    "orörde": "orörd",
    "orördes": "orörd",
    "orördheten": "orördhet",
    "orördhetens": "orördhet",
    "orördhets": "orördhet",
    "orörds": "orörd",
    "orörliga": "orörlig",
    "orörligare": "orörlig",
    "orörligares": "orörlig",
    "orörligas": "orörlig",
    "orörligast": "orörlig",
    "orörligaste": "orörlig",
    "orörligastes": "orörlig",
    "orörligasts": "orörlig",
    "orörlige": "orörlig",
    "orörliges": "orörlig",
    "orörligheten": "orörlighet",
    "orörlighetens": "orörlighet",
    "orörlighets": "orörlighet",
    "orörligs": "orörlig",
    "orörligt": "orörlig",
    "orörligts": "orörlig",
    "orört": "orörd",
    "orörts": "orörd",
    "orösade": "orösad",
    "orösades": "orösad",
    "orösads": "orösad",
    "orösat": "orösad",
    "orösats": "orösad",
    "orövade": "orövad",
    "orövades": "orövad",
    "orövads": "orövad",
    "orövat": "orövad",
    "orövats": "orövad",
    "os": "osa",
    "osabbade": "osabbad",
    "osabbades": "osabbad",
    "osabbads": "osabbad",
    "osabbat": "osabbad",
    "osabbats": "osabbad",
    "osaboterade": "osaboterad",
    "osaboterades": "osaboterad",
    "osaboterads": "osaboterad",
    "osaboterat": "osaboterad",
    "osaboterats": "osaboterad",
    "osaboterbara": "osaboterbar",
    "osaboterbarare": "osaboterbar",
    "osaboterbarares": "osaboterbar",
    "osaboterbaras": "osaboterbar",
    "osaboterbarast": "osaboterbar",
    "osaboterbaraste": "osaboterbar",
    "osaboterbarastes": "osaboterbar",
    "osaboterbarasts": "osaboterbar",
    "osaboterbare": "osaboterbar",
    "osaboterbares": "osaboterbar",
    "osaboterbarheten": "osaboterbarhet",
    "osaboterbarhetens": "osaboterbarhet",
    "osaboterbarhets": "osaboterbarhet",
    "osaboterbars": "osaboterbar",
    "osaboterbart": "osaboterbar",
    "osaboterbarts": "osaboterbar",
    "osabrerade": "osabrerad",
    "osabrerades": "osabrerad",
    "osabrerads": "osabrerad",
    "osabrerat": "osabrerad",
    "osabrerats": "osabrerad",
    "osabrerbara": "osabrerbar",
    "osabrerbarare": "osabrerbar",
    "osabrerbarares": "osabrerbar",
    "osabrerbaras": "osabrerbar",
    "osabrerbarast": "osabrerbar",
    "osabrerbaraste": "osabrerbar",
    "osabrerbarastes": "osabrerbar",
    "osabrerbarasts": "osabrerbar",
    "osabrerbare": "osabrerbar",
    "osabrerbares": "osabrerbar",
    "osabrerbarheten": "osabrerbarhet",
    "osabrerbarhetens": "osabrerbarhet",
    "osabrerbarhets": "osabrerbarhet",
    "osabrerbars": "osabrerbar",
    "osabrerbart": "osabrerbar",
    "osabrerbarts": "osabrerbar",
    "osade": "osa",
    "osades": "osa",
    "osadlade": "osadlad",
    "osadlades": "osadlad",
    "osadlads": "osadlad",
    "osadlat": "osadlad",
    "osadlats": "osadlad",
    "osaftade": "osaftad",
    "osaftades": "osaftad",
    "osaftads": "osaftad",
    "osaftat": "osaftad",
    "osaftats": "osaftad",
    "osagda": "osagd",
    "osagdare": "osagd",
    "osagdares": "osagd",
    "osagdas": "osagd",
    "osagdast": "osagd",
    "osagdaste": "osagd",
    "osagdastes": "osagd",
    "osagdasts": "osagd",
    "osagde": "osagd",
    "osagdes": "osagd",
    "osagds": "osagd",
    "osagt": "osagd",
    "osagts": "osagd",
    "osakade": "osakad",
    "osakades": "osakad",
    "osakads": "osakad",
    "osakat": "osakad",
    "osakats": "osakad",
    "osakkunniga": "osakkunnig",
    "osakkunnigare": "osakkunnig",
    "osakkunnigares": "osakkunnig",
    "osakkunnigas": "osakkunnig",
    "osakkunnigast": "osakkunnig",
    "osakkunnigaste": "osakkunnig",
    "osakkunnigastes": "osakkunnig",
    "osakkunnigasts": "osakkunnig",
    "osakkunnige": "osakkunnig",
    "osakkunniges": "osakkunnig",
    "osakkunnigheten": "osakkunnighet",
    "osakkunnighetens": "osakkunnighet",
    "osakkunnighets": "osakkunnighet",
    "osakkunnigs": "osakkunnig",
    "osakkunnigt": "osakkunnig",
    "osakkunnigts": "osakkunnig",
    "osakliga": "osaklig",
    "osakligare": "osaklig",
    "osakligares": "osaklig",
    "osakligas": "osaklig",
    "osakligast": "osaklig",
    "osakligaste": "osaklig",
    "osakligastes": "osaklig",
    "osakligasts": "osaklig",
    "osaklige": "osaklig",
    "osakliges": "osaklig",
    "osakligheten": "osaklighet",
    "osaklighetens": "osaklighet",
    "osakligheter": "osaklighet",
    "osakligheterna": "osaklighet",
    "osakligheternas": "osaklighet",
    "osakligheters": "osaklighet",
    "osaklighets": "osaklighet",
    "osakligs": "osaklig",
    "osakligt": "osaklig",
    "osakligts": "osaklig",
    "osaknade": "osaknad",
    "osaknades": "osaknad",
    "osaknads": "osaknad",
    "osaknat": "osaknad",
    "osaknats": "osaknad",
    "osaktade": "osaktad",
    "osaktades": "osaktad",
    "osaktads": "osaktad",
    "osaktat": "osaktad",
    "osaktats": "osaktad",
    "osalade": "osalad",
    "osalades": "osalad",
    "osalads": "osalad",
    "osalat": "osalad",
    "osalats": "osalad",
    "osalderade": "osalderad",
    "osalderades": "osalderad",
    "osalderads": "osalderad",
    "osalderat": "osalderad",
    "osalderats": "osalderad",
    "osalderbara": "osalderbar",
    "osalderbarare": "osalderbar",
    "osalderbarares": "osalderbar",
    "osalderbaras": "osalderbar",
    "osalderbarast": "osalderbar",
    "osalderbaraste": "osalderbar",
    "osalderbarastes": "osalderbar",
    "osalderbarasts": "osalderbar",
    "osalderbare": "osalderbar",
    "osalderbares": "osalderbar",
    "osalderbarheten": "osalderbarhet",
    "osalderbarhetens": "osalderbarhet",
    "osalderbarhets": "osalderbarhet",
    "osalderbars": "osalderbar",
    "osalderbart": "osalderbar",
    "osalderbarts": "osalderbar",
    "osaliga": "osalig",
    "osaligare": "osalig",
    "osaligares": "osalig",
    "osaligas": "osalig",
    "osaligast": "osalig",
    "osaligaste": "osalig",
    "osaligastes": "osalig",
    "osaligasts": "osalig",
    "osalige": "osalig",
    "osaliges": "osalig",
    "osaligheten": "osalighet",
    "osalighetens": "osalighet",
    "osalighets": "osalighet",
    "osaligs": "osalig",
    "osaligt": "osalig",
    "osaligts": "osalig",
    "osaltade": "osaltad",
    "osaltades": "osaltad",
    "osaltads": "osaltad",
    "osaltat": "osaltad",
    "osaltats": "osaltad",
    "osaluterade": "osaluterad",
    "osaluterades": "osaluterad",
    "osaluterads": "osaluterad",
    "osaluterat": "osaluterad",
    "osaluterats": "osaluterad",
    "osaluterbara": "osaluterbar",
    "osaluterbarare": "osaluterbar",
    "osaluterbarares": "osaluterbar",
    "osaluterbaras": "osaluterbar",
    "osaluterbarast": "osaluterbar",
    "osaluterbaraste": "osaluterbar",
    "osaluterbarastes": "osaluterbar",
    "osaluterbarasts": "osaluterbar",
    "osaluterbare": "osaluterbar",
    "osaluterbares": "osaluterbar",
    "osaluterbarheten": "osaluterbarhet",
    "osaluterbarhetens": "osaluterbarhet",
    "osaluterbarhets": "osaluterbarhet",
    "osaluterbars": "osaluterbar",
    "osaluterbart": "osaluterbar",
    "osaluterbarts": "osaluterbar",
    "osambeskattade": "osambeskattad",
    "osambeskattades": "osambeskattad",
    "osambeskattads": "osambeskattad",
    "osambeskattat": "osambeskattad",
    "osambeskattats": "osambeskattad",
    "osamkade": "osamkad",
    "osamkades": "osamkad",
    "osamkads": "osamkad",
    "osamkat": "osamkad",
    "osamkats": "osamkad",
    "osamkörde": "osamkörd",
    "osamkördes": "osamkörd",
    "osamkörds": "osamkörd",
    "osamkört": "osamkörd",
    "osamkörts": "osamkörd",
    "osamlade": "osamlad",
    "osamlades": "osamlad",
    "osamlads": "osamlad",
    "osamlat": "osamlad",
    "osamlats": "osamlad",
    "osammanblandade": "osammanblandad",
    "osammanblandades": "osammanblandad",
    "osammanblandads": "osammanblandad",
    "osammanblandat": "osammanblandad",
    "osammanblandats": "osammanblandad",
    "osammanfattade": "osammanfattad",
    "osammanfattades": "osammanfattad",
    "osammanfattads": "osammanfattad",
    "osammanfattat": "osammanfattad",
    "osammanfattats": "osammanfattad",
    "osammanflätade": "osammanflätad",
    "osammanflätades": "osammanflätad",
    "osammanflätads": "osammanflätad",
    "osammanflätat": "osammanflätad",
    "osammanflätats": "osammanflätad",
    "osammanfogade": "osammanfogad",
    "osammanfogades": "osammanfogad",
    "osammanfogads": "osammanfogad",
    "osammanfogat": "osammanfogad",
    "osammanfogats": "osammanfogad",
    "osammanförde": "osammanförd",
    "osammanfördes": "osammanförd",
    "osammanförds": "osammanförd",
    "osammanfört": "osammanförd",
    "osammanförts": "osammanförd",
    "osammanhopade": "osammanhopad",
    "osammanhopades": "osammanhopad",
    "osammanhopads": "osammanhopad",
    "osammanhopat": "osammanhopad",
    "osammanhopats": "osammanhopad",
    "osammanjämkade": "osammanjämkad",
    "osammanjämkades": "osammanjämkad",
    "osammanjämkads": "osammanjämkad",
    "osammanjämkat": "osammanjämkad",
    "osammanjämkats": "osammanjämkad",
    "osammankallade": "osammankallad",
    "osammankallades": "osammankallad",
    "osammankallads": "osammankallad",
    "osammankallat": "osammankallad",
    "osammankallats": "osammankallad",
    "osammankopplade": "osammankopplad",
    "osammankopplades": "osammankopplad",
    "osammankopplads": "osammankopplad",
    "osammankopplat": "osammankopplad",
    "osammankopplats": "osammankopplad",
    "osammanlänkade": "osammanlänkad",
    "osammanlänkades": "osammanlänkad",
    "osammanlänkads": "osammanlänkad",
    "osammanlänkat": "osammanlänkad",
    "osammanlänkats": "osammanlänkad",
    "osammanlöpta": "osammanlöpt",
    "osammanlöptas": "osammanlöpt",
    "osammanlöpte": "osammanlöpt",
    "osammanlöptes": "osammanlöpt",
    "osammanlöpts": "osammanlöpt",
    "osammanpackade": "osammanpackad",
    "osammanpackades": "osammanpackad",
    "osammanpackads": "osammanpackad",
    "osammanpackat": "osammanpackad",
    "osammanpackats": "osammanpackad",
    "osammanpressade": "osammanpressad",
    "osammanpressades": "osammanpressad",
    "osammanpressads": "osammanpressad",
    "osammanpressat": "osammanpressad",
    "osammanpressats": "osammanpressad",
    "osammanringde": "osammanringd",
    "osammanringdes": "osammanringd",
    "osammanringds": "osammanringd",
    "osammanringt": "osammanringd",
    "osammanringts": "osammanringd",
    "osammanräknade": "osammanräknad",
    "osammanräknades": "osammanräknad",
    "osammanräknads": "osammanräknad",
    "osammanräknat": "osammanräknad",
    "osammanräknats": "osammanräknad",
    "osammanstrålade": "osammanstrålad",
    "osammanstrålades": "osammanstrålad",
    "osammanstrålads": "osammanstrålad",
    "osammanstrålat": "osammanstrålad",
    "osammanstrålats": "osammanstrålad",
    "osammanställde": "osammanställd",
    "osammanställdes": "osammanställd",
    "osammanställds": "osammanställd",
    "osammanställt": "osammanställd",
    "osammanställts": "osammanställd",
    "osammanstötta": "osammanstött",
    "osammanstöttas": "osammanstött",
    "osammanstötte": "osammanstött",
    "osammanstöttes": "osammanstött",
    "osammanstötts": "osammanstött",
    "osammansvetsade": "osammansvetsad",
    "osammansvetsades": "osammansvetsad",
    "osammansvetsads": "osammansvetsad",
    "osammansvetsat": "osammansvetsad",
    "osammansvetsats": "osammansvetsad",
    "osammantryckta": "osammantryckt",
    "osammantrycktas": "osammantryckt",
    "osammantryckte": "osammantryckt",
    "osammantrycktes": "osammantryckt",
    "osammantryckts": "osammantryckt",
    "osammanträffade": "osammanträffad",
    "osammanträffades": "osammanträffad",
    "osammanträffads": "osammanträffad",
    "osammanträffat": "osammanträffad",
    "osammanträffats": "osammanträffad",
    "osammanvävde": "osammanvävd",
    "osammanvävdes": "osammanvävd",
    "osammanvävds": "osammanvävd",
    "osammanvävt": "osammanvävd",
    "osammanvävts": "osammanvävd",
    "osammanväxta": "osammanväxt",
    "osammanväxtas": "osammanväxt",
    "osammanväxte": "osammanväxt",
    "osammanväxtes": "osammanväxt",
    "osammanväxts": "osammanväxt",
    "osamordnade": "osamordnad",
    "osamordnades": "osamordnad",
    "osamordnads": "osamordnad",
    "osamordnat": "osamordnad",
    "osamordnats": "osamordnad",
    "osamplade": "osamplad",
    "osamplades": "osamplad",
    "osamplads": "osamplad",
    "osamplat": "osamplad",
    "osamplats": "osamplad",
    "osamsade": "osamsad",
    "osamsades": "osamsad",
    "osamsads": "osamsad",
    "osamsat": "osamsad",
    "osamsats": "osamsad",
    "osamtaxerade": "osamtaxerad",
    "osamtaxerades": "osamtaxerad",
    "osamtaxerads": "osamtaxerad",
    "osamtaxerat": "osamtaxerad",
    "osamtaxerats": "osamtaxerad",
    "osamtaxerbara": "osamtaxerbar",
    "osamtaxerbarare": "osamtaxerbar",
    "osamtaxerbarares": "osamtaxerbar",
    "osamtaxerbaras": "osamtaxerbar",
    "osamtaxerbarast": "osamtaxerbar",
    "osamtaxerbaraste": "osamtaxerbar",
    "osamtaxerbarastes": "osamtaxerbar",
    "osamtaxerbarasts": "osamtaxerbar",
    "osamtaxerbare": "osamtaxerbar",
    "osamtaxerbares": "osamtaxerbar",
    "osamtaxerbarheten": "osamtaxerbarhet",
    "osamtaxerbarhetens": "osamtaxerbarhet",
    "osamtaxerbarhets": "osamtaxerbarhet",
    "osamtaxerbars": "osamtaxerbar",
    "osamtaxerbart": "osamtaxerbar",
    "osamtaxerbarts": "osamtaxerbar",
    "osandade": "osandad",
    "osandades": "osandad",
    "osandads": "osandad",
    "osandat": "osandad",
    "osandats": "osandad",
    "osande": "osa",
    "osanden": "osande",
    "osandena": "osande",
    "osandenas": "osande",
    "osandens": "osande",
    "osandes": "osande",
    "osandet": "osande",
    "osandets": "osande",
    "osanerade": "osanerad",
    "osanerades": "osanerad",
    "osanerads": "osanerad",
    "osanerat": "osanerad",
    "osanerats": "osanerad",
    "osanerbara": "osanerbar",
    "osanerbarare": "osanerbar",
    "osanerbarares": "osanerbar",
    "osanerbaras": "osanerbar",
    "osanerbarast": "osanerbar",
    "osanerbaraste": "osanerbar",
    "osanerbarastes": "osanerbar",
    "osanerbarasts": "osanerbar",
    "osanerbare": "osanerbar",
    "osanerbares": "osanerbar",
    "osanerbarheten": "osanerbarhet",
    "osanerbarhetens": "osanerbarhet",
    "osanerbarhets": "osanerbarhet",
    "osanerbars": "osanerbar",
    "osanerbart": "osanerbar",
    "osanerbarts": "osanerbar",
    "osanforiserade": "osanforiserad",
    "osanforiserades": "osanforiserad",
    "osanforiserads": "osanforiserad",
    "osanforiserat": "osanforiserad",
    "osanforiserats": "osanforiserad",
    "osanforiserbara": "osanforiserbar",
    "osanforiserbarare": "osanforiserbar",
    "osanforiserbarares": "osanforiserbar",
    "osanforiserbaras": "osanforiserbar",
    "osanforiserbarast": "osanforiserbar",
    "osanforiserbaraste": "osanforiserbar",
    "osanforiserbarastes": "osanforiserbar",
    "osanforiserbarasts": "osanforiserbar",
    "osanforiserbare": "osanforiserbar",
    "osanforiserbares": "osanforiserbar",
    "osanforiserbarheten": "osanforiserbarhet",
    "osanforiserbarhetens": "osanforiserbarhet",
    "osanforiserbarhets": "osanforiserbarhet",
    "osanforiserbars": "osanforiserbar",
    "osanforiserbart": "osanforiserbar",
    "osanforiserbarts": "osanforiserbar",
    "osanktifierade": "osanktifierad",
    "osanktifierades": "osanktifierad",
    "osanktifierads": "osanktifierad",
    "osanktifierat": "osanktifierad",
    "osanktifierats": "osanktifierad",
    "osanktifierbara": "osanktifierbar",
    "osanktifierbarare": "osanktifierbar",
    "osanktifierbarares": "osanktifierbar",
    "osanktifierbaras": "osanktifierbar",
    "osanktifierbarast": "osanktifierbar",
    "osanktifierbaraste": "osanktifierbar",
    "osanktifierbarastes": "osanktifierbar",
    "osanktifierbarasts": "osanktifierbar",
    "osanktifierbare": "osanktifierbar",
    "osanktifierbares": "osanktifierbar",
    "osanktifierbarheten": "osanktifierbarhet",
    "osanktifierbarhetens": "osanktifierbarhet",
    "osanktifierbarhets": "osanktifierbarhet",
    "osanktifierbars": "osanktifierbar",
    "osanktifierbart": "osanktifierbar",
    "osanktifierbarts": "osanktifierbar",
    "osanktionerade": "osanktionerad",
    "osanktionerades": "osanktionerad",
    "osanktionerads": "osanktionerad",
    "osanktionerat": "osanktionerad",
    "osanktionerats": "osanktionerad",
    "osanktionerbara": "osanktionerbar",
    "osanktionerbarare": "osanktionerbar",
    "osanktionerbarares": "osanktionerbar",
    "osanktionerbaras": "osanktionerbar",
    "osanktionerbarast": "osanktionerbar",
    "osanktionerbaraste": "osanktionerbar",
    "osanktionerbarastes": "osanktionerbar",
    "osanktionerbarasts": "osanktionerbar",
    "osanktionerbare": "osanktionerbar",
    "osanktionerbares": "osanktionerbar",
    "osanktionerbarheten": "osanktionerbarhet",
    "osanktionerbarhetens": "osanktionerbarhet",
    "osanktionerbarhets": "osanktionerbarhet",
    "osanktionerbars": "osanktionerbar",
    "osanktionerbart": "osanktionerbar",
    "osanktionerbarts": "osanktionerbar",
    "osanna": "osann",
    "osannade": "osannad",
    "osannades": "osannad",
    "osannads": "osannad",
    "osannare": "osann",
    "osannares": "osann",
    "osannas": "osann",
    "osannast": "osann",
    "osannaste": "osann",
    "osannastes": "osann",
    "osannasts": "osann",
    "osannat": "osannad",
    "osannats": "osannad",
    "osanne": "osann",
    "osannes": "osann",
    "osannfärdiga": "osannfärdig",
    "osannfärdigare": "osannfärdig",
    "osannfärdigares": "osannfärdig",
    "osannfärdigas": "osannfärdig",
    "osannfärdigast": "osannfärdig",
    "osannfärdigaste": "osannfärdig",
    "osannfärdigastes": "osannfärdig",
    "osannfärdigasts": "osannfärdig",
    "osannfärdige": "osannfärdig",
    "osannfärdiges": "osannfärdig",
    "osannfärdigheten": "osannfärdighet",
    "osannfärdighetens": "osannfärdighet",
    "osannfärdighets": "osannfärdighet",
    "osannfärdigs": "osannfärdig",
    "osannfärdigt": "osannfärdig",
    "osannfärdigts": "osannfärdig",
    "osanningar": "osanning",
    "osanningarna": "osanning",
    "osanningarnas": "osanning",
    "osanningars": "osanning",
    "osanningen": "osanning",
    "osanningens": "osanning",
    "osannings": "osanning",
    "osannolika": "osannolik",
    "osannolikare": "osannolik",
    "osannolikares": "osannolik",
    "osannolikas": "osannolik",
    "osannolikast": "osannolik",
    "osannolikaste": "osannolik",
    "osannolikastes": "osannolik",
    "osannolikasts": "osannolik",
    "osannolike": "osannolik",
    "osannolikes": "osannolik",
    "osannolikheten": "osannolikhet",
    "osannolikhetens": "osannolikhet",
    "osannolikhets": "osannolikhet",
    "osannoliks": "osannolik",
    "osannolikt": "osannolik",
    "osannolikts": "osannolik",
    "osanns": "osann",
    "osant": "osann",
    "osants": "osann",
    "osaponifierade": "osaponifierad",
    "osaponifierades": "osaponifierad",
    "osaponifierads": "osaponifierad",
    "osaponifierat": "osaponifierad",
    "osaponifierats": "osaponifierad",
    "osaponifierbara": "osaponifierbar",
    "osaponifierbarare": "osaponifierbar",
    "osaponifierbarares": "osaponifierbar",
    "osaponifierbaras": "osaponifierbar",
    "osaponifierbarast": "osaponifierbar",
    "osaponifierbaraste": "osaponifierbar",
    "osaponifierbarastes": "osaponifierbar",
    "osaponifierbarasts": "osaponifierbar",
    "osaponifierbare": "osaponifierbar",
    "osaponifierbares": "osaponifierbar",
    "osaponifierbarheten": "osaponifierbarhet",
    "osaponifierbarhetens": "osaponifierbarhet",
    "osaponifierbarhets": "osaponifierbarhet",
    "osaponifierbars": "osaponifierbar",
    "osaponifierbart": "osaponifierbar",
    "osaponifierbarts": "osaponifierbar",
    "osar": "osa",
    "osargade": "osargad",
    "osargades": "osargad",
    "osargads": "osargad",
    "osargat": "osargad",
    "osargats": "osargad",
    "osas": "osa",
    "osat": "osa",
    "osatinerade": "osatinerad",
    "osatinerades": "osatinerad",
    "osatinerads": "osatinerad",
    "osatinerat": "osatinerad",
    "osatinerats": "osatinerad",
    "osatinerbara": "osatinerbar",
    "osatinerbarare": "osatinerbar",
    "osatinerbarares": "osatinerbar",
    "osatinerbaras": "osatinerbar",
    "osatinerbarast": "osatinerbar",
    "osatinerbaraste": "osatinerbar",
    "osatinerbarastes": "osatinerbar",
    "osatinerbarasts": "osatinerbar",
    "osatinerbare": "osatinerbar",
    "osatinerbares": "osatinerbar",
    "osatinerbarheten": "osatinerbarhet",
    "osatinerbarhetens": "osatinerbarhet",
    "osatinerbarhets": "osatinerbarhet",
    "osatinerbars": "osatinerbar",
    "osatinerbart": "osatinerbar",
    "osatinerbarts": "osatinerbar",
    "osatisfierade": "osatisfierad",
    "osatisfierades": "osatisfierad",
    "osatisfierads": "osatisfierad",
    "osatisfierat": "osatisfierad",
    "osatisfierats": "osatisfierad",
    "osatisfierbara": "osatisfierbar",
    "osatisfierbarare": "osatisfierbar",
    "osatisfierbarares": "osatisfierbar",
    "osatisfierbaras": "osatisfierbar",
    "osatisfierbarast": "osatisfierbar",
    "osatisfierbaraste": "osatisfierbar",
    "osatisfierbarastes": "osatisfierbar",
    "osatisfierbarasts": "osatisfierbar",
    "osatisfierbare": "osatisfierbar",
    "osatisfierbares": "osatisfierbar",
    "osatisfierbarheten": "osatisfierbarhet",
    "osatisfierbarhetens": "osatisfierbarhet",
    "osatisfierbarhets": "osatisfierbarhet",
    "osatisfierbars": "osatisfierbar",
    "osatisfierbart": "osatisfierbar",
    "osatisfierbarts": "osatisfierbar",
    "osats": "osa",
    "osatsade": "osatsad",
    "osatsades": "osatsad",
    "osatsads": "osatsad",
    "osatsat": "osatsad",
    "osatsats": "osatsad",
    "osaturerade": "osaturerad",
    "osaturerades": "osaturerad",
    "osaturerads": "osaturerad",
    "osaturerat": "osaturerad",
    "osaturerats": "osaturerad",
    "osaturerbara": "osaturerbar",
    "osaturerbarare": "osaturerbar",
    "osaturerbarares": "osaturerbar",
    "osaturerbaras": "osaturerbar",
    "osaturerbarast": "osaturerbar",
    "osaturerbaraste": "osaturerbar",
    "osaturerbarastes": "osaturerbar",
    "osaturerbarasts": "osaturerbar",
    "osaturerbare": "osaturerbar",
    "osaturerbares": "osaturerbar",
    "osaturerbarheten": "osaturerbarhet",
    "osaturerbarhetens": "osaturerbarhet",
    "osaturerbarhets": "osaturerbarhet",
    "osaturerbars": "osaturerbar",
    "osaturerbart": "osaturerbar",
    "osaturerbarts": "osaturerbar",
    "osauterade": "osauterad",
    "osauterades": "osauterad",
    "osauterads": "osauterad",
    "osauterat": "osauterad",
    "osauterats": "osauterad",
    "osauterbara": "osauterbar",
    "osauterbarare": "osauterbar",
    "osauterbarares": "osauterbar",
    "osauterbaras": "osauterbar",
    "osauterbarast": "osauterbar",
    "osauterbaraste": "osauterbar",
    "osauterbarastes": "osauterbar",
    "osauterbarasts": "osauterbar",
    "osauterbare": "osauterbar",
    "osauterbares": "osauterbar",
    "osauterbarheten": "osauterbarhet",
    "osauterbarhetens": "osauterbarhet",
    "osauterbarhets": "osauterbarhet",
    "osauterbars": "osauterbar",
    "osauterbart": "osauterbar",
    "osauterbarts": "osauterbar",
    "osauverade": "osauverad",
    "osauverades": "osauverad",
    "osauverads": "osauverad",
    "osauverat": "osauverad",
    "osauverats": "osauverad",
    "osauverbara": "osauverbar",
    "osauverbarare": "osauverbar",
    "osauverbarares": "osauverbar",
    "osauverbaras": "osauverbar",
    "osauverbarast": "osauverbar",
    "osauverbaraste": "osauverbar",
    "osauverbarastes": "osauverbar",
    "osauverbarasts": "osauverbar",
    "osauverbare": "osauverbar",
    "osauverbares": "osauverbar",
    "osauverbarheten": "osauverbarhet",
    "osauverbarhetens": "osauverbarhet",
    "osauverbarhets": "osauverbarhet",
    "osauverbars": "osauverbar",
    "osauverbart": "osauverbar",
    "osauverbarts": "osauverbar",
    "osaxade": "osaxad",
    "osaxades": "osaxad",
    "osaxads": "osaxad",
    "osaxat": "osaxad",
    "osaxats": "osaxad",
    "oscannade": "oscannad",
    "oscannades": "oscannad",
    "oscannads": "oscannad",
    "oscannat": "oscannad",
    "oscannats": "oscannad",
    "oschablonerade": "oschablonerad",
    "oschablonerades": "oschablonerad",
    "oschablonerads": "oschablonerad",
    "oschablonerat": "oschablonerad",
    "oschablonerats": "oschablonerad",
    "oschablonerbara": "oschablonerbar",
    "oschablonerbarare": "oschablonerbar",
    "oschablonerbarares": "oschablonerbar",
    "oschablonerbaras": "oschablonerbar",
    "oschablonerbarast": "oschablonerbar",
    "oschablonerbaraste": "oschablonerbar",
    "oschablonerbarastes": "oschablonerbar",
    "oschablonerbarasts": "oschablonerbar",
    "oschablonerbare": "oschablonerbar",
    "oschablonerbares": "oschablonerbar",
    "oschablonerbarheten": "oschablonerbarhet",
    "oschablonerbarhetens": "oschablonerbarhet",
    "oschablonerbarhets": "oschablonerbarhet",
    "oschablonerbars": "oschablonerbar",
    "oschablonerbart": "oschablonerbar",
    "oschablonerbarts": "oschablonerbar",
    "oschabloniserade": "oschabloniserad",
    "oschabloniserades": "oschabloniserad",
    "oschabloniserads": "oschabloniserad",
    "oschabloniserat": "oschabloniserad",
    "oschabloniserats": "oschabloniserad",
    "oschabloniserbara": "oschabloniserbar",
    "oschabloniserbarare": "oschabloniserbar",
    "oschabloniserbarares": "oschabloniserbar",
    "oschabloniserbaras": "oschabloniserbar",
    "oschabloniserbarast": "oschabloniserbar",
    "oschabloniserbaraste": "oschabloniserbar",
    "oschabloniserbarastes": "oschabloniserbar",
    "oschabloniserbarasts": "oschabloniserbar",
    "oschabloniserbare": "oschabloniserbar",
    "oschabloniserbares": "oschabloniserbar",
    "oschabloniserbarheten": "oschabloniserbarhet",
    "oschabloniserbarhetens": "oschabloniserbarhet",
    "oschabloniserbarhets": "oschabloniserbarhet",
    "oschabloniserbars": "oschabloniserbar",
    "oschabloniserbart": "oschabloniserbar",
    "oschabloniserbarts": "oschabloniserbar",
    "oschackade": "oschackad",
    "oschackades": "oschackad",
    "oschackads": "oschackad",
    "oschackat": "oschackad",
    "oschackats": "oschackad",
    "oschacklade": "oschacklad",
    "oschacklades": "oschacklad",
    "oschacklads": "oschacklad",
    "oschacklat": "oschacklad",
    "oschacklats": "oschacklad",
    "oschaktade": "oschaktad",
    "oschaktades": "oschaktad",
    "oschaktads": "oschaktad",
    "oschaktat": "oschaktad",
    "oschaktats": "oschaktad",
    "oschamponerade": "oschamponerad",
    "oschamponerades": "oschamponerad",
    "oschamponerads": "oschamponerad",
    "oschamponerat": "oschamponerad",
    "oschamponerats": "oschamponerad",
    "oschamponerbara": "oschamponerbar",
    "oschamponerbarare": "oschamponerbar",
    "oschamponerbarares": "oschamponerbar",
    "oschamponerbaras": "oschamponerbar",
    "oschamponerbarast": "oschamponerbar",
    "oschamponerbaraste": "oschamponerbar",
    "oschamponerbarastes": "oschamponerbar",
    "oschamponerbarasts": "oschamponerbar",
    "oschamponerbare": "oschamponerbar",
    "oschamponerbares": "oschamponerbar",
    "oschamponerbarheten": "oschamponerbarhet",
    "oschamponerbarhetens": "oschamponerbarhet",
    "oschamponerbarhets": "oschamponerbarhet",
    "oschamponerbars": "oschamponerbar",
    "oschamponerbart": "oschamponerbar",
    "oschamponerbarts": "oschamponerbar",
    "oschanghajade": "oschanghajad",
    "oschanghajades": "oschanghajad",
    "oschanghajads": "oschanghajad",
    "oschanghajat": "oschanghajad",
    "oschanghajats": "oschanghajad",
    "oschappade": "oschappad",
    "oschappades": "oschappad",
    "oschappads": "oschappad",
    "oschappat": "oschappad",
    "oschappats": "oschappad",
    "oschasade": "oschasad",
    "oschasades": "oschasad",
    "oschasads": "oschasad",
    "oschasat": "oschasad",
    "oschasats": "oschasad",
    "oschatterade": "oschatterad",
    "oschatterades": "oschatterad",
    "oschatterads": "oschatterad",
    "oschatterat": "oschatterad",
    "oschatterats": "oschatterad",
    "oschatterbara": "oschatterbar",
    "oschatterbarare": "oschatterbar",
    "oschatterbarares": "oschatterbar",
    "oschatterbaras": "oschatterbar",
    "oschatterbarast": "oschatterbar",
    "oschatterbaraste": "oschatterbar",
    "oschatterbarastes": "oschatterbar",
    "oschatterbarasts": "oschatterbar",
    "oschatterbare": "oschatterbar",
    "oschatterbares": "oschatterbar",
    "oschatterbarheten": "oschatterbarhet",
    "oschatterbarhetens": "oschatterbarhet",
    "oschatterbarhets": "oschatterbarhet",
    "oschatterbars": "oschatterbar",
    "oschatterbart": "oschatterbar",
    "oschatterbarts": "oschatterbar",
    "oschematiserade": "oschematiserad",
    "oschematiserades": "oschematiserad",
    "oschematiserads": "oschematiserad",
    "oschematiserat": "oschematiserad",
    "oschematiserats": "oschematiserad",
    "oschematiserbara": "oschematiserbar",
    "oschematiserbarare": "oschematiserbar",
    "oschematiserbarares": "oschematiserbar",
    "oschematiserbaras": "oschematiserbar",
    "oschematiserbarast": "oschematiserbar",
    "oschematiserbaraste": "oschematiserbar",
    "oschematiserbarastes": "oschematiserbar",
    "oschematiserbarasts": "oschematiserbar",
    "oschematiserbare": "oschematiserbar",
    "oschematiserbares": "oschematiserbar",
    "oschematiserbarheten": "oschematiserbarhet",
    "oschematiserbarhetens": "oschematiserbarhet",
    "oschematiserbarhets": "oschematiserbarhet",
    "oschematiserbars": "oschematiserbar",
    "oschematiserbart": "oschematiserbar",
    "oschematiserbarts": "oschematiserbar",
    "oschveifade": "oschveifad",
    "oschveifades": "oschveifad",
    "oschveifads": "oschveifad",
    "oschveifat": "oschveifad",
    "oschveifats": "oschveifad",
    "oscillationen": "oscillation",
    "oscillationens": "oscillation",
    "oscillationer": "oscillation",
    "oscillationerna": "oscillation",
    "oscillationernas": "oscillation",
    "oscillationers": "oscillation",
    "oscillations": "oscillation",
    "oscillatorer": "oscillator",
    "oscillatorerna": "oscillator",
    "oscillatorernas": "oscillator",
    "oscillatorers": "oscillator",
    "oscillatorn": "oscillator",
    "oscillatorns": "oscillator",
    "oscillators": "oscillator",
    "oscillerade": "oscillera",
    "oscillerades": "oscillera",
    "oscillerande": "oscillera",
    "oscilleranden": "oscillerande",
    "oscillerandena": "oscillerande",
    "oscillerandenas": "oscillerande",
    "oscillerandens": "oscillerande",
    "oscillerandes": "oscillerande",
    "oscillerandet": "oscillerande",
    "oscillerandets": "oscillerande",
    "oscillerar": "oscillera",
    "oscilleras": "oscillera",
    "oscillerat": "oscillera",
    "oscillerats": "oscillera",
    "oscilleringar": "oscillering",
    "oscilleringarna": "oscillering",
    "oscilleringarnas": "oscillering",
    "oscilleringars": "oscillering",
    "oscilleringen": "oscillering",
    "oscilleringens": "oscillering",
    "oscillerings": "oscillering",
    "oscillografen": "oscillograf",
    "oscillografens": "oscillograf",
    "oscillografer": "oscillograf",
    "oscillograferna": "oscillograf",
    "oscillografernas": "oscillograf",
    "oscillografers": "oscillograf",
    "oscillografs": "oscillograf",
    "oscillogrammen": "oscillogram",
    "oscillogrammens": "oscillogram",
    "oscillogrammet": "oscillogram",
    "oscillogrammets": "oscillogram",
    "oscillograms": "oscillogram",
    "oscilloskopen": "oscilloskop",
    "oscilloskopens": "oscilloskop",
    "oscilloskopet": "oscilloskop",
    "oscilloskopets": "oscilloskop",
    "oscilloskops": "oscilloskop",
    "oseden": "osed",
    "osedens": "osed",
    "oseder": "osed",
    "osederna": "osed",
    "osedernas": "osed",
    "oseders": "osed",
    "osedimenterade": "osedimenterad",
    "osedimenterades": "osedimenterad",
    "osedimenterads": "osedimenterad",
    "osedimenterat": "osedimenterad",
    "osedimenterats": "osedimenterad",
    "osedimenterbara": "osedimenterbar",
    "osedimenterbarare": "osedimenterbar",
    "osedimenterbarares": "osedimenterbar",
    "osedimenterbaras": "osedimenterbar",
    "osedimenterbarast": "osedimenterbar",
    "osedimenterbaraste": "osedimenterbar",
    "osedimenterbarastes": "osedimenterbar",
    "osedimenterbarasts": "osedimenterbar",
    "osedimenterbare": "osedimenterbar",
    "osedimenterbares": "osedimenterbar",
    "osedimenterbarheten": "osedimenterbarhet",
    "osedimenterbarhetens": "osedimenterbarhet",
    "osedimenterbarhets": "osedimenterbarhet",
    "osedimenterbars": "osedimenterbar",
    "osedimenterbart": "osedimenterbar",
    "osedimenterbarts": "osedimenterbar",
    "osedliga": "osedlig",
    "osedligare": "osedlig",
    "osedligares": "osedlig",
    "osedligas": "osedlig",
    "osedligast": "osedlig",
    "osedligaste": "osedlig",
    "osedligastes": "osedlig",
    "osedligasts": "osedlig",
    "osedlige": "osedlig",
    "osedliges": "osedlig",
    "osedligheten": "osedlighet",
    "osedlighetens": "osedlighet",
    "osedligheter": "osedlighet",
    "osedligheterna": "osedlighet",
    "osedligheternas": "osedlighet",
    "osedligheters": "osedlighet",
    "osedlighets": "osedlighet",
    "osedligs": "osedlig",
    "osedligt": "osedlig",
    "osedligts": "osedlig",
    "oseds": "osed",
    "osedvanliga": "osedvanlig",
    "osedvanligare": "osedvanlig",
    "osedvanligares": "osedvanlig",
    "osedvanligas": "osedvanlig",
    "osedvanligast": "osedvanlig",
    "osedvanligaste": "osedvanlig",
    "osedvanligastes": "osedvanlig",
    "osedvanligasts": "osedvanlig",
    "osedvanlige": "osedvanlig",
    "osedvanliges": "osedvanlig",
    "osedvanligheten": "osedvanlighet",
    "osedvanlighetens": "osedvanlighet",
    "osedvanlighets": "osedvanlighet",
    "osedvanligs": "osedvanlig",
    "osedvanligt": "osedvanlig",
    "osedvanligts": "osedvanlig",
    "oseedade": "oseedad",
    "oseedades": "oseedad",
    "oseedads": "oseedad",
    "oseedat": "oseedad",
    "oseedats": "oseedad",
    "oseglade": "oseglad",
    "oseglades": "oseglad",
    "oseglads": "oseglad",
    "oseglat": "oseglad",
    "oseglats": "oseglad",
    "osegmenterade": "osegmenterad",
    "osegmenterades": "osegmenterad",
    "osegmenterads": "osegmenterad",
    "osegmenterat": "osegmenterad",
    "osegmenterats": "osegmenterad",
    "osegmenterbara": "osegmenterbar",
    "osegmenterbarare": "osegmenterbar",
    "osegmenterbarares": "osegmenterbar",
    "osegmenterbaras": "osegmenterbar",
    "osegmenterbarast": "osegmenterbar",
    "osegmenterbaraste": "osegmenterbar",
    "osegmenterbarastes": "osegmenterbar",
    "osegmenterbarasts": "osegmenterbar",
    "osegmenterbare": "osegmenterbar",
    "osegmenterbares": "osegmenterbar",
    "osegmenterbarheten": "osegmenterbarhet",
    "osegmenterbarhetens": "osegmenterbarhet",
    "osegmenterbarhets": "osegmenterbarhet",
    "osegmenterbars": "osegmenterbar",
    "osegmenterbart": "osegmenterbar",
    "osegmenterbarts": "osegmenterbar",
    "osegrade": "osegrad",
    "osegrades": "osegrad",
    "osegrads": "osegrad",
    "osegrat": "osegrad",
    "osegrats": "osegrad",
    "osegregerade": "osegregerad",
    "osegregerades": "osegregerad",
    "osegregerads": "osegregerad",
    "osegregerat": "osegregerad",
    "osegregerats": "osegregerad",
    "osegregerbara": "osegregerbar",
    "osegregerbarare": "osegregerbar",
    "osegregerbarares": "osegregerbar",
    "osegregerbaras": "osegregerbar",
    "osegregerbarast": "osegregerbar",
    "osegregerbaraste": "osegregerbar",
    "osegregerbarastes": "osegregerbar",
    "osegregerbarasts": "osegregerbar",
    "osegregerbare": "osegregerbar",
    "osegregerbares": "osegregerbar",
    "osegregerbarheten": "osegregerbarhet",
    "osegregerbarhetens": "osegregerbarhet",
    "osegregerbarhets": "osegregerbarhet",
    "osegregerbars": "osegregerbar",
    "osegregerbart": "osegregerbar",
    "osegregerbarts": "osegregerbar",
    "osejsade": "osejsad",
    "osejsades": "osejsad",
    "osejsads": "osejsad",
    "osejsat": "osejsad",
    "osejsats": "osejsad",
    "osekonderade": "osekonderad",
    "osekonderades": "osekonderad",
    "osekonderads": "osekonderad",
    "osekonderat": "osekonderad",
    "osekonderats": "osekonderad",
    "osekonderbara": "osekonderbar",
    "osekonderbarare": "osekonderbar",
    "osekonderbarares": "osekonderbar",
    "osekonderbaras": "osekonderbar",
    "osekonderbarast": "osekonderbar",
    "osekonderbaraste": "osekonderbar",
    "osekonderbarastes": "osekonderbar",
    "osekonderbarasts": "osekonderbar",
    "osekonderbare": "osekonderbar",
    "osekonderbares": "osekonderbar",
    "osekonderbarheten": "osekonderbarhet",
    "osekonderbarhetens": "osekonderbarhet",
    "osekonderbarhets": "osekonderbarhet",
    "osekonderbars": "osekonderbar",
    "osekonderbart": "osekonderbar",
    "osekonderbarts": "osekonderbar",
    "osekulariserade": "osekulariserad",
    "osekulariserades": "osekulariserad",
    "osekulariserads": "osekulariserad",
    "osekulariserat": "osekulariserad",
    "osekulariserats": "osekulariserad",
    "osekulariserbara": "osekulariserbar",
    "osekulariserbarare": "osekulariserbar",
    "osekulariserbarares": "osekulariserbar",
    "osekulariserbaras": "osekulariserbar",
    "osekulariserbarast": "osekulariserbar",
    "osekulariserbaraste": "osekulariserbar",
    "osekulariserbarastes": "osekulariserbar",
    "osekulariserbarasts": "osekulariserbar",
    "osekulariserbare": "osekulariserbar",
    "osekulariserbares": "osekulariserbar",
    "osekulariserbarheten": "osekulariserbarhet",
    "osekulariserbarhetens": "osekulariserbarhet",
    "osekulariserbarhets": "osekulariserbarhet",
    "osekulariserbars": "osekulariserbar",
    "osekulariserbart": "osekulariserbar",
    "osekulariserbarts": "osekulariserbar",
    "osekunderade": "osekunderad",
    "osekunderades": "osekunderad",
    "osekunderads": "osekunderad",
    "osekunderat": "osekunderad",
    "osekunderats": "osekunderad",
    "osekunderbara": "osekunderbar",
    "osekunderbarare": "osekunderbar",
    "osekunderbarares": "osekunderbar",
    "osekunderbaras": "osekunderbar",
    "osekunderbarast": "osekunderbar",
    "osekunderbaraste": "osekunderbar",
    "osekunderbarastes": "osekunderbar",
    "osekunderbarasts": "osekunderbar",
    "osekunderbare": "osekunderbar",
    "osekunderbares": "osekunderbar",
    "osekunderbarheten": "osekunderbarhet",
    "osekunderbarhetens": "osekunderbarhet",
    "osekunderbarhets": "osekunderbarhet",
    "osekunderbars": "osekunderbar",
    "osekunderbart": "osekunderbar",
    "osekunderbarts": "osekunderbar",
    "osekvestrerade": "osekvestrerad",
    "osekvestrerades": "osekvestrerad",
    "osekvestrerads": "osekvestrerad",
    "osekvestrerat": "osekvestrerad",
    "osekvestrerats": "osekvestrerad",
    "osekvestrerbara": "osekvestrerbar",
    "osekvestrerbarare": "osekvestrerbar",
    "osekvestrerbarares": "osekvestrerbar",
    "osekvestrerbaras": "osekvestrerbar",
    "osekvestrerbarast": "osekvestrerbar",
    "osekvestrerbaraste": "osekvestrerbar",
    "osekvestrerbarastes": "osekvestrerbar",
    "osekvestrerbarasts": "osekvestrerbar",
    "osekvestrerbare": "osekvestrerbar",
    "osekvestrerbares": "osekvestrerbar",
    "osekvestrerbarheten": "osekvestrerbarhet",
    "osekvestrerbarhetens": "osekvestrerbarhet",
    "osekvestrerbarhets": "osekvestrerbarhet",
    "osekvestrerbars": "osekvestrerbar",
    "osekvestrerbart": "osekvestrerbar",
    "osekvestrerbarts": "osekvestrerbar",
    "oselade": "oselad",
    "oselades": "oselad",
    "oselads": "oselad",
    "oselat": "oselad",
    "oselats": "oselad",
    "oselekterade": "oselekterad",
    "oselekterades": "oselekterad",
    "oselekterads": "oselekterad",
    "oselekterat": "oselekterad",
    "oselekterats": "oselekterad",
    "oselekterbara": "oselekterbar",
    "oselekterbarare": "oselekterbar",
    "oselekterbarares": "oselekterbar",
    "oselekterbaras": "oselekterbar",
    "oselekterbarast": "oselekterbar",
    "oselekterbaraste": "oselekterbar",
    "oselekterbarastes": "oselekterbar",
    "oselekterbarasts": "oselekterbar",
    "oselekterbare": "oselekterbar",
    "oselekterbares": "oselekterbar",
    "oselekterbarheten": "oselekterbarhet",
    "oselekterbarhetens": "oselekterbarhet",
    "oselekterbarhets": "oselekterbarhet",
    "oselekterbars": "oselekterbar",
    "oselekterbart": "oselekterbar",
    "oselekterbarts": "oselekterbar",
    "osemaforerade": "osemaforerad",
    "osemaforerades": "osemaforerad",
    "osemaforerads": "osemaforerad",
    "osemaforerat": "osemaforerad",
    "osemaforerats": "osemaforerad",
    "osemaforerbara": "osemaforerbar",
    "osemaforerbarare": "osemaforerbar",
    "osemaforerbarares": "osemaforerbar",
    "osemaforerbaras": "osemaforerbar",
    "osemaforerbarast": "osemaforerbar",
    "osemaforerbaraste": "osemaforerbar",
    "osemaforerbarastes": "osemaforerbar",
    "osemaforerbarasts": "osemaforerbar",
    "osemaforerbare": "osemaforerbar",
    "osemaforerbares": "osemaforerbar",
    "osemaforerbarheten": "osemaforerbarhet",
    "osemaforerbarhetens": "osemaforerbarhet",
    "osemaforerbarhets": "osemaforerbarhet",
    "osemaforerbars": "osemaforerbar",
    "osemaforerbart": "osemaforerbar",
    "osemaforerbarts": "osemaforerbar",
    "oseminerade": "oseminerad",
    "oseminerades": "oseminerad",
    "oseminerads": "oseminerad",
    "oseminerat": "oseminerad",
    "oseminerats": "oseminerad",
    "oseminerbara": "oseminerbar",
    "oseminerbarare": "oseminerbar",
    "oseminerbarares": "oseminerbar",
    "oseminerbaras": "oseminerbar",
    "oseminerbarast": "oseminerbar",
    "oseminerbaraste": "oseminerbar",
    "oseminerbarastes": "oseminerbar",
    "oseminerbarasts": "oseminerbar",
    "oseminerbare": "oseminerbar",
    "oseminerbares": "oseminerbar",
    "oseminerbarheten": "oseminerbarhet",
    "oseminerbarhetens": "oseminerbarhet",
    "oseminerbarhets": "oseminerbarhet",
    "oseminerbars": "oseminerbar",
    "oseminerbart": "oseminerbar",
    "oseminerbarts": "oseminerbar",
    "osen": "os",
    "osens": "os",
    "osensibiliserade": "osensibiliserad",
    "osensibiliserades": "osensibiliserad",
    "osensibiliserads": "osensibiliserad",
    "osensibiliserat": "osensibiliserad",
    "osensibiliserats": "osensibiliserad",
    "osensibiliserbara": "osensibiliserbar",
    "osensibiliserbarare": "osensibiliserbar",
    "osensibiliserbarares": "osensibiliserbar",
    "osensibiliserbaras": "osensibiliserbar",
    "osensibiliserbarast": "osensibiliserbar",
    "osensibiliserbaraste": "osensibiliserbar",
    "osensibiliserbarastes": "osensibiliserbar",
    "osensibiliserbarasts": "osensibiliserbar",
    "osensibiliserbare": "osensibiliserbar",
    "osensibiliserbares": "osensibiliserbar",
    "osensibiliserbarheten": "osensibiliserbarhet",
    "osensibiliserbarhetens": "osensibiliserbarhet",
    "osensibiliserbarhets": "osensibiliserbarhet",
    "osensibiliserbars": "osensibiliserbar",
    "osensibiliserbart": "osensibiliserbar",
    "osensibiliserbarts": "osensibiliserbar",
    "osenterade": "osenterad",
    "osenterades": "osenterad",
    "osenterads": "osenterad",
    "osenterat": "osenterad",
    "osenterats": "osenterad",
    "osenterbara": "osenterbar",
    "osenterbarare": "osenterbar",
    "osenterbarares": "osenterbar",
    "osenterbaras": "osenterbar",
    "osenterbarast": "osenterbar",
    "osenterbaraste": "osenterbar",
    "osenterbarastes": "osenterbar",
    "osenterbarasts": "osenterbar",
    "osenterbare": "osenterbar",
    "osenterbares": "osenterbar",
    "osenterbarheten": "osenterbarhet",
    "osenterbarhetens": "osenterbarhet",
    "osenterbarhets": "osenterbarhet",
    "osenterbars": "osenterbar",
    "osenterbart": "osenterbar",
    "osenterbarts": "osenterbar",
    "osentimentala": "osentimental",
    "osentimentalare": "osentimental",
    "osentimentalares": "osentimental",
    "osentimentalas": "osentimental",
    "osentimentalast": "osentimental",
    "osentimentalaste": "osentimental",
    "osentimentalastes": "osentimental",
    "osentimentalasts": "osentimental",
    "osentimentale": "osentimental",
    "osentimentales": "osentimental",
    "osentimentals": "osentimental",
    "osentimentalt": "osentimental",
    "osentimentalts": "osentimental",
    "oseparerade": "oseparerad",
    "oseparerades": "oseparerad",
    "oseparerads": "oseparerad",
    "oseparerat": "oseparerad",
    "oseparerats": "oseparerad",
    "oseparerbara": "oseparerbar",
    "oseparerbarare": "oseparerbar",
    "oseparerbarares": "oseparerbar",
    "oseparerbaras": "oseparerbar",
    "oseparerbarast": "oseparerbar",
    "oseparerbaraste": "oseparerbar",
    "oseparerbarastes": "oseparerbar",
    "oseparerbarasts": "oseparerbar",
    "oseparerbare": "oseparerbar",
    "oseparerbares": "oseparerbar",
    "oseparerbarheten": "oseparerbarhet",
    "oseparerbarhetens": "oseparerbarhet",
    "oseparerbarhets": "oseparerbarhet",
    "oseparerbars": "oseparerbar",
    "oseparerbart": "oseparerbar",
    "oseparerbarts": "oseparerbar",
    "oseriösa": "oseriös",
    "oseriösare": "oseriös",
    "oseriösares": "oseriös",
    "oseriösas": "oseriös",
    "oseriösast": "oseriös",
    "oseriösaste": "oseriös",
    "oseriösastes": "oseriös",
    "oseriösasts": "oseriös",
    "oseriöse": "oseriös",
    "oseriöses": "oseriös",
    "oseriöst": "oseriös",
    "oseriösts": "oseriös",
    "oservade": "oservad",
    "oservades": "oservad",
    "oservads": "oservad",
    "oservat": "oservad",
    "oservats": "oservad",
    "oserverade": "oserverad",
    "oserverades": "oserverad",
    "oserverads": "oserverad",
    "oserverat": "oserverad",
    "oserverats": "oserverad",
    "oserverbara": "oserverbar",
    "oserverbarare": "oserverbar",
    "oserverbarares": "oserverbar",
    "oserverbaras": "oserverbar",
    "oserverbarast": "oserverbar",
    "oserverbaraste": "oserverbar",
    "oserverbarastes": "oserverbar",
    "oserverbarasts": "oserverbar",
    "oserverbare": "oserverbar",
    "oserverbares": "oserverbar",
    "oserverbarheten": "oserverbarhet",
    "oserverbarhetens": "oserverbarhet",
    "oserverbarhets": "oserverbarhet",
    "oserverbars": "oserverbar",
    "oserverbart": "oserverbar",
    "oserverbarts": "oserverbar",
    "oset": "os",
    "osets": "os",
    "osexualiserade": "osexualiserad",
    "osexualiserades": "osexualiserad",
    "osexualiserads": "osexualiserad",
    "osexualiserat": "osexualiserad",
    "osexualiserats": "osexualiserad",
    "osexualiserbara": "osexualiserbar",
    "osexualiserbarare": "osexualiserbar",
    "osexualiserbarares": "osexualiserbar",
    "osexualiserbaras": "osexualiserbar",
    "osexualiserbarast": "osexualiserbar",
    "osexualiserbaraste": "osexualiserbar",
    "osexualiserbarastes": "osexualiserbar",
    "osexualiserbarasts": "osexualiserbar",
    "osexualiserbare": "osexualiserbar",
    "osexualiserbares": "osexualiserbar",
    "osexualiserbarheten": "osexualiserbarhet",
    "osexualiserbarhetens": "osexualiserbarhet",
    "osexualiserbarhets": "osexualiserbarhet",
    "osexualiserbars": "osexualiserbar",
    "osexualiserbart": "osexualiserbar",
    "osexualiserbarts": "osexualiserbar",
    "oshamponerade": "oshamponerad",
    "oshamponerades": "oshamponerad",
    "oshamponerads": "oshamponerad",
    "oshamponerat": "oshamponerad",
    "oshamponerats": "oshamponerad",
    "oshamponerbara": "oshamponerbar",
    "oshamponerbarare": "oshamponerbar",
    "oshamponerbarares": "oshamponerbar",
    "oshamponerbaras": "oshamponerbar",
    "oshamponerbarast": "oshamponerbar",
    "oshamponerbaraste": "oshamponerbar",
    "oshamponerbarastes": "oshamponerbar",
    "oshamponerbarasts": "oshamponerbar",
    "oshamponerbare": "oshamponerbar",
    "oshamponerbares": "oshamponerbar",
    "oshamponerbarheten": "oshamponerbarhet",
    "oshamponerbarhetens": "oshamponerbarhet",
    "oshamponerbarhets": "oshamponerbarhet",
    "oshamponerbars": "oshamponerbar",
    "oshamponerbart": "oshamponerbar",
    "oshamponerbarts": "oshamponerbar",
    "oshanghajade": "oshanghajad",
    "oshanghajades": "oshanghajad",
    "oshanghajads": "oshanghajad",
    "oshanghajat": "oshanghajad",
    "oshanghajats": "oshanghajad",
    "oshinglade": "oshinglad",
    "oshinglades": "oshinglad",
    "oshinglads": "oshinglad",
    "oshinglat": "oshinglad",
    "oshinglats": "oshinglad",
    "oshortade": "oshortad",
    "oshortades": "oshortad",
    "oshortads": "oshortad",
    "oshortat": "oshortad",
    "oshortats": "oshortad",
    "oshuntade": "oshuntad",
    "oshuntades": "oshuntad",
    "oshuntads": "oshuntad",
    "oshuntat": "oshuntad",
    "oshuntats": "oshuntad",
    "osickade": "osickad",
    "osickades": "osickad",
    "osickads": "osickad",
    "osickat": "osickad",
    "osickats": "osickad",
    "osicklade": "osicklad",
    "osicklades": "osicklad",
    "osicklads": "osicklad",
    "osicklat": "osicklad",
    "osicklats": "osicklad",
    "osicksackade": "osicksackad",
    "osicksackades": "osicksackad",
    "osicksackads": "osicksackad",
    "osicksackat": "osicksackad",
    "osicksackats": "osicksackad",
    "osigillerade": "osigillerad",
    "osigillerades": "osigillerad",
    "osigillerads": "osigillerad",
    "osigillerat": "osigillerad",
    "osigillerats": "osigillerad",
    "osigillerbara": "osigillerbar",
    "osigillerbarare": "osigillerbar",
    "osigillerbarares": "osigillerbar",
    "osigillerbaras": "osigillerbar",
    "osigillerbarast": "osigillerbar",
    "osigillerbaraste": "osigillerbar",
    "osigillerbarastes": "osigillerbar",
    "osigillerbarasts": "osigillerbar",
    "osigillerbare": "osigillerbar",
    "osigillerbares": "osigillerbar",
    "osigillerbarheten": "osigillerbarhet",
    "osigillerbarhetens": "osigillerbarhet",
    "osigillerbarhets": "osigillerbarhet",
    "osigillerbars": "osigillerbar",
    "osigillerbart": "osigillerbar",
    "osigillerbarts": "osigillerbar",
    "osignade": "osignad",
    "osignades": "osignad",
    "osignads": "osignad",
    "osignalerade": "osignalerad",
    "osignalerades": "osignalerad",
    "osignalerads": "osignalerad",
    "osignalerat": "osignalerad",
    "osignalerats": "osignalerad",
    "osignalerbara": "osignalerbar",
    "osignalerbarare": "osignalerbar",
    "osignalerbarares": "osignalerbar",
    "osignalerbaras": "osignalerbar",
    "osignalerbarast": "osignalerbar",
    "osignalerbaraste": "osignalerbar",
    "osignalerbarastes": "osignalerbar",
    "osignalerbarasts": "osignalerbar",
    "osignalerbare": "osignalerbar",
    "osignalerbares": "osignalerbar",
    "osignalerbarheten": "osignalerbarhet",
    "osignalerbarhetens": "osignalerbarhet",
    "osignalerbarhets": "osignalerbarhet",
    "osignalerbars": "osignalerbar",
    "osignalerbart": "osignalerbar",
    "osignalerbarts": "osignalerbar",
    "osignat": "osignad",
    "osignats": "osignad",
    "osignerade": "osignerad",
    "osignerades": "osignerad",
    "osignerads": "osignerad",
    "osignerat": "osignerad",
    "osignerats": "osignerad",
    "osignerbara": "osignerbar",
    "osignerbarare": "osignerbar",
    "osignerbarares": "osignerbar",
    "osignerbaras": "osignerbar",
    "osignerbarast": "osignerbar",
    "osignerbaraste": "osignerbar",
    "osignerbarastes": "osignerbar",
    "osignerbarasts": "osignerbar",
    "osignerbare": "osignerbar",
    "osignerbares": "osignerbar",
    "osignerbarheten": "osignerbarhet",
    "osignerbarhetens": "osignerbarhet",
    "osignerbarhets": "osignerbarhet",
    "osignerbars": "osignerbar",
    "osignerbart": "osignerbar",
    "osignerbarts": "osignerbar",
    "osiktade": "osiktad",
    "osiktades": "osiktad",
    "osiktads": "osiktad",
    "osiktat": "osiktad",
    "osiktats": "osiktad",
    "osiktbara": "osiktbar",
    "osiktbarare": "osiktbar",
    "osiktbarares": "osiktbar",
    "osiktbaras": "osiktbar",
    "osiktbarast": "osiktbar",
    "osiktbaraste": "osiktbar",
    "osiktbarastes": "osiktbar",
    "osiktbarasts": "osiktbar",
    "osiktbare": "osiktbar",
    "osiktbares": "osiktbar",
    "osiktbarheten": "osiktbarhet",
    "osiktbarhetens": "osiktbarhet",
    "osiktbarhets": "osiktbarhet",
    "osiktbars": "osiktbar",
    "osiktbart": "osiktbar",
    "osiktbarts": "osiktbar",
    "osiktiga": "osiktig",
    "osiktigare": "osiktig",
    "osiktigares": "osiktig",
    "osiktigas": "osiktig",
    "osiktigast": "osiktig",
    "osiktigaste": "osiktig",
    "osiktigastes": "osiktig",
    "osiktigasts": "osiktig",
    "osiktige": "osiktig",
    "osiktiges": "osiktig",
    "osiktigheten": "osiktighet",
    "osiktighetens": "osiktighet",
    "osiktighets": "osiktighet",
    "osiktigs": "osiktig",
    "osiktigt": "osiktig",
    "osiktigts": "osiktig",
    "osilade": "osilad",
    "osilades": "osilad",
    "osilads": "osilad",
    "osilat": "osilad",
    "osilats": "osilad",
    "osilhuetterade": "osilhuetterad",
    "osilhuetterades": "osilhuetterad",
    "osilhuetterads": "osilhuetterad",
    "osilhuetterat": "osilhuetterad",
    "osilhuetterats": "osilhuetterad",
    "osilhuetterbara": "osilhuetterbar",
    "osilhuetterbarare": "osilhuetterbar",
    "osilhuetterbarares": "osilhuetterbar",
    "osilhuetterbaras": "osilhuetterbar",
    "osilhuetterbarast": "osilhuetterbar",
    "osilhuetterbaraste": "osilhuetterbar",
    "osilhuetterbarastes": "osilhuetterbar",
    "osilhuetterbarasts": "osilhuetterbar",
    "osilhuetterbare": "osilhuetterbar",
    "osilhuetterbares": "osilhuetterbar",
    "osilhuetterbarheten": "osilhuetterbarhet",
    "osilhuetterbarhetens": "osilhuetterbarhet",
    "osilhuetterbarhets": "osilhuetterbarhet",
    "osilhuetterbars": "osilhuetterbar",
    "osilhuetterbart": "osilhuetterbar",
    "osilhuetterbarts": "osilhuetterbar",
    "osiluetterade": "osiluetterad",
    "osiluetterades": "osiluetterad",
    "osiluetterads": "osiluetterad",
    "osiluetterat": "osiluetterad",
    "osiluetterats": "osiluetterad",
    "osiluetterbara": "osiluetterbar",
    "osiluetterbarare": "osiluetterbar",
    "osiluetterbarares": "osiluetterbar",
    "osiluetterbaras": "osiluetterbar",
    "osiluetterbarast": "osiluetterbar",
    "osiluetterbaraste": "osiluetterbar",
    "osiluetterbarastes": "osiluetterbar",
    "osiluetterbarasts": "osiluetterbar",
    "osiluetterbare": "osiluetterbar",
    "osiluetterbares": "osiluetterbar",
    "osiluetterbarheten": "osiluetterbarhet",
    "osiluetterbarhetens": "osiluetterbarhet",
    "osiluetterbarhets": "osiluetterbarhet",
    "osiluetterbars": "osiluetterbar",
    "osiluetterbart": "osiluetterbar",
    "osiluetterbarts": "osiluetterbar",
    "osilvrade": "osilvrad",
    "osilvrades": "osilvrad",
    "osilvrads": "osilvrad",
    "osilvrat": "osilvrad",
    "osilvrats": "osilvrad",
    "osimplifierade": "osimplifierad",
    "osimplifierades": "osimplifierad",
    "osimplifierads": "osimplifierad",
    "osimplifierat": "osimplifierad",
    "osimplifierats": "osimplifierad",
    "osimplifierbara": "osimplifierbar",
    "osimplifierbarare": "osimplifierbar",
    "osimplifierbarares": "osimplifierbar",
    "osimplifierbaras": "osimplifierbar",
    "osimplifierbarast": "osimplifierbar",
    "osimplifierbaraste": "osimplifierbar",
    "osimplifierbarastes": "osimplifierbar",
    "osimplifierbarasts": "osimplifierbar",
    "osimplifierbare": "osimplifierbar",
    "osimplifierbares": "osimplifierbar",
    "osimplifierbarheten": "osimplifierbarhet",
    "osimplifierbarhetens": "osimplifierbarhet",
    "osimplifierbarhets": "osimplifierbarhet",
    "osimplifierbars": "osimplifierbar",
    "osimplifierbart": "osimplifierbar",
    "osimplifierbarts": "osimplifierbar",
    "osimsade": "osimsad",
    "osimsades": "osimsad",
    "osimsads": "osimsad",
    "osimsat": "osimsad",
    "osimsats": "osimsad",
    "osimulerade": "osimulerad",
    "osimulerades": "osimulerad",
    "osimulerads": "osimulerad",
    "osimulerat": "osimulerad",
    "osimulerats": "osimulerad",
    "osimulerbara": "osimulerbar",
    "osimulerbarare": "osimulerbar",
    "osimulerbarares": "osimulerbar",
    "osimulerbaras": "osimulerbar",
    "osimulerbarast": "osimulerbar",
    "osimulerbaraste": "osimulerbar",
    "osimulerbarastes": "osimulerbar",
    "osimulerbarasts": "osimulerbar",
    "osimulerbare": "osimulerbar",
    "osimulerbares": "osimulerbar",
    "osimulerbarheten": "osimulerbarhet",
    "osimulerbarhetens": "osimulerbarhet",
    "osimulerbarhets": "osimulerbarhet",
    "osimulerbars": "osimulerbar",
    "osimulerbart": "osimulerbar",
    "osimulerbarts": "osimulerbar",
    "osinkade": "osinkad",
    "osinkades": "osinkad",
    "osinkads": "osinkad",
    "osinkat": "osinkad",
    "osinkats": "osinkad",
    "osinliga": "osinlig",
    "osinligare": "osinlig",
    "osinligares": "osinlig",
    "osinligas": "osinlig",
    "osinligast": "osinlig",
    "osinligaste": "osinlig",
    "osinligastes": "osinlig",
    "osinligasts": "osinlig",
    "osinlige": "osinlig",
    "osinliges": "osinlig",
    "osinligheten": "osinlighet",
    "osinlighetens": "osinlighet",
    "osinlighets": "osinlighet",
    "osinligs": "osinlig",
    "osinligt": "osinlig",
    "osinligts": "osinlig",
    "osinnliga": "osinnlig",
    "osinnligare": "osinnlig",
    "osinnligares": "osinnlig",
    "osinnligas": "osinnlig",
    "osinnligast": "osinnlig",
    "osinnligaste": "osinnlig",
    "osinnligastes": "osinnlig",
    "osinnligasts": "osinnlig",
    "osinnlige": "osinnlig",
    "osinnliges": "osinnlig",
    "osinnligheten": "osinnlighet",
    "osinnlighetens": "osinnlighet",
    "osinnlighets": "osinnlighet",
    "osinnligs": "osinnlig",
    "osinnligt": "osinnlig",
    "osinnligts": "osinnlig",
    "osintrade": "osintrad",
    "osintrades": "osintrad",
    "osintrads": "osintrad",
    "osintrat": "osintrad",
    "osintrats": "osintrad",
    "osirade": "osirad",
    "osirades": "osirad",
    "osirads": "osirad",
    "osirat": "osirad",
    "osirats": "osirad",
    "osisen": "osis",
    "osisens": "osis",
    "osjanghajade": "osjanghajad",
    "osjanghajades": "osjanghajad",
    "osjanghajads": "osjanghajad",
    "osjanghajat": "osjanghajad",
    "osjanghajats": "osjanghajad",
    "osjappade": "osjappad",
    "osjappades": "osjappad",
    "osjappads": "osjappad",
    "osjappat": "osjappad",
    "osjappats": "osjappad",
    "osjasade": "osjasad",
    "osjasades": "osjasad",
    "osjasads": "osjasad",
    "osjasat": "osjasad",
    "osjasats": "osjasad",
    "osjälviska": "osjälvisk",
    "osjälviskare": "osjälvisk",
    "osjälviskares": "osjälvisk",
    "osjälviskas": "osjälvisk",
    "osjälviskast": "osjälvisk",
    "osjälviskaste": "osjälvisk",
    "osjälviskastes": "osjälvisk",
    "osjälviskasts": "osjälvisk",
    "osjälviske": "osjälvisk",
    "osjälviskes": "osjälvisk",
    "osjälviskheten": "osjälviskhet",
    "osjälviskhetens": "osjälviskhet",
    "osjälviskheter": "osjälviskhet",
    "osjälviskheterna": "osjälviskhet",
    "osjälviskheternas": "osjälviskhet",
    "osjälviskheters": "osjälviskhet",
    "osjälviskhets": "osjälviskhet",
    "osjälvisks": "osjälvisk",
    "osjälviskt": "osjälvisk",
    "osjälviskts": "osjälvisk",
    "osjälvständiga": "osjälvständig",
    "osjälvständigare": "osjälvständig",
    "osjälvständigares": "osjälvständig",
    "osjälvständigas": "osjälvständig",
    "osjälvständigast": "osjälvständig",
    "osjälvständigaste": "osjälvständig",
    "osjälvständigastes": "osjälvständig",
    "osjälvständigasts": "osjälvständig",
    "osjälvständige": "osjälvständig",
    "osjälvständiges": "osjälvständig",
    "osjälvständigheten": "osjälvständighet",
    "osjälvständighetens": "osjälvständighet",
    "osjälvständigheter": "osjälvständighet",
    "osjälvständigheterna": "osjälvständighet",
    "osjälvständigheternas": "osjälvständighet",
    "osjälvständigheters": "osjälvständighet",
    "osjälvständighets": "osjälvständighet",
    "osjälvständigs": "osjälvständig",
    "osjälvständigt": "osjälvständig",
    "osjälvständigts": "osjälvständig",
    "oskadade": "oskadad",
    "oskadades": "oskadad",
    "oskadads": "oskadad",
    "oskadat": "oskadad",
    "oskadats": "oskadad",
    "oskadda": "oskadd",
    "oskaddare": "oskadd",
    "oskaddares": "oskadd",
    "oskaddas": "oskadd",
    "oskaddast": "oskadd",
    "oskaddaste": "oskadd",
    "oskaddastes": "oskadd",
    "oskaddasts": "oskadd",
    "oskadde": "oskadd",
    "oskaddes": "oskadd",
    "oskadds": "oskadd",
    "oskadliga": "oskadlig",
    "oskadligare": "oskadlig",
    "oskadligares": "oskadlig",
    "oskadligas": "oskadlig",
    "oskadligast": "oskadlig",
    "oskadligaste": "oskadlig",
    "oskadligastes": "oskadlig",
    "oskadligasts": "oskadlig",
    "oskadlige": "oskadlig",
    "oskadliges": "oskadlig",
    "oskadliggjord": "oskadliggöra",
    "oskadliggjorda": "oskadliggöra",
    "oskadliggjordas": "oskadliggöra",
    "oskadliggjorde": "oskadliggöra",
    "oskadliggjordes": "oskadliggöra",
    "oskadliggjords": "oskadliggöra",
    "oskadliggjort": "oskadliggöra",
    "oskadliggjorts": "oskadliggöra",
    "oskadliggör": "oskadliggöra",
    "oskadliggörande": "oskadliggöra",
    "oskadliggöranden": "oskadliggörande",
    "oskadliggörandena": "oskadliggörande",
    "oskadliggörandenas": "oskadliggörande",
    "oskadliggörandens": "oskadliggörande",
    "oskadliggörandes": "oskadliggörande",
    "oskadliggörandet": "oskadliggörande",
    "oskadliggörandets": "oskadliggörande",
    "oskadliggöras": "oskadliggöra",
    "oskadliggöres": "oskadliggöra",
    "oskadliggörs": "oskadliggöra",
    "oskadligheten": "oskadlighet",
    "oskadlighetens": "oskadlighet",
    "oskadlighets": "oskadlighet",
    "oskadligs": "oskadlig",
    "oskadligt": "oskadlig",
    "oskadligts": "oskadlig",
    "oskaffade": "oskaffad",
    "oskaffades": "oskaffad",
    "oskaffads": "oskaffad",
    "oskaffat": "oskaffad",
    "oskaffats": "oskaffad",
    "oskaftade": "oskaftad",
    "oskaftades": "oskaftad",
    "oskaftads": "oskaftad",
    "oskaftat": "oskaftad",
    "oskaftats": "oskaftad",
    "oskakade": "oskakad",
    "oskakades": "oskakad",
    "oskakads": "oskakad",
    "oskakat": "oskakad",
    "oskakats": "oskakad",
    "oskalade": "oskalad",
    "oskalades": "oskalad",
    "oskalads": "oskalad",
    "oskalat": "oskalad",
    "oskalats": "oskalad",
    "oskaldade": "oskaldad",
    "oskaldades": "oskaldad",
    "oskaldads": "oskaldad",
    "oskaldat": "oskaldad",
    "oskaldats": "oskaldad",
    "oskalkade": "oskalkad",
    "oskalkades": "oskalkad",
    "oskalkads": "oskalkad",
    "oskalkat": "oskalkad",
    "oskalkats": "oskalkad",
    "oskallade": "oskallad",
    "oskallades": "oskallad",
    "oskallads": "oskallad",
    "oskallat": "oskallad",
    "oskallats": "oskallad",
    "oskalperade": "oskalperad",
    "oskalperades": "oskalperad",
    "oskalperads": "oskalperad",
    "oskalperat": "oskalperad",
    "oskalperats": "oskalperad",
    "oskalperbara": "oskalperbar",
    "oskalperbarare": "oskalperbar",
    "oskalperbarares": "oskalperbar",
    "oskalperbaras": "oskalperbar",
    "oskalperbarast": "oskalperbar",
    "oskalperbaraste": "oskalperbar",
    "oskalperbarastes": "oskalperbar",
    "oskalperbarasts": "oskalperbar",
    "oskalperbare": "oskalperbar",
    "oskalperbares": "oskalperbar",
    "oskalperbarheten": "oskalperbarhet",
    "oskalperbarhetens": "oskalperbarhet",
    "oskalperbarhets": "oskalperbarhet",
    "oskalperbars": "oskalperbar",
    "oskalperbart": "oskalperbar",
    "oskalperbarts": "oskalperbar",
    "oskandaliserade": "oskandaliserad",
    "oskandaliserades": "oskandaliserad",
    "oskandaliserads": "oskandaliserad",
    "oskandaliserat": "oskandaliserad",
    "oskandaliserats": "oskandaliserad",
    "oskandaliserbara": "oskandaliserbar",
    "oskandaliserbarare": "oskandaliserbar",
    "oskandaliserbarares": "oskandaliserbar",
    "oskandaliserbaras": "oskandaliserbar",
    "oskandaliserbarast": "oskandaliserbar",
    "oskandaliserbaraste": "oskandaliserbar",
    "oskandaliserbarastes": "oskandaliserbar",
    "oskandaliserbarasts": "oskandaliserbar",
    "oskandaliserbare": "oskandaliserbar",
    "oskandaliserbares": "oskandaliserbar",
    "oskandaliserbarheten": "oskandaliserbarhet",
    "oskandaliserbarhetens": "oskandaliserbarhet",
    "oskandaliserbarhets": "oskandaliserbarhet",
    "oskandaliserbars": "oskandaliserbar",
    "oskandaliserbart": "oskandaliserbar",
    "oskandaliserbarts": "oskandaliserbar",
    "oskanderade": "oskanderad",
    "oskanderades": "oskanderad",
    "oskanderads": "oskanderad",
    "oskanderat": "oskanderad",
    "oskanderats": "oskanderad",
    "oskanderbara": "oskanderbar",
    "oskanderbarare": "oskanderbar",
    "oskanderbarares": "oskanderbar",
    "oskanderbaras": "oskanderbar",
    "oskanderbarast": "oskanderbar",
    "oskanderbaraste": "oskanderbar",
    "oskanderbarastes": "oskanderbar",
    "oskanderbarasts": "oskanderbar",
    "oskanderbare": "oskanderbar",
    "oskanderbares": "oskanderbar",
    "oskanderbarheten": "oskanderbarhet",
    "oskanderbarhetens": "oskanderbarhet",
    "oskanderbarhets": "oskanderbarhet",
    "oskanderbars": "oskanderbar",
    "oskanderbart": "oskanderbar",
    "oskanderbarts": "oskanderbar",
    "oskannade": "oskannad",
    "oskannades": "oskannad",
    "oskannads": "oskannad",
    "oskannat": "oskannad",
    "oskannats": "oskannad",
    "oskapade": "oskapad",
    "oskapades": "oskapad",
    "oskapads": "oskapad",
    "oskapat": "oskapad",
    "oskapats": "oskapad",
    "oskapliga": "oskaplig",
    "oskapligare": "oskaplig",
    "oskapligares": "oskaplig",
    "oskapligas": "oskaplig",
    "oskapligast": "oskaplig",
    "oskapligaste": "oskaplig",
    "oskapligastes": "oskaplig",
    "oskapligasts": "oskaplig",
    "oskaplige": "oskaplig",
    "oskapliges": "oskaplig",
    "oskapligheten": "oskaplighet",
    "oskaplighetens": "oskaplighet",
    "oskaplighets": "oskaplighet",
    "oskapligs": "oskaplig",
    "oskapligt": "oskaplig",
    "oskapligts": "oskaplig",
    "oskarianen": "oskarian",
    "oskarianens": "oskarian",
    "oskarianer": "oskarian",
    "oskarianerna": "oskarian",
    "oskarianernas": "oskarian",
    "oskarianers": "oskarian",
    "oskarians": "oskarian",
    "oskarianska": "oskariansk",
    "oskarianskare": "oskariansk",
    "oskarianskares": "oskariansk",
    "oskarianskas": "oskariansk",
    "oskarianskast": "oskariansk",
    "oskarianskaste": "oskariansk",
    "oskarianskastes": "oskariansk",
    "oskarianskasts": "oskariansk",
    "oskarianske": "oskariansk",
    "oskarianskes": "oskariansk",
    "oskariansks": "oskariansk",
    "oskarianskt": "oskariansk",
    "oskarianskts": "oskariansk",
    "oskarpa": "oskarp",
    "oskarpare": "oskarp",
    "oskarpares": "oskarp",
    "oskarpas": "oskarp",
    "oskarpast": "oskarp",
    "oskarpaste": "oskarp",
    "oskarpastes": "oskarp",
    "oskarpasts": "oskarp",
    "oskarpe": "oskarp",
    "oskarpes": "oskarp",
    "oskarpheten": "oskarphet",
    "oskarphetens": "oskarphet",
    "oskarphets": "oskarphet",
    "oskarps": "oskarp",
    "oskarpt": "oskarp",
    "oskarpts": "oskarp",
    "oskarvade": "oskarvad",
    "oskarvades": "oskarvad",
    "oskarvads": "oskarvad",
    "oskarvat": "oskarvad",
    "oskarvats": "oskarvad",
    "oskatt": "oskadd",
    "oskattade": "oskattad",
    "oskattades": "oskattad",
    "oskattads": "oskattad",
    "oskattat": "oskattad",
    "oskattats": "oskattad",
    "oskattbara": "oskattbar",
    "oskattbarare": "oskattbar",
    "oskattbarares": "oskattbar",
    "oskattbaras": "oskattbar",
    "oskattbarast": "oskattbar",
    "oskattbaraste": "oskattbar",
    "oskattbarastes": "oskattbar",
    "oskattbarasts": "oskattbar",
    "oskattbare": "oskattbar",
    "oskattbares": "oskattbar",
    "oskattbarheten": "oskattbarhet",
    "oskattbarhetens": "oskattbarhet",
    "oskattbarhets": "oskattbarhet",
    "oskattbars": "oskattbar",
    "oskattbart": "oskattbar",
    "oskattbarts": "oskattbar",
    "oskatts": "oskadd",
    "oskavde": "oskavd",
    "oskavdes": "oskavd",
    "oskavds": "oskavd",
    "oskavt": "oskavd",
    "oskavts": "oskavd",
    "oskedade": "oskedad",
    "oskedades": "oskedad",
    "oskedads": "oskedad",
    "oskedat": "oskedad",
    "oskedats": "oskedad",
    "oskenade": "oskenad",
    "oskenades": "oskenad",
    "oskenads": "oskenad",
    "oskenat": "oskenad",
    "oskenats": "oskenad",
    "oskeppade": "oskeppad",
    "oskeppades": "oskeppad",
    "oskeppads": "oskeppad",
    "oskeppat": "oskeppad",
    "oskeppats": "oskeppad",
    "oskevade": "oskevad",
    "oskevades": "oskevad",
    "oskevads": "oskevad",
    "oskevat": "oskevad",
    "oskevats": "oskevad",
    "oskevrade": "oskevrad",
    "oskevrades": "oskevrad",
    "oskevrads": "oskevrad",
    "oskevrat": "oskevrad",
    "oskevrats": "oskevrad",
    "oskicken": "oskick",
    "oskickens": "oskick",
    "oskicket": "oskick",
    "oskickets": "oskick",
    "oskickliga": "oskicklig",
    "oskickligare": "oskicklig",
    "oskickligares": "oskicklig",
    "oskickligas": "oskicklig",
    "oskickligast": "oskicklig",
    "oskickligaste": "oskicklig",
    "oskickligastes": "oskicklig",
    "oskickligasts": "oskicklig",
    "oskicklige": "oskicklig",
    "oskickliges": "oskicklig",
    "oskickligheten": "oskicklighet",
    "oskicklighetens": "oskicklighet",
    "oskicklighets": "oskicklighet",
    "oskickligs": "oskicklig",
    "oskickligt": "oskicklig",
    "oskickligts": "oskicklig",
    "oskicks": "oskick",
    "oskiftade": "oskiftad",
    "oskiftades": "oskiftad",
    "oskiftads": "oskiftad",
    "oskiftat": "oskiftad",
    "oskiftats": "oskiftad",
    "oskiktade": "oskiktad",
    "oskiktades": "oskiktad",
    "oskiktads": "oskiktad",
    "oskiktat": "oskiktad",
    "oskiktats": "oskiktad",
    "oskildrade": "oskildrad",
    "oskildrades": "oskildrad",
    "oskildrads": "oskildrad",
    "oskildrat": "oskildrad",
    "oskildrats": "oskildrad",
    "oskiljaktiga": "oskiljaktig",
    "oskiljaktigare": "oskiljaktig",
    "oskiljaktigares": "oskiljaktig",
    "oskiljaktigas": "oskiljaktig",
    "oskiljaktigast": "oskiljaktig",
    "oskiljaktigaste": "oskiljaktig",
    "oskiljaktigastes": "oskiljaktig",
    "oskiljaktigasts": "oskiljaktig",
    "oskiljaktige": "oskiljaktig",
    "oskiljaktiges": "oskiljaktig",
    "oskiljaktigheten": "oskiljaktighet",
    "oskiljaktighetens": "oskiljaktighet",
    "oskiljaktigheter": "oskiljaktighet",
    "oskiljaktigheterna": "oskiljaktighet",
    "oskiljaktigheternas": "oskiljaktighet",
    "oskiljaktigheters": "oskiljaktighet",
    "oskiljaktighets": "oskiljaktighet",
    "oskiljaktigs": "oskiljaktig",
    "oskiljaktigt": "oskiljaktig",
    "oskiljaktigts": "oskiljaktig",
    "oskingrade": "oskingrad",
    "oskingrades": "oskingrad",
    "oskingrads": "oskingrad",
    "oskingrat": "oskingrad",
    "oskingrats": "oskingrad",
    "oskinnade": "oskinnad",
    "oskinnades": "oskinnad",
    "oskinnads": "oskinnad",
    "oskinnat": "oskinnad",
    "oskinnats": "oskinnad",
    "oskipade": "oskipad",
    "oskipades": "oskipad",
    "oskipads": "oskipad",
    "oskipat": "oskipad",
    "oskipats": "oskipad",
    "oskippade": "oskippad",
    "oskippades": "oskippad",
    "oskippads": "oskippad",
    "oskippat": "oskippad",
    "oskippats": "oskippad",
    "oskirade": "oskirad",
    "oskirades": "oskirad",
    "oskirads": "oskirad",
    "oskirat": "oskirad",
    "oskirats": "oskirad",
    "oskissade": "oskissad",
    "oskissades": "oskissad",
    "oskissads": "oskissad",
    "oskissat": "oskissad",
    "oskissats": "oskissad",
    "oskisserade": "oskisserad",
    "oskisserades": "oskisserad",
    "oskisserads": "oskisserad",
    "oskisserat": "oskisserad",
    "oskisserats": "oskisserad",
    "oskisserbara": "oskisserbar",
    "oskisserbarare": "oskisserbar",
    "oskisserbarares": "oskisserbar",
    "oskisserbaras": "oskisserbar",
    "oskisserbarast": "oskisserbar",
    "oskisserbaraste": "oskisserbar",
    "oskisserbarastes": "oskisserbar",
    "oskisserbarasts": "oskisserbar",
    "oskisserbare": "oskisserbar",
    "oskisserbares": "oskisserbar",
    "oskisserbarheten": "oskisserbarhet",
    "oskisserbarhetens": "oskisserbarhet",
    "oskisserbarhets": "oskisserbarhet",
    "oskisserbars": "oskisserbar",
    "oskisserbart": "oskisserbar",
    "oskisserbarts": "oskisserbar",
    "oskivade": "oskivad",
    "oskivades": "oskivad",
    "oskivads": "oskivad",
    "oskivat": "oskivad",
    "oskivats": "oskivad",
    "oskjutsade": "oskjutsad",
    "oskjutsades": "oskjutsad",
    "oskjutsads": "oskjutsad",
    "oskjutsat": "oskjutsad",
    "oskjutsats": "oskjutsad",
    "oskjuvade": "oskjuvad",
    "oskjuvades": "oskjuvad",
    "oskjuvads": "oskjuvad",
    "oskjuvat": "oskjuvad",
    "oskjuvats": "oskjuvad",
    "oskojade": "oskojad",
    "oskojades": "oskojad",
    "oskojads": "oskojad",
    "oskojat": "oskojad",
    "oskojats": "oskojad",
    "oskolade": "oskolad",
    "oskolades": "oskolad",
    "oskolads": "oskolad",
    "oskolat": "oskolad",
    "oskolats": "oskolad",
    "oskonade": "oskonad",
    "oskonades": "oskonad",
    "oskonads": "oskonad",
    "oskonat": "oskonad",
    "oskonats": "oskonad",
    "oskopade": "oskopad",
    "oskopades": "oskopad",
    "oskopads": "oskopad",
    "oskopat": "oskopad",
    "oskopats": "oskopad",
    "oskotade": "oskotad",
    "oskotades": "oskotad",
    "oskotads": "oskotad",
    "oskotat": "oskotad",
    "oskotats": "oskotad",
    "oskottade": "oskottad",
    "oskottades": "oskottad",
    "oskottads": "oskottad",
    "oskottat": "oskottad",
    "oskottats": "oskottad",
    "oskovlade": "oskovlad",
    "oskovlades": "oskovlad",
    "oskovlads": "oskovlad",
    "oskovlat": "oskovlad",
    "oskovlats": "oskovlad",
    "oskrafferade": "oskrafferad",
    "oskrafferades": "oskrafferad",
    "oskrafferads": "oskrafferad",
    "oskrafferat": "oskrafferad",
    "oskrafferats": "oskrafferad",
    "oskrafferbara": "oskrafferbar",
    "oskrafferbarare": "oskrafferbar",
    "oskrafferbarares": "oskrafferbar",
    "oskrafferbaras": "oskrafferbar",
    "oskrafferbarast": "oskrafferbar",
    "oskrafferbaraste": "oskrafferbar",
    "oskrafferbarastes": "oskrafferbar",
    "oskrafferbarasts": "oskrafferbar",
    "oskrafferbare": "oskrafferbar",
    "oskrafferbares": "oskrafferbar",
    "oskrafferbarheten": "oskrafferbarhet",
    "oskrafferbarhetens": "oskrafferbarhet",
    "oskrafferbarhets": "oskrafferbarhet",
    "oskrafferbars": "oskrafferbar",
    "oskrafferbart": "oskrafferbar",
    "oskrafferbarts": "oskrafferbar",
    "oskramlade": "oskramlad",
    "oskramlades": "oskramlad",
    "oskramlads": "oskramlad",
    "oskramlat": "oskramlad",
    "oskramlats": "oskramlad",
    "oskrapade": "oskrapad",
    "oskrapades": "oskrapad",
    "oskrapads": "oskrapad",
    "oskrapat": "oskrapad",
    "oskrapats": "oskrapad",
    "oskrivens": "oskriven",
    "oskrivet": "oskriven",
    "oskrivets": "oskriven",
    "oskrivna": "oskriven",
    "oskrivnare": "oskriven",
    "oskrivnares": "oskriven",
    "oskrivnas": "oskriven",
    "oskrivnast": "oskriven",
    "oskrivnaste": "oskriven",
    "oskrivnastes": "oskriven",
    "oskrivnasts": "oskriven",
    "oskrivne": "oskriven",
    "oskrivnes": "oskriven",
    "oskrotade": "oskrotad",
    "oskrotades": "oskrotad",
    "oskrotads": "oskrotad",
    "oskrotat": "oskrotad",
    "oskrotats": "oskrotad",
    "oskrubbade": "oskrubbad",
    "oskrubbades": "oskrubbad",
    "oskrubbads": "oskrubbad",
    "oskrubbat": "oskrubbad",
    "oskrubbats": "oskrubbad",
    "oskrudade": "oskrudad",
    "oskrudades": "oskrudad",
    "oskrudads": "oskrudad",
    "oskrudat": "oskrudad",
    "oskrudats": "oskrudad",
    "oskrymtade": "oskrymtad",
    "oskrymtades": "oskrymtad",
    "oskrymtads": "oskrymtad",
    "oskrymtat": "oskrymtad",
    "oskrymtats": "oskrymtad",
    "oskulden": "oskuld",
    "oskuldens": "oskuld",
    "oskulder": "oskuld",
    "oskulderna": "oskuld",
    "oskuldernas": "oskuld",
    "oskulders": "oskuld",
    "oskulds": "oskuld",
    "oskuldsbevisen": "oskuldsbevis",
    "oskuldsbevisens": "oskuldsbevis",
    "oskuldsbeviset": "oskuldsbevis",
    "oskuldsbevisets": "oskuldsbevis",
    "oskuldsfulla": "oskuldsfull",
    "oskuldsfullare": "oskuldsfull",
    "oskuldsfullares": "oskuldsfull",
    "oskuldsfullas": "oskuldsfull",
    "oskuldsfullast": "oskuldsfull",
    "oskuldsfullaste": "oskuldsfull",
    "oskuldsfullastes": "oskuldsfull",
    "oskuldsfullasts": "oskuldsfull",
    "oskuldsfulle": "oskuldsfull",
    "oskuldsfulles": "oskuldsfull",
    "oskuldsfullheten": "oskuldsfullhet",
    "oskuldsfullhetens": "oskuldsfullhet",
    "oskuldsfullhets": "oskuldsfullhet",
    "oskuldsfulls": "oskuldsfull",
    "oskuldsfullt": "oskuldsfull",
    "oskuldsfullts": "oskuldsfull",
    "oskulpterade": "oskulpterad",
    "oskulpterades": "oskulpterad",
    "oskulpterads": "oskulpterad",
    "oskulpterat": "oskulpterad",
    "oskulpterats": "oskulpterad",
    "oskulpterbara": "oskulpterbar",
    "oskulpterbarare": "oskulpterbar",
    "oskulpterbarares": "oskulpterbar",
    "oskulpterbaras": "oskulpterbar",
    "oskulpterbarast": "oskulpterbar",
    "oskulpterbaraste": "oskulpterbar",
    "oskulpterbarastes": "oskulpterbar",
    "oskulpterbarasts": "oskulpterbar",
    "oskulpterbare": "oskulpterbar",
    "oskulpterbares": "oskulpterbar",
    "oskulpterbarheten": "oskulpterbarhet",
    "oskulpterbarhetens": "oskulpterbarhet",
    "oskulpterbarhets": "oskulpterbarhet",
    "oskulpterbars": "oskulpterbar",
    "oskulpterbart": "oskulpterbar",
    "oskulpterbarts": "oskulpterbar",
    "oskulpturerade": "oskulpturerad",
    "oskulpturerades": "oskulpturerad",
    "oskulpturerads": "oskulpturerad",
    "oskulpturerat": "oskulpturerad",
    "oskulpturerats": "oskulpturerad",
    "oskulpturerbara": "oskulpturerbar",
    "oskulpturerbarare": "oskulpturerbar",
    "oskulpturerbarares": "oskulpturerbar",
    "oskulpturerbaras": "oskulpturerbar",
    "oskulpturerbarast": "oskulpturerbar",
    "oskulpturerbaraste": "oskulpturerbar",
    "oskulpturerbarastes": "oskulpturerbar",
    "oskulpturerbarasts": "oskulpturerbar",
    "oskulpturerbare": "oskulpturerbar",
    "oskulpturerbares": "oskulpturerbar",
    "oskulpturerbarheten": "oskulpturerbarhet",
    "oskulpturerbarhetens": "oskulpturerbarhet",
    "oskulpturerbarhets": "oskulpturerbarhet",
    "oskulpturerbars": "oskulpturerbar",
    "oskulpturerbart": "oskulpturerbar",
    "oskulpturerbarts": "oskulpturerbar",
    "oskyddade": "oskyddad",
    "oskyddades": "oskyddad",
    "oskyddads": "oskyddad",
    "oskyddat": "oskyddad",
    "oskyddats": "oskyddad",
    "oskylda": "oskyld",
    "oskyldare": "oskyld",
    "oskyldares": "oskyld",
    "oskyldas": "oskyld",
    "oskyldast": "oskyld",
    "oskyldaste": "oskyld",
    "oskyldastes": "oskyld",
    "oskyldasts": "oskyld",
    "oskylde": "oskyld",
    "oskyldes": "oskyld",
    "oskyldiga": "oskyldig",
    "oskyldigare": "oskyldig",
    "oskyldigares": "oskyldig",
    "oskyldigas": "oskyldig",
    "oskyldigast": "oskyldig",
    "oskyldigaste": "oskyldig",
    "oskyldigastes": "oskyldig",
    "oskyldigasts": "oskyldig",
    "oskyldige": "oskyldig",
    "oskyldiges": "oskyldig",
    "oskyldigheten": "oskyldighet",
    "oskyldighetens": "oskyldighet",
    "oskyldighets": "oskyldighet",
    "oskyldigs": "oskyldig",
    "oskyldigt": "oskyldig",
    "oskyldigts": "oskyldig",
    "oskylds": "oskyld",
    "oskylt": "oskyld",
    "oskylts": "oskyld",
    "oskäliga": "oskälig",
    "oskäligare": "oskälig",
    "oskäligares": "oskälig",
    "oskäligas": "oskälig",
    "oskäligast": "oskälig",
    "oskäligaste": "oskälig",
    "oskäligastes": "oskälig",
    "oskäligasts": "oskälig",
    "oskälige": "oskälig",
    "oskäliges": "oskälig",
    "oskäligheten": "oskälighet",
    "oskälighetens": "oskälighet",
    "oskälighets": "oskälighet",
    "oskäligs": "oskälig",
    "oskäligt": "oskälig",
    "oskäligts": "oskälig",
    "oskär": "oskära",
    "oskärad": "oskära",
    "oskärade": "oskära",
    "oskärades": "oskära",
    "oskärads": "oskära",
    "oskärande": "oskära",
    "oskäranden": "oskärande",
    "oskärandena": "oskärande",
    "oskärandenas": "oskärande",
    "oskärandens": "oskärande",
    "oskärandes": "oskärande",
    "oskärandet": "oskärande",
    "oskärandets": "oskärande",
    "oskärar": "oskära",
    "oskäras": "oskära",
    "oskärat": "oskära",
    "oskärats": "oskära",
    "oskärpan": "oskärpa",
    "oskärpans": "oskärpa",
    "oskärpas": "oskärpa",
    "osköna": "oskön",
    "oskönare": "oskön",
    "oskönares": "oskön",
    "oskönas": "oskön",
    "oskönast": "oskön",
    "oskönaste": "oskön",
    "oskönastes": "oskön",
    "oskönasts": "oskön",
    "osköne": "oskön",
    "oskönes": "oskön",
    "oskönheten": "oskönhet",
    "oskönhetens": "oskönhet",
    "oskönhets": "oskönhet",
    "osköns": "oskön",
    "oskönt": "oskön",
    "oskönts": "oskön",
    "oslagbara": "oslagbar",
    "oslagbarare": "oslagbar",
    "oslagbarares": "oslagbar",
    "oslagbaras": "oslagbar",
    "oslagbarast": "oslagbar",
    "oslagbaraste": "oslagbar",
    "oslagbarastes": "oslagbar",
    "oslagbarasts": "oslagbar",
    "oslagbare": "oslagbar",
    "oslagbares": "oslagbar",
    "oslagbarheten": "oslagbarhet",
    "oslagbarhetens": "oslagbarhet",
    "oslagbarhets": "oslagbarhet",
    "oslagbars": "oslagbar",
    "oslagbart": "oslagbar",
    "oslagbarts": "oslagbar",
    "oslagens": "oslagen",
    "oslaget": "oslagen",
    "oslagets": "oslagen",
    "oslagna": "oslagen",
    "oslagnare": "oslagen",
    "oslagnares": "oslagen",
    "oslagnas": "oslagen",
    "oslagnast": "oslagen",
    "oslagnaste": "oslagen",
    "oslagnastes": "oslagen",
    "oslagnasts": "oslagen",
    "oslagne": "oslagen",
    "oslagnes": "oslagen",
    "oslaktade": "oslaktad",
    "oslaktades": "oslaktad",
    "oslaktads": "oslaktad",
    "oslaktat": "oslaktad",
    "oslaktats": "oslaktad",
    "oslaviserade": "oslaviserad",
    "oslaviserades": "oslaviserad",
    "oslaviserads": "oslaviserad",
    "oslaviserat": "oslaviserad",
    "oslaviserats": "oslaviserad",
    "oslaviserbara": "oslaviserbar",
    "oslaviserbarare": "oslaviserbar",
    "oslaviserbarares": "oslaviserbar",
    "oslaviserbaras": "oslaviserbar",
    "oslaviserbarast": "oslaviserbar",
    "oslaviserbaraste": "oslaviserbar",
    "oslaviserbarastes": "oslaviserbar",
    "oslaviserbarasts": "oslaviserbar",
    "oslaviserbare": "oslaviserbar",
    "oslaviserbares": "oslaviserbar",
    "oslaviserbarheten": "oslaviserbarhet",
    "oslaviserbarhetens": "oslaviserbarhet",
    "oslaviserbarhets": "oslaviserbarhet",
    "oslaviserbars": "oslaviserbar",
    "oslaviserbart": "oslaviserbar",
    "oslaviserbarts": "oslaviserbar",
    "oslipade": "oslipad",
    "oslipades": "oslipad",
    "oslipads": "oslipad",
    "oslipat": "oslipad",
    "oslipats": "oslipad",
    "osläckliga": "osläcklig",
    "osläckligare": "osläcklig",
    "osläckligares": "osläcklig",
    "osläckligas": "osläcklig",
    "osläckligast": "osläcklig",
    "osläckligaste": "osläcklig",
    "osläckligastes": "osläcklig",
    "osläckligasts": "osläcklig",
    "osläcklige": "osläcklig",
    "osläckliges": "osläcklig",
    "osläckligheten": "osläcklighet",
    "osläcklighetens": "osläcklighet",
    "osläcklighets": "osläcklighet",
    "osläckligs": "osläcklig",
    "osläckligt": "osläcklig",
    "osläckligts": "osläcklig",
    "osläckta": "osläckt",
    "osläcktare": "osläckt",
    "osläcktares": "osläckt",
    "osläcktas": "osläckt",
    "osläcktast": "osläckt",
    "osläcktaste": "osläckt",
    "osläcktastes": "osläckt",
    "osläcktasts": "osläckt",
    "osläckte": "osläckt",
    "osläcktes": "osläckt",
    "osläckts": "osläckt",
    "osmaken": "osmak",
    "osmakens": "osmak",
    "osmakliga": "osmaklig",
    "osmakligare": "osmaklig",
    "osmakligares": "osmaklig",
    "osmakligas": "osmaklig",
    "osmakligast": "osmaklig",
    "osmakligaste": "osmaklig",
    "osmakligastes": "osmaklig",
    "osmakligasts": "osmaklig",
    "osmaklige": "osmaklig",
    "osmakliges": "osmaklig",
    "osmakligheten": "osmaklighet",
    "osmaklighetens": "osmaklighet",
    "osmakligheter": "osmaklighet",
    "osmakligheterna": "osmaklighet",
    "osmakligheternas": "osmaklighet",
    "osmakligheters": "osmaklighet",
    "osmaklighets": "osmaklighet",
    "osmakligs": "osmaklig",
    "osmakligt": "osmaklig",
    "osmakligts": "osmaklig",
    "osmaks": "osmak",
    "osmanen": "osman",
    "osmanens": "osman",
    "osmaner": "osman",
    "osmanerna": "osman",
    "osmanernas": "osman",
    "osmaners": "osman",
    "osmans": "osman",
    "osmanska": "osmansk",
    "osmanskare": "osmansk",
    "osmanskares": "osmansk",
    "osmanskas": "osmansk",
    "osmanskast": "osmansk",
    "osmanskaste": "osmansk",
    "osmanskastes": "osmansk",
    "osmanskasts": "osmansk",
    "osmanske": "osmansk",
    "osmanskes": "osmansk",
    "osmansks": "osmansk",
    "osmanskt": "osmansk",
    "osmanskts": "osmansk",
    "osmidbara": "osmidbar",
    "osmidbarare": "osmidbar",
    "osmidbarares": "osmidbar",
    "osmidbaras": "osmidbar",
    "osmidbarast": "osmidbar",
    "osmidbaraste": "osmidbar",
    "osmidbarastes": "osmidbar",
    "osmidbarasts": "osmidbar",
    "osmidbare": "osmidbar",
    "osmidbares": "osmidbar",
    "osmidbarheten": "osmidbarhet",
    "osmidbarhetens": "osmidbarhet",
    "osmidbarhets": "osmidbarhet",
    "osmidbars": "osmidbar",
    "osmidbart": "osmidbar",
    "osmidbarts": "osmidbar",
    "osmidiga": "osmidig",
    "osmidigare": "osmidig",
    "osmidigares": "osmidig",
    "osmidigas": "osmidig",
    "osmidigast": "osmidig",
    "osmidigaste": "osmidig",
    "osmidigastes": "osmidig",
    "osmidigasts": "osmidig",
    "osmidige": "osmidig",
    "osmidiges": "osmidig",
    "osmidigheten": "osmidighet",
    "osmidighetens": "osmidighet",
    "osmidigheter": "osmidighet",
    "osmidigheterna": "osmidighet",
    "osmidigheternas": "osmidighet",
    "osmidigheters": "osmidighet",
    "osmidighets": "osmidighet",
    "osmidigs": "osmidig",
    "osmidigt": "osmidig",
    "osmidigts": "osmidig",
    "osmiet": "osmium",
    "osmiets": "osmium",
    "osminkade": "osminkad",
    "osminkades": "osminkad",
    "osminkads": "osminkad",
    "osminkat": "osminkad",
    "osminkats": "osminkad",
    "osmiumet": "osmium",
    "osmiumets": "osmium",
    "osmiums": "osmium",
    "osmorda": "osmord",
    "osmordare": "osmord",
    "osmordares": "osmord",
    "osmordas": "osmord",
    "osmordast": "osmord",
    "osmordaste": "osmord",
    "osmordastes": "osmord",
    "osmordasts": "osmord",
    "osmorde": "osmord",
    "osmordes": "osmord",
    "osmords": "osmord",
    "osmort": "osmord",
    "osmorts": "osmord",
    "osmosen": "osmos",
    "osmosens": "osmos",
    "osmotiska": "osmotisk",
    "osmotiskare": "osmotisk",
    "osmotiskares": "osmotisk",
    "osmotiskas": "osmotisk",
    "osmotiskast": "osmotisk",
    "osmotiskaste": "osmotisk",
    "osmotiskastes": "osmotisk",
    "osmotiskasts": "osmotisk",
    "osmotiske": "osmotisk",
    "osmotiskes": "osmotisk",
    "osmotisks": "osmotisk",
    "osmotiskt": "osmotisk",
    "osmotiskts": "osmotisk",
    "osmunden": "osmund",
    "osmundens": "osmund",
    "osmunds": "osmund",
    "osmälta": "osmält",
    "osmältare": "osmält",
    "osmältares": "osmält",
    "osmältas": "osmält",
    "osmältast": "osmält",
    "osmältaste": "osmält",
    "osmältastes": "osmält",
    "osmältasts": "osmält",
    "osmältbara": "osmältbar",
    "osmältbarare": "osmältbar",
    "osmältbarares": "osmältbar",
    "osmältbaras": "osmältbar",
    "osmältbarast": "osmältbar",
    "osmältbaraste": "osmältbar",
    "osmältbarastes": "osmältbar",
    "osmältbarasts": "osmältbar",
    "osmältbare": "osmältbar",
    "osmältbares": "osmältbar",
    "osmältbarheten": "osmältbarhet",
    "osmältbarhetens": "osmältbarhet",
    "osmältbarhets": "osmältbarhet",
    "osmältbars": "osmältbar",
    "osmältbart": "osmältbar",
    "osmältbarts": "osmältbar",
    "osmälte": "osmält",
    "osmältes": "osmält",
    "osmälts": "osmält",
    "osnedrekryterbara": "osnedrekryterbar",
    "osnedrekryterbarare": "osnedrekryterbar",
    "osnedrekryterbarares": "osnedrekryterbar",
    "osnedrekryterbaras": "osnedrekryterbar",
    "osnedrekryterbarast": "osnedrekryterbar",
    "osnedrekryterbaraste": "osnedrekryterbar",
    "osnedrekryterbarastes": "osnedrekryterbar",
    "osnedrekryterbarasts": "osnedrekryterbar",
    "osnedrekryterbare": "osnedrekryterbar",
    "osnedrekryterbares": "osnedrekryterbar",
    "osnedrekryterbarheten": "osnedrekryterbarhet",
    "osnedrekryterbarhetens": "osnedrekryterbarhet",
    "osnedrekryterbarhets": "osnedrekryterbarhet",
    "osnedrekryterbars": "osnedrekryterbar",
    "osnedrekryterbart": "osnedrekryterbar",
    "osnedrekryterbarts": "osnedrekryterbar",
    "osnutens": "osnuten",
    "osnutet": "osnuten",
    "osnutets": "osnuten",
    "osnutna": "osnuten",
    "osnutnare": "osnuten",
    "osnutnares": "osnuten",
    "osnutnas": "osnuten",
    "osnutnast": "osnuten",
    "osnutnaste": "osnuten",
    "osnutnastes": "osnuten",
    "osnutnasts": "osnuten",
    "osnutne": "osnuten",
    "osnutnes": "osnuten",
    "osnygg": "osnygga",
    "osnygga": "osnygg",
    "osnyggad": "osnygga",
    "osnyggade": "osnygga",
    "osnyggades": "osnygga",
    "osnyggads": "osnygga",
    "osnyggande": "osnygga",
    "osnygganden": "osnyggande",
    "osnyggandena": "osnyggande",
    "osnyggandenas": "osnyggande",
    "osnyggandens": "osnyggande",
    "osnyggandes": "osnyggande",
    "osnyggandet": "osnyggande",
    "osnyggandets": "osnyggande",
    "osnyggar": "osnygga",
    "osnyggare": "osnygg",
    "osnyggares": "osnygg",
    "osnyggas": "osnygga",
    "osnyggast": "osnygg",
    "osnyggaste": "osnygg",
    "osnyggastes": "osnygg",
    "osnyggasts": "osnygg",
    "osnyggat": "osnygga",
    "osnyggats": "osnygga",
    "osnygge": "osnygg",
    "osnygges": "osnygg",
    "osnyggheten": "osnygghet",
    "osnygghetens": "osnygghet",
    "osnygghets": "osnygghet",
    "osnyggs": "osnygg",
    "osnyggt": "osnygg",
    "osnyggts": "osnygg",
    "osociala": "osocial",
    "osocialare": "osocial",
    "osocialares": "osocial",
    "osocialas": "osocial",
    "osocialast": "osocial",
    "osocialaste": "osocial",
    "osocialastes": "osocial",
    "osocialasts": "osocial",
    "osociale": "osocial",
    "osociales": "osocial",
    "osocialiserade": "osocialiserad",
    "osocialiserades": "osocialiserad",
    "osocialiserads": "osocialiserad",
    "osocialiserat": "osocialiserad",
    "osocialiserats": "osocialiserad",
    "osocialiserbara": "osocialiserbar",
    "osocialiserbarare": "osocialiserbar",
    "osocialiserbarares": "osocialiserbar",
    "osocialiserbaras": "osocialiserbar",
    "osocialiserbarast": "osocialiserbar",
    "osocialiserbaraste": "osocialiserbar",
    "osocialiserbarastes": "osocialiserbar",
    "osocialiserbarasts": "osocialiserbar",
    "osocialiserbare": "osocialiserbar",
    "osocialiserbares": "osocialiserbar",
    "osocialiserbarheten": "osocialiserbarhet",
    "osocialiserbarhetens": "osocialiserbarhet",
    "osocialiserbarhets": "osocialiserbarhet",
    "osocialiserbars": "osocialiserbar",
    "osocialiserbart": "osocialiserbar",
    "osocialiserbarts": "osocialiserbar",
    "osocials": "osocial",
    "osocialt": "osocial",
    "osocialts": "osocial",
    "osolidariska": "osolidarisk",
    "osolidariskare": "osolidarisk",
    "osolidariskares": "osolidarisk",
    "osolidariskas": "osolidarisk",
    "osolidariskast": "osolidarisk",
    "osolidariskaste": "osolidarisk",
    "osolidariskastes": "osolidarisk",
    "osolidariskasts": "osolidarisk",
    "osolidariske": "osolidarisk",
    "osolidariskes": "osolidarisk",
    "osolidarisks": "osolidarisk",
    "osolidariskt": "osolidarisk",
    "osolidariskts": "osolidarisk",
    "osolverade": "osolverad",
    "osolverades": "osolverad",
    "osolverads": "osolverad",
    "osolverat": "osolverad",
    "osolverats": "osolverad",
    "osolverbara": "osolverbar",
    "osolverbarare": "osolverbar",
    "osolverbarares": "osolverbar",
    "osolverbaras": "osolverbar",
    "osolverbarast": "osolverbar",
    "osolverbaraste": "osolverbar",
    "osolverbarastes": "osolverbar",
    "osolverbarasts": "osolverbar",
    "osolverbare": "osolverbar",
    "osolverbares": "osolverbar",
    "osolverbarheten": "osolverbarhet",
    "osolverbarhetens": "osolverbarhet",
    "osolverbarhets": "osolverbarhet",
    "osolverbars": "osolverbar",
    "osolverbart": "osolverbar",
    "osolverbarts": "osolverbar",
    "osonderade": "osonderad",
    "osonderades": "osonderad",
    "osonderads": "osonderad",
    "osonderat": "osonderad",
    "osonderats": "osonderad",
    "osonderbara": "osonderbar",
    "osonderbarare": "osonderbar",
    "osonderbarares": "osonderbar",
    "osonderbaras": "osonderbar",
    "osonderbarast": "osonderbar",
    "osonderbaraste": "osonderbar",
    "osonderbarastes": "osonderbar",
    "osonderbarasts": "osonderbar",
    "osonderbare": "osonderbar",
    "osonderbares": "osonderbar",
    "osonderbarheten": "osonderbarhet",
    "osonderbarhetens": "osonderbarhet",
    "osonderbarhets": "osonderbarhet",
    "osonderbars": "osonderbar",
    "osonderbart": "osonderbar",
    "osonderbarts": "osonderbar",
    "osordinerade": "osordinerad",
    "osordinerades": "osordinerad",
    "osordinerads": "osordinerad",
    "osordinerat": "osordinerad",
    "osordinerats": "osordinerad",
    "osordinerbara": "osordinerbar",
    "osordinerbarare": "osordinerbar",
    "osordinerbarares": "osordinerbar",
    "osordinerbaras": "osordinerbar",
    "osordinerbarast": "osordinerbar",
    "osordinerbaraste": "osordinerbar",
    "osordinerbarastes": "osordinerbar",
    "osordinerbarasts": "osordinerbar",
    "osordinerbare": "osordinerbar",
    "osordinerbares": "osordinerbar",
    "osordinerbarheten": "osordinerbarhet",
    "osordinerbarhetens": "osordinerbarhet",
    "osordinerbarhets": "osordinerbarhet",
    "osordinerbars": "osordinerbar",
    "osordinerbart": "osordinerbar",
    "osordinerbarts": "osordinerbar",
    "osorterade": "osorterad",
    "osorterades": "osorterad",
    "osorterads": "osorterad",
    "osorterat": "osorterad",
    "osorterats": "osorterad",
    "osorterbara": "osorterbar",
    "osorterbarare": "osorterbar",
    "osorterbarares": "osorterbar",
    "osorterbaras": "osorterbar",
    "osorterbarast": "osorterbar",
    "osorterbaraste": "osorterbar",
    "osorterbarastes": "osorterbar",
    "osorterbarasts": "osorterbar",
    "osorterbare": "osorterbar",
    "osorterbares": "osorterbar",
    "osorterbarheten": "osorterbarhet",
    "osorterbarhetens": "osorterbarhet",
    "osorterbarhets": "osorterbarhet",
    "osorterbars": "osorterbar",
    "osorterbart": "osorterbar",
    "osorterbarts": "osorterbar",
    "osoulagerade": "osoulagerad",
    "osoulagerades": "osoulagerad",
    "osoulagerads": "osoulagerad",
    "osoulagerat": "osoulagerad",
    "osoulagerats": "osoulagerad",
    "osoulagerbara": "osoulagerbar",
    "osoulagerbarare": "osoulagerbar",
    "osoulagerbarares": "osoulagerbar",
    "osoulagerbaras": "osoulagerbar",
    "osoulagerbarast": "osoulagerbar",
    "osoulagerbaraste": "osoulagerbar",
    "osoulagerbarastes": "osoulagerbar",
    "osoulagerbarasts": "osoulagerbar",
    "osoulagerbare": "osoulagerbar",
    "osoulagerbares": "osoulagerbar",
    "osoulagerbarheten": "osoulagerbarhet",
    "osoulagerbarhetens": "osoulagerbarhet",
    "osoulagerbarhets": "osoulagerbarhet",
    "osoulagerbars": "osoulagerbar",
    "osoulagerbart": "osoulagerbar",
    "osoulagerbarts": "osoulagerbar",
    "osovjetiserade": "osovjetiserad",
    "osovjetiserades": "osovjetiserad",
    "osovjetiserads": "osovjetiserad",
    "osovjetiserat": "osovjetiserad",
    "osovjetiserats": "osovjetiserad",
    "osovjetiserbara": "osovjetiserbar",
    "osovjetiserbarare": "osovjetiserbar",
    "osovjetiserbarares": "osovjetiserbar",
    "osovjetiserbaras": "osovjetiserbar",
    "osovjetiserbarast": "osovjetiserbar",
    "osovjetiserbaraste": "osovjetiserbar",
    "osovjetiserbarastes": "osovjetiserbar",
    "osovjetiserbarasts": "osovjetiserbar",
    "osovjetiserbare": "osovjetiserbar",
    "osovjetiserbares": "osovjetiserbar",
    "osovjetiserbarheten": "osovjetiserbarhet",
    "osovjetiserbarhetens": "osovjetiserbarhet",
    "osovjetiserbarhets": "osovjetiserbarhet",
    "osovjetiserbars": "osovjetiserbar",
    "osovjetiserbart": "osovjetiserbar",
    "osovjetiserbarts": "osovjetiserbar",
    "ospaljerade": "ospaljerad",
    "ospaljerades": "ospaljerad",
    "ospaljerads": "ospaljerad",
    "ospaljerat": "ospaljerad",
    "ospaljerats": "ospaljerad",
    "ospaljerbara": "ospaljerbar",
    "ospaljerbarare": "ospaljerbar",
    "ospaljerbarares": "ospaljerbar",
    "ospaljerbaras": "ospaljerbar",
    "ospaljerbarast": "ospaljerbar",
    "ospaljerbaraste": "ospaljerbar",
    "ospaljerbarastes": "ospaljerbar",
    "ospaljerbarasts": "ospaljerbar",
    "ospaljerbare": "ospaljerbar",
    "ospaljerbares": "ospaljerbar",
    "ospaljerbarheten": "ospaljerbarhet",
    "ospaljerbarhetens": "ospaljerbarhet",
    "ospaljerbarhets": "ospaljerbarhet",
    "ospaljerbars": "ospaljerbar",
    "ospaljerbart": "ospaljerbar",
    "ospaljerbarts": "ospaljerbar",
    "ospallerade": "ospallerad",
    "ospallerades": "ospallerad",
    "ospallerads": "ospallerad",
    "ospallerat": "ospallerad",
    "ospallerats": "ospallerad",
    "ospallerbara": "ospallerbar",
    "ospallerbarare": "ospallerbar",
    "ospallerbarares": "ospallerbar",
    "ospallerbaras": "ospallerbar",
    "ospallerbarast": "ospallerbar",
    "ospallerbaraste": "ospallerbar",
    "ospallerbarastes": "ospallerbar",
    "ospallerbarasts": "ospallerbar",
    "ospallerbare": "ospallerbar",
    "ospallerbares": "ospallerbar",
    "ospallerbarheten": "ospallerbarhet",
    "ospallerbarhetens": "ospallerbarhet",
    "ospallerbarhets": "ospallerbarhet",
    "ospallerbars": "ospallerbar",
    "ospallerbart": "ospallerbar",
    "ospallerbarts": "ospallerbar",
    "osparade": "osparad",
    "osparades": "osparad",
    "osparads": "osparad",
    "osparat": "osparad",
    "osparats": "osparad",
    "osparda": "ospard",
    "ospardare": "ospard",
    "ospardares": "ospard",
    "ospardas": "ospard",
    "ospardast": "ospard",
    "ospardaste": "ospard",
    "ospardastes": "ospard",
    "ospardasts": "ospard",
    "osparde": "ospard",
    "ospardes": "ospard",
    "ospards": "ospard",
    "ospart": "ospard",
    "osparts": "ospard",
    "ospecialiserade": "ospecialiserad",
    "ospecialiserades": "ospecialiserad",
    "ospecialiserads": "ospecialiserad",
    "ospecialiserat": "ospecialiserad",
    "ospecialiserats": "ospecialiserad",
    "ospecialiserbara": "ospecialiserbar",
    "ospecialiserbarare": "ospecialiserbar",
    "ospecialiserbarares": "ospecialiserbar",
    "ospecialiserbaras": "ospecialiserbar",
    "ospecialiserbarast": "ospecialiserbar",
    "ospecialiserbaraste": "ospecialiserbar",
    "ospecialiserbarastes": "ospecialiserbar",
    "ospecialiserbarasts": "ospecialiserbar",
    "ospecialiserbare": "ospecialiserbar",
    "ospecialiserbares": "ospecialiserbar",
    "ospecialiserbarheten": "ospecialiserbarhet",
    "ospecialiserbarhetens": "ospecialiserbarhet",
    "ospecialiserbarhets": "ospecialiserbarhet",
    "ospecialiserbars": "ospecialiserbar",
    "ospecialiserbart": "ospecialiserbar",
    "ospecialiserbarts": "ospecialiserbar",
    "ospecificerade": "ospecificerad",
    "ospecificerades": "ospecificerad",
    "ospecificerads": "ospecificerad",
    "ospecificerat": "ospecificerad",
    "ospecificerats": "ospecificerad",
    "ospecificerbara": "ospecificerbar",
    "ospecificerbarare": "ospecificerbar",
    "ospecificerbarares": "ospecificerbar",
    "ospecificerbaras": "ospecificerbar",
    "ospecificerbarast": "ospecificerbar",
    "ospecificerbaraste": "ospecificerbar",
    "ospecificerbarastes": "ospecificerbar",
    "ospecificerbarasts": "ospecificerbar",
    "ospecificerbare": "ospecificerbar",
    "ospecificerbares": "ospecificerbar",
    "ospecificerbarheten": "ospecificerbarhet",
    "ospecificerbarhetens": "ospecificerbarhet",
    "ospecificerbarhets": "ospecificerbarhet",
    "ospecificerbars": "ospecificerbar",
    "ospecificerbart": "ospecificerbar",
    "ospecificerbarts": "ospecificerbar",
    "ospeciminerade": "ospeciminerad",
    "ospeciminerades": "ospeciminerad",
    "ospeciminerads": "ospeciminerad",
    "ospeciminerat": "ospeciminerad",
    "ospeciminerats": "ospeciminerad",
    "ospeciminerbara": "ospeciminerbar",
    "ospeciminerbarare": "ospeciminerbar",
    "ospeciminerbarares": "ospeciminerbar",
    "ospeciminerbaras": "ospeciminerbar",
    "ospeciminerbarast": "ospeciminerbar",
    "ospeciminerbaraste": "ospeciminerbar",
    "ospeciminerbarastes": "ospeciminerbar",
    "ospeciminerbarasts": "ospeciminerbar",
    "ospeciminerbare": "ospeciminerbar",
    "ospeciminerbares": "ospeciminerbar",
    "ospeciminerbarheten": "ospeciminerbarhet",
    "ospeciminerbarhetens": "ospeciminerbarhet",
    "ospeciminerbarhets": "ospeciminerbarhet",
    "ospeciminerbars": "ospeciminerbar",
    "ospeciminerbart": "ospeciminerbar",
    "ospeciminerbarts": "ospeciminerbar",
    "ospekulerade": "ospekulerad",
    "ospekulerades": "ospekulerad",
    "ospekulerads": "ospekulerad",
    "ospekulerat": "ospekulerad",
    "ospekulerats": "ospekulerad",
    "ospekulerbara": "ospekulerbar",
    "ospekulerbarare": "ospekulerbar",
    "ospekulerbarares": "ospekulerbar",
    "ospekulerbaras": "ospekulerbar",
    "ospekulerbarast": "ospekulerbar",
    "ospekulerbaraste": "ospekulerbar",
    "ospekulerbarastes": "ospekulerbar",
    "ospekulerbarasts": "ospekulerbar",
    "ospekulerbare": "ospekulerbar",
    "ospekulerbares": "ospekulerbar",
    "ospekulerbarheten": "ospekulerbarhet",
    "ospekulerbarhetens": "ospekulerbarhet",
    "ospekulerbarhets": "ospekulerbarhet",
    "ospekulerbars": "ospekulerbar",
    "ospekulerbart": "ospekulerbar",
    "ospekulerbarts": "ospekulerbar",
    "ospelbara": "ospelbar",
    "ospelbarare": "ospelbar",
    "ospelbarares": "ospelbar",
    "ospelbaras": "ospelbar",
    "ospelbarast": "ospelbar",
    "ospelbaraste": "ospelbar",
    "ospelbarastes": "ospelbar",
    "ospelbarasts": "ospelbar",
    "ospelbare": "ospelbar",
    "ospelbares": "ospelbar",
    "ospelbarheten": "ospelbarhet",
    "ospelbarhetens": "ospelbarhet",
    "ospelbarhets": "ospelbarhet",
    "ospelbars": "ospelbar",
    "ospelbart": "ospelbar",
    "ospelbarts": "ospelbar",
    "ospenderade": "ospenderad",
    "ospenderades": "ospenderad",
    "ospenderads": "ospenderad",
    "ospenderat": "ospenderad",
    "ospenderats": "ospenderad",
    "ospenderbara": "ospenderbar",
    "ospenderbarare": "ospenderbar",
    "ospenderbarares": "ospenderbar",
    "ospenderbaras": "ospenderbar",
    "ospenderbarast": "ospenderbar",
    "ospenderbaraste": "ospenderbar",
    "ospenderbarastes": "ospenderbar",
    "ospenderbarasts": "ospenderbar",
    "ospenderbare": "ospenderbar",
    "ospenderbares": "ospenderbar",
    "ospenderbarheten": "ospenderbarhet",
    "ospenderbarhetens": "ospenderbarhet",
    "ospenderbarhets": "ospenderbarhet",
    "ospenderbars": "ospenderbar",
    "ospenderbart": "ospenderbar",
    "ospenderbarts": "ospenderbar",
    "ospolierade": "ospolierad",
    "ospolierades": "ospolierad",
    "ospolierads": "ospolierad",
    "ospolierat": "ospolierad",
    "ospolierats": "ospolierad",
    "ospolierbara": "ospolierbar",
    "ospolierbarare": "ospolierbar",
    "ospolierbarares": "ospolierbar",
    "ospolierbaras": "ospolierbar",
    "ospolierbarast": "ospolierbar",
    "ospolierbaraste": "ospolierbar",
    "ospolierbarastes": "ospolierbar",
    "ospolierbarasts": "ospolierbar",
    "ospolierbare": "ospolierbar",
    "ospolierbares": "ospolierbar",
    "ospolierbarheten": "ospolierbarhet",
    "ospolierbarhetens": "ospolierbarhet",
    "ospolierbarhets": "ospolierbarhet",
    "ospolierbars": "ospolierbar",
    "ospolierbart": "ospolierbar",
    "ospolierbarts": "ospolierbar",
    "osportsliga": "osportslig",
    "osportsligare": "osportslig",
    "osportsligares": "osportslig",
    "osportsligas": "osportslig",
    "osportsligast": "osportslig",
    "osportsligaste": "osportslig",
    "osportsligastes": "osportslig",
    "osportsligasts": "osportslig",
    "osportslige": "osportslig",
    "osportsliges": "osportslig",
    "osportsligheten": "osportslighet",
    "osportslighetens": "osportslighet",
    "osportsligheter": "osportslighet",
    "osportsligheterna": "osportslighet",
    "osportsligheternas": "osportslighet",
    "osportsligheters": "osportslighet",
    "osportslighets": "osportslighet",
    "osportsligs": "osportslig",
    "osportsligt": "osportslig",
    "osportsligts": "osportslig",
    "ospärrade": "ospärrad",
    "ospärrades": "ospärrad",
    "ospärrads": "ospärrad",
    "ospärrat": "ospärrad",
    "ospärrats": "ospärrad",
    "oss": "vi",
    "ossobucon": "ossobuco",
    "ossobucons": "ossobuco",
    "ossobucos": "ossobuco",
    "ossuarie": "ossuarium",
    "ossuarier": "ossuarium",
    "ossuarierna": "ossuarium",
    "ossuariernas": "ossuarium",
    "ossuariers": "ossuarium",
    "ossuariet": "ossuarium",
    "ossuariets": "ossuarium",
    "ossuariums": "ossuarium",
    "ostabiliserade": "ostabiliserad",
    "ostabiliserades": "ostabiliserad",
    "ostabiliserads": "ostabiliserad",
    "ostabiliserat": "ostabiliserad",
    "ostabiliserats": "ostabiliserad",
    "ostabiliserbara": "ostabiliserbar",
    "ostabiliserbarare": "ostabiliserbar",
    "ostabiliserbarares": "ostabiliserbar",
    "ostabiliserbaras": "ostabiliserbar",
    "ostabiliserbarast": "ostabiliserbar",
    "ostabiliserbaraste": "ostabiliserbar",
    "ostabiliserbarastes": "ostabiliserbar",
    "ostabiliserbarasts": "ostabiliserbar",
    "ostabiliserbare": "ostabiliserbar",
    "ostabiliserbares": "ostabiliserbar",
    "ostabiliserbarheten": "ostabiliserbarhet",
    "ostabiliserbarhetens": "ostabiliserbarhet",
    "ostabiliserbarhets": "ostabiliserbarhet",
    "ostabiliserbars": "ostabiliserbar",
    "ostabiliserbart": "ostabiliserbar",
    "ostabiliserbarts": "ostabiliserbar",
    "ostadiga": "ostadig",
    "ostadigare": "ostadig",
    "ostadigares": "ostadig",
    "ostadigas": "ostadig",
    "ostadigast": "ostadig",
    "ostadigaste": "ostadig",
    "ostadigastes": "ostadig",
    "ostadigasts": "ostadig",
    "ostadige": "ostadig",
    "ostadiges": "ostadig",
    "ostadigheten": "ostadighet",
    "ostadighetens": "ostadighet",
    "ostadighets": "ostadighet",
    "ostadigs": "ostadig",
    "ostadigt": "ostadig",
    "ostadigts": "ostadig",
    "ostafferade": "ostafferad",
    "ostafferades": "ostafferad",
    "ostafferads": "ostafferad",
    "ostafferat": "ostafferad",
    "ostafferats": "ostafferad",
    "ostafferbara": "ostafferbar",
    "ostafferbarare": "ostafferbar",
    "ostafferbarares": "ostafferbar",
    "ostafferbaras": "ostafferbar",
    "ostafferbarast": "ostafferbar",
    "ostafferbaraste": "ostafferbar",
    "ostafferbarastes": "ostafferbar",
    "ostafferbarasts": "ostafferbar",
    "ostafferbare": "ostafferbar",
    "ostafferbares": "ostafferbar",
    "ostafferbarheten": "ostafferbarhet",
    "ostafferbarhetens": "ostafferbarhet",
    "ostafferbarhets": "ostafferbarhet",
    "ostafferbars": "ostafferbar",
    "ostafferbart": "ostafferbar",
    "ostafferbarts": "ostafferbar",
    "ostagnerade": "ostagnerad",
    "ostagnerades": "ostagnerad",
    "ostagnerads": "ostagnerad",
    "ostagnerat": "ostagnerad",
    "ostagnerats": "ostagnerad",
    "ostalgien": "ostalgi",
    "ostalgiens": "ostalgi",
    "ostalgier": "ostalgi",
    "ostalgierna": "ostalgi",
    "ostalgiernas": "ostalgi",
    "ostalgiers": "ostalgi",
    "ostalgin": "ostalgi",
    "ostalgins": "ostalgi",
    "ostalgis": "ostalgi",
    "ostandardiserade": "ostandardiserad",
    "ostandardiserades": "ostandardiserad",
    "ostandardiserads": "ostandardiserad",
    "ostandardiserat": "ostandardiserad",
    "ostandardiserats": "ostandardiserad",
    "ostandardiserbara": "ostandardiserbar",
    "ostandardiserbarare": "ostandardiserbar",
    "ostandardiserbarares": "ostandardiserbar",
    "ostandardiserbaras": "ostandardiserbar",
    "ostandardiserbarast": "ostandardiserbar",
    "ostandardiserbaraste": "ostandardiserbar",
    "ostandardiserbarastes": "ostandardiserbar",
    "ostandardiserbarasts": "ostandardiserbar",
    "ostandardiserbare": "ostandardiserbar",
    "ostandardiserbares": "ostandardiserbar",
    "ostandardiserbarheten": "ostandardiserbarhet",
    "ostandardiserbarhetens": "ostandardiserbarhet",
    "ostandardiserbarhets": "ostandardiserbarhet",
    "ostandardiserbars": "ostandardiserbar",
    "ostandardiserbart": "ostandardiserbar",
    "ostandardiserbarts": "ostandardiserbar",
    "ostans": "ostan",
    "ostar": "ost",
    "ostarna": "ost",
    "ostarnas": "ost",
    "ostars": "ost",
    "ostasiaten": "ostasiat",
    "ostasiatens": "ostasiat",
    "ostasiater": "ostasiat",
    "ostasiaterna": "ostasiat",
    "ostasiaternas": "ostasiat",
    "ostasiaters": "ostasiat",
    "ostasiats": "ostasiat",
    "ostationerade": "ostationerad",
    "ostationerades": "ostationerad",
    "ostationerads": "ostationerad",
    "ostationerat": "ostationerad",
    "ostationerats": "ostationerad",
    "ostationerbara": "ostationerbar",
    "ostationerbarare": "ostationerbar",
    "ostationerbarares": "ostationerbar",
    "ostationerbaras": "ostationerbar",
    "ostationerbarast": "ostationerbar",
    "ostationerbaraste": "ostationerbar",
    "ostationerbarastes": "ostationerbar",
    "ostationerbarasts": "ostationerbar",
    "ostationerbare": "ostationerbar",
    "ostationerbares": "ostationerbar",
    "ostationerbarheten": "ostationerbarhet",
    "ostationerbarhetens": "ostationerbarhet",
    "ostationerbarhets": "ostationerbarhet",
    "ostationerbars": "ostationerbar",
    "ostationerbart": "ostationerbar",
    "ostationerbarts": "ostationerbar",
    "ostatuerade": "ostatuerad",
    "ostatuerades": "ostatuerad",
    "ostatuerads": "ostatuerad",
    "ostatuerat": "ostatuerad",
    "ostatuerats": "ostatuerad",
    "ostatuerbara": "ostatuerbar",
    "ostatuerbarare": "ostatuerbar",
    "ostatuerbarares": "ostatuerbar",
    "ostatuerbaras": "ostatuerbar",
    "ostatuerbarast": "ostatuerbar",
    "ostatuerbaraste": "ostatuerbar",
    "ostatuerbarastes": "ostatuerbar",
    "ostatuerbarasts": "ostatuerbar",
    "ostatuerbare": "ostatuerbar",
    "ostatuerbares": "ostatuerbar",
    "ostatuerbarheten": "ostatuerbarhet",
    "ostatuerbarhetens": "ostatuerbarhet",
    "ostatuerbarhets": "ostatuerbarhet",
    "ostatuerbars": "ostatuerbar",
    "ostatuerbart": "ostatuerbar",
    "ostatuerbarts": "ostatuerbar",
    "ostbrick": "ostbricka",
    "ostbrickan": "ostbricka",
    "ostbrickans": "ostbricka",
    "ostbrickas": "ostbricka",
    "ostbricke": "ostbricka",
    "ostbrickor": "ostbricka",
    "ostbrickorna": "ostbricka",
    "ostbrickornas": "ostbricka",
    "ostbrickors": "ostbricka",
    "ostbricks": "ostbricka",
    "ostbågar": "ostbåge",
    "ostbågarna": "ostbåge",
    "ostbågarnas": "ostbåge",
    "ostbågars": "ostbåge",
    "ostbågen": "ostbåge",
    "ostbågens": "ostbåge",
    "ostbåges": "ostbåge",
    "osten": "ost",
    "ostencilerade": "ostencilerad",
    "ostencilerades": "ostencilerad",
    "ostencilerads": "ostencilerad",
    "ostencilerat": "ostencilerad",
    "ostencilerats": "ostencilerad",
    "ostencilerbara": "ostencilerbar",
    "ostencilerbarare": "ostencilerbar",
    "ostencilerbarares": "ostencilerbar",
    "ostencilerbaras": "ostencilerbar",
    "ostencilerbarast": "ostencilerbar",
    "ostencilerbaraste": "ostencilerbar",
    "ostencilerbarastes": "ostencilerbar",
    "ostencilerbarasts": "ostencilerbar",
    "ostencilerbare": "ostencilerbar",
    "ostencilerbares": "ostencilerbar",
    "ostencilerbarheten": "ostencilerbarhet",
    "ostencilerbarhetens": "ostencilerbarhet",
    "ostencilerbarhets": "ostencilerbarhet",
    "ostencilerbars": "ostencilerbar",
    "ostencilerbart": "ostencilerbar",
    "ostencilerbarts": "ostencilerbar",
    "ostenograferade": "ostenograferad",
    "ostenograferades": "ostenograferad",
    "ostenograferads": "ostenograferad",
    "ostenograferat": "ostenograferad",
    "ostenograferats": "ostenograferad",
    "ostenograferbara": "ostenograferbar",
    "ostenograferbarare": "ostenograferbar",
    "ostenograferbarares": "ostenograferbar",
    "ostenograferbaras": "ostenograferbar",
    "ostenograferbarast": "ostenograferbar",
    "ostenograferbaraste": "ostenograferbar",
    "ostenograferbarastes": "ostenograferbar",
    "ostenograferbarasts": "ostenograferbar",
    "ostenograferbare": "ostenograferbar",
    "ostenograferbares": "ostenograferbar",
    "ostenograferbarheten": "ostenograferbarhet",
    "ostenograferbarhetens": "ostenograferbarhet",
    "ostenograferbarhets": "ostenograferbarhet",
    "ostenograferbars": "ostenograferbar",
    "ostenograferbart": "ostenograferbar",
    "ostenograferbarts": "ostenograferbar",
    "ostens": "ost",
    "ostensiva": "ostensiv",
    "ostensivare": "ostensiv",
    "ostensivares": "ostensiv",
    "ostensivas": "ostensiv",
    "ostensivast": "ostensiv",
    "ostensivaste": "ostensiv",
    "ostensivastes": "ostensiv",
    "ostensivasts": "ostensiv",
    "ostensive": "ostensiv",
    "ostensives": "ostensiv",
    "ostensivs": "ostensiv",
    "ostensivt": "ostensiv",
    "ostensivts": "ostensiv",
    "ostentationen": "ostentation",
    "ostentationens": "ostentation",
    "ostentationer": "ostentation",
    "ostentationerna": "ostentation",
    "ostentationernas": "ostentation",
    "ostentationers": "ostentation",
    "ostentations": "ostentation",
    "ostentativa": "ostentativ",
    "ostentativare": "ostentativ",
    "ostentativares": "ostentativ",
    "ostentativas": "ostentativ",
    "ostentativast": "ostentativ",
    "ostentativaste": "ostentativ",
    "ostentativastes": "ostentativ",
    "ostentativasts": "ostentativ",
    "ostentative": "ostentativ",
    "ostentatives": "ostentativ",
    "ostentativs": "ostentativ",
    "ostentativt": "ostentativ",
    "ostentativts": "ostentativ",
    "osteologen": "osteolog",
    "osteologens": "osteolog",
    "osteologer": "osteolog",
    "osteologerna": "osteolog",
    "osteologernas": "osteolog",
    "osteologers": "osteolog",
    "osteologien": "osteologi",
    "osteologiens": "osteologi",
    "osteologin": "osteologi",
    "osteologins": "osteologi",
    "osteologis": "osteologi",
    "osteologs": "osteolog",
    "ostereotyperade": "ostereotyperad",
    "ostereotyperades": "ostereotyperad",
    "ostereotyperads": "ostereotyperad",
    "ostereotyperat": "ostereotyperad",
    "ostereotyperats": "ostereotyperad",
    "ostereotyperbara": "ostereotyperbar",
    "ostereotyperbarare": "ostereotyperbar",
    "ostereotyperbarares": "ostereotyperbar",
    "ostereotyperbaras": "ostereotyperbar",
    "ostereotyperbarast": "ostereotyperbar",
    "ostereotyperbaraste": "ostereotyperbar",
    "ostereotyperbarastes": "ostereotyperbar",
    "ostereotyperbarasts": "ostereotyperbar",
    "ostereotyperbare": "ostereotyperbar",
    "ostereotyperbares": "ostereotyperbar",
    "ostereotyperbarheten": "ostereotyperbarhet",
    "ostereotyperbarhetens": "ostereotyperbarhet",
    "ostereotyperbarhets": "ostereotyperbarhet",
    "ostereotyperbars": "ostereotyperbar",
    "ostereotyperbart": "ostereotyperbar",
    "ostereotyperbarts": "ostereotyperbar",
    "osteri": "osteria",
    "osterian": "osteria",
    "osterians": "osteria",
    "osterias": "osteria",
    "osterie": "osteria",
    "osteriliserade": "osteriliserad",
    "osteriliserades": "osteriliserad",
    "osteriliserads": "osteriliserad",
    "osteriliserat": "osteriliserad",
    "osteriliserats": "osteriliserad",
    "osteriliserbara": "osteriliserbar",
    "osteriliserbarare": "osteriliserbar",
    "osteriliserbarares": "osteriliserbar",
    "osteriliserbaras": "osteriliserbar",
    "osteriliserbarast": "osteriliserbar",
    "osteriliserbaraste": "osteriliserbar",
    "osteriliserbarastes": "osteriliserbar",
    "osteriliserbarasts": "osteriliserbar",
    "osteriliserbare": "osteriliserbar",
    "osteriliserbares": "osteriliserbar",
    "osteriliserbarheten": "osteriliserbarhet",
    "osteriliserbarhetens": "osteriliserbarhet",
    "osteriliserbarhets": "osteriliserbarhet",
    "osteriliserbars": "osteriliserbar",
    "osteriliserbart": "osteriliserbar",
    "osteriliserbarts": "osteriliserbar",
    "osterior": "osteria",
    "osteriorna": "osteria",
    "osteriornas": "osteria",
    "osteriors": "osteria",
    "osteris": "osteria",
    "ostflug": "ostfluga",
    "ostflugan": "ostfluga",
    "ostflugans": "ostfluga",
    "ostflugas": "ostfluga",
    "ostfluge": "ostfluga",
    "ostflugor": "ostfluga",
    "ostflugorna": "ostfluga",
    "ostflugornas": "ostfluga",
    "ostflugors": "ostfluga",
    "ostflugs": "ostfluga",
    "ostframställningar": "ostframställning",
    "ostframställningarna": "ostframställning",
    "ostframställningarnas": "ostframställning",
    "ostframställningars": "ostframställning",
    "ostframställningen": "ostframställning",
    "ostframställningens": "ostframställning",
    "ostframställnings": "ostframställning",
    "osthyveln": "osthyvel",
    "osthyvelns": "osthyvel",
    "osthyvels": "osthyvel",
    "osthyvelsprincipen": "osthyvelsprincip",
    "osthyvelsprincipens": "osthyvelsprincip",
    "osthyvelsprincips": "osthyvelsprincip",
    "osthyvlar": "osthyvel",
    "osthyvlarna": "osthyvel",
    "osthyvlarnas": "osthyvel",
    "osthyvlars": "osthyvel",
    "ostiga": "ostig",
    "ostigare": "ostig",
    "ostigares": "ostig",
    "ostigas": "ostig",
    "ostigast": "ostig",
    "ostigaste": "ostig",
    "ostigastes": "ostig",
    "ostigasts": "ostig",
    "ostige": "ostig",
    "ostiges": "ostig",
    "ostigheten": "ostighet",
    "ostighetens": "ostighet",
    "ostighets": "ostighet",
    "ostigmatiserade": "ostigmatiserad",
    "ostigmatiserades": "ostigmatiserad",
    "ostigmatiserads": "ostigmatiserad",
    "ostigmatiserat": "ostigmatiserad",
    "ostigmatiserats": "ostigmatiserad",
    "ostigmatiserbara": "ostigmatiserbar",
    "ostigmatiserbarare": "ostigmatiserbar",
    "ostigmatiserbarares": "ostigmatiserbar",
    "ostigmatiserbaras": "ostigmatiserbar",
    "ostigmatiserbarast": "ostigmatiserbar",
    "ostigmatiserbaraste": "ostigmatiserbar",
    "ostigmatiserbarastes": "ostigmatiserbar",
    "ostigmatiserbarasts": "ostigmatiserbar",
    "ostigmatiserbare": "ostigmatiserbar",
    "ostigmatiserbares": "ostigmatiserbar",
    "ostigmatiserbarheten": "ostigmatiserbarhet",
    "ostigmatiserbarhetens": "ostigmatiserbarhet",
    "ostigmatiserbarhets": "ostigmatiserbarhet",
    "ostigmatiserbars": "ostigmatiserbar",
    "ostigmatiserbart": "ostigmatiserbar",
    "ostigmatiserbarts": "ostigmatiserbar",
    "ostigs": "ostig",
    "ostigt": "ostig",
    "ostigts": "ostig",
    "ostiliserade": "ostiliserad",
    "ostiliserades": "ostiliserad",
    "ostiliserads": "ostiliserad",
    "ostiliserat": "ostiliserad",
    "ostiliserats": "ostiliserad",
    "ostiliserbara": "ostiliserbar",
    "ostiliserbarare": "ostiliserbar",
    "ostiliserbarares": "ostiliserbar",
    "ostiliserbaras": "ostiliserbar",
    "ostiliserbarast": "ostiliserbar",
    "ostiliserbaraste": "ostiliserbar",
    "ostiliserbarastes": "ostiliserbar",
    "ostiliserbarasts": "ostiliserbar",
    "ostiliserbare": "ostiliserbar",
    "ostiliserbares": "ostiliserbar",
    "ostiliserbarheten": "ostiliserbarhet",
    "ostiliserbarhetens": "ostiliserbarhet",
    "ostiliserbarhets": "ostiliserbarhet",
    "ostiliserbars": "ostiliserbar",
    "ostiliserbart": "ostiliserbar",
    "ostiliserbarts": "ostiliserbar",
    "ostimulerade": "ostimulerad",
    "ostimulerades": "ostimulerad",
    "ostimulerads": "ostimulerad",
    "ostimulerat": "ostimulerad",
    "ostimulerats": "ostimulerad",
    "ostimulerbara": "ostimulerbar",
    "ostimulerbarare": "ostimulerbar",
    "ostimulerbarares": "ostimulerbar",
    "ostimulerbaras": "ostimulerbar",
    "ostimulerbarast": "ostimulerbar",
    "ostimulerbaraste": "ostimulerbar",
    "ostimulerbarastes": "ostimulerbar",
    "ostimulerbarasts": "ostimulerbar",
    "ostimulerbare": "ostimulerbar",
    "ostimulerbares": "ostimulerbar",
    "ostimulerbarheten": "ostimulerbarhet",
    "ostimulerbarhetens": "ostimulerbarhet",
    "ostimulerbarhets": "ostimulerbarhet",
    "ostimulerbars": "ostimulerbar",
    "ostimulerbart": "ostimulerbar",
    "ostimulerbarts": "ostimulerbar",
    "ostinaton": "ostinato",
    "ostinatona": "ostinato",
    "ostinatonas": "ostinato",
    "ostinatons": "ostinato",
    "ostinatos": "ostinato",
    "ostinatot": "ostinato",
    "ostinatots": "ostinato",
    "ostindiska": "ostindisk",
    "ostindiskare": "ostindisk",
    "ostindiskares": "ostindisk",
    "ostindiskas": "ostindisk",
    "ostindiskast": "ostindisk",
    "ostindiskaste": "ostindisk",
    "ostindiskastes": "ostindisk",
    "ostindiskasts": "ostindisk",
    "ostindiske": "ostindisk",
    "ostindiskes": "ostindisk",
    "ostindisks": "ostindisk",
    "ostindiskt": "ostindisk",
    "ostindiskts": "ostindisk",
    "ostipendierade": "ostipendierad",
    "ostipendierades": "ostipendierad",
    "ostipendierads": "ostipendierad",
    "ostipendierat": "ostipendierad",
    "ostipendierats": "ostipendierad",
    "ostipendierbara": "ostipendierbar",
    "ostipendierbarare": "ostipendierbar",
    "ostipendierbarares": "ostipendierbar",
    "ostipendierbaras": "ostipendierbar",
    "ostipendierbarast": "ostipendierbar",
    "ostipendierbaraste": "ostipendierbar",
    "ostipendierbarastes": "ostipendierbar",
    "ostipendierbarasts": "ostipendierbar",
    "ostipendierbare": "ostipendierbar",
    "ostipendierbares": "ostipendierbar",
    "ostipendierbarheten": "ostipendierbarhet",
    "ostipendierbarhetens": "ostipendierbarhet",
    "ostipendierbarhets": "ostipendierbarhet",
    "ostipendierbars": "ostipendierbar",
    "ostipendierbart": "ostipendierbar",
    "ostipendierbarts": "ostipendierbar",
    "ostipulerade": "ostipulerad",
    "ostipulerades": "ostipulerad",
    "ostipulerads": "ostipulerad",
    "ostipulerat": "ostipulerad",
    "ostipulerats": "ostipulerad",
    "ostipulerbara": "ostipulerbar",
    "ostipulerbarare": "ostipulerbar",
    "ostipulerbarares": "ostipulerbar",
    "ostipulerbaras": "ostipulerbar",
    "ostipulerbarast": "ostipulerbar",
    "ostipulerbaraste": "ostipulerbar",
    "ostipulerbarastes": "ostipulerbar",
    "ostipulerbarasts": "ostipulerbar",
    "ostipulerbare": "ostipulerbar",
    "ostipulerbares": "ostipulerbar",
    "ostipulerbarheten": "ostipulerbarhet",
    "ostipulerbarhetens": "ostipulerbarhet",
    "ostipulerbarhets": "ostipulerbarhet",
    "ostipulerbars": "ostipulerbar",
    "ostipulerbart": "ostipulerbar",
    "ostipulerbarts": "ostipulerbar",
    "ostjaken": "ostjak",
    "ostjakens": "ostjak",
    "ostjaker": "ostjak",
    "ostjakerna": "ostjak",
    "ostjakernas": "ostjak",
    "ostjakers": "ostjak",
    "ostjakisk": "ostjakiska",
    "ostjakiska": "ostjakisk",
    "ostjakiskan": "ostjakiska",
    "ostjakiskans": "ostjakiska",
    "ostjakiskare": "ostjakisk",
    "ostjakiskares": "ostjakisk",
    "ostjakiskas": "ostjakiska",
    "ostjakiskast": "ostjakisk",
    "ostjakiskaste": "ostjakisk",
    "ostjakiskastes": "ostjakisk",
    "ostjakiskasts": "ostjakisk",
    "ostjakiske": "ostjakisk",
    "ostjakiskes": "ostjakisk",
    "ostjakisks": "ostjakisk",
    "ostjakiskt": "ostjakisk",
    "ostjakiskts": "ostjakisk",
    "ostjaks": "ostjak",
    "ostkak": "ostkaka",
    "ostkakan": "ostkaka",
    "ostkakans": "ostkaka",
    "ostkakas": "ostkaka",
    "ostkake": "ostkaka",
    "ostkakor": "ostkaka",
    "ostkakorna": "ostkaka",
    "ostkakornas": "ostkaka",
    "ostkakors": "ostkaka",
    "ostkaks": "ostkaka",
    "ostkanten": "ostkant",
    "ostkantens": "ostkant",
    "ostkanter": "ostkant",
    "ostkanterna": "ostkant",
    "ostkanternas": "ostkant",
    "ostkanters": "ostkant",
    "ostkants": "ostkant",
    "ostkrokar": "ostkrok",
    "ostkrokarna": "ostkrok",
    "ostkrokarnas": "ostkrok",
    "ostkrokars": "ostkrok",
    "ostkroken": "ostkrok",
    "ostkrokens": "ostkrok",
    "ostkroks": "ostkrok",
    "ostkrämen": "ostkräm",
    "ostkrämens": "ostkräm",
    "ostkrämer": "ostkräm",
    "ostkrämerna": "ostkräm",
    "ostkrämernas": "ostkräm",
    "ostkrämers": "ostkräm",
    "ostkräms": "ostkräm",
    "ostkup": "ostkupa",
    "ostkupan": "ostkupa",
    "ostkupans": "ostkupa",
    "ostkupas": "ostkupa",
    "ostkupe": "ostkupa",
    "ostkupor": "ostkupa",
    "ostkuporna": "ostkupa",
    "ostkupornas": "ostkupa",
    "ostkupors": "ostkupa",
    "ostkups": "ostkupa",
    "ostkusten": "ostkust",
    "ostkustens": "ostkust",
    "ostkuster": "ostkust",
    "ostkusterna": "ostkust",
    "ostkusternas": "ostkust",
    "ostkusters": "ostkust",
    "ostkusts": "ostkust",
    "ostliga": "ostlig",
    "ostligare": "ostlig",
    "ostligares": "ostlig",
    "ostligas": "ostlig",
    "ostligast": "ostlig",
    "ostligaste": "ostlig",
    "ostligastes": "ostlig",
    "ostligasts": "ostlig",
    "ostlige": "ostlig",
    "ostliges": "ostlig",
    "ostligs": "ostlig",
    "ostligt": "ostlig",
    "ostligts": "ostlig",
    "ostlöpes": "ostlöpe",
    "ostlöpet": "ostlöpe",
    "ostlöpets": "ostlöpe",
    "ostmaskar": "ostmask",
    "ostmaskarna": "ostmask",
    "ostmaskarnas": "ostmask",
    "ostmaskars": "ostmask",
    "ostmasken": "ostmask",
    "ostmaskens": "ostmask",
    "ostmasks": "ostmask",
    "ostmassan": "ostmassa",
    "ostmassans": "ostmassa",
    "ostmassas": "ostmassa",
    "ostmasse": "ostmassa",
    "ostofferade": "ostofferad",
    "ostofferades": "ostofferad",
    "ostofferads": "ostofferad",
    "ostofferat": "ostofferad",
    "ostofferats": "ostofferad",
    "ostofferbara": "ostofferbar",
    "ostofferbarare": "ostofferbar",
    "ostofferbarares": "ostofferbar",
    "ostofferbaras": "ostofferbar",
    "ostofferbarast": "ostofferbar",
    "ostofferbaraste": "ostofferbar",
    "ostofferbarastes": "ostofferbar",
    "ostofferbarasts": "ostofferbar",
    "ostofferbare": "ostofferbar",
    "ostofferbares": "ostofferbar",
    "ostofferbarheten": "ostofferbarhet",
    "ostofferbarhetens": "ostofferbarhet",
    "ostofferbarhets": "ostofferbarhet",
    "ostofferbars": "ostofferbar",
    "ostofferbart": "ostofferbar",
    "ostofferbarts": "ostofferbar",
    "ostr": "ostra",
    "ostracismen": "ostracism",
    "ostracismens": "ostracism",
    "ostracismer": "ostracism",
    "ostracismerna": "ostracism",
    "ostracismernas": "ostracism",
    "ostracismers": "ostracism",
    "ostracisms": "ostracism",
    "ostraffade": "ostraffad",
    "ostraffades": "ostraffad",
    "ostraffads": "ostraffad",
    "ostraffat": "ostraffad",
    "ostraffats": "ostraffad",
    "ostraffliga": "ostrafflig",
    "ostraffligare": "ostrafflig",
    "ostraffligares": "ostrafflig",
    "ostraffligas": "ostrafflig",
    "ostraffligast": "ostrafflig",
    "ostraffligaste": "ostrafflig",
    "ostraffligastes": "ostrafflig",
    "ostraffligasts": "ostrafflig",
    "ostrafflige": "ostrafflig",
    "ostraffliges": "ostrafflig",
    "ostraffligheten": "ostrafflighet",
    "ostrafflighetens": "ostrafflighet",
    "ostrafflighets": "ostrafflighet",
    "ostraffligs": "ostrafflig",
    "ostraffligt": "ostrafflig",
    "ostraffligts": "ostrafflig",
    "ostran": "ostra",
    "ostrangulerade": "ostrangulerad",
    "ostrangulerades": "ostrangulerad",
    "ostrangulerads": "ostrangulerad",
    "ostrangulerat": "ostrangulerad",
    "ostrangulerats": "ostrangulerad",
    "ostrangulerbara": "ostrangulerbar",
    "ostrangulerbarare": "ostrangulerbar",
    "ostrangulerbarares": "ostrangulerbar",
    "ostrangulerbaras": "ostrangulerbar",
    "ostrangulerbarast": "ostrangulerbar",
    "ostrangulerbaraste": "ostrangulerbar",
    "ostrangulerbarastes": "ostrangulerbar",
    "ostrangulerbarasts": "ostrangulerbar",
    "ostrangulerbare": "ostrangulerbar",
    "ostrangulerbares": "ostrangulerbar",
    "ostrangulerbarheten": "ostrangulerbarhet",
    "ostrangulerbarhetens": "ostrangulerbarhet",
    "ostrangulerbarhets": "ostrangulerbarhet",
    "ostrangulerbars": "ostrangulerbar",
    "ostrangulerbart": "ostrangulerbar",
    "ostrangulerbarts": "ostrangulerbar",
    "ostrans": "ostra",
    "ostras": "ostra",
    "ostratifierade": "ostratifierad",
    "ostratifierades": "ostratifierad",
    "ostratifierads": "ostratifierad",
    "ostratifierat": "ostratifierad",
    "ostratifierats": "ostratifierad",
    "ostratifierbara": "ostratifierbar",
    "ostratifierbarare": "ostratifierbar",
    "ostratifierbarares": "ostratifierbar",
    "ostratifierbaras": "ostratifierbar",
    "ostratifierbarast": "ostratifierbar",
    "ostratifierbaraste": "ostratifierbar",
    "ostratifierbarastes": "ostratifierbar",
    "ostratifierbarasts": "ostratifierbar",
    "ostratifierbare": "ostratifierbar",
    "ostratifierbares": "ostratifierbar",
    "ostratifierbarheten": "ostratifierbarhet",
    "ostratifierbarhetens": "ostratifierbarhet",
    "ostratifierbarhets": "ostratifierbarhet",
    "ostratifierbars": "ostratifierbar",
    "ostratifierbart": "ostratifierbar",
    "ostratifierbarts": "ostratifierbar",
    "ostre": "ostra",
    "ostresten": "ostrest",
    "ostrestens": "ostrest",
    "ostrester": "ostrest",
    "ostresterna": "ostrest",
    "ostresternas": "ostrest",
    "ostresters": "ostrest",
    "ostrests": "ostrest",
    "ostridiga": "ostridig",
    "ostridigare": "ostridig",
    "ostridigares": "ostridig",
    "ostridigas": "ostridig",
    "ostridigast": "ostridig",
    "ostridigaste": "ostridig",
    "ostridigastes": "ostridig",
    "ostridigasts": "ostridig",
    "ostridige": "ostridig",
    "ostridiges": "ostridig",
    "ostridigheten": "ostridighet",
    "ostridighetens": "ostridighet",
    "ostridighets": "ostridighet",
    "ostridigs": "ostridig",
    "ostridigt": "ostridig",
    "ostridigts": "ostridig",
    "ostronbankar": "ostronbank",
    "ostronbankarna": "ostronbank",
    "ostronbankarnas": "ostronbank",
    "ostronbankars": "ostronbank",
    "ostronbanken": "ostronbank",
    "ostronbankens": "ostronbank",
    "ostronbanks": "ostronbank",
    "ostronen": "ostron",
    "ostronens": "ostron",
    "ostronet": "ostron",
    "ostronets": "ostron",
    "ostronförgiftningar": "ostronförgiftning",
    "ostronförgiftningarna": "ostronförgiftning",
    "ostronförgiftningarnas": "ostronförgiftning",
    "ostronförgiftningars": "ostronförgiftning",
    "ostronförgiftningen": "ostronförgiftning",
    "ostronförgiftningens": "ostronförgiftning",
    "ostronförgiftnings": "ostronförgiftning",
    "ostronknivar": "ostronkniv",
    "ostronknivarna": "ostronkniv",
    "ostronknivarnas": "ostronkniv",
    "ostronknivars": "ostronkniv",
    "ostronkniven": "ostronkniv",
    "ostronknivens": "ostronkniv",
    "ostronknivs": "ostronkniv",
    "ostrons": "ostron",
    "ostronskalen": "ostronskal",
    "ostronskalens": "ostronskal",
    "ostronskalet": "ostronskal",
    "ostronskalets": "ostronskal",
    "ostronskals": "ostronskal",
    "ostronörten": "ostronört",
    "ostronörtens": "ostronört",
    "ostronörts": "ostronört",
    "ostror": "ostra",
    "ostrorna": "ostra",
    "ostrornas": "ostra",
    "ostrors": "ostra",
    "ostrs": "ostra",
    "ostrukens": "ostruken",
    "ostruket": "ostruken",
    "ostrukets": "ostruken",
    "ostrukna": "ostruken",
    "ostruknare": "ostruken",
    "ostruknares": "ostruken",
    "ostruknas": "ostruken",
    "ostruknast": "ostruken",
    "ostruknaste": "ostruken",
    "ostruknastes": "ostruken",
    "ostruknasts": "ostruken",
    "ostrukne": "ostruken",
    "ostruknes": "ostruken",
    "ostrukturerade": "ostrukturerad",
    "ostrukturerades": "ostrukturerad",
    "ostrukturerads": "ostrukturerad",
    "ostrukturerat": "ostrukturerad",
    "ostrukturerats": "ostrukturerad",
    "ostrukturerbara": "ostrukturerbar",
    "ostrukturerbarare": "ostrukturerbar",
    "ostrukturerbarares": "ostrukturerbar",
    "ostrukturerbaras": "ostrukturerbar",
    "ostrukturerbarast": "ostrukturerbar",
    "ostrukturerbaraste": "ostrukturerbar",
    "ostrukturerbarastes": "ostrukturerbar",
    "ostrukturerbarasts": "ostrukturerbar",
    "ostrukturerbare": "ostrukturerbar",
    "ostrukturerbares": "ostrukturerbar",
    "ostrukturerbarheten": "ostrukturerbarhet",
    "ostrukturerbarhetens": "ostrukturerbarhet",
    "ostrukturerbarhets": "ostrukturerbarhet",
    "ostrukturerbars": "ostrukturerbar",
    "ostrukturerbart": "ostrukturerbar",
    "ostrukturerbarts": "ostrukturerbar",
    "osts": "ost",
    "ostskalkar": "ostskalk",
    "ostskalkarna": "ostskalk",
    "ostskalkarnas": "ostskalk",
    "ostskalkars": "ostskalk",
    "ostskalken": "ostskalk",
    "ostskalkens": "ostskalk",
    "ostskalks": "ostskalk",
    "ostskivan": "ostskiva",
    "ostskivans": "ostskiva",
    "ostskivas": "ostskiva",
    "ostskive": "ostskiva",
    "ostskivor": "ostskiva",
    "ostskivorna": "ostskiva",
    "ostskivornas": "ostskiva",
    "ostskivors": "ostskiva",
    "ostskärar": "ostskärare",
    "ostskäraren": "ostskärare",
    "ostskärarens": "ostskärare",
    "ostskärares": "ostskärare",
    "ostskärarna": "ostskärare",
    "ostskärarnas": "ostskärare",
    "ostsmörgåsar": "ostsmörgås",
    "ostsmörgåsarna": "ostsmörgås",
    "ostsmörgåsarnas": "ostsmörgås",
    "ostsmörgåsars": "ostsmörgås",
    "ostsmörgåsen": "ostsmörgås",
    "ostsmörgåsens": "ostsmörgås",
    "oststänger": "oststång",
    "oststängerna": "oststång",
    "oststängernas": "oststång",
    "oststängers": "oststång",
    "oststången": "oststång",
    "oststångens": "oststång",
    "oststångs": "oststång",
    "ostuderade": "ostuderad",
    "ostuderades": "ostuderad",
    "ostuderads": "ostuderad",
    "ostuderat": "ostuderad",
    "ostuderats": "ostuderad",
    "ostuderbara": "ostuderbar",
    "ostuderbarare": "ostuderbar",
    "ostuderbarares": "ostuderbar",
    "ostuderbaras": "ostuderbar",
    "ostuderbarast": "ostuderbar",
    "ostuderbaraste": "ostuderbar",
    "ostuderbarastes": "ostuderbar",
    "ostuderbarasts": "ostuderbar",
    "ostuderbare": "ostuderbar",
    "ostuderbares": "ostuderbar",
    "ostuderbarheten": "ostuderbarhet",
    "ostuderbarhetens": "ostuderbarhet",
    "ostuderbarhets": "ostuderbarhet",
    "ostuderbars": "ostuderbar",
    "ostuderbart": "ostuderbar",
    "ostuderbarts": "ostuderbar",
    "ostvasslan": "ostvassla",
    "ostvasslans": "ostvassla",
    "ostvasslas": "ostvassla",
    "ostyckade": "ostyckad",
    "ostyckades": "ostyckad",
    "ostyckads": "ostyckad",
    "ostyckat": "ostyckad",
    "ostyckats": "ostyckad",
    "ostyriga": "ostyrig",
    "ostyrigare": "ostyrig",
    "ostyrigares": "ostyrig",
    "ostyrigas": "ostyrig",
    "ostyrigast": "ostyrig",
    "ostyrigaste": "ostyrig",
    "ostyrigastes": "ostyrig",
    "ostyrigasts": "ostyrig",
    "ostyrige": "ostyrig",
    "ostyriges": "ostyrig",
    "ostyrigheten": "ostyrighet",
    "ostyrighetens": "ostyrighet",
    "ostyrighets": "ostyrighet",
    "ostyrigs": "ostyrig",
    "ostyrigt": "ostyrig",
    "ostyrigts": "ostyrig",
    "ostyrkta": "ostyrkt",
    "ostyrktare": "ostyrkt",
    "ostyrktares": "ostyrkt",
    "ostyrktas": "ostyrkt",
    "ostyrktast": "ostyrkt",
    "ostyrktaste": "ostyrkt",
    "ostyrktastes": "ostyrkt",
    "ostyrktasts": "ostyrkt",
    "ostyrkte": "ostyrkt",
    "ostyrktes": "ostyrkt",
    "ostyrkts": "ostyrkt",
    "ostädade": "ostädad",
    "ostädades": "ostädad",
    "ostädads": "ostädad",
    "ostädat": "ostädad",
    "ostädats": "ostädad",
    "ostämda": "ostämd",
    "ostämdare": "ostämd",
    "ostämdares": "ostämd",
    "ostämdas": "ostämd",
    "ostämdast": "ostämd",
    "ostämdaste": "ostämd",
    "ostämdastes": "ostämd",
    "ostämdasts": "ostämd",
    "ostämde": "ostämd",
    "ostämdes": "ostämd",
    "ostämdheten": "ostämdhet",
    "ostämdhetens": "ostämdhet",
    "ostämdhets": "ostämdhet",
    "ostämds": "ostämd",
    "ostämnes": "ostämne",
    "ostämnet": "ostämne",
    "ostämnets": "ostämne",
    "ostämplade": "ostämplad",
    "ostämplades": "ostämplad",
    "ostämplads": "ostämplad",
    "ostämplat": "ostämplad",
    "ostämplats": "ostämplad",
    "ostämt": "ostämd",
    "ostämts": "ostämd",
    "ostärkta": "ostärkt",
    "ostärktare": "ostärkt",
    "ostärktares": "ostärkt",
    "ostärktas": "ostärkt",
    "ostärktast": "ostärkt",
    "ostärktaste": "ostärkt",
    "ostärktastes": "ostärkt",
    "ostärktasts": "ostärkt",
    "ostärkte": "ostärkt",
    "ostärktes": "ostärkt",
    "ostärkts": "ostärkt",
    "ostörda": "ostörd",
    "ostördare": "ostörd",
    "ostördares": "ostörd",
    "ostördas": "ostörd",
    "ostördast": "ostörd",
    "ostördaste": "ostörd",
    "ostördastes": "ostörd",
    "ostördasts": "ostörd",
    "ostörde": "ostörd",
    "ostördes": "ostörd",
    "ostördheten": "ostördhet",
    "ostördhetens": "ostördhet",
    "ostördhets": "ostördhet",
    "ostörds": "ostörd",
    "ostört": "ostörd",
    "ostörts": "ostörd",
    "osublimerade": "osublimerad",
    "osublimerades": "osublimerad",
    "osublimerads": "osublimerad",
    "osublimerat": "osublimerad",
    "osublimerats": "osublimerad",
    "osublimerbara": "osublimerbar",
    "osublimerbarare": "osublimerbar",
    "osublimerbarares": "osublimerbar",
    "osublimerbaras": "osublimerbar",
    "osublimerbarast": "osublimerbar",
    "osublimerbaraste": "osublimerbar",
    "osublimerbarastes": "osublimerbar",
    "osublimerbarasts": "osublimerbar",
    "osublimerbare": "osublimerbar",
    "osublimerbares": "osublimerbar",
    "osublimerbarheten": "osublimerbarhet",
    "osublimerbarhetens": "osublimerbarhet",
    "osublimerbarhets": "osublimerbarhet",
    "osublimerbars": "osublimerbar",
    "osublimerbart": "osublimerbar",
    "osublimerbarts": "osublimerbar",
    "osubordinerade": "osubordinerad",
    "osubordinerades": "osubordinerad",
    "osubordinerads": "osubordinerad",
    "osubordinerat": "osubordinerad",
    "osubordinerats": "osubordinerad",
    "osubordinerbara": "osubordinerbar",
    "osubordinerbarare": "osubordinerbar",
    "osubordinerbarares": "osubordinerbar",
    "osubordinerbaras": "osubordinerbar",
    "osubordinerbarast": "osubordinerbar",
    "osubordinerbaraste": "osubordinerbar",
    "osubordinerbarastes": "osubordinerbar",
    "osubordinerbarasts": "osubordinerbar",
    "osubordinerbare": "osubordinerbar",
    "osubordinerbares": "osubordinerbar",
    "osubordinerbarheten": "osubordinerbarhet",
    "osubordinerbarhetens": "osubordinerbarhet",
    "osubordinerbarhets": "osubordinerbarhet",
    "osubordinerbars": "osubordinerbar",
    "osubordinerbart": "osubordinerbar",
    "osubordinerbarts": "osubordinerbar",
    "osubsidierade": "osubsidierad",
    "osubsidierades": "osubsidierad",
    "osubsidierads": "osubsidierad",
    "osubsidierat": "osubsidierad",
    "osubsidierats": "osubsidierad",
    "osubsidierbara": "osubsidierbar",
    "osubsidierbarare": "osubsidierbar",
    "osubsidierbarares": "osubsidierbar",
    "osubsidierbaras": "osubsidierbar",
    "osubsidierbarast": "osubsidierbar",
    "osubsidierbaraste": "osubsidierbar",
    "osubsidierbarastes": "osubsidierbar",
    "osubsidierbarasts": "osubsidierbar",
    "osubsidierbare": "osubsidierbar",
    "osubsidierbares": "osubsidierbar",
    "osubsidierbarheten": "osubsidierbarhet",
    "osubsidierbarhetens": "osubsidierbarhet",
    "osubsidierbarhets": "osubsidierbarhet",
    "osubsidierbars": "osubsidierbar",
    "osubsidierbart": "osubsidierbar",
    "osubsidierbarts": "osubsidierbar",
    "osubskriberade": "osubskriberad",
    "osubskriberades": "osubskriberad",
    "osubskriberads": "osubskriberad",
    "osubskriberat": "osubskriberad",
    "osubskriberats": "osubskriberad",
    "osubskriberbara": "osubskriberbar",
    "osubskriberbarare": "osubskriberbar",
    "osubskriberbarares": "osubskriberbar",
    "osubskriberbaras": "osubskriberbar",
    "osubskriberbarast": "osubskriberbar",
    "osubskriberbaraste": "osubskriberbar",
    "osubskriberbarastes": "osubskriberbar",
    "osubskriberbarasts": "osubskriberbar",
    "osubskriberbare": "osubskriberbar",
    "osubskriberbares": "osubskriberbar",
    "osubskriberbarheten": "osubskriberbarhet",
    "osubskriberbarhetens": "osubskriberbarhet",
    "osubskriberbarhets": "osubskriberbarhet",
    "osubskriberbars": "osubskriberbar",
    "osubskriberbart": "osubskriberbar",
    "osubskriberbarts": "osubskriberbar",
    "osubstantiverade": "osubstantiverad",
    "osubstantiverades": "osubstantiverad",
    "osubstantiverads": "osubstantiverad",
    "osubstantiverat": "osubstantiverad",
    "osubstantiverats": "osubstantiverad",
    "osubstantiverbara": "osubstantiverbar",
    "osubstantiverbarare": "osubstantiverbar",
    "osubstantiverbarares": "osubstantiverbar",
    "osubstantiverbaras": "osubstantiverbar",
    "osubstantiverbarast": "osubstantiverbar",
    "osubstantiverbaraste": "osubstantiverbar",
    "osubstantiverbarastes": "osubstantiverbar",
    "osubstantiverbarasts": "osubstantiverbar",
    "osubstantiverbare": "osubstantiverbar",
    "osubstantiverbares": "osubstantiverbar",
    "osubstantiverbarheten": "osubstantiverbarhet",
    "osubstantiverbarhetens": "osubstantiverbarhet",
    "osubstantiverbarhets": "osubstantiverbarhet",
    "osubstantiverbars": "osubstantiverbar",
    "osubstantiverbart": "osubstantiverbar",
    "osubstantiverbarts": "osubstantiverbar",
    "osubstituerade": "osubstituerad",
    "osubstituerades": "osubstituerad",
    "osubstituerads": "osubstituerad",
    "osubstituerat": "osubstituerad",
    "osubstituerats": "osubstituerad",
    "osubstituerbara": "osubstituerbar",
    "osubstituerbarare": "osubstituerbar",
    "osubstituerbarares": "osubstituerbar",
    "osubstituerbaras": "osubstituerbar",
    "osubstituerbarast": "osubstituerbar",
    "osubstituerbaraste": "osubstituerbar",
    "osubstituerbarastes": "osubstituerbar",
    "osubstituerbarasts": "osubstituerbar",
    "osubstituerbare": "osubstituerbar",
    "osubstituerbares": "osubstituerbar",
    "osubstituerbarheten": "osubstituerbarhet",
    "osubstituerbarhetens": "osubstituerbarhet",
    "osubstituerbarhets": "osubstituerbarhet",
    "osubstituerbars": "osubstituerbar",
    "osubstituerbart": "osubstituerbar",
    "osubstituerbarts": "osubstituerbar",
    "osubsumerade": "osubsumerad",
    "osubsumerades": "osubsumerad",
    "osubsumerads": "osubsumerad",
    "osubsumerat": "osubsumerad",
    "osubsumerats": "osubsumerad",
    "osubsumerbara": "osubsumerbar",
    "osubsumerbarare": "osubsumerbar",
    "osubsumerbarares": "osubsumerbar",
    "osubsumerbaras": "osubsumerbar",
    "osubsumerbarast": "osubsumerbar",
    "osubsumerbaraste": "osubsumerbar",
    "osubsumerbarastes": "osubsumerbar",
    "osubsumerbarasts": "osubsumerbar",
    "osubsumerbare": "osubsumerbar",
    "osubsumerbares": "osubsumerbar",
    "osubsumerbarheten": "osubsumerbarhet",
    "osubsumerbarhetens": "osubsumerbarhet",
    "osubsumerbarhets": "osubsumerbarhet",
    "osubsumerbars": "osubsumerbar",
    "osubsumerbart": "osubsumerbar",
    "osubsumerbarts": "osubsumerbar",
    "osubtraherade": "osubtraherad",
    "osubtraherades": "osubtraherad",
    "osubtraherads": "osubtraherad",
    "osubtraherat": "osubtraherad",
    "osubtraherats": "osubtraherad",
    "osubtraherbara": "osubtraherbar",
    "osubtraherbarare": "osubtraherbar",
    "osubtraherbarares": "osubtraherbar",
    "osubtraherbaras": "osubtraherbar",
    "osubtraherbarast": "osubtraherbar",
    "osubtraherbaraste": "osubtraherbar",
    "osubtraherbarastes": "osubtraherbar",
    "osubtraherbarasts": "osubtraherbar",
    "osubtraherbare": "osubtraherbar",
    "osubtraherbares": "osubtraherbar",
    "osubtraherbarheten": "osubtraherbarhet",
    "osubtraherbarhetens": "osubtraherbarhet",
    "osubtraherbarhets": "osubtraherbarhet",
    "osubtraherbars": "osubtraherbar",
    "osubtraherbart": "osubtraherbar",
    "osubtraherbarts": "osubtraherbar",
    "osubventionerade": "osubventionerad",
    "osubventionerades": "osubventionerad",
    "osubventionerads": "osubventionerad",
    "osubventionerat": "osubventionerad",
    "osubventionerats": "osubventionerad",
    "osubventionerbara": "osubventionerbar",
    "osubventionerbarare": "osubventionerbar",
    "osubventionerbarares": "osubventionerbar",
    "osubventionerbaras": "osubventionerbar",
    "osubventionerbarast": "osubventionerbar",
    "osubventionerbaraste": "osubventionerbar",
    "osubventionerbarastes": "osubventionerbar",
    "osubventionerbarasts": "osubventionerbar",
    "osubventionerbare": "osubventionerbar",
    "osubventionerbares": "osubventionerbar",
    "osubventionerbarheten": "osubventionerbarhet",
    "osubventionerbarhetens": "osubventionerbarhet",
    "osubventionerbarhets": "osubventionerbarhet",
    "osubventionerbars": "osubventionerbar",
    "osubventionerbart": "osubventionerbar",
    "osubventionerbarts": "osubventionerbar",
    "osuccederade": "osuccederad",
    "osuccederades": "osuccederad",
    "osuccederads": "osuccederad",
    "osuccederat": "osuccederad",
    "osuccederats": "osuccederad",
    "osuccederbara": "osuccederbar",
    "osuccederbarare": "osuccederbar",
    "osuccederbarares": "osuccederbar",
    "osuccederbaras": "osuccederbar",
    "osuccederbarast": "osuccederbar",
    "osuccederbaraste": "osuccederbar",
    "osuccederbarastes": "osuccederbar",
    "osuccederbarasts": "osuccederbar",
    "osuccederbare": "osuccederbar",
    "osuccederbares": "osuccederbar",
    "osuccederbarheten": "osuccederbarhet",
    "osuccederbarhetens": "osuccederbarhet",
    "osuccederbarhets": "osuccederbarhet",
    "osuccederbars": "osuccederbar",
    "osuccederbart": "osuccederbar",
    "osuccederbarts": "osuccederbar",
    "osuffigerade": "osuffigerad",
    "osuffigerades": "osuffigerad",
    "osuffigerads": "osuffigerad",
    "osuffigerat": "osuffigerad",
    "osuffigerats": "osuffigerad",
    "osuffigerbara": "osuffigerbar",
    "osuffigerbarare": "osuffigerbar",
    "osuffigerbarares": "osuffigerbar",
    "osuffigerbaras": "osuffigerbar",
    "osuffigerbarast": "osuffigerbar",
    "osuffigerbaraste": "osuffigerbar",
    "osuffigerbarastes": "osuffigerbar",
    "osuffigerbarasts": "osuffigerbar",
    "osuffigerbare": "osuffigerbar",
    "osuffigerbares": "osuffigerbar",
    "osuffigerbarheten": "osuffigerbarhet",
    "osuffigerbarhetens": "osuffigerbarhet",
    "osuffigerbarhets": "osuffigerbarhet",
    "osuffigerbars": "osuffigerbar",
    "osuffigerbart": "osuffigerbar",
    "osuffigerbarts": "osuffigerbar",
    "osufflerade": "osufflerad",
    "osufflerades": "osufflerad",
    "osufflerads": "osufflerad",
    "osufflerat": "osufflerad",
    "osufflerats": "osufflerad",
    "osufflerbara": "osufflerbar",
    "osufflerbarare": "osufflerbar",
    "osufflerbarares": "osufflerbar",
    "osufflerbaras": "osufflerbar",
    "osufflerbarast": "osufflerbar",
    "osufflerbaraste": "osufflerbar",
    "osufflerbarastes": "osufflerbar",
    "osufflerbarasts": "osufflerbar",
    "osufflerbare": "osufflerbar",
    "osufflerbares": "osufflerbar",
    "osufflerbarheten": "osufflerbarhet",
    "osufflerbarhetens": "osufflerbarhet",
    "osufflerbarhets": "osufflerbarhet",
    "osufflerbars": "osufflerbar",
    "osufflerbart": "osufflerbar",
    "osufflerbarts": "osufflerbar",
    "osuggererade": "osuggererad",
    "osuggererades": "osuggererad",
    "osuggererads": "osuggererad",
    "osuggererat": "osuggererad",
    "osuggererats": "osuggererad",
    "osuggererbara": "osuggererbar",
    "osuggererbarare": "osuggererbar",
    "osuggererbarares": "osuggererbar",
    "osuggererbaras": "osuggererbar",
    "osuggererbarast": "osuggererbar",
    "osuggererbaraste": "osuggererbar",
    "osuggererbarastes": "osuggererbar",
    "osuggererbarasts": "osuggererbar",
    "osuggererbare": "osuggererbar",
    "osuggererbares": "osuggererbar",
    "osuggererbarheten": "osuggererbarhet",
    "osuggererbarhetens": "osuggererbarhet",
    "osuggererbarhets": "osuggererbarhet",
    "osuggererbars": "osuggererbar",
    "osuggererbart": "osuggererbar",
    "osuggererbarts": "osuggererbar",
    "osummerade": "osummerad",
    "osummerades": "osummerad",
    "osummerads": "osummerad",
    "osummerat": "osummerad",
    "osummerats": "osummerad",
    "osummerbara": "osummerbar",
    "osummerbarare": "osummerbar",
    "osummerbarares": "osummerbar",
    "osummerbaras": "osummerbar",
    "osummerbarast": "osummerbar",
    "osummerbaraste": "osummerbar",
    "osummerbarastes": "osummerbar",
    "osummerbarasts": "osummerbar",
    "osummerbare": "osummerbar",
    "osummerbares": "osummerbar",
    "osummerbarheten": "osummerbarhet",
    "osummerbarhetens": "osummerbarhet",
    "osummerbarhets": "osummerbarhet",
    "osummerbars": "osummerbar",
    "osummerbart": "osummerbar",
    "osummerbarts": "osummerbar",
    "osunda": "osund",
    "osundare": "osund",
    "osundares": "osund",
    "osundas": "osund",
    "osundast": "osund",
    "osundaste": "osund",
    "osundastes": "osund",
    "osundasts": "osund",
    "osunde": "osund",
    "osundes": "osund",
    "osundheten": "osundhet",
    "osundhetens": "osundhet",
    "osundheter": "osundhet",
    "osundheterna": "osundhet",
    "osundheternas": "osundhet",
    "osundheters": "osundhet",
    "osundhets": "osundhet",
    "osunds": "osund",
    "osunt": "osund",
    "osunts": "osund",
    "osupplerade": "osupplerad",
    "osupplerades": "osupplerad",
    "osupplerads": "osupplerad",
    "osupplerat": "osupplerad",
    "osupplerats": "osupplerad",
    "osupplerbara": "osupplerbar",
    "osupplerbarare": "osupplerbar",
    "osupplerbarares": "osupplerbar",
    "osupplerbaras": "osupplerbar",
    "osupplerbarast": "osupplerbar",
    "osupplerbaraste": "osupplerbar",
    "osupplerbarastes": "osupplerbar",
    "osupplerbarasts": "osupplerbar",
    "osupplerbare": "osupplerbar",
    "osupplerbares": "osupplerbar",
    "osupplerbarheten": "osupplerbarhet",
    "osupplerbarhetens": "osupplerbarhet",
    "osupplerbarhets": "osupplerbarhet",
    "osupplerbars": "osupplerbar",
    "osupplerbart": "osupplerbar",
    "osupplerbarts": "osupplerbar",
    "osupponerade": "osupponerad",
    "osupponerades": "osupponerad",
    "osupponerads": "osupponerad",
    "osupponerat": "osupponerad",
    "osupponerats": "osupponerad",
    "osupponerbara": "osupponerbar",
    "osupponerbarare": "osupponerbar",
    "osupponerbarares": "osupponerbar",
    "osupponerbaras": "osupponerbar",
    "osupponerbarast": "osupponerbar",
    "osupponerbaraste": "osupponerbar",
    "osupponerbarastes": "osupponerbar",
    "osupponerbarasts": "osupponerbar",
    "osupponerbare": "osupponerbar",
    "osupponerbares": "osupponerbar",
    "osupponerbarheten": "osupponerbarhet",
    "osupponerbarhetens": "osupponerbarhet",
    "osupponerbarhets": "osupponerbarhet",
    "osupponerbars": "osupponerbar",
    "osupponerbart": "osupponerbar",
    "osupponerbarts": "osupponerbar",
    "osurfbara": "osurfbar",
    "osurfbarare": "osurfbar",
    "osurfbarares": "osurfbar",
    "osurfbaras": "osurfbar",
    "osurfbarast": "osurfbar",
    "osurfbaraste": "osurfbar",
    "osurfbarastes": "osurfbar",
    "osurfbarasts": "osurfbar",
    "osurfbare": "osurfbar",
    "osurfbares": "osurfbar",
    "osurfbarheten": "osurfbarhet",
    "osurfbarhetens": "osurfbarhet",
    "osurfbarhets": "osurfbarhet",
    "osurfbars": "osurfbar",
    "osurfbart": "osurfbar",
    "osurfbarts": "osurfbar",
    "osuspenderade": "osuspenderad",
    "osuspenderades": "osuspenderad",
    "osuspenderads": "osuspenderad",
    "osuspenderat": "osuspenderad",
    "osuspenderats": "osuspenderad",
    "osuspenderbara": "osuspenderbar",
    "osuspenderbarare": "osuspenderbar",
    "osuspenderbarares": "osuspenderbar",
    "osuspenderbaras": "osuspenderbar",
    "osuspenderbarast": "osuspenderbar",
    "osuspenderbaraste": "osuspenderbar",
    "osuspenderbarastes": "osuspenderbar",
    "osuspenderbarasts": "osuspenderbar",
    "osuspenderbare": "osuspenderbar",
    "osuspenderbares": "osuspenderbar",
    "osuspenderbarheten": "osuspenderbarhet",
    "osuspenderbarhetens": "osuspenderbarhet",
    "osuspenderbarhets": "osuspenderbarhet",
    "osuspenderbars": "osuspenderbar",
    "osuspenderbart": "osuspenderbar",
    "osuspenderbarts": "osuspenderbar",
    "osvenska": "osvensk",
    "osvenskare": "osvensk",
    "osvenskares": "osvensk",
    "osvenskas": "osvensk",
    "osvenskast": "osvensk",
    "osvenskaste": "osvensk",
    "osvenskastes": "osvensk",
    "osvenskasts": "osvensk",
    "osvenske": "osvensk",
    "osvenskes": "osvensk",
    "osvensks": "osvensk",
    "osvenskt": "osvensk",
    "osvenskts": "osvensk",
    "osvikliga": "osviklig",
    "osvikligare": "osviklig",
    "osvikligares": "osviklig",
    "osvikligas": "osviklig",
    "osvikligast": "osviklig",
    "osvikligaste": "osviklig",
    "osvikligastes": "osviklig",
    "osvikligasts": "osviklig",
    "osviklige": "osviklig",
    "osvikliges": "osviklig",
    "osvikligheten": "osviklighet",
    "osviklighetens": "osviklighet",
    "osviklighets": "osviklighet",
    "osvikligs": "osviklig",
    "osvikligt": "osviklig",
    "osvikligts": "osviklig",
    "osvurens": "osvuren",
    "osvuret": "osvuren",
    "osvurets": "osvuren",
    "osvurna": "osvuren",
    "osvurnare": "osvuren",
    "osvurnares": "osvuren",
    "osvurnas": "osvuren",
    "osvurnast": "osvuren",
    "osvurnaste": "osvuren",
    "osvurnastes": "osvuren",
    "osvurnasts": "osvuren",
    "osvurne": "osvuren",
    "osvurnes": "osvuren",
    "osymboliserade": "osymboliserad",
    "osymboliserades": "osymboliserad",
    "osymboliserads": "osymboliserad",
    "osymboliserat": "osymboliserad",
    "osymboliserats": "osymboliserad",
    "osymboliserbara": "osymboliserbar",
    "osymboliserbarare": "osymboliserbar",
    "osymboliserbarares": "osymboliserbar",
    "osymboliserbaras": "osymboliserbar",
    "osymboliserbarast": "osymboliserbar",
    "osymboliserbaraste": "osymboliserbar",
    "osymboliserbarastes": "osymboliserbar",
    "osymboliserbarasts": "osymboliserbar",
    "osymboliserbare": "osymboliserbar",
    "osymboliserbares": "osymboliserbar",
    "osymboliserbarheten": "osymboliserbarhet",
    "osymboliserbarhetens": "osymboliserbarhet",
    "osymboliserbarhets": "osymboliserbarhet",
    "osymboliserbars": "osymboliserbar",
    "osymboliserbart": "osymboliserbar",
    "osymboliserbarts": "osymboliserbar",
    "osymmetriska": "osymmetrisk",
    "osymmetriskare": "osymmetrisk",
    "osymmetriskares": "osymmetrisk",
    "osymmetriskas": "osymmetrisk",
    "osymmetriskast": "osymmetrisk",
    "osymmetriskaste": "osymmetrisk",
    "osymmetriskastes": "osymmetrisk",
    "osymmetriskasts": "osymmetrisk",
    "osymmetriske": "osymmetrisk",
    "osymmetriskes": "osymmetrisk",
    "osymmetrisks": "osymmetrisk",
    "osymmetriskt": "osymmetrisk",
    "osymmetriskts": "osymmetrisk",
    "osympatiska": "osympatisk",
    "osympatiskare": "osympatisk",
    "osympatiskares": "osympatisk",
    "osympatiskas": "osympatisk",
    "osympatiskast": "osympatisk",
    "osympatiskaste": "osympatisk",
    "osympatiskastes": "osympatisk",
    "osympatiskasts": "osympatisk",
    "osympatiske": "osympatisk",
    "osympatiskes": "osympatisk",
    "osympatisks": "osympatisk",
    "osympatiskt": "osympatisk",
    "osympatiskts": "osympatisk",
    "osynkoperade": "osynkoperad",
    "osynkoperades": "osynkoperad",
    "osynkoperads": "osynkoperad",
    "osynkoperat": "osynkoperad",
    "osynkoperats": "osynkoperad",
    "osynkoperbara": "osynkoperbar",
    "osynkoperbarare": "osynkoperbar",
    "osynkoperbarares": "osynkoperbar",
    "osynkoperbaras": "osynkoperbar",
    "osynkoperbarast": "osynkoperbar",
    "osynkoperbaraste": "osynkoperbar",
    "osynkoperbarastes": "osynkoperbar",
    "osynkoperbarasts": "osynkoperbar",
    "osynkoperbare": "osynkoperbar",
    "osynkoperbares": "osynkoperbar",
    "osynkoperbarheten": "osynkoperbarhet",
    "osynkoperbarhetens": "osynkoperbarhet",
    "osynkoperbarhets": "osynkoperbarhet",
    "osynkoperbars": "osynkoperbar",
    "osynkoperbart": "osynkoperbar",
    "osynkoperbarts": "osynkoperbar",
    "osynkroniserade": "osynkroniserad",
    "osynkroniserades": "osynkroniserad",
    "osynkroniserads": "osynkroniserad",
    "osynkroniserat": "osynkroniserad",
    "osynkroniserats": "osynkroniserad",
    "osynkroniserbara": "osynkroniserbar",
    "osynkroniserbarare": "osynkroniserbar",
    "osynkroniserbarares": "osynkroniserbar",
    "osynkroniserbaras": "osynkroniserbar",
    "osynkroniserbarast": "osynkroniserbar",
    "osynkroniserbaraste": "osynkroniserbar",
    "osynkroniserbarastes": "osynkroniserbar",
    "osynkroniserbarasts": "osynkroniserbar",
    "osynkroniserbare": "osynkroniserbar",
    "osynkroniserbares": "osynkroniserbar",
    "osynkroniserbarheten": "osynkroniserbarhet",
    "osynkroniserbarhetens": "osynkroniserbarhet",
    "osynkroniserbarhets": "osynkroniserbarhet",
    "osynkroniserbars": "osynkroniserbar",
    "osynkroniserbart": "osynkroniserbar",
    "osynkroniserbarts": "osynkroniserbar",
    "osynliga": "osynlig",
    "osynligare": "osynlig",
    "osynligares": "osynlig",
    "osynligas": "osynlig",
    "osynligast": "osynlig",
    "osynligaste": "osynlig",
    "osynligastes": "osynlig",
    "osynligasts": "osynlig",
    "osynlige": "osynlig",
    "osynliges": "osynlig",
    "osynligheten": "osynlighet",
    "osynlighetens": "osynlighet",
    "osynligheter": "osynlighet",
    "osynligheterna": "osynlighet",
    "osynligheternas": "osynlighet",
    "osynligheters": "osynlighet",
    "osynlighets": "osynlighet",
    "osynligs": "osynlig",
    "osynligt": "osynlig",
    "osynligts": "osynlig",
    "osyntetiserade": "osyntetiserad",
    "osyntetiserades": "osyntetiserad",
    "osyntetiserads": "osyntetiserad",
    "osyntetiserat": "osyntetiserad",
    "osyntetiserats": "osyntetiserad",
    "osyntetiserbara": "osyntetiserbar",
    "osyntetiserbarare": "osyntetiserbar",
    "osyntetiserbarares": "osyntetiserbar",
    "osyntetiserbaras": "osyntetiserbar",
    "osyntetiserbarast": "osyntetiserbar",
    "osyntetiserbaraste": "osyntetiserbar",
    "osyntetiserbarastes": "osyntetiserbar",
    "osyntetiserbarasts": "osyntetiserbar",
    "osyntetiserbare": "osyntetiserbar",
    "osyntetiserbares": "osyntetiserbar",
    "osyntetiserbarheten": "osyntetiserbarhet",
    "osyntetiserbarhetens": "osyntetiserbarhet",
    "osyntetiserbarhets": "osyntetiserbarhet",
    "osyntetiserbars": "osyntetiserbar",
    "osyntetiserbart": "osyntetiserbar",
    "osyntetiserbarts": "osyntetiserbar",
    "osyrade": "osyrad",
    "osyrades": "osyrad",
    "osyrads": "osyrad",
    "osyrat": "osyrad",
    "osyrats": "osyrad",
    "osystematiserade": "osystematiserad",
    "osystematiserades": "osystematiserad",
    "osystematiserads": "osystematiserad",
    "osystematiserat": "osystematiserad",
    "osystematiserats": "osystematiserad",
    "osystematiserbara": "osystematiserbar",
    "osystematiserbarare": "osystematiserbar",
    "osystematiserbarares": "osystematiserbar",
    "osystematiserbaras": "osystematiserbar",
    "osystematiserbarast": "osystematiserbar",
    "osystematiserbaraste": "osystematiserbar",
    "osystematiserbarastes": "osystematiserbar",
    "osystematiserbarasts": "osystematiserbar",
    "osystematiserbare": "osystematiserbar",
    "osystematiserbares": "osystematiserbar",
    "osystematiserbarheten": "osystematiserbarhet",
    "osystematiserbarhetens": "osystematiserbarhet",
    "osystematiserbarhets": "osystematiserbarhet",
    "osystematiserbars": "osystematiserbar",
    "osystematiserbart": "osystematiserbar",
    "osystematiserbarts": "osystematiserbar",
    "osystematiska": "osystematisk",
    "osystematiskare": "osystematisk",
    "osystematiskares": "osystematisk",
    "osystematiskas": "osystematisk",
    "osystematiskast": "osystematisk",
    "osystematiskaste": "osystematisk",
    "osystematiskastes": "osystematisk",
    "osystematiskasts": "osystematisk",
    "osystematiske": "osystematisk",
    "osystematiskes": "osystematisk",
    "osystematisks": "osystematisk",
    "osystematiskt": "osystematisk",
    "osystematiskts": "osystematisk",
    "osägbara": "osägbar",
    "osägbarare": "osägbar",
    "osägbarares": "osägbar",
    "osägbaras": "osägbar",
    "osägbarast": "osägbar",
    "osägbaraste": "osägbar",
    "osägbarastes": "osägbar",
    "osägbarasts": "osägbar",
    "osägbare": "osägbar",
    "osägbares": "osägbar",
    "osägbarheten": "osägbarhet",
    "osägbarhetens": "osägbarhet",
    "osägbarhets": "osägbarhet",
    "osägbars": "osägbar",
    "osägbart": "osägbar",
    "osägbarts": "osägbar",
    "osägliga": "osäglig",
    "osägligare": "osäglig",
    "osägligares": "osäglig",
    "osägligas": "osäglig",
    "osägligast": "osäglig",
    "osägligaste": "osäglig",
    "osägligastes": "osäglig",
    "osägligasts": "osäglig",
    "osäglige": "osäglig",
    "osägliges": "osäglig",
    "osägligheten": "osäglighet",
    "osäglighetens": "osäglighet",
    "osäglighets": "osäglighet",
    "osägligs": "osäglig",
    "osägligt": "osäglig",
    "osägligts": "osäglig",
    "osäkerheten": "osäkerhet",
    "osäkerhetens": "osäkerhet",
    "osäkerheter": "osäkerhet",
    "osäkerheterna": "osäkerhet",
    "osäkerheternas": "osäkerhet",
    "osäkerheters": "osäkerhet",
    "osäkerhets": "osäkerhet",
    "osäkerhetsmomenten": "osäkerhetsmoment",
    "osäkerhetsmomentens": "osäkerhetsmoment",
    "osäkerhetsmomentet": "osäkerhetsmoment",
    "osäkerhetsmomentets": "osäkerhetsmoment",
    "osäkerhetsmoments": "osäkerhetsmoment",
    "osäkerhetsrelationen": "osäkerhetsrelation",
    "osäkerhetsrelationens": "osäkerhetsrelation",
    "osäkerhetsrelationer": "osäkerhetsrelation",
    "osäkerhetsrelationerna": "osäkerhetsrelation",
    "osäkerhetsrelationernas": "osäkerhetsrelation",
    "osäkerhetsrelationers": "osäkerhetsrelation",
    "osäkerhetsrelations": "osäkerhetsrelation",
    "osäkers": "osäker",
    "osäkert": "osäker",
    "osäkerts": "osäker",
    "osäkra": "osäker",
    "osäkrad": "osäkra",
    "osäkrade": "osäkra",
    "osäkrades": "osäkra",
    "osäkrads": "osäkra",
    "osäkrande": "osäkra",
    "osäkranden": "osäkrande",
    "osäkrandena": "osäkrande",
    "osäkrandenas": "osäkrande",
    "osäkrandens": "osäkrande",
    "osäkrandes": "osäkrande",
    "osäkrandet": "osäkrande",
    "osäkrandets": "osäkrande",
    "osäkrar": "osäkra",
    "osäkrare": "osäker",
    "osäkrares": "osäker",
    "osäkras": "osäkra",
    "osäkrast": "osäker",
    "osäkraste": "osäker",
    "osäkrastes": "osäker",
    "osäkrasts": "osäker",
    "osäkrat": "osäkra",
    "osäkrats": "osäkra",
    "osäkre": "osäker",
    "osäkres": "osäker",
    "osäljbara": "osäljbar",
    "osäljbarare": "osäljbar",
    "osäljbarares": "osäljbar",
    "osäljbaras": "osäljbar",
    "osäljbarast": "osäljbar",
    "osäljbaraste": "osäljbar",
    "osäljbarastes": "osäljbar",
    "osäljbarasts": "osäljbar",
    "osäljbare": "osäljbar",
    "osäljbares": "osäljbar",
    "osäljbarheten": "osäljbarhet",
    "osäljbarhetens": "osäljbarhet",
    "osäljbarhets": "osäljbarhet",
    "osäljbars": "osäljbar",
    "osäljbart": "osäljbar",
    "osäljbarts": "osäljbar",
    "osälla": "osäll",
    "osällare": "osäll",
    "osällares": "osäll",
    "osällas": "osäll",
    "osällast": "osäll",
    "osällaste": "osäll",
    "osällastes": "osäll",
    "osällasts": "osäll",
    "osälle": "osäll",
    "osälles": "osäll",
    "osällheten": "osällhet",
    "osällhetens": "osällhet",
    "osällhets": "osällhet",
    "osälls": "osäll",
    "osällskapliga": "osällskaplig",
    "osällskapligare": "osällskaplig",
    "osällskapligares": "osällskaplig",
    "osällskapligas": "osällskaplig",
    "osällskapligast": "osällskaplig",
    "osällskapligaste": "osällskaplig",
    "osällskapligastes": "osällskaplig",
    "osällskapligasts": "osällskaplig",
    "osällskaplige": "osällskaplig",
    "osällskapliges": "osällskaplig",
    "osällskapligheten": "osällskaplighet",
    "osällskaplighetens": "osällskaplighet",
    "osällskaplighets": "osällskaplighet",
    "osällskapligs": "osällskaplig",
    "osällskapligt": "osällskaplig",
    "osällskapligts": "osällskaplig",
    "osällt": "osäll",
    "osällts": "osäll",
    "osämjan": "osämja",
    "osämjans": "osämja",
    "osämjas": "osämja",
    "osänkbara": "osänkbar",
    "osänkbarare": "osänkbar",
    "osänkbarares": "osänkbar",
    "osänkbaras": "osänkbar",
    "osänkbarast": "osänkbar",
    "osänkbaraste": "osänkbar",
    "osänkbarastes": "osänkbar",
    "osänkbarasts": "osänkbar",
    "osänkbare": "osänkbar",
    "osänkbares": "osänkbar",
    "osänkbarheten": "osänkbarhet",
    "osänkbarhetens": "osänkbarhet",
    "osänkbarhets": "osänkbarhet",
    "osänkbars": "osänkbar",
    "osänkbart": "osänkbar",
    "osänkbarts": "osänkbar",
    "osålda": "osåld",
    "osåldare": "osåld",
    "osåldares": "osåld",
    "osåldas": "osåld",
    "osåldast": "osåld",
    "osåldaste": "osåld",
    "osåldastes": "osåld",
    "osåldasts": "osåld",
    "osålde": "osåld",
    "osåldes": "osåld",
    "osålds": "osåld",
    "osålt": "osåld",
    "osålts": "osåld",
    "osårbara": "osårbar",
    "osårbarare": "osårbar",
    "osårbarares": "osårbar",
    "osårbaras": "osårbar",
    "osårbarast": "osårbar",
    "osårbaraste": "osårbar",
    "osårbarastes": "osårbar",
    "osårbarasts": "osårbar",
    "osårbare": "osårbar",
    "osårbares": "osårbar",
    "osårbarheten": "osårbarhet",
    "osårbarhetens": "osårbarhet",
    "osårbarhets": "osårbarhet",
    "osårbars": "osårbar",
    "osårbart": "osårbar",
    "osårbarts": "osårbar",
    "osåterade": "osåterad",
    "osåterades": "osåterad",
    "osåterads": "osåterad",
    "osåterat": "osåterad",
    "osåterats": "osåterad",
    "osåterbara": "osåterbar",
    "osåterbarare": "osåterbar",
    "osåterbarares": "osåterbar",
    "osåterbaras": "osåterbar",
    "osåterbarast": "osåterbar",
    "osåterbaraste": "osåterbar",
    "osåterbarastes": "osåterbar",
    "osåterbarasts": "osåterbar",
    "osåterbare": "osåterbar",
    "osåterbares": "osåterbar",
    "osåterbarheten": "osåterbarhet",
    "osåterbarhetens": "osåterbarhet",
    "osåterbarhets": "osåterbarhet",
    "osåterbars": "osåterbar",
    "osåterbart": "osåterbar",
    "osåterbarts": "osåterbar",
    "osåverade": "osåverad",
    "osåverades": "osåverad",
    "osåverads": "osåverad",
    "osåverat": "osåverad",
    "osåverats": "osåverad",
    "osåverbara": "osåverbar",
    "osåverbarare": "osåverbar",
    "osåverbarares": "osåverbar",
    "osåverbaras": "osåverbar",
    "osåverbarast": "osåverbar",
    "osåverbaraste": "osåverbar",
    "osåverbarastes": "osåverbar",
    "osåverbarasts": "osåverbar",
    "osåverbare": "osåverbar",
    "osåverbares": "osåverbar",
    "osåverbarheten": "osåverbarhet",
    "osåverbarhetens": "osåverbarhet",
    "osåverbarhets": "osåverbarhet",
    "osåverbars": "osåverbar",
    "osåverbart": "osåverbar",
    "osåverbarts": "osåverbar",
    "osökta": "osökt",
    "osöktare": "osökt",
    "osöktares": "osökt",
    "osöktas": "osökt",
    "osöktast": "osökt",
    "osöktaste": "osökt",
    "osöktastes": "osökt",
    "osöktasts": "osökt",
    "osökte": "osökt",
    "osöktes": "osökt",
    "osöktheten": "osökthet",
    "osökthetens": "osökthet",
    "osökthets": "osökthet",
    "osökts": "osökt",
    "osötade": "osötad",
    "osötades": "osötad",
    "osötads": "osötad",
    "osötat": "osötad",
    "osötats": "osötad",
    "ot": "o",
    "otabellerade": "otabellerad",
    "otabellerades": "otabellerad",
    "otabellerads": "otabellerad",
    "otabellerat": "otabellerad",
    "otabellerats": "otabellerad",
    "otabellerbara": "otabellerbar",
    "otabellerbarare": "otabellerbar",
    "otabellerbarares": "otabellerbar",
    "otabellerbaras": "otabellerbar",
    "otabellerbarast": "otabellerbar",
    "otabellerbaraste": "otabellerbar",
    "otabellerbarastes": "otabellerbar",
    "otabellerbarasts": "otabellerbar",
    "otabellerbare": "otabellerbar",
    "otabellerbares": "otabellerbar",
    "otabellerbarheten": "otabellerbarhet",
    "otabellerbarhetens": "otabellerbarhet",
    "otabellerbarhets": "otabellerbarhet",
    "otabellerbars": "otabellerbar",
    "otabellerbart": "otabellerbar",
    "otabellerbarts": "otabellerbar",
    "otabuerade": "otabuerad",
    "otabuerades": "otabuerad",
    "otabuerads": "otabuerad",
    "otabuerat": "otabuerad",
    "otabuerats": "otabuerad",
    "otabuerbara": "otabuerbar",
    "otabuerbarare": "otabuerbar",
    "otabuerbarares": "otabuerbar",
    "otabuerbaras": "otabuerbar",
    "otabuerbarast": "otabuerbar",
    "otabuerbaraste": "otabuerbar",
    "otabuerbarastes": "otabuerbar",
    "otabuerbarasts": "otabuerbar",
    "otabuerbare": "otabuerbar",
    "otabuerbares": "otabuerbar",
    "otabuerbarheten": "otabuerbarhet",
    "otabuerbarhetens": "otabuerbarhet",
    "otabuerbarhets": "otabuerbarhet",
    "otabuerbars": "otabuerbar",
    "otabuerbart": "otabuerbar",
    "otabuerbarts": "otabuerbar",
    "otacket": "otack",
    "otackets": "otack",
    "otacks": "otack",
    "otacksamheten": "otacksamhet",
    "otacksamhetens": "otacksamhet",
    "otacksamhets": "otacksamhet",
    "otacksamma": "otacksam",
    "otacksammare": "otacksam",
    "otacksammares": "otacksam",
    "otacksammas": "otacksam",
    "otacksammast": "otacksam",
    "otacksammaste": "otacksam",
    "otacksammastes": "otacksam",
    "otacksammasts": "otacksam",
    "otacksamme": "otacksam",
    "otacksammes": "otacksam",
    "otacksams": "otacksam",
    "otacksamt": "otacksam",
    "otacksamts": "otacksam",
    "otadliga": "otadlig",
    "otadligare": "otadlig",
    "otadligares": "otadlig",
    "otadligas": "otadlig",
    "otadligast": "otadlig",
    "otadligaste": "otadlig",
    "otadligastes": "otadlig",
    "otadligasts": "otadlig",
    "otadlige": "otadlig",
    "otadliges": "otadlig",
    "otadligheten": "otadlighet",
    "otadlighetens": "otadlighet",
    "otadlighets": "otadlighet",
    "otadligs": "otadlig",
    "otadligt": "otadlig",
    "otadligts": "otadlig",
    "otaliga": "otalig",
    "otaligare": "otalig",
    "otaligares": "otalig",
    "otaligas": "otalig",
    "otaligast": "otalig",
    "otaligaste": "otalig",
    "otaligastes": "otalig",
    "otaligasts": "otalig",
    "otalige": "otalig",
    "otaliges": "otalig",
    "otaligheten": "otalighet",
    "otalighetens": "otalighet",
    "otalighets": "otalighet",
    "otaligs": "otalig",
    "otaligt": "otalig",
    "otaligts": "otalig",
    "otals": "otal",
    "otamponerade": "otamponerad",
    "otamponerades": "otamponerad",
    "otamponerads": "otamponerad",
    "otamponerat": "otamponerad",
    "otamponerats": "otamponerad",
    "otamponerbara": "otamponerbar",
    "otamponerbarare": "otamponerbar",
    "otamponerbarares": "otamponerbar",
    "otamponerbaras": "otamponerbar",
    "otamponerbarast": "otamponerbar",
    "otamponerbaraste": "otamponerbar",
    "otamponerbarastes": "otamponerbar",
    "otamponerbarasts": "otamponerbar",
    "otamponerbare": "otamponerbar",
    "otamponerbares": "otamponerbar",
    "otamponerbarheten": "otamponerbarhet",
    "otamponerbarhetens": "otamponerbarhet",
    "otamponerbarhets": "otamponerbarhet",
    "otamponerbars": "otamponerbar",
    "otamponerbart": "otamponerbar",
    "otamponerbarts": "otamponerbar",
    "otandade": "otandad",
    "otandades": "otandad",
    "otandads": "otandad",
    "otandat": "otandad",
    "otandats": "otandad",
    "otangerade": "otangerad",
    "otangerades": "otangerad",
    "otangerads": "otangerad",
    "otangerat": "otangerad",
    "otangerats": "otangerad",
    "otangerbara": "otangerbar",
    "otangerbarare": "otangerbar",
    "otangerbarares": "otangerbar",
    "otangerbaras": "otangerbar",
    "otangerbarast": "otangerbar",
    "otangerbaraste": "otangerbar",
    "otangerbarastes": "otangerbar",
    "otangerbarasts": "otangerbar",
    "otangerbare": "otangerbar",
    "otangerbares": "otangerbar",
    "otangerbarheten": "otangerbarhet",
    "otangerbarhetens": "otangerbarhet",
    "otangerbarhets": "otangerbarhet",
    "otangerbars": "otangerbar",
    "otangerbart": "otangerbar",
    "otangerbarts": "otangerbar",
    "otapetserade": "otapetserad",
    "otapetserades": "otapetserad",
    "otapetserads": "otapetserad",
    "otapetserat": "otapetserad",
    "otapetserats": "otapetserad",
    "otapetserbara": "otapetserbar",
    "otapetserbarare": "otapetserbar",
    "otapetserbarares": "otapetserbar",
    "otapetserbaras": "otapetserbar",
    "otapetserbarast": "otapetserbar",
    "otapetserbaraste": "otapetserbar",
    "otapetserbarastes": "otapetserbar",
    "otapetserbarasts": "otapetserbar",
    "otapetserbare": "otapetserbar",
    "otapetserbares": "otapetserbar",
    "otapetserbarheten": "otapetserbarhet",
    "otapetserbarhetens": "otapetserbarhet",
    "otapetserbarhets": "otapetserbarhet",
    "otapetserbars": "otapetserbar",
    "otapetserbart": "otapetserbar",
    "otapetserbarts": "otapetserbar",
    "otarerade": "otarerad",
    "otarerades": "otarerad",
    "otarerads": "otarerad",
    "otarerat": "otarerad",
    "otarerats": "otarerad",
    "otarerbara": "otarerbar",
    "otarerbarare": "otarerbar",
    "otarerbarares": "otarerbar",
    "otarerbaras": "otarerbar",
    "otarerbarast": "otarerbar",
    "otarerbaraste": "otarerbar",
    "otarerbarastes": "otarerbar",
    "otarerbarasts": "otarerbar",
    "otarerbare": "otarerbar",
    "otarerbares": "otarerbar",
    "otarerbarheten": "otarerbarhet",
    "otarerbarhetens": "otarerbarhet",
    "otarerbarhets": "otarerbarhet",
    "otarerbars": "otarerbar",
    "otarerbart": "otarerbar",
    "otarerbarts": "otarerbar",
    "otarifferade": "otarifferad",
    "otarifferades": "otarifferad",
    "otarifferads": "otarifferad",
    "otarifferat": "otarifferad",
    "otarifferats": "otarifferad",
    "otarifferbara": "otarifferbar",
    "otarifferbarare": "otarifferbar",
    "otarifferbarares": "otarifferbar",
    "otarifferbaras": "otarifferbar",
    "otarifferbarast": "otarifferbar",
    "otarifferbaraste": "otarifferbar",
    "otarifferbarastes": "otarifferbar",
    "otarifferbarasts": "otarifferbar",
    "otarifferbare": "otarifferbar",
    "otarifferbares": "otarifferbar",
    "otarifferbarheten": "otarifferbarhet",
    "otarifferbarhetens": "otarifferbarhet",
    "otarifferbarhets": "otarifferbarhet",
    "otarifferbars": "otarifferbar",
    "otarifferbart": "otarifferbar",
    "otarifferbarts": "otarifferbar",
    "otatuerade": "otatuerad",
    "otatuerades": "otatuerad",
    "otatuerads": "otatuerad",
    "otatuerat": "otatuerad",
    "otatuerats": "otatuerad",
    "otatuerbara": "otatuerbar",
    "otatuerbarare": "otatuerbar",
    "otatuerbarares": "otatuerbar",
    "otatuerbaras": "otatuerbar",
    "otatuerbarast": "otatuerbar",
    "otatuerbaraste": "otatuerbar",
    "otatuerbarastes": "otatuerbar",
    "otatuerbarasts": "otatuerbar",
    "otatuerbare": "otatuerbar",
    "otatuerbares": "otatuerbar",
    "otatuerbarheten": "otatuerbarhet",
    "otatuerbarhetens": "otatuerbarhet",
    "otatuerbarhets": "otatuerbarhet",
    "otatuerbars": "otatuerbar",
    "otatuerbart": "otatuerbar",
    "otatuerbarts": "otatuerbar",
    "otaxerade": "otaxerad",
    "otaxerades": "otaxerad",
    "otaxerads": "otaxerad",
    "otaxerat": "otaxerad",
    "otaxerats": "otaxerad",
    "otaxerbara": "otaxerbar",
    "otaxerbarare": "otaxerbar",
    "otaxerbarares": "otaxerbar",
    "otaxerbaras": "otaxerbar",
    "otaxerbarast": "otaxerbar",
    "otaxerbaraste": "otaxerbar",
    "otaxerbarastes": "otaxerbar",
    "otaxerbarasts": "otaxerbar",
    "otaxerbare": "otaxerbar",
    "otaxerbares": "otaxerbar",
    "otaxerbarheten": "otaxerbarhet",
    "otaxerbarhetens": "otaxerbarhet",
    "otaxerbarhets": "otaxerbarhet",
    "otaxerbars": "otaxerbar",
    "otaxerbart": "otaxerbar",
    "otaxerbarts": "otaxerbar",
    "oteknifierade": "oteknifierad",
    "oteknifierades": "oteknifierad",
    "oteknifierads": "oteknifierad",
    "oteknifierat": "oteknifierad",
    "oteknifierats": "oteknifierad",
    "oteknifierbara": "oteknifierbar",
    "oteknifierbarare": "oteknifierbar",
    "oteknifierbarares": "oteknifierbar",
    "oteknifierbaras": "oteknifierbar",
    "oteknifierbarast": "oteknifierbar",
    "oteknifierbaraste": "oteknifierbar",
    "oteknifierbarastes": "oteknifierbar",
    "oteknifierbarasts": "oteknifierbar",
    "oteknifierbare": "oteknifierbar",
    "oteknifierbares": "oteknifierbar",
    "oteknifierbarheten": "oteknifierbarhet",
    "oteknifierbarhetens": "oteknifierbarhet",
    "oteknifierbarhets": "oteknifierbarhet",
    "oteknifierbars": "oteknifierbar",
    "oteknifierbart": "oteknifierbar",
    "oteknifierbarts": "oteknifierbar",
    "otekniska": "oteknisk",
    "otekniskare": "oteknisk",
    "otekniskares": "oteknisk",
    "otekniskas": "oteknisk",
    "otekniskast": "oteknisk",
    "otekniskaste": "oteknisk",
    "otekniskastes": "oteknisk",
    "otekniskasts": "oteknisk",
    "otekniske": "oteknisk",
    "otekniskes": "oteknisk",
    "oteknisks": "oteknisk",
    "otekniskt": "oteknisk",
    "otekniskts": "oteknisk",
    "otelefonerade": "otelefonerad",
    "otelefonerades": "otelefonerad",
    "otelefonerads": "otelefonerad",
    "otelefonerat": "otelefonerad",
    "otelefonerats": "otelefonerad",
    "otelefonerbara": "otelefonerbar",
    "otelefonerbarare": "otelefonerbar",
    "otelefonerbarares": "otelefonerbar",
    "otelefonerbaras": "otelefonerbar",
    "otelefonerbarast": "otelefonerbar",
    "otelefonerbaraste": "otelefonerbar",
    "otelefonerbarastes": "otelefonerbar",
    "otelefonerbarasts": "otelefonerbar",
    "otelefonerbare": "otelefonerbar",
    "otelefonerbares": "otelefonerbar",
    "otelefonerbarheten": "otelefonerbarhet",
    "otelefonerbarhetens": "otelefonerbarhet",
    "otelefonerbarhets": "otelefonerbarhet",
    "otelefonerbars": "otelefonerbar",
    "otelefonerbart": "otelefonerbar",
    "otelefonerbarts": "otelefonerbar",
    "otelegraferade": "otelegraferad",
    "otelegraferades": "otelegraferad",
    "otelegraferads": "otelegraferad",
    "otelegraferat": "otelegraferad",
    "otelegraferats": "otelegraferad",
    "otelegraferbara": "otelegraferbar",
    "otelegraferbarare": "otelegraferbar",
    "otelegraferbarares": "otelegraferbar",
    "otelegraferbaras": "otelegraferbar",
    "otelegraferbarast": "otelegraferbar",
    "otelegraferbaraste": "otelegraferbar",
    "otelegraferbarastes": "otelegraferbar",
    "otelegraferbarasts": "otelegraferbar",
    "otelegraferbare": "otelegraferbar",
    "otelegraferbares": "otelegraferbar",
    "otelegraferbarheten": "otelegraferbarhet",
    "otelegraferbarhetens": "otelegraferbarhet",
    "otelegraferbarhets": "otelegraferbarhet",
    "otelegraferbars": "otelegraferbar",
    "otelegraferbart": "otelegraferbar",
    "otelegraferbarts": "otelegraferbar",
    "oteleviserade": "oteleviserad",
    "oteleviserades": "oteleviserad",
    "oteleviserads": "oteleviserad",
    "oteleviserat": "oteleviserad",
    "oteleviserats": "oteleviserad",
    "oteleviserbara": "oteleviserbar",
    "oteleviserbarare": "oteleviserbar",
    "oteleviserbarares": "oteleviserbar",
    "oteleviserbaras": "oteleviserbar",
    "oteleviserbarast": "oteleviserbar",
    "oteleviserbaraste": "oteleviserbar",
    "oteleviserbarastes": "oteleviserbar",
    "oteleviserbarasts": "oteleviserbar",
    "oteleviserbare": "oteleviserbar",
    "oteleviserbares": "oteleviserbar",
    "oteleviserbarheten": "oteleviserbarhet",
    "oteleviserbarhetens": "oteleviserbarhet",
    "oteleviserbarhets": "oteleviserbarhet",
    "oteleviserbars": "oteleviserbar",
    "oteleviserbart": "oteleviserbar",
    "oteleviserbarts": "oteleviserbar",
    "otemperade": "otemperad",
    "otemperades": "otemperad",
    "otemperads": "otemperad",
    "otemperat": "otemperad",
    "otemperats": "otemperad",
    "otemperbara": "otemperbar",
    "otemperbarare": "otemperbar",
    "otemperbarares": "otemperbar",
    "otemperbaras": "otemperbar",
    "otemperbarast": "otemperbar",
    "otemperbaraste": "otemperbar",
    "otemperbarastes": "otemperbar",
    "otemperbarasts": "otemperbar",
    "otemperbare": "otemperbar",
    "otemperbares": "otemperbar",
    "otemperbarheten": "otemperbarhet",
    "otemperbarhetens": "otemperbarhet",
    "otemperbarhets": "otemperbarhet",
    "otemperbars": "otemperbar",
    "otemperbart": "otemperbar",
    "otemperbarts": "otemperbar",
    "otempererade": "otempererad",
    "otempererades": "otempererad",
    "otempererads": "otempererad",
    "otempererat": "otempererad",
    "otempererats": "otempererad",
    "otempererbara": "otempererbar",
    "otempererbarare": "otempererbar",
    "otempererbarares": "otempererbar",
    "otempererbaras": "otempererbar",
    "otempererbarast": "otempererbar",
    "otempererbaraste": "otempererbar",
    "otempererbarastes": "otempererbar",
    "otempererbarasts": "otempererbar",
    "otempererbare": "otempererbar",
    "otempererbares": "otempererbar",
    "otempererbarheten": "otempererbarhet",
    "otempererbarhetens": "otempererbarhet",
    "otempererbarhets": "otempererbarhet",
    "otempererbars": "otempererbar",
    "otempererbart": "otempererbar",
    "otempererbarts": "otempererbar",
    "otenterade": "otenterad",
    "otenterades": "otenterad",
    "otenterads": "otenterad",
    "otenterat": "otenterad",
    "otenterats": "otenterad",
    "otenterbara": "otenterbar",
    "otenterbarare": "otenterbar",
    "otenterbarares": "otenterbar",
    "otenterbaras": "otenterbar",
    "otenterbarast": "otenterbar",
    "otenterbaraste": "otenterbar",
    "otenterbarastes": "otenterbar",
    "otenterbarasts": "otenterbar",
    "otenterbare": "otenterbar",
    "otenterbares": "otenterbar",
    "otenterbarheten": "otenterbarhet",
    "otenterbarhetens": "otenterbarhet",
    "otenterbarhets": "otenterbarhet",
    "otenterbars": "otenterbar",
    "otenterbart": "otenterbar",
    "otenterbarts": "otenterbar",
    "oterrasserade": "oterrasserad",
    "oterrasserades": "oterrasserad",
    "oterrasserads": "oterrasserad",
    "oterrasserat": "oterrasserad",
    "oterrasserats": "oterrasserad",
    "oterrasserbara": "oterrasserbar",
    "oterrasserbarare": "oterrasserbar",
    "oterrasserbarares": "oterrasserbar",
    "oterrasserbaras": "oterrasserbar",
    "oterrasserbarast": "oterrasserbar",
    "oterrasserbaraste": "oterrasserbar",
    "oterrasserbarastes": "oterrasserbar",
    "oterrasserbarasts": "oterrasserbar",
    "oterrasserbare": "oterrasserbar",
    "oterrasserbares": "oterrasserbar",
    "oterrasserbarheten": "oterrasserbarhet",
    "oterrasserbarhetens": "oterrasserbarhet",
    "oterrasserbarhets": "oterrasserbarhet",
    "oterrasserbars": "oterrasserbar",
    "oterrasserbart": "oterrasserbar",
    "oterrasserbarts": "oterrasserbar",
    "oterroriserade": "oterroriserad",
    "oterroriserades": "oterroriserad",
    "oterroriserads": "oterroriserad",
    "oterroriserat": "oterroriserad",
    "oterroriserats": "oterroriserad",
    "oterroriserbara": "oterroriserbar",
    "oterroriserbarare": "oterroriserbar",
    "oterroriserbarares": "oterroriserbar",
    "oterroriserbaras": "oterroriserbar",
    "oterroriserbarast": "oterroriserbar",
    "oterroriserbaraste": "oterroriserbar",
    "oterroriserbarastes": "oterroriserbar",
    "oterroriserbarasts": "oterroriserbar",
    "oterroriserbare": "oterroriserbar",
    "oterroriserbares": "oterroriserbar",
    "oterroriserbarheten": "oterroriserbarhet",
    "oterroriserbarhetens": "oterroriserbarhet",
    "oterroriserbarhets": "oterroriserbarhet",
    "oterroriserbars": "oterroriserbar",
    "oterroriserbart": "oterroriserbar",
    "oterroriserbarts": "oterroriserbar",
    "otesaurerade": "otesaurerad",
    "otesaurerades": "otesaurerad",
    "otesaurerads": "otesaurerad",
    "otesaurerat": "otesaurerad",
    "otesaurerats": "otesaurerad",
    "otesaurerbara": "otesaurerbar",
    "otesaurerbarare": "otesaurerbar",
    "otesaurerbarares": "otesaurerbar",
    "otesaurerbaras": "otesaurerbar",
    "otesaurerbarast": "otesaurerbar",
    "otesaurerbaraste": "otesaurerbar",
    "otesaurerbarastes": "otesaurerbar",
    "otesaurerbarasts": "otesaurerbar",
    "otesaurerbare": "otesaurerbar",
    "otesaurerbares": "otesaurerbar",
    "otesaurerbarheten": "otesaurerbarhet",
    "otesaurerbarhetens": "otesaurerbarhet",
    "otesaurerbarhets": "otesaurerbarhet",
    "otesaurerbars": "otesaurerbar",
    "otesaurerbart": "otesaurerbar",
    "otesaurerbarts": "otesaurerbar",
    "otestamenterade": "otestamenterad",
    "otestamenterades": "otestamenterad",
    "otestamenterads": "otestamenterad",
    "otestamenterat": "otestamenterad",
    "otestamenterats": "otestamenterad",
    "otestamenterbara": "otestamenterbar",
    "otestamenterbarare": "otestamenterbar",
    "otestamenterbarares": "otestamenterbar",
    "otestamenterbaras": "otestamenterbar",
    "otestamenterbarast": "otestamenterbar",
    "otestamenterbaraste": "otestamenterbar",
    "otestamenterbarastes": "otestamenterbar",
    "otestamenterbarasts": "otestamenterbar",
    "otestamenterbare": "otestamenterbar",
    "otestamenterbares": "otestamenterbar",
    "otestamenterbarheten": "otestamenterbarhet",
    "otestamenterbarhetens": "otestamenterbarhet",
    "otestamenterbarhets": "otestamenterbarhet",
    "otestamenterbars": "otestamenterbar",
    "otestamenterbart": "otestamenterbar",
    "otestamenterbarts": "otestamenterbar",
    "otidiga": "otidig",
    "otidigare": "otidig",
    "otidigares": "otidig",
    "otidigas": "otidig",
    "otidigast": "otidig",
    "otidigaste": "otidig",
    "otidigastes": "otidig",
    "otidigasts": "otidig",
    "otidige": "otidig",
    "otidiges": "otidig",
    "otidigheten": "otidighet",
    "otidighetens": "otidighet",
    "otidigheter": "otidighet",
    "otidigheterna": "otidighet",
    "otidigheternas": "otidighet",
    "otidigheters": "otidighet",
    "otidighets": "otidighet",
    "otidigs": "otidig",
    "otidigt": "otidig",
    "otidigts": "otidig",
    "otids": "otid",
    "otidsenliga": "otidsenlig",
    "otidsenligare": "otidsenlig",
    "otidsenligares": "otidsenlig",
    "otidsenligas": "otidsenlig",
    "otidsenligast": "otidsenlig",
    "otidsenligaste": "otidsenlig",
    "otidsenligastes": "otidsenlig",
    "otidsenligasts": "otidsenlig",
    "otidsenlige": "otidsenlig",
    "otidsenliges": "otidsenlig",
    "otidsenligheten": "otidsenlighet",
    "otidsenlighetens": "otidsenlighet",
    "otidsenligheter": "otidsenlighet",
    "otidsenligheterna": "otidsenlighet",
    "otidsenligheternas": "otidsenlighet",
    "otidsenligheters": "otidsenlighet",
    "otidsenlighets": "otidsenlighet",
    "otidsenligs": "otidsenlig",
    "otidsenligt": "otidsenlig",
    "otidsenligts": "otidsenlig",
    "otiet": "otium",
    "otiets": "otium",
    "otillbörliga": "otillbörlig",
    "otillbörligare": "otillbörlig",
    "otillbörligares": "otillbörlig",
    "otillbörligas": "otillbörlig",
    "otillbörligast": "otillbörlig",
    "otillbörligaste": "otillbörlig",
    "otillbörligastes": "otillbörlig",
    "otillbörligasts": "otillbörlig",
    "otillbörlige": "otillbörlig",
    "otillbörliges": "otillbörlig",
    "otillbörligheten": "otillbörlighet",
    "otillbörlighetens": "otillbörlighet",
    "otillbörligheter": "otillbörlighet",
    "otillbörligheterna": "otillbörlighet",
    "otillbörligheternas": "otillbörlighet",
    "otillbörligheters": "otillbörlighet",
    "otillbörlighets": "otillbörlighet",
    "otillbörligs": "otillbörlig",
    "otillbörligt": "otillbörlig",
    "otillbörligts": "otillbörlig",
    "otillfredsställda": "otillfredsställd",
    "otillfredsställdare": "otillfredsställd",
    "otillfredsställdares": "otillfredsställd",
    "otillfredsställdas": "otillfredsställd",
    "otillfredsställdast": "otillfredsställd",
    "otillfredsställdaste": "otillfredsställd",
    "otillfredsställdastes": "otillfredsställd",
    "otillfredsställdasts": "otillfredsställd",
    "otillfredsställde": "otillfredsställd",
    "otillfredsställdes": "otillfredsställd",
    "otillfredsställds": "otillfredsställd",
    "otillfredsställelsen": "otillfredsställelse",
    "otillfredsställelsens": "otillfredsställelse",
    "otillfredsställelses": "otillfredsställelse",
    "otillfredsställt": "otillfredsställd",
    "otillfredsställts": "otillfredsställd",
    "otillförlitliga": "otillförlitlig",
    "otillförlitligare": "otillförlitlig",
    "otillförlitligares": "otillförlitlig",
    "otillförlitligas": "otillförlitlig",
    "otillförlitligast": "otillförlitlig",
    "otillförlitligaste": "otillförlitlig",
    "otillförlitligastes": "otillförlitlig",
    "otillförlitligasts": "otillförlitlig",
    "otillförlitlige": "otillförlitlig",
    "otillförlitliges": "otillförlitlig",
    "otillförlitligheten": "otillförlitlighet",
    "otillförlitlighetens": "otillförlitlighet",
    "otillförlitlighets": "otillförlitlighet",
    "otillförlitligs": "otillförlitlig",
    "otillförlitligt": "otillförlitlig",
    "otillförlitligts": "otillförlitlig",
    "otillgängliga": "otillgänglig",
    "otillgängligare": "otillgänglig",
    "otillgängligares": "otillgänglig",
    "otillgängligas": "otillgänglig",
    "otillgängligast": "otillgänglig",
    "otillgängligaste": "otillgänglig",
    "otillgängligastes": "otillgänglig",
    "otillgängligasts": "otillgänglig",
    "otillgänglige": "otillgänglig",
    "otillgängliges": "otillgänglig",
    "otillgängligheten": "otillgänglighet",
    "otillgänglighetens": "otillgänglighet",
    "otillgängligheter": "otillgänglighet",
    "otillgängligheterna": "otillgänglighet",
    "otillgängligheternas": "otillgänglighet",
    "otillgängligheters": "otillgänglighet",
    "otillgänglighets": "otillgänglighet",
    "otillgängligs": "otillgänglig",
    "otillgängligt": "otillgänglig",
    "otillgängligts": "otillgänglig",
    "otillräckliga": "otillräcklig",
    "otillräckligare": "otillräcklig",
    "otillräckligares": "otillräcklig",
    "otillräckligas": "otillräcklig",
    "otillräckligast": "otillräcklig",
    "otillräckligaste": "otillräcklig",
    "otillräckligastes": "otillräcklig",
    "otillräckligasts": "otillräcklig",
    "otillräcklige": "otillräcklig",
    "otillräckliges": "otillräcklig",
    "otillräckligheten": "otillräcklighet",
    "otillräcklighetens": "otillräcklighet",
    "otillräcklighets": "otillräcklighet",
    "otillräckligs": "otillräcklig",
    "otillräckligt": "otillräcklig",
    "otillräckligts": "otillräcklig",
    "otillräkneliga": "otillräknelig",
    "otillräkneligare": "otillräknelig",
    "otillräkneligares": "otillräknelig",
    "otillräkneligas": "otillräknelig",
    "otillräkneligast": "otillräknelig",
    "otillräkneligaste": "otillräknelig",
    "otillräkneligastes": "otillräknelig",
    "otillräkneligasts": "otillräknelig",
    "otillräknelige": "otillräknelig",
    "otillräkneliges": "otillräknelig",
    "otillräkneligheten": "otillräknelighet",
    "otillräknelighetens": "otillräknelighet",
    "otillräknelighets": "otillräknelighet",
    "otillräkneligs": "otillräknelig",
    "otillräkneligt": "otillräknelig",
    "otillräkneligts": "otillräknelig",
    "otillständiga": "otillständig",
    "otillständigare": "otillständig",
    "otillständigares": "otillständig",
    "otillständigas": "otillständig",
    "otillständigast": "otillständig",
    "otillständigaste": "otillständig",
    "otillständigastes": "otillständig",
    "otillständigasts": "otillständig",
    "otillständige": "otillständig",
    "otillständiges": "otillständig",
    "otillständigheten": "otillständighet",
    "otillständighetens": "otillständighet",
    "otillständighets": "otillständighet",
    "otillständigs": "otillständig",
    "otillständigt": "otillständig",
    "otillständigts": "otillständig",
    "otillåtens": "otillåten",
    "otillåtet": "otillåten",
    "otillåtets": "otillåten",
    "otillåtliga": "otillåtlig",
    "otillåtligare": "otillåtlig",
    "otillåtligares": "otillåtlig",
    "otillåtligas": "otillåtlig",
    "otillåtligast": "otillåtlig",
    "otillåtligaste": "otillåtlig",
    "otillåtligastes": "otillåtlig",
    "otillåtligasts": "otillåtlig",
    "otillåtlige": "otillåtlig",
    "otillåtliges": "otillåtlig",
    "otillåtligheten": "otillåtlighet",
    "otillåtlighetens": "otillåtlighet",
    "otillåtlighets": "otillåtlighet",
    "otillåtligs": "otillåtlig",
    "otillåtligt": "otillåtlig",
    "otillåtligts": "otillåtlig",
    "otillåtna": "otillåten",
    "otillåtnare": "otillåten",
    "otillåtnares": "otillåten",
    "otillåtnas": "otillåten",
    "otillåtnast": "otillåten",
    "otillåtnaste": "otillåten",
    "otillåtnastes": "otillåten",
    "otillåtnasts": "otillåten",
    "otillåtne": "otillåten",
    "otillåtnes": "otillåten",
    "otings": "oting",
    "otippade": "otippad",
    "otippades": "otippad",
    "otippads": "otippad",
    "otippat": "otippad",
    "otippats": "otippad",
    "otiten": "otit",
    "otitens": "otit",
    "otiter": "otit",
    "otiterna": "otit",
    "otiternas": "otit",
    "otiters": "otit",
    "otitrerade": "otitrerad",
    "otitrerades": "otitrerad",
    "otitrerads": "otitrerad",
    "otitrerat": "otitrerad",
    "otitrerats": "otitrerad",
    "otitrerbara": "otitrerbar",
    "otitrerbarare": "otitrerbar",
    "otitrerbarares": "otitrerbar",
    "otitrerbaras": "otitrerbar",
    "otitrerbarast": "otitrerbar",
    "otitrerbaraste": "otitrerbar",
    "otitrerbarastes": "otitrerbar",
    "otitrerbarasts": "otitrerbar",
    "otitrerbare": "otitrerbar",
    "otitrerbares": "otitrerbar",
    "otitrerbarheten": "otitrerbarhet",
    "otitrerbarhetens": "otitrerbarhet",
    "otitrerbarhets": "otitrerbarhet",
    "otitrerbars": "otitrerbar",
    "otitrerbart": "otitrerbar",
    "otitrerbarts": "otitrerbar",
    "otits": "otit",
    "otitulerade": "otitulerad",
    "otitulerades": "otitulerad",
    "otitulerads": "otitulerad",
    "otitulerat": "otitulerad",
    "otitulerats": "otitulerad",
    "otitulerbara": "otitulerbar",
    "otitulerbarare": "otitulerbar",
    "otitulerbarares": "otitulerbar",
    "otitulerbaras": "otitulerbar",
    "otitulerbarast": "otitulerbar",
    "otitulerbaraste": "otitulerbar",
    "otitulerbarastes": "otitulerbar",
    "otitulerbarasts": "otitulerbar",
    "otitulerbare": "otitulerbar",
    "otitulerbares": "otitulerbar",
    "otitulerbarheten": "otitulerbarhet",
    "otitulerbarhetens": "otitulerbarhet",
    "otitulerbarhets": "otitulerbarhet",
    "otitulerbars": "otitulerbar",
    "otitulerbart": "otitulerbar",
    "otitulerbarts": "otitulerbar",
    "otiumet": "otium",
    "otiumets": "otium",
    "otiums": "otium",
    "otjusiga": "otjusig",
    "otjusigare": "otjusig",
    "otjusigares": "otjusig",
    "otjusigas": "otjusig",
    "otjusigast": "otjusig",
    "otjusigaste": "otjusig",
    "otjusigastes": "otjusig",
    "otjusigasts": "otjusig",
    "otjusige": "otjusig",
    "otjusiges": "otjusig",
    "otjusigheten": "otjusighet",
    "otjusighetens": "otjusighet",
    "otjusighets": "otjusighet",
    "otjusigs": "otjusig",
    "otjusigt": "otjusig",
    "otjusigts": "otjusig",
    "otjänliga": "otjänlig",
    "otjänligare": "otjänlig",
    "otjänligares": "otjänlig",
    "otjänligas": "otjänlig",
    "otjänligast": "otjänlig",
    "otjänligaste": "otjänlig",
    "otjänligastes": "otjänlig",
    "otjänligasts": "otjänlig",
    "otjänlige": "otjänlig",
    "otjänliges": "otjänlig",
    "otjänligheten": "otjänlighet",
    "otjänlighetens": "otjänlighet",
    "otjänlighets": "otjänlighet",
    "otjänligs": "otjänlig",
    "otjänligt": "otjänlig",
    "otjänligts": "otjänlig",
    "otjänsten": "otjänst",
    "otjänstens": "otjänst",
    "otjänster": "otjänst",
    "otjänsterna": "otjänst",
    "otjänsternas": "otjänst",
    "otjänsters": "otjänst",
    "otjänsts": "otjänst",
    "otolererade": "otolererad",
    "otolererades": "otolererad",
    "otolererads": "otolererad",
    "otolererat": "otolererad",
    "otolererats": "otolererad",
    "otolererbara": "otolererbar",
    "otolererbarare": "otolererbar",
    "otolererbarares": "otolererbar",
    "otolererbaras": "otolererbar",
    "otolererbarast": "otolererbar",
    "otolererbaraste": "otolererbar",
    "otolererbarastes": "otolererbar",
    "otolererbarasts": "otolererbar",
    "otolererbare": "otolererbar",
    "otolererbares": "otolererbar",
    "otolererbarheten": "otolererbarhet",
    "otolererbarhetens": "otolererbarhet",
    "otolererbarhets": "otolererbarhet",
    "otolererbars": "otolererbar",
    "otolererbart": "otolererbar",
    "otolererbarts": "otolererbar",
    "otologen": "otolog",
    "otologens": "otolog",
    "otologer": "otolog",
    "otologerna": "otolog",
    "otologernas": "otolog",
    "otologers": "otolog",
    "otologien": "otologi",
    "otologiens": "otologi",
    "otologin": "otologi",
    "otologins": "otologi",
    "otologis": "otologi",
    "otologs": "otolog",
    "otorderade": "otorderad",
    "otorderades": "otorderad",
    "otorderads": "otorderad",
    "otorderat": "otorderad",
    "otorderats": "otorderad",
    "otorderbara": "otorderbar",
    "otorderbarare": "otorderbar",
    "otorderbarares": "otorderbar",
    "otorderbaras": "otorderbar",
    "otorderbarast": "otorderbar",
    "otorderbaraste": "otorderbar",
    "otorderbarastes": "otorderbar",
    "otorderbarasts": "otorderbar",
    "otorderbare": "otorderbar",
    "otorderbares": "otorderbar",
    "otorderbarheten": "otorderbarhet",
    "otorderbarhetens": "otorderbarhet",
    "otorderbarhets": "otorderbarhet",
    "otorderbars": "otorderbar",
    "otorderbart": "otorderbar",
    "otorderbarts": "otorderbar",
    "otorpederade": "otorpederad",
    "otorpederades": "otorpederad",
    "otorpederads": "otorpederad",
    "otorpederat": "otorpederad",
    "otorpederats": "otorpederad",
    "otorpederbara": "otorpederbar",
    "otorpederbarare": "otorpederbar",
    "otorpederbarares": "otorpederbar",
    "otorpederbaras": "otorpederbar",
    "otorpederbarast": "otorpederbar",
    "otorpederbaraste": "otorpederbar",
    "otorpederbarastes": "otorpederbar",
    "otorpederbarasts": "otorpederbar",
    "otorpederbare": "otorpederbar",
    "otorpederbares": "otorpederbar",
    "otorpederbarheten": "otorpederbarhet",
    "otorpederbarhetens": "otorpederbarhet",
    "otorpederbarhets": "otorpederbarhet",
    "otorpederbars": "otorpederbar",
    "otorpederbart": "otorpederbar",
    "otorpederbarts": "otorpederbar",
    "otorterade": "otorterad",
    "otorterades": "otorterad",
    "otorterads": "otorterad",
    "otorterat": "otorterad",
    "otorterats": "otorterad",
    "otorterbara": "otorterbar",
    "otorterbarare": "otorterbar",
    "otorterbarares": "otorterbar",
    "otorterbaras": "otorterbar",
    "otorterbarast": "otorterbar",
    "otorterbaraste": "otorterbar",
    "otorterbarastes": "otorterbar",
    "otorterbarasts": "otorterbar",
    "otorterbare": "otorterbar",
    "otorterbares": "otorterbar",
    "otorterbarheten": "otorterbarhet",
    "otorterbarhetens": "otorterbarhet",
    "otorterbarhets": "otorterbarhet",
    "otorterbars": "otorterbar",
    "otorterbart": "otorterbar",
    "otorterbarts": "otorterbar",
    "otoucherade": "otoucherad",
    "otoucherades": "otoucherad",
    "otoucherads": "otoucherad",
    "otoucherat": "otoucherad",
    "otoucherats": "otoucherad",
    "otoucherbara": "otoucherbar",
    "otoucherbarare": "otoucherbar",
    "otoucherbarares": "otoucherbar",
    "otoucherbaras": "otoucherbar",
    "otoucherbarast": "otoucherbar",
    "otoucherbaraste": "otoucherbar",
    "otoucherbarastes": "otoucherbar",
    "otoucherbarasts": "otoucherbar",
    "otoucherbare": "otoucherbar",
    "otoucherbares": "otoucherbar",
    "otoucherbarheten": "otoucherbarhet",
    "otoucherbarhetens": "otoucherbarhet",
    "otoucherbarhets": "otoucherbarhet",
    "otoucherbars": "otoucherbar",
    "otoucherbart": "otoucherbar",
    "otoucherbarts": "otoucherbar",
    "otouperade": "otouperad",
    "otouperades": "otouperad",
    "otouperads": "otouperad",
    "otouperat": "otouperad",
    "otouperats": "otouperad",
    "otouperbara": "otouperbar",
    "otouperbarare": "otouperbar",
    "otouperbarares": "otouperbar",
    "otouperbaras": "otouperbar",
    "otouperbarast": "otouperbar",
    "otouperbaraste": "otouperbar",
    "otouperbarastes": "otouperbar",
    "otouperbarasts": "otouperbar",
    "otouperbare": "otouperbar",
    "otouperbares": "otouperbar",
    "otouperbarheten": "otouperbarhet",
    "otouperbarhetens": "otouperbarhet",
    "otouperbarhets": "otouperbarhet",
    "otouperbars": "otouperbar",
    "otouperbart": "otouperbar",
    "otouperbarts": "otouperbar",
    "otraderade": "otraderad",
    "otraderades": "otraderad",
    "otraderads": "otraderad",
    "otraderat": "otraderad",
    "otraderats": "otraderad",
    "otraderbara": "otraderbar",
    "otraderbarare": "otraderbar",
    "otraderbarares": "otraderbar",
    "otraderbaras": "otraderbar",
    "otraderbarast": "otraderbar",
    "otraderbaraste": "otraderbar",
    "otraderbarastes": "otraderbar",
    "otraderbarasts": "otraderbar",
    "otraderbare": "otraderbar",
    "otraderbares": "otraderbar",
    "otraderbarheten": "otraderbarhet",
    "otraderbarhetens": "otraderbarhet",
    "otraderbarhets": "otraderbarhet",
    "otraderbars": "otraderbar",
    "otraderbart": "otraderbar",
    "otraderbarts": "otraderbar",
    "otrafikerade": "otrafikerad",
    "otrafikerades": "otrafikerad",
    "otrafikerads": "otrafikerad",
    "otrafikerat": "otrafikerad",
    "otrafikerats": "otrafikerad",
    "otrafikerbara": "otrafikerbar",
    "otrafikerbarare": "otrafikerbar",
    "otrafikerbarares": "otrafikerbar",
    "otrafikerbaras": "otrafikerbar",
    "otrafikerbarast": "otrafikerbar",
    "otrafikerbaraste": "otrafikerbar",
    "otrafikerbarastes": "otrafikerbar",
    "otrafikerbarasts": "otrafikerbar",
    "otrafikerbare": "otrafikerbar",
    "otrafikerbares": "otrafikerbar",
    "otrafikerbarheten": "otrafikerbarhet",
    "otrafikerbarhetens": "otrafikerbarhet",
    "otrafikerbarhets": "otrafikerbarhet",
    "otrafikerbars": "otrafikerbar",
    "otrafikerbart": "otrafikerbar",
    "otrafikerbarts": "otrafikerbar",
    "otrakasserade": "otrakasserad",
    "otrakasserades": "otrakasserad",
    "otrakasserads": "otrakasserad",
    "otrakasserat": "otrakasserad",
    "otrakasserats": "otrakasserad",
    "otrakasserbara": "otrakasserbar",
    "otrakasserbarare": "otrakasserbar",
    "otrakasserbarares": "otrakasserbar",
    "otrakasserbaras": "otrakasserbar",
    "otrakasserbarast": "otrakasserbar",
    "otrakasserbaraste": "otrakasserbar",
    "otrakasserbarastes": "otrakasserbar",
    "otrakasserbarasts": "otrakasserbar",
    "otrakasserbare": "otrakasserbar",
    "otrakasserbares": "otrakasserbar",
    "otrakasserbarheten": "otrakasserbarhet",
    "otrakasserbarhetens": "otrakasserbarhet",
    "otrakasserbarhets": "otrakasserbarhet",
    "otrakasserbars": "otrakasserbar",
    "otrakasserbart": "otrakasserbar",
    "otrakasserbarts": "otrakasserbar",
    "otrakterade": "otrakterad",
    "otrakterades": "otrakterad",
    "otrakterads": "otrakterad",
    "otrakterat": "otrakterad",
    "otrakterats": "otrakterad",
    "otrakterbara": "otrakterbar",
    "otrakterbarare": "otrakterbar",
    "otrakterbarares": "otrakterbar",
    "otrakterbaras": "otrakterbar",
    "otrakterbarast": "otrakterbar",
    "otrakterbaraste": "otrakterbar",
    "otrakterbarastes": "otrakterbar",
    "otrakterbarasts": "otrakterbar",
    "otrakterbare": "otrakterbar",
    "otrakterbares": "otrakterbar",
    "otrakterbarheten": "otrakterbarhet",
    "otrakterbarhetens": "otrakterbarhet",
    "otrakterbarhets": "otrakterbarhet",
    "otrakterbars": "otrakterbar",
    "otrakterbart": "otrakterbar",
    "otrakterbarts": "otrakterbar",
    "otrancherade": "otrancherad",
    "otrancherades": "otrancherad",
    "otrancherads": "otrancherad",
    "otrancherat": "otrancherad",
    "otrancherats": "otrancherad",
    "otrancherbara": "otrancherbar",
    "otrancherbarare": "otrancherbar",
    "otrancherbarares": "otrancherbar",
    "otrancherbaras": "otrancherbar",
    "otrancherbarast": "otrancherbar",
    "otrancherbaraste": "otrancherbar",
    "otrancherbarastes": "otrancherbar",
    "otrancherbarasts": "otrancherbar",
    "otrancherbare": "otrancherbar",
    "otrancherbares": "otrancherbar",
    "otrancherbarheten": "otrancherbarhet",
    "otrancherbarhetens": "otrancherbarhet",
    "otrancherbarhets": "otrancherbarhet",
    "otrancherbars": "otrancherbar",
    "otrancherbart": "otrancherbar",
    "otrancherbarts": "otrancherbar",
    "otransfererade": "otransfererad",
    "otransfererades": "otransfererad",
    "otransfererads": "otransfererad",
    "otransfererat": "otransfererad",
    "otransfererats": "otransfererad",
    "otransfererbara": "otransfererbar",
    "otransfererbarare": "otransfererbar",
    "otransfererbarares": "otransfererbar",
    "otransfererbaras": "otransfererbar",
    "otransfererbarast": "otransfererbar",
    "otransfererbaraste": "otransfererbar",
    "otransfererbarastes": "otransfererbar",
    "otransfererbarasts": "otransfererbar",
    "otransfererbare": "otransfererbar",
    "otransfererbares": "otransfererbar",
    "otransfererbarheten": "otransfererbarhet",
    "otransfererbarhetens": "otransfererbarhet",
    "otransfererbarhets": "otransfererbarhet",
    "otransfererbars": "otransfererbar",
    "otransfererbart": "otransfererbar",
    "otransfererbarts": "otransfererbar",
    "otransformerade": "otransformerad",
    "otransformerades": "otransformerad",
    "otransformerads": "otransformerad",
    "otransformerat": "otransformerad",
    "otransformerats": "otransformerad",
    "otransformerbara": "otransformerbar",
    "otransformerbarare": "otransformerbar",
    "otransformerbarares": "otransformerbar",
    "otransformerbaras": "otransformerbar",
    "otransformerbarast": "otransformerbar",
    "otransformerbaraste": "otransformerbar",
    "otransformerbarastes": "otransformerbar",
    "otransformerbarasts": "otransformerbar",
    "otransformerbare": "otransformerbar",
    "otransformerbares": "otransformerbar",
    "otransformerbarheten": "otransformerbarhet",
    "otransformerbarhetens": "otransformerbarhet",
    "otransformerbarhets": "otransformerbarhet",
    "otransformerbars": "otransformerbar",
    "otransformerbart": "otransformerbar",
    "otransformerbarts": "otransformerbar",
    "otransiterade": "otransiterad",
    "otransiterades": "otransiterad",
    "otransiterads": "otransiterad",
    "otransiterat": "otransiterad",
    "otransiterats": "otransiterad",
    "otransiterbara": "otransiterbar",
    "otransiterbarare": "otransiterbar",
    "otransiterbarares": "otransiterbar",
    "otransiterbaras": "otransiterbar",
    "otransiterbarast": "otransiterbar",
    "otransiterbaraste": "otransiterbar",
    "otransiterbarastes": "otransiterbar",
    "otransiterbarasts": "otransiterbar",
    "otransiterbare": "otransiterbar",
    "otransiterbares": "otransiterbar",
    "otransiterbarheten": "otransiterbarhet",
    "otransiterbarhetens": "otransiterbarhet",
    "otransiterbarhets": "otransiterbarhet",
    "otransiterbars": "otransiterbar",
    "otransiterbart": "otransiterbar",
    "otransiterbarts": "otransiterbar",
    "otranskriberade": "otranskriberad",
    "otranskriberades": "otranskriberad",
    "otranskriberads": "otranskriberad",
    "otranskriberat": "otranskriberad",
    "otranskriberats": "otranskriberad",
    "otranskriberbara": "otranskriberbar",
    "otranskriberbarare": "otranskriberbar",
    "otranskriberbarares": "otranskriberbar",
    "otranskriberbaras": "otranskriberbar",
    "otranskriberbarast": "otranskriberbar",
    "otranskriberbaraste": "otranskriberbar",
    "otranskriberbarastes": "otranskriberbar",
    "otranskriberbarasts": "otranskriberbar",
    "otranskriberbare": "otranskriberbar",
    "otranskriberbares": "otranskriberbar",
    "otranskriberbarheten": "otranskriberbarhet",
    "otranskriberbarhetens": "otranskriberbarhet",
    "otranskriberbarhets": "otranskriberbarhet",
    "otranskriberbars": "otranskriberbar",
    "otranskriberbart": "otranskriberbar",
    "otranskriberbarts": "otranskriberbar",
    "otranslittererade": "otranslittererad",
    "otranslittererades": "otranslittererad",
    "otranslittererads": "otranslittererad",
    "otranslittererat": "otranslittererad",
    "otranslittererats": "otranslittererad",
    "otranslittererbara": "otranslittererbar",
    "otranslittererbarare": "otranslittererbar",
    "otranslittererbarares": "otranslittererbar",
    "otranslittererbaras": "otranslittererbar",
    "otranslittererbarast": "otranslittererbar",
    "otranslittererbaraste": "otranslittererbar",
    "otranslittererbarastes": "otranslittererbar",
    "otranslittererbarasts": "otranslittererbar",
    "otranslittererbare": "otranslittererbar",
    "otranslittererbares": "otranslittererbar",
    "otranslittererbarheten": "otranslittererbarhet",
    "otranslittererbarhetens": "otranslittererbarhet",
    "otranslittererbarhets": "otranslittererbarhet",
    "otranslittererbars": "otranslittererbar",
    "otranslittererbart": "otranslittererbar",
    "otranslittererbarts": "otranslittererbar",
    "otransmitterade": "otransmitterad",
    "otransmitterades": "otransmitterad",
    "otransmitterads": "otransmitterad",
    "otransmitterat": "otransmitterad",
    "otransmitterats": "otransmitterad",
    "otransmitterbara": "otransmitterbar",
    "otransmitterbarare": "otransmitterbar",
    "otransmitterbarares": "otransmitterbar",
    "otransmitterbaras": "otransmitterbar",
    "otransmitterbarast": "otransmitterbar",
    "otransmitterbaraste": "otransmitterbar",
    "otransmitterbarastes": "otransmitterbar",
    "otransmitterbarasts": "otransmitterbar",
    "otransmitterbare": "otransmitterbar",
    "otransmitterbares": "otransmitterbar",
    "otransmitterbarheten": "otransmitterbarhet",
    "otransmitterbarhetens": "otransmitterbarhet",
    "otransmitterbarhets": "otransmitterbarhet",
    "otransmitterbars": "otransmitterbar",
    "otransmitterbart": "otransmitterbar",
    "otransmitterbarts": "otransmitterbar",
    "otransmuterade": "otransmuterad",
    "otransmuterades": "otransmuterad",
    "otransmuterads": "otransmuterad",
    "otransmuterat": "otransmuterad",
    "otransmuterats": "otransmuterad",
    "otransmuterbara": "otransmuterbar",
    "otransmuterbarare": "otransmuterbar",
    "otransmuterbarares": "otransmuterbar",
    "otransmuterbaras": "otransmuterbar",
    "otransmuterbarast": "otransmuterbar",
    "otransmuterbaraste": "otransmuterbar",
    "otransmuterbarastes": "otransmuterbar",
    "otransmuterbarasts": "otransmuterbar",
    "otransmuterbare": "otransmuterbar",
    "otransmuterbares": "otransmuterbar",
    "otransmuterbarheten": "otransmuterbarhet",
    "otransmuterbarhetens": "otransmuterbarhet",
    "otransmuterbarhets": "otransmuterbarhet",
    "otransmuterbars": "otransmuterbar",
    "otransmuterbart": "otransmuterbar",
    "otransmuterbarts": "otransmuterbar",
    "otransplanterade": "otransplanterad",
    "otransplanterades": "otransplanterad",
    "otransplanterads": "otransplanterad",
    "otransplanterat": "otransplanterad",
    "otransplanterats": "otransplanterad",
    "otransplanterbara": "otransplanterbar",
    "otransplanterbarare": "otransplanterbar",
    "otransplanterbarares": "otransplanterbar",
    "otransplanterbaras": "otransplanterbar",
    "otransplanterbarast": "otransplanterbar",
    "otransplanterbaraste": "otransplanterbar",
    "otransplanterbarastes": "otransplanterbar",
    "otransplanterbarasts": "otransplanterbar",
    "otransplanterbare": "otransplanterbar",
    "otransplanterbares": "otransplanterbar",
    "otransplanterbarheten": "otransplanterbarhet",
    "otransplanterbarhetens": "otransplanterbarhet",
    "otransplanterbarhets": "otransplanterbarhet",
    "otransplanterbars": "otransplanterbar",
    "otransplanterbart": "otransplanterbar",
    "otransplanterbarts": "otransplanterbar",
    "otransponerade": "otransponerad",
    "otransponerades": "otransponerad",
    "otransponerads": "otransponerad",
    "otransponerat": "otransponerad",
    "otransponerats": "otransponerad",
    "otransponerbara": "otransponerbar",
    "otransponerbarare": "otransponerbar",
    "otransponerbarares": "otransponerbar",
    "otransponerbaras": "otransponerbar",
    "otransponerbarast": "otransponerbar",
    "otransponerbaraste": "otransponerbar",
    "otransponerbarastes": "otransponerbar",
    "otransponerbarasts": "otransponerbar",
    "otransponerbare": "otransponerbar",
    "otransponerbares": "otransponerbar",
    "otransponerbarheten": "otransponerbarhet",
    "otransponerbarhetens": "otransponerbarhet",
    "otransponerbarhets": "otransponerbarhet",
    "otransponerbars": "otransponerbar",
    "otransponerbart": "otransponerbar",
    "otransponerbarts": "otransponerbar",
    "otransporterade": "otransporterad",
    "otransporterades": "otransporterad",
    "otransporterads": "otransporterad",
    "otransporterat": "otransporterad",
    "otransporterats": "otransporterad",
    "otransporterbara": "otransporterbar",
    "otransporterbarare": "otransporterbar",
    "otransporterbarares": "otransporterbar",
    "otransporterbaras": "otransporterbar",
    "otransporterbarast": "otransporterbar",
    "otransporterbaraste": "otransporterbar",
    "otransporterbarastes": "otransporterbar",
    "otransporterbarasts": "otransporterbar",
    "otransporterbare": "otransporterbar",
    "otransporterbares": "otransporterbar",
    "otransporterbarheten": "otransporterbarhet",
    "otransporterbarhetens": "otransporterbarhet",
    "otransporterbarhets": "otransporterbarhet",
    "otransporterbars": "otransporterbar",
    "otransporterbart": "otransporterbar",
    "otransporterbarts": "otransporterbar",
    "otransumerade": "otransumerad",
    "otransumerades": "otransumerad",
    "otransumerads": "otransumerad",
    "otransumerat": "otransumerad",
    "otransumerats": "otransumerad",
    "otransumerbara": "otransumerbar",
    "otransumerbarare": "otransumerbar",
    "otransumerbarares": "otransumerbar",
    "otransumerbaras": "otransumerbar",
    "otransumerbarast": "otransumerbar",
    "otransumerbaraste": "otransumerbar",
    "otransumerbarastes": "otransumerbar",
    "otransumerbarasts": "otransumerbar",
    "otransumerbare": "otransumerbar",
    "otransumerbares": "otransumerbar",
    "otransumerbarheten": "otransumerbarhet",
    "otransumerbarhetens": "otransumerbarhet",
    "otransumerbarhets": "otransumerbarhet",
    "otransumerbars": "otransumerbar",
    "otransumerbart": "otransumerbar",
    "otransumerbarts": "otransumerbar",
    "otrasserade": "otrasserad",
    "otrasserades": "otrasserad",
    "otrasserads": "otrasserad",
    "otrasserat": "otrasserad",
    "otrasserats": "otrasserad",
    "otrasserbara": "otrasserbar",
    "otrasserbarare": "otrasserbar",
    "otrasserbarares": "otrasserbar",
    "otrasserbaras": "otrasserbar",
    "otrasserbarast": "otrasserbar",
    "otrasserbaraste": "otrasserbar",
    "otrasserbarastes": "otrasserbar",
    "otrasserbarasts": "otrasserbar",
    "otrasserbare": "otrasserbar",
    "otrasserbares": "otrasserbar",
    "otrasserbarheten": "otrasserbarhet",
    "otrasserbarhetens": "otrasserbarhet",
    "otrasserbarhets": "otrasserbarhet",
    "otrasserbars": "otrasserbar",
    "otrasserbart": "otrasserbar",
    "otrasserbarts": "otrasserbar",
    "otravesterade": "otravesterad",
    "otravesterades": "otravesterad",
    "otravesterads": "otravesterad",
    "otravesterat": "otravesterad",
    "otravesterats": "otravesterad",
    "otravesterbara": "otravesterbar",
    "otravesterbarare": "otravesterbar",
    "otravesterbarares": "otravesterbar",
    "otravesterbaras": "otravesterbar",
    "otravesterbarast": "otravesterbar",
    "otravesterbaraste": "otravesterbar",
    "otravesterbarastes": "otravesterbar",
    "otravesterbarasts": "otravesterbar",
    "otravesterbare": "otravesterbar",
    "otravesterbares": "otravesterbar",
    "otravesterbarheten": "otravesterbarhet",
    "otravesterbarhetens": "otravesterbarhet",
    "otravesterbarhets": "otravesterbarhet",
    "otravesterbars": "otravesterbar",
    "otravesterbart": "otravesterbar",
    "otravesterbarts": "otravesterbar",
    "otrepanerade": "otrepanerad",
    "otrepanerades": "otrepanerad",
    "otrepanerads": "otrepanerad",
    "otrepanerat": "otrepanerad",
    "otrepanerats": "otrepanerad",
    "otrepanerbara": "otrepanerbar",
    "otrepanerbarare": "otrepanerbar",
    "otrepanerbarares": "otrepanerbar",
    "otrepanerbaras": "otrepanerbar",
    "otrepanerbarast": "otrepanerbar",
    "otrepanerbaraste": "otrepanerbar",
    "otrepanerbarastes": "otrepanerbar",
    "otrepanerbarasts": "otrepanerbar",
    "otrepanerbare": "otrepanerbar",
    "otrepanerbares": "otrepanerbar",
    "otrepanerbarheten": "otrepanerbarhet",
    "otrepanerbarhetens": "otrepanerbarhet",
    "otrepanerbarhets": "otrepanerbarhet",
    "otrepanerbars": "otrepanerbar",
    "otrepanerbart": "otrepanerbar",
    "otrepanerbarts": "otrepanerbar",
    "otrevliga": "otrevlig",
    "otrevligare": "otrevlig",
    "otrevligares": "otrevlig",
    "otrevligas": "otrevlig",
    "otrevligast": "otrevlig",
    "otrevligaste": "otrevlig",
    "otrevligastes": "otrevlig",
    "otrevligasts": "otrevlig",
    "otrevlige": "otrevlig",
    "otrevliges": "otrevlig",
    "otrevligheten": "otrevlighet",
    "otrevlighetens": "otrevlighet",
    "otrevligheter": "otrevlighet",
    "otrevligheterna": "otrevlighet",
    "otrevligheternas": "otrevlighet",
    "otrevligheters": "otrevlighet",
    "otrevlighets": "otrevlighet",
    "otrevligs": "otrevlig",
    "otrevligt": "otrevlig",
    "otrevligts": "otrevlig",
    "otriangulerade": "otriangulerad",
    "otriangulerades": "otriangulerad",
    "otriangulerads": "otriangulerad",
    "otriangulerat": "otriangulerad",
    "otriangulerats": "otriangulerad",
    "otriangulerbara": "otriangulerbar",
    "otriangulerbarare": "otriangulerbar",
    "otriangulerbarares": "otriangulerbar",
    "otriangulerbaras": "otriangulerbar",
    "otriangulerbarast": "otriangulerbar",
    "otriangulerbaraste": "otriangulerbar",
    "otriangulerbarastes": "otriangulerbar",
    "otriangulerbarasts": "otriangulerbar",
    "otriangulerbare": "otriangulerbar",
    "otriangulerbares": "otriangulerbar",
    "otriangulerbarheten": "otriangulerbarhet",
    "otriangulerbarhetens": "otriangulerbarhet",
    "otriangulerbarhets": "otriangulerbarhet",
    "otriangulerbars": "otriangulerbar",
    "otriangulerbart": "otriangulerbar",
    "otriangulerbarts": "otriangulerbar",
    "otrierade": "otrierad",
    "otrierades": "otrierad",
    "otrierads": "otrierad",
    "otrierat": "otrierad",
    "otrierats": "otrierad",
    "otrierbara": "otrierbar",
    "otrierbarare": "otrierbar",
    "otrierbarares": "otrierbar",
    "otrierbaras": "otrierbar",
    "otrierbarast": "otrierbar",
    "otrierbaraste": "otrierbar",
    "otrierbarastes": "otrierbar",
    "otrierbarasts": "otrierbar",
    "otrierbare": "otrierbar",
    "otrierbares": "otrierbar",
    "otrierbarheten": "otrierbarhet",
    "otrierbarhetens": "otrierbarhet",
    "otrierbarhets": "otrierbarhet",
    "otrierbars": "otrierbar",
    "otrierbart": "otrierbar",
    "otrierbarts": "otrierbar",
    "otrivialiserade": "otrivialiserad",
    "otrivialiserades": "otrivialiserad",
    "otrivialiserads": "otrivialiserad",
    "otrivialiserat": "otrivialiserad",
    "otrivialiserats": "otrivialiserad",
    "otrivialiserbara": "otrivialiserbar",
    "otrivialiserbarare": "otrivialiserbar",
    "otrivialiserbarares": "otrivialiserbar",
    "otrivialiserbaras": "otrivialiserbar",
    "otrivialiserbarast": "otrivialiserbar",
    "otrivialiserbaraste": "otrivialiserbar",
    "otrivialiserbarastes": "otrivialiserbar",
    "otrivialiserbarasts": "otrivialiserbar",
    "otrivialiserbare": "otrivialiserbar",
    "otrivialiserbares": "otrivialiserbar",
    "otrivialiserbarheten": "otrivialiserbarhet",
    "otrivialiserbarhetens": "otrivialiserbarhet",
    "otrivialiserbarhets": "otrivialiserbarhet",
    "otrivialiserbars": "otrivialiserbar",
    "otrivialiserbart": "otrivialiserbar",
    "otrivialiserbarts": "otrivialiserbar",
    "otrivsamheten": "otrivsamhet",
    "otrivsamhetens": "otrivsamhet",
    "otrivsamhets": "otrivsamhet",
    "otrivsamma": "otrivsam",
    "otrivsammare": "otrivsam",
    "otrivsammares": "otrivsam",
    "otrivsammas": "otrivsam",
    "otrivsammast": "otrivsam",
    "otrivsammaste": "otrivsam",
    "otrivsammastes": "otrivsam",
    "otrivsammasts": "otrivsam",
    "otrivsamme": "otrivsam",
    "otrivsammes": "otrivsam",
    "otrivsams": "otrivsam",
    "otrivsamt": "otrivsam",
    "otrivsamts": "otrivsam",
    "otrivseln": "otrivsel",
    "otrivselns": "otrivsel",
    "otrivsels": "otrivsel",
    "otrogens": "otrogen",
    "otroget": "otrogen",
    "otrogets": "otrogen",
    "otrogna": "otrogen",
    "otrognare": "otrogen",
    "otrognares": "otrogen",
    "otrognas": "otrogen",
    "otrognast": "otrogen",
    "otrognaste": "otrogen",
    "otrognastes": "otrogen",
    "otrognasts": "otrogen",
    "otrogne": "otrogen",
    "otrognes": "otrogen",
    "otroheten": "otrohet",
    "otrohetens": "otrohet",
    "otroheter": "otrohet",
    "otroheterna": "otrohet",
    "otroheternas": "otrohet",
    "otroheters": "otrohet",
    "otrohets": "otrohet",
    "otrohetsaffären": "otrohetsaffär",
    "otrohetsaffärens": "otrohetsaffär",
    "otrohetsaffärer": "otrohetsaffär",
    "otrohetsaffärerna": "otrohetsaffär",
    "otrohetsaffärernas": "otrohetsaffär",
    "otrohetsaffärers": "otrohetsaffär",
    "otrohetsaffärs": "otrohetsaffär",
    "otrohetsdraman": "otrohetsdrama",
    "otrohetsdramana": "otrohetsdrama",
    "otrohetsdramanas": "otrohetsdrama",
    "otrohetsdramans": "otrohetsdrama",
    "otrohetsdramas": "otrohetsdrama",
    "otrohetsdramat": "otrohetsdrama",
    "otrohetsdramats": "otrohetsdrama",
    "otrohetsdramer": "otrohetsdrama",
    "otrohetsdramerna": "otrohetsdrama",
    "otrohetsdramernas": "otrohetsdrama",
    "otrohetsdramers": "otrohetsdrama",
    "otrohetsgrälen": "otrohetsgräl",
    "otrohetsgrälens": "otrohetsgräl",
    "otrohetsgrälet": "otrohetsgräl",
    "otrohetsgrälets": "otrohetsgräl",
    "otrohetsgräls": "otrohetsgräl",
    "otrohetsskandalen": "otrohetsskandal",
    "otrohetsskandalens": "otrohetsskandal",
    "otrohetsskandaler": "otrohetsskandal",
    "otrohetsskandalerna": "otrohetsskandal",
    "otrohetsskandalernas": "otrohetsskandal",
    "otrohetsskandalers": "otrohetsskandal",
    "otrohetsskandals": "otrohetsskandal",
    "otrohetstrassels": "otrohetstrassel",
    "otrohetstrasslen": "otrohetstrassel",
    "otrohetstrasslens": "otrohetstrassel",
    "otrohetstrasslet": "otrohetstrassel",
    "otrohetstrasslets": "otrohetstrassel",
    "otrohetsuppgiften": "otrohetsuppgift",
    "otrohetsuppgiftens": "otrohetsuppgift",
    "otrohetsuppgifter": "otrohetsuppgift",
    "otrohetsuppgifterna": "otrohetsuppgift",
    "otrohetsuppgifternas": "otrohetsuppgift",
    "otrohetsuppgifters": "otrohetsuppgift",
    "otrohetsuppgifts": "otrohetsuppgift",
    "otroliga": "otrolig",
    "otroligare": "otrolig",
    "otroligares": "otrolig",
    "otroligas": "otrolig",
    "otroligast": "otrolig",
    "otroligaste": "otrolig",
    "otroligastes": "otrolig",
    "otroligasts": "otrolig",
    "otrolige": "otrolig",
    "otroliges": "otrolig",
    "otroligheten": "otrolighet",
    "otrolighetens": "otrolighet",
    "otroligheter": "otrolighet",
    "otroligheterna": "otrolighet",
    "otroligheternas": "otrolighet",
    "otroligheters": "otrolighet",
    "otrolighets": "otrolighet",
    "otroligs": "otrolig",
    "otroligt": "otrolig",
    "otroligts": "otrolig",
    "otron": "otro",
    "otrons": "otro",
    "otros": "otro",
    "otryckbara": "otryckbar",
    "otryckbarare": "otryckbar",
    "otryckbarares": "otryckbar",
    "otryckbaras": "otryckbar",
    "otryckbarast": "otryckbar",
    "otryckbaraste": "otryckbar",
    "otryckbarastes": "otryckbar",
    "otryckbarasts": "otryckbar",
    "otryckbare": "otryckbar",
    "otryckbares": "otryckbar",
    "otryckbarheten": "otryckbarhet",
    "otryckbarhetens": "otryckbarhet",
    "otryckbarheter": "otryckbarhet",
    "otryckbarheterna": "otryckbarhet",
    "otryckbarheternas": "otryckbarhet",
    "otryckbarheters": "otryckbarhet",
    "otryckbarhets": "otryckbarhet",
    "otryckbars": "otryckbar",
    "otryckbart": "otryckbar",
    "otryckbarts": "otryckbar",
    "otryckta": "otryckt",
    "otrycktare": "otryckt",
    "otrycktares": "otryckt",
    "otrycktas": "otryckt",
    "otrycktast": "otryckt",
    "otrycktaste": "otryckt",
    "otrycktastes": "otryckt",
    "otrycktasts": "otryckt",
    "otryckte": "otryckt",
    "otrycktes": "otryckt",
    "otryckts": "otryckt",
    "otryfferade": "otryfferad",
    "otryfferades": "otryfferad",
    "otryfferads": "otryfferad",
    "otryfferat": "otryfferad",
    "otryfferats": "otryfferad",
    "otryfferbara": "otryfferbar",
    "otryfferbarare": "otryfferbar",
    "otryfferbarares": "otryfferbar",
    "otryfferbaras": "otryfferbar",
    "otryfferbarast": "otryfferbar",
    "otryfferbaraste": "otryfferbar",
    "otryfferbarastes": "otryfferbar",
    "otryfferbarasts": "otryfferbar",
    "otryfferbare": "otryfferbar",
    "otryfferbares": "otryfferbar",
    "otryfferbarheten": "otryfferbarhet",
    "otryfferbarhetens": "otryfferbarhet",
    "otryfferbarhets": "otryfferbarhet",
    "otryfferbars": "otryfferbar",
    "otryfferbart": "otryfferbar",
    "otryfferbarts": "otryfferbar",
    "otrygga": "otrygg",
    "otryggare": "otrygg",
    "otryggares": "otrygg",
    "otryggas": "otrygg",
    "otryggast": "otrygg",
    "otryggaste": "otrygg",
    "otryggastes": "otrygg",
    "otryggasts": "otrygg",
    "otrygge": "otrygg",
    "otrygges": "otrygg",
    "otryggheten": "otrygghet",
    "otrygghetens": "otrygghet",
    "otrygghets": "otrygghet",
    "otryggs": "otrygg",
    "otryggt": "otrygg",
    "otryggts": "otrygg",
    "otränade": "otränad",
    "otränades": "otränad",
    "otränads": "otränad",
    "otränat": "otränad",
    "otränats": "otränad",
    "otröstliga": "otröstlig",
    "otröstligare": "otröstlig",
    "otröstligares": "otröstlig",
    "otröstligas": "otröstlig",
    "otröstligast": "otröstlig",
    "otröstligaste": "otröstlig",
    "otröstligastes": "otröstlig",
    "otröstligasts": "otröstlig",
    "otröstlige": "otröstlig",
    "otröstliges": "otröstlig",
    "otröstligheten": "otröstlighet",
    "otröstlighetens": "otröstlighet",
    "otröstlighets": "otröstlighet",
    "otröstligs": "otröstlig",
    "otröstligt": "otröstlig",
    "otröstligts": "otröstlig",
    "otröttliga": "otröttlig",
    "otröttligare": "otröttlig",
    "otröttligares": "otröttlig",
    "otröttligas": "otröttlig",
    "otröttligast": "otröttlig",
    "otröttligaste": "otröttlig",
    "otröttligastes": "otröttlig",
    "otröttligasts": "otröttlig",
    "otröttlige": "otröttlig",
    "otröttliges": "otröttlig",
    "otröttligheten": "otröttlighet",
    "otröttlighetens": "otröttlighet",
    "otröttlighets": "otröttlighet",
    "otröttligs": "otröttlig",
    "otröttligt": "otröttlig",
    "otröttligts": "otröttlig",
    "ots": "o",
    "ottan": "otta",
    "ottans": "otta",
    "ottas": "otta",
    "otte": "otta",
    "ottesången": "ottesång",
    "ottesångens": "ottesång",
    "ottesångs": "ottesång",
    "ottomanen": "ottoman",
    "ottomanens": "ottoman",
    "ottomaner": "ottoman",
    "ottomanerna": "ottoman",
    "ottomanernas": "ottoman",
    "ottomaners": "ottoman",
    "ottomans": "ottoman",
    "ottomanska": "ottomansk",
    "ottomanskare": "ottomansk",
    "ottomanskares": "ottomansk",
    "ottomanskas": "ottomansk",
    "ottomanskast": "ottomansk",
    "ottomanskaste": "ottomansk",
    "ottomanskastes": "ottomansk",
    "ottomanskasts": "ottomansk",
    "ottomanske": "ottomansk",
    "ottomanskes": "ottomansk",
    "ottomansks": "ottomansk",
    "ottomanskt": "ottomansk",
    "ottomanskts": "ottomansk",
    "ottomotorer": "ottomotor",
    "ottomotorerna": "ottomotor",
    "ottomotorernas": "ottomotor",
    "ottomotorers": "ottomotor",
    "ottomotorn": "ottomotor",
    "ottomotorns": "ottomotor",
    "ottomotors": "ottomotor",
    "ottor": "otta",
    "ottorna": "otta",
    "ottornas": "otta",
    "ottors": "otta",
    "otuktade": "otuktad",
    "otuktades": "otuktad",
    "otuktads": "otuktad",
    "otuktat": "otuktad",
    "otuktats": "otuktad",
    "otukten": "otukt",
    "otuktens": "otukt",
    "otuktiga": "otuktig",
    "otuktigare": "otuktig",
    "otuktigares": "otuktig",
    "otuktigas": "otuktig",
    "otuktigast": "otuktig",
    "otuktigaste": "otuktig",
    "otuktigastes": "otuktig",
    "otuktigasts": "otuktig",
    "otuktige": "otuktig",
    "otuktiges": "otuktig",
    "otuktigs": "otuktig",
    "otuktigt": "otuktig",
    "otuktigts": "otuktig",
    "otukts": "otukt",
    "otuperade": "otuperad",
    "otuperades": "otuperad",
    "otuperads": "otuperad",
    "otuperat": "otuperad",
    "otuperats": "otuperad",
    "otuperbara": "otuperbar",
    "otuperbarare": "otuperbar",
    "otuperbarares": "otuperbar",
    "otuperbaras": "otuperbar",
    "otuperbarast": "otuperbar",
    "otuperbaraste": "otuperbar",
    "otuperbarastes": "otuperbar",
    "otuperbarasts": "otuperbar",
    "otuperbare": "otuperbar",
    "otuperbares": "otuperbar",
    "otuperbarheten": "otuperbarhet",
    "otuperbarhetens": "otuperbarhet",
    "otuperbarhets": "otuperbarhet",
    "otuperbars": "otuperbar",
    "otuperbart": "otuperbar",
    "otuperbarts": "otuperbar",
    "oturades": "oturas",
    "oturats": "oturas",
    "oturen": "otur",
    "oturens": "otur",
    "oturliga": "oturlig",
    "oturligare": "oturlig",
    "oturligares": "oturlig",
    "oturligas": "oturlig",
    "oturligast": "oturlig",
    "oturligaste": "oturlig",
    "oturligastes": "oturlig",
    "oturligasts": "oturlig",
    "oturlige": "oturlig",
    "oturliges": "oturlig",
    "oturligheten": "oturlighet",
    "oturlighetens": "oturlighet",
    "oturlighets": "oturlighet",
    "oturligs": "oturlig",
    "oturligt": "oturlig",
    "oturligts": "oturlig",
    "oturnerade": "oturnerad",
    "oturnerades": "oturnerad",
    "oturnerads": "oturnerad",
    "oturnerat": "oturnerad",
    "oturnerats": "oturnerad",
    "oturnerbara": "oturnerbar",
    "oturnerbarare": "oturnerbar",
    "oturnerbarares": "oturnerbar",
    "oturnerbaras": "oturnerbar",
    "oturnerbarast": "oturnerbar",
    "oturnerbaraste": "oturnerbar",
    "oturnerbarastes": "oturnerbar",
    "oturnerbarasts": "oturnerbar",
    "oturnerbare": "oturnerbar",
    "oturnerbares": "oturnerbar",
    "oturnerbarheten": "oturnerbarhet",
    "oturnerbarhetens": "oturnerbarhet",
    "oturnerbarhets": "oturnerbarhet",
    "oturnerbars": "oturnerbar",
    "oturnerbart": "oturnerbar",
    "oturnerbarts": "oturnerbar",
    "oturs": "otur",
    "otursamheten": "otursamhet",
    "otursamhetens": "otursamhet",
    "otursamhets": "otursamhet",
    "otursamma": "otursam",
    "otursammare": "otursam",
    "otursammares": "otursam",
    "otursammas": "otursam",
    "otursammast": "otursam",
    "otursammaste": "otursam",
    "otursammastes": "otursam",
    "otursammasts": "otursam",
    "otursamme": "otursam",
    "otursammes": "otursam",
    "otursams": "otursam",
    "otursamt": "otursam",
    "otursamts": "otursam",
    "otursförföljda": "otursförföljd",
    "otursförföljdare": "otursförföljd",
    "otursförföljdares": "otursförföljd",
    "otursförföljdas": "otursförföljd",
    "otursförföljdast": "otursförföljd",
    "otursförföljdaste": "otursförföljd",
    "otursförföljdastes": "otursförföljd",
    "otursförföljdasts": "otursförföljd",
    "otursförföljde": "otursförföljd",
    "otursförföljdes": "otursförföljd",
    "otursförföljdheten": "otursförföljdhet",
    "otursförföljdhetens": "otursförföljdhet",
    "otursförföljdhets": "otursförföljdhet",
    "otursförföljds": "otursförföljd",
    "otursförföljt": "otursförföljd",
    "otursförföljts": "otursförföljd",
    "otuscherade": "otuscherad",
    "otuscherades": "otuscherad",
    "otuscherads": "otuscherad",
    "otuscherat": "otuscherad",
    "otuscherats": "otuscherad",
    "otuscherbara": "otuscherbar",
    "otuscherbarare": "otuscherbar",
    "otuscherbarares": "otuscherbar",
    "otuscherbaras": "otuscherbar",
    "otuscherbarast": "otuscherbar",
    "otuscherbaraste": "otuscherbar",
    "otuscherbarastes": "otuscherbar",
    "otuscherbarasts": "otuscherbar",
    "otuscherbare": "otuscherbar",
    "otuscherbares": "otuscherbar",
    "otuscherbarheten": "otuscherbarhet",
    "otuscherbarhetens": "otuscherbarhet",
    "otuscherbarhets": "otuscherbarhet",
    "otuscherbars": "otuscherbar",
    "otuscherbart": "otuscherbar",
    "otuscherbarts": "otuscherbar",
    "otvetydiga": "otvetydig",
    "otvetydigare": "otvetydig",
    "otvetydigares": "otvetydig",
    "otvetydigas": "otvetydig",
    "otvetydigast": "otvetydig",
    "otvetydigaste": "otvetydig",
    "otvetydigastes": "otvetydig",
    "otvetydigasts": "otvetydig",
    "otvetydige": "otvetydig",
    "otvetydiges": "otvetydig",
    "otvetydigheten": "otvetydighet",
    "otvetydighetens": "otvetydighet",
    "otvetydighets": "otvetydighet",
    "otvetydigs": "otvetydig",
    "otvetydigt": "otvetydig",
    "otvetydigts": "otvetydig",
    "otvivelaktiga": "otvivelaktig",
    "otvivelaktigare": "otvivelaktig",
    "otvivelaktigares": "otvivelaktig",
    "otvivelaktigas": "otvivelaktig",
    "otvivelaktigast": "otvivelaktig",
    "otvivelaktigaste": "otvivelaktig",
    "otvivelaktigastes": "otvivelaktig",
    "otvivelaktigasts": "otvivelaktig",
    "otvivelaktige": "otvivelaktig",
    "otvivelaktiges": "otvivelaktig",
    "otvivelaktigheten": "otvivelaktighet",
    "otvivelaktighetens": "otvivelaktighet",
    "otvivelaktighets": "otvivelaktighet",
    "otvivelaktigs": "otvivelaktig",
    "otvivelaktigt": "otvivelaktig",
    "otvivelaktigts": "otvivelaktig",
    "otvungens": "otvungen",
    "otvunget": "otvungen",
    "otvungets": "otvungen",
    "otvungna": "otvungen",
    "otvungnare": "otvungen",
    "otvungnares": "otvungen",
    "otvungnas": "otvungen",
    "otvungnast": "otvungen",
    "otvungnaste": "otvungen",
    "otvungnastes": "otvungen",
    "otvungnasts": "otvungen",
    "otvungne": "otvungen",
    "otvungnes": "otvungen",
    "otvättade": "otvättad",
    "otvättades": "otvättad",
    "otvättads": "otvättad",
    "otvättat": "otvättad",
    "otvättats": "otvättad",
    "otydbara": "otydbar",
    "otydbarare": "otydbar",
    "otydbarares": "otydbar",
    "otydbaras": "otydbar",
    "otydbarast": "otydbar",
    "otydbaraste": "otydbar",
    "otydbarastes": "otydbar",
    "otydbarasts": "otydbar",
    "otydbare": "otydbar",
    "otydbares": "otydbar",
    "otydbarheten": "otydbarhet",
    "otydbarhetens": "otydbarhet",
    "otydbarhets": "otydbarhet",
    "otydbars": "otydbar",
    "otydbart": "otydbar",
    "otydbarts": "otydbar",
    "otydliga": "otydlig",
    "otydligare": "otydlig",
    "otydligares": "otydlig",
    "otydligas": "otydlig",
    "otydligast": "otydlig",
    "otydligaste": "otydlig",
    "otydligastes": "otydlig",
    "otydligasts": "otydlig",
    "otydlige": "otydlig",
    "otydliges": "otydlig",
    "otydligheten": "otydlighet",
    "otydlighetens": "otydlighet",
    "otydligheter": "otydlighet",
    "otydligheterna": "otydlighet",
    "otydligheternas": "otydlighet",
    "otydligheters": "otydlighet",
    "otydlighets": "otydlighet",
    "otydligs": "otydlig",
    "otydligt": "otydlig",
    "otydligts": "otydlig",
    "otyget": "otyg",
    "otygets": "otyg",
    "otyglade": "otyglad",
    "otyglades": "otyglad",
    "otyglads": "otyglad",
    "otyglat": "otyglad",
    "otyglats": "otyglad",
    "otygs": "otyg",
    "otympliga": "otymplig",
    "otympligare": "otymplig",
    "otympligares": "otymplig",
    "otympligas": "otymplig",
    "otympligast": "otymplig",
    "otympligaste": "otymplig",
    "otympligastes": "otymplig",
    "otympligasts": "otymplig",
    "otymplige": "otymplig",
    "otympliges": "otymplig",
    "otympligheten": "otymplighet",
    "otymplighetens": "otymplighet",
    "otympligheter": "otymplighet",
    "otympligheterna": "otymplighet",
    "otympligheternas": "otymplighet",
    "otympligheters": "otymplighet",
    "otymplighets": "otymplighet",
    "otympligs": "otymplig",
    "otympligt": "otymplig",
    "otympligts": "otymplig",
    "otypifierade": "otypifierad",
    "otypifierades": "otypifierad",
    "otypifierads": "otypifierad",
    "otypifierat": "otypifierad",
    "otypifierats": "otypifierad",
    "otypifierbara": "otypifierbar",
    "otypifierbarare": "otypifierbar",
    "otypifierbarares": "otypifierbar",
    "otypifierbaras": "otypifierbar",
    "otypifierbarast": "otypifierbar",
    "otypifierbaraste": "otypifierbar",
    "otypifierbarastes": "otypifierbar",
    "otypifierbarasts": "otypifierbar",
    "otypifierbare": "otypifierbar",
    "otypifierbares": "otypifierbar",
    "otypifierbarheten": "otypifierbarhet",
    "otypifierbarhetens": "otypifierbarhet",
    "otypifierbarhets": "otypifierbarhet",
    "otypifierbars": "otypifierbar",
    "otypifierbart": "otypifierbar",
    "otypifierbarts": "otypifierbar",
    "otypiserade": "otypiserad",
    "otypiserades": "otypiserad",
    "otypiserads": "otypiserad",
    "otypiserat": "otypiserad",
    "otypiserats": "otypiserad",
    "otypiserbara": "otypiserbar",
    "otypiserbarare": "otypiserbar",
    "otypiserbarares": "otypiserbar",
    "otypiserbaras": "otypiserbar",
    "otypiserbarast": "otypiserbar",
    "otypiserbaraste": "otypiserbar",
    "otypiserbarastes": "otypiserbar",
    "otypiserbarasts": "otypiserbar",
    "otypiserbare": "otypiserbar",
    "otypiserbares": "otypiserbar",
    "otypiserbarheten": "otypiserbarhet",
    "otypiserbarhetens": "otypiserbarhet",
    "otypiserbarhets": "otypiserbarhet",
    "otypiserbars": "otypiserbar",
    "otypiserbart": "otypiserbar",
    "otypiserbarts": "otypiserbar",
    "otypiska": "otypisk",
    "otypiskare": "otypisk",
    "otypiskares": "otypisk",
    "otypiskas": "otypisk",
    "otypiskast": "otypisk",
    "otypiskaste": "otypisk",
    "otypiskastes": "otypisk",
    "otypiskasts": "otypisk",
    "otypiske": "otypisk",
    "otypiskes": "otypisk",
    "otypisks": "otypisk",
    "otypiskt": "otypisk",
    "otypiskts": "otypisk",
    "otyranniserade": "otyranniserad",
    "otyranniserades": "otyranniserad",
    "otyranniserads": "otyranniserad",
    "otyranniserat": "otyranniserad",
    "otyranniserats": "otyranniserad",
    "otyranniserbara": "otyranniserbar",
    "otyranniserbarare": "otyranniserbar",
    "otyranniserbarares": "otyranniserbar",
    "otyranniserbaras": "otyranniserbar",
    "otyranniserbarast": "otyranniserbar",
    "otyranniserbaraste": "otyranniserbar",
    "otyranniserbarastes": "otyranniserbar",
    "otyranniserbarasts": "otyranniserbar",
    "otyranniserbare": "otyranniserbar",
    "otyranniserbares": "otyranniserbar",
    "otyranniserbarheten": "otyranniserbarhet",
    "otyranniserbarhetens": "otyranniserbarhet",
    "otyranniserbarhets": "otyranniserbarhet",
    "otyranniserbars": "otyranniserbar",
    "otyranniserbart": "otyranniserbar",
    "otyranniserbarts": "otyranniserbar",
    "otäck": "otäcka",
    "otäcka": "otäck",
    "otäckan": "otäcka",
    "otäckans": "otäcka",
    "otäckare": "otäck",
    "otäckares": "otäck",
    "otäckas": "otäcka",
    "otäckast": "otäck",
    "otäckaste": "otäck",
    "otäckastes": "otäck",
    "otäckasts": "otäck",
    "otäcke": "otäcka",
    "otäckes": "otäck",
    "otäckheten": "otäckhet",
    "otäckhetens": "otäckhet",
    "otäckheter": "otäckhet",
    "otäckheterna": "otäckhet",
    "otäckheternas": "otäckhet",
    "otäckheters": "otäckhet",
    "otäckhets": "otäckhet",
    "otäckingar": "otäcking",
    "otäckingarna": "otäcking",
    "otäckingarnas": "otäcking",
    "otäckingars": "otäcking",
    "otäckingen": "otäcking",
    "otäckingens": "otäcking",
    "otäckings": "otäcking",
    "otäckor": "otäcka",
    "otäckorna": "otäcka",
    "otäckornas": "otäcka",
    "otäckors": "otäcka",
    "otäcks": "otäcka",
    "otäckt": "otäck",
    "otäckts": "otäck",
    "otämda": "otämd",
    "otämdare": "otämd",
    "otämdares": "otämd",
    "otämdas": "otämd",
    "otämdast": "otämd",
    "otämdaste": "otämd",
    "otämdastes": "otämd",
    "otämdasts": "otämd",
    "otämde": "otämd",
    "otämdes": "otämd",
    "otämds": "otämd",
    "otämjbara": "otämjbar",
    "otämjbarare": "otämjbar",
    "otämjbarares": "otämjbar",
    "otämjbaras": "otämjbar",
    "otämjbarast": "otämjbar",
    "otämjbaraste": "otämjbar",
    "otämjbarastes": "otämjbar",
    "otämjbarasts": "otämjbar",
    "otämjbare": "otämjbar",
    "otämjbares": "otämjbar",
    "otämjbarheten": "otämjbarhet",
    "otämjbarhetens": "otämjbarhet",
    "otämjbarhets": "otämjbarhet",
    "otämjbars": "otämjbar",
    "otämjbart": "otämjbar",
    "otämjbarts": "otämjbar",
    "otämjda": "otämjd",
    "otämjdare": "otämjd",
    "otämjdares": "otämjd",
    "otämjdas": "otämjd",
    "otämjdast": "otämjd",
    "otämjdaste": "otämjd",
    "otämjdastes": "otämjd",
    "otämjdasts": "otämjd",
    "otämjde": "otämjd",
    "otämjdes": "otämjd",
    "otämjds": "otämjd",
    "otämjt": "otämjd",
    "otämjts": "otämjd",
    "otämt": "otämd",
    "otämts": "otämd",
    "otända": "otänd",
    "otändare": "otänd",
    "otändares": "otänd",
    "otändas": "otänd",
    "otändast": "otänd",
    "otändaste": "otänd",
    "otändastes": "otänd",
    "otändasts": "otänd",
    "otände": "otänd",
    "otändes": "otänd",
    "otänds": "otänd",
    "otänkbara": "otänkbar",
    "otänkbarare": "otänkbar",
    "otänkbarares": "otänkbar",
    "otänkbaras": "otänkbar",
    "otänkbarast": "otänkbar",
    "otänkbaraste": "otänkbar",
    "otänkbarastes": "otänkbar",
    "otänkbarasts": "otänkbar",
    "otänkbare": "otänkbar",
    "otänkbares": "otänkbar",
    "otänkbarheten": "otänkbarhet",
    "otänkbarhetens": "otänkbarhet",
    "otänkbarhets": "otänkbarhet",
    "otänkbars": "otänkbar",
    "otänkbart": "otänkbar",
    "otänkbarts": "otänkbar",
    "otänt": "otänd",
    "otänts": "otänd",
    "otäta": "otät",
    "otätare": "otät",
    "otätares": "otät",
    "otätas": "otät",
    "otätast": "otät",
    "otätaste": "otät",
    "otätastes": "otät",
    "otätasts": "otät",
    "otäte": "otät",
    "otätes": "otät",
    "otätheten": "otäthet",
    "otäthetens": "otäthet",
    "otätheter": "otäthet",
    "otätheterna": "otäthet",
    "otätheternas": "otäthet",
    "otätheters": "otäthet",
    "otäthets": "otäthet",
    "otäts": "otät",
    "otätt": "otät",
    "otätts": "otät",
    "otåliga": "otålig",
    "otåligare": "otålig",
    "otåligares": "otålig",
    "otåligas": "otålig",
    "otåligast": "otålig",
    "otåligaste": "otålig",
    "otåligastes": "otålig",
    "otåligasts": "otålig",
    "otålige": "otålig",
    "otåliges": "otålig",
    "otåligheten": "otålighet",
    "otålighetens": "otålighet",
    "otålighets": "otålighet",
    "otåligs": "otålig",
    "otåligt": "otålig",
    "otåligts": "otålig",
    "otörstiga": "otörstig",
    "otörstigare": "otörstig",
    "otörstigares": "otörstig",
    "otörstigas": "otörstig",
    "otörstigast": "otörstig",
    "otörstigaste": "otörstig",
    "otörstigastes": "otörstig",
    "otörstigasts": "otörstig",
    "otörstige": "otörstig",
    "otörstiges": "otörstig",
    "otörstigheten": "otörstighet",
    "otörstighetens": "otörstighet",
    "otörstighets": "otörstighet",
    "otörstigs": "otörstig",
    "otörstigt": "otörstig",
    "otörstigts": "otörstig",
    "oumbärliga": "oumbärlig",
    "oumbärligare": "oumbärlig",
    "oumbärligares": "oumbärlig",
    "oumbärligas": "oumbärlig",
    "oumbärligast": "oumbärlig",
    "oumbärligaste": "oumbärlig",
    "oumbärligastes": "oumbärlig",
    "oumbärligasts": "oumbärlig",
    "oumbärlige": "oumbärlig",
    "oumbärliges": "oumbärlig",
    "oumbärligheten": "oumbärlighet",
    "oumbärlighetens": "oumbärlighet",
    "oumbärlighets": "oumbärlighet",
    "oumbärligs": "oumbärlig",
    "oumbärligt": "oumbärlig",
    "oumbärligts": "oumbärlig",
    "ounderbalanserbara": "ounderbalanserbar",
    "ounderbalanserbarare": "ounderbalanserbar",
    "ounderbalanserbarares": "ounderbalanserbar",
    "ounderbalanserbaras": "ounderbalanserbar",
    "ounderbalanserbarast": "ounderbalanserbar",
    "ounderbalanserbaraste": "ounderbalanserbar",
    "ounderbalanserbarastes": "ounderbalanserbar",
    "ounderbalanserbarasts": "ounderbalanserbar",
    "ounderbalanserbare": "ounderbalanserbar",
    "ounderbalanserbares": "ounderbalanserbar",
    "ounderbalanserbarheten": "ounderbalanserbarhet",
    "ounderbalanserbarhetens": "ounderbalanserbarhet",
    "ounderbalanserbarhets": "ounderbalanserbarhet",
    "ounderbalanserbars": "ounderbalanserbar",
    "ounderbalanserbart": "ounderbalanserbar",
    "ounderbalanserbarts": "ounderbalanserbar",
    "ounderdimensionerbara": "ounderdimensionerbar",
    "ounderdimensionerbarare": "ounderdimensionerbar",
    "ounderdimensionerbarares": "ounderdimensionerbar",
    "ounderdimensionerbaras": "ounderdimensionerbar",
    "ounderdimensionerbarast": "ounderdimensionerbar",
    "ounderdimensionerbaraste": "ounderdimensionerbar",
    "ounderdimensionerbarastes": "ounderdimensionerbar",
    "ounderdimensionerbarasts": "ounderdimensionerbar",
    "ounderdimensionerbare": "ounderdimensionerbar",
    "ounderdimensionerbares": "ounderdimensionerbar",
    "ounderdimensionerbarheten": "ounderdimensionerbarhet",
    "ounderdimensionerbarhetens": "ounderdimensionerbarhet",
    "ounderdimensionerbarhets": "ounderdimensionerbarhet",
    "ounderdimensionerbars": "ounderdimensionerbar",
    "ounderdimensionerbart": "ounderdimensionerbar",
    "ounderdimensionerbarts": "ounderdimensionerbar",
    "ounderexponerbara": "ounderexponerbar",
    "ounderexponerbarare": "ounderexponerbar",
    "ounderexponerbarares": "ounderexponerbar",
    "ounderexponerbaras": "ounderexponerbar",
    "ounderexponerbarast": "ounderexponerbar",
    "ounderexponerbaraste": "ounderexponerbar",
    "ounderexponerbarastes": "ounderexponerbar",
    "ounderexponerbarasts": "ounderexponerbar",
    "ounderexponerbare": "ounderexponerbar",
    "ounderexponerbares": "ounderexponerbar",
    "ounderexponerbarheten": "ounderexponerbarhet",
    "ounderexponerbarhetens": "ounderexponerbarhet",
    "ounderexponerbarhets": "ounderexponerbarhet",
    "ounderexponerbars": "ounderexponerbar",
    "ounderexponerbart": "ounderexponerbar",
    "ounderexponerbarts": "ounderexponerbar",
    "ounderminerbara": "ounderminerbar",
    "ounderminerbarare": "ounderminerbar",
    "ounderminerbarares": "ounderminerbar",
    "ounderminerbaras": "ounderminerbar",
    "ounderminerbarast": "ounderminerbar",
    "ounderminerbaraste": "ounderminerbar",
    "ounderminerbarastes": "ounderminerbar",
    "ounderminerbarasts": "ounderminerbar",
    "ounderminerbare": "ounderminerbar",
    "ounderminerbares": "ounderminerbar",
    "ounderminerbarheten": "ounderminerbarhet",
    "ounderminerbarhetens": "ounderminerbarhet",
    "ounderminerbarhets": "ounderminerbarhet",
    "ounderminerbars": "ounderminerbar",
    "ounderminerbart": "ounderminerbar",
    "ounderminerbarts": "ounderminerbar",
    "oundertaxerbara": "oundertaxerbar",
    "oundertaxerbarare": "oundertaxerbar",
    "oundertaxerbarares": "oundertaxerbar",
    "oundertaxerbaras": "oundertaxerbar",
    "oundertaxerbarast": "oundertaxerbar",
    "oundertaxerbaraste": "oundertaxerbar",
    "oundertaxerbarastes": "oundertaxerbar",
    "oundertaxerbarasts": "oundertaxerbar",
    "oundertaxerbare": "oundertaxerbar",
    "oundertaxerbares": "oundertaxerbar",
    "oundertaxerbarheten": "oundertaxerbarhet",
    "oundertaxerbarhetens": "oundertaxerbarhet",
    "oundertaxerbarhets": "oundertaxerbarhet",
    "oundertaxerbars": "oundertaxerbar",
    "oundertaxerbart": "oundertaxerbar",
    "oundertaxerbarts": "oundertaxerbar",
    "oundervärderbara": "oundervärderbar",
    "oundervärderbarare": "oundervärderbar",
    "oundervärderbarares": "oundervärderbar",
    "oundervärderbaras": "oundervärderbar",
    "oundervärderbarast": "oundervärderbar",
    "oundervärderbaraste": "oundervärderbar",
    "oundervärderbarastes": "oundervärderbar",
    "oundervärderbarasts": "oundervärderbar",
    "oundervärderbare": "oundervärderbar",
    "oundervärderbares": "oundervärderbar",
    "oundervärderbarheten": "oundervärderbarhet",
    "oundervärderbarhetens": "oundervärderbarhet",
    "oundervärderbarhets": "oundervärderbarhet",
    "oundervärderbars": "oundervärderbar",
    "oundervärderbart": "oundervärderbar",
    "oundervärderbarts": "oundervärderbar",
    "oundgängliga": "oundgänglig",
    "oundgängligare": "oundgänglig",
    "oundgängligares": "oundgänglig",
    "oundgängligas": "oundgänglig",
    "oundgängligast": "oundgänglig",
    "oundgängligaste": "oundgänglig",
    "oundgängligastes": "oundgänglig",
    "oundgängligasts": "oundgänglig",
    "oundgänglige": "oundgänglig",
    "oundgängliges": "oundgänglig",
    "oundgängligheten": "oundgänglighet",
    "oundgänglighetens": "oundgänglighet",
    "oundgänglighets": "oundgänglighet",
    "oundgängligs": "oundgänglig",
    "oundgängligt": "oundgänglig",
    "oundgängligts": "oundgänglig",
    "oundvikliga": "oundviklig",
    "oundvikligare": "oundviklig",
    "oundvikligares": "oundviklig",
    "oundvikligas": "oundviklig",
    "oundvikligast": "oundviklig",
    "oundvikligaste": "oundviklig",
    "oundvikligastes": "oundviklig",
    "oundvikligasts": "oundviklig",
    "oundviklige": "oundviklig",
    "oundvikliges": "oundviklig",
    "oundvikligheten": "oundviklighet",
    "oundviklighetens": "oundviklighet",
    "oundviklighets": "oundviklighet",
    "oundvikligs": "oundviklig",
    "oundvikligt": "oundviklig",
    "oundvikligts": "oundviklig",
    "ounifierade": "ounifierad",
    "ounifierades": "ounifierad",
    "ounifierads": "ounifierad",
    "ounifierat": "ounifierad",
    "ounifierats": "ounifierad",
    "ounifierbara": "ounifierbar",
    "ounifierbarare": "ounifierbar",
    "ounifierbarares": "ounifierbar",
    "ounifierbaras": "ounifierbar",
    "ounifierbarast": "ounifierbar",
    "ounifierbaraste": "ounifierbar",
    "ounifierbarastes": "ounifierbar",
    "ounifierbarasts": "ounifierbar",
    "ounifierbare": "ounifierbar",
    "ounifierbares": "ounifierbar",
    "ounifierbarheten": "ounifierbarhet",
    "ounifierbarhetens": "ounifierbarhet",
    "ounifierbarhets": "ounifierbarhet",
    "ounifierbars": "ounifierbar",
    "ounifierbart": "ounifierbar",
    "ounifierbarts": "ounifierbar",
    "ouniformerade": "ouniformerad",
    "ouniformerades": "ouniformerad",
    "ouniformerads": "ouniformerad",
    "ouniformerat": "ouniformerad",
    "ouniformerats": "ouniformerad",
    "ouniformerbara": "ouniformerbar",
    "ouniformerbarare": "ouniformerbar",
    "ouniformerbarares": "ouniformerbar",
    "ouniformerbaras": "ouniformerbar",
    "ouniformerbarast": "ouniformerbar",
    "ouniformerbaraste": "ouniformerbar",
    "ouniformerbarastes": "ouniformerbar",
    "ouniformerbarasts": "ouniformerbar",
    "ouniformerbare": "ouniformerbar",
    "ouniformerbares": "ouniformerbar",
    "ouniformerbarheten": "ouniformerbarhet",
    "ouniformerbarhetens": "ouniformerbarhet",
    "ouniformerbarhets": "ouniformerbarhet",
    "ouniformerbars": "ouniformerbar",
    "ouniformerbart": "ouniformerbar",
    "ouniformerbarts": "ouniformerbar",
    "ouppackade": "ouppackad",
    "ouppackades": "ouppackad",
    "ouppackads": "ouppackad",
    "ouppackat": "ouppackad",
    "ouppackats": "ouppackad",
    "ouppdaterade": "ouppdaterad",
    "ouppdaterades": "ouppdaterad",
    "ouppdaterads": "ouppdaterad",
    "ouppdaterat": "ouppdaterad",
    "ouppdaterats": "ouppdaterad",
    "ouppdaterbara": "ouppdaterbar",
    "ouppdaterbarare": "ouppdaterbar",
    "ouppdaterbarares": "ouppdaterbar",
    "ouppdaterbaras": "ouppdaterbar",
    "ouppdaterbarast": "ouppdaterbar",
    "ouppdaterbaraste": "ouppdaterbar",
    "ouppdaterbarastes": "ouppdaterbar",
    "ouppdaterbarasts": "ouppdaterbar",
    "ouppdaterbare": "ouppdaterbar",
    "ouppdaterbares": "ouppdaterbar",
    "ouppdaterbarheten": "ouppdaterbarhet",
    "ouppdaterbarhetens": "ouppdaterbarhet",
    "ouppdaterbarhets": "ouppdaterbarhet",
    "ouppdaterbars": "ouppdaterbar",
    "ouppdaterbart": "ouppdaterbar",
    "ouppdaterbarts": "ouppdaterbar",
    "ouppfattbara": "ouppfattbar",
    "ouppfattbarare": "ouppfattbar",
    "ouppfattbarares": "ouppfattbar",
    "ouppfattbaras": "ouppfattbar",
    "ouppfattbarast": "ouppfattbar",
    "ouppfattbaraste": "ouppfattbar",
    "ouppfattbarastes": "ouppfattbar",
    "ouppfattbarasts": "ouppfattbar",
    "ouppfattbare": "ouppfattbar",
    "ouppfattbares": "ouppfattbar",
    "ouppfattbarheten": "ouppfattbarhet",
    "ouppfattbarhetens": "ouppfattbarhet",
    "ouppfattbarhets": "ouppfattbarhet",
    "ouppfattbars": "ouppfattbar",
    "ouppfattbart": "ouppfattbar",
    "ouppfattbarts": "ouppfattbar",
    "ouppfostrade": "ouppfostrad",
    "ouppfostrades": "ouppfostrad",
    "ouppfostrads": "ouppfostrad",
    "ouppfostrat": "ouppfostrad",
    "ouppfostrats": "ouppfostrad",
    "ouppfyllda": "ouppfylld",
    "ouppfylldare": "ouppfylld",
    "ouppfylldares": "ouppfylld",
    "ouppfylldas": "ouppfylld",
    "ouppfylldast": "ouppfylld",
    "ouppfylldaste": "ouppfylld",
    "ouppfylldastes": "ouppfylld",
    "ouppfylldasts": "ouppfylld",
    "ouppfyllde": "ouppfylld",
    "ouppfylldes": "ouppfylld",
    "ouppfyllds": "ouppfylld",
    "ouppfyllt": "ouppfylld",
    "ouppfyllts": "ouppfylld",
    "ouppgjorda": "ouppgjord",
    "ouppgjordare": "ouppgjord",
    "ouppgjordares": "ouppgjord",
    "ouppgjordas": "ouppgjord",
    "ouppgjordast": "ouppgjord",
    "ouppgjordaste": "ouppgjord",
    "ouppgjordastes": "ouppgjord",
    "ouppgjordasts": "ouppgjord",
    "ouppgjorde": "ouppgjord",
    "ouppgjordes": "ouppgjord",
    "ouppgjords": "ouppgjord",
    "ouppgjort": "ouppgjord",
    "ouppgjorts": "ouppgjord",
    "ouppgraderade": "ouppgraderad",
    "ouppgraderades": "ouppgraderad",
    "ouppgraderads": "ouppgraderad",
    "ouppgraderat": "ouppgraderad",
    "ouppgraderats": "ouppgraderad",
    "ouppgraderbara": "ouppgraderbar",
    "ouppgraderbarare": "ouppgraderbar",
    "ouppgraderbarares": "ouppgraderbar",
    "ouppgraderbaras": "ouppgraderbar",
    "ouppgraderbarast": "ouppgraderbar",
    "ouppgraderbaraste": "ouppgraderbar",
    "ouppgraderbarastes": "ouppgraderbar",
    "ouppgraderbarasts": "ouppgraderbar",
    "ouppgraderbare": "ouppgraderbar",
    "ouppgraderbares": "ouppgraderbar",
    "ouppgraderbarheten": "ouppgraderbarhet",
    "ouppgraderbarhetens": "ouppgraderbarhet",
    "ouppgraderbarhets": "ouppgraderbarhet",
    "ouppgraderbars": "ouppgraderbar",
    "ouppgraderbart": "ouppgraderbar",
    "ouppgraderbarts": "ouppgraderbar",
    "oupphinneliga": "oupphinnelig",
    "oupphinneligare": "oupphinnelig",
    "oupphinneligares": "oupphinnelig",
    "oupphinneligas": "oupphinnelig",
    "oupphinneligast": "oupphinnelig",
    "oupphinneligaste": "oupphinnelig",
    "oupphinneligastes": "oupphinnelig",
    "oupphinneligasts": "oupphinnelig",
    "oupphinnelige": "oupphinnelig",
    "oupphinneliges": "oupphinnelig",
    "oupphinneligheten": "oupphinnelighet",
    "oupphinnelighetens": "oupphinnelighet",
    "oupphinnelighets": "oupphinnelighet",
    "oupphinneligs": "oupphinnelig",
    "oupphinneligt": "oupphinnelig",
    "oupphinneligts": "oupphinnelig",
    "oupphörliga": "oupphörlig",
    "oupphörligare": "oupphörlig",
    "oupphörligares": "oupphörlig",
    "oupphörligas": "oupphörlig",
    "oupphörligast": "oupphörlig",
    "oupphörligaste": "oupphörlig",
    "oupphörligastes": "oupphörlig",
    "oupphörligasts": "oupphörlig",
    "oupphörlige": "oupphörlig",
    "oupphörliges": "oupphörlig",
    "oupphörligheten": "oupphörlighet",
    "oupphörlighetens": "oupphörlighet",
    "oupphörlighets": "oupphörlighet",
    "oupphörligs": "oupphörlig",
    "oupphörligt": "oupphörlig",
    "oupphörligts": "oupphörlig",
    "ouppjusterade": "ouppjusterad",
    "ouppjusterades": "ouppjusterad",
    "ouppjusterads": "ouppjusterad",
    "ouppjusterat": "ouppjusterad",
    "ouppjusterats": "ouppjusterad",
    "ouppjusterbara": "ouppjusterbar",
    "ouppjusterbarare": "ouppjusterbar",
    "ouppjusterbarares": "ouppjusterbar",
    "ouppjusterbaras": "ouppjusterbar",
    "ouppjusterbarast": "ouppjusterbar",
    "ouppjusterbaraste": "ouppjusterbar",
    "ouppjusterbarastes": "ouppjusterbar",
    "ouppjusterbarasts": "ouppjusterbar",
    "ouppjusterbare": "ouppjusterbar",
    "ouppjusterbares": "ouppjusterbar",
    "ouppjusterbarheten": "ouppjusterbarhet",
    "ouppjusterbarhetens": "ouppjusterbarhet",
    "ouppjusterbarhets": "ouppjusterbarhet",
    "ouppjusterbars": "ouppjusterbar",
    "ouppjusterbart": "ouppjusterbar",
    "ouppjusterbarts": "ouppjusterbar",
    "ouppklarade": "ouppklarad",
    "ouppklarades": "ouppklarad",
    "ouppklarads": "ouppklarad",
    "ouppklarat": "ouppklarad",
    "ouppklarats": "ouppklarad",
    "oupplysta": "oupplyst",
    "oupplystare": "oupplyst",
    "oupplystares": "oupplyst",
    "oupplystas": "oupplyst",
    "oupplystast": "oupplyst",
    "oupplystaste": "oupplyst",
    "oupplystastes": "oupplyst",
    "oupplystasts": "oupplyst",
    "oupplyste": "oupplyst",
    "oupplystes": "oupplyst",
    "oupplystheten": "oupplysthet",
    "oupplysthetens": "oupplysthet",
    "oupplysthets": "oupplysthet",
    "oupplysts": "oupplyst",
    "oupplösliga": "oupplöslig",
    "oupplösligare": "oupplöslig",
    "oupplösligares": "oupplöslig",
    "oupplösligas": "oupplöslig",
    "oupplösligast": "oupplöslig",
    "oupplösligaste": "oupplöslig",
    "oupplösligastes": "oupplöslig",
    "oupplösligasts": "oupplöslig",
    "oupplöslige": "oupplöslig",
    "oupplösliges": "oupplöslig",
    "oupplösligheten": "oupplöslighet",
    "oupplöslighetens": "oupplöslighet",
    "oupplöslighets": "oupplöslighet",
    "oupplösligs": "oupplöslig",
    "oupplösligt": "oupplöslig",
    "oupplösligts": "oupplöslig",
    "ouppmärksamheten": "ouppmärksamhet",
    "ouppmärksamhetens": "ouppmärksamhet",
    "ouppmärksamhets": "ouppmärksamhet",
    "ouppmärksamma": "ouppmärksam",
    "ouppmärksammare": "ouppmärksam",
    "ouppmärksammares": "ouppmärksam",
    "ouppmärksammas": "ouppmärksam",
    "ouppmärksammast": "ouppmärksam",
    "ouppmärksammaste": "ouppmärksam",
    "ouppmärksammastes": "ouppmärksam",
    "ouppmärksammasts": "ouppmärksam",
    "ouppmärksamme": "ouppmärksam",
    "ouppmärksammes": "ouppmärksam",
    "ouppmärksams": "ouppmärksam",
    "ouppmärksamt": "ouppmärksam",
    "ouppmärksamts": "ouppmärksam",
    "ouppnåeliga": "ouppnåelig",
    "ouppnåeligare": "ouppnåelig",
    "ouppnåeligares": "ouppnåelig",
    "ouppnåeligas": "ouppnåelig",
    "ouppnåeligast": "ouppnåelig",
    "ouppnåeligaste": "ouppnåelig",
    "ouppnåeligastes": "ouppnåelig",
    "ouppnåeligasts": "ouppnåelig",
    "ouppnåelige": "ouppnåelig",
    "ouppnåeliges": "ouppnåelig",
    "ouppnåeligheten": "ouppnåelighet",
    "ouppnåelighetens": "ouppnåelighet",
    "ouppnåelighets": "ouppnåelighet",
    "ouppnåeligs": "ouppnåelig",
    "ouppnåeligt": "ouppnåelig",
    "ouppnåeligts": "ouppnåelig",
    "ouppreklamerade": "ouppreklamerad",
    "ouppreklamerades": "ouppreklamerad",
    "ouppreklamerads": "ouppreklamerad",
    "ouppreklamerat": "ouppreklamerad",
    "ouppreklamerats": "ouppreklamerad",
    "ouppreklamerbara": "ouppreklamerbar",
    "ouppreklamerbarare": "ouppreklamerbar",
    "ouppreklamerbarares": "ouppreklamerbar",
    "ouppreklamerbaras": "ouppreklamerbar",
    "ouppreklamerbarast": "ouppreklamerbar",
    "ouppreklamerbaraste": "ouppreklamerbar",
    "ouppreklamerbarastes": "ouppreklamerbar",
    "ouppreklamerbarasts": "ouppreklamerbar",
    "ouppreklamerbare": "ouppreklamerbar",
    "ouppreklamerbares": "ouppreklamerbar",
    "ouppreklamerbarheten": "ouppreklamerbarhet",
    "ouppreklamerbarhetens": "ouppreklamerbarhet",
    "ouppreklamerbarhets": "ouppreklamerbarhet",
    "ouppreklamerbars": "ouppreklamerbar",
    "ouppreklamerbart": "ouppreklamerbar",
    "ouppreklamerbarts": "ouppreklamerbar",
    "ouppskattbara": "ouppskattbar",
    "ouppskattbarare": "ouppskattbar",
    "ouppskattbarares": "ouppskattbar",
    "ouppskattbaras": "ouppskattbar",
    "ouppskattbarast": "ouppskattbar",
    "ouppskattbaraste": "ouppskattbar",
    "ouppskattbarastes": "ouppskattbar",
    "ouppskattbarasts": "ouppskattbar",
    "ouppskattbare": "ouppskattbar",
    "ouppskattbares": "ouppskattbar",
    "ouppskattbarheten": "ouppskattbarhet",
    "ouppskattbarhetens": "ouppskattbarhet",
    "ouppskattbarhets": "ouppskattbarhet",
    "ouppskattbars": "ouppskattbar",
    "ouppskattbart": "ouppskattbar",
    "ouppskattbarts": "ouppskattbar",
    "ouppskurens": "ouppskuren",
    "ouppskuret": "ouppskuren",
    "ouppskurets": "ouppskuren",
    "ouppskurna": "ouppskuren",
    "ouppskurnare": "ouppskuren",
    "ouppskurnares": "ouppskuren",
    "ouppskurnas": "ouppskuren",
    "ouppskurnast": "ouppskuren",
    "ouppskurnaste": "ouppskuren",
    "ouppskurnastes": "ouppskuren",
    "ouppskurnasts": "ouppskuren",
    "ouppskurne": "ouppskuren",
    "ouppskurnes": "ouppskuren",
    "ouppsummerade": "ouppsummerad",
    "ouppsummerades": "ouppsummerad",
    "ouppsummerads": "ouppsummerad",
    "ouppsummerat": "ouppsummerad",
    "ouppsummerats": "ouppsummerad",
    "ouppsummerbara": "ouppsummerbar",
    "ouppsummerbarare": "ouppsummerbar",
    "ouppsummerbarares": "ouppsummerbar",
    "ouppsummerbaras": "ouppsummerbar",
    "ouppsummerbarast": "ouppsummerbar",
    "ouppsummerbaraste": "ouppsummerbar",
    "ouppsummerbarastes": "ouppsummerbar",
    "ouppsummerbarasts": "ouppsummerbar",
    "ouppsummerbare": "ouppsummerbar",
    "ouppsummerbares": "ouppsummerbar",
    "ouppsummerbarheten": "ouppsummerbarhet",
    "ouppsummerbarhetens": "ouppsummerbarhet",
    "ouppsummerbarhets": "ouppsummerbarhet",
    "ouppsummerbars": "ouppsummerbar",
    "ouppsummerbart": "ouppsummerbar",
    "ouppsummerbarts": "ouppsummerbar",
    "ouppsägbara": "ouppsägbar",
    "ouppsägbarare": "ouppsägbar",
    "ouppsägbarares": "ouppsägbar",
    "ouppsägbaras": "ouppsägbar",
    "ouppsägbarast": "ouppsägbar",
    "ouppsägbaraste": "ouppsägbar",
    "ouppsägbarastes": "ouppsägbar",
    "ouppsägbarasts": "ouppsägbar",
    "ouppsägbare": "ouppsägbar",
    "ouppsägbares": "ouppsägbar",
    "ouppsägbarheten": "ouppsägbarhet",
    "ouppsägbarhetens": "ouppsägbarhet",
    "ouppsägbarhets": "ouppsägbarhet",
    "ouppsägbars": "ouppsägbar",
    "ouppsägbart": "ouppsägbar",
    "ouppsägbarts": "ouppsägbar",
    "ouppsåtliga": "ouppsåtlig",
    "ouppsåtligare": "ouppsåtlig",
    "ouppsåtligares": "ouppsåtlig",
    "ouppsåtligas": "ouppsåtlig",
    "ouppsåtligast": "ouppsåtlig",
    "ouppsåtligaste": "ouppsåtlig",
    "ouppsåtligastes": "ouppsåtlig",
    "ouppsåtligasts": "ouppsåtlig",
    "ouppsåtlige": "ouppsåtlig",
    "ouppsåtliges": "ouppsåtlig",
    "ouppsåtligheten": "ouppsåtlighet",
    "ouppsåtlighetens": "ouppsåtlighet",
    "ouppsåtlighets": "ouppsåtlighet",
    "ouppsåtligs": "ouppsåtlig",
    "ouppsåtligt": "ouppsåtlig",
    "ouppsåtligts": "ouppsåtlig",
    "oupptaxerade": "oupptaxerad",
    "oupptaxerades": "oupptaxerad",
    "oupptaxerads": "oupptaxerad",
    "oupptaxerat": "oupptaxerad",
    "oupptaxerats": "oupptaxerad",
    "oupptaxerbara": "oupptaxerbar",
    "oupptaxerbarare": "oupptaxerbar",
    "oupptaxerbarares": "oupptaxerbar",
    "oupptaxerbaras": "oupptaxerbar",
    "oupptaxerbarast": "oupptaxerbar",
    "oupptaxerbaraste": "oupptaxerbar",
    "oupptaxerbarastes": "oupptaxerbar",
    "oupptaxerbarasts": "oupptaxerbar",
    "oupptaxerbare": "oupptaxerbar",
    "oupptaxerbares": "oupptaxerbar",
    "oupptaxerbarheten": "oupptaxerbarhet",
    "oupptaxerbarhetens": "oupptaxerbarhet",
    "oupptaxerbarhets": "oupptaxerbarhet",
    "oupptaxerbars": "oupptaxerbar",
    "oupptaxerbart": "oupptaxerbar",
    "oupptaxerbarts": "oupptaxerbar",
    "oupptäckta": "oupptäckt",
    "oupptäcktare": "oupptäckt",
    "oupptäcktares": "oupptäckt",
    "oupptäcktas": "oupptäckt",
    "oupptäcktast": "oupptäckt",
    "oupptäcktaste": "oupptäckt",
    "oupptäcktastes": "oupptäckt",
    "oupptäcktasts": "oupptäckt",
    "oupptäckte": "oupptäckt",
    "oupptäcktes": "oupptäckt",
    "oupptäckts": "oupptäckt",
    "ouppvärderade": "ouppvärderad",
    "ouppvärderades": "ouppvärderad",
    "ouppvärderads": "ouppvärderad",
    "ouppvärderat": "ouppvärderad",
    "ouppvärderats": "ouppvärderad",
    "ouppvärderbara": "ouppvärderbar",
    "ouppvärderbarare": "ouppvärderbar",
    "ouppvärderbarares": "ouppvärderbar",
    "ouppvärderbaras": "ouppvärderbar",
    "ouppvärderbarast": "ouppvärderbar",
    "ouppvärderbaraste": "ouppvärderbar",
    "ouppvärderbarastes": "ouppvärderbar",
    "ouppvärderbarasts": "ouppvärderbar",
    "ouppvärderbare": "ouppvärderbar",
    "ouppvärderbares": "ouppvärderbar",
    "ouppvärderbarheten": "ouppvärderbarhet",
    "ouppvärderbarhetens": "ouppvärderbarhet",
    "ouppvärderbarhets": "ouppvärderbarhet",
    "ouppvärderbars": "ouppvärderbar",
    "ouppvärderbart": "ouppvärderbar",
    "ouppvärderbarts": "ouppvärderbar",
    "ouppvärmda": "ouppvärmd",
    "ouppvärmdare": "ouppvärmd",
    "ouppvärmdares": "ouppvärmd",
    "ouppvärmdas": "ouppvärmd",
    "ouppvärmdast": "ouppvärmd",
    "ouppvärmdaste": "ouppvärmd",
    "ouppvärmdastes": "ouppvärmd",
    "ouppvärmdasts": "ouppvärmd",
    "ouppvärmde": "ouppvärmd",
    "ouppvärmdes": "ouppvärmd",
    "ouppvärmds": "ouppvärmd",
    "ouppvärmt": "ouppvärmd",
    "ouppvärmts": "ouppvärmd",
    "ouppövade": "ouppövad",
    "ouppövades": "ouppövad",
    "ouppövads": "ouppövad",
    "ouppövat": "ouppövad",
    "ouppövats": "ouppövad",
    "ourbaniserade": "ourbaniserad",
    "ourbaniserades": "ourbaniserad",
    "ourbaniserads": "ourbaniserad",
    "ourbaniserat": "ourbaniserad",
    "ourbaniserats": "ourbaniserad",
    "ourbaniserbara": "ourbaniserbar",
    "ourbaniserbarare": "ourbaniserbar",
    "ourbaniserbarares": "ourbaniserbar",
    "ourbaniserbaras": "ourbaniserbar",
    "ourbaniserbarast": "ourbaniserbar",
    "ourbaniserbaraste": "ourbaniserbar",
    "ourbaniserbarastes": "ourbaniserbar",
    "ourbaniserbarasts": "ourbaniserbar",
    "ourbaniserbare": "ourbaniserbar",
    "ourbaniserbares": "ourbaniserbar",
    "ourbaniserbarheten": "ourbaniserbarhet",
    "ourbaniserbarhetens": "ourbaniserbarhet",
    "ourbaniserbarhets": "ourbaniserbarhet",
    "ourbaniserbars": "ourbaniserbar",
    "ourbaniserbart": "ourbaniserbar",
    "ourbaniserbarts": "ourbaniserbar",
    "oursäktliga": "oursäktlig",
    "oursäktligare": "oursäktlig",
    "oursäktligares": "oursäktlig",
    "oursäktligas": "oursäktlig",
    "oursäktligast": "oursäktlig",
    "oursäktligaste": "oursäktlig",
    "oursäktligastes": "oursäktlig",
    "oursäktligasts": "oursäktlig",
    "oursäktlige": "oursäktlig",
    "oursäktliges": "oursäktlig",
    "oursäktligheten": "oursäktlighet",
    "oursäktlighetens": "oursäktlighet",
    "oursäktlighets": "oursäktlighet",
    "oursäktligs": "oursäktlig",
    "oursäktligt": "oursäktlig",
    "oursäktligts": "oursäktlig",
    "ousurperade": "ousurperad",
    "ousurperades": "ousurperad",
    "ousurperads": "ousurperad",
    "ousurperat": "ousurperad",
    "ousurperats": "ousurperad",
    "ousurperbara": "ousurperbar",
    "ousurperbarare": "ousurperbar",
    "ousurperbarares": "ousurperbar",
    "ousurperbaras": "ousurperbar",
    "ousurperbarast": "ousurperbar",
    "ousurperbaraste": "ousurperbar",
    "ousurperbarastes": "ousurperbar",
    "ousurperbarasts": "ousurperbar",
    "ousurperbare": "ousurperbar",
    "ousurperbares": "ousurperbar",
    "ousurperbarheten": "ousurperbarhet",
    "ousurperbarhetens": "ousurperbarhet",
    "ousurperbarhets": "ousurperbarhet",
    "ousurperbars": "ousurperbar",
    "ousurperbart": "ousurperbar",
    "ousurperbarts": "ousurperbar",
    "outackorderade": "outackorderad",
    "outackorderades": "outackorderad",
    "outackorderads": "outackorderad",
    "outackorderat": "outackorderad",
    "outackorderats": "outackorderad",
    "outackorderbara": "outackorderbar",
    "outackorderbarare": "outackorderbar",
    "outackorderbarares": "outackorderbar",
    "outackorderbaras": "outackorderbar",
    "outackorderbarast": "outackorderbar",
    "outackorderbaraste": "outackorderbar",
    "outackorderbarastes": "outackorderbar",
    "outackorderbarasts": "outackorderbar",
    "outackorderbare": "outackorderbar",
    "outackorderbares": "outackorderbar",
    "outackorderbarheten": "outackorderbarhet",
    "outackorderbarhetens": "outackorderbarhet",
    "outackorderbarhets": "outackorderbarhet",
    "outackorderbars": "outackorderbar",
    "outackorderbart": "outackorderbar",
    "outackorderbarts": "outackorderbar",
    "outad": "outa",
    "outade": "outa",
    "outades": "outa",
    "outads": "outa",
    "outande": "outa",
    "outanden": "outande",
    "outandena": "outande",
    "outandenas": "outande",
    "outandens": "outande",
    "outandes": "outande",
    "outandet": "outande",
    "outandets": "outande",
    "outannonserade": "outannonserad",
    "outannonserades": "outannonserad",
    "outannonserads": "outannonserad",
    "outannonserat": "outannonserad",
    "outannonserats": "outannonserad",
    "outannonserbara": "outannonserbar",
    "outannonserbarare": "outannonserbar",
    "outannonserbarares": "outannonserbar",
    "outannonserbaras": "outannonserbar",
    "outannonserbarast": "outannonserbar",
    "outannonserbaraste": "outannonserbar",
    "outannonserbarastes": "outannonserbar",
    "outannonserbarasts": "outannonserbar",
    "outannonserbare": "outannonserbar",
    "outannonserbares": "outannonserbar",
    "outannonserbarheten": "outannonserbarhet",
    "outannonserbarhetens": "outannonserbarhet",
    "outannonserbarhets": "outannonserbarhet",
    "outannonserbars": "outannonserbar",
    "outannonserbart": "outannonserbar",
    "outannonserbarts": "outannonserbar",
    "outar": "outa",
    "outarrenderade": "outarrenderad",
    "outarrenderades": "outarrenderad",
    "outarrenderads": "outarrenderad",
    "outarrenderat": "outarrenderad",
    "outarrenderats": "outarrenderad",
    "outarrenderbara": "outarrenderbar",
    "outarrenderbarare": "outarrenderbar",
    "outarrenderbarares": "outarrenderbar",
    "outarrenderbaras": "outarrenderbar",
    "outarrenderbarast": "outarrenderbar",
    "outarrenderbaraste": "outarrenderbar",
    "outarrenderbarastes": "outarrenderbar",
    "outarrenderbarasts": "outarrenderbar",
    "outarrenderbare": "outarrenderbar",
    "outarrenderbares": "outarrenderbar",
    "outarrenderbarheten": "outarrenderbarhet",
    "outarrenderbarhetens": "outarrenderbarhet",
    "outarrenderbarhets": "outarrenderbarhet",
    "outarrenderbars": "outarrenderbar",
    "outarrenderbart": "outarrenderbar",
    "outarrenderbarts": "outarrenderbar",
    "outas": "outa",
    "outat": "outa",
    "outats": "outa",
    "outbalanserade": "outbalanserad",
    "outbalanserades": "outbalanserad",
    "outbalanserads": "outbalanserad",
    "outbalanserat": "outbalanserad",
    "outbalanserats": "outbalanserad",
    "outbalanserbara": "outbalanserbar",
    "outbalanserbarare": "outbalanserbar",
    "outbalanserbarares": "outbalanserbar",
    "outbalanserbaras": "outbalanserbar",
    "outbalanserbarast": "outbalanserbar",
    "outbalanserbaraste": "outbalanserbar",
    "outbalanserbarastes": "outbalanserbar",
    "outbalanserbarasts": "outbalanserbar",
    "outbalanserbare": "outbalanserbar",
    "outbalanserbares": "outbalanserbar",
    "outbalanserbarheten": "outbalanserbarhet",
    "outbalanserbarhetens": "outbalanserbarhet",
    "outbalanserbarhets": "outbalanserbarhet",
    "outbalanserbars": "outbalanserbar",
    "outbalanserbart": "outbalanserbar",
    "outbalanserbarts": "outbalanserbar",
    "outbasunerade": "outbasunerad",
    "outbasunerades": "outbasunerad",
    "outbasunerads": "outbasunerad",
    "outbasunerat": "outbasunerad",
    "outbasunerats": "outbasunerad",
    "outbasunerbara": "outbasunerbar",
    "outbasunerbarare": "outbasunerbar",
    "outbasunerbarares": "outbasunerbar",
    "outbasunerbaras": "outbasunerbar",
    "outbasunerbarast": "outbasunerbar",
    "outbasunerbaraste": "outbasunerbar",
    "outbasunerbarastes": "outbasunerbar",
    "outbasunerbarasts": "outbasunerbar",
    "outbasunerbare": "outbasunerbar",
    "outbasunerbares": "outbasunerbar",
    "outbasunerbarheten": "outbasunerbarhet",
    "outbasunerbarhetens": "outbasunerbarhet",
    "outbasunerbarhets": "outbasunerbarhet",
    "outbasunerbars": "outbasunerbar",
    "outbasunerbart": "outbasunerbar",
    "outbasunerbarts": "outbasunerbar",
    "outbildade": "outbildad",
    "outbildades": "outbildad",
    "outbildads": "outbildad",
    "outbildat": "outbildad",
    "outbildats": "outbildad",
    "outbroderade": "outbroderad",
    "outbroderades": "outbroderad",
    "outbroderads": "outbroderad",
    "outbroderat": "outbroderad",
    "outbroderats": "outbroderad",
    "outbroderbara": "outbroderbar",
    "outbroderbarare": "outbroderbar",
    "outbroderbarares": "outbroderbar",
    "outbroderbaras": "outbroderbar",
    "outbroderbarast": "outbroderbar",
    "outbroderbaraste": "outbroderbar",
    "outbroderbarastes": "outbroderbar",
    "outbroderbarasts": "outbroderbar",
    "outbroderbare": "outbroderbar",
    "outbroderbares": "outbroderbar",
    "outbroderbarheten": "outbroderbarhet",
    "outbroderbarhetens": "outbroderbarhet",
    "outbroderbarhets": "outbroderbarhet",
    "outbroderbars": "outbroderbar",
    "outbroderbart": "outbroderbar",
    "outbroderbarts": "outbroderbar",
    "outdebiterade": "outdebiterad",
    "outdebiterades": "outdebiterad",
    "outdebiterads": "outdebiterad",
    "outdebiterat": "outdebiterad",
    "outdebiterats": "outdebiterad",
    "outdebiterbara": "outdebiterbar",
    "outdebiterbarare": "outdebiterbar",
    "outdebiterbarares": "outdebiterbar",
    "outdebiterbaras": "outdebiterbar",
    "outdebiterbarast": "outdebiterbar",
    "outdebiterbaraste": "outdebiterbar",
    "outdebiterbarastes": "outdebiterbar",
    "outdebiterbarasts": "outdebiterbar",
    "outdebiterbare": "outdebiterbar",
    "outdebiterbares": "outdebiterbar",
    "outdebiterbarheten": "outdebiterbarhet",
    "outdebiterbarhetens": "outdebiterbarhet",
    "outdebiterbarhets": "outdebiterbarhet",
    "outdebiterbars": "outdebiterbar",
    "outdebiterbart": "outdebiterbar",
    "outdebiterbarts": "outdebiterbar",
    "outexaminerade": "outexaminerad",
    "outexaminerades": "outexaminerad",
    "outexaminerads": "outexaminerad",
    "outexaminerat": "outexaminerad",
    "outexaminerats": "outexaminerad",
    "outexaminerbara": "outexaminerbar",
    "outexaminerbarare": "outexaminerbar",
    "outexaminerbarares": "outexaminerbar",
    "outexaminerbaras": "outexaminerbar",
    "outexaminerbarast": "outexaminerbar",
    "outexaminerbaraste": "outexaminerbar",
    "outexaminerbarastes": "outexaminerbar",
    "outexaminerbarasts": "outexaminerbar",
    "outexaminerbare": "outexaminerbar",
    "outexaminerbares": "outexaminerbar",
    "outexaminerbarheten": "outexaminerbarhet",
    "outexaminerbarhetens": "outexaminerbarhet",
    "outexaminerbarhets": "outexaminerbarhet",
    "outexaminerbars": "outexaminerbar",
    "outexaminerbart": "outexaminerbar",
    "outexaminerbarts": "outexaminerbar",
    "outexperimenterade": "outexperimenterad",
    "outexperimenterades": "outexperimenterad",
    "outexperimenterads": "outexperimenterad",
    "outexperimenterat": "outexperimenterad",
    "outexperimenterats": "outexperimenterad",
    "outexperimenterbara": "outexperimenterbar",
    "outexperimenterbarare": "outexperimenterbar",
    "outexperimenterbarares": "outexperimenterbar",
    "outexperimenterbaras": "outexperimenterbar",
    "outexperimenterbarast": "outexperimenterbar",
    "outexperimenterbaraste": "outexperimenterbar",
    "outexperimenterbarastes": "outexperimenterbar",
    "outexperimenterbarasts": "outexperimenterbar",
    "outexperimenterbare": "outexperimenterbar",
    "outexperimenterbares": "outexperimenterbar",
    "outexperimenterbarheten": "outexperimenterbarhet",
    "outexperimenterbarhetens": "outexperimenterbarhet",
    "outexperimenterbarhets": "outexperimenterbarhet",
    "outexperimenterbars": "outexperimenterbar",
    "outexperimenterbart": "outexperimenterbar",
    "outexperimenterbarts": "outexperimenterbar",
    "outforskade": "outforskad",
    "outforskades": "outforskad",
    "outforskads": "outforskad",
    "outforskat": "outforskad",
    "outforskats": "outforskad",
    "outförbara": "outförbar",
    "outförbarare": "outförbar",
    "outförbarares": "outförbar",
    "outförbaras": "outförbar",
    "outförbarast": "outförbar",
    "outförbaraste": "outförbar",
    "outförbarastes": "outförbar",
    "outförbarasts": "outförbar",
    "outförbare": "outförbar",
    "outförbares": "outförbar",
    "outförbarheten": "outförbarhet",
    "outförbarhetens": "outförbarhet",
    "outförbarhets": "outförbarhet",
    "outförbars": "outförbar",
    "outförbart": "outförbar",
    "outförbarts": "outförbar",
    "outgivens": "outgiven",
    "outgivet": "outgiven",
    "outgivets": "outgiven",
    "outgivna": "outgiven",
    "outgivnare": "outgiven",
    "outgivnares": "outgiven",
    "outgivnas": "outgiven",
    "outgivnast": "outgiven",
    "outgivnaste": "outgiven",
    "outgivnastes": "outgiven",
    "outgivnasts": "outgiven",
    "outgivne": "outgiven",
    "outgivnes": "outgiven",
    "outgrundliga": "outgrundlig",
    "outgrundligare": "outgrundlig",
    "outgrundligares": "outgrundlig",
    "outgrundligas": "outgrundlig",
    "outgrundligast": "outgrundlig",
    "outgrundligaste": "outgrundlig",
    "outgrundligastes": "outgrundlig",
    "outgrundligasts": "outgrundlig",
    "outgrundlige": "outgrundlig",
    "outgrundliges": "outgrundlig",
    "outgrundligheten": "outgrundlighet",
    "outgrundlighetens": "outgrundlighet",
    "outgrundlighets": "outgrundlighet",
    "outgrundligs": "outgrundlig",
    "outgrundligt": "outgrundlig",
    "outgrundligts": "outgrundlig",
    "outhyrda": "outhyrd",
    "outhyrdare": "outhyrd",
    "outhyrdares": "outhyrd",
    "outhyrdas": "outhyrd",
    "outhyrdast": "outhyrd",
    "outhyrdaste": "outhyrd",
    "outhyrdastes": "outhyrd",
    "outhyrdasts": "outhyrd",
    "outhyrde": "outhyrd",
    "outhyrdes": "outhyrd",
    "outhyrds": "outhyrd",
    "outhyrt": "outhyrd",
    "outhyrts": "outhyrd",
    "outhärdliga": "outhärdlig",
    "outhärdligare": "outhärdlig",
    "outhärdligares": "outhärdlig",
    "outhärdligas": "outhärdlig",
    "outhärdligast": "outhärdlig",
    "outhärdligaste": "outhärdlig",
    "outhärdligastes": "outhärdlig",
    "outhärdligasts": "outhärdlig",
    "outhärdlige": "outhärdlig",
    "outhärdliges": "outhärdlig",
    "outhärdligheten": "outhärdlighet",
    "outhärdlighetens": "outhärdlighet",
    "outhärdlighets": "outhärdlighet",
    "outhärdligs": "outhärdlig",
    "outhärdligt": "outhärdlig",
    "outhärdligts": "outhärdlig",
    "outklarerade": "outklarerad",
    "outklarerades": "outklarerad",
    "outklarerads": "outklarerad",
    "outklarerat": "outklarerad",
    "outklarerats": "outklarerad",
    "outklarerbara": "outklarerbar",
    "outklarerbarare": "outklarerbar",
    "outklarerbarares": "outklarerbar",
    "outklarerbaras": "outklarerbar",
    "outklarerbarast": "outklarerbar",
    "outklarerbaraste": "outklarerbar",
    "outklarerbarastes": "outklarerbar",
    "outklarerbarasts": "outklarerbar",
    "outklarerbare": "outklarerbar",
    "outklarerbares": "outklarerbar",
    "outklarerbarheten": "outklarerbarhet",
    "outklarerbarhetens": "outklarerbarhet",
    "outklarerbarhets": "outklarerbarhet",
    "outklarerbars": "outklarerbar",
    "outklarerbart": "outklarerbar",
    "outklarerbarts": "outklarerbar",
    "outkommenderade": "outkommenderad",
    "outkommenderades": "outkommenderad",
    "outkommenderads": "outkommenderad",
    "outkommenderat": "outkommenderad",
    "outkommenderats": "outkommenderad",
    "outkommenderbara": "outkommenderbar",
    "outkommenderbarare": "outkommenderbar",
    "outkommenderbarares": "outkommenderbar",
    "outkommenderbaras": "outkommenderbar",
    "outkommenderbarast": "outkommenderbar",
    "outkommenderbaraste": "outkommenderbar",
    "outkommenderbarastes": "outkommenderbar",
    "outkommenderbarasts": "outkommenderbar",
    "outkommenderbare": "outkommenderbar",
    "outkommenderbares": "outkommenderbar",
    "outkommenderbarheten": "outkommenderbarhet",
    "outkommenderbarhetens": "outkommenderbarhet",
    "outkommenderbarhets": "outkommenderbarhet",
    "outkommenderbars": "outkommenderbar",
    "outkommenderbart": "outkommenderbar",
    "outkommenderbarts": "outkommenderbar",
    "outkonkurrerade": "outkonkurrerad",
    "outkonkurrerades": "outkonkurrerad",
    "outkonkurrerads": "outkonkurrerad",
    "outkonkurrerat": "outkonkurrerad",
    "outkonkurrerats": "outkonkurrerad",
    "outkonkurrerbara": "outkonkurrerbar",
    "outkonkurrerbarare": "outkonkurrerbar",
    "outkonkurrerbarares": "outkonkurrerbar",
    "outkonkurrerbaras": "outkonkurrerbar",
    "outkonkurrerbarast": "outkonkurrerbar",
    "outkonkurrerbaraste": "outkonkurrerbar",
    "outkonkurrerbarastes": "outkonkurrerbar",
    "outkonkurrerbarasts": "outkonkurrerbar",
    "outkonkurrerbare": "outkonkurrerbar",
    "outkonkurrerbares": "outkonkurrerbar",
    "outkonkurrerbarheten": "outkonkurrerbarhet",
    "outkonkurrerbarhetens": "outkonkurrerbarhet",
    "outkonkurrerbarhets": "outkonkurrerbarhet",
    "outkonkurrerbars": "outkonkurrerbar",
    "outkonkurrerbart": "outkonkurrerbar",
    "outkonkurrerbarts": "outkonkurrerbar",
    "outkristalliserade": "outkristalliserad",
    "outkristalliserades": "outkristalliserad",
    "outkristalliserads": "outkristalliserad",
    "outkristalliserat": "outkristalliserad",
    "outkristalliserats": "outkristalliserad",
    "outkristalliserbara": "outkristalliserbar",
    "outkristalliserbarare": "outkristalliserbar",
    "outkristalliserbarares": "outkristalliserbar",
    "outkristalliserbaras": "outkristalliserbar",
    "outkristalliserbarast": "outkristalliserbar",
    "outkristalliserbaraste": "outkristalliserbar",
    "outkristalliserbarastes": "outkristalliserbar",
    "outkristalliserbarasts": "outkristalliserbar",
    "outkristalliserbare": "outkristalliserbar",
    "outkristalliserbares": "outkristalliserbar",
    "outkristalliserbarheten": "outkristalliserbarhet",
    "outkristalliserbarhetens": "outkristalliserbarhet",
    "outkristalliserbarhets": "outkristalliserbarhet",
    "outkristalliserbars": "outkristalliserbar",
    "outkristalliserbart": "outkristalliserbar",
    "outkristalliserbarts": "outkristalliserbar",
    "outkvitterade": "outkvitterad",
    "outkvitterades": "outkvitterad",
    "outkvitterads": "outkvitterad",
    "outkvitterat": "outkvitterad",
    "outkvitterats": "outkvitterad",
    "outkvitterbara": "outkvitterbar",
    "outkvitterbarare": "outkvitterbar",
    "outkvitterbarares": "outkvitterbar",
    "outkvitterbaras": "outkvitterbar",
    "outkvitterbarast": "outkvitterbar",
    "outkvitterbaraste": "outkvitterbar",
    "outkvitterbarastes": "outkvitterbar",
    "outkvitterbarasts": "outkvitterbar",
    "outkvitterbare": "outkvitterbar",
    "outkvitterbares": "outkvitterbar",
    "outkvitterbarheten": "outkvitterbarhet",
    "outkvitterbarhetens": "outkvitterbarhet",
    "outkvitterbarhets": "outkvitterbarhet",
    "outkvitterbars": "outkvitterbar",
    "outkvitterbart": "outkvitterbar",
    "outkvitterbarts": "outkvitterbar",
    "outlokaliserade": "outlokaliserad",
    "outlokaliserades": "outlokaliserad",
    "outlokaliserads": "outlokaliserad",
    "outlokaliserat": "outlokaliserad",
    "outlokaliserats": "outlokaliserad",
    "outlokaliserbara": "outlokaliserbar",
    "outlokaliserbarare": "outlokaliserbar",
    "outlokaliserbarares": "outlokaliserbar",
    "outlokaliserbaras": "outlokaliserbar",
    "outlokaliserbarast": "outlokaliserbar",
    "outlokaliserbaraste": "outlokaliserbar",
    "outlokaliserbarastes": "outlokaliserbar",
    "outlokaliserbarasts": "outlokaliserbar",
    "outlokaliserbare": "outlokaliserbar",
    "outlokaliserbares": "outlokaliserbar",
    "outlokaliserbarheten": "outlokaliserbarhet",
    "outlokaliserbarhetens": "outlokaliserbarhet",
    "outlokaliserbarhets": "outlokaliserbarhet",
    "outlokaliserbars": "outlokaliserbar",
    "outlokaliserbart": "outlokaliserbar",
    "outlokaliserbarts": "outlokaliserbar",
    "outmanövrerade": "outmanövrerad",
    "outmanövrerades": "outmanövrerad",
    "outmanövrerads": "outmanövrerad",
    "outmanövrerat": "outmanövrerad",
    "outmanövrerats": "outmanövrerad",
    "outmanövrerbara": "outmanövrerbar",
    "outmanövrerbarare": "outmanövrerbar",
    "outmanövrerbarares": "outmanövrerbar",
    "outmanövrerbaras": "outmanövrerbar",
    "outmanövrerbarast": "outmanövrerbar",
    "outmanövrerbaraste": "outmanövrerbar",
    "outmanövrerbarastes": "outmanövrerbar",
    "outmanövrerbarasts": "outmanövrerbar",
    "outmanövrerbare": "outmanövrerbar",
    "outmanövrerbares": "outmanövrerbar",
    "outmanövrerbarheten": "outmanövrerbarhet",
    "outmanövrerbarhetens": "outmanövrerbarhet",
    "outmanövrerbarhets": "outmanövrerbarhet",
    "outmanövrerbars": "outmanövrerbar",
    "outmanövrerbart": "outmanövrerbar",
    "outmanövrerbarts": "outmanövrerbar",
    "outminuterade": "outminuterad",
    "outminuterades": "outminuterad",
    "outminuterads": "outminuterad",
    "outminuterat": "outminuterad",
    "outminuterats": "outminuterad",
    "outminuterbara": "outminuterbar",
    "outminuterbarare": "outminuterbar",
    "outminuterbarares": "outminuterbar",
    "outminuterbaras": "outminuterbar",
    "outminuterbarast": "outminuterbar",
    "outminuterbaraste": "outminuterbar",
    "outminuterbarastes": "outminuterbar",
    "outminuterbarasts": "outminuterbar",
    "outminuterbare": "outminuterbar",
    "outminuterbares": "outminuterbar",
    "outminuterbarheten": "outminuterbarhet",
    "outminuterbarhetens": "outminuterbarhet",
    "outminuterbarhets": "outminuterbarhet",
    "outminuterbars": "outminuterbar",
    "outminuterbart": "outminuterbar",
    "outminuterbarts": "outminuterbar",
    "outnyttjade": "outnyttjad",
    "outnyttjades": "outnyttjad",
    "outnyttjads": "outnyttjad",
    "outnyttjat": "outnyttjad",
    "outnyttjats": "outnyttjad",
    "outplacerade": "outplacerad",
    "outplacerades": "outplacerad",
    "outplacerads": "outplacerad",
    "outplacerat": "outplacerad",
    "outplacerats": "outplacerad",
    "outplacerbara": "outplacerbar",
    "outplacerbarare": "outplacerbar",
    "outplacerbarares": "outplacerbar",
    "outplacerbaras": "outplacerbar",
    "outplacerbarast": "outplacerbar",
    "outplacerbaraste": "outplacerbar",
    "outplacerbarastes": "outplacerbar",
    "outplacerbarasts": "outplacerbar",
    "outplacerbare": "outplacerbar",
    "outplacerbares": "outplacerbar",
    "outplacerbarheten": "outplacerbarhet",
    "outplacerbarhetens": "outplacerbarhet",
    "outplacerbarhets": "outplacerbarhet",
    "outplacerbars": "outplacerbar",
    "outplacerbart": "outplacerbar",
    "outplacerbarts": "outplacerbar",
    "outplånliga": "outplånlig",
    "outplånligare": "outplånlig",
    "outplånligares": "outplånlig",
    "outplånligas": "outplånlig",
    "outplånligast": "outplånlig",
    "outplånligaste": "outplånlig",
    "outplånligastes": "outplånlig",
    "outplånligasts": "outplånlig",
    "outplånlige": "outplånlig",
    "outplånliges": "outplånlig",
    "outplånligheten": "outplånlighet",
    "outplånlighetens": "outplånlighet",
    "outplånlighets": "outplånlighet",
    "outplånligs": "outplånlig",
    "outplånligt": "outplånlig",
    "outplånligts": "outplånlig",
    "outposterade": "outposterad",
    "outposterades": "outposterad",
    "outposterads": "outposterad",
    "outposterat": "outposterad",
    "outposterats": "outposterad",
    "outposterbara": "outposterbar",
    "outposterbarare": "outposterbar",
    "outposterbarares": "outposterbar",
    "outposterbaras": "outposterbar",
    "outposterbarast": "outposterbar",
    "outposterbaraste": "outposterbar",
    "outposterbarastes": "outposterbar",
    "outposterbarasts": "outposterbar",
    "outposterbare": "outposterbar",
    "outposterbares": "outposterbar",
    "outposterbarheten": "outposterbarhet",
    "outposterbarhetens": "outposterbarhet",
    "outposterbarhets": "outposterbarhet",
    "outposterbars": "outposterbar",
    "outposterbart": "outposterbar",
    "outposterbarts": "outposterbar",
    "outputen": "output",
    "outputens": "output",
    "outputs": "output",
    "outraderade": "outraderad",
    "outraderades": "outraderad",
    "outraderads": "outraderad",
    "outraderat": "outraderad",
    "outraderats": "outraderad",
    "outraderbara": "outraderbar",
    "outraderbarare": "outraderbar",
    "outraderbarares": "outraderbar",
    "outraderbaras": "outraderbar",
    "outraderbarast": "outraderbar",
    "outraderbaraste": "outraderbar",
    "outraderbarastes": "outraderbar",
    "outraderbarasts": "outraderbar",
    "outraderbare": "outraderbar",
    "outraderbares": "outraderbar",
    "outraderbarheten": "outraderbarhet",
    "outraderbarhetens": "outraderbarhet",
    "outraderbarhets": "outraderbarhet",
    "outraderbars": "outraderbar",
    "outraderbart": "outraderbar",
    "outraderbarts": "outraderbar",
    "outrangerade": "outrangerad",
    "outrangerades": "outrangerad",
    "outrangerads": "outrangerad",
    "outrangerat": "outrangerad",
    "outrangerats": "outrangerad",
    "outrangerbara": "outrangerbar",
    "outrangerbarare": "outrangerbar",
    "outrangerbarares": "outrangerbar",
    "outrangerbaras": "outrangerbar",
    "outrangerbarast": "outrangerbar",
    "outrangerbaraste": "outrangerbar",
    "outrangerbarastes": "outrangerbar",
    "outrangerbarasts": "outrangerbar",
    "outrangerbare": "outrangerbar",
    "outrangerbares": "outrangerbar",
    "outrangerbarheten": "outrangerbarhet",
    "outrangerbarhetens": "outrangerbarhet",
    "outrangerbarhets": "outrangerbarhet",
    "outrangerbars": "outrangerbar",
    "outrangerbart": "outrangerbar",
    "outrangerbarts": "outrangerbar",
    "outrannsakliga": "outrannsaklig",
    "outrannsakligare": "outrannsaklig",
    "outrannsakligares": "outrannsaklig",
    "outrannsakligas": "outrannsaklig",
    "outrannsakligast": "outrannsaklig",
    "outrannsakligaste": "outrannsaklig",
    "outrannsakligastes": "outrannsaklig",
    "outrannsakligasts": "outrannsaklig",
    "outrannsaklige": "outrannsaklig",
    "outrannsakliges": "outrannsaklig",
    "outrannsakligheten": "outrannsaklighet",
    "outrannsaklighetens": "outrannsaklighet",
    "outrannsaklighets": "outrannsaklighet",
    "outrannsakligs": "outrannsaklig",
    "outrannsakligt": "outrannsaklig",
    "outrannsakligts": "outrannsaklig",
    "outrotliga": "outrotlig",
    "outrotligare": "outrotlig",
    "outrotligares": "outrotlig",
    "outrotligas": "outrotlig",
    "outrotligast": "outrotlig",
    "outrotligaste": "outrotlig",
    "outrotligastes": "outrotlig",
    "outrotligasts": "outrotlig",
    "outrotlige": "outrotlig",
    "outrotliges": "outrotlig",
    "outrotligheten": "outrotlighet",
    "outrotlighetens": "outrotlighet",
    "outrotlighets": "outrotlighet",
    "outrotligs": "outrotlig",
    "outrotligt": "outrotlig",
    "outrotligts": "outrotlig",
    "outsagda": "outsagd",
    "outsagdare": "outsagd",
    "outsagdares": "outsagd",
    "outsagdas": "outsagd",
    "outsagdast": "outsagd",
    "outsagdaste": "outsagd",
    "outsagdastes": "outsagd",
    "outsagdasts": "outsagd",
    "outsagde": "outsagd",
    "outsagdes": "outsagd",
    "outsagdheten": "outsagdhet",
    "outsagdhetens": "outsagdhet",
    "outsagdhets": "outsagdhet",
    "outsagds": "outsagd",
    "outsagt": "outsagd",
    "outsagts": "outsagd",
    "outsidern": "outsider",
    "outsiderna": "outsider",
    "outsidernas": "outsider",
    "outsiderns": "outsider",
    "outsiders": "outsider",
    "outsidersarna": "outsider",
    "outsidersarnas": "outsider",
    "outsidersen": "outsider",
    "outsidersens": "outsider",
    "outsinliga": "outsinlig",
    "outsinligare": "outsinlig",
    "outsinligares": "outsinlig",
    "outsinligas": "outsinlig",
    "outsinligast": "outsinlig",
    "outsinligaste": "outsinlig",
    "outsinligastes": "outsinlig",
    "outsinligasts": "outsinlig",
    "outsinlige": "outsinlig",
    "outsinliges": "outsinlig",
    "outsinligheten": "outsinlighet",
    "outsinlighetens": "outsinlighet",
    "outsinlighets": "outsinlighet",
    "outsinligs": "outsinlig",
    "outsinligt": "outsinlig",
    "outsinligts": "outsinlig",
    "outslitliga": "outslitlig",
    "outslitligare": "outslitlig",
    "outslitligares": "outslitlig",
    "outslitligas": "outslitlig",
    "outslitligast": "outslitlig",
    "outslitligaste": "outslitlig",
    "outslitligastes": "outslitlig",
    "outslitligasts": "outslitlig",
    "outslitlige": "outslitlig",
    "outslitliges": "outslitlig",
    "outslitligheten": "outslitlighet",
    "outslitlighetens": "outslitlighet",
    "outslitlighets": "outslitlighet",
    "outslitligs": "outslitlig",
    "outslitligt": "outslitlig",
    "outslitligts": "outslitlig",
    "outsläckliga": "outsläcklig",
    "outsläckligare": "outsläcklig",
    "outsläckligares": "outsläcklig",
    "outsläckligas": "outsläcklig",
    "outsläckligast": "outsläcklig",
    "outsläckligaste": "outsläcklig",
    "outsläckligastes": "outsläcklig",
    "outsläckligasts": "outsläcklig",
    "outsläcklige": "outsläcklig",
    "outsläckliges": "outsläcklig",
    "outsläckligheten": "outsläcklighet",
    "outsläcklighetens": "outsläcklighet",
    "outsläcklighets": "outsläcklighet",
    "outsläckligs": "outsläcklig",
    "outsläckligt": "outsläcklig",
    "outsläckligts": "outsläcklig",
    "outspädda": "outspädd",
    "outspäddare": "outspädd",
    "outspäddares": "outspädd",
    "outspäddas": "outspädd",
    "outspäddast": "outspädd",
    "outspäddaste": "outspädd",
    "outspäddastes": "outspädd",
    "outspäddasts": "outspädd",
    "outspädde": "outspädd",
    "outspäddes": "outspädd",
    "outspädds": "outspädd",
    "outspätt": "outspädd",
    "outspätts": "outspädd",
    "outstofferade": "outstofferad",
    "outstofferades": "outstofferad",
    "outstofferads": "outstofferad",
    "outstofferat": "outstofferad",
    "outstofferats": "outstofferad",
    "outstofferbara": "outstofferbar",
    "outstofferbarare": "outstofferbar",
    "outstofferbarares": "outstofferbar",
    "outstofferbaras": "outstofferbar",
    "outstofferbarast": "outstofferbar",
    "outstofferbaraste": "outstofferbar",
    "outstofferbarastes": "outstofferbar",
    "outstofferbarasts": "outstofferbar",
    "outstofferbare": "outstofferbar",
    "outstofferbares": "outstofferbar",
    "outstofferbarheten": "outstofferbarhet",
    "outstofferbarhetens": "outstofferbarhet",
    "outstofferbarhets": "outstofferbarhet",
    "outstofferbars": "outstofferbar",
    "outstofferbart": "outstofferbar",
    "outstofferbarts": "outstofferbar",
    "outsägbara": "outsägbar",
    "outsägbarare": "outsägbar",
    "outsägbarares": "outsägbar",
    "outsägbaras": "outsägbar",
    "outsägbarast": "outsägbar",
    "outsägbaraste": "outsägbar",
    "outsägbarastes": "outsägbar",
    "outsägbarasts": "outsägbar",
    "outsägbare": "outsägbar",
    "outsägbares": "outsägbar",
    "outsägbarheten": "outsägbarhet",
    "outsägbarhetens": "outsägbarhet",
    "outsägbarhets": "outsägbarhet",
    "outsägbars": "outsägbar",
    "outsägbart": "outsägbar",
    "outsägbarts": "outsägbar",
    "outsägliga": "outsäglig",
    "outsägligare": "outsäglig",
    "outsägligares": "outsäglig",
    "outsägligas": "outsäglig",
    "outsägligast": "outsäglig",
    "outsägligaste": "outsäglig",
    "outsägligastes": "outsäglig",
    "outsägligasts": "outsäglig",
    "outsäglige": "outsäglig",
    "outsägliges": "outsäglig",
    "outsägligheten": "outsäglighet",
    "outsäglighetens": "outsäglighet",
    "outsäglighets": "outsäglighet",
    "outsägligs": "outsäglig",
    "outsägligt": "outsäglig",
    "outsägligts": "outsäglig",
    "outtalade": "outtalad",
    "outtalades": "outtalad",
    "outtalads": "outtalad",
    "outtalat": "outtalad",
    "outtalats": "outtalad",
    "outtalbara": "outtalbar",
    "outtalbarare": "outtalbar",
    "outtalbarares": "outtalbar",
    "outtalbaras": "outtalbar",
    "outtalbarast": "outtalbar",
    "outtalbaraste": "outtalbar",
    "outtalbarastes": "outtalbar",
    "outtalbarasts": "outtalbar",
    "outtalbare": "outtalbar",
    "outtalbares": "outtalbar",
    "outtalbarheten": "outtalbarhet",
    "outtalbarhetens": "outtalbarhet",
    "outtalbarhets": "outtalbarhet",
    "outtalbars": "outtalbar",
    "outtalbart": "outtalbar",
    "outtalbarts": "outtalbar",
    "outtaxerade": "outtaxerad",
    "outtaxerades": "outtaxerad",
    "outtaxerads": "outtaxerad",
    "outtaxerat": "outtaxerad",
    "outtaxerats": "outtaxerad",
    "outtaxerbara": "outtaxerbar",
    "outtaxerbarare": "outtaxerbar",
    "outtaxerbarares": "outtaxerbar",
    "outtaxerbaras": "outtaxerbar",
    "outtaxerbarast": "outtaxerbar",
    "outtaxerbaraste": "outtaxerbar",
    "outtaxerbarastes": "outtaxerbar",
    "outtaxerbarasts": "outtaxerbar",
    "outtaxerbare": "outtaxerbar",
    "outtaxerbares": "outtaxerbar",
    "outtaxerbarheten": "outtaxerbarhet",
    "outtaxerbarhetens": "outtaxerbarhet",
    "outtaxerbarhets": "outtaxerbarhet",
    "outtaxerbars": "outtaxerbar",
    "outtaxerbart": "outtaxerbar",
    "outtaxerbarts": "outtaxerbar",
    "outtröttliga": "outtröttlig",
    "outtröttligare": "outtröttlig",
    "outtröttligares": "outtröttlig",
    "outtröttligas": "outtröttlig",
    "outtröttligast": "outtröttlig",
    "outtröttligaste": "outtröttlig",
    "outtröttligastes": "outtröttlig",
    "outtröttligasts": "outtröttlig",
    "outtröttlige": "outtröttlig",
    "outtröttliges": "outtröttlig",
    "outtröttligheten": "outtröttlighet",
    "outtröttlighetens": "outtröttlighet",
    "outtröttlighets": "outtröttlighet",
    "outtröttligs": "outtröttlig",
    "outtröttligt": "outtröttlig",
    "outtröttligts": "outtröttlig",
    "outtömliga": "outtömlig",
    "outtömligare": "outtömlig",
    "outtömligares": "outtömlig",
    "outtömligas": "outtömlig",
    "outtömligast": "outtömlig",
    "outtömligaste": "outtömlig",
    "outtömligastes": "outtömlig",
    "outtömligasts": "outtömlig",
    "outtömlige": "outtömlig",
    "outtömliges": "outtömlig",
    "outtömligheten": "outtömlighet",
    "outtömlighetens": "outtömlighet",
    "outtömlighets": "outtömlighet",
    "outtömligs": "outtömlig",
    "outtömligt": "outtömlig",
    "outtömligts": "outtömlig",
    "outvecklade": "outvecklad",
    "outvecklades": "outvecklad",
    "outvecklads": "outvecklad",
    "outvecklat": "outvecklad",
    "outvecklats": "outvecklad",
    "outvuxens": "outvuxen",
    "outvuxet": "outvuxen",
    "outvuxets": "outvuxen",
    "outvuxna": "outvuxen",
    "outvuxnare": "outvuxen",
    "outvuxnares": "outvuxen",
    "outvuxnas": "outvuxen",
    "outvuxnast": "outvuxen",
    "outvuxnaste": "outvuxen",
    "outvuxnastes": "outvuxen",
    "outvuxnasts": "outvuxen",
    "outvuxne": "outvuxen",
    "outvuxnes": "outvuxen",
    "outvärderade": "outvärderad",
    "outvärderades": "outvärderad",
    "outvärderads": "outvärderad",
    "outvärderat": "outvärderad",
    "outvärderats": "outvärderad",
    "outvärderbara": "outvärderbar",
    "outvärderbarare": "outvärderbar",
    "outvärderbarares": "outvärderbar",
    "outvärderbaras": "outvärderbar",
    "outvärderbarast": "outvärderbar",
    "outvärderbaraste": "outvärderbar",
    "outvärderbarastes": "outvärderbar",
    "outvärderbarasts": "outvärderbar",
    "outvärderbare": "outvärderbar",
    "outvärderbares": "outvärderbar",
    "outvärderbarheten": "outvärderbarhet",
    "outvärderbarhetens": "outvärderbarhet",
    "outvärderbarhets": "outvärderbarhet",
    "outvärderbars": "outvärderbar",
    "outvärderbart": "outvärderbar",
    "outvärderbarts": "outvärderbar",
    "outväxta": "outväxt",
    "outväxtare": "outväxt",
    "outväxtares": "outväxt",
    "outväxtas": "outväxt",
    "outväxtast": "outväxt",
    "outväxtaste": "outväxt",
    "outväxtastes": "outväxt",
    "outväxtasts": "outväxt",
    "outväxte": "outväxt",
    "outväxtes": "outväxt",
    "outväxts": "outväxt",
    "ouvertyren": "ouvertyr",
    "ouvertyrens": "ouvertyr",
    "ouvertyrer": "ouvertyr",
    "ouvertyrerna": "ouvertyr",
    "ouvertyrernas": "ouvertyr",
    "ouvertyrers": "ouvertyr",
    "ouvertyrs": "ouvertyr",
    "ouzon": "ouzo",
    "ouzons": "ouzo",
    "ouzos": "ouzo",
    "ovaccinerade": "ovaccinerad",
    "ovaccinerades": "ovaccinerad",
    "ovaccinerads": "ovaccinerad",
    "ovaccinerat": "ovaccinerad",
    "ovaccinerats": "ovaccinerad",
    "ovaccinerbara": "ovaccinerbar",
    "ovaccinerbarare": "ovaccinerbar",
    "ovaccinerbarares": "ovaccinerbar",
    "ovaccinerbaras": "ovaccinerbar",
    "ovaccinerbarast": "ovaccinerbar",
    "ovaccinerbaraste": "ovaccinerbar",
    "ovaccinerbarastes": "ovaccinerbar",
    "ovaccinerbarasts": "ovaccinerbar",
    "ovaccinerbare": "ovaccinerbar",
    "ovaccinerbares": "ovaccinerbar",
    "ovaccinerbarheten": "ovaccinerbarhet",
    "ovaccinerbarhetens": "ovaccinerbarhet",
    "ovaccinerbarhets": "ovaccinerbarhet",
    "ovaccinerbars": "ovaccinerbar",
    "ovaccinerbart": "ovaccinerbar",
    "ovaccinerbarts": "ovaccinerbar",
    "ovadderade": "ovadderad",
    "ovadderades": "ovadderad",
    "ovadderads": "ovadderad",
    "ovadderat": "ovadderad",
    "ovadderats": "ovadderad",
    "ovadderbara": "ovadderbar",
    "ovadderbarare": "ovadderbar",
    "ovadderbarares": "ovadderbar",
    "ovadderbaras": "ovadderbar",
    "ovadderbarast": "ovadderbar",
    "ovadderbaraste": "ovadderbar",
    "ovadderbarastes": "ovadderbar",
    "ovadderbarasts": "ovadderbar",
    "ovadderbare": "ovadderbar",
    "ovadderbares": "ovadderbar",
    "ovadderbarheten": "ovadderbarhet",
    "ovadderbarhetens": "ovadderbarhet",
    "ovadderbarhets": "ovadderbarhet",
    "ovadderbars": "ovadderbar",
    "ovadderbart": "ovadderbar",
    "ovadderbarts": "ovadderbar",
    "ovaggade": "ovaggad",
    "ovaggades": "ovaggad",
    "ovaggads": "ovaggad",
    "ovaggat": "ovaggad",
    "ovaggats": "ovaggad",
    "ovaksinerade": "ovaksinerad",
    "ovaksinerades": "ovaksinerad",
    "ovaksinerads": "ovaksinerad",
    "ovaksinerat": "ovaksinerad",
    "ovaksinerats": "ovaksinerad",
    "ovaksinerbara": "ovaksinerbar",
    "ovaksinerbarare": "ovaksinerbar",
    "ovaksinerbarares": "ovaksinerbar",
    "ovaksinerbaras": "ovaksinerbar",
    "ovaksinerbarast": "ovaksinerbar",
    "ovaksinerbaraste": "ovaksinerbar",
    "ovaksinerbarastes": "ovaksinerbar",
    "ovaksinerbarasts": "ovaksinerbar",
    "ovaksinerbare": "ovaksinerbar",
    "ovaksinerbares": "ovaksinerbar",
    "ovaksinerbarheten": "ovaksinerbarhet",
    "ovaksinerbarhetens": "ovaksinerbarhet",
    "ovaksinerbarhets": "ovaksinerbarhet",
    "ovaksinerbars": "ovaksinerbar",
    "ovaksinerbart": "ovaksinerbar",
    "ovaksinerbarts": "ovaksinerbar",
    "ovala": "oval",
    "ovalare": "oval",
    "ovalares": "oval",
    "ovalas": "oval",
    "ovalast": "oval",
    "ovalaste": "oval",
    "ovalastes": "oval",
    "ovalasts": "oval",
    "ovale": "oval",
    "ovalen": "oval",
    "ovalens": "oval",
    "ovaler": "oval",
    "ovalerna": "oval",
    "ovalernas": "oval",
    "ovalers": "oval",
    "ovales": "oval",
    "ovals": "oval",
    "ovalsvarvningar": "ovalsvarvning",
    "ovalsvarvningarna": "ovalsvarvning",
    "ovalsvarvningarnas": "ovalsvarvning",
    "ovalsvarvningars": "ovalsvarvning",
    "ovalsvarvningen": "ovalsvarvning",
    "ovalsvarvningens": "ovalsvarvning",
    "ovalsvarvnings": "ovalsvarvning",
    "ovalt": "oval",
    "ovalts": "oval",
    "ovaluterade": "ovaluterad",
    "ovaluterades": "ovaluterad",
    "ovaluterads": "ovaluterad",
    "ovaluterat": "ovaluterad",
    "ovaluterats": "ovaluterad",
    "ovaluterbara": "ovaluterbar",
    "ovaluterbarare": "ovaluterbar",
    "ovaluterbarares": "ovaluterbar",
    "ovaluterbaras": "ovaluterbar",
    "ovaluterbarast": "ovaluterbar",
    "ovaluterbaraste": "ovaluterbar",
    "ovaluterbarastes": "ovaluterbar",
    "ovaluterbarasts": "ovaluterbar",
    "ovaluterbare": "ovaluterbar",
    "ovaluterbares": "ovaluterbar",
    "ovaluterbarheten": "ovaluterbarhet",
    "ovaluterbarhetens": "ovaluterbarhet",
    "ovaluterbarhets": "ovaluterbarhet",
    "ovaluterbars": "ovaluterbar",
    "ovaluterbart": "ovaluterbar",
    "ovaluterbarts": "ovaluterbar",
    "ovalverade": "ovalverad",
    "ovalverades": "ovalverad",
    "ovalverads": "ovalverad",
    "ovalverat": "ovalverad",
    "ovalverats": "ovalverad",
    "ovalverbara": "ovalverbar",
    "ovalverbarare": "ovalverbar",
    "ovalverbarares": "ovalverbar",
    "ovalverbaras": "ovalverbar",
    "ovalverbarast": "ovalverbar",
    "ovalverbaraste": "ovalverbar",
    "ovalverbarastes": "ovalverbar",
    "ovalverbarasts": "ovalverbar",
    "ovalverbare": "ovalverbar",
    "ovalverbares": "ovalverbar",
    "ovalverbarheten": "ovalverbarhet",
    "ovalverbarhetens": "ovalverbarhet",
    "ovalverbarhets": "ovalverbarhet",
    "ovalverbars": "ovalverbar",
    "ovalverbart": "ovalverbar",
    "ovalverbarts": "ovalverbar",
    "ovana": "ovan",
    "ovanan": "ovana",
    "ovanans": "ovana",
    "ovanare": "ovan",
    "ovanares": "ovan",
    "ovanas": "ovana",
    "ovanast": "ovan",
    "ovanaste": "ovan",
    "ovanastes": "ovan",
    "ovanasts": "ovan",
    "ovanbemäldas": "ovanbemälda",
    "ovanbemälde": "ovanbemälda",
    "ovanbemäldes": "ovanbemälda",
    "ovanbemältas": "ovanbemälta",
    "ovanbemälte": "ovanbemälta",
    "ovanbemältes": "ovanbemälta",
    "ovandagern": "ovandager",
    "ovandagerns": "ovandager",
    "ovandagers": "ovandager",
    "ovandaliserade": "ovandaliserad",
    "ovandaliserades": "ovandaliserad",
    "ovandaliserads": "ovandaliserad",
    "ovandaliserat": "ovandaliserad",
    "ovandaliserats": "ovandaliserad",
    "ovandaliserbara": "ovandaliserbar",
    "ovandaliserbarare": "ovandaliserbar",
    "ovandaliserbarares": "ovandaliserbar",
    "ovandaliserbaras": "ovandaliserbar",
    "ovandaliserbarast": "ovandaliserbar",
    "ovandaliserbaraste": "ovandaliserbar",
    "ovandaliserbarastes": "ovandaliserbar",
    "ovandaliserbarasts": "ovandaliserbar",
    "ovandaliserbare": "ovandaliserbar",
    "ovandaliserbares": "ovandaliserbar",
    "ovandaliserbarheten": "ovandaliserbarhet",
    "ovandaliserbarhetens": "ovandaliserbarhet",
    "ovandaliserbarhets": "ovandaliserbarhet",
    "ovandaliserbars": "ovandaliserbar",
    "ovandaliserbart": "ovandaliserbar",
    "ovandaliserbarts": "ovandaliserbar",
    "ovandelar": "ovandel",
    "ovandelarna": "ovandel",
    "ovandelarnas": "ovandel",
    "ovandelars": "ovandel",
    "ovandelen": "ovandel",
    "ovandelens": "ovandel",
    "ovandels": "ovandel",
    "ovane": "ovana",
    "ovanes": "ovan",
    "ovanjordiska": "ovanjordisk",
    "ovanjordiskare": "ovanjordisk",
    "ovanjordiskares": "ovanjordisk",
    "ovanjordiskas": "ovanjordisk",
    "ovanjordiskast": "ovanjordisk",
    "ovanjordiskaste": "ovanjordisk",
    "ovanjordiskastes": "ovanjordisk",
    "ovanjordiskasts": "ovanjordisk",
    "ovanjordiske": "ovanjordisk",
    "ovanjordiskes": "ovanjordisk",
    "ovanjordisks": "ovanjordisk",
    "ovanjordiskt": "ovanjordisk",
    "ovanjordiskts": "ovanjordisk",
    "ovanliga": "ovanlig",
    "ovanligare": "ovanlig",
    "ovanligares": "ovanlig",
    "ovanligas": "ovanlig",
    "ovanligast": "ovanlig",
    "ovanligaste": "ovanlig",
    "ovanligastes": "ovanlig",
    "ovanligasts": "ovanlig",
    "ovanlige": "ovanlig",
    "ovanliges": "ovanlig",
    "ovanligheten": "ovanlighet",
    "ovanlighetens": "ovanlighet",
    "ovanligheter": "ovanlighet",
    "ovanligheterna": "ovanlighet",
    "ovanligheternas": "ovanlighet",
    "ovanligheters": "ovanlighet",
    "ovanlighets": "ovanlighet",
    "ovanligs": "ovanlig",
    "ovanligt": "ovanlig",
    "ovanligts": "ovanlig",
    "ovanläders": "ovanläder",
    "ovanlädret": "ovanläder",
    "ovanlädrets": "ovanläder",
    "ovannämnda": "ovannämnd",
    "ovannämndare": "ovannämnd",
    "ovannämndares": "ovannämnd",
    "ovannämndas": "ovannämnd",
    "ovannämndast": "ovannämnd",
    "ovannämndaste": "ovannämnd",
    "ovannämndastes": "ovannämnd",
    "ovannämndasts": "ovannämnd",
    "ovannämnde": "ovannämnd",
    "ovannämndes": "ovannämnd",
    "ovannämnds": "ovannämnd",
    "ovannämnt": "ovannämnd",
    "ovannämnts": "ovannämnd",
    "ovanor": "ovana",
    "ovanorna": "ovana",
    "ovanornas": "ovana",
    "ovanors": "ovana",
    "ovans": "ovan",
    "ovansidan": "ovansida",
    "ovansidans": "ovansida",
    "ovansidas": "ovansida",
    "ovanside": "ovansida",
    "ovansides": "ovansida",
    "ovansidor": "ovansida",
    "ovansidorna": "ovansida",
    "ovansidornas": "ovansida",
    "ovansidors": "ovansida",
    "ovanskliga": "ovansklig",
    "ovanskligare": "ovansklig",
    "ovanskligares": "ovansklig",
    "ovanskligas": "ovansklig",
    "ovanskligast": "ovansklig",
    "ovanskligaste": "ovansklig",
    "ovanskligastes": "ovansklig",
    "ovanskligasts": "ovansklig",
    "ovansklige": "ovansklig",
    "ovanskliges": "ovansklig",
    "ovanskligheten": "ovansklighet",
    "ovansklighetens": "ovansklighet",
    "ovansklighets": "ovansklighet",
    "ovanskligs": "ovansklig",
    "ovanskligt": "ovansklig",
    "ovanskligts": "ovansklig",
    "ovant": "ovan",
    "ovants": "ovan",
    "ovanvåningar": "ovanvåning",
    "ovanvåningarna": "ovanvåning",
    "ovanvåningarnas": "ovanvåning",
    "ovanvåningars": "ovanvåning",
    "ovanvåningen": "ovanvåning",
    "ovanvåningens": "ovanvåning",
    "ovanvånings": "ovanvåning",
    "ovarie": "ovarium",
    "ovarier": "ovarium",
    "ovarierade": "ovarierad",
    "ovarierades": "ovarierad",
    "ovarierads": "ovarierad",
    "ovarierat": "ovarierad",
    "ovarierats": "ovarierad",
    "ovarierbara": "ovarierbar",
    "ovarierbarare": "ovarierbar",
    "ovarierbarares": "ovarierbar",
    "ovarierbaras": "ovarierbar",
    "ovarierbarast": "ovarierbar",
    "ovarierbaraste": "ovarierbar",
    "ovarierbarastes": "ovarierbar",
    "ovarierbarasts": "ovarierbar",
    "ovarierbare": "ovarierbar",
    "ovarierbares": "ovarierbar",
    "ovarierbarheten": "ovarierbarhet",
    "ovarierbarhetens": "ovarierbarhet",
    "ovarierbarhets": "ovarierbarhet",
    "ovarierbars": "ovarierbar",
    "ovarierbart": "ovarierbar",
    "ovarierbarts": "ovarierbar",
    "ovarierna": "ovarium",
    "ovariernas": "ovarium",
    "ovariers": "ovarium",
    "ovariet": "ovarium",
    "ovariets": "ovarium",
    "ovariotomien": "ovariotomi",
    "ovariotomiens": "ovariotomi",
    "ovariotomier": "ovariotomi",
    "ovariotomierna": "ovariotomi",
    "ovariotomiernas": "ovariotomi",
    "ovariotomiers": "ovariotomi",
    "ovariotomin": "ovariotomi",
    "ovariotomins": "ovariotomi",
    "ovariotomis": "ovariotomi",
    "ovariums": "ovarium",
    "ovarsamheten": "ovarsamhet",
    "ovarsamhetens": "ovarsamhet",
    "ovarsamhets": "ovarsamhet",
    "ovarsamma": "ovarsam",
    "ovarsammare": "ovarsam",
    "ovarsammares": "ovarsam",
    "ovarsammas": "ovarsam",
    "ovarsammast": "ovarsam",
    "ovarsammaste": "ovarsam",
    "ovarsammastes": "ovarsam",
    "ovarsammasts": "ovarsam",
    "ovarsamme": "ovarsam",
    "ovarsammes": "ovarsam",
    "ovarsams": "ovarsam",
    "ovarsamt": "ovarsam",
    "ovarsamts": "ovarsam",
    "ovationen": "ovation",
    "ovationens": "ovation",
    "ovationer": "ovation",
    "ovationerna": "ovation",
    "ovationernas": "ovation",
    "ovationers": "ovation",
    "ovations": "ovation",
    "ovederhäftiga": "ovederhäftig",
    "ovederhäftigare": "ovederhäftig",
    "ovederhäftigares": "ovederhäftig",
    "ovederhäftigas": "ovederhäftig",
    "ovederhäftigast": "ovederhäftig",
    "ovederhäftigaste": "ovederhäftig",
    "ovederhäftigastes": "ovederhäftig",
    "ovederhäftigasts": "ovederhäftig",
    "ovederhäftige": "ovederhäftig",
    "ovederhäftiges": "ovederhäftig",
    "ovederhäftigheten": "ovederhäftighet",
    "ovederhäftighetens": "ovederhäftighet",
    "ovederhäftighets": "ovederhäftighet",
    "ovederhäftigs": "ovederhäftig",
    "ovederhäftigt": "ovederhäftig",
    "ovederhäftigts": "ovederhäftig",
    "ovederläggliga": "ovederlägglig",
    "ovederläggligare": "ovederlägglig",
    "ovederläggligares": "ovederlägglig",
    "ovederläggligas": "ovederlägglig",
    "ovederläggligast": "ovederlägglig",
    "ovederläggligaste": "ovederlägglig",
    "ovederläggligastes": "ovederlägglig",
    "ovederläggligasts": "ovederlägglig",
    "ovederlägglige": "ovederlägglig",
    "ovederläggliges": "ovederlägglig",
    "ovederläggligheten": "ovederlägglighet",
    "ovederlägglighetens": "ovederlägglighet",
    "ovederlägglighets": "ovederlägglighet",
    "ovederläggligs": "ovederlägglig",
    "ovederläggligt": "ovederlägglig",
    "ovederläggligts": "ovederlägglig",
    "ovedersägliga": "ovedersäglig",
    "ovedersägligare": "ovedersäglig",
    "ovedersägligares": "ovedersäglig",
    "ovedersägligas": "ovedersäglig",
    "ovedersägligast": "ovedersäglig",
    "ovedersägligaste": "ovedersäglig",
    "ovedersägligastes": "ovedersäglig",
    "ovedersägligasts": "ovedersäglig",
    "ovedersäglige": "ovedersäglig",
    "ovedersägliges": "ovedersäglig",
    "ovedersägligheten": "ovedersäglighet",
    "ovedersäglighetens": "ovedersäglighet",
    "ovedersäglighets": "ovedersäglighet",
    "ovedersägligs": "ovedersäglig",
    "ovedersägligt": "ovedersäglig",
    "ovedersägligts": "ovedersäglig",
    "ovelouriserade": "ovelouriserad",
    "ovelouriserades": "ovelouriserad",
    "ovelouriserads": "ovelouriserad",
    "ovelouriserat": "ovelouriserad",
    "ovelouriserats": "ovelouriserad",
    "ovelouriserbara": "ovelouriserbar",
    "ovelouriserbarare": "ovelouriserbar",
    "ovelouriserbarares": "ovelouriserbar",
    "ovelouriserbaras": "ovelouriserbar",
    "ovelouriserbarast": "ovelouriserbar",
    "ovelouriserbaraste": "ovelouriserbar",
    "ovelouriserbarastes": "ovelouriserbar",
    "ovelouriserbarasts": "ovelouriserbar",
    "ovelouriserbare": "ovelouriserbar",
    "ovelouriserbares": "ovelouriserbar",
    "ovelouriserbarheten": "ovelouriserbarhet",
    "ovelouriserbarhetens": "ovelouriserbarhet",
    "ovelouriserbarhets": "ovelouriserbarhet",
    "ovelouriserbars": "ovelouriserbar",
    "ovelouriserbart": "ovelouriserbar",
    "ovelouriserbarts": "ovelouriserbar",
    "oventilerade": "oventilerad",
    "oventilerades": "oventilerad",
    "oventilerads": "oventilerad",
    "oventilerat": "oventilerad",
    "oventilerats": "oventilerad",
    "oventilerbara": "oventilerbar",
    "oventilerbarare": "oventilerbar",
    "oventilerbarares": "oventilerbar",
    "oventilerbaras": "oventilerbar",
    "oventilerbarast": "oventilerbar",
    "oventilerbaraste": "oventilerbar",
    "oventilerbarastes": "oventilerbar",
    "oventilerbarasts": "oventilerbar",
    "oventilerbare": "oventilerbar",
    "oventilerbares": "oventilerbar",
    "oventilerbarheten": "oventilerbarhet",
    "oventilerbarhetens": "oventilerbarhet",
    "oventilerbarhets": "oventilerbarhet",
    "oventilerbars": "oventilerbar",
    "oventilerbart": "oventilerbar",
    "oventilerbarts": "oventilerbar",
    "overallen": "overall",
    "overallens": "overall",
    "overaller": "overall",
    "overallerna": "overall",
    "overallernas": "overall",
    "overallers": "overall",
    "overalls": "overall",
    "overbaliserade": "overbaliserad",
    "overbaliserades": "overbaliserad",
    "overbaliserads": "overbaliserad",
    "overbaliserat": "overbaliserad",
    "overbaliserats": "overbaliserad",
    "overbaliserbara": "overbaliserbar",
    "overbaliserbarare": "overbaliserbar",
    "overbaliserbarares": "overbaliserbar",
    "overbaliserbaras": "overbaliserbar",
    "overbaliserbarast": "overbaliserbar",
    "overbaliserbaraste": "overbaliserbar",
    "overbaliserbarastes": "overbaliserbar",
    "overbaliserbarasts": "overbaliserbar",
    "overbaliserbare": "overbaliserbar",
    "overbaliserbares": "overbaliserbar",
    "overbaliserbarheten": "overbaliserbarhet",
    "overbaliserbarhetens": "overbaliserbarhet",
    "overbaliserbarhets": "overbaliserbarhet",
    "overbaliserbars": "overbaliserbar",
    "overbaliserbart": "overbaliserbar",
    "overbaliserbarts": "overbaliserbar",
    "overhead-projektorer": "overhead-projektor",
    "overhead-projektorerna": "overhead-projektor",
    "overhead-projektorernas": "overhead-projektor",
    "overhead-projektorers": "overhead-projektor",
    "overhead-projektorn": "overhead-projektor",
    "overhead-projektorns": "overhead-projektor",
    "overhead-projektors": "overhead-projektor",
    "overheadbilden": "overheadbild",
    "overheadbildens": "overheadbild",
    "overheadbilder": "overheadbild",
    "overheadbilderna": "overheadbild",
    "overheadbildernas": "overheadbild",
    "overheadbilders": "overheadbild",
    "overheadbilds": "overheadbild",
    "overheaden": "overhead",
    "overheadens": "overhead",
    "overheadprojektorer": "overheadprojektor",
    "overheadprojektorerna": "overheadprojektor",
    "overheadprojektorernas": "overheadprojektor",
    "overheadprojektorers": "overheadprojektor",
    "overheadprojektorn": "overheadprojektor",
    "overheadprojektorns": "overheadprojektor",
    "overheadprojektors": "overheadprojektor",
    "overheads": "overhead",
    "overifierade": "overifierad",
    "overifierades": "overifierad",
    "overifierads": "overifierad",
    "overifierat": "overifierad",
    "overifierats": "overifierad",
    "overifierbara": "overifierbar",
    "overifierbarare": "overifierbar",
    "overifierbarares": "overifierbar",
    "overifierbaras": "overifierbar",
    "overifierbarast": "overifierbar",
    "overifierbaraste": "overifierbar",
    "overifierbarastes": "overifierbar",
    "overifierbarasts": "overifierbar",
    "overifierbare": "overifierbar",
    "overifierbares": "overifierbar",
    "overifierbarheten": "overifierbarhet",
    "overifierbarhetens": "overifierbarhet",
    "overifierbarhets": "overifierbarhet",
    "overifierbars": "overifierbar",
    "overifierbart": "overifierbar",
    "overifierbarts": "overifierbar",
    "overkliga": "overklig",
    "overkligare": "overklig",
    "overkligares": "overklig",
    "overkligas": "overklig",
    "overkligast": "overklig",
    "overkligaste": "overklig",
    "overkligastes": "overklig",
    "overkligasts": "overklig",
    "overklige": "overklig",
    "overkliges": "overklig",
    "overkligheten": "overklighet",
    "overklighetens": "overklighet",
    "overklighets": "overklighet",
    "overkligs": "overklig",
    "overkligt": "overklig",
    "overkligts": "overklig",
    "overksamheten": "overksamhet",
    "overksamhetens": "overksamhet",
    "overksamheter": "overksamhet",
    "overksamheterna": "overksamhet",
    "overksamheternas": "overksamhet",
    "overksamheters": "overksamhet",
    "overksamhets": "overksamhet",
    "overksamma": "overksam",
    "overksammare": "overksam",
    "overksammares": "overksam",
    "overksammas": "overksam",
    "overksammast": "overksam",
    "overksammaste": "overksam",
    "overksammastes": "overksam",
    "overksammasts": "overksam",
    "overksamme": "overksam",
    "overksammes": "overksam",
    "overksams": "overksam",
    "overksamt": "overksam",
    "overksamts": "overksam",
    "oversifierade": "oversifierad",
    "oversifierades": "oversifierad",
    "oversifierads": "oversifierad",
    "oversifierat": "oversifierad",
    "oversifierats": "oversifierad",
    "oversifierbara": "oversifierbar",
    "oversifierbarare": "oversifierbar",
    "oversifierbarares": "oversifierbar",
    "oversifierbaras": "oversifierbar",
    "oversifierbarast": "oversifierbar",
    "oversifierbaraste": "oversifierbar",
    "oversifierbarastes": "oversifierbar",
    "oversifierbarasts": "oversifierbar",
    "oversifierbare": "oversifierbar",
    "oversifierbares": "oversifierbar",
    "oversifierbarheten": "oversifierbarhet",
    "oversifierbarhetens": "oversifierbarhet",
    "oversifierbarhets": "oversifierbarhet",
    "oversifierbars": "oversifierbar",
    "oversifierbart": "oversifierbar",
    "oversifierbarts": "oversifierbar",
    "ovetbara": "ovetbar",
    "ovetbarare": "ovetbar",
    "ovetbarares": "ovetbar",
    "ovetbaras": "ovetbar",
    "ovetbarast": "ovetbar",
    "ovetbaraste": "ovetbar",
    "ovetbarastes": "ovetbar",
    "ovetbarasts": "ovetbar",
    "ovetbare": "ovetbar",
    "ovetbares": "ovetbar",
    "ovetbarheten": "ovetbarhet",
    "ovetbarhetens": "ovetbarhet",
    "ovetbarhets": "ovetbarhet",
    "ovetbars": "ovetbar",
    "ovetbart": "ovetbar",
    "ovetbarts": "ovetbar",
    "ovetenheten": "ovetenhet",
    "ovetenhetens": "ovetenhet",
    "ovetenheter": "ovetenhet",
    "ovetenheterna": "ovetenhet",
    "ovetenheternas": "ovetenhet",
    "ovetenheters": "ovetenhet",
    "ovetenhets": "ovetenhet",
    "ovetens": "oveten",
    "ovetenskapliga": "ovetenskaplig",
    "ovetenskapligare": "ovetenskaplig",
    "ovetenskapligares": "ovetenskaplig",
    "ovetenskapligas": "ovetenskaplig",
    "ovetenskapligast": "ovetenskaplig",
    "ovetenskapligaste": "ovetenskaplig",
    "ovetenskapligastes": "ovetenskaplig",
    "ovetenskapligasts": "ovetenskaplig",
    "ovetenskaplige": "ovetenskaplig",
    "ovetenskapliges": "ovetenskaplig",
    "ovetenskapligheten": "ovetenskaplighet",
    "ovetenskaplighetens": "ovetenskaplighet",
    "ovetenskaplighets": "ovetenskaplighet",
    "ovetenskapligs": "ovetenskaplig",
    "ovetenskapligt": "ovetenskaplig",
    "ovetenskapligts": "ovetenskaplig",
    "ovetet": "oveten",
    "ovetets": "oveten",
    "ovetna": "oveten",
    "ovetnare": "oveten",
    "ovetnares": "oveten",
    "ovetnas": "oveten",
    "ovetnast": "oveten",
    "ovetnaste": "oveten",
    "ovetnastes": "oveten",
    "ovetnasts": "oveten",
    "ovetne": "oveten",
    "ovetnes": "oveten",
    "ovetskapen": "ovetskap",
    "ovetskapens": "ovetskap",
    "ovetskaps": "ovetskap",
    "ovettet": "ovett",
    "ovettets": "ovett",
    "ovettiga": "ovettig",
    "ovettigare": "ovettig",
    "ovettigares": "ovettig",
    "ovettigas": "ovettig",
    "ovettigast": "ovettig",
    "ovettigaste": "ovettig",
    "ovettigastes": "ovettig",
    "ovettigasts": "ovettig",
    "ovettige": "ovettig",
    "ovettiges": "ovettig",
    "ovettigheten": "ovettighet",
    "ovettighetens": "ovettighet",
    "ovettigheter": "ovettighet",
    "ovettigheterna": "ovettighet",
    "ovettigheternas": "ovettighet",
    "ovettigheters": "ovettighet",
    "ovettighets": "ovettighet",
    "ovettigs": "ovettig",
    "ovettigt": "ovettig",
    "ovettigts": "ovettig",
    "ovetts": "ovett",
    "ovidimerade": "ovidimerad",
    "ovidimerades": "ovidimerad",
    "ovidimerads": "ovidimerad",
    "ovidimerat": "ovidimerad",
    "ovidimerats": "ovidimerad",
    "ovidimerbara": "ovidimerbar",
    "ovidimerbarare": "ovidimerbar",
    "ovidimerbarares": "ovidimerbar",
    "ovidimerbaras": "ovidimerbar",
    "ovidimerbarast": "ovidimerbar",
    "ovidimerbaraste": "ovidimerbar",
    "ovidimerbarastes": "ovidimerbar",
    "ovidimerbarasts": "ovidimerbar",
    "ovidimerbare": "ovidimerbar",
    "ovidimerbares": "ovidimerbar",
    "ovidimerbarheten": "ovidimerbarhet",
    "ovidimerbarhetens": "ovidimerbarhet",
    "ovidimerbarhets": "ovidimerbarhet",
    "ovidimerbars": "ovidimerbar",
    "ovidimerbart": "ovidimerbar",
    "ovidimerbarts": "ovidimerbar",
    "oviga": "ovig",
    "ovigare": "ovig",
    "ovigares": "ovig",
    "ovigas": "ovig",
    "ovigast": "ovig",
    "ovigaste": "ovig",
    "ovigastes": "ovig",
    "ovigasts": "ovig",
    "ovigda": "ovigd",
    "ovigdare": "ovigd",
    "ovigdares": "ovigd",
    "ovigdas": "ovigd",
    "ovigdast": "ovigd",
    "ovigdaste": "ovigd",
    "ovigdastes": "ovigd",
    "ovigdasts": "ovigd",
    "ovigde": "ovigd",
    "ovigdes": "ovigd",
    "ovigds": "ovigd",
    "ovige": "ovig",
    "oviges": "ovig",
    "ovigs": "ovig",
    "ovigt": "ovigd",
    "ovigts": "ovigd",
    "oviktiga": "oviktig",
    "oviktigare": "oviktig",
    "oviktigares": "oviktig",
    "oviktigas": "oviktig",
    "oviktigast": "oviktig",
    "oviktigaste": "oviktig",
    "oviktigastes": "oviktig",
    "oviktigasts": "oviktig",
    "oviktige": "oviktig",
    "oviktiges": "oviktig",
    "oviktigheten": "oviktighet",
    "oviktighetens": "oviktighet",
    "oviktighets": "oviktighet",
    "oviktigs": "oviktig",
    "oviktigt": "oviktig",
    "oviktigts": "oviktig",
    "oviljan": "ovilja",
    "oviljans": "ovilja",
    "oviljas": "ovilja",
    "ovilliga": "ovillig",
    "ovilligare": "ovillig",
    "ovilligares": "ovillig",
    "ovilligas": "ovillig",
    "ovilligast": "ovillig",
    "ovilligaste": "ovillig",
    "ovilligastes": "ovillig",
    "ovilligasts": "ovillig",
    "ovillige": "ovillig",
    "ovilliges": "ovillig",
    "ovilligheten": "ovillighet",
    "ovillighetens": "ovillighet",
    "ovillighets": "ovillighet",
    "ovilligs": "ovillig",
    "ovilligt": "ovillig",
    "ovilligts": "ovillig",
    "ovillkorliga": "ovillkorlig",
    "ovillkorligare": "ovillkorlig",
    "ovillkorligares": "ovillkorlig",
    "ovillkorligas": "ovillkorlig",
    "ovillkorligast": "ovillkorlig",
    "ovillkorligaste": "ovillkorlig",
    "ovillkorligastes": "ovillkorlig",
    "ovillkorligasts": "ovillkorlig",
    "ovillkorlige": "ovillkorlig",
    "ovillkorliges": "ovillkorlig",
    "ovillkorligheten": "ovillkorlighet",
    "ovillkorlighetens": "ovillkorlighet",
    "ovillkorlighets": "ovillkorlighet",
    "ovillkorligs": "ovillkorlig",
    "ovillkorligt": "ovillkorlig",
    "ovillkorligts": "ovillkorlig",
    "ovindicerade": "ovindicerad",
    "ovindicerades": "ovindicerad",
    "ovindicerads": "ovindicerad",
    "ovindicerat": "ovindicerad",
    "ovindicerats": "ovindicerad",
    "ovindicerbara": "ovindicerbar",
    "ovindicerbarare": "ovindicerbar",
    "ovindicerbarares": "ovindicerbar",
    "ovindicerbaras": "ovindicerbar",
    "ovindicerbarast": "ovindicerbar",
    "ovindicerbaraste": "ovindicerbar",
    "ovindicerbarastes": "ovindicerbar",
    "ovindicerbarasts": "ovindicerbar",
    "ovindicerbare": "ovindicerbar",
    "ovindicerbares": "ovindicerbar",
    "ovindicerbarheten": "ovindicerbarhet",
    "ovindicerbarhetens": "ovindicerbarhet",
    "ovindicerbarhets": "ovindicerbarhet",
    "ovindicerbars": "ovindicerbar",
    "ovindicerbart": "ovindicerbar",
    "ovindicerbarts": "ovindicerbar",
    "ovipara": "ovipar",
    "oviparare": "ovipar",
    "oviparares": "ovipar",
    "oviparas": "ovipar",
    "oviparast": "ovipar",
    "oviparaste": "ovipar",
    "oviparastes": "ovipar",
    "oviparasts": "ovipar",
    "ovipare": "ovipar",
    "ovipares": "ovipar",
    "ovipars": "ovipar",
    "ovipart": "ovipar",
    "oviparts": "ovipar",
    "ovisa": "ovis",
    "ovisare": "ovis",
    "ovisares": "ovis",
    "ovisas": "ovis",
    "ovisast": "ovis",
    "ovisaste": "ovis",
    "ovisastes": "ovis",
    "ovisasts": "ovis",
    "ovise": "ovis",
    "oviserade": "oviserad",
    "oviserades": "oviserad",
    "oviserads": "oviserad",
    "oviserat": "oviserad",
    "oviserats": "oviserad",
    "oviserbara": "oviserbar",
    "oviserbarare": "oviserbar",
    "oviserbarares": "oviserbar",
    "oviserbaras": "oviserbar",
    "oviserbarast": "oviserbar",
    "oviserbaraste": "oviserbar",
    "oviserbarastes": "oviserbar",
    "oviserbarasts": "oviserbar",
    "oviserbare": "oviserbar",
    "oviserbares": "oviserbar",
    "oviserbarheten": "oviserbarhet",
    "oviserbarhetens": "oviserbarhet",
    "oviserbarhets": "oviserbarhet",
    "oviserbars": "oviserbar",
    "oviserbart": "oviserbar",
    "oviserbarts": "oviserbar",
    "ovises": "ovis",
    "ovisiterade": "ovisiterad",
    "ovisiterades": "ovisiterad",
    "ovisiterads": "ovisiterad",
    "ovisiterat": "ovisiterad",
    "ovisiterats": "ovisiterad",
    "ovisiterbara": "ovisiterbar",
    "ovisiterbarare": "ovisiterbar",
    "ovisiterbarares": "ovisiterbar",
    "ovisiterbaras": "ovisiterbar",
    "ovisiterbarast": "ovisiterbar",
    "ovisiterbaraste": "ovisiterbar",
    "ovisiterbarastes": "ovisiterbar",
    "ovisiterbarasts": "ovisiterbar",
    "ovisiterbare": "ovisiterbar",
    "ovisiterbares": "ovisiterbar",
    "ovisiterbarheten": "ovisiterbarhet",
    "ovisiterbarhetens": "ovisiterbarhet",
    "ovisiterbarhets": "ovisiterbarhet",
    "ovisiterbars": "ovisiterbar",
    "ovisiterbart": "ovisiterbar",
    "ovisiterbarts": "ovisiterbar",
    "ovissa": "oviss",
    "ovissare": "oviss",
    "ovissares": "oviss",
    "ovissas": "oviss",
    "ovissast": "oviss",
    "ovissaste": "oviss",
    "ovissastes": "oviss",
    "ovissasts": "oviss",
    "ovisse": "oviss",
    "ovisses": "oviss",
    "ovissheten": "ovisshet",
    "ovisshetens": "ovisshet",
    "ovissheter": "ovisshet",
    "ovissheterna": "ovisshet",
    "ovissheternas": "ovisshet",
    "ovissheters": "ovisshet",
    "ovisshets": "ovisshet",
    "ovisst": "oviss",
    "ovissts": "oviss",
    "ovist": "ovis",
    "ovists": "ovis",
    "ovisualiserade": "ovisualiserad",
    "ovisualiserades": "ovisualiserad",
    "ovisualiserads": "ovisualiserad",
    "ovisualiserat": "ovisualiserad",
    "ovisualiserats": "ovisualiserad",
    "ovisualiserbara": "ovisualiserbar",
    "ovisualiserbarare": "ovisualiserbar",
    "ovisualiserbarares": "ovisualiserbar",
    "ovisualiserbaras": "ovisualiserbar",
    "ovisualiserbarast": "ovisualiserbar",
    "ovisualiserbaraste": "ovisualiserbar",
    "ovisualiserbarastes": "ovisualiserbar",
    "ovisualiserbarasts": "ovisualiserbar",
    "ovisualiserbare": "ovisualiserbar",
    "ovisualiserbares": "ovisualiserbar",
    "ovisualiserbarheten": "ovisualiserbarhet",
    "ovisualiserbarhetens": "ovisualiserbarhet",
    "ovisualiserbarhets": "ovisualiserbarhet",
    "ovisualiserbars": "ovisualiserbar",
    "ovisualiserbart": "ovisualiserbar",
    "ovisualiserbarts": "ovisualiserbar",
    "ovitaliserade": "ovitaliserad",
    "ovitaliserades": "ovitaliserad",
    "ovitaliserads": "ovitaliserad",
    "ovitaliserat": "ovitaliserad",
    "ovitaliserats": "ovitaliserad",
    "ovitaliserbara": "ovitaliserbar",
    "ovitaliserbarare": "ovitaliserbar",
    "ovitaliserbarares": "ovitaliserbar",
    "ovitaliserbaras": "ovitaliserbar",
    "ovitaliserbarast": "ovitaliserbar",
    "ovitaliserbaraste": "ovitaliserbar",
    "ovitaliserbarastes": "ovitaliserbar",
    "ovitaliserbarasts": "ovitaliserbar",
    "ovitaliserbare": "ovitaliserbar",
    "ovitaliserbares": "ovitaliserbar",
    "ovitaliserbarheten": "ovitaliserbarhet",
    "ovitaliserbarhetens": "ovitaliserbarhet",
    "ovitaliserbarhets": "ovitaliserbarhet",
    "ovitaliserbars": "ovitaliserbar",
    "ovitaliserbart": "ovitaliserbar",
    "ovitaliserbarts": "ovitaliserbar",
    "ovitaminerade": "ovitaminerad",
    "ovitaminerades": "ovitaminerad",
    "ovitaminerads": "ovitaminerad",
    "ovitaminerat": "ovitaminerad",
    "ovitaminerats": "ovitaminerad",
    "ovitaminerbara": "ovitaminerbar",
    "ovitaminerbarare": "ovitaminerbar",
    "ovitaminerbarares": "ovitaminerbar",
    "ovitaminerbaras": "ovitaminerbar",
    "ovitaminerbarast": "ovitaminerbar",
    "ovitaminerbaraste": "ovitaminerbar",
    "ovitaminerbarastes": "ovitaminerbar",
    "ovitaminerbarasts": "ovitaminerbar",
    "ovitaminerbare": "ovitaminerbar",
    "ovitaminerbares": "ovitaminerbar",
    "ovitaminerbarheten": "ovitaminerbarhet",
    "ovitaminerbarhetens": "ovitaminerbarhet",
    "ovitaminerbarhets": "ovitaminerbarhet",
    "ovitaminerbars": "ovitaminerbar",
    "ovitaminerbart": "ovitaminerbar",
    "ovitaminerbarts": "ovitaminerbar",
    "ovitaminiserade": "ovitaminiserad",
    "ovitaminiserades": "ovitaminiserad",
    "ovitaminiserads": "ovitaminiserad",
    "ovitaminiserat": "ovitaminiserad",
    "ovitaminiserats": "ovitaminiserad",
    "ovitaminiserbara": "ovitaminiserbar",
    "ovitaminiserbarare": "ovitaminiserbar",
    "ovitaminiserbarares": "ovitaminiserbar",
    "ovitaminiserbaras": "ovitaminiserbar",
    "ovitaminiserbarast": "ovitaminiserbar",
    "ovitaminiserbaraste": "ovitaminiserbar",
    "ovitaminiserbarastes": "ovitaminiserbar",
    "ovitaminiserbarasts": "ovitaminiserbar",
    "ovitaminiserbare": "ovitaminiserbar",
    "ovitaminiserbares": "ovitaminiserbar",
    "ovitaminiserbarheten": "ovitaminiserbarhet",
    "ovitaminiserbarhetens": "ovitaminiserbarhet",
    "ovitaminiserbarhets": "ovitaminiserbarhet",
    "ovitaminiserbars": "ovitaminiserbar",
    "ovitaminiserbart": "ovitaminiserbar",
    "ovitaminiserbarts": "ovitaminiserbar",
    "ovokaliserade": "ovokaliserad",
    "ovokaliserades": "ovokaliserad",
    "ovokaliserads": "ovokaliserad",
    "ovokaliserat": "ovokaliserad",
    "ovokaliserats": "ovokaliserad",
    "ovokaliserbara": "ovokaliserbar",
    "ovokaliserbarare": "ovokaliserbar",
    "ovokaliserbarares": "ovokaliserbar",
    "ovokaliserbaras": "ovokaliserbar",
    "ovokaliserbarast": "ovokaliserbar",
    "ovokaliserbaraste": "ovokaliserbar",
    "ovokaliserbarastes": "ovokaliserbar",
    "ovokaliserbarasts": "ovokaliserbar",
    "ovokaliserbare": "ovokaliserbar",
    "ovokaliserbares": "ovokaliserbar",
    "ovokaliserbarheten": "ovokaliserbarhet",
    "ovokaliserbarhetens": "ovokaliserbarhet",
    "ovokaliserbarhets": "ovokaliserbarhet",
    "ovokaliserbars": "ovokaliserbar",
    "ovokaliserbart": "ovokaliserbar",
    "ovokaliserbarts": "ovokaliserbar",
    "ovulationen": "ovulation",
    "ovulationens": "ovulation",
    "ovulationer": "ovulation",
    "ovulationerna": "ovulation",
    "ovulationernas": "ovulation",
    "ovulationers": "ovulation",
    "ovulations": "ovulation",
    "ovulgariserade": "ovulgariserad",
    "ovulgariserades": "ovulgariserad",
    "ovulgariserads": "ovulgariserad",
    "ovulgariserat": "ovulgariserad",
    "ovulgariserats": "ovulgariserad",
    "ovulgariserbara": "ovulgariserbar",
    "ovulgariserbarare": "ovulgariserbar",
    "ovulgariserbarares": "ovulgariserbar",
    "ovulgariserbaras": "ovulgariserbar",
    "ovulgariserbarast": "ovulgariserbar",
    "ovulgariserbaraste": "ovulgariserbar",
    "ovulgariserbarastes": "ovulgariserbar",
    "ovulgariserbarasts": "ovulgariserbar",
    "ovulgariserbare": "ovulgariserbar",
    "ovulgariserbares": "ovulgariserbar",
    "ovulgariserbarheten": "ovulgariserbarhet",
    "ovulgariserbarhetens": "ovulgariserbarhet",
    "ovulgariserbarhets": "ovulgariserbarhet",
    "ovulgariserbars": "ovulgariserbar",
    "ovulgariserbart": "ovulgariserbar",
    "ovulgariserbarts": "ovulgariserbar",
    "ovulkaniserade": "ovulkaniserad",
    "ovulkaniserades": "ovulkaniserad",
    "ovulkaniserads": "ovulkaniserad",
    "ovulkaniserat": "ovulkaniserad",
    "ovulkaniserats": "ovulkaniserad",
    "ovulkaniserbara": "ovulkaniserbar",
    "ovulkaniserbarare": "ovulkaniserbar",
    "ovulkaniserbarares": "ovulkaniserbar",
    "ovulkaniserbaras": "ovulkaniserbar",
    "ovulkaniserbarast": "ovulkaniserbar",
    "ovulkaniserbaraste": "ovulkaniserbar",
    "ovulkaniserbarastes": "ovulkaniserbar",
    "ovulkaniserbarasts": "ovulkaniserbar",
    "ovulkaniserbare": "ovulkaniserbar",
    "ovulkaniserbares": "ovulkaniserbar",
    "ovulkaniserbarheten": "ovulkaniserbarhet",
    "ovulkaniserbarhetens": "ovulkaniserbarhet",
    "ovulkaniserbarhets": "ovulkaniserbarhet",
    "ovulkaniserbars": "ovulkaniserbar",
    "ovulkaniserbart": "ovulkaniserbar",
    "ovulkaniserbarts": "ovulkaniserbar",
    "oväderna": "oväder",
    "ovädernas": "oväder",
    "oväders": "oväder",
    "ovädren": "oväder",
    "ovädrens": "oväder",
    "ovädret": "oväder",
    "ovädrets": "oväder",
    "ovälden": "oväld",
    "oväldens": "oväld",
    "oväldiga": "oväldig",
    "oväldigare": "oväldig",
    "oväldigares": "oväldig",
    "oväldigas": "oväldig",
    "oväldigast": "oväldig",
    "oväldigaste": "oväldig",
    "oväldigastes": "oväldig",
    "oväldigasts": "oväldig",
    "oväldige": "oväldig",
    "oväldiges": "oväldig",
    "oväldigheten": "oväldighet",
    "oväldighetens": "oväldighet",
    "oväldighets": "oväldighet",
    "oväldigs": "oväldig",
    "oväldigt": "oväldig",
    "oväldigts": "oväldig",
    "ovälds": "oväld",
    "ovälkommens": "ovälkommen",
    "ovälkommet": "ovälkommen",
    "ovälkommets": "ovälkommen",
    "ovälkomna": "ovälkommen",
    "ovälkomnare": "ovälkommen",
    "ovälkomnares": "ovälkommen",
    "ovälkomnas": "ovälkommen",
    "ovälkomnast": "ovälkommen",
    "ovälkomnaste": "ovälkommen",
    "ovälkomnastes": "ovälkommen",
    "ovälkomnasts": "ovälkommen",
    "ovälkomne": "ovälkommen",
    "ovälkomnes": "ovälkommen",
    "ovänliga": "ovänlig",
    "ovänligare": "ovänlig",
    "ovänligares": "ovänlig",
    "ovänligas": "ovänlig",
    "ovänligast": "ovänlig",
    "ovänligaste": "ovänlig",
    "ovänligastes": "ovänlig",
    "ovänligasts": "ovänlig",
    "ovänlige": "ovänlig",
    "ovänliges": "ovänlig",
    "ovänligheten": "ovänlighet",
    "ovänlighetens": "ovänlighet",
    "ovänligheter": "ovänlighet",
    "ovänligheterna": "ovänlighet",
    "ovänligheternas": "ovänlighet",
    "ovänligheters": "ovänlighet",
    "ovänlighets": "ovänlighet",
    "ovänligs": "ovänlig",
    "ovänligt": "ovänlig",
    "ovänligts": "ovänlig",
    "ovännen": "ovän",
    "ovännens": "ovän",
    "ovänner": "ovän",
    "ovännerna": "ovän",
    "ovännernas": "ovän",
    "ovänners": "ovän",
    "oväns": "ovän",
    "ovänskapen": "ovänskap",
    "ovänskapens": "ovänskap",
    "ovänskaper": "ovänskap",
    "ovänskaperna": "ovänskap",
    "ovänskapernas": "ovänskap",
    "ovänskapers": "ovänskap",
    "ovänskaps": "ovänskap",
    "oväntade": "oväntad",
    "oväntades": "oväntad",
    "oväntads": "oväntad",
    "oväntat": "oväntad",
    "oväntats": "oväntad",
    "oväpnade": "oväpnad",
    "oväpnades": "oväpnad",
    "oväpnads": "oväpnad",
    "oväpnat": "oväpnad",
    "oväpnats": "oväpnad",
    "ovärderade": "ovärderad",
    "ovärderades": "ovärderad",
    "ovärderads": "ovärderad",
    "ovärderat": "ovärderad",
    "ovärderats": "ovärderad",
    "ovärderbara": "ovärderbar",
    "ovärderbarare": "ovärderbar",
    "ovärderbarares": "ovärderbar",
    "ovärderbaras": "ovärderbar",
    "ovärderbarast": "ovärderbar",
    "ovärderbaraste": "ovärderbar",
    "ovärderbarastes": "ovärderbar",
    "ovärderbarasts": "ovärderbar",
    "ovärderbare": "ovärderbar",
    "ovärderbares": "ovärderbar",
    "ovärderbarheten": "ovärderbarhet",
    "ovärderbarhetens": "ovärderbarhet",
    "ovärderbarhets": "ovärderbarhet",
    "ovärderbars": "ovärderbar",
    "ovärderbart": "ovärderbar",
    "ovärderbarts": "ovärderbar",
    "ovärderliga": "ovärderlig",
    "ovärderligare": "ovärderlig",
    "ovärderligares": "ovärderlig",
    "ovärderligas": "ovärderlig",
    "ovärderligast": "ovärderlig",
    "ovärderligaste": "ovärderlig",
    "ovärderligastes": "ovärderlig",
    "ovärderligasts": "ovärderlig",
    "ovärderlige": "ovärderlig",
    "ovärderliges": "ovärderlig",
    "ovärderligheten": "ovärderlighet",
    "ovärderlighetens": "ovärderlighet",
    "ovärderlighets": "ovärderlighet",
    "ovärderligs": "ovärderlig",
    "ovärderligt": "ovärderlig",
    "ovärderligts": "ovärderlig",
    "ovärdiga": "ovärdig",
    "ovärdigare": "ovärdig",
    "ovärdigares": "ovärdig",
    "ovärdigas": "ovärdig",
    "ovärdigast": "ovärdig",
    "ovärdigaste": "ovärdig",
    "ovärdigastes": "ovärdig",
    "ovärdigasts": "ovärdig",
    "ovärdige": "ovärdig",
    "ovärdiges": "ovärdig",
    "ovärdigheten": "ovärdighet",
    "ovärdighetens": "ovärdighet",
    "ovärdighets": "ovärdighet",
    "ovärdigs": "ovärdig",
    "ovärdigt": "ovärdig",
    "ovärdigts": "ovärdig",
    "ovärldsliga": "ovärldslig",
    "ovärldsligare": "ovärldslig",
    "ovärldsligares": "ovärldslig",
    "ovärldsligas": "ovärldslig",
    "ovärldsligast": "ovärldslig",
    "ovärldsligaste": "ovärldslig",
    "ovärldsligastes": "ovärldslig",
    "ovärldsligasts": "ovärldslig",
    "ovärldslige": "ovärldslig",
    "ovärldsliges": "ovärldslig",
    "ovärldsligheten": "ovärldslighet",
    "ovärldslighetens": "ovärldslighet",
    "ovärldslighets": "ovärldslighet",
    "ovärldsligs": "ovärldslig",
    "ovärldsligt": "ovärldslig",
    "ovärldsligts": "ovärldslig",
    "oväsendet": "oväsen",
    "oväsendets": "oväsen",
    "oväsenet": "oväsen",
    "oväsenets": "oväsen",
    "oväsens": "oväsen",
    "oväsentliga": "oväsentlig",
    "oväsentligare": "oväsentlig",
    "oväsentligares": "oväsentlig",
    "oväsentligas": "oväsentlig",
    "oväsentligast": "oväsentlig",
    "oväsentligaste": "oväsentlig",
    "oväsentligastes": "oväsentlig",
    "oväsentligasts": "oväsentlig",
    "oväsentlige": "oväsentlig",
    "oväsentliges": "oväsentlig",
    "oväsentligheten": "oväsentlighet",
    "oväsentlighetens": "oväsentlighet",
    "oväsentligheter": "oväsentlighet",
    "oväsentligheterna": "oväsentlighet",
    "oväsentligheternas": "oväsentlighet",
    "oväsentligheters": "oväsentlighet",
    "oväsentlighets": "oväsentlighet",
    "oväsentligs": "oväsentlig",
    "oväsentligt": "oväsentlig",
    "oväsentligts": "oväsentlig",
    "ovåliga": "ovålig",
    "ovåligare": "ovålig",
    "ovåligares": "ovålig",
    "ovåligas": "ovålig",
    "ovåligast": "ovålig",
    "ovåligaste": "ovålig",
    "ovåligastes": "ovålig",
    "ovåligasts": "ovålig",
    "ovålige": "ovålig",
    "ovåliges": "ovålig",
    "ovåligheten": "ovålighet",
    "ovålighetens": "ovålighet",
    "ovålighets": "ovålighet",
    "ovåligs": "ovålig",
    "ovåligt": "ovålig",
    "ovåligts": "ovålig",
    "ovårdade": "ovårdad",
    "ovårdades": "ovårdad",
    "ovårdads": "ovårdad",
    "ovårdat": "ovårdad",
    "ovårdats": "ovårdad",
    "ox": "oxe",
    "oxalatstenar": "oxalatsten",
    "oxalatstenarna": "oxalatsten",
    "oxalatstenarnas": "oxalatsten",
    "oxalatstenars": "oxalatsten",
    "oxalatstenen": "oxalatsten",
    "oxalatstenens": "oxalatsten",
    "oxalatstens": "oxalatsten",
    "oxalsyran": "oxalsyra",
    "oxalsyrans": "oxalsyra",
    "oxalsyras": "oxalsyra",
    "oxalsyre": "oxalsyra",
    "oxalättiksyran": "oxalättiksyra",
    "oxalättiksyrans": "oxalättiksyra",
    "oxalättiksyras": "oxalättiksyra",
    "oxalättiksyre": "oxalättiksyra",
    "oxar": "oxe",
    "oxarna": "oxe",
    "oxarnas": "oxe",
    "oxars": "oxe",
    "oxblodet": "oxblod",
    "oxblodets": "oxblod",
    "oxblods": "oxblod",
    "oxblodsröda": "oxblodsröd",
    "oxblodsrödare": "oxblodsröd",
    "oxblodsrödares": "oxblodsröd",
    "oxblodsrödas": "oxblodsröd",
    "oxblodsrödast": "oxblodsröd",
    "oxblodsrödaste": "oxblodsröd",
    "oxblodsrödastes": "oxblodsröd",
    "oxblodsrödasts": "oxblodsröd",
    "oxblodsröde": "oxblodsröd",
    "oxblodsrödes": "oxblodsröd",
    "oxblodsröds": "oxblodsröd",
    "oxblodsrött": "oxblodsröd",
    "oxblodsrötts": "oxblodsröd",
    "oxbären": "oxbär",
    "oxbärens": "oxbär",
    "oxbäret": "oxbär",
    "oxbärets": "oxbär",
    "oxbärs": "oxbär",
    "oxdansen": "oxdans",
    "oxdansens": "oxdans",
    "oxdjuren": "oxdjur",
    "oxdjurens": "oxdjur",
    "oxdjuret": "oxdjur",
    "oxdjurets": "oxdjur",
    "oxdjurs": "oxdjur",
    "oxdriften": "oxdrift",
    "oxdriftens": "oxdrift",
    "oxdrifts": "oxdrift",
    "oxeln": "oxel",
    "oxelns": "oxel",
    "oxels": "oxel",
    "oxeltanden": "oxeltand",
    "oxeltandens": "oxeltand",
    "oxeltands": "oxeltand",
    "oxeltänder": "oxeltand",
    "oxeltänderna": "oxeltand",
    "oxeltändernas": "oxeltand",
    "oxeltänders": "oxeltand",
    "oxen": "oxe",
    "oxens": "oxe",
    "oxes": "oxe",
    "oxfiléer": "oxfilé",
    "oxfiléerna": "oxfilé",
    "oxfiléernas": "oxfilé",
    "oxfiléers": "oxfilé",
    "oxfilén": "oxfilé",
    "oxfiléns": "oxfilé",
    "oxfilés": "oxfilé",
    "oxfordrörelsen": "oxfordrörelse",
    "oxfordrörelsens": "oxfordrörelse",
    "oxfordrörelses": "oxfordrörelse",
    "oxfordskolan": "oxfordskola",
    "oxfordskolans": "oxfordskola",
    "oxfordskolas": "oxfordskola",
    "oxidationen": "oxidation",
    "oxidationens": "oxidation",
    "oxidationer": "oxidation",
    "oxidationerna": "oxidation",
    "oxidationernas": "oxidation",
    "oxidationers": "oxidation",
    "oxidations": "oxidation",
    "oxidationsmedels": "oxidationsmedel",
    "oxidationsmedlen": "oxidationsmedel",
    "oxidationsmedlens": "oxidationsmedel",
    "oxidationsmedlet": "oxidationsmedel",
    "oxidationsmedlets": "oxidationsmedel",
    "oxidationsreaktionen": "oxidationsreaktion",
    "oxidationsreaktionens": "oxidationsreaktion",
    "oxidationsreaktioner": "oxidationsreaktion",
    "oxidationsreaktionerna": "oxidationsreaktion",
    "oxidationsreaktionernas": "oxidationsreaktion",
    "oxidationsreaktioners": "oxidationsreaktion",
    "oxidationsreaktions": "oxidationsreaktion",
    "oxidationstalen": "oxidationstal",
    "oxidationstalens": "oxidationstal",
    "oxidationstalet": "oxidationstal",
    "oxidationstalets": "oxidationstal",
    "oxidationstals": "oxidationstal",
    "oxiden": "oxid",
    "oxidens": "oxid",
    "oxider": "oxid",
    "oxiderad": "oxidera",
    "oxiderade": "oxidera",
    "oxiderades": "oxidera",
    "oxiderads": "oxidera",
    "oxiderande": "oxidera",
    "oxideranden": "oxiderande",
    "oxiderandena": "oxiderande",
    "oxiderandenas": "oxiderande",
    "oxiderandens": "oxiderande",
    "oxiderandes": "oxiderande",
    "oxiderandet": "oxiderande",
    "oxiderandets": "oxiderande",
    "oxiderar": "oxidera",
    "oxideras": "oxidera",
    "oxiderat": "oxidera",
    "oxiderats": "oxidera",
    "oxiderbara": "oxiderbar",
    "oxiderbarare": "oxiderbar",
    "oxiderbarares": "oxiderbar",
    "oxiderbaras": "oxiderbar",
    "oxiderbarast": "oxiderbar",
    "oxiderbaraste": "oxiderbar",
    "oxiderbarastes": "oxiderbar",
    "oxiderbarasts": "oxiderbar",
    "oxiderbare": "oxiderbar",
    "oxiderbares": "oxiderbar",
    "oxiderbarheten": "oxiderbarhet",
    "oxiderbarhetens": "oxiderbarhet",
    "oxiderbarhets": "oxiderbarhet",
    "oxiderbars": "oxiderbar",
    "oxiderbart": "oxiderbar",
    "oxiderbarts": "oxiderbar",
    "oxideringar": "oxidering",
    "oxideringarna": "oxidering",
    "oxideringarnas": "oxidering",
    "oxideringars": "oxidering",
    "oxideringen": "oxidering",
    "oxideringens": "oxidering",
    "oxiderings": "oxidering",
    "oxiderna": "oxid",
    "oxidernas": "oxid",
    "oxiders": "oxid",
    "oxids": "oxid",
    "oxjärp": "oxjärpe",
    "oxjärpar": "oxjärpe",
    "oxjärparna": "oxjärpe",
    "oxjärparnas": "oxjärpe",
    "oxjärpars": "oxjärpe",
    "oxjärpen": "oxjärpe",
    "oxjärpens": "oxjärpe",
    "oxjärpes": "oxjärpe",
    "oxjärps": "oxjärpe",
    "oxköttet": "oxkött",
    "oxköttets": "oxkött",
    "oxkötts": "oxkött",
    "oxlar": "oxel",
    "oxlarna": "oxel",
    "oxlarnas": "oxel",
    "oxlars": "oxel",
    "oxläders": "oxläder",
    "oxlädret": "oxläder",
    "oxlädrets": "oxläder",
    "oxläggar": "oxlägg",
    "oxläggarna": "oxlägg",
    "oxläggarnas": "oxlägg",
    "oxläggars": "oxlägg",
    "oxläggen": "oxlägg",
    "oxläggens": "oxlägg",
    "oxläggs": "oxlägg",
    "oxrouladen": "oxroulad",
    "oxrouladens": "oxroulad",
    "oxroulader": "oxroulad",
    "oxrouladerna": "oxroulad",
    "oxrouladernas": "oxroulad",
    "oxrouladers": "oxroulad",
    "oxroulads": "oxroulad",
    "oxrulladen": "oxrullad",
    "oxrulladens": "oxrullad",
    "oxrullader": "oxrullad",
    "oxrulladerna": "oxrullad",
    "oxrulladernas": "oxrullad",
    "oxrulladers": "oxrullad",
    "oxrullads": "oxrullad",
    "oxstekar": "oxstek",
    "oxstekarna": "oxstek",
    "oxstekarnas": "oxstek",
    "oxstekars": "oxstek",
    "oxsteken": "oxstek",
    "oxstekens": "oxstek",
    "oxsteks": "oxstek",
    "oxstyngen": "oxstyng",
    "oxstyngens": "oxstyng",
    "oxstynget": "oxstyng",
    "oxstyngets": "oxstyng",
    "oxstyngs": "oxstyng",
    "oxtungan": "oxtunga",
    "oxtungans": "oxtunga",
    "oxtungas": "oxtunga",
    "oxtunge": "oxtunga",
    "oxtungo": "oxtunga",
    "oxtungor": "oxtunga",
    "oxtungorna": "oxtunga",
    "oxtungornas": "oxtunga",
    "oxtungors": "oxtunga",
    "oxtungsvampar": "oxtungsvamp",
    "oxtungsvamparna": "oxtungsvamp",
    "oxtungsvamparnas": "oxtungsvamp",
    "oxtungsvampars": "oxtungsvamp",
    "oxtungsvampen": "oxtungsvamp",
    "oxtungsvampens": "oxtungsvamp",
    "oxtungsvamps": "oxtungsvamp",
    "oxvandringar": "oxvandring",
    "oxvandringarna": "oxvandring",
    "oxvandringarnas": "oxvandring",
    "oxvandringars": "oxvandring",
    "oxvandringen": "oxvandring",
    "oxvandringens": "oxvandring",
    "oxvandrings": "oxvandring",
    "oxveck": "oxvecka",
    "oxveckan": "oxvecka",
    "oxveckans": "oxvecka",
    "oxveckas": "oxvecka",
    "oxvecke": "oxvecka",
    "oxvecko": "oxvecka",
    "oxveckor": "oxvecka",
    "oxveckorna": "oxvecka",
    "oxveckornas": "oxvecka",
    "oxveckors": "oxvecka",
    "oxvecks": "oxvecka",
    "oxygenet": "oxygen",
    "oxygenets": "oxygen",
    "oxygens": "oxygen",
    "oxytocinen": "oxytocin",
    "oxytocinens": "oxytocin",
    "oxytociner": "oxytocin",
    "oxytocinerna": "oxytocin",
    "oxytocinernas": "oxytocin",
    "oxytociners": "oxytocin",
    "oxytocinet": "oxytocin",
    "oxytocinets": "oxytocin",
    "oxytocins": "oxytocin",
    "oxögas": "oxöga",
    "oxögat": "oxöga",
    "oxögats": "oxöga",
    "oxögon": "oxöga",
    "oxögonen": "oxöga",
    "oxögonens": "oxöga",
    "oxögons": "oxöga",
    "ozeloten": "ozelot",
    "ozelotens": "ozelot",
    "ozeloter": "ozelot",
    "ozeloterna": "ozelot",
    "ozeloternas": "ozelot",
    "ozeloters": "ozelot",
    "ozelots": "ozelot",
    "ozokeriten": "ozokerit",
    "ozokeritens": "ozokerit",
    "ozokerits": "ozokerit",
    "ozonen": "ozon",
    "ozonens": "ozon",
    "ozonet": "ozon",
    "ozonets": "ozon",
    "ozonhalten": "ozonhalt",
    "ozonhaltens": "ozonhalt",
    "ozonhalter": "ozonhalt",
    "ozonhalterna": "ozonhalt",
    "ozonhalternas": "ozonhalt",
    "ozonhalters": "ozonhalt",
    "ozonhalts": "ozonhalt",
    "ozonlagerna": "ozonlager",
    "ozonlagernas": "ozonlager",
    "ozonlagers": "ozonlager",
    "ozonlagren": "ozonlager",
    "ozonlagrens": "ozonlager",
    "ozonlagret": "ozonlager",
    "ozonlagrets": "ozonlager",
    "ozonminskningar": "ozonminskning",
    "ozonminskningarna": "ozonminskning",
    "ozonminskningarnas": "ozonminskning",
    "ozonminskningars": "ozonminskning",
    "ozonminskningen": "ozonminskning",
    "ozonminskningens": "ozonminskning",
    "ozonminsknings": "ozonminskning",
    "ozonmolekylen": "ozonmolekyl",
    "ozonmolekylens": "ozonmolekyl",
    "ozonmolekyler": "ozonmolekyl",
    "ozonmolekylerna": "ozonmolekyl",
    "ozonmolekylernas": "ozonmolekyl",
    "ozonmolekylers": "ozonmolekyl",
    "ozonmolekyls": "ozonmolekyl",
    "ozonmängden": "ozonmängd",
    "ozonmängdens": "ozonmängd",
    "ozonmängder": "ozonmängd",
    "ozonmängderna": "ozonmängd",
    "ozonmängdernas": "ozonmängd",
    "ozonmängders": "ozonmängd",
    "ozonmängds": "ozonmängd",
    "ozonreduktionen": "ozonreduktion",
    "ozonreduktionens": "ozonreduktion",
    "ozonreduktioner": "ozonreduktion",
    "ozonreduktionerna": "ozonreduktion",
    "ozonreduktionernas": "ozonreduktion",
    "ozonreduktioners": "ozonreduktion",
    "ozonreduktions": "ozonreduktion",
    "ozons": "ozon",
    "ozonskikten": "ozonskikt",
    "ozonskiktens": "ozonskikt",
    "ozonskiktet": "ozonskikt",
    "ozonskiktets": "ozonskikt",
    "ozonskikts": "ozonskikt",
    "oädela": "oädel",
    "oädelare": "oädel",
    "oädelares": "oädel",
    "oädelas": "oädel",
    "oädelast": "oädel",
    "oädelaste": "oädel",
    "oädelastes": "oädel",
    "oädelasts": "oädel",
    "oädele": "oädel",
    "oädeles": "oädel",
    "oädels": "oädel",
    "oädelt": "oädel",
    "oädelts": "oädel",
    "oälskade": "oälskad",
    "oälskades": "oälskad",
    "oälskads": "oälskad",
    "oälskat": "oälskad",
    "oälskats": "oälskad",
    "oändliga": "oändlig",
    "oändligare": "oändlig",
    "oändligares": "oändlig",
    "oändligas": "oändlig",
    "oändligast": "oändlig",
    "oändligaste": "oändlig",
    "oändligastes": "oändlig",
    "oändligasts": "oändlig",
    "oändlige": "oändlig",
    "oändliges": "oändlig",
    "oändligheten": "oändlighet",
    "oändlighetens": "oändlighet",
    "oändligheter": "oändlighet",
    "oändligheterna": "oändlighet",
    "oändligheternas": "oändlighet",
    "oändligheters": "oändlighet",
    "oändlighets": "oändlighet",
    "oändlighetslängtans": "oändlighetslängtan",
    "oändligs": "oändlig",
    "oändligt": "oändlig",
    "oändligts": "oändlig",
    "oärliga": "oärlig",
    "oärligare": "oärlig",
    "oärligares": "oärlig",
    "oärligas": "oärlig",
    "oärligast": "oärlig",
    "oärligaste": "oärlig",
    "oärligastes": "oärlig",
    "oärligasts": "oärlig",
    "oärlige": "oärlig",
    "oärliges": "oärlig",
    "oärligheten": "oärlighet",
    "oärlighetens": "oärlighet",
    "oärligheter": "oärlighet",
    "oärligheterna": "oärlighet",
    "oärligheternas": "oärlighet",
    "oärligheters": "oärlighet",
    "oärlighets": "oärlighet",
    "oärligs": "oärlig",
    "oärligt": "oärlig",
    "oärligts": "oärlig",
    "oätbara": "oätbar",
    "oätbarare": "oätbar",
    "oätbarares": "oätbar",
    "oätbaras": "oätbar",
    "oätbarast": "oätbar",
    "oätbaraste": "oätbar",
    "oätbarastes": "oätbar",
    "oätbarasts": "oätbar",
    "oätbare": "oätbar",
    "oätbares": "oätbar",
    "oätbarheten": "oätbarhet",
    "oätbarhetens": "oätbarhet",
    "oätbarhets": "oätbarhet",
    "oätbars": "oätbar",
    "oätbart": "oätbar",
    "oätbarts": "oätbar",
    "oätliga": "oätlig",
    "oätligare": "oätlig",
    "oätligares": "oätlig",
    "oätligas": "oätlig",
    "oätligast": "oätlig",
    "oätligaste": "oätlig",
    "oätligastes": "oätlig",
    "oätligasts": "oätlig",
    "oätlige": "oätlig",
    "oätliges": "oätlig",
    "oätligheten": "oätlighet",
    "oätlighetens": "oätlighet",
    "oätlighets": "oätlighet",
    "oätligs": "oätlig",
    "oätligt": "oätlig",
    "oätligts": "oätlig",
    "oåterinstallerbara": "oåterinstallerbar",
    "oåterinstallerbarare": "oåterinstallerbar",
    "oåterinstallerbarares": "oåterinstallerbar",
    "oåterinstallerbaras": "oåterinstallerbar",
    "oåterinstallerbarast": "oåterinstallerbar",
    "oåterinstallerbaraste": "oåterinstallerbar",
    "oåterinstallerbarastes": "oåterinstallerbar",
    "oåterinstallerbarasts": "oåterinstallerbar",
    "oåterinstallerbare": "oåterinstallerbar",
    "oåterinstallerbares": "oåterinstallerbar",
    "oåterinstallerbarheten": "oåterinstallerbarhet",
    "oåterinstallerbarhetens": "oåterinstallerbarhet",
    "oåterinstallerbarhets": "oåterinstallerbarhet",
    "oåterinstallerbars": "oåterinstallerbar",
    "oåterinstallerbart": "oåterinstallerbar",
    "oåterinstallerbarts": "oåterinstallerbar",
    "oåterkalleliga": "oåterkallelig",
    "oåterkalleligare": "oåterkallelig",
    "oåterkalleligares": "oåterkallelig",
    "oåterkalleligas": "oåterkallelig",
    "oåterkalleligast": "oåterkallelig",
    "oåterkalleligaste": "oåterkallelig",
    "oåterkalleligastes": "oåterkallelig",
    "oåterkalleligasts": "oåterkallelig",
    "oåterkallelige": "oåterkallelig",
    "oåterkalleliges": "oåterkallelig",
    "oåterkalleligheten": "oåterkallelighet",
    "oåterkallelighetens": "oåterkallelighet",
    "oåterkallelighets": "oåterkallelighet",
    "oåterkalleligs": "oåterkallelig",
    "oåterkalleligt": "oåterkallelig",
    "oåterkalleligts": "oåterkallelig",
    "oåtkomliga": "oåtkomlig",
    "oåtkomligare": "oåtkomlig",
    "oåtkomligares": "oåtkomlig",
    "oåtkomligas": "oåtkomlig",
    "oåtkomligast": "oåtkomlig",
    "oåtkomligaste": "oåtkomlig",
    "oåtkomligastes": "oåtkomlig",
    "oåtkomligasts": "oåtkomlig",
    "oåtkomlige": "oåtkomlig",
    "oåtkomliges": "oåtkomlig",
    "oåtkomligheten": "oåtkomlighet",
    "oåtkomlighetens": "oåtkomlighet",
    "oåtkomligheter": "oåtkomlighet",
    "oåtkomligheterna": "oåtkomlighet",
    "oåtkomligheternas": "oåtkomlighet",
    "oåtkomligheters": "oåtkomlighet",
    "oåtkomlighets": "oåtkomlighet",
    "oåtkomligs": "oåtkomlig",
    "oåtkomligt": "oåtkomlig",
    "oåtkomligts": "oåtkomlig",
    "oömheten": "oömhet",
    "oömhetens": "oömhet",
    "oömhets": "oömhet",
    "oömma": "oöm",
    "oömmare": "oöm",
    "oömmares": "oöm",
    "oömmas": "oöm",
    "oömmast": "oöm",
    "oömmaste": "oöm",
    "oömmastes": "oöm",
    "oömmasts": "oöm",
    "oömme": "oöm",
    "oömmes": "oöm",
    "oöms": "oöm",
    "oömt": "oöm",
    "oömts": "oöm",
    "oönskade": "oönskad",
    "oönskades": "oönskad",
    "oönskads": "oönskad",
    "oönskat": "oönskad",
    "oönskats": "oönskad",
    "oöverbryggliga": "oöverbrygglig",
    "oöverbryggligare": "oöverbrygglig",
    "oöverbryggligares": "oöverbrygglig",
    "oöverbryggligas": "oöverbrygglig",
    "oöverbryggligast": "oöverbrygglig",
    "oöverbryggligaste": "oöverbrygglig",
    "oöverbryggligastes": "oöverbrygglig",
    "oöverbryggligasts": "oöverbrygglig",
    "oöverbrygglige": "oöverbrygglig",
    "oöverbryggliges": "oöverbrygglig",
    "oöverbryggligheten": "oöverbrygglighet",
    "oöverbrygglighetens": "oöverbrygglighet",
    "oöverbrygglighets": "oöverbrygglighet",
    "oöverbryggligs": "oöverbrygglig",
    "oöverbryggligt": "oöverbrygglig",
    "oöverbryggligts": "oöverbrygglig",
    "oöverdimensionerbara": "oöverdimensionerbar",
    "oöverdimensionerbarare": "oöverdimensionerbar",
    "oöverdimensionerbarares": "oöverdimensionerbar",
    "oöverdimensionerbaras": "oöverdimensionerbar",
    "oöverdimensionerbarast": "oöverdimensionerbar",
    "oöverdimensionerbaraste": "oöverdimensionerbar",
    "oöverdimensionerbarastes": "oöverdimensionerbar",
    "oöverdimensionerbarasts": "oöverdimensionerbar",
    "oöverdimensionerbare": "oöverdimensionerbar",
    "oöverdimensionerbares": "oöverdimensionerbar",
    "oöverdimensionerbarheten": "oöverdimensionerbarhet",
    "oöverdimensionerbarhetens": "oöverdimensionerbarhet",
    "oöverdimensionerbarhets": "oöverdimensionerbarhet",
    "oöverdimensionerbars": "oöverdimensionerbar",
    "oöverdimensionerbart": "oöverdimensionerbar",
    "oöverdimensionerbarts": "oöverdimensionerbar",
    "oöverdoserbara": "oöverdoserbar",
    "oöverdoserbarare": "oöverdoserbar",
    "oöverdoserbarares": "oöverdoserbar",
    "oöverdoserbaras": "oöverdoserbar",
    "oöverdoserbarast": "oöverdoserbar",
    "oöverdoserbaraste": "oöverdoserbar",
    "oöverdoserbarastes": "oöverdoserbar",
    "oöverdoserbarasts": "oöverdoserbar",
    "oöverdoserbare": "oöverdoserbar",
    "oöverdoserbares": "oöverdoserbar",
    "oöverdoserbarheten": "oöverdoserbarhet",
    "oöverdoserbarhetens": "oöverdoserbarhet",
    "oöverdoserbarhets": "oöverdoserbarhet",
    "oöverdoserbars": "oöverdoserbar",
    "oöverdoserbart": "oöverdoserbar",
    "oöverdoserbarts": "oöverdoserbar",
    "oöverexponerbara": "oöverexponerbar",
    "oöverexponerbarare": "oöverexponerbar",
    "oöverexponerbarares": "oöverexponerbar",
    "oöverexponerbaras": "oöverexponerbar",
    "oöverexponerbarast": "oöverexponerbar",
    "oöverexponerbaraste": "oöverexponerbar",
    "oöverexponerbarastes": "oöverexponerbar",
    "oöverexponerbarasts": "oöverexponerbar",
    "oöverexponerbare": "oöverexponerbar",
    "oöverexponerbares": "oöverexponerbar",
    "oöverexponerbarheten": "oöverexponerbarhet",
    "oöverexponerbarhetens": "oöverexponerbarhet",
    "oöverexponerbarhets": "oöverexponerbarhet",
    "oöverexponerbars": "oöverexponerbar",
    "oöverexponerbart": "oöverexponerbar",
    "oöverexponerbarts": "oöverexponerbar",
    "oöverkomliga": "oöverkomlig",
    "oöverkomligare": "oöverkomlig",
    "oöverkomligares": "oöverkomlig",
    "oöverkomligas": "oöverkomlig",
    "oöverkomligast": "oöverkomlig",
    "oöverkomligaste": "oöverkomlig",
    "oöverkomligastes": "oöverkomlig",
    "oöverkomligasts": "oöverkomlig",
    "oöverkomlige": "oöverkomlig",
    "oöverkomliges": "oöverkomlig",
    "oöverkomligheten": "oöverkomlighet",
    "oöverkomlighetens": "oöverkomlighet",
    "oöverkomlighets": "oöverkomlighet",
    "oöverkomligs": "oöverkomlig",
    "oöverkomligt": "oöverkomlig",
    "oöverkomligts": "oöverkomlig",
    "oöverkompenserbara": "oöverkompenserbar",
    "oöverkompenserbarare": "oöverkompenserbar",
    "oöverkompenserbarares": "oöverkompenserbar",
    "oöverkompenserbaras": "oöverkompenserbar",
    "oöverkompenserbarast": "oöverkompenserbar",
    "oöverkompenserbaraste": "oöverkompenserbar",
    "oöverkompenserbarastes": "oöverkompenserbar",
    "oöverkompenserbarasts": "oöverkompenserbar",
    "oöverkompenserbare": "oöverkompenserbar",
    "oöverkompenserbares": "oöverkompenserbar",
    "oöverkompenserbarheten": "oöverkompenserbarhet",
    "oöverkompenserbarhetens": "oöverkompenserbarhet",
    "oöverkompenserbarhets": "oöverkompenserbarhet",
    "oöverkompenserbars": "oöverkompenserbar",
    "oöverkompenserbart": "oöverkompenserbar",
    "oöverkompenserbarts": "oöverkompenserbar",
    "oöverlagda": "oöverlagd",
    "oöverlagdare": "oöverlagd",
    "oöverlagdares": "oöverlagd",
    "oöverlagdas": "oöverlagd",
    "oöverlagdast": "oöverlagd",
    "oöverlagdaste": "oöverlagd",
    "oöverlagdastes": "oöverlagd",
    "oöverlagdasts": "oöverlagd",
    "oöverlagde": "oöverlagd",
    "oöverlagdes": "oöverlagd",
    "oöverlagdheten": "oöverlagdhet",
    "oöverlagdhetens": "oöverlagdhet",
    "oöverlagdhets": "oöverlagdhet",
    "oöverlagds": "oöverlagd",
    "oöverlagt": "oöverlagd",
    "oöverlagts": "oöverlagd",
    "oöverskådliga": "oöverskådlig",
    "oöverskådligare": "oöverskådlig",
    "oöverskådligares": "oöverskådlig",
    "oöverskådligas": "oöverskådlig",
    "oöverskådligast": "oöverskådlig",
    "oöverskådligaste": "oöverskådlig",
    "oöverskådligastes": "oöverskådlig",
    "oöverskådligasts": "oöverskådlig",
    "oöverskådlige": "oöverskådlig",
    "oöverskådliges": "oöverskådlig",
    "oöverskådligheten": "oöverskådlighet",
    "oöverskådlighetens": "oöverskådlighet",
    "oöverskådlighets": "oöverskådlighet",
    "oöverskådligs": "oöverskådlig",
    "oöverskådligt": "oöverskådlig",
    "oöverskådligts": "oöverskådlig",
    "oöverstigliga": "oöverstiglig",
    "oöverstigligare": "oöverstiglig",
    "oöverstigligares": "oöverstiglig",
    "oöverstigligas": "oöverstiglig",
    "oöverstigligast": "oöverstiglig",
    "oöverstigligaste": "oöverstiglig",
    "oöverstigligastes": "oöverstiglig",
    "oöverstigligasts": "oöverstiglig",
    "oöverstiglige": "oöverstiglig",
    "oöverstigliges": "oöverstiglig",
    "oöverstigligheten": "oöverstiglighet",
    "oöverstiglighetens": "oöverstiglighet",
    "oöverstiglighets": "oöverstiglighet",
    "oöverstigligs": "oöverstiglig",
    "oöverstigligt": "oöverstiglig",
    "oöverstigligts": "oöverstiglig",
    "oöversättliga": "oöversättlig",
    "oöversättligare": "oöversättlig",
    "oöversättligares": "oöversättlig",
    "oöversättligas": "oöversättlig",
    "oöversättligast": "oöversättlig",
    "oöversättligaste": "oöversättlig",
    "oöversättligastes": "oöversättlig",
    "oöversättligasts": "oöversättlig",
    "oöversättlige": "oöversättlig",
    "oöversättliges": "oöversättlig",
    "oöversättligheten": "oöversättlighet",
    "oöversättlighetens": "oöversättlighet",
    "oöversättlighets": "oöversättlighet",
    "oöversättligs": "oöversättlig",
    "oöversättligt": "oöversättlig",
    "oöversättligts": "oöversättlig",
    "oövertrasserbara": "oövertrasserbar",
    "oövertrasserbarare": "oövertrasserbar",
    "oövertrasserbarares": "oövertrasserbar",
    "oövertrasserbaras": "oövertrasserbar",
    "oövertrasserbarast": "oövertrasserbar",
    "oövertrasserbaraste": "oövertrasserbar",
    "oövertrasserbarastes": "oövertrasserbar",
    "oövertrasserbarasts": "oövertrasserbar",
    "oövertrasserbare": "oövertrasserbar",
    "oövertrasserbares": "oövertrasserbar",
    "oövertrasserbarheten": "oövertrasserbarhet",
    "oövertrasserbarhetens": "oövertrasserbarhet",
    "oövertrasserbarhets": "oövertrasserbarhet",
    "oövertrasserbars": "oövertrasserbar",
    "oövertrasserbart": "oövertrasserbar",
    "oövertrasserbarts": "oövertrasserbar",
    "oöverträffade": "oöverträffad",
    "oöverträffades": "oöverträffad",
    "oöverträffads": "oöverträffad",
    "oöverträffat": "oöverträffad",
    "oöverträffats": "oöverträffad",
    "oöverträffliga": "oöverträfflig",
    "oöverträffligare": "oöverträfflig",
    "oöverträffligares": "oöverträfflig",
    "oöverträffligas": "oöverträfflig",
    "oöverträffligast": "oöverträfflig",
    "oöverträffligaste": "oöverträfflig",
    "oöverträffligastes": "oöverträfflig",
    "oöverträffligasts": "oöverträfflig",
    "oöverträfflige": "oöverträfflig",
    "oöverträffliges": "oöverträfflig",
    "oöverträffligheten": "oöverträfflighet",
    "oöverträfflighetens": "oöverträfflighet",
    "oöverträfflighets": "oöverträfflighet",
    "oöverträffligs": "oöverträfflig",
    "oöverträffligt": "oöverträfflig",
    "oöverträffligts": "oöverträfflig",
    "oövertänkta": "oövertänkt",
    "oövertänktare": "oövertänkt",
    "oövertänktares": "oövertänkt",
    "oövertänktas": "oövertänkt",
    "oövertänktast": "oövertänkt",
    "oövertänktaste": "oövertänkt",
    "oövertänktastes": "oövertänkt",
    "oövertänktasts": "oövertänkt",
    "oövertänkte": "oövertänkt",
    "oövertänktes": "oövertänkt",
    "oövertänktheten": "oövertänkthet",
    "oövertänkthetens": "oövertänkthet",
    "oövertänkthets": "oövertänkthet",
    "oövertänkts": "oövertänkt",
    "oövervinneliga": "oövervinnelig",
    "oövervinneligare": "oövervinnelig",
    "oövervinneligares": "oövervinnelig",
    "oövervinneligas": "oövervinnelig",
    "oövervinneligast": "oövervinnelig",
    "oövervinneligaste": "oövervinnelig",
    "oövervinneligastes": "oövervinnelig",
    "oövervinneligasts": "oövervinnelig",
    "oövervinnelige": "oövervinnelig",
    "oövervinneliges": "oövervinnelig",
    "oövervinneligheten": "oövervinnelighet",
    "oövervinnelighetens": "oövervinnelighet",
    "oövervinnelighets": "oövervinnelighet",
    "oövervinneligs": "oövervinnelig",
    "oövervinneligt": "oövervinnelig",
    "oövervinneligts": "oövervinnelig",
    "oövervinnerliga": "oövervinnerlig",
    "oövervinnerligare": "oövervinnerlig",
    "oövervinnerligares": "oövervinnerlig",
    "oövervinnerligas": "oövervinnerlig",
    "oövervinnerligast": "oövervinnerlig",
    "oövervinnerligaste": "oövervinnerlig",
    "oövervinnerligastes": "oövervinnerlig",
    "oövervinnerligasts": "oövervinnerlig",
    "oövervinnerlige": "oövervinnerlig",
    "oövervinnerliges": "oövervinnerlig",
    "oövervinnerligheten": "oövervinnerlighet",
    "oövervinnerlighetens": "oövervinnerlighet",
    "oövervinnerlighets": "oövervinnerlighet",
    "oövervinnerligs": "oövervinnerlig",
    "oövervinnerligt": "oövervinnerlig",
    "oövervinnerligts": "oövervinnerlig",
    "oövervinnliga": "oövervinnlig",
    "oövervinnligare": "oövervinnlig",
    "oövervinnligares": "oövervinnlig",
    "oövervinnligas": "oövervinnlig",
    "oövervinnligast": "oövervinnlig",
    "oövervinnligaste": "oövervinnlig",
    "oövervinnligastes": "oövervinnlig",
    "oövervinnligasts": "oövervinnlig",
    "oövervinnlige": "oövervinnlig",
    "oövervinnliges": "oövervinnlig",
    "oövervinnligheten": "oövervinnlighet",
    "oövervinnlighetens": "oövervinnlighet",
    "oövervinnlighets": "oövervinnlighet",
    "oövervinnligs": "oövervinnlig",
    "oövervinnligt": "oövervinnlig",
    "oövervinnligts": "oövervinnlig",
    "oövervägda": "oövervägd",
    "oövervägdare": "oövervägd",
    "oövervägdares": "oövervägd",
    "oövervägdas": "oövervägd",
    "oövervägdast": "oövervägd",
    "oövervägdaste": "oövervägd",
    "oövervägdastes": "oövervägd",
    "oövervägdasts": "oövervägd",
    "oövervägde": "oövervägd",
    "oövervägdes": "oövervägd",
    "oövervägds": "oövervägd",
    "oövervägt": "oövervägd",
    "oövervägts": "oövervägd",
    "oövervärderbara": "oövervärderbar",
    "oövervärderbarare": "oövervärderbar",
    "oövervärderbarares": "oövervärderbar",
    "oövervärderbaras": "oövervärderbar",
    "oövervärderbarast": "oövervärderbar",
    "oövervärderbaraste": "oövervärderbar",
    "oövervärderbarastes": "oövervärderbar",
    "oövervärderbarasts": "oövervärderbar",
    "oövervärderbare": "oövervärderbar",
    "oövervärderbares": "oövervärderbar",
    "oövervärderbarheten": "oövervärderbarhet",
    "oövervärderbarhetens": "oövervärderbarhet",
    "oövervärderbarhets": "oövervärderbarhet",
    "oövervärderbars": "oövervärderbar",
    "oövervärderbart": "oövervärderbar",
    "oövervärderbarts": "oövervärderbar",
    "p-et": "p",
    "p-ets": "p",
    "p-n": "p",
    "p-na": "p",
    "p-nas": "p",
    "p-ns": "p",
    "p-pillerna": "p-piller",
    "p-pillernas": "p-piller",
    "p-pillers": "p-piller",
    "p-pillren": "p-piller",
    "p-pillrens": "p-piller",
    "p-pillret": "p-piller",
    "p-pillrets": "p-piller",
    "p-platsen": "p-plats",
    "p-platsens": "p-plats",
    "p-platser": "p-plats",
    "p-platserna": "p-plats",
    "p-platsernas": "p-plats",
    "p-platsers": "p-plats",
    "p-rull": "p-rulle",
    "p-rullar": "p-rulle",
    "p-rullarna": "p-rulle",
    "p-rullarnas": "p-rulle",
    "p-rullars": "p-rulle",
    "p-rullen": "p-rulle",
    "p-rullens": "p-rulle",
    "p-rulles": "p-rulle",
    "p-rulls": "p-rulle",
    "p-t": "p",
    "p-ts": "p",
    "p:et": "p",
    "p:ets": "p",
    "p:n": "p",
    "p:na": "p",
    "p:nas": "p",
    "p:ns": "p",
    "p:s": "p",
    "p:t": "p",
    "p:ts": "p",
    "pH-er": "pH",
    "pH-erna": "pH",
    "pH-ernas": "pH",
    "pH-ers": "pH",
    "pH-n": "pH",
    "pH-na": "pH",
    "pH-nas": "pH",
    "pH-ns": "pH",
    "pH-s": "pH",
    "pH-t": "pH",
    "pH-ts": "pH",
    "pH-värden": "pH-värde",
    "pH-värdena": "pH-värde",
    "pH-värdenas": "pH-värde",
    "pH-värdens": "pH-värde",
    "pH-värdes": "pH-värde",
    "pH-värdet": "pH-värde",
    "pH-värdets": "pH-värde",
    "pH:er": "pH",
    "pH:erna": "pH",
    "pH:ernas": "pH",
    "pH:ers": "pH",
    "pH:n": "pH",
    "pH:na": "pH",
    "pH:nas": "pH",
    "pH:ns": "pH",
    "pH:s": "pH",
    "pH:t": "pH",
    "pH:ts": "pH",
    "pHer": "pH",
    "pHerna": "pH",
    "pHernas": "pH",
    "pHers": "pH",
    "pHn": "pH",
    "pHna": "pH",
    "pHnas": "pH",
    "pHns": "pH",
    "pHs": "pH",
    "pHt": "pH",
    "pHts": "pH",
    "pacemakern": "pacemaker",
    "pacemakerna": "pacemaker",
    "pacemakernas": "pacemaker",
    "pacemakerns": "pacemaker",
    "pacemakers": "pacemaker",
    "pacemakrar": "pacemaker",
    "pacemakrarna": "pacemaker",
    "pacemakrarnas": "pacemaker",
    "pacemakrars": "pacemaker",
    "pacificerad": "pacificera",
    "pacificerade": "pacificera",
    "pacificerades": "pacificera",
    "pacificerads": "pacificera",
    "pacificerande": "pacificera",
    "pacificeranden": "pacificerande",
    "pacificerandena": "pacificerande",
    "pacificerandenas": "pacificerande",
    "pacificerandens": "pacificerande",
    "pacificerandes": "pacificerande",
    "pacificerandet": "pacificerande",
    "pacificerandets": "pacificerande",
    "pacificerar": "pacificera",
    "pacificeras": "pacificera",
    "pacificerat": "pacificera",
    "pacificerats": "pacificera",
    "pacificerbara": "pacificerbar",
    "pacificerbarare": "pacificerbar",
    "pacificerbarares": "pacificerbar",
    "pacificerbaras": "pacificerbar",
    "pacificerbarast": "pacificerbar",
    "pacificerbaraste": "pacificerbar",
    "pacificerbarastes": "pacificerbar",
    "pacificerbarasts": "pacificerbar",
    "pacificerbare": "pacificerbar",
    "pacificerbares": "pacificerbar",
    "pacificerbarheten": "pacificerbarhet",
    "pacificerbarhetens": "pacificerbarhet",
    "pacificerbarhets": "pacificerbarhet",
    "pacificerbars": "pacificerbar",
    "pacificerbart": "pacificerbar",
    "pacificerbarts": "pacificerbar",
    "pacificeringar": "pacificering",
    "pacificeringarna": "pacificering",
    "pacificeringarnas": "pacificering",
    "pacificeringars": "pacificering",
    "pacificeringen": "pacificering",
    "pacificeringens": "pacificering",
    "pacificerings": "pacificering",
    "pacifismen": "pacifism",
    "pacifismens": "pacifism",
    "pacifismer": "pacifism",
    "pacifismerna": "pacifism",
    "pacifismernas": "pacifism",
    "pacifismers": "pacifism",
    "pacifisms": "pacifism",
    "pacifisten": "pacifist",
    "pacifistens": "pacifist",
    "pacifister": "pacifist",
    "pacifisterna": "pacifist",
    "pacifisternas": "pacifist",
    "pacifisters": "pacifist",
    "pacifistiska": "pacifistisk",
    "pacifistiskare": "pacifistisk",
    "pacifistiskares": "pacifistisk",
    "pacifistiskas": "pacifistisk",
    "pacifistiskast": "pacifistisk",
    "pacifistiskaste": "pacifistisk",
    "pacifistiskastes": "pacifistisk",
    "pacifistiskasts": "pacifistisk",
    "pacifistiske": "pacifistisk",
    "pacifistiskes": "pacifistisk",
    "pacifistisks": "pacifistisk",
    "pacifistiskt": "pacifistisk",
    "pacifistiskts": "pacifistisk",
    "pacifists": "pacifist",
    "pack": "packe",
    "packad": "packa",
    "packade": "packad",
    "packades": "packad",
    "packads": "packad",
    "packande": "packa",
    "packanden": "packande",
    "packandena": "packande",
    "packandenas": "packande",
    "packandens": "packande",
    "packandes": "packande",
    "packandet": "packande",
    "packandets": "packande",
    "packar": "packe",
    "packarna": "packe",
    "packarnas": "packe",
    "packars": "packe",
    "packas": "packa",
    "packat": "packad",
    "packats": "packad",
    "packboxar": "packbox",
    "packboxarna": "packbox",
    "packboxarnas": "packbox",
    "packboxars": "packbox",
    "packboxen": "packbox",
    "packboxens": "packbox",
    "packdjuren": "packdjur",
    "packdjurens": "packdjur",
    "packdjuret": "packdjur",
    "packdjurets": "packdjur",
    "packdjurs": "packdjur",
    "packen": "packe",
    "packens": "packe",
    "packes": "packe",
    "packet": "pack",
    "packets": "pack",
    "packhusen": "packhus",
    "packhusens": "packhus",
    "packhuset": "packhus",
    "packhusets": "packhus",
    "packisen": "packis",
    "packisens": "packis",
    "packkorgar": "packkorg",
    "packkorgarna": "packkorg",
    "packkorgarnas": "packkorg",
    "packkorgars": "packkorg",
    "packkorgen": "packkorg",
    "packkorgens": "packkorg",
    "packkorgs": "packkorg",
    "packlårar": "packlår",
    "packlårarna": "packlår",
    "packlårarnas": "packlår",
    "packlårars": "packlår",
    "packlåren": "packlår",
    "packlårens": "packlår",
    "packlårs": "packlår",
    "packningar": "packning",
    "packningarna": "packning",
    "packningarnas": "packning",
    "packningars": "packning",
    "packningen": "packning",
    "packningens": "packning",
    "packnings": "packning",
    "packningsdos": "packningsdosa",
    "packningsdosan": "packningsdosa",
    "packningsdosans": "packningsdosa",
    "packningsdosas": "packningsdosa",
    "packningsdose": "packningsdosa",
    "packningsdosor": "packningsdosa",
    "packningsdosorna": "packningsdosa",
    "packningsdosornas": "packningsdosa",
    "packningsdosors": "packningsdosa",
    "packs": "packe",
    "packsadeln": "packsadel",
    "packsadelns": "packsadel",
    "packsadels": "packsadel",
    "packsadlar": "packsadel",
    "packsadlarna": "packsadel",
    "packsadlarnas": "packsadel",
    "packsadlars": "packsadel",
    "packåsnan": "packåsna",
    "packåsnans": "packåsna",
    "packåsnas": "packåsna",
    "packåsne": "packåsna",
    "packåsnor": "packåsna",
    "packåsnorna": "packåsna",
    "packåsnornas": "packåsna",
    "packåsnors": "packåsna",
    "padd": "padda",
    "paddan": "padda",
    "paddans": "padda",
    "paddas": "padda",
    "padde": "padda",
    "paddel": "paddla",
    "paddeln": "paddel",
    "paddelns": "paddel",
    "paddels": "paddel",
    "paddfoten": "paddfot",
    "paddfotens": "paddfot",
    "paddfots": "paddfot",
    "paddfötter": "paddfot",
    "paddfötterna": "paddfot",
    "paddfötternas": "paddfot",
    "paddfötters": "paddfot",
    "paddlade": "paddla",
    "paddlades": "paddla",
    "paddlande": "paddla",
    "paddlanden": "paddlande",
    "paddlandena": "paddlande",
    "paddlandenas": "paddlande",
    "paddlandens": "paddlande",
    "paddlandes": "paddlande",
    "paddlandet": "paddlande",
    "paddlandets": "paddlande",
    "paddlar": "paddla",
    "paddlarna": "paddel",
    "paddlarnas": "paddel",
    "paddlars": "paddel",
    "paddlas": "paddla",
    "paddlat": "paddla",
    "paddlats": "paddla",
    "paddockar": "paddock",
    "paddockarna": "paddock",
    "paddockarnas": "paddock",
    "paddockars": "paddock",
    "paddocken": "paddock",
    "paddockens": "paddock",
    "paddocker": "paddock",
    "paddockerna": "paddock",
    "paddockernas": "paddock",
    "paddockers": "paddock",
    "paddocks": "paddock",
    "paddor": "padda",
    "paddorna": "padda",
    "paddornas": "padda",
    "paddors": "padda",
    "padds": "padda",
    "paell": "paella",
    "paellan": "paella",
    "paellans": "paella",
    "paellas": "paella",
    "paelle": "paella",
    "paellor": "paella",
    "paellorna": "paella",
    "paellornas": "paella",
    "paellors": "paella",
    "paells": "paella",
    "paffa": "paff",
    "paffare": "paff",
    "paffares": "paff",
    "paffas": "paff",
    "paffast": "paff",
    "paffaste": "paff",
    "paffastes": "paff",
    "paffasts": "paff",
    "paffe": "paff",
    "paffes": "paff",
    "paffheten": "paffhet",
    "paffhetens": "paffhet",
    "paffhets": "paffhet",
    "paffs": "paff",
    "pafft": "paff",
    "paffts": "paff",
    "pagefrisyren": "pagefrisyr",
    "pagefrisyrens": "pagefrisyr",
    "pagefrisyrer": "pagefrisyr",
    "pagefrisyrerna": "pagefrisyr",
    "pagefrisyrernas": "pagefrisyr",
    "pagefrisyrers": "pagefrisyr",
    "pagefrisyrs": "pagefrisyr",
    "pagen": "page",
    "pagens": "page",
    "pager": "page",
    "pagerna": "page",
    "pagernas": "page",
    "pagers": "page",
    "pages": "page",
    "pagin": "pagina",
    "paginan": "pagina",
    "paginans": "pagina",
    "paginas": "pagina",
    "pagine": "pagina",
    "paginerad": "paginera",
    "paginerade": "paginera",
    "paginerades": "paginera",
    "paginerads": "paginera",
    "paginerande": "paginera",
    "pagineranden": "paginerande",
    "paginerandena": "paginerande",
    "paginerandenas": "paginerande",
    "paginerandens": "paginerande",
    "paginerandes": "paginerande",
    "paginerandet": "paginerande",
    "paginerandets": "paginerande",
    "paginerar": "paginera",
    "pagineras": "paginera",
    "paginerat": "paginera",
    "paginerats": "paginera",
    "paginerbara": "paginerbar",
    "paginerbarare": "paginerbar",
    "paginerbarares": "paginerbar",
    "paginerbaras": "paginerbar",
    "paginerbarast": "paginerbar",
    "paginerbaraste": "paginerbar",
    "paginerbarastes": "paginerbar",
    "paginerbarasts": "paginerbar",
    "paginerbare": "paginerbar",
    "paginerbares": "paginerbar",
    "paginerbarheten": "paginerbarhet",
    "paginerbarhetens": "paginerbarhet",
    "paginerbarhets": "paginerbarhet",
    "paginerbars": "paginerbar",
    "paginerbart": "paginerbar",
    "paginerbarts": "paginerbar",
    "pagineringar": "paginering",
    "pagineringarna": "paginering",
    "pagineringarnas": "paginering",
    "pagineringars": "paginering",
    "pagineringen": "paginering",
    "pagineringens": "paginering",
    "paginerings": "paginering",
    "paginor": "pagina",
    "paginorna": "pagina",
    "paginornas": "pagina",
    "paginors": "pagina",
    "pagins": "pagina",
    "pagoden": "pagod",
    "pagodens": "pagod",
    "pagoder": "pagod",
    "pagoderna": "pagod",
    "pagodernas": "pagod",
    "pagoders": "pagod",
    "pagods": "pagod",
    "paj": "paja",
    "pajad": "paja",
    "pajade": "paja",
    "pajades": "paja",
    "pajads": "paja",
    "pajande": "paja",
    "pajanden": "pajande",
    "pajandena": "pajande",
    "pajandenas": "pajande",
    "pajandens": "pajande",
    "pajandes": "pajande",
    "pajandet": "pajande",
    "pajandets": "pajande",
    "pajar": "paja",
    "pajas": "paja",
    "pajasar": "pajas",
    "pajasarna": "pajas",
    "pajasarnas": "pajas",
    "pajasars": "pajas",
    "pajasen": "pajas",
    "pajasens": "pajas",
    "pajaser": "pajas",
    "pajaseri": "pajaserier",
    "pajaserierna": "pajaserier",
    "pajaseriernas": "pajaserier",
    "pajaseriers": "pajaserier",
    "pajaserna": "pajas",
    "pajasernas": "pajas",
    "pajasers": "pajas",
    "pajaskonst": "pajaskonster",
    "pajaskonsterna": "pajaskonster",
    "pajaskonsternas": "pajaskonster",
    "pajaskonsters": "pajaskonster",
    "pajat": "paja",
    "pajats": "paja",
    "pajdegar": "pajdeg",
    "pajdegarna": "pajdeg",
    "pajdegarnas": "pajdeg",
    "pajdegars": "pajdeg",
    "pajdegen": "pajdeg",
    "pajdegens": "pajdeg",
    "pajdegs": "pajdeg",
    "pajen": "paj",
    "pajens": "paj",
    "pajer": "paj",
    "pajerna": "paj",
    "pajernas": "paj",
    "pajers": "paj",
    "pajkastningar": "pajkastning",
    "pajkastningarna": "pajkastning",
    "pajkastningarnas": "pajkastning",
    "pajkastningars": "pajkastning",
    "pajkastningen": "pajkastning",
    "pajkastningens": "pajkastning",
    "pajkastnings": "pajkastning",
    "pajs": "paj",
    "pajsar": "pajsare",
    "pajsaren": "pajsare",
    "pajsarens": "pajsare",
    "pajsares": "pajsare",
    "pajsarna": "pajsare",
    "pajsarnas": "pajsare",
    "paketauktionen": "paketauktion",
    "paketauktionens": "paketauktion",
    "paketauktioner": "paketauktion",
    "paketauktionerna": "paketauktion",
    "paketauktionernas": "paketauktion",
    "paketauktioners": "paketauktion",
    "paketauktions": "paketauktion",
    "paketen": "paket",
    "paketens": "paket",
    "paketerad": "paketera",
    "paketerade": "paketera",
    "paketerades": "paketera",
    "paketerads": "paketera",
    "paketerande": "paketera",
    "paketeranden": "paketerande",
    "paketerandena": "paketerande",
    "paketerandenas": "paketerande",
    "paketerandens": "paketerande",
    "paketerandes": "paketerande",
    "paketerandet": "paketerande",
    "paketerandets": "paketerande",
    "paketerar": "paketera",
    "paketeras": "paketera",
    "paketerat": "paketera",
    "paketerats": "paketera",
    "paketerbara": "paketerbar",
    "paketerbarare": "paketerbar",
    "paketerbarares": "paketerbar",
    "paketerbaras": "paketerbar",
    "paketerbarast": "paketerbar",
    "paketerbaraste": "paketerbar",
    "paketerbarastes": "paketerbar",
    "paketerbarasts": "paketerbar",
    "paketerbare": "paketerbar",
    "paketerbares": "paketerbar",
    "paketerbarheten": "paketerbarhet",
    "paketerbarhetens": "paketerbarhet",
    "paketerbarhets": "paketerbarhet",
    "paketerbars": "paketerbar",
    "paketerbart": "paketerbar",
    "paketerbarts": "paketerbar",
    "paketeringar": "paketering",
    "paketeringarna": "paketering",
    "paketeringarnas": "paketering",
    "paketeringars": "paketering",
    "paketeringen": "paketering",
    "paketeringens": "paketering",
    "paketerings": "paketering",
    "paketeringsdiskar": "paketeringsdisk",
    "paketeringsdiskarna": "paketeringsdisk",
    "paketeringsdiskarnas": "paketeringsdisk",
    "paketeringsdiskars": "paketeringsdisk",
    "paketeringsdisken": "paketeringsdisk",
    "paketeringsdiskens": "paketeringsdisk",
    "paketeringsdisks": "paketeringsdisk",
    "paketet": "paket",
    "paketets": "paket",
    "paketexpeditionen": "paketexpedition",
    "paketexpeditionens": "paketexpedition",
    "paketexpeditioner": "paketexpedition",
    "paketexpeditionerna": "paketexpedition",
    "paketexpeditionernas": "paketexpedition",
    "paketexpeditioners": "paketexpedition",
    "paketexpeditions": "paketexpedition",
    "paketgodset": "paketgods",
    "paketgodsets": "paketgods",
    "pakethållar": "pakethållare",
    "pakethållaren": "pakethållare",
    "pakethållarens": "pakethållare",
    "pakethållares": "pakethållare",
    "pakethållarna": "pakethållare",
    "pakethållarnas": "pakethållare",
    "paketinlämningar": "paketinlämning",
    "paketinlämningarna": "paketinlämning",
    "paketinlämningarnas": "paketinlämning",
    "paketinlämningars": "paketinlämning",
    "paketinlämningen": "paketinlämning",
    "paketinlämningens": "paketinlämning",
    "paketinlämnings": "paketinlämning",
    "paketkärr": "paketkärra",
    "paketkärran": "paketkärra",
    "paketkärrans": "paketkärra",
    "paketkärras": "paketkärra",
    "paketkärre": "paketkärra",
    "paketkärror": "paketkärra",
    "paketkärrorna": "paketkärra",
    "paketkärrornas": "paketkärra",
    "paketkärrors": "paketkärra",
    "paketkärrs": "paketkärra",
    "paketlösningar": "paketlösning",
    "paketlösningarna": "paketlösning",
    "paketlösningarnas": "paketlösning",
    "paketlösningars": "paketlösning",
    "paketlösningen": "paketlösning",
    "paketlösningens": "paketlösning",
    "paketlösnings": "paketlösning",
    "paketprisen": "paketpris",
    "paketprisens": "paketpris",
    "paketpriset": "paketpris",
    "paketprisets": "paketpris",
    "paketresan": "paketresa",
    "paketresans": "paketresa",
    "paketresas": "paketresa",
    "paketrese": "paketresa",
    "paketresor": "paketresa",
    "paketresorna": "paketresa",
    "paketresornas": "paketresa",
    "paketresors": "paketresa",
    "pakets": "paket",
    "paketutlämningar": "paketutlämning",
    "paketutlämningarna": "paketutlämning",
    "paketutlämningarnas": "paketutlämning",
    "paketutlämningars": "paketutlämning",
    "paketutlämningen": "paketutlämning",
    "paketutlämningens": "paketutlämning",
    "paketutlämnings": "paketutlämning",
    "pakistanar": "pakistanare",
    "pakistanaren": "pakistanare",
    "pakistanarens": "pakistanare",
    "pakistanares": "pakistanare",
    "pakistanarna": "pakistanare",
    "pakistanarnas": "pakistanare",
    "pakistanen": "pakistan",
    "pakistanens": "pakistan",
    "pakistaner": "pakistan",
    "pakistanerna": "pakistan",
    "pakistanernas": "pakistan",
    "pakistaners": "pakistan",
    "pakistans": "pakistan",
    "pakistanska": "pakistansk",
    "pakistanskan": "pakistanska",
    "pakistanskans": "pakistanska",
    "pakistanskare": "pakistansk",
    "pakistanskares": "pakistansk",
    "pakistanskas": "pakistanska",
    "pakistanskast": "pakistansk",
    "pakistanskaste": "pakistansk",
    "pakistanskastes": "pakistansk",
    "pakistanskasts": "pakistansk",
    "pakistanske": "pakistanska",
    "pakistanskes": "pakistansk",
    "pakistanskor": "pakistanska",
    "pakistanskorna": "pakistanska",
    "pakistanskornas": "pakistanska",
    "pakistanskors": "pakistanska",
    "pakistansks": "pakistansk",
    "pakistanskt": "pakistansk",
    "pakistanskts": "pakistansk",
    "pakta": "paktum",
    "paktana": "paktum",
    "paktanas": "paktum",
    "paktas": "paktum",
    "pakten": "pakt",
    "paktens": "pakt",
    "pakter": "pakt",
    "pakterna": "pakt",
    "pakternas": "pakt",
    "pakters": "pakt",
    "pakts": "pakt",
    "paktumen": "paktum",
    "paktumens": "paktum",
    "paktumet": "paktum",
    "paktumets": "paktum",
    "paktums": "paktum",
    "paladinen": "paladin",
    "paladinens": "paladin",
    "paladiner": "paladin",
    "paladinerna": "paladin",
    "paladinernas": "paladin",
    "paladiners": "paladin",
    "paladins": "paladin",
    "palatala": "palatal",
    "palatalare": "palatal",
    "palatalares": "palatal",
    "palatalas": "palatal",
    "palatalast": "palatal",
    "palatalaste": "palatal",
    "palatalastes": "palatal",
    "palatalasts": "palatal",
    "palatale": "palatal",
    "palatalen": "palatal",
    "palatalens": "palatal",
    "palataler": "palatal",
    "palatalerna": "palatal",
    "palatalernas": "palatal",
    "palatalers": "palatal",
    "palatales": "palatal",
    "palataliserad": "palatalisera",
    "palataliserade": "palatalisera",
    "palataliserades": "palatalisera",
    "palataliserads": "palatalisera",
    "palataliserande": "palatalisera",
    "palataliseranden": "palataliserande",
    "palataliserandena": "palataliserande",
    "palataliserandenas": "palataliserande",
    "palataliserandens": "palataliserande",
    "palataliserandes": "palataliserande",
    "palataliserandet": "palataliserande",
    "palataliserandets": "palataliserande",
    "palataliserar": "palatalisera",
    "palataliseras": "palatalisera",
    "palataliserat": "palatalisera",
    "palataliserats": "palatalisera",
    "palataliserbara": "palataliserbar",
    "palataliserbarare": "palataliserbar",
    "palataliserbarares": "palataliserbar",
    "palataliserbaras": "palataliserbar",
    "palataliserbarast": "palataliserbar",
    "palataliserbaraste": "palataliserbar",
    "palataliserbarastes": "palataliserbar",
    "palataliserbarasts": "palataliserbar",
    "palataliserbare": "palataliserbar",
    "palataliserbares": "palataliserbar",
    "palataliserbarheten": "palataliserbarhet",
    "palataliserbarhetens": "palataliserbarhet",
    "palataliserbarhets": "palataliserbarhet",
    "palataliserbars": "palataliserbar",
    "palataliserbart": "palataliserbar",
    "palataliserbarts": "palataliserbar",
    "palataliseringar": "palatalisering",
    "palataliseringarna": "palatalisering",
    "palataliseringarnas": "palatalisering",
    "palataliseringars": "palatalisering",
    "palataliseringen": "palatalisering",
    "palataliseringens": "palatalisering",
    "palataliserings": "palatalisering",
    "palatals": "palatal",
    "palatalt": "palatal",
    "palatalts": "palatal",
    "palatsen": "palats",
    "palatsens": "palats",
    "palatset": "palats",
    "palatsets": "palats",
    "palatsmurar": "palatsmur",
    "palatsmurarna": "palatsmur",
    "palatsmurarnas": "palatsmur",
    "palatsmurars": "palatsmur",
    "palatsmuren": "palatsmur",
    "palatsmurens": "palatsmur",
    "palatsmurs": "palatsmur",
    "palatsrevolutionen": "palatsrevolution",
    "palatsrevolutionens": "palatsrevolution",
    "palatsrevolutioner": "palatsrevolution",
    "palatsrevolutionerna": "palatsrevolution",
    "palatsrevolutionernas": "palatsrevolution",
    "palatsrevolutioners": "palatsrevolution",
    "palatsrevolutions": "palatsrevolution",
    "palauern": "palauer",
    "palauerna": "palauer",
    "palauernas": "palauer",
    "palauerns": "palauer",
    "palauers": "palauer",
    "palauisk": "palauiska",
    "palauiska": "palauisk",
    "palauiskan": "palauiska",
    "palauiskans": "palauiska",
    "palauiskare": "palauisk",
    "palauiskares": "palauisk",
    "palauiskas": "palauiska",
    "palauiskast": "palauisk",
    "palauiskaste": "palauisk",
    "palauiskastes": "palauisk",
    "palauiskasts": "palauisk",
    "palauiske": "palauiska",
    "palauiskes": "palauisk",
    "palauiskor": "palauiska",
    "palauiskorna": "palauiska",
    "palauiskornas": "palauiska",
    "palauiskors": "palauiska",
    "palauisks": "palauisk",
    "palauiskt": "palauisk",
    "palauiskts": "palauisk",
    "palavern": "palaver",
    "palaverns": "palaver",
    "palavers": "palaver",
    "palavrer": "palaver",
    "palavrerna": "palaver",
    "palavrernas": "palaver",
    "palavrers": "palaver",
    "paleocens": "paleocen",
    "paleoekologiska": "paleoekologisk",
    "paleoekologiskare": "paleoekologisk",
    "paleoekologiskares": "paleoekologisk",
    "paleoekologiskas": "paleoekologisk",
    "paleoekologiskast": "paleoekologisk",
    "paleoekologiskaste": "paleoekologisk",
    "paleoekologiskastes": "paleoekologisk",
    "paleoekologiskasts": "paleoekologisk",
    "paleoekologiske": "paleoekologisk",
    "paleoekologiskes": "paleoekologisk",
    "paleoekologisks": "paleoekologisk",
    "paleoekologiskt": "paleoekologisk",
    "paleoekologiskts": "paleoekologisk",
    "paleogens": "paleogen",
    "paleografen": "paleograf",
    "paleografens": "paleograf",
    "paleografer": "paleograf",
    "paleograferna": "paleograf",
    "paleografernas": "paleograf",
    "paleografers": "paleograf",
    "paleografien": "paleografi",
    "paleografiens": "paleografi",
    "paleografin": "paleografi",
    "paleografins": "paleografi",
    "paleografis": "paleografi",
    "paleografs": "paleograf",
    "paleolitiska": "paleolitisk",
    "paleolitiskare": "paleolitisk",
    "paleolitiskares": "paleolitisk",
    "paleolitiskas": "paleolitisk",
    "paleolitiskast": "paleolitisk",
    "paleolitiskaste": "paleolitisk",
    "paleolitiskastes": "paleolitisk",
    "paleolitiskasts": "paleolitisk",
    "paleolitiske": "paleolitisk",
    "paleolitiskes": "paleolitisk",
    "paleolitisks": "paleolitisk",
    "paleolitiskt": "paleolitisk",
    "paleolitiskts": "paleolitisk",
    "paleontologen": "paleontolog",
    "paleontologens": "paleontolog",
    "paleontologer": "paleontolog",
    "paleontologerna": "paleontolog",
    "paleontologernas": "paleontolog",
    "paleontologers": "paleontolog",
    "paleontologien": "paleontologi",
    "paleontologiens": "paleontologi",
    "paleontologin": "paleontologi",
    "paleontologins": "paleontologi",
    "paleontologis": "paleontologi",
    "paleontologiska": "paleontologisk",
    "paleontologiskare": "paleontologisk",
    "paleontologiskares": "paleontologisk",
    "paleontologiskas": "paleontologisk",
    "paleontologiskast": "paleontologisk",
    "paleontologiskaste": "paleontologisk",
    "paleontologiskastes": "paleontologisk",
    "paleontologiskasts": "paleontologisk",
    "paleontologiske": "paleontologisk",
    "paleontologiskes": "paleontologisk",
    "paleontologisks": "paleontologisk",
    "paleontologiskt": "paleontologisk",
    "paleontologiskts": "paleontologisk",
    "paleontologs": "paleontolog",
    "paleozoikums": "paleozoikum",
    "palestinasjalar": "palestinasjal",
    "palestinasjalarna": "palestinasjal",
    "palestinasjalarnas": "palestinasjal",
    "palestinasjalars": "palestinasjal",
    "palestinasjalen": "palestinasjal",
    "palestinasjalens": "palestinasjal",
    "palestinasjals": "palestinasjal",
    "palestiniern": "palestinier",
    "palestinierna": "palestinier",
    "palestiniernas": "palestinier",
    "palestinierns": "palestinier",
    "palestiniers": "palestinier",
    "palestinska": "palestinsk",
    "palestinskare": "palestinsk",
    "palestinskares": "palestinsk",
    "palestinskas": "palestinsk",
    "palestinskast": "palestinsk",
    "palestinskaste": "palestinsk",
    "palestinskastes": "palestinsk",
    "palestinskasts": "palestinsk",
    "palestinske": "palestinsk",
    "palestinskes": "palestinsk",
    "palestinsks": "palestinsk",
    "palestinskt": "palestinsk",
    "palestinskts": "palestinsk",
    "paletten": "palett",
    "palettens": "palett",
    "paletter": "palett",
    "paletterna": "palett",
    "paletternas": "palett",
    "paletters": "palett",
    "palettknivar": "palettkniv",
    "palettknivarna": "palettkniv",
    "palettknivarnas": "palettkniv",
    "palettknivars": "palettkniv",
    "palettkniven": "palettkniv",
    "palettknivens": "palettkniv",
    "palettknivs": "palettkniv",
    "paletts": "palett",
    "paletåer": "paletå",
    "paletåerna": "paletå",
    "paletåernas": "paletå",
    "paletåers": "paletå",
    "paletån": "paletå",
    "paletåns": "paletå",
    "paletås": "paletå",
    "palimpsesten": "palimpsest",
    "palimpsestens": "palimpsest",
    "palimpsester": "palimpsest",
    "palimpsesterna": "palimpsest",
    "palimpsesternas": "palimpsest",
    "palimpsesters": "palimpsest",
    "palimpsests": "palimpsest",
    "palindromen": "palindrom",
    "palindromens": "palindrom",
    "palindromer": "palindrom",
    "palindromerna": "palindrom",
    "palindromernas": "palindrom",
    "palindromers": "palindrom",
    "palindromet": "palindrom",
    "palindromets": "palindrom",
    "palindroms": "palindrom",
    "palisandern": "palisander",
    "palisanderns": "palisander",
    "palisanders": "palisander",
    "palissaden": "palissad",
    "palissadens": "palissad",
    "palissader": "palissad",
    "palissaderna": "palissad",
    "palissadernas": "palissad",
    "palissaders": "palissad",
    "palissads": "palissad",
    "paljettbeströdda": "paljettbeströdd",
    "paljettbeströddare": "paljettbeströdd",
    "paljettbeströddares": "paljettbeströdd",
    "paljettbeströddas": "paljettbeströdd",
    "paljettbeströddast": "paljettbeströdd",
    "paljettbeströddaste": "paljettbeströdd",
    "paljettbeströddastes": "paljettbeströdd",
    "paljettbeströddasts": "paljettbeströdd",
    "paljettbeströdde": "paljettbeströdd",
    "paljettbeströddes": "paljettbeströdd",
    "paljettbeströdds": "paljettbeströdd",
    "paljettbestrött": "paljettbeströdd",
    "paljettbeströtts": "paljettbeströdd",
    "paljetten": "paljett",
    "paljettens": "paljett",
    "paljetter": "paljett",
    "paljetterad": "paljettera",
    "paljetterade": "paljettera",
    "paljetterades": "paljettera",
    "paljetterads": "paljettera",
    "paljetterande": "paljettera",
    "paljetteranden": "paljetterande",
    "paljetterandena": "paljetterande",
    "paljetterandenas": "paljetterande",
    "paljetterandens": "paljetterande",
    "paljetterandes": "paljetterande",
    "paljetterandet": "paljetterande",
    "paljetterandets": "paljetterande",
    "paljetterar": "paljettera",
    "paljetteras": "paljettera",
    "paljetterat": "paljettera",
    "paljetterats": "paljettera",
    "paljetterbara": "paljetterbar",
    "paljetterbarare": "paljetterbar",
    "paljetterbarares": "paljetterbar",
    "paljetterbaras": "paljetterbar",
    "paljetterbarast": "paljetterbar",
    "paljetterbaraste": "paljetterbar",
    "paljetterbarastes": "paljetterbar",
    "paljetterbarasts": "paljetterbar",
    "paljetterbare": "paljetterbar",
    "paljetterbares": "paljetterbar",
    "paljetterbarheten": "paljetterbarhet",
    "paljetterbarhetens": "paljetterbarhet",
    "paljetterbarhets": "paljetterbarhet",
    "paljetterbars": "paljetterbar",
    "paljetterbart": "paljetterbar",
    "paljetterbarts": "paljetterbar",
    "paljetteringar": "paljettering",
    "paljetteringarna": "paljettering",
    "paljetteringarnas": "paljettering",
    "paljetteringars": "paljettering",
    "paljetteringen": "paljettering",
    "paljetteringens": "paljettering",
    "paljetterings": "paljettering",
    "paljetterna": "paljett",
    "paljetternas": "paljett",
    "paljetters": "paljett",
    "paljettklänningar": "paljettklänning",
    "paljettklänningarna": "paljettklänning",
    "paljettklänningarnas": "paljettklänning",
    "paljettklänningars": "paljettklänning",
    "paljettklänningen": "paljettklänning",
    "paljettklänningens": "paljettklänning",
    "paljettklännings": "paljettklänning",
    "paljetts": "paljett",
    "pallad": "palla",
    "pallade": "palla",
    "pallades": "palla",
    "palladiet": "palladium",
    "palladiets": "palladium",
    "palladiumet": "palladium",
    "palladiumets": "palladium",
    "palladiums": "palladium",
    "pallads": "palla",
    "pallande": "palla",
    "pallanden": "pallande",
    "pallandena": "pallande",
    "pallandenas": "pallande",
    "pallandens": "pallande",
    "pallandes": "pallande",
    "pallandet": "pallande",
    "pallandets": "pallande",
    "pallar": "palla",
    "pallarna": "pall",
    "pallarnas": "pall",
    "pallars": "pall",
    "pallas": "palla",
    "pallaschen": "pallasch",
    "pallaschens": "pallasch",
    "pallascher": "pallasch",
    "pallascherna": "pallasch",
    "pallaschernas": "pallasch",
    "pallaschers": "pallasch",
    "pallaschs": "pallasch",
    "pallat": "palla",
    "pallats": "palla",
    "pallen": "pall",
    "pallens": "pall",
    "pallet": "pall",
    "pallets": "pall",
    "palliativa": "palliativ",
    "palliativare": "palliativ",
    "palliativares": "palliativ",
    "palliativas": "palliativ",
    "palliativast": "palliativ",
    "palliativaste": "palliativ",
    "palliativastes": "palliativ",
    "palliativasts": "palliativ",
    "palliative": "palliativ",
    "palliativer": "palliativ",
    "palliativerna": "palliativ",
    "palliativernas": "palliativ",
    "palliativers": "palliativ",
    "palliatives": "palliativ",
    "palliativet": "palliativ",
    "palliativets": "palliativ",
    "palliativs": "palliativ",
    "palliativt": "palliativ",
    "palliativts": "palliativ",
    "palls": "pall",
    "palm": "palma",
    "palmad": "palma",
    "palmade": "palma",
    "palmades": "palma",
    "palmads": "palma",
    "palmande": "palma",
    "palmanden": "palmande",
    "palmandena": "palmande",
    "palmandenas": "palmande",
    "palmandens": "palmande",
    "palmandes": "palmande",
    "palmandet": "palmande",
    "palmandets": "palmande",
    "palmar": "palma",
    "palmas": "palma",
    "palmat": "palma",
    "palmats": "palma",
    "palmbladen": "palmblad",
    "palmbladens": "palmblad",
    "palmbladet": "palmblad",
    "palmbladets": "palmblad",
    "palmblads": "palmblad",
    "palmen": "palm",
    "palmens": "palm",
    "palmer": "palm",
    "palmerna": "palm",
    "palmernas": "palm",
    "palmers": "palm",
    "palmetten": "palmett",
    "palmettens": "palmett",
    "palmetter": "palmett",
    "palmetterna": "palmett",
    "palmetternas": "palmett",
    "palmetters": "palmett",
    "palmetts": "palmett",
    "palmfettet": "palmfett",
    "palmfettets": "palmfett",
    "palmfetts": "palmfett",
    "palmhusen": "palmhus",
    "palmhusens": "palmhus",
    "palmhuset": "palmhus",
    "palmhusets": "palmhus",
    "palmitinen": "palmitin",
    "palmitinens": "palmitin",
    "palmitinet": "palmitin",
    "palmitinets": "palmitin",
    "palmitins": "palmitin",
    "palmitinsyran": "palmitinsyra",
    "palmitinsyrans": "palmitinsyra",
    "palmitinsyras": "palmitinsyra",
    "palmitinsyre": "palmitinsyra",
    "palmkärn": "palmkärna",
    "palmkärnan": "palmkärna",
    "palmkärnans": "palmkärna",
    "palmkärnas": "palmkärna",
    "palmkärne": "palmkärna",
    "palmkärnor": "palmkärna",
    "palmkärnorna": "palmkärna",
    "palmkärnornas": "palmkärna",
    "palmkärnors": "palmkärna",
    "palmkärns": "palmkärna",
    "palmoljan": "palmolja",
    "palmoljans": "palmolja",
    "palmoljas": "palmolja",
    "palmolje": "palmolja",
    "palmplymen": "palmplym",
    "palmplymens": "palmplym",
    "palmplymer": "palmplym",
    "palmplymerna": "palmplym",
    "palmplymernas": "palmplym",
    "palmplymers": "palmplym",
    "palmplyms": "palmplym",
    "palms": "palm",
    "palmsöndagar": "palmsöndag",
    "palmsöndagarna": "palmsöndag",
    "palmsöndagarnas": "palmsöndag",
    "palmsöndagars": "palmsöndag",
    "palmsöndagen": "palmsöndag",
    "palmsöndagens": "palmsöndag",
    "palmsöndags": "palmsöndag",
    "palmviner": "palmvin",
    "palmvinerna": "palmvin",
    "palmvinernas": "palmvin",
    "palmviners": "palmvin",
    "palmvinet": "palmvin",
    "palmvinets": "palmvin",
    "palmvins": "palmvin",
    "palpationen": "palpation",
    "palpationens": "palpation",
    "palpationer": "palpation",
    "palpationerna": "palpation",
    "palpationernas": "palpation",
    "palpationers": "palpation",
    "palpations": "palpation",
    "palpen": "palp",
    "palpens": "palp",
    "palper": "palp",
    "palperad": "palpera",
    "palperade": "palpera",
    "palperades": "palpera",
    "palperads": "palpera",
    "palperande": "palpera",
    "palperanden": "palperande",
    "palperandena": "palperande",
    "palperandenas": "palperande",
    "palperandens": "palperande",
    "palperandes": "palperande",
    "palperandet": "palperande",
    "palperandets": "palperande",
    "palperar": "palpera",
    "palperas": "palpera",
    "palperat": "palpera",
    "palperats": "palpera",
    "palperbara": "palperbar",
    "palperbarare": "palperbar",
    "palperbarares": "palperbar",
    "palperbaras": "palperbar",
    "palperbarast": "palperbar",
    "palperbaraste": "palperbar",
    "palperbarastes": "palperbar",
    "palperbarasts": "palperbar",
    "palperbare": "palperbar",
    "palperbares": "palperbar",
    "palperbarheten": "palperbarhet",
    "palperbarhetens": "palperbarhet",
    "palperbarhets": "palperbarhet",
    "palperbars": "palperbar",
    "palperbart": "palperbar",
    "palperbarts": "palperbar",
    "palperingar": "palpering",
    "palperingarna": "palpering",
    "palperingarnas": "palpering",
    "palperingars": "palpering",
    "palperingen": "palpering",
    "palperingens": "palpering",
    "palperings": "palpering",
    "palperna": "palp",
    "palpernas": "palp",
    "palpers": "palp",
    "palps": "palp",
    "palsar": "pals",
    "palsarna": "pals",
    "palsarnas": "pals",
    "palsars": "pals",
    "palsen": "pals",
    "palsens": "pals",
    "palsternack": "palsternacka",
    "palsternackan": "palsternacka",
    "palsternackans": "palsternacka",
    "palsternackas": "palsternacka",
    "palsternacke": "palsternacka",
    "palsternackor": "palsternacka",
    "palsternackorna": "palsternacka",
    "palsternackornas": "palsternacka",
    "palsternackors": "palsternacka",
    "palsternacks": "palsternacka",
    "palt": "paltor",
    "paltar": "palt",
    "paltarna": "palt",
    "paltarnas": "palt",
    "paltars": "palt",
    "paltbröden": "paltbröd",
    "paltbrödens": "paltbröd",
    "paltbrödet": "paltbröd",
    "paltbrödets": "paltbröd",
    "paltbröds": "paltbröd",
    "palten": "palt",
    "paltens": "palt",
    "paltiga": "paltig",
    "paltigare": "paltig",
    "paltigares": "paltig",
    "paltigas": "paltig",
    "paltigast": "paltig",
    "paltigaste": "paltig",
    "paltigastes": "paltig",
    "paltigasts": "paltig",
    "paltige": "paltig",
    "paltiges": "paltig",
    "paltigheten": "paltighet",
    "paltighetens": "paltighet",
    "paltighets": "paltighet",
    "paltigs": "paltig",
    "paltigt": "paltig",
    "paltigts": "paltig",
    "paltkoman": "paltkoma",
    "paltkomans": "paltkoma",
    "paltkomas": "paltkoma",
    "paltorna": "paltor",
    "paltornas": "paltor",
    "paltors": "paltor",
    "palts": "paltor",
    "paläer": "palä",
    "paläerna": "palä",
    "paläernas": "palä",
    "paläers": "palä",
    "paläet": "palä",
    "paläets": "palä",
    "paläs": "palä",
    "palät": "palä",
    "paläts": "palä",
    "pamfletten": "pamflett",
    "pamflettens": "pamflett",
    "pamfletter": "pamflett",
    "pamfletterna": "pamflett",
    "pamfletternas": "pamflett",
    "pamfletters": "pamflett",
    "pamflettisten": "pamflettist",
    "pamflettistens": "pamflettist",
    "pamflettister": "pamflettist",
    "pamflettisterna": "pamflettist",
    "pamflettisternas": "pamflettist",
    "pamflettisters": "pamflettist",
    "pamflettists": "pamflettist",
    "pamfletts": "pamflett",
    "pampar": "pamp",
    "pamparna": "pamp",
    "pamparnas": "pamp",
    "pampars": "pamp",
    "pampasgräset": "pampasgräs",
    "pampasgräsets": "pampasgräs",
    "pampen": "pamp",
    "pampens": "pamp",
    "pampiga": "pampig",
    "pampigare": "pampig",
    "pampigares": "pampig",
    "pampigas": "pampig",
    "pampigast": "pampig",
    "pampigaste": "pampig",
    "pampigastes": "pampig",
    "pampigasts": "pampig",
    "pampige": "pampig",
    "pampiges": "pampig",
    "pampigheten": "pampighet",
    "pampighetens": "pampighet",
    "pampighets": "pampighet",
    "pampigs": "pampig",
    "pampigt": "pampig",
    "pampigts": "pampig",
    "pamps": "pamp",
    "pampuschen": "pampusch",
    "pampuschens": "pampusch",
    "pampuscher": "pampusch",
    "pampuscherna": "pampusch",
    "pampuschernas": "pampusch",
    "pampuschers": "pampusch",
    "pampuschs": "pampusch",
    "panafrikanska": "panafrikansk",
    "panafrikanskare": "panafrikansk",
    "panafrikanskares": "panafrikansk",
    "panafrikanskas": "panafrikansk",
    "panafrikanskast": "panafrikansk",
    "panafrikanskaste": "panafrikansk",
    "panafrikanskastes": "panafrikansk",
    "panafrikanskasts": "panafrikansk",
    "panafrikanske": "panafrikansk",
    "panafrikanskes": "panafrikansk",
    "panafrikansks": "panafrikansk",
    "panafrikanskt": "panafrikansk",
    "panafrikanskts": "panafrikansk",
    "panamahattar": "panamahatt",
    "panamahattarna": "panamahatt",
    "panamahattarnas": "panamahatt",
    "panamahattars": "panamahatt",
    "panamahatten": "panamahatt",
    "panamahattens": "panamahatt",
    "panamahatts": "panamahatt",
    "panaman": "panama",
    "panamanen": "panaman",
    "panamanens": "panaman",
    "panamaner": "panaman",
    "panamanerna": "panaman",
    "panamanernas": "panaman",
    "panamaners": "panaman",
    "panamans": "panaman",
    "panamanska": "panamansk",
    "panamanskan": "panamanska",
    "panamanskans": "panamanska",
    "panamanskare": "panamansk",
    "panamanskares": "panamansk",
    "panamanskas": "panamanska",
    "panamanskast": "panamansk",
    "panamanskaste": "panamansk",
    "panamanskastes": "panamansk",
    "panamanskasts": "panamansk",
    "panamanske": "panamanska",
    "panamanskes": "panamansk",
    "panamanskor": "panamanska",
    "panamanskorna": "panamanska",
    "panamanskornas": "panamanska",
    "panamanskors": "panamanska",
    "panamansks": "panamansk",
    "panamanskt": "panamansk",
    "panamanskts": "panamansk",
    "panamas": "panama",
    "panamerikanska": "panamerikansk",
    "panamerikanskare": "panamerikansk",
    "panamerikanskares": "panamerikansk",
    "panamerikanskas": "panamerikansk",
    "panamerikanskast": "panamerikansk",
    "panamerikanskaste": "panamerikansk",
    "panamerikanskastes": "panamerikansk",
    "panamerikanskasts": "panamerikansk",
    "panamerikanske": "panamerikansk",
    "panamerikanskes": "panamerikansk",
    "panamerikansks": "panamerikansk",
    "panamerikanskt": "panamerikansk",
    "panamerikanskts": "panamerikansk",
    "panarabiska": "panarabisk",
    "panarabiskare": "panarabisk",
    "panarabiskares": "panarabisk",
    "panarabiskas": "panarabisk",
    "panarabiskast": "panarabisk",
    "panarabiskaste": "panarabisk",
    "panarabiskastes": "panarabisk",
    "panarabiskasts": "panarabisk",
    "panarabiske": "panarabisk",
    "panarabiskes": "panarabisk",
    "panarabisks": "panarabisk",
    "panarabiskt": "panarabisk",
    "panarabiskts": "panarabisk",
    "panaschen": "panasch",
    "panaschens": "panasch",
    "panascher": "panasch",
    "panascheringar": "panaschering",
    "panascheringarna": "panaschering",
    "panascheringarnas": "panaschering",
    "panascheringars": "panaschering",
    "panascheringen": "panaschering",
    "panascheringens": "panaschering",
    "panascherings": "panaschering",
    "panascherna": "panasch",
    "panaschernas": "panasch",
    "panaschers": "panasch",
    "panaschs": "panasch",
    "pand": "panda",
    "pandan": "panda",
    "pandans": "panda",
    "pandas": "panda",
    "pande": "panda",
    "pandemien": "pandemi",
    "pandemiens": "pandemi",
    "pandemier": "pandemi",
    "pandemierna": "pandemi",
    "pandemiernas": "pandemi",
    "pandemiers": "pandemi",
    "pandemin": "pandemi",
    "pandemins": "pandemi",
    "pandemis": "pandemi",
    "pandemiska": "pandemisk",
    "pandemiskas": "pandemisk",
    "pandemiske": "pandemisk",
    "pandemiskes": "pandemisk",
    "pandemisks": "pandemisk",
    "pandemiskt": "pandemisk",
    "pandemiskts": "pandemisk",
    "pandemoniet": "pandemonium",
    "pandemoniets": "pandemonium",
    "pandemoniums": "pandemonium",
    "pandor": "panda",
    "pandorna": "panda",
    "pandornas": "panda",
    "pandors": "panda",
    "pands": "panda",
    "panegyriken": "panegyrik",
    "panegyrikens": "panegyrik",
    "panegyriker": "panegyrik",
    "panegyrikerna": "panegyrik",
    "panegyrikernas": "panegyrik",
    "panegyrikers": "panegyrik",
    "panegyriks": "panegyrik",
    "panegyriska": "panegyrisk",
    "panegyriskare": "panegyrisk",
    "panegyriskares": "panegyrisk",
    "panegyriskas": "panegyrisk",
    "panegyriskast": "panegyrisk",
    "panegyriskaste": "panegyrisk",
    "panegyriskastes": "panegyrisk",
    "panegyriskasts": "panegyrisk",
    "panegyriske": "panegyrisk",
    "panegyriskes": "panegyrisk",
    "panegyrisks": "panegyrisk",
    "panegyriskt": "panegyrisk",
    "panegyriskts": "panegyrisk",
    "panel": "panela",
    "panelad": "panela",
    "panelade": "panela",
    "panelades": "panela",
    "panelads": "panela",
    "panelande": "panela",
    "panelanden": "panelande",
    "panelandena": "panelande",
    "panelandenas": "panelande",
    "panelandens": "panelande",
    "panelandes": "panelande",
    "panelandet": "panelande",
    "panelandets": "panelande",
    "panelar": "panela",
    "panelas": "panela",
    "panelat": "panela",
    "panelats": "panela",
    "paneldebatten": "paneldebatt",
    "paneldebattens": "paneldebatt",
    "paneldebatter": "paneldebatt",
    "paneldebatterna": "paneldebatt",
    "paneldebatternas": "paneldebatt",
    "paneldebatters": "paneldebatt",
    "paneldebatts": "paneldebatt",
    "paneldiskussionen": "paneldiskussion",
    "paneldiskussionens": "paneldiskussion",
    "paneldiskussioner": "paneldiskussion",
    "paneldiskussionerna": "paneldiskussion",
    "paneldiskussionernas": "paneldiskussion",
    "paneldiskussioners": "paneldiskussion",
    "paneldiskussions": "paneldiskussion",
    "panelen": "panel",
    "panelens": "panel",
    "paneler": "panel",
    "panelerna": "panel",
    "panelernas": "panel",
    "panelers": "panel",
    "panelhön": "panelhöna",
    "panelhönan": "panelhöna",
    "panelhönans": "panelhöna",
    "panelhönas": "panelhöna",
    "panelhöne": "panelhöna",
    "panelhönor": "panelhöna",
    "panelhönorna": "panelhöna",
    "panelhönornas": "panelhöna",
    "panelhönors": "panelhöna",
    "panelhöns": "panelhöna",
    "panels": "panel",
    "panerad": "panera",
    "panerade": "panera",
    "panerades": "panera",
    "panerads": "panera",
    "panerande": "panera",
    "paneranden": "panerande",
    "panerandena": "panerande",
    "panerandenas": "panerande",
    "panerandens": "panerande",
    "panerandes": "panerande",
    "panerandet": "panerande",
    "panerandets": "panerande",
    "panerar": "panera",
    "paneras": "panera",
    "panerat": "panera",
    "panerats": "panera",
    "panerbara": "panerbar",
    "panerbarare": "panerbar",
    "panerbarares": "panerbar",
    "panerbaras": "panerbar",
    "panerbarast": "panerbar",
    "panerbaraste": "panerbar",
    "panerbarastes": "panerbar",
    "panerbarasts": "panerbar",
    "panerbare": "panerbar",
    "panerbares": "panerbar",
    "panerbarheten": "panerbarhet",
    "panerbarhetens": "panerbarhet",
    "panerbarhets": "panerbarhet",
    "panerbars": "panerbar",
    "panerbart": "panerbar",
    "panerbarts": "panerbar",
    "paneringar": "panering",
    "paneringarna": "panering",
    "paneringarnas": "panering",
    "paneringars": "panering",
    "paneringen": "panering",
    "paneringens": "panering",
    "panerings": "panering",
    "panetten": "panett",
    "panettens": "panett",
    "panetter": "panett",
    "panetterna": "panett",
    "panetternas": "panett",
    "panetters": "panett",
    "panetts": "panett",
    "panflöjten": "panflöjt",
    "panflöjtens": "panflöjt",
    "panflöjter": "panflöjt",
    "panflöjterna": "panflöjt",
    "panflöjternas": "panflöjt",
    "panflöjters": "panflöjt",
    "panflöjts": "panflöjt",
    "pang-pangfilmen": "pang-pangfilm",
    "pang-pangfilmens": "pang-pangfilm",
    "pang-pangfilmer": "pang-pangfilm",
    "pang-pangfilmerna": "pang-pangfilm",
    "pang-pangfilmernas": "pang-pangfilm",
    "pang-pangfilmers": "pang-pangfilm",
    "pang-pangfilms": "pang-pangfilm",
    "pangad": "panga",
    "pangade": "panga",
    "pangades": "panga",
    "pangads": "panga",
    "pangande": "panga",
    "panganden": "pangande",
    "pangandena": "pangande",
    "pangandenas": "pangande",
    "pangandens": "pangande",
    "pangandes": "pangande",
    "pangandet": "pangande",
    "pangandets": "pangande",
    "pangar": "panga",
    "pangas": "panga",
    "pangasiusen": "pangasius",
    "pangasiusens": "pangasius",
    "pangat": "panga",
    "pangats": "panga",
    "pangen": "pang",
    "pangens": "pang",
    "panget": "pang",
    "pangets": "pang",
    "pangpjäsen": "pangpjäs",
    "pangpjäsens": "pangpjäs",
    "pangpjäser": "pangpjäs",
    "pangpjäserna": "pangpjäs",
    "pangpjäsernas": "pangpjäs",
    "pangpjäsers": "pangpjäs",
    "pangs": "pang",
    "panhellenismen": "panhellenism",
    "panhellenismens": "panhellenism",
    "panhellenismer": "panhellenism",
    "panhellenismerna": "panhellenism",
    "panhellenismernas": "panhellenism",
    "panhellenismers": "panhellenism",
    "panhellenisms": "panhellenism",
    "panikanfallen": "panikanfall",
    "panikanfallens": "panikanfall",
    "panikanfallet": "panikanfall",
    "panikanfallets": "panikanfall",
    "panikanfalls": "panikanfall",
    "panikartade": "panikartad",
    "panikartades": "panikartad",
    "panikartads": "panikartad",
    "panikartat": "panikartad",
    "panikartats": "panikartad",
    "panikattacken": "panikattack",
    "panikattackens": "panikattack",
    "panikattacker": "panikattack",
    "panikattackerna": "panikattack",
    "panikattackernas": "panikattack",
    "panikattackers": "panikattack",
    "panikattacks": "panikattack",
    "panikbroms": "panikbromsa",
    "panikbromsad": "panikbromsa",
    "panikbromsade": "panikbromsa",
    "panikbromsades": "panikbromsa",
    "panikbromsads": "panikbromsa",
    "panikbromsande": "panikbromsa",
    "panikbromsandes": "panikbromsa",
    "panikbromsar": "panikbromsa",
    "panikbromsas": "panikbromsa",
    "panikbromsat": "panikbromsa",
    "panikbromsats": "panikbromsa",
    "paniken": "panik",
    "panikens": "panik",
    "panikmässiga": "panikmässig",
    "panikmässigare": "panikmässig",
    "panikmässigares": "panikmässig",
    "panikmässigas": "panikmässig",
    "panikmässigast": "panikmässig",
    "panikmässigaste": "panikmässig",
    "panikmässigastes": "panikmässig",
    "panikmässigasts": "panikmässig",
    "panikmässige": "panikmässig",
    "panikmässiges": "panikmässig",
    "panikmässigs": "panikmässig",
    "panikmässigt": "panikmässig",
    "panikmässigts": "panikmässig",
    "paniks": "panik",
    "panikslagens": "panikslagen",
    "panikslaget": "panikslagen",
    "panikslagets": "panikslagen",
    "panikslagna": "panikslagen",
    "panikslagnare": "panikslagen",
    "panikslagnares": "panikslagen",
    "panikslagnas": "panikslagen",
    "panikslagnast": "panikslagen",
    "panikslagnaste": "panikslagen",
    "panikslagnastes": "panikslagen",
    "panikslagnasts": "panikslagen",
    "panikslagne": "panikslagen",
    "panikslagnes": "panikslagen",
    "panikungar": "panikunge",
    "panikungarna": "panikunge",
    "panikungarnas": "panikunge",
    "panikungars": "panikunge",
    "panikungen": "panikunge",
    "panikungens": "panikunge",
    "panikunges": "panikunge",
    "panikångestattacken": "panikångestattack",
    "panikångestattackens": "panikångestattack",
    "panikångestattacker": "panikångestattack",
    "panikångestattackerna": "panikångestattack",
    "panikångestattackernas": "panikångestattack",
    "panikångestattackers": "panikångestattack",
    "panikångestattacks": "panikångestattack",
    "panikångesten": "panikångest",
    "panikångestens": "panikångest",
    "panikångests": "panikångest",
    "paniska": "panisk",
    "paniskare": "panisk",
    "paniskares": "panisk",
    "paniskas": "panisk",
    "paniskast": "panisk",
    "paniskaste": "panisk",
    "paniskastes": "panisk",
    "paniskasts": "panisk",
    "paniske": "panisk",
    "paniskes": "panisk",
    "panisks": "panisk",
    "paniskt": "panisk",
    "paniskts": "panisk",
    "pank": "panka",
    "panka": "pank",
    "pankan": "panka",
    "pankans": "panka",
    "pankare": "pank",
    "pankares": "pank",
    "pankas": "panka",
    "pankast": "pank",
    "pankaste": "pank",
    "pankastes": "pank",
    "pankasts": "pank",
    "panke": "panka",
    "pankes": "pank",
    "pankheten": "pankhet",
    "pankhetens": "pankhet",
    "pankhets": "pankhet",
    "pankor": "panka",
    "pankorna": "panka",
    "pankornas": "panka",
    "pankors": "panka",
    "pankreaskörteln": "pankreaskörtel",
    "pankreaskörtelns": "pankreaskörtel",
    "pankreaskörtels": "pankreaskörtel",
    "pankreaskörtlar": "pankreaskörtel",
    "pankreaskörtlarna": "pankreaskörtel",
    "pankreaskörtlarnas": "pankreaskörtel",
    "pankreaskörtlars": "pankreaskörtel",
    "pankreatiten": "pankreatit",
    "pankreatitens": "pankreatit",
    "pankreatiter": "pankreatit",
    "pankreatiterna": "pankreatit",
    "pankreatiternas": "pankreatit",
    "pankreatiters": "pankreatit",
    "pankreatits": "pankreatit",
    "pankromatiska": "pankromatisk",
    "pankromatiskare": "pankromatisk",
    "pankromatiskares": "pankromatisk",
    "pankromatiskas": "pankromatisk",
    "pankromatiskast": "pankromatisk",
    "pankromatiskaste": "pankromatisk",
    "pankromatiskastes": "pankromatisk",
    "pankromatiskasts": "pankromatisk",
    "pankromatiske": "pankromatisk",
    "pankromatiskes": "pankromatisk",
    "pankromatisks": "pankromatisk",
    "pankromatiskt": "pankromatisk",
    "pankromatiskts": "pankromatisk",
    "panks": "panka",
    "pankt": "pank",
    "pankts": "pank",
    "pann": "panna",
    "pannan": "panna",
    "pannans": "panna",
    "pannas": "panna",
    "pannbanden": "pannband",
    "pannbandens": "pannband",
    "pannbandet": "pannband",
    "pannbandets": "pannband",
    "pannbands": "pannband",
    "pannbenen": "pannben",
    "pannbenens": "pannben",
    "pannbenet": "pannben",
    "pannbenets": "pannben",
    "pannbens": "pannben",
    "pannbiffar": "pannbiff",
    "pannbiffarna": "pannbiff",
    "pannbiffarnas": "pannbiff",
    "pannbiffars": "pannbiff",
    "pannbiffen": "pannbiff",
    "pannbiffens": "pannbiff",
    "pannbiffs": "pannbiff",
    "panne": "panna",
    "pannhål": "pannhåla",
    "pannhålan": "pannhåla",
    "pannhålans": "pannhåla",
    "pannhålas": "pannhåla",
    "pannhåle": "pannhåla",
    "pannhålor": "pannhåla",
    "pannhålorna": "pannhåla",
    "pannhålornas": "pannhåla",
    "pannhålors": "pannhåla",
    "pannhåls": "pannhåla",
    "pannkak": "pannkaka",
    "pannkakan": "pannkaka",
    "pannkakans": "pannkaka",
    "pannkakas": "pannkaka",
    "pannkake": "pannkaka",
    "pannkakor": "pannkaka",
    "pannkakorna": "pannkaka",
    "pannkakornas": "pannkaka",
    "pannkakors": "pannkaka",
    "pannkaks": "pannkaka",
    "pannkaksmolnen": "pannkaksmoln",
    "pannkaksmolnens": "pannkaksmoln",
    "pannkaksmolnet": "pannkaksmoln",
    "pannkaksmolnets": "pannkaksmoln",
    "pannkaksmolns": "pannkaksmoln",
    "pannkakssmeten": "pannkakssmet",
    "pannkakssmetens": "pannkakssmet",
    "pannkakssmeter": "pannkakssmet",
    "pannkakssmeterna": "pannkakssmet",
    "pannkakssmeternas": "pannkakssmet",
    "pannkakssmeters": "pannkakssmet",
    "pannkakssmets": "pannkakssmet",
    "pannkaksteoretikern": "pannkaksteoretiker",
    "pannkaksteoretikerna": "pannkaksteoretiker",
    "pannkaksteoretikernas": "pannkaksteoretiker",
    "pannkaksteoretikerns": "pannkaksteoretiker",
    "pannkaksteoretikers": "pannkaksteoretiker",
    "pannkaksteorien": "pannkaksteori",
    "pannkaksteoriens": "pannkaksteori",
    "pannkaksteorier": "pannkaksteori",
    "pannkaksteorierna": "pannkaksteori",
    "pannkaksteoriernas": "pannkaksteori",
    "pannkaksteoriers": "pannkaksteori",
    "pannkaksteorin": "pannkaksteori",
    "pannkaksteorins": "pannkaksteori",
    "pannkaksteoris": "pannkaksteori",
    "pannlamp": "pannlampa",
    "pannlampan": "pannlampa",
    "pannlampans": "pannlampa",
    "pannlampas": "pannlampa",
    "pannlampe": "pannlampa",
    "pannlampor": "pannlampa",
    "pannlamporna": "pannlampa",
    "pannlampornas": "pannlampa",
    "pannlampors": "pannlampa",
    "pannlamps": "pannlampa",
    "pannloben": "pannlob",
    "pannlobens": "pannlob",
    "pannlober": "pannlob",
    "pannloberna": "pannlob",
    "pannlobernas": "pannlob",
    "pannlobers": "pannlob",
    "pannlobs": "pannlob",
    "pannor": "panna",
    "pannorna": "panna",
    "pannornas": "panna",
    "pannors": "panna",
    "pannrummen": "pannrum",
    "pannrummens": "pannrum",
    "pannrummet": "pannrum",
    "pannrummets": "pannrum",
    "pannrums": "pannrum",
    "panns": "panna",
    "pannspegeln": "pannspegel",
    "pannspegelns": "pannspegel",
    "pannspegels": "pannspegel",
    "pannspeglar": "pannspegel",
    "pannspeglarna": "pannspegel",
    "pannspeglarnas": "pannspegel",
    "pannspeglars": "pannspegel",
    "pannstenen": "pannsten",
    "pannstenens": "pannsten",
    "pannstens": "pannsten",
    "pannåer": "pannå",
    "pannåerna": "pannå",
    "pannåernas": "pannå",
    "pannåers": "pannå",
    "pannån": "pannå",
    "pannåns": "pannå",
    "pannås": "pannå",
    "panoptikonen": "panoptikon",
    "panoptikonens": "panoptikon",
    "panoptikonet": "panoptikon",
    "panoptikonets": "panoptikon",
    "panoptikons": "panoptikon",
    "panoramafönsterna": "panoramafönster",
    "panoramafönsternas": "panoramafönster",
    "panoramafönsters": "panoramafönster",
    "panoramafönstren": "panoramafönster",
    "panoramafönstrens": "panoramafönster",
    "panoramafönstret": "panoramafönster",
    "panoramafönstrets": "panoramafönster",
    "panoramakameran": "panoramakamera",
    "panoramakamerans": "panoramakamera",
    "panoramakameras": "panoramakamera",
    "panoramakameror": "panoramakamera",
    "panoramakamerorna": "panoramakamera",
    "panoramakamerornas": "panoramakamera",
    "panoramakamerors": "panoramakamera",
    "panoraman": "panorama",
    "panoramana": "panorama",
    "panoramanas": "panorama",
    "panoramans": "panorama",
    "panoramas": "panorama",
    "panoramat": "panorama",
    "panoramats": "panorama",
    "panoramor": "panorama",
    "panoramorna": "panorama",
    "panoramornas": "panorama",
    "panoramors": "panorama",
    "panorerad": "panorera",
    "panorerade": "panorera",
    "panorerades": "panorera",
    "panorerads": "panorera",
    "panorerande": "panorera",
    "panoreranden": "panorerande",
    "panorerandena": "panorerande",
    "panorerandenas": "panorerande",
    "panorerandens": "panorerande",
    "panorerandes": "panorerande",
    "panorerandet": "panorerande",
    "panorerandets": "panorerande",
    "panorerar": "panorera",
    "panoreras": "panorera",
    "panorerat": "panorera",
    "panorerats": "panorera",
    "panorerbara": "panorerbar",
    "panorerbarare": "panorerbar",
    "panorerbarares": "panorerbar",
    "panorerbaras": "panorerbar",
    "panorerbarast": "panorerbar",
    "panorerbaraste": "panorerbar",
    "panorerbarastes": "panorerbar",
    "panorerbarasts": "panorerbar",
    "panorerbare": "panorerbar",
    "panorerbares": "panorerbar",
    "panorerbarheten": "panorerbarhet",
    "panorerbarhetens": "panorerbarhet",
    "panorerbarhets": "panorerbarhet",
    "panorerbars": "panorerbar",
    "panorerbart": "panorerbar",
    "panorerbarts": "panorerbar",
    "panoreringar": "panorering",
    "panoreringarna": "panorering",
    "panoreringarnas": "panorering",
    "panoreringars": "panorering",
    "panoreringen": "panorering",
    "panoreringens": "panorering",
    "panorerings": "panorering",
    "pansarbilar": "pansarbil",
    "pansarbilarna": "pansarbil",
    "pansarbilarnas": "pansarbil",
    "pansarbilars": "pansarbil",
    "pansarbilen": "pansarbil",
    "pansarbilens": "pansarbil",
    "pansarbils": "pansarbil",
    "pansaren": "pansar",
    "pansarens": "pansar",
    "pansaret": "pansar",
    "pansarets": "pansar",
    "pansarfordonen": "pansarfordon",
    "pansarfordonens": "pansarfordon",
    "pansarfordonet": "pansarfordon",
    "pansarfordonets": "pansarfordon",
    "pansarfordons": "pansarfordon",
    "pansarfärgen": "pansarfärg",
    "pansarfärgens": "pansarfärg",
    "pansarfärgs": "pansarfärg",
    "pansargeneralen": "pansargeneral",
    "pansargeneralens": "pansargeneral",
    "pansargeneraler": "pansargeneral",
    "pansargeneralerna": "pansargeneral",
    "pansargeneralernas": "pansargeneral",
    "pansargeneralers": "pansargeneral",
    "pansargenerals": "pansargeneral",
    "pansargranaten": "pansargranat",
    "pansargranatens": "pansargranat",
    "pansargranater": "pansargranat",
    "pansargranaterna": "pansargranat",
    "pansargranaternas": "pansargranat",
    "pansargranaters": "pansargranat",
    "pansargranats": "pansargranat",
    "pansarhinderna": "pansarhinder",
    "pansarhindernas": "pansarhinder",
    "pansarhinders": "pansarhinder",
    "pansarhindren": "pansarhinder",
    "pansarhindrens": "pansarhinder",
    "pansarhindret": "pansarhinder",
    "pansarhindrets": "pansarhinder",
    "pansarhjärt": "pansarhjärta",
    "pansarhjärtan": "pansarhjärta",
    "pansarhjärtana": "pansarhjärta",
    "pansarhjärtanas": "pansarhjärta",
    "pansarhjärtans": "pansarhjärta",
    "pansarhjärtas": "pansarhjärta",
    "pansarhjärtat": "pansarhjärta",
    "pansarhjärtats": "pansarhjärta",
    "pansarhjärts": "pansarhjärta",
    "pansarmalar": "pansarmal",
    "pansarmalarna": "pansarmal",
    "pansarmalarnas": "pansarmal",
    "pansarmalars": "pansarmal",
    "pansarmalen": "pansarmal",
    "pansarmalens": "pansarmal",
    "pansarmals": "pansarmal",
    "pansarna": "pansar",
    "pansarnas": "pansar",
    "pansarregementen": "pansarregemente",
    "pansarregementena": "pansarregemente",
    "pansarregementenas": "pansarregemente",
    "pansarregementens": "pansarregemente",
    "pansarregementes": "pansarregemente",
    "pansarregementet": "pansarregemente",
    "pansarregementets": "pansarregemente",
    "pansarrören": "pansarrör",
    "pansarrörens": "pansarrör",
    "pansarröret": "pansarrör",
    "pansarrörets": "pansarrör",
    "pansarrörs": "pansarrör",
    "pansars": "pansar",
    "pansarsjälen": "pansarsjäl",
    "pansarsjälens": "pansarsjäl",
    "pansarsjäls": "pansarsjäl",
    "pansarskjort": "pansarskjorta",
    "pansarskjortan": "pansarskjorta",
    "pansarskjortans": "pansarskjorta",
    "pansarskjortas": "pansarskjorta",
    "pansarskjorte": "pansarskjorta",
    "pansarskjortor": "pansarskjorta",
    "pansarskjortorna": "pansarskjorta",
    "pansarskjortornas": "pansarskjorta",
    "pansarskjortors": "pansarskjorta",
    "pansarskjorts": "pansarskjorta",
    "pansarskotten": "pansarskott",
    "pansarskottens": "pansarskott",
    "pansarskottet": "pansarskott",
    "pansarskottets": "pansarskott",
    "pansarskotts": "pansarskott",
    "pansartruppen": "pansartrupp",
    "pansartruppens": "pansartrupp",
    "pansartrupper": "pansartrupp",
    "pansartrupperna": "pansartrupp",
    "pansartruppernas": "pansartrupp",
    "pansartruppers": "pansartrupp",
    "pansartrupps": "pansartrupp",
    "pansarvagnar": "pansarvagn",
    "pansarvagnarna": "pansarvagn",
    "pansarvagnarnas": "pansarvagn",
    "pansarvagnars": "pansarvagn",
    "pansarvagnen": "pansarvagn",
    "pansarvagnens": "pansarvagn",
    "pansarvagns": "pansarvagn",
    "pansarvärnen": "pansarvärn",
    "pansarvärnens": "pansarvärn",
    "pansarvärnet": "pansarvärn",
    "pansarvärnets": "pansarvärn",
    "pansarvärns": "pansarvärn",
    "pansarvärnsrobotar": "pansarvärnsrobot",
    "pansarvärnsrobotarna": "pansarvärnsrobot",
    "pansarvärnsrobotarnas": "pansarvärnsrobot",
    "pansarvärnsrobotars": "pansarvärnsrobot",
    "pansarvärnsroboten": "pansarvärnsrobot",
    "pansarvärnsrobotens": "pansarvärnsrobot",
    "pansarvärnsrobots": "pansarvärnsrobot",
    "pansarvärnsvapens": "pansarvärnsvapen",
    "pansarvärnsvapnen": "pansarvärnsvapen",
    "pansarvärnsvapnens": "pansarvärnsvapen",
    "pansarvärnsvapnet": "pansarvärnsvapen",
    "pansarvärnsvapnets": "pansarvärnsvapen",
    "pansrad": "pansra",
    "pansrade": "pansra",
    "pansrades": "pansra",
    "pansrads": "pansra",
    "pansrande": "pansra",
    "pansranden": "pansrande",
    "pansrandena": "pansrande",
    "pansrandenas": "pansrande",
    "pansrandens": "pansrande",
    "pansrandes": "pansrande",
    "pansrandet": "pansrande",
    "pansrandets": "pansrande",
    "pansrar": "pansra",
    "pansras": "pansra",
    "pansrat": "pansra",
    "pansrats": "pansra",
    "pant": "panta",
    "pantad": "panta",
    "pantade": "pantad",
    "pantades": "pantad",
    "pantads": "pantad",
    "pantalong": "pantalonger",
    "pantalongerna": "pantalonger",
    "pantalongernas": "pantalonger",
    "pantalongers": "pantalonger",
    "pantalongs": "pantalonger",
    "pantande": "panta",
    "pantanden": "pantande",
    "pantandena": "pantande",
    "pantandenas": "pantande",
    "pantandens": "pantande",
    "pantandes": "pantande",
    "pantandet": "pantande",
    "pantandets": "pantande",
    "pantar": "panta",
    "pantas": "panta",
    "pantat": "pantad",
    "pantats": "pantad",
    "pantbanken": "pantbank",
    "pantbankens": "pantbank",
    "pantbanker": "pantbank",
    "pantbankerna": "pantbank",
    "pantbankernas": "pantbank",
    "pantbankers": "pantbank",
    "pantbanks": "pantbank",
    "pantbreven": "pantbrev",
    "pantbrevens": "pantbrev",
    "pantbrevet": "pantbrev",
    "pantbrevets": "pantbrev",
    "pantbrevs": "pantbrev",
    "pantburkar": "pantburk",
    "pantburkarna": "pantburk",
    "pantburkarnas": "pantburk",
    "pantburkars": "pantburk",
    "pantburken": "pantburk",
    "pantburkens": "pantburk",
    "pantburks": "pantburk",
    "panteismen": "panteism",
    "panteismens": "panteism",
    "panteismer": "panteism",
    "panteismerna": "panteism",
    "panteismernas": "panteism",
    "panteismers": "panteism",
    "panteisms": "panteism",
    "panteisten": "panteist",
    "panteistens": "panteist",
    "panteister": "panteist",
    "panteisterna": "panteist",
    "panteisternas": "panteist",
    "panteisters": "panteist",
    "panteistiska": "panteistisk",
    "panteistiskare": "panteistisk",
    "panteistiskares": "panteistisk",
    "panteistiskas": "panteistisk",
    "panteistiskast": "panteistisk",
    "panteistiskaste": "panteistisk",
    "panteistiskastes": "panteistisk",
    "panteistiskasts": "panteistisk",
    "panteistiske": "panteistisk",
    "panteistiskes": "panteistisk",
    "panteistisks": "panteistisk",
    "panteistiskt": "panteistisk",
    "panteistiskts": "panteistisk",
    "panteists": "panteist",
    "panten": "pant",
    "pantens": "pant",
    "panteonen": "panteon",
    "panteonens": "panteon",
    "panteonet": "panteon",
    "panteonets": "panteon",
    "panteons": "panteon",
    "panter": "pant",
    "panterkatten": "panterkatt",
    "panterkattens": "panterkatt",
    "panterkatter": "panterkatt",
    "panterkatterna": "panterkatt",
    "panterkatternas": "panterkatt",
    "panterkatters": "panterkatt",
    "panterkatts": "panterkatt",
    "pantern": "panter",
    "panterna": "pant",
    "panternas": "pant",
    "panterns": "panter",
    "panters": "panter",
    "pantersprången": "pantersprång",
    "pantersprångens": "pantersprång",
    "pantersprånget": "pantersprång",
    "pantersprångets": "pantersprång",
    "pantersprångs": "pantersprång",
    "pantförskrev": "pantförskriva",
    "pantförskrevs": "pantförskriva",
    "pantförskriv": "pantförskriva",
    "pantförskrivande": "pantförskriva",
    "pantförskrivanden": "pantförskrivande",
    "pantförskrivandena": "pantförskrivande",
    "pantförskrivandenas": "pantförskrivande",
    "pantförskrivandens": "pantförskrivande",
    "pantförskrivandes": "pantförskrivande",
    "pantförskrivandet": "pantförskrivande",
    "pantförskrivandets": "pantförskrivande",
    "pantförskrivas": "pantförskriva",
    "pantförskrive": "pantförskriva",
    "pantförskriven": "pantförskriva",
    "pantförskrivens": "pantförskriva",
    "pantförskriver": "pantförskriva",
    "pantförskrives": "pantförskriva",
    "pantförskrivet": "pantförskriva",
    "pantförskrivets": "pantförskriva",
    "pantförskrivit": "pantförskriva",
    "pantförskrivits": "pantförskriva",
    "pantförskrivna": "pantförskriva",
    "pantförskrivnas": "pantförskriva",
    "pantförskrivne": "pantförskriva",
    "pantförskrivnes": "pantförskriva",
    "pantförskrivs": "pantförskriva",
    "panthavar": "panthavare",
    "panthavaren": "panthavare",
    "panthavarens": "panthavare",
    "panthavares": "panthavare",
    "panthavarna": "panthavare",
    "panthavarnas": "panthavare",
    "pantlånar": "pantlånare",
    "pantlånaren": "pantlånare",
    "pantlånarens": "pantlånare",
    "pantlånares": "pantlånare",
    "pantlånarna": "pantlånare",
    "pantlånarnas": "pantlånare",
    "pantlånen": "pantlån",
    "pantlånens": "pantlån",
    "pantlånerörelsen": "pantlånerörelse",
    "pantlånerörelsens": "pantlånerörelse",
    "pantlånerörelser": "pantlånerörelse",
    "pantlånerörelserna": "pantlånerörelse",
    "pantlånerörelsernas": "pantlånerörelse",
    "pantlånerörelsers": "pantlånerörelse",
    "pantlånerörelses": "pantlånerörelse",
    "pantlånet": "pantlån",
    "pantlånets": "pantlån",
    "pantlåns": "pantlån",
    "pantografen": "pantograf",
    "pantografens": "pantograf",
    "pantografer": "pantograf",
    "pantograferad": "pantografera",
    "pantograferade": "pantografera",
    "pantograferades": "pantografera",
    "pantograferads": "pantografera",
    "pantograferande": "pantografera",
    "pantograferanden": "pantograferande",
    "pantograferandena": "pantograferande",
    "pantograferandenas": "pantograferande",
    "pantograferandens": "pantograferande",
    "pantograferandes": "pantograferande",
    "pantograferandet": "pantograferande",
    "pantograferandets": "pantograferande",
    "pantograferar": "pantografera",
    "pantograferas": "pantografera",
    "pantograferat": "pantografera",
    "pantograferats": "pantografera",
    "pantograferbara": "pantograferbar",
    "pantograferbarare": "pantograferbar",
    "pantograferbarares": "pantograferbar",
    "pantograferbaras": "pantograferbar",
    "pantograferbarast": "pantograferbar",
    "pantograferbaraste": "pantograferbar",
    "pantograferbarastes": "pantograferbar",
    "pantograferbarasts": "pantograferbar",
    "pantograferbare": "pantograferbar",
    "pantograferbares": "pantograferbar",
    "pantograferbarheten": "pantograferbarhet",
    "pantograferbarhetens": "pantograferbarhet",
    "pantograferbarhets": "pantograferbarhet",
    "pantograferbars": "pantograferbar",
    "pantograferbart": "pantograferbar",
    "pantograferbarts": "pantograferbar",
    "pantograferingar": "pantografering",
    "pantograferingarna": "pantografering",
    "pantograferingarnas": "pantografering",
    "pantograferingars": "pantografering",
    "pantograferingen": "pantografering",
    "pantograferingens": "pantografering",
    "pantograferings": "pantografering",
    "pantograferna": "pantograf",
    "pantografernas": "pantograf",
    "pantografers": "pantograf",
    "pantografs": "pantograf",
    "pantomimen": "pantomim",
    "pantomimens": "pantomim",
    "pantomimer": "pantomim",
    "pantomimerna": "pantomim",
    "pantomimernas": "pantomim",
    "pantomimers": "pantomim",
    "pantomimiska": "pantomimisk",
    "pantomimiskare": "pantomimisk",
    "pantomimiskares": "pantomimisk",
    "pantomimiskas": "pantomimisk",
    "pantomimiskast": "pantomimisk",
    "pantomimiskaste": "pantomimisk",
    "pantomimiskastes": "pantomimisk",
    "pantomimiskasts": "pantomimisk",
    "pantomimiske": "pantomimisk",
    "pantomimiskes": "pantomimisk",
    "pantomimisks": "pantomimisk",
    "pantomimiskt": "pantomimisk",
    "pantomimiskts": "pantomimisk",
    "pantomims": "pantomim",
    "pantrar": "panter",
    "pantrarna": "panter",
    "pantrarnas": "panter",
    "pantrars": "panter",
    "panträtten": "panträtt",
    "panträttens": "panträtt",
    "panträtter": "panträtt",
    "panträtterna": "panträtt",
    "panträtternas": "panträtt",
    "panträtters": "panträtt",
    "panträtts": "panträtt",
    "pants": "pant",
    "pantsatt": "pantsätta",
    "pantsatta": "pantsätta",
    "pantsattas": "pantsätta",
    "pantsatte": "pantsätta",
    "pantsattes": "pantsätta",
    "pantsatts": "pantsätta",
    "pantsätt": "pantsätta",
    "pantsättande": "pantsätta",
    "pantsättanden": "pantsättande",
    "pantsättandena": "pantsättande",
    "pantsättandenas": "pantsättande",
    "pantsättandens": "pantsättande",
    "pantsättandes": "pantsättande",
    "pantsättandet": "pantsättande",
    "pantsättandets": "pantsättande",
    "pantsättar": "pantsättare",
    "pantsättaren": "pantsättare",
    "pantsättarens": "pantsättare",
    "pantsättares": "pantsättare",
    "pantsättarna": "pantsättare",
    "pantsättarnas": "pantsättare",
    "pantsättas": "pantsätta",
    "pantsätter": "pantsätta",
    "pantsättes": "pantsätta",
    "pantsätts": "pantsätta",
    "papaverinen": "papaverin",
    "papaverinens": "papaverin",
    "papaverinet": "papaverin",
    "papaverinets": "papaverin",
    "papaverins": "papaverin",
    "papay": "papaya",
    "papayan": "papaya",
    "papayans": "papaya",
    "papayas": "papaya",
    "papaye": "papaya",
    "papayor": "papaya",
    "papayorna": "papaya",
    "papayornas": "papaya",
    "papayors": "papaya",
    "papays": "papaya",
    "papegoj": "papegoja",
    "papegojan": "papegoja",
    "papegojans": "papegoja",
    "papegojas": "papegoja",
    "papegoje": "papegoja",
    "papegojfiskar": "papegojfisk",
    "papegojfiskarna": "papegojfisk",
    "papegojfiskarnas": "papegojfisk",
    "papegojfiskars": "papegojfisk",
    "papegojfisken": "papegojfisk",
    "papegojfiskens": "papegojfisk",
    "papegojfisks": "papegojfisk",
    "papegojor": "papegoja",
    "papegojorna": "papegoja",
    "papegojornas": "papegoja",
    "papegojors": "papegoja",
    "papegojs": "papegoja",
    "papegojsjukan": "papegojsjuka",
    "papegojsjukans": "papegojsjuka",
    "papegojsjukas": "papegojsjuka",
    "papegojsjuke": "papegojsjuka",
    "papegojsjuks": "papegojsjuka",
    "papegojtulpanen": "papegojtulpan",
    "papegojtulpanens": "papegojtulpan",
    "papegojtulpaner": "papegojtulpan",
    "papegojtulpanerna": "papegojtulpan",
    "papegojtulpanernas": "papegojtulpan",
    "papegojtulpaners": "papegojtulpan",
    "papegojtulpans": "papegojtulpan",
    "paperbacken": "paperback",
    "paperbackens": "paperback",
    "paperbacks": "paperback",
    "paperen": "paper",
    "paperens": "paper",
    "paperet": "paper",
    "paperets": "paper",
    "papers": "paper",
    "papeterier": "papeteri",
    "papeterierna": "papeteri",
    "papeteriernas": "papeteri",
    "papeteriers": "papeteri",
    "papeteriet": "papeteri",
    "papeteriets": "papeteri",
    "papeteris": "papeteri",
    "papeterit": "papeteri",
    "papeterits": "papeteri",
    "papier-machén": "papier-maché",
    "papier-machéns": "papier-maché",
    "papier-machés": "papier-maché",
    "papiljotten": "papiljott",
    "papiljottens": "papiljott",
    "papiljotter": "papiljott",
    "papiljotterna": "papiljott",
    "papiljotternas": "papiljott",
    "papiljotters": "papiljott",
    "papiljotts": "papiljott",
    "papillen": "papill",
    "papillens": "papill",
    "papiller": "papill",
    "papillerna": "papill",
    "papillernas": "papill",
    "papillers": "papill",
    "papillomen": "papillom",
    "papillomens": "papillom",
    "papillomet": "papillom",
    "papillomets": "papillom",
    "papilloms": "papillom",
    "papillonen": "papillon",
    "papillonens": "papillon",
    "papilloner": "papillon",
    "papillonerna": "papillon",
    "papillonernas": "papillon",
    "papilloners": "papillon",
    "papillons": "papillon",
    "papills": "papill",
    "papismen": "papism",
    "papismens": "papism",
    "papismer": "papism",
    "papismerna": "papism",
    "papismernas": "papism",
    "papismers": "papism",
    "papisms": "papism",
    "papistiska": "papistisk",
    "papistiskas": "papistisk",
    "papistiske": "papistisk",
    "papistiskes": "papistisk",
    "papistisks": "papistisk",
    "papistiskt": "papistisk",
    "papistiskts": "papistisk",
    "papjemachén": "papjemaché",
    "papjemachéns": "papjemaché",
    "papjemachés": "papjemaché",
    "pappalediga": "pappaledig",
    "pappaledigare": "pappaledig",
    "pappaledigares": "pappaledig",
    "pappaledigas": "pappaledig",
    "pappaledigast": "pappaledig",
    "pappaledigaste": "pappaledig",
    "pappaledigastes": "pappaledig",
    "pappaledigasts": "pappaledig",
    "pappaledige": "pappaledig",
    "pappalediges": "pappaledig",
    "pappaledigheten": "pappaledighet",
    "pappaledighetens": "pappaledighet",
    "pappaledighets": "pappaledighet",
    "pappaledigs": "pappaledig",
    "pappaledigt": "pappaledig",
    "pappaledigts": "pappaledig",
    "pappan": "pappa",
    "pappans": "pappa",
    "pappas": "pappa",
    "pappbanden": "pappband",
    "pappbandens": "pappband",
    "pappbandet": "pappband",
    "pappbandets": "pappband",
    "pappbands": "pappband",
    "pappburkar": "pappburk",
    "pappburkarna": "pappburk",
    "pappburkarnas": "pappburk",
    "pappburkars": "pappburk",
    "pappburken": "pappburk",
    "pappburkens": "pappburk",
    "pappburks": "pappburk",
    "pappen": "papp",
    "pappenheimar": "pappenheimare",
    "pappenheimaren": "pappenheimare",
    "pappenheimarens": "pappenheimare",
    "pappenheimares": "pappenheimare",
    "pappenheimarna": "pappenheimare",
    "pappenheimarnas": "pappenheimare",
    "pappens": "papp",
    "papperen": "papper",
    "papperens": "papper",
    "papperet": "papper",
    "papperets": "papper",
    "papperna": "papper",
    "pappernas": "papper",
    "pappers": "papper",
    "pappersarbeten": "pappersarbete",
    "pappersarbetena": "pappersarbete",
    "pappersarbetenas": "pappersarbete",
    "pappersarbetens": "pappersarbete",
    "pappersarbetes": "pappersarbete",
    "pappersarbetet": "pappersarbete",
    "pappersarbetets": "pappersarbete",
    "pappersarbets": "pappersarbete",
    "pappersarken": "pappersark",
    "pappersarkens": "pappersark",
    "pappersarket": "pappersark",
    "pappersarkets": "pappersark",
    "pappersarks": "pappersark",
    "pappersbitar": "pappersbit",
    "pappersbitarna": "pappersbit",
    "pappersbitarnas": "pappersbit",
    "pappersbitars": "pappersbit",
    "pappersbiten": "pappersbit",
    "pappersbitens": "pappersbit",
    "pappersbits": "pappersbit",
    "pappersblom": "pappersblomma",
    "pappersblomman": "pappersblomma",
    "pappersblommans": "pappersblomma",
    "pappersblommas": "pappersblomma",
    "pappersblomme": "pappersblomma",
    "pappersblommor": "pappersblomma",
    "pappersblommorna": "pappersblomma",
    "pappersblommornas": "pappersblomma",
    "pappersblommors": "pappersblomma",
    "pappersbloms": "pappersblomma",
    "pappersbruken": "pappersbruk",
    "pappersbrukens": "pappersbruk",
    "pappersbruket": "pappersbruk",
    "pappersbrukets": "pappersbruk",
    "pappersbruks": "pappersbruk",
    "pappersbuntar": "pappersbunt",
    "pappersbuntarna": "pappersbunt",
    "pappersbuntarnas": "pappersbunt",
    "pappersbuntars": "pappersbunt",
    "pappersbunten": "pappersbunt",
    "pappersbuntens": "pappersbunt",
    "pappersbunts": "pappersbunt",
    "pappersexercisen": "pappersexercis",
    "pappersexercisens": "pappersexercis",
    "pappersformaten": "pappersformat",
    "pappersformatens": "pappersformat",
    "pappersformatet": "pappersformat",
    "pappersformatets": "pappersformat",
    "pappersformats": "pappersformat",
    "pappershanddukar": "pappershandduk",
    "pappershanddukarna": "pappershandduk",
    "pappershanddukarnas": "pappershandduk",
    "pappershanddukars": "pappershandduk",
    "pappershandduken": "pappershandduk",
    "pappershanddukens": "pappershandduk",
    "pappershandduks": "pappershandduk",
    "pappershandeln": "pappershandel",
    "pappershandelns": "pappershandel",
    "pappershandels": "pappershandel",
    "pappershandlar": "pappershandel",
    "pappershandlarna": "pappershandel",
    "pappershandlarnas": "pappershandel",
    "pappershandlars": "pappershandel",
    "pappersinsamlingar": "pappersinsamling",
    "pappersinsamlingarna": "pappersinsamling",
    "pappersinsamlingarnas": "pappersinsamling",
    "pappersinsamlingars": "pappersinsamling",
    "pappersinsamlingen": "pappersinsamling",
    "pappersinsamlingens": "pappersinsamling",
    "pappersinsamlings": "pappersinsamling",
    "papperskass": "papperskasse",
    "papperskassar": "papperskasse",
    "papperskassarna": "papperskasse",
    "papperskassarnas": "papperskasse",
    "papperskassars": "papperskasse",
    "papperskassen": "papperskasse",
    "papperskassens": "papperskasse",
    "papperskasses": "papperskasse",
    "pappersklämman": "pappersklämma",
    "pappersklämmans": "pappersklämma",
    "pappersklämmas": "pappersklämma",
    "pappersklämme": "pappersklämma",
    "pappersklämmor": "pappersklämma",
    "pappersklämmorna": "pappersklämma",
    "pappersklämmornas": "pappersklämma",
    "pappersklämmors": "pappersklämma",
    "pappersknivar": "papperskniv",
    "pappersknivarna": "papperskniv",
    "pappersknivarnas": "papperskniv",
    "pappersknivars": "papperskniv",
    "papperskniven": "papperskniv",
    "pappersknivens": "papperskniv",
    "pappersknivs": "papperskniv",
    "papperskorgar": "papperskorg",
    "papperskorgarna": "papperskorg",
    "papperskorgarnas": "papperskorg",
    "papperskorgars": "papperskorg",
    "papperskorgen": "papperskorg",
    "papperskorgens": "papperskorg",
    "papperskorgs": "papperskorg",
    "papperskul": "papperskula",
    "papperskulan": "papperskula",
    "papperskulans": "papperskula",
    "papperskulas": "papperskula",
    "papperskule": "papperskula",
    "papperskulor": "papperskula",
    "papperskulorna": "papperskula",
    "papperskulornas": "papperskula",
    "papperskulors": "papperskula",
    "papperskuls": "papperskula",
    "papperskvarnar": "papperskvarn",
    "papperskvarnarna": "papperskvarn",
    "papperskvarnarnas": "papperskvarn",
    "papperskvarnars": "papperskvarn",
    "papperskvarnen": "papperskvarn",
    "papperskvarnens": "papperskvarn",
    "papperskvarns": "papperskvarn",
    "papperslappar": "papperslapp",
    "papperslapparna": "papperslapp",
    "papperslapparnas": "papperslapp",
    "papperslappars": "papperslapp",
    "papperslappen": "papperslapp",
    "papperslappens": "papperslapp",
    "papperslapps": "papperslapp",
    "papperslumpen": "papperslump",
    "papperslumpens": "papperslump",
    "papperslumps": "papperslump",
    "papperslösa": "papperslös",
    "papperslösare": "papperslös",
    "papperslösares": "papperslös",
    "papperslösas": "papperslös",
    "papperslösast": "papperslös",
    "papperslösaste": "papperslös",
    "papperslösastes": "papperslös",
    "papperslösasts": "papperslös",
    "papperslöse": "papperslös",
    "papperslöses": "papperslös",
    "papperslöst": "papperslös",
    "papperslösts": "papperslös",
    "pappersmaskinen": "pappersmaskin",
    "pappersmaskinens": "pappersmaskin",
    "pappersmaskiner": "pappersmaskin",
    "pappersmaskinerna": "pappersmaskin",
    "pappersmaskinernas": "pappersmaskin",
    "pappersmaskiners": "pappersmaskin",
    "pappersmaskins": "pappersmaskin",
    "pappersmassan": "pappersmassa",
    "pappersmassans": "pappersmassa",
    "pappersmassas": "pappersmassa",
    "pappersmasse": "pappersmassa",
    "pappersmuggar": "pappersmugg",
    "pappersmuggarna": "pappersmugg",
    "pappersmuggarnas": "pappersmugg",
    "pappersmuggars": "pappersmugg",
    "pappersmuggen": "pappersmugg",
    "pappersmuggens": "pappersmugg",
    "pappersmuggs": "pappersmugg",
    "pappersmyntfoten": "pappersmyntfot",
    "pappersmyntfotens": "pappersmyntfot",
    "pappersmyntfots": "pappersmyntfot",
    "pappersnäsdukar": "pappersnäsduk",
    "pappersnäsdukarna": "pappersnäsduk",
    "pappersnäsdukarnas": "pappersnäsduk",
    "pappersnäsdukars": "pappersnäsduk",
    "pappersnäsduken": "pappersnäsduk",
    "pappersnäsdukens": "pappersnäsduk",
    "pappersnäsduks": "pappersnäsduk",
    "papperspell": "papperspelle",
    "papperspellar": "papperspelle",
    "papperspellarna": "papperspelle",
    "papperspellarnas": "papperspelle",
    "papperspellars": "papperspelle",
    "papperspellen": "papperspelle",
    "papperspellens": "papperspelle",
    "papperspelles": "papperspelle",
    "papperspells": "papperspelle",
    "papperspengar": "papperspeng",
    "papperspengarna": "papperspeng",
    "papperspengarnas": "papperspeng",
    "papperspengars": "papperspeng",
    "papperspengen": "papperspeng",
    "papperspengens": "papperspeng",
    "papperspengs": "papperspeng",
    "papperspås": "papperspåse",
    "papperspåsar": "papperspåse",
    "papperspåsarna": "papperspåse",
    "papperspåsarnas": "papperspåse",
    "papperspåsars": "papperspåse",
    "papperspåsen": "papperspåse",
    "papperspåsens": "papperspåse",
    "papperspåses": "papperspåse",
    "pappersrems": "pappersremsa",
    "pappersremsan": "pappersremsa",
    "pappersremsans": "pappersremsa",
    "pappersremsas": "pappersremsa",
    "pappersremse": "pappersremsa",
    "pappersremsor": "pappersremsa",
    "pappersremsorna": "pappersremsa",
    "pappersremsornas": "pappersremsa",
    "pappersremsors": "pappersremsa",
    "papperssaxar": "papperssax",
    "papperssaxarna": "papperssax",
    "papperssaxarnas": "papperssax",
    "papperssaxars": "papperssax",
    "papperssaxen": "papperssax",
    "papperssaxens": "papperssax",
    "pappersservetten": "pappersservett",
    "pappersservettens": "pappersservett",
    "pappersservetter": "pappersservett",
    "pappersservetterna": "pappersservett",
    "pappersservetternas": "pappersservett",
    "pappersservetters": "pappersservett",
    "pappersservetts": "pappersservett",
    "papperssnör": "papperssnöre",
    "papperssnören": "papperssnöre",
    "papperssnörena": "papperssnöre",
    "papperssnörenas": "papperssnöre",
    "papperssnörens": "papperssnöre",
    "papperssnöres": "papperssnöre",
    "papperssnöret": "papperssnöre",
    "papperssnörets": "papperssnöre",
    "papperssnörs": "papperssnöre",
    "pappersstjärnan": "pappersstjärna",
    "pappersstjärnans": "pappersstjärna",
    "pappersstjärnas": "pappersstjärna",
    "pappersstjärne": "pappersstjärna",
    "pappersstjärnor": "pappersstjärna",
    "pappersstjärnorna": "pappersstjärna",
    "pappersstjärnornas": "pappersstjärna",
    "pappersstjärnors": "pappersstjärna",
    "papperssval": "papperssvala",
    "papperssvalan": "papperssvala",
    "papperssvalans": "papperssvala",
    "papperssvalas": "papperssvala",
    "papperssvale": "papperssvala",
    "papperssvalor": "papperssvala",
    "papperssvalorna": "papperssvala",
    "papperssvalornas": "papperssvala",
    "papperssvalors": "papperssvala",
    "papperssvals": "papperssvala",
    "papperssäckar": "papperssäck",
    "papperssäckarna": "papperssäck",
    "papperssäckarnas": "papperssäck",
    "papperssäckars": "papperssäck",
    "papperssäcken": "papperssäck",
    "papperssäckens": "papperssäck",
    "papperssäcks": "papperssäck",
    "papperstallrikar": "papperstallrik",
    "papperstallrikarna": "papperstallrik",
    "papperstallrikarnas": "papperstallrik",
    "papperstallrikars": "papperstallrik",
    "papperstallriken": "papperstallrik",
    "papperstallrikens": "papperstallrik",
    "papperstallriks": "papperstallrik",
    "papperstidningar": "papperstidning",
    "papperstidningarna": "papperstidning",
    "papperstidningarnas": "papperstidning",
    "papperstidningars": "papperstidning",
    "papperstidningen": "papperstidning",
    "papperstidningens": "papperstidning",
    "papperstidnings": "papperstidning",
    "papperstigern": "papperstiger",
    "papperstigerns": "papperstiger",
    "papperstigers": "papperstiger",
    "papperstigrar": "papperstiger",
    "papperstigrarna": "papperstiger",
    "papperstigrarnas": "papperstiger",
    "papperstigrars": "papperstiger",
    "papperstillverkningar": "papperstillverkning",
    "papperstillverkningarna": "papperstillverkning",
    "papperstillverkningarnas": "papperstillverkning",
    "papperstillverkningars": "papperstillverkning",
    "papperstillverkningen": "papperstillverkning",
    "papperstillverkningens": "papperstillverkning",
    "papperstillverknings": "papperstillverkning",
    "papperstussar": "papperstuss",
    "papperstussarna": "papperstuss",
    "papperstussarnas": "papperstuss",
    "papperstussars": "papperstuss",
    "papperstussen": "papperstuss",
    "papperstussens": "papperstuss",
    "pappersupplagan": "pappersupplaga",
    "pappersupplagans": "pappersupplaga",
    "pappersupplagas": "pappersupplaga",
    "pappersupplage": "pappersupplaga",
    "pappersupplagor": "pappersupplaga",
    "pappersupplagorna": "pappersupplaga",
    "pappersupplagornas": "pappersupplaga",
    "pappersupplagors": "pappersupplaga",
    "pappet": "papp",
    "pappets": "papp",
    "pappiga": "pappig",
    "pappigare": "pappig",
    "pappigares": "pappig",
    "pappigas": "pappig",
    "pappigast": "pappig",
    "pappigaste": "pappig",
    "pappigastes": "pappig",
    "pappigasts": "pappig",
    "pappige": "pappig",
    "pappiges": "pappig",
    "pappigheten": "pappighet",
    "pappighetens": "pappighet",
    "pappighets": "pappighet",
    "pappigs": "pappig",
    "pappigt": "pappig",
    "pappigts": "pappig",
    "pappkartongen": "pappkartong",
    "pappkartongens": "pappkartong",
    "pappkartonger": "pappkartong",
    "pappkartongerna": "pappkartong",
    "pappkartongernas": "pappkartong",
    "pappkartongers": "pappkartong",
    "pappkartongs": "pappkartong",
    "pappor": "pappa",
    "papporna": "pappa",
    "pappornas": "pappa",
    "pappors": "pappa",
    "pappren": "papper",
    "papprens": "papper",
    "pappret": "papper",
    "papprets": "papper",
    "papps": "papp",
    "pappskall": "pappskalle",
    "pappskallar": "pappskalle",
    "pappskallarna": "pappskalle",
    "pappskallarnas": "pappskalle",
    "pappskallars": "pappskalle",
    "pappskallen": "pappskalle",
    "pappskallens": "pappskalle",
    "pappskalles": "pappskalle",
    "pappskalls": "pappskalle",
    "pappskyltar": "pappskylt",
    "pappskyltarna": "pappskylt",
    "pappskyltarnas": "pappskylt",
    "pappskyltars": "pappskylt",
    "pappskylten": "pappskylt",
    "pappskyltens": "pappskylt",
    "pappskylts": "pappskylt",
    "pappslöjden": "pappslöjd",
    "pappslöjdens": "pappslöjd",
    "pappslöjds": "pappslöjd",
    "pappspikar": "pappspik",
    "pappspikarna": "pappspik",
    "pappspikarnas": "pappspik",
    "pappspikars": "pappspik",
    "pappspiken": "pappspik",
    "pappspikens": "pappspik",
    "pappspiks": "pappspik",
    "pappurn": "pappurna",
    "pappurnan": "pappurna",
    "pappurnans": "pappurna",
    "pappurnas": "pappurna",
    "pappurne": "pappurna",
    "pappurnor": "pappurna",
    "pappurnorna": "pappurna",
    "pappurnornas": "pappurna",
    "pappurnors": "pappurna",
    "pappurns": "pappurna",
    "paprikan": "paprika",
    "paprikans": "paprika",
    "paprikaringar": "paprikaring",
    "paprikaringarna": "paprikaring",
    "paprikaringarnas": "paprikaring",
    "paprikaringars": "paprikaring",
    "paprikaringen": "paprikaring",
    "paprikaringens": "paprikaring",
    "paprikarings": "paprikaring",
    "paprikas": "paprika",
    "paprikor": "paprika",
    "paprikorna": "paprika",
    "paprikornas": "paprika",
    "paprikors": "paprika",
    "papuan": "papua",
    "papuanen": "papuan",
    "papuanens": "papuan",
    "papuaner": "papuan",
    "papuanerna": "papuan",
    "papuanernas": "papuan",
    "papuaners": "papuan",
    "papuans": "papuan",
    "papuanska": "papuansk",
    "papuanskare": "papuansk",
    "papuanskares": "papuansk",
    "papuanskas": "papuansk",
    "papuanskast": "papuansk",
    "papuanskaste": "papuansk",
    "papuanskastes": "papuansk",
    "papuanskasts": "papuansk",
    "papuanske": "papuansk",
    "papuanskes": "papuansk",
    "papuansks": "papuansk",
    "papuanskt": "papuansk",
    "papuanskts": "papuansk",
    "papuas": "papua",
    "papuasarna": "papua",
    "papuasarnas": "papua",
    "papuasen": "papua",
    "papuasens": "papua",
    "papyren": "papyrus",
    "papyrens": "papyrus",
    "papyrer": "papyrus",
    "papyrerna": "papyrus",
    "papyrernas": "papyrus",
    "papyrers": "papyrus",
    "papyrologien": "papyrologi",
    "papyrologiens": "papyrologi",
    "papyrologin": "papyrologi",
    "papyrologins": "papyrologi",
    "papyrologis": "papyrologi",
    "papyrossen": "papyross",
    "papyrossens": "papyross",
    "papyrosser": "papyross",
    "papyrosserna": "papyross",
    "papyrossernas": "papyross",
    "papyrossers": "papyross",
    "papyrusen": "papyrus",
    "papyrusens": "papyrus",
    "papyrusrull": "papyrusrulle",
    "papyrusrullar": "papyrusrulle",
    "papyrusrullarna": "papyrusrulle",
    "papyrusrullarnas": "papyrusrulle",
    "papyrusrullars": "papyrusrulle",
    "papyrusrullen": "papyrusrulle",
    "papyrusrullens": "papyrusrulle",
    "papyrusrulles": "papyrusrulle",
    "papyrusrulls": "papyrusrulle",
    "par": "para",
    "parabellumar": "parabellum",
    "parabellumarna": "parabellum",
    "parabellumarnas": "parabellum",
    "parabellumars": "parabellum",
    "parabellumen": "parabellum",
    "parabellumens": "parabellum",
    "parabellums": "parabellum",
    "parabeln": "parabel",
    "parabelns": "parabel",
    "parabels": "parabel",
    "parabler": "parabel",
    "parablerna": "parabel",
    "parablernas": "parabel",
    "parablers": "parabel",
    "parabolantennen": "parabolantenn",
    "parabolantennens": "parabolantenn",
    "parabolantenner": "parabolantenn",
    "parabolantennerna": "parabolantenn",
    "parabolantennernas": "parabolantenn",
    "parabolantenners": "parabolantenn",
    "parabolantenns": "parabolantenn",
    "paraboliska": "parabolisk",
    "paraboliskare": "parabolisk",
    "paraboliskares": "parabolisk",
    "paraboliskas": "parabolisk",
    "paraboliskast": "parabolisk",
    "paraboliskaste": "parabolisk",
    "paraboliskastes": "parabolisk",
    "paraboliskasts": "parabolisk",
    "paraboliske": "parabolisk",
    "paraboliskes": "parabolisk",
    "parabolisks": "parabolisk",
    "paraboliskt": "parabolisk",
    "paraboliskts": "parabolisk",
    "paracervikalblockaden": "paracervikalblockad",
    "paracervikalblockadens": "paracervikalblockad",
    "paracervikalblockader": "paracervikalblockad",
    "paracervikalblockaderna": "paracervikalblockad",
    "paracervikalblockadernas": "paracervikalblockad",
    "paracervikalblockaders": "paracervikalblockad",
    "paracervikalblockads": "paracervikalblockad",
    "parad": "para",
    "parade": "para",
    "paraden": "parad",
    "paradens": "parad",
    "paradentiten": "paradentit",
    "paradentitens": "paradentit",
    "paradentiter": "paradentit",
    "paradentiterna": "paradentit",
    "paradentiternas": "paradentit",
    "paradentiters": "paradentit",
    "paradentits": "paradentit",
    "parader": "parad",
    "paraderad": "paradera",
    "paraderade": "paradera",
    "paraderades": "paradera",
    "paraderads": "paradera",
    "paraderande": "paradera",
    "paraderanden": "paraderande",
    "paraderandena": "paraderande",
    "paraderandenas": "paraderande",
    "paraderandens": "paraderande",
    "paraderandes": "paraderande",
    "paraderandet": "paraderande",
    "paraderandets": "paraderande",
    "paraderar": "paradera",
    "paraderas": "paradera",
    "paraderat": "paradera",
    "paraderats": "paradera",
    "paraderbara": "paraderbar",
    "paraderbarare": "paraderbar",
    "paraderbarares": "paraderbar",
    "paraderbaras": "paraderbar",
    "paraderbarast": "paraderbar",
    "paraderbaraste": "paraderbar",
    "paraderbarastes": "paraderbar",
    "paraderbarasts": "paraderbar",
    "paraderbare": "paraderbar",
    "paraderbares": "paraderbar",
    "paraderbarheten": "paraderbarhet",
    "paraderbarhetens": "paraderbarhet",
    "paraderbarhets": "paraderbarhet",
    "paraderbars": "paraderbar",
    "paraderbart": "paraderbar",
    "paraderbarts": "paraderbar",
    "paraderingar": "paradering",
    "paraderingarna": "paradering",
    "paraderingarnas": "paradering",
    "paraderingars": "paradering",
    "paraderingen": "paradering",
    "paraderingens": "paradering",
    "paraderings": "paradering",
    "paraderna": "parad",
    "paradernas": "parad",
    "paraders": "parad",
    "parades": "para",
    "paradexempels": "paradexempel",
    "paradexemplen": "paradexempel",
    "paradexemplens": "paradexempel",
    "paradexemplet": "paradexempel",
    "paradexemplets": "paradexempel",
    "paradgat": "paradgata",
    "paradgatan": "paradgata",
    "paradgatans": "paradgata",
    "paradgatas": "paradgata",
    "paradgate": "paradgata",
    "paradgator": "paradgata",
    "paradgatorna": "paradgata",
    "paradgatornas": "paradgata",
    "paradgators": "paradgata",
    "paradgats": "paradgata",
    "paradigmen": "paradigm",
    "paradigmens": "paradigm",
    "paradigmer": "paradigm",
    "paradigmerna": "paradigm",
    "paradigmernas": "paradigm",
    "paradigmers": "paradigm",
    "paradigmet": "paradigm",
    "paradigmets": "paradigm",
    "paradigms": "paradigm",
    "paradigmskiften": "paradigmskifte",
    "paradigmskiftena": "paradigmskifte",
    "paradigmskiftenas": "paradigmskifte",
    "paradigmskiftens": "paradigmskifte",
    "paradigmskiftes": "paradigmskifte",
    "paradigmskiftet": "paradigmskifte",
    "paradigmskiftets": "paradigmskifte",
    "paradisen": "paradis",
    "paradisens": "paradis",
    "paradiset": "paradis",
    "paradisets": "paradis",
    "paradisfröen": "paradisfrö",
    "paradisfröens": "paradisfrö",
    "paradisfröet": "paradisfrö",
    "paradisfröets": "paradisfrö",
    "paradisfrön": "paradisfrö",
    "paradisfröna": "paradisfrö",
    "paradisfrönas": "paradisfrö",
    "paradisfröns": "paradisfrö",
    "paradisfrös": "paradisfrö",
    "paradisfröt": "paradisfrö",
    "paradisfröts": "paradisfrö",
    "paradisfågeln": "paradisfågel",
    "paradisfågelns": "paradisfågel",
    "paradisfågels": "paradisfågel",
    "paradisfåglar": "paradisfågel",
    "paradisfåglarna": "paradisfågel",
    "paradisfåglarnas": "paradisfågel",
    "paradisfåglars": "paradisfågel",
    "paradisiska": "paradisisk",
    "paradisiskare": "paradisisk",
    "paradisiskares": "paradisisk",
    "paradisiskas": "paradisisk",
    "paradisiskast": "paradisisk",
    "paradisiskaste": "paradisisk",
    "paradisiskastes": "paradisisk",
    "paradisiskasts": "paradisisk",
    "paradisiske": "paradisisk",
    "paradisiskes": "paradisisk",
    "paradisisks": "paradisisk",
    "paradisiskt": "paradisisk",
    "paradisiskts": "paradisisk",
    "paradiskornen": "paradiskorn",
    "paradiskornens": "paradiskorn",
    "paradiskornet": "paradiskorn",
    "paradiskornets": "paradiskorn",
    "paradiskorns": "paradiskorn",
    "paradisstranden": "paradisstrand",
    "paradisstrandens": "paradisstrand",
    "paradisstrands": "paradisstrand",
    "paradisstränder": "paradisstrand",
    "paradisstränderna": "paradisstrand",
    "paradissträndernas": "paradisstrand",
    "paradisstränders": "paradisstrand",
    "paradisäpplen": "paradisäpple",
    "paradisäpplena": "paradisäpple",
    "paradisäpplenas": "paradisäpple",
    "paradisäpplens": "paradisäpple",
    "paradisäpples": "paradisäpple",
    "paradisäpplet": "paradisäpple",
    "paradisäpplets": "paradisäpple",
    "paradisäppls": "paradisäpple",
    "paradmarschen": "paradmarsch",
    "paradmarschens": "paradmarsch",
    "paradmarscher": "paradmarsch",
    "paradmarscherna": "paradmarsch",
    "paradmarschernas": "paradmarsch",
    "paradmarschers": "paradmarsch",
    "paradmarschs": "paradmarsch",
    "paradmässiga": "paradmässig",
    "paradmässigare": "paradmässig",
    "paradmässigares": "paradmässig",
    "paradmässigas": "paradmässig",
    "paradmässigast": "paradmässig",
    "paradmässigaste": "paradmässig",
    "paradmässigastes": "paradmässig",
    "paradmässigasts": "paradmässig",
    "paradmässige": "paradmässig",
    "paradmässiges": "paradmässig",
    "paradmässigs": "paradmässig",
    "paradmässigt": "paradmässig",
    "paradmässigts": "paradmässig",
    "paradmålningar": "paradmålning",
    "paradmålningarna": "paradmålning",
    "paradmålningarnas": "paradmålning",
    "paradmålningars": "paradmålning",
    "paradmålningen": "paradmålning",
    "paradmålningens": "paradmålning",
    "paradmålnings": "paradmålning",
    "paradnummerna": "paradnummer",
    "paradnummernas": "paradnummer",
    "paradnummers": "paradnummer",
    "paradnumren": "paradnummer",
    "paradnumrens": "paradnummer",
    "paradnumret": "paradnummer",
    "paradnumrets": "paradnummer",
    "paradoxala": "paradoxal",
    "paradoxalare": "paradoxal",
    "paradoxalares": "paradoxal",
    "paradoxalas": "paradoxal",
    "paradoxalast": "paradoxal",
    "paradoxalaste": "paradoxal",
    "paradoxalastes": "paradoxal",
    "paradoxalasts": "paradoxal",
    "paradoxale": "paradoxal",
    "paradoxales": "paradoxal",
    "paradoxals": "paradoxal",
    "paradoxalt": "paradoxal",
    "paradoxalts": "paradoxal",
    "paradoxen": "paradox",
    "paradoxens": "paradox",
    "paradoxer": "paradox",
    "paradoxerna": "paradox",
    "paradoxernas": "paradox",
    "paradoxers": "paradox",
    "paradoxmakar": "paradoxmakare",
    "paradoxmakaren": "paradoxmakare",
    "paradoxmakarens": "paradoxmakare",
    "paradoxmakares": "paradoxmakare",
    "paradoxmakarna": "paradoxmakare",
    "paradoxmakarnas": "paradoxmakare",
    "parads": "parad",
    "paraduniformen": "paraduniform",
    "paraduniformens": "paraduniform",
    "paraduniformer": "paraduniform",
    "paraduniformerna": "paraduniform",
    "paraduniformernas": "paraduniform",
    "paraduniformers": "paraduniform",
    "paraduniforms": "paraduniform",
    "paraduppställningar": "paraduppställning",
    "paraduppställningarna": "paraduppställning",
    "paraduppställningarnas": "paraduppställning",
    "paraduppställningars": "paraduppställning",
    "paraduppställningen": "paraduppställning",
    "paraduppställningens": "paraduppställning",
    "paraduppställnings": "paraduppställning",
    "parafasien": "parafasi",
    "parafasiens": "parafasi",
    "parafasier": "parafasi",
    "parafasierna": "parafasi",
    "parafasiernas": "parafasi",
    "parafasiers": "parafasi",
    "parafasin": "parafasi",
    "parafasins": "parafasi",
    "parafasis": "parafasi",
    "paraferad": "parafera",
    "paraferade": "parafera",
    "paraferades": "parafera",
    "paraferads": "parafera",
    "paraferande": "parafera",
    "paraferanden": "paraferande",
    "paraferandena": "paraferande",
    "paraferandenas": "paraferande",
    "paraferandens": "paraferande",
    "paraferandes": "paraferande",
    "paraferandet": "paraferande",
    "paraferandets": "paraferande",
    "paraferar": "parafera",
    "paraferas": "parafera",
    "paraferat": "parafera",
    "paraferats": "parafera",
    "paraferbara": "paraferbar",
    "paraferbarare": "paraferbar",
    "paraferbarares": "paraferbar",
    "paraferbaras": "paraferbar",
    "paraferbarast": "paraferbar",
    "paraferbaraste": "paraferbar",
    "paraferbarastes": "paraferbar",
    "paraferbarasts": "paraferbar",
    "paraferbare": "paraferbar",
    "paraferbares": "paraferbar",
    "paraferbarheten": "paraferbarhet",
    "paraferbarhetens": "paraferbarhet",
    "paraferbarhets": "paraferbarhet",
    "paraferbars": "paraferbar",
    "paraferbart": "paraferbar",
    "paraferbarts": "paraferbar",
    "paraferingar": "parafering",
    "paraferingarna": "parafering",
    "paraferingarnas": "parafering",
    "paraferingars": "parafering",
    "paraferingen": "parafering",
    "paraferingens": "parafering",
    "paraferings": "parafering",
    "paraffinen": "paraffin",
    "paraffinens": "paraffin",
    "paraffinerad": "paraffinera",
    "paraffinerade": "paraffinera",
    "paraffinerades": "paraffinera",
    "paraffinerads": "paraffinera",
    "paraffinerande": "paraffinera",
    "paraffineranden": "paraffinerande",
    "paraffinerandena": "paraffinerande",
    "paraffinerandenas": "paraffinerande",
    "paraffinerandens": "paraffinerande",
    "paraffinerandes": "paraffinerande",
    "paraffinerandet": "paraffinerande",
    "paraffinerandets": "paraffinerande",
    "paraffinerar": "paraffinera",
    "paraffineras": "paraffinera",
    "paraffinerat": "paraffinera",
    "paraffinerats": "paraffinera",
    "paraffinerbara": "paraffinerbar",
    "paraffinerbarare": "paraffinerbar",
    "paraffinerbarares": "paraffinerbar",
    "paraffinerbaras": "paraffinerbar",
    "paraffinerbarast": "paraffinerbar",
    "paraffinerbaraste": "paraffinerbar",
    "paraffinerbarastes": "paraffinerbar",
    "paraffinerbarasts": "paraffinerbar",
    "paraffinerbare": "paraffinerbar",
    "paraffinerbares": "paraffinerbar",
    "paraffinerbarheten": "paraffinerbarhet",
    "paraffinerbarhetens": "paraffinerbarhet",
    "paraffinerbarhets": "paraffinerbarhet",
    "paraffinerbars": "paraffinerbar",
    "paraffinerbart": "paraffinerbar",
    "paraffinerbarts": "paraffinerbar",
    "paraffineringar": "paraffinering",
    "paraffineringarna": "paraffinering",
    "paraffineringarnas": "paraffinering",
    "paraffineringars": "paraffinering",
    "paraffineringen": "paraffinering",
    "paraffineringens": "paraffinering",
    "paraffinerings": "paraffinering",
    "paraffinet": "paraffin",
    "paraffinets": "paraffin",
    "paraffins": "paraffin",
    "parafibern": "parafiber",
    "parafiberns": "parafiber",
    "parafibers": "parafiber",
    "parafibrer": "parafiber",
    "parafibrerna": "parafiber",
    "parafibrernas": "parafiber",
    "parafibrers": "parafiber",
    "parafrasen": "parafras",
    "parafrasens": "parafras",
    "parafraser": "parafras",
    "parafraserad": "parafrasera",
    "parafraserade": "parafrasera",
    "parafraserades": "parafrasera",
    "parafraserads": "parafrasera",
    "parafraserande": "parafrasera",
    "parafraseranden": "parafraserande",
    "parafraserandena": "parafraserande",
    "parafraserandenas": "parafraserande",
    "parafraserandens": "parafraserande",
    "parafraserandes": "parafraserande",
    "parafraserandet": "parafraserande",
    "parafraserandets": "parafraserande",
    "parafraserar": "parafrasera",
    "parafraseras": "parafrasera",
    "parafraserat": "parafrasera",
    "parafraserats": "parafrasera",
    "parafraserbara": "parafraserbar",
    "parafraserbarare": "parafraserbar",
    "parafraserbarares": "parafraserbar",
    "parafraserbaras": "parafraserbar",
    "parafraserbarast": "parafraserbar",
    "parafraserbaraste": "parafraserbar",
    "parafraserbarastes": "parafraserbar",
    "parafraserbarasts": "parafraserbar",
    "parafraserbare": "parafraserbar",
    "parafraserbares": "parafraserbar",
    "parafraserbarheten": "parafraserbarhet",
    "parafraserbarhetens": "parafraserbarhet",
    "parafraserbarhets": "parafraserbarhet",
    "parafraserbars": "parafraserbar",
    "parafraserbart": "parafraserbar",
    "parafraserbarts": "parafraserbar",
    "parafraseringar": "parafrasering",
    "parafraseringarna": "parafrasering",
    "parafraseringarnas": "parafrasering",
    "parafraseringars": "parafrasering",
    "parafraseringen": "parafrasering",
    "parafraseringens": "parafrasering",
    "parafraserings": "parafrasering",
    "parafraserna": "parafras",
    "parafrasernas": "parafras",
    "parafrasers": "parafras",
    "parafrastiska": "parafrastisk",
    "parafrastiskare": "parafrastisk",
    "parafrastiskares": "parafrastisk",
    "parafrastiskas": "parafrastisk",
    "parafrastiskast": "parafrastisk",
    "parafrastiskaste": "parafrastisk",
    "parafrastiskastes": "parafrastisk",
    "parafrastiskasts": "parafrastisk",
    "parafrastiske": "parafrastisk",
    "parafrastiskes": "parafrastisk",
    "parafrastisks": "parafrastisk",
    "parafrastiskt": "parafrastisk",
    "parafrastiskts": "parafrastisk",
    "paragonen": "paragon",
    "paragonens": "paragon",
    "paragoner": "paragon",
    "paragonerna": "paragon",
    "paragonernas": "paragon",
    "paragoners": "paragon",
    "paragons": "paragon",
    "paragrafen": "paragraf",
    "paragrafens": "paragraf",
    "paragrafer": "paragraf",
    "paragraferna": "paragraf",
    "paragrafernas": "paragraf",
    "paragrafers": "paragraf",
    "paragrafryttar": "paragrafryttare",
    "paragrafryttaren": "paragrafryttare",
    "paragrafryttarens": "paragrafryttare",
    "paragrafryttares": "paragrafryttare",
    "paragrafryttarna": "paragrafryttare",
    "paragrafryttarnas": "paragrafryttare",
    "paragrafs": "paragraf",
    "paragrafteckens": "paragraftecken",
    "paragraftecknen": "paragraftecken",
    "paragraftecknens": "paragraftecken",
    "paragraftecknet": "paragraftecken",
    "paragraftecknets": "paragraftecken",
    "paraguayanen": "paraguayan",
    "paraguayanens": "paraguayan",
    "paraguayaner": "paraguayan",
    "paraguayanerna": "paraguayan",
    "paraguayanernas": "paraguayan",
    "paraguayaners": "paraguayan",
    "paraguayans": "paraguayan",
    "paraguayanska": "paraguayansk",
    "paraguayanskan": "paraguayanska",
    "paraguayanskans": "paraguayanska",
    "paraguayanskare": "paraguayansk",
    "paraguayanskares": "paraguayansk",
    "paraguayanskas": "paraguayanska",
    "paraguayanskast": "paraguayansk",
    "paraguayanskaste": "paraguayansk",
    "paraguayanskastes": "paraguayansk",
    "paraguayanskasts": "paraguayansk",
    "paraguayanske": "paraguayanska",
    "paraguayanskes": "paraguayansk",
    "paraguayanskor": "paraguayanska",
    "paraguayanskorna": "paraguayanska",
    "paraguayanskornas": "paraguayanska",
    "paraguayanskors": "paraguayanska",
    "paraguayansks": "paraguayansk",
    "paraguayanskt": "paraguayansk",
    "paraguayanskts": "paraguayansk",
    "paraguayar": "paraguayare",
    "paraguayaren": "paraguayare",
    "paraguayarens": "paraguayare",
    "paraguayares": "paraguayare",
    "paraguayarna": "paraguayare",
    "paraguayarnas": "paraguayare",
    "paraguayska": "paraguaysk",
    "paraguayskare": "paraguaysk",
    "paraguayskares": "paraguaysk",
    "paraguayskas": "paraguaysk",
    "paraguayskast": "paraguaysk",
    "paraguayskaste": "paraguaysk",
    "paraguayskastes": "paraguaysk",
    "paraguayskasts": "paraguaysk",
    "paraguayske": "paraguaysk",
    "paraguayskes": "paraguaysk",
    "paraguaysks": "paraguaysk",
    "paraguayskt": "paraguaysk",
    "paraguayskts": "paraguaysk",
    "paraguayteet": "paraguayte",
    "paraguayteets": "paraguayte",
    "paraguaytes": "paraguayte",
    "paraguaytet": "paraguayte",
    "paraguaytets": "paraguayte",
    "parallaxen": "parallax",
    "parallaxens": "parallax",
    "parallella": "parallell",
    "parallellare": "parallell",
    "parallellares": "parallell",
    "parallellas": "parallell",
    "parallellast": "parallell",
    "parallellaste": "parallell",
    "parallellastes": "parallell",
    "parallellasts": "parallell",
    "parallellaxiomet": "parallellaxiom",
    "parallellaxiomets": "parallellaxiom",
    "parallellaxioms": "parallellaxiom",
    "parallellcirkeln": "parallellcirkel",
    "parallellcirkelns": "parallellcirkel",
    "parallellcirkels": "parallellcirkel",
    "parallellcirklar": "parallellcirkel",
    "parallellcirklarna": "parallellcirkel",
    "parallellcirklarnas": "parallellcirkel",
    "parallellcirklars": "parallellcirkel",
    "parallelldamen": "parallelldam",
    "parallelldamens": "parallelldam",
    "parallelldamer": "parallelldam",
    "parallelldamerna": "parallelldam",
    "parallelldamernas": "parallelldam",
    "parallelldamers": "parallelldam",
    "parallelldams": "parallelldam",
    "parallelle": "parallell",
    "parallellen": "parallell",
    "parallellens": "parallell",
    "parallellepipeden": "parallellepiped",
    "parallellepipedens": "parallellepiped",
    "parallellepipeder": "parallellepiped",
    "parallellepipederna": "parallellepiped",
    "parallellepipedernas": "parallellepiped",
    "parallellepipeders": "parallellepiped",
    "parallellepipeds": "parallellepiped",
    "paralleller": "parallell",
    "parallellerna": "parallell",
    "parallellernas": "parallell",
    "parallellers": "parallell",
    "parallelles": "parallell",
    "parallellfallen": "parallellfall",
    "parallellfallens": "parallellfall",
    "parallellfallet": "parallellfall",
    "parallellfallets": "parallellfall",
    "parallellfalls": "parallellfall",
    "parallellgraden": "parallellgrad",
    "parallellgradens": "parallellgrad",
    "parallellgrader": "parallellgrad",
    "parallellgraderna": "parallellgrad",
    "parallellgradernas": "parallellgrad",
    "parallellgraders": "parallellgrad",
    "parallellgrads": "parallellgrad",
    "parallelliserad": "parallellisera",
    "parallelliserade": "parallellisera",
    "parallelliserades": "parallellisera",
    "parallelliserads": "parallellisera",
    "parallelliserande": "parallellisera",
    "parallelliseranden": "parallelliserande",
    "parallelliserandena": "parallelliserande",
    "parallelliserandenas": "parallelliserande",
    "parallelliserandens": "parallelliserande",
    "parallelliserandes": "parallelliserande",
    "parallelliserandet": "parallelliserande",
    "parallelliserandets": "parallelliserande",
    "parallelliserar": "parallellisera",
    "parallelliseras": "parallellisera",
    "parallelliserat": "parallellisera",
    "parallelliserats": "parallellisera",
    "parallelliserbara": "parallelliserbar",
    "parallelliserbarare": "parallelliserbar",
    "parallelliserbarares": "parallelliserbar",
    "parallelliserbaras": "parallelliserbar",
    "parallelliserbarast": "parallelliserbar",
    "parallelliserbaraste": "parallelliserbar",
    "parallelliserbarastes": "parallelliserbar",
    "parallelliserbarasts": "parallelliserbar",
    "parallelliserbare": "parallelliserbar",
    "parallelliserbares": "parallelliserbar",
    "parallelliserbarheten": "parallelliserbarhet",
    "parallelliserbarhetens": "parallelliserbarhet",
    "parallelliserbarhets": "parallelliserbarhet",
    "parallelliserbars": "parallelliserbar",
    "parallelliserbart": "parallelliserbar",
    "parallelliserbarts": "parallelliserbar",
    "parallelliseringar": "parallellisering",
    "parallelliseringarna": "parallellisering",
    "parallelliseringarnas": "parallellisering",
    "parallelliseringars": "parallellisering",
    "parallelliseringen": "parallellisering",
    "parallelliseringens": "parallellisering",
    "parallelliserings": "parallellisering",
    "parallellismen": "parallellism",
    "parallellismens": "parallellism",
    "parallellismer": "parallellism",
    "parallellismerna": "parallellism",
    "parallellismernas": "parallellism",
    "parallellismers": "parallellism",
    "parallellisms": "parallellism",
    "parallellistiska": "parallellistisk",
    "parallellistiskas": "parallellistisk",
    "parallellistiske": "parallellistisk",
    "parallellistiskes": "parallellistisk",
    "parallellistisks": "parallellistisk",
    "parallellistiskt": "parallellistisk",
    "parallellistiskts": "parallellistisk",
    "parallelliteten": "parallellitet",
    "parallellitetens": "parallellitet",
    "parallelliteter": "parallellitet",
    "parallelliteterna": "parallellitet",
    "parallelliteternas": "parallellitet",
    "parallelliteters": "parallellitet",
    "parallellitets": "parallellitet",
    "parallellklassen": "parallellklass",
    "parallellklassens": "parallellklass",
    "parallellklasser": "parallellklass",
    "parallellklasserna": "parallellklass",
    "parallellklassernas": "parallellklass",
    "parallellklassers": "parallellklass",
    "parallellkopplad": "parallellkoppla",
    "parallellkopplade": "parallellkoppla",
    "parallellkopplades": "parallellkoppla",
    "parallellkopplads": "parallellkoppla",
    "parallellkopplande": "parallellkoppla",
    "parallellkopplanden": "parallellkopplande",
    "parallellkopplandena": "parallellkopplande",
    "parallellkopplandenas": "parallellkopplande",
    "parallellkopplandens": "parallellkopplande",
    "parallellkopplandes": "parallellkopplande",
    "parallellkopplandet": "parallellkopplande",
    "parallellkopplandets": "parallellkopplande",
    "parallellkopplar": "parallellkoppla",
    "parallellkopplas": "parallellkoppla",
    "parallellkopplat": "parallellkoppla",
    "parallellkopplats": "parallellkoppla",
    "parallellkopplingar": "parallellkoppling",
    "parallellkopplingarna": "parallellkoppling",
    "parallellkopplingarnas": "parallellkoppling",
    "parallellkopplingars": "parallellkoppling",
    "parallellkopplingen": "parallellkoppling",
    "parallellkopplingens": "parallellkoppling",
    "parallellkopplings": "parallellkoppling",
    "parallellogrammen": "parallellogram",
    "parallellogrammens": "parallellogram",
    "parallellogrammer": "parallellogram",
    "parallellogrammerna": "parallellogram",
    "parallellogrammernas": "parallellogram",
    "parallellogrammers": "parallellogram",
    "parallellograms": "parallellogram",
    "parallells": "parallell",
    "parallellstagen": "parallellstag",
    "parallellstagens": "parallellstag",
    "parallellstaget": "parallellstag",
    "parallellstagets": "parallellstag",
    "parallellstags": "parallellstag",
    "parallellt": "parallell",
    "parallelltrapetser": "parallelltrapets",
    "parallelltrapetserna": "parallelltrapets",
    "parallelltrapetsernas": "parallelltrapets",
    "parallelltrapetsers": "parallelltrapets",
    "parallelltrapetset": "parallelltrapets",
    "parallelltrapetsets": "parallelltrapets",
    "parallellts": "parallell",
    "parallellvärldar": "parallellvärld",
    "parallellvärldarna": "parallellvärld",
    "parallellvärldarnas": "parallellvärld",
    "parallellvärldars": "parallellvärld",
    "parallellvärlden": "parallellvärld",
    "parallellvärldens": "parallellvärld",
    "parallellvärlds": "parallellvärld",
    "paralysen": "paralys",
    "paralysens": "paralys",
    "paralyser": "paralys",
    "paralyserad": "paralysera",
    "paralyserade": "paralysera",
    "paralyserades": "paralysera",
    "paralyserads": "paralysera",
    "paralyserande": "paralysera",
    "paralyseranden": "paralyserande",
    "paralyserandena": "paralyserande",
    "paralyserandenas": "paralyserande",
    "paralyserandens": "paralyserande",
    "paralyserandes": "paralyserande",
    "paralyserandet": "paralyserande",
    "paralyserandets": "paralyserande",
    "paralyserar": "paralysera",
    "paralyseras": "paralysera",
    "paralyserat": "paralysera",
    "paralyserats": "paralysera",
    "paralyserbara": "paralyserbar",
    "paralyserbarare": "paralyserbar",
    "paralyserbarares": "paralyserbar",
    "paralyserbaras": "paralyserbar",
    "paralyserbarast": "paralyserbar",
    "paralyserbaraste": "paralyserbar",
    "paralyserbarastes": "paralyserbar",
    "paralyserbarasts": "paralyserbar",
    "paralyserbare": "paralyserbar",
    "paralyserbares": "paralyserbar",
    "paralyserbarheten": "paralyserbarhet",
    "paralyserbarhetens": "paralyserbarhet",
    "paralyserbarhets": "paralyserbarhet",
    "paralyserbars": "paralyserbar",
    "paralyserbart": "paralyserbar",
    "paralyserbarts": "paralyserbar",
    "paralyseringar": "paralysering",
    "paralyseringarna": "paralysering",
    "paralyseringarnas": "paralysering",
    "paralyseringars": "paralysering",
    "paralyseringen": "paralysering",
    "paralyseringens": "paralysering",
    "paralyserings": "paralysering",
    "paralyserna": "paralys",
    "paralysernas": "paralys",
    "paralysers": "paralys",
    "paralytikern": "paralytiker",
    "paralytikerna": "paralytiker",
    "paralytikernas": "paralytiker",
    "paralytikerns": "paralytiker",
    "paralytikers": "paralytiker",
    "paralytiska": "paralytisk",
    "paralytiskare": "paralytisk",
    "paralytiskares": "paralytisk",
    "paralytiskas": "paralytisk",
    "paralytiskast": "paralytisk",
    "paralytiskaste": "paralytisk",
    "paralytiskastes": "paralytisk",
    "paralytiskasts": "paralytisk",
    "paralytiske": "paralytisk",
    "paralytiskes": "paralytisk",
    "paralytisks": "paralytisk",
    "paralytiskt": "paralytisk",
    "paralytiskts": "paralytisk",
    "parametern": "parameter",
    "parameterns": "parameter",
    "parameters": "parameter",
    "parametrar": "parameter",
    "parametrarna": "parameter",
    "parametrarnas": "parameter",
    "parametrars": "parameter",
    "paramilitära": "paramilitär",
    "paramilitärare": "paramilitär",
    "paramilitärares": "paramilitär",
    "paramilitäras": "paramilitär",
    "paramilitärast": "paramilitär",
    "paramilitäraste": "paramilitär",
    "paramilitärastes": "paramilitär",
    "paramilitärasts": "paramilitär",
    "paramilitäre": "paramilitär",
    "paramilitäres": "paramilitär",
    "paramilitärs": "paramilitär",
    "paramilitärt": "paramilitär",
    "paramilitärts": "paramilitär",
    "parande": "para",
    "paranden": "parande",
    "parandena": "parande",
    "parandenas": "parande",
    "parandens": "parande",
    "parandes": "parande",
    "parandet": "parande",
    "parandets": "parande",
    "paranoian": "paranoia",
    "paranoians": "paranoia",
    "paranoias": "paranoia",
    "paranoida": "paranoid",
    "paranoidare": "paranoid",
    "paranoidares": "paranoid",
    "paranoidas": "paranoid",
    "paranoidast": "paranoid",
    "paranoidaste": "paranoid",
    "paranoidastes": "paranoid",
    "paranoidasts": "paranoid",
    "paranoide": "paranoid",
    "paranoides": "paranoid",
    "paranoids": "paranoid",
    "paranoikern": "paranoiker",
    "paranoikerna": "paranoiker",
    "paranoikernas": "paranoiker",
    "paranoikerns": "paranoiker",
    "paranoikers": "paranoiker",
    "paranta": "parant",
    "parantare": "parant",
    "parantares": "parant",
    "parantas": "parant",
    "parantast": "parant",
    "parantaste": "parant",
    "parantastes": "parant",
    "parantasts": "parant",
    "parante": "parant",
    "parantes": "parant",
    "parants": "parant",
    "paranöten": "paranöt",
    "paranötens": "paranöt",
    "paranöts": "paranöt",
    "paranötter": "paranöt",
    "paranötterna": "paranöt",
    "paranötternas": "paranöt",
    "paranötters": "paranöt",
    "parapeten": "parapet",
    "parapetens": "parapet",
    "parapeter": "parapet",
    "parapeterna": "parapet",
    "parapeternas": "parapet",
    "parapeters": "parapet",
    "parapets": "parapet",
    "paraplyer": "paraply",
    "paraplyerna": "paraply",
    "paraplyernas": "paraply",
    "paraplyers": "paraply",
    "paraplyet": "paraply",
    "paraplyets": "paraply",
    "paraplyn": "paraply",
    "paraplyna": "paraply",
    "paraplynas": "paraply",
    "paraplyns": "paraply",
    "paraplyorganisationen": "paraplyorganisation",
    "paraplyorganisationens": "paraplyorganisation",
    "paraplyorganisationer": "paraplyorganisation",
    "paraplyorganisationerna": "paraplyorganisation",
    "paraplyorganisationernas": "paraplyorganisation",
    "paraplyorganisationers": "paraplyorganisation",
    "paraplyorganisations": "paraplyorganisation",
    "paraplys": "paraply",
    "paraplyställen": "paraplyställ",
    "paraplyställens": "paraplyställ",
    "paraplystället": "paraplyställ",
    "paraplyställets": "paraplyställ",
    "paraplyställs": "paraplyställ",
    "paraplyt": "paraply",
    "paraplytaken": "paraplytak",
    "paraplytakens": "paraplytak",
    "paraplytaket": "paraplytak",
    "paraplytakets": "paraplytak",
    "paraplytaks": "paraplytak",
    "paraplyts": "paraply",
    "parapsykologien": "parapsykologi",
    "parapsykologiens": "parapsykologi",
    "parapsykologin": "parapsykologi",
    "parapsykologins": "parapsykologi",
    "parapsykologis": "parapsykologi",
    "parar": "para",
    "paras": "para",
    "parasiten": "parasit",
    "parasitens": "parasit",
    "parasiter": "parasit",
    "parasiterade": "parasitera",
    "parasiterades": "parasitera",
    "parasiterande": "parasitera",
    "parasiteranden": "parasiterande",
    "parasiterandena": "parasiterande",
    "parasiterandenas": "parasiterande",
    "parasiterandens": "parasiterande",
    "parasiterandes": "parasiterande",
    "parasiterandet": "parasiterande",
    "parasiterandets": "parasiterande",
    "parasiterar": "parasitera",
    "parasiteras": "parasitera",
    "parasiterat": "parasitera",
    "parasiterats": "parasitera",
    "parasiteringar": "parasitering",
    "parasiteringarna": "parasitering",
    "parasiteringarnas": "parasitering",
    "parasiteringars": "parasitering",
    "parasiteringen": "parasitering",
    "parasiteringens": "parasitering",
    "parasiterings": "parasitering",
    "parasiterna": "parasit",
    "parasiternas": "parasit",
    "parasiters": "parasit",
    "parasitflug": "parasitfluga",
    "parasitflugan": "parasitfluga",
    "parasitflugans": "parasitfluga",
    "parasitflugas": "parasitfluga",
    "parasitfluge": "parasitfluga",
    "parasitflugor": "parasitfluga",
    "parasitflugorna": "parasitfluga",
    "parasitflugornas": "parasitfluga",
    "parasitflugors": "parasitfluga",
    "parasitflugs": "parasitfluga",
    "parasitiska": "parasitisk",
    "parasitiskare": "parasitisk",
    "parasitiskares": "parasitisk",
    "parasitiskas": "parasitisk",
    "parasitiskast": "parasitisk",
    "parasitiskaste": "parasitisk",
    "parasitiskastes": "parasitisk",
    "parasitiskasts": "parasitisk",
    "parasitiske": "parasitisk",
    "parasitiskes": "parasitisk",
    "parasitisks": "parasitisk",
    "parasitiskt": "parasitisk",
    "parasitiskts": "parasitisk",
    "parasitismen": "parasitism",
    "parasitismens": "parasitism",
    "parasitismer": "parasitism",
    "parasitismerna": "parasitism",
    "parasitismernas": "parasitism",
    "parasitismers": "parasitism",
    "parasitisms": "parasitism",
    "parasits": "parasit",
    "parasitära": "parasitär",
    "parasitärare": "parasitär",
    "parasitärares": "parasitär",
    "parasitäras": "parasitär",
    "parasitärast": "parasitär",
    "parasitäraste": "parasitär",
    "parasitärastes": "parasitär",
    "parasitärasts": "parasitär",
    "parasitäre": "parasitär",
    "parasitäres": "parasitär",
    "parasitärs": "parasitär",
    "parasitärt": "parasitär",
    "parasitärts": "parasitär",
    "parasollen": "parasoll",
    "parasollens": "parasoll",
    "parasoller": "parasoll",
    "parasollerna": "parasoll",
    "parasollernas": "parasoll",
    "parasollers": "parasoll",
    "parasollet": "parasoll",
    "parasollets": "parasoll",
    "parasolls": "parasoll",
    "parasömnen": "parasömn",
    "parasömnens": "parasömn",
    "parasömns": "parasömn",
    "parat": "para",
    "parata": "parat",
    "parataktiska": "parataktisk",
    "parataktiskare": "parataktisk",
    "parataktiskares": "parataktisk",
    "parataktiskas": "parataktisk",
    "parataktiskast": "parataktisk",
    "parataktiskaste": "parataktisk",
    "parataktiskastes": "parataktisk",
    "parataktiskasts": "parataktisk",
    "parataktiske": "parataktisk",
    "parataktiskes": "parataktisk",
    "parataktisks": "parataktisk",
    "parataktiskt": "parataktisk",
    "parataktiskts": "parataktisk",
    "paratare": "parat",
    "paratares": "parat",
    "paratas": "parat",
    "paratast": "parat",
    "parataste": "parat",
    "paratastes": "parat",
    "paratasts": "parat",
    "parataxen": "paratax",
    "parataxens": "paratax",
    "parate": "parat",
    "parates": "parat",
    "parats": "parat",
    "paratyfusen": "paratyfus",
    "paratyfusens": "paratyfus",
    "paravanen": "paravan",
    "paravanens": "paravan",
    "paravaner": "paravan",
    "paravanerna": "paravan",
    "paravanernas": "paravan",
    "paravaners": "paravan",
    "paravans": "paravan",
    "parbladiga": "parbladig",
    "parbladigare": "parbladig",
    "parbladigares": "parbladig",
    "parbladigas": "parbladig",
    "parbladigast": "parbladig",
    "parbladigaste": "parbladig",
    "parbladigastes": "parbladig",
    "parbladigasts": "parbladig",
    "parbladige": "parbladig",
    "parbladiges": "parbladig",
    "parbladigs": "parbladig",
    "parbladigt": "parbladig",
    "parbladigts": "parbladig",
    "parcellen": "parcell",
    "parcellens": "parcell",
    "parceller": "parcell",
    "parcellerna": "parcell",
    "parcellernas": "parcell",
    "parcellers": "parcell",
    "parcells": "parcell",
    "parcen": "parce",
    "parcens": "parce",
    "parcer": "parce",
    "parcerna": "parce",
    "parcernas": "parce",
    "parcers": "parce",
    "parces": "parce",
    "pardansen": "pardans",
    "pardansens": "pardans",
    "pardanser": "pardans",
    "pardanserna": "pardans",
    "pardansernas": "pardans",
    "pardansers": "pardans",
    "pardonen": "pardon",
    "pardonens": "pardon",
    "pardons": "pardon",
    "paren": "par",
    "parenkymet": "parenkym",
    "parenkymets": "parenkym",
    "parenkyms": "parenkym",
    "parens": "par",
    "parentationen": "parentation",
    "parentationens": "parentation",
    "parentationer": "parentation",
    "parentationerna": "parentation",
    "parentationernas": "parentation",
    "parentationers": "parentation",
    "parentations": "parentation",
    "parentatorer": "parentator",
    "parentatorerna": "parentator",
    "parentatorernas": "parentator",
    "parentatorers": "parentator",
    "parentatorn": "parentator",
    "parentatorns": "parentator",
    "parentators": "parentator",
    "parenterade": "parentera",
    "parenterades": "parentera",
    "parenterande": "parentera",
    "parenteranden": "parenterande",
    "parenterandena": "parenterande",
    "parenterandenas": "parenterande",
    "parenterandens": "parenterande",
    "parenterandes": "parenterande",
    "parenterandet": "parenterande",
    "parenterandets": "parenterande",
    "parenterar": "parentera",
    "parenteras": "parentera",
    "parenterat": "parentera",
    "parenterats": "parentera",
    "parenteringar": "parentering",
    "parenteringarna": "parentering",
    "parenteringarnas": "parentering",
    "parenteringars": "parentering",
    "parenteringen": "parentering",
    "parenteringens": "parentering",
    "parenterings": "parentering",
    "parentesen": "parentes",
    "parentesens": "parentes",
    "parenteser": "parentes",
    "parenteserna": "parentes",
    "parentesernas": "parentes",
    "parentesers": "parentes",
    "parentesteckens": "parentestecken",
    "parentestecknen": "parentestecken",
    "parentestecknens": "parentestecken",
    "parentestecknet": "parentestecken",
    "parentestecknets": "parentestecken",
    "parentetiska": "parentetisk",
    "parentetiskare": "parentetisk",
    "parentetiskares": "parentetisk",
    "parentetiskas": "parentetisk",
    "parentetiskast": "parentetisk",
    "parentetiskaste": "parentetisk",
    "parentetiskastes": "parentetisk",
    "parentetiskasts": "parentetisk",
    "parentetiske": "parentetisk",
    "parentetiskes": "parentetisk",
    "parentetisks": "parentetisk",
    "parentetiskt": "parentetisk",
    "parentetiskts": "parentetisk",
    "parerad": "parera",
    "parerade": "parera",
    "parerades": "parera",
    "parerads": "parera",
    "parerande": "parera",
    "pareranden": "parerande",
    "parerandena": "parerande",
    "parerandenas": "parerande",
    "parerandens": "parerande",
    "parerandes": "parerande",
    "parerandet": "parerande",
    "parerandets": "parerande",
    "parerar": "parera",
    "pareras": "parera",
    "parerat": "parera",
    "parerats": "parera",
    "parerbara": "parerbar",
    "parerbarare": "parerbar",
    "parerbarares": "parerbar",
    "parerbaras": "parerbar",
    "parerbarast": "parerbar",
    "parerbaraste": "parerbar",
    "parerbarastes": "parerbar",
    "parerbarasts": "parerbar",
    "parerbare": "parerbar",
    "parerbares": "parerbar",
    "parerbarheten": "parerbarhet",
    "parerbarhetens": "parerbarhet",
    "parerbarhets": "parerbarhet",
    "parerbars": "parerbar",
    "parerbart": "parerbar",
    "parerbarts": "parerbar",
    "pareringar": "parering",
    "pareringarna": "parering",
    "pareringarnas": "parering",
    "pareringars": "parering",
    "pareringen": "parering",
    "pareringens": "parering",
    "parerings": "parering",
    "parerplåtar": "parerplåt",
    "parerplåtarna": "parerplåt",
    "parerplåtarnas": "parerplåt",
    "parerplåtars": "parerplåt",
    "parerplåten": "parerplåt",
    "parerplåtens": "parerplåt",
    "parerplåts": "parerplåt",
    "parerstänger": "parerstång",
    "parerstängerna": "parerstång",
    "parerstängernas": "parerstång",
    "parerstängers": "parerstång",
    "parerstången": "parerstång",
    "parerstångens": "parerstång",
    "parerstångs": "parerstång",
    "paresen": "pares",
    "paresens": "pares",
    "pareser": "pares",
    "pareserna": "pares",
    "paresernas": "pares",
    "paresers": "pares",
    "paret": "par",
    "parets": "par",
    "parfaiten": "parfait",
    "parfaitens": "parfait",
    "parfaiter": "parfait",
    "parfaiterna": "parfait",
    "parfaiternas": "parfait",
    "parfaiters": "parfait",
    "parfaits": "parfait",
    "parflikiga": "parflikig",
    "parflikigare": "parflikig",
    "parflikigares": "parflikig",
    "parflikigas": "parflikig",
    "parflikigast": "parflikig",
    "parflikigaste": "parflikig",
    "parflikigastes": "parflikig",
    "parflikigasts": "parflikig",
    "parflikige": "parflikig",
    "parflikiges": "parflikig",
    "parflikigs": "parflikig",
    "parflikigt": "parflikig",
    "parflikigts": "parflikig",
    "parfymaffären": "parfymaffär",
    "parfymaffärens": "parfymaffär",
    "parfymaffärer": "parfymaffär",
    "parfymaffärerna": "parfymaffär",
    "parfymaffärernas": "parfymaffär",
    "parfymaffärers": "parfymaffär",
    "parfymaffärs": "parfymaffär",
    "parfymen": "parfym",
    "parfymens": "parfym",
    "parfymer": "parfym",
    "parfymerad": "parfymera",
    "parfymerade": "parfymera",
    "parfymerades": "parfymera",
    "parfymerads": "parfymera",
    "parfymerande": "parfymera",
    "parfymeranden": "parfymerande",
    "parfymerandena": "parfymerande",
    "parfymerandenas": "parfymerande",
    "parfymerandens": "parfymerande",
    "parfymerandes": "parfymerande",
    "parfymerandet": "parfymerande",
    "parfymerandets": "parfymerande",
    "parfymerar": "parfymera",
    "parfymeras": "parfymera",
    "parfymerat": "parfymera",
    "parfymerats": "parfymera",
    "parfymerbara": "parfymerbar",
    "parfymerbarare": "parfymerbar",
    "parfymerbarares": "parfymerbar",
    "parfymerbaras": "parfymerbar",
    "parfymerbarast": "parfymerbar",
    "parfymerbaraste": "parfymerbar",
    "parfymerbarastes": "parfymerbar",
    "parfymerbarasts": "parfymerbar",
    "parfymerbare": "parfymerbar",
    "parfymerbares": "parfymerbar",
    "parfymerbarheten": "parfymerbarhet",
    "parfymerbarhetens": "parfymerbarhet",
    "parfymerbarhets": "parfymerbarhet",
    "parfymerbars": "parfymerbar",
    "parfymerbart": "parfymerbar",
    "parfymerbarts": "parfymerbar",
    "parfymerier": "parfymeri",
    "parfymerierna": "parfymeri",
    "parfymeriernas": "parfymeri",
    "parfymeriers": "parfymeri",
    "parfymeriet": "parfymeri",
    "parfymeriets": "parfymeri",
    "parfymeringar": "parfymering",
    "parfymeringarna": "parfymering",
    "parfymeringarnas": "parfymering",
    "parfymeringars": "parfymering",
    "parfymeringen": "parfymering",
    "parfymeringens": "parfymering",
    "parfymerings": "parfymering",
    "parfymeris": "parfymeri",
    "parfymerit": "parfymeri",
    "parfymerits": "parfymeri",
    "parfymerna": "parfym",
    "parfymernas": "parfym",
    "parfymers": "parfym",
    "parfymflask": "parfymflaska",
    "parfymflaskan": "parfymflaska",
    "parfymflaskans": "parfymflaska",
    "parfymflaskas": "parfymflaska",
    "parfymflaske": "parfymflaska",
    "parfymflaskor": "parfymflaska",
    "parfymflaskorna": "parfymflaska",
    "parfymflaskornas": "parfymflaska",
    "parfymflaskors": "parfymflaska",
    "parfyms": "parfym",
    "parförhållanden": "parförhållande",
    "parförhållandena": "parförhållande",
    "parförhållandenas": "parförhållande",
    "parförhållandens": "parförhållande",
    "parförhållandes": "parförhållande",
    "parförhållandet": "parförhållande",
    "parförhållandets": "parförhållande",
    "parhusen": "parhus",
    "parhusens": "parhus",
    "parhuset": "parhus",
    "parhusets": "parhus",
    "parhästar": "parhäst",
    "parhästarna": "parhäst",
    "parhästarnas": "parhäst",
    "parhästars": "parhäst",
    "parhästen": "parhäst",
    "parhästens": "parhäst",
    "parhästs": "parhäst",
    "parian": "paria",
    "parianen": "parian",
    "parianens": "parian",
    "parians": "parian",
    "parias": "paria",
    "pariga": "parig",
    "parigare": "parig",
    "parigares": "parig",
    "parigas": "parig",
    "parigast": "parig",
    "parigaste": "parig",
    "parigastes": "parig",
    "parigasts": "parig",
    "parige": "parig",
    "pariges": "parig",
    "parigs": "parig",
    "parigt": "parig",
    "parigts": "parig",
    "parior": "paria",
    "pariorna": "paria",
    "pariornas": "paria",
    "pariors": "paria",
    "paris": "pari",
    "pariserhjulen": "pariserhjul",
    "pariserhjulens": "pariserhjul",
    "pariserhjulet": "pariserhjul",
    "pariserhjulets": "pariserhjul",
    "pariserhjuls": "pariserhjul",
    "pariserlivet": "pariserliv",
    "pariserlivets": "pariserliv",
    "pariserlivs": "pariserliv",
    "parisersmörgåsar": "parisersmörgås",
    "parisersmörgåsarna": "parisersmörgås",
    "parisersmörgåsarnas": "parisersmörgås",
    "parisersmörgåsars": "parisersmörgås",
    "parisersmörgåsen": "parisersmörgås",
    "parisersmörgåsens": "parisersmörgås",
    "parisfrisyren": "parisfrisyr",
    "parisfrisyrens": "parisfrisyr",
    "parisfrisyrer": "parisfrisyr",
    "parisfrisyrerna": "parisfrisyr",
    "parisfrisyrernas": "parisfrisyr",
    "parisfrisyrers": "parisfrisyr",
    "parisfrisyrs": "parisfrisyr",
    "parisiska": "parisisk",
    "parisiskare": "parisisk",
    "parisiskares": "parisisk",
    "parisiskas": "parisisk",
    "parisiskast": "parisisk",
    "parisiskaste": "parisisk",
    "parisiskastes": "parisisk",
    "parisiskasts": "parisisk",
    "parisiske": "parisisk",
    "parisiskes": "parisisk",
    "parisisks": "parisisk",
    "parisiskt": "parisisk",
    "parisiskts": "parisisk",
    "parismodes": "parismode",
    "parismodet": "parismode",
    "parismodets": "parismode",
    "parit": "pari",
    "pariteten": "paritet",
    "paritetens": "paritet",
    "pariteter": "paritet",
    "pariteterna": "paritet",
    "pariteternas": "paritet",
    "pariteters": "paritet",
    "paritets": "paritet",
    "parits": "pari",
    "parkasar": "parkas",
    "parkasarna": "parkas",
    "parkasarnas": "parkas",
    "parkasars": "parkas",
    "parkasen": "parkas",
    "parkasens": "parkas",
    "parkaser": "parkas",
    "parkaserna": "parkas",
    "parkasernas": "parkas",
    "parkasers": "parkas",
    "parkbänkar": "parkbänk",
    "parkbänkarna": "parkbänk",
    "parkbänkarnas": "parkbänk",
    "parkbänkars": "parkbänk",
    "parkbänken": "parkbänk",
    "parkbänkens": "parkbänk",
    "parkbänks": "parkbänk",
    "parken": "park",
    "parkens": "park",
    "parker": "park",
    "parkerad": "parkera",
    "parkerade": "parkera",
    "parkerades": "parkera",
    "parkerads": "parkera",
    "parkerande": "parkera",
    "parkeranden": "parkerande",
    "parkerandena": "parkerande",
    "parkerandenas": "parkerande",
    "parkerandens": "parkerande",
    "parkerandes": "parkerande",
    "parkerandet": "parkerande",
    "parkerandets": "parkerande",
    "parkerar": "parkera",
    "parkeras": "parkera",
    "parkerat": "parkera",
    "parkerats": "parkera",
    "parkerbara": "parkerbar",
    "parkerbarare": "parkerbar",
    "parkerbarares": "parkerbar",
    "parkerbaras": "parkerbar",
    "parkerbarast": "parkerbar",
    "parkerbaraste": "parkerbar",
    "parkerbarastes": "parkerbar",
    "parkerbarasts": "parkerbar",
    "parkerbare": "parkerbar",
    "parkerbares": "parkerbar",
    "parkerbarheten": "parkerbarhet",
    "parkerbarhetens": "parkerbarhet",
    "parkerbarhets": "parkerbarhet",
    "parkerbars": "parkerbar",
    "parkerbart": "parkerbar",
    "parkerbarts": "parkerbar",
    "parkeringar": "parkering",
    "parkeringarna": "parkering",
    "parkeringarnas": "parkering",
    "parkeringars": "parkering",
    "parkeringen": "parkering",
    "parkeringens": "parkering",
    "parkerings": "parkering",
    "parkeringsautomaten": "parkeringsautomat",
    "parkeringsautomatens": "parkeringsautomat",
    "parkeringsautomater": "parkeringsautomat",
    "parkeringsautomaterna": "parkeringsautomat",
    "parkeringsautomaternas": "parkeringsautomat",
    "parkeringsautomaters": "parkeringsautomat",
    "parkeringsautomats": "parkeringsautomat",
    "parkeringsavgiften": "parkeringsavgift",
    "parkeringsavgiftens": "parkeringsavgift",
    "parkeringsavgifter": "parkeringsavgift",
    "parkeringsavgifterna": "parkeringsavgift",
    "parkeringsavgifternas": "parkeringsavgift",
    "parkeringsavgifters": "parkeringsavgift",
    "parkeringsavgifts": "parkeringsavgift",
    "parkeringsboten": "parkeringsbot",
    "parkeringsbotens": "parkeringsbot",
    "parkeringsbots": "parkeringsbot",
    "parkeringsbromsar": "parkeringsbroms",
    "parkeringsbromsarna": "parkeringsbroms",
    "parkeringsbromsarnas": "parkeringsbroms",
    "parkeringsbromsars": "parkeringsbroms",
    "parkeringsbromsen": "parkeringsbroms",
    "parkeringsbromsens": "parkeringsbroms",
    "parkeringsböter": "parkeringsbot",
    "parkeringsböterna": "parkeringsbot",
    "parkeringsböternas": "parkeringsbot",
    "parkeringsböters": "parkeringsbot",
    "parkeringsfick": "parkeringsficka",
    "parkeringsfickan": "parkeringsficka",
    "parkeringsfickans": "parkeringsficka",
    "parkeringsfickas": "parkeringsficka",
    "parkeringsficke": "parkeringsficka",
    "parkeringsfickor": "parkeringsficka",
    "parkeringsfickorna": "parkeringsficka",
    "parkeringsfickornas": "parkeringsficka",
    "parkeringsfickors": "parkeringsficka",
    "parkeringsficks": "parkeringsficka",
    "parkeringshusen": "parkeringshus",
    "parkeringshusens": "parkeringshus",
    "parkeringshuset": "parkeringshus",
    "parkeringshusets": "parkeringshus",
    "parkeringslamp": "parkeringslampa",
    "parkeringslampan": "parkeringslampa",
    "parkeringslampans": "parkeringslampa",
    "parkeringslampas": "parkeringslampa",
    "parkeringslampe": "parkeringslampa",
    "parkeringslampor": "parkeringslampa",
    "parkeringslamporna": "parkeringslampa",
    "parkeringslampornas": "parkeringslampa",
    "parkeringslampors": "parkeringslampa",
    "parkeringslamps": "parkeringslampa",
    "parkeringsljusen": "parkeringsljus",
    "parkeringsljusens": "parkeringsljus",
    "parkeringsljuset": "parkeringsljus",
    "parkeringsljusets": "parkeringsljus",
    "parkeringsplatsen": "parkeringsplats",
    "parkeringsplatsens": "parkeringsplats",
    "parkeringsplatser": "parkeringsplats",
    "parkeringsplatserna": "parkeringsplats",
    "parkeringsplatsernas": "parkeringsplats",
    "parkeringsplatsers": "parkeringsplats",
    "parkeringsvakten": "parkeringsvakt",
    "parkeringsvaktens": "parkeringsvakt",
    "parkeringsvakter": "parkeringsvakt",
    "parkeringsvakterna": "parkeringsvakt",
    "parkeringsvakternas": "parkeringsvakt",
    "parkeringsvakters": "parkeringsvakt",
    "parkeringsvakts": "parkeringsvakt",
    "parkerna": "park",
    "parkernas": "park",
    "parkers": "park",
    "parketten": "parkett",
    "parkettens": "parkett",
    "parketter": "parkett",
    "parketterad": "parkettera",
    "parketterade": "parkettera",
    "parketterades": "parkettera",
    "parketterads": "parkettera",
    "parketterande": "parkettera",
    "parketteranden": "parketterande",
    "parketterandena": "parketterande",
    "parketterandenas": "parketterande",
    "parketterandens": "parketterande",
    "parketterandes": "parketterande",
    "parketterandet": "parketterande",
    "parketterandets": "parketterande",
    "parketterar": "parkettera",
    "parketteras": "parkettera",
    "parketterat": "parkettera",
    "parketterats": "parkettera",
    "parketterbara": "parketterbar",
    "parketterbarare": "parketterbar",
    "parketterbarares": "parketterbar",
    "parketterbaras": "parketterbar",
    "parketterbarast": "parketterbar",
    "parketterbaraste": "parketterbar",
    "parketterbarastes": "parketterbar",
    "parketterbarasts": "parketterbar",
    "parketterbare": "parketterbar",
    "parketterbares": "parketterbar",
    "parketterbarheten": "parketterbarhet",
    "parketterbarhetens": "parketterbarhet",
    "parketterbarhets": "parketterbarhet",
    "parketterbars": "parketterbar",
    "parketterbart": "parketterbar",
    "parketterbarts": "parketterbar",
    "parketteringar": "parkettering",
    "parketteringarna": "parkettering",
    "parketteringarnas": "parkettering",
    "parketteringars": "parkettering",
    "parketteringen": "parkettering",
    "parketteringens": "parkettering",
    "parketterings": "parkettering",
    "parketterna": "parkett",
    "parketternas": "parkett",
    "parketters": "parkett",
    "parkettgolven": "parkettgolv",
    "parkettgolvens": "parkettgolv",
    "parkettgolvet": "parkettgolv",
    "parkettgolvets": "parkettgolv",
    "parkettgolvs": "parkettgolv",
    "parketts": "parkett",
    "parkettstavar": "parkettstav",
    "parkettstavarna": "parkettstav",
    "parkettstavarnas": "parkettstav",
    "parkettstavars": "parkettstav",
    "parkettstaven": "parkettstav",
    "parkettstavens": "parkettstav",
    "parkettstavs": "parkettstav",
    "parkleken": "parklek",
    "parklekens": "parklek",
    "parkleks": "parklek",
    "parkpromenaden": "parkpromenad",
    "parkpromenadens": "parkpromenad",
    "parkpromenader": "parkpromenad",
    "parkpromenaderna": "parkpromenad",
    "parkpromenadernas": "parkpromenad",
    "parkpromenaders": "parkpromenad",
    "parkpromenads": "parkpromenad",
    "parks": "park",
    "parkskötar": "parkskötare",
    "parkskötaren": "parkskötare",
    "parkskötarens": "parkskötare",
    "parkskötares": "parkskötare",
    "parkskötarna": "parkskötare",
    "parkskötarnas": "parkskötare",
    "parkumen": "parkum",
    "parkumens": "parkum",
    "parkumet": "parkum",
    "parkumets": "parkum",
    "parkums": "parkum",
    "parlamentarikern": "parlamentariker",
    "parlamentarikerna": "parlamentariker",
    "parlamentarikernas": "parlamentariker",
    "parlamentarikerns": "parlamentariker",
    "parlamentarikers": "parlamentariker",
    "parlamentariska": "parlamentarisk",
    "parlamentariskare": "parlamentarisk",
    "parlamentariskares": "parlamentarisk",
    "parlamentariskas": "parlamentarisk",
    "parlamentariskast": "parlamentarisk",
    "parlamentariskaste": "parlamentarisk",
    "parlamentariskastes": "parlamentarisk",
    "parlamentariskasts": "parlamentarisk",
    "parlamentariske": "parlamentarisk",
    "parlamentariskes": "parlamentarisk",
    "parlamentarisks": "parlamentarisk",
    "parlamentariskt": "parlamentarisk",
    "parlamentariskts": "parlamentarisk",
    "parlamentarismen": "parlamentarism",
    "parlamentarismens": "parlamentarism",
    "parlamentarismer": "parlamentarism",
    "parlamentarismerna": "parlamentarism",
    "parlamentarismernas": "parlamentarism",
    "parlamentarismers": "parlamentarism",
    "parlamentarisms": "parlamentarism",
    "parlamentaristiska": "parlamentaristisk",
    "parlamentaristiskas": "parlamentaristisk",
    "parlamentaristiske": "parlamentaristisk",
    "parlamentaristiskes": "parlamentaristisk",
    "parlamentaristisks": "parlamentaristisk",
    "parlamentaristiskt": "parlamentaristisk",
    "parlamentaristiskts": "parlamentaristisk",
    "parlamenten": "parlament",
    "parlamentens": "parlament",
    "parlamenterade": "parlamentera",
    "parlamenterades": "parlamentera",
    "parlamenterande": "parlamentera",
    "parlamenteranden": "parlamenterande",
    "parlamenterandena": "parlamenterande",
    "parlamenterandenas": "parlamenterande",
    "parlamenterandens": "parlamenterande",
    "parlamenterandes": "parlamenterande",
    "parlamenterandet": "parlamenterande",
    "parlamenterandets": "parlamenterande",
    "parlamenterar": "parlamentera",
    "parlamenteras": "parlamentera",
    "parlamenterat": "parlamentera",
    "parlamenterats": "parlamentera",
    "parlamenteringar": "parlamentering",
    "parlamenteringarna": "parlamentering",
    "parlamenteringarnas": "parlamentering",
    "parlamenteringars": "parlamentering",
    "parlamenteringen": "parlamentering",
    "parlamenteringens": "parlamentering",
    "parlamenterings": "parlamentering",
    "parlamentet": "parlament",
    "parlamentets": "parlament",
    "parlaments": "parlament",
    "parlamentsreformen": "parlamentsreform",
    "parlamentsreformens": "parlamentsreform",
    "parlamentsreformer": "parlamentsreform",
    "parlamentsreformerna": "parlamentsreform",
    "parlamentsreformernas": "parlamentsreform",
    "parlamentsreformers": "parlamentsreform",
    "parlamentsreforms": "parlamentsreform",
    "parlamentären": "parlamentär",
    "parlamentärens": "parlamentär",
    "parlamentärer": "parlamentär",
    "parlamentärerna": "parlamentär",
    "parlamentärernas": "parlamentär",
    "parlamentärers": "parlamentär",
    "parlamentärs": "parlamentär",
    "parlandon": "parlando",
    "parlandona": "parlando",
    "parlandonas": "parlando",
    "parlandons": "parlando",
    "parlandos": "parlando",
    "parlandot": "parlando",
    "parlandots": "parlando",
    "parlerade": "parlera",
    "parlerades": "parlera",
    "parlerande": "parlera",
    "parleranden": "parlerande",
    "parlerandena": "parlerande",
    "parlerandenas": "parlerande",
    "parlerandens": "parlerande",
    "parlerandes": "parlerande",
    "parlerandet": "parlerande",
    "parlerandets": "parlerande",
    "parlerar": "parlera",
    "parleras": "parlera",
    "parlerat": "parlera",
    "parlerats": "parlera",
    "parleringar": "parlering",
    "parleringarna": "parlering",
    "parleringarnas": "parlering",
    "parleringars": "parlering",
    "parleringen": "parlering",
    "parleringens": "parlering",
    "parlerings": "parlering",
    "parlören": "parlör",
    "parlörens": "parlör",
    "parlörer": "parlör",
    "parlörerna": "parlör",
    "parlörernas": "parlör",
    "parlörers": "parlör",
    "parlörs": "parlör",
    "parmesanosten": "parmesanost",
    "parmesanostens": "parmesanost",
    "parmesanosts": "parmesanost",
    "parnassen": "parnass",
    "parnassens": "parnass",
    "parnasser": "parnass",
    "parnasserna": "parnass",
    "parnassernas": "parnass",
    "parnassers": "parnass",
    "parningar": "parning",
    "parningarna": "parning",
    "parningarnas": "parning",
    "parningars": "parning",
    "parningen": "parning",
    "parningens": "parning",
    "parnings": "parning",
    "parningsdriften": "parningsdrift",
    "parningsdriftens": "parningsdrift",
    "parningsdrifter": "parningsdrift",
    "parningsdrifterna": "parningsdrift",
    "parningsdrifternas": "parningsdrift",
    "parningsdrifters": "parningsdrift",
    "parningsdrifts": "parningsdrift",
    "parningsdräkten": "parningsdräkt",
    "parningsdräktens": "parningsdräkt",
    "parningsdräkter": "parningsdräkt",
    "parningsdräkterna": "parningsdräkt",
    "parningsdräkternas": "parningsdräkt",
    "parningsdräkters": "parningsdräkt",
    "parningsdräkts": "parningsdräkt",
    "parningslekar": "parningslek",
    "parningslekarna": "parningslek",
    "parningslekarnas": "parningslek",
    "parningslekars": "parningslek",
    "parningsleken": "parningslek",
    "parningslekens": "parningslek",
    "parningsleks": "parningslek",
    "parningsorganen": "parningsorgan",
    "parningsorganens": "parningsorgan",
    "parningsorganet": "parningsorgan",
    "parningsorganets": "parningsorgan",
    "parningsorgans": "parningsorgan",
    "parodien": "parodi",
    "parodiens": "parodi",
    "parodier": "parodi",
    "parodierad": "parodiera",
    "parodierade": "parodiera",
    "parodierades": "parodiera",
    "parodierads": "parodiera",
    "parodierande": "parodiera",
    "parodieranden": "parodierande",
    "parodierandena": "parodierande",
    "parodierandenas": "parodierande",
    "parodierandens": "parodierande",
    "parodierandes": "parodierande",
    "parodierandet": "parodierande",
    "parodierandets": "parodierande",
    "parodierar": "parodiera",
    "parodieras": "parodiera",
    "parodierat": "parodiera",
    "parodierats": "parodiera",
    "parodierbara": "parodierbar",
    "parodierbarare": "parodierbar",
    "parodierbarares": "parodierbar",
    "parodierbaras": "parodierbar",
    "parodierbarast": "parodierbar",
    "parodierbaraste": "parodierbar",
    "parodierbarastes": "parodierbar",
    "parodierbarasts": "parodierbar",
    "parodierbare": "parodierbar",
    "parodierbares": "parodierbar",
    "parodierbarheten": "parodierbarhet",
    "parodierbarhetens": "parodierbarhet",
    "parodierbarhets": "parodierbarhet",
    "parodierbars": "parodierbar",
    "parodierbart": "parodierbar",
    "parodierbarts": "parodierbar",
    "parodieringar": "parodiering",
    "parodieringarna": "parodiering",
    "parodieringarnas": "parodiering",
    "parodieringars": "parodiering",
    "parodieringen": "parodiering",
    "parodieringens": "parodiering",
    "parodierings": "parodiering",
    "parodierna": "parodi",
    "parodiernas": "parodi",
    "parodiers": "parodi",
    "parodikern": "parodiker",
    "parodikerna": "parodiker",
    "parodikernas": "parodiker",
    "parodikerns": "parodiker",
    "parodikers": "parodiker",
    "parodin": "parodi",
    "parodins": "parodi",
    "parodis": "parodi",
    "parodiska": "parodisk",
    "parodiskare": "parodisk",
    "parodiskares": "parodisk",
    "parodiskas": "parodisk",
    "parodiskast": "parodisk",
    "parodiskaste": "parodisk",
    "parodiskastes": "parodisk",
    "parodiskasts": "parodisk",
    "parodiske": "parodisk",
    "parodiskes": "parodisk",
    "parodisks": "parodisk",
    "parodiskt": "parodisk",
    "parodiskts": "parodisk",
    "parodontiten": "parodontit",
    "parodontitens": "parodontit",
    "parodontiter": "parodontit",
    "parodontiterna": "parodontit",
    "parodontiternas": "parodontit",
    "parodontiters": "parodontit",
    "parodontits": "parodontit",
    "parollen": "paroll",
    "parollens": "paroll",
    "paroller": "paroll",
    "parollerna": "paroll",
    "parollernas": "paroll",
    "parollers": "paroll",
    "parolls": "paroll",
    "paronymen": "paronym",
    "paronymens": "paronym",
    "paronymer": "paronym",
    "paronymerna": "paronym",
    "paronymernas": "paronym",
    "paronymers": "paronym",
    "paronymien": "paronymi",
    "paronymiens": "paronymi",
    "paronymier": "paronymi",
    "paronymierna": "paronymi",
    "paronymiernas": "paronymi",
    "paronymiers": "paronymi",
    "paronymin": "paronymi",
    "paronymins": "paronymi",
    "paronymis": "paronymi",
    "paronyms": "paronym",
    "paroxysmen": "paroxysm",
    "paroxysmens": "paroxysm",
    "paroxysmer": "paroxysm",
    "paroxysmerna": "paroxysm",
    "paroxysmernas": "paroxysm",
    "paroxysmers": "paroxysm",
    "paroxysms": "paroxysm",
    "parrimmade": "parrimmad",
    "parrimmades": "parrimmad",
    "parrimmads": "parrimmad",
    "parrimmat": "parrimmad",
    "parrimmats": "parrimmad",
    "pars": "parsa",
    "parsad": "parsa",
    "parsade": "parsa",
    "parsades": "parsa",
    "parsads": "parsa",
    "parsande": "parsa",
    "parsandes": "parsa",
    "parsar": "parsa",
    "parsas": "parsa",
    "parsat": "parsa",
    "parsats": "parsa",
    "parsern": "parser",
    "parserns": "parser",
    "parsers": "parser",
    "parsersarna": "parser",
    "parsersarnas": "parser",
    "parsersen": "parser",
    "parsersens": "parser",
    "parsingen": "parsing",
    "parsingens": "parsing",
    "parsings": "parsing",
    "parsningen": "parsning",
    "parsningens": "parsning",
    "parsnings": "parsning",
    "parspelen": "parspel",
    "parspelens": "parspel",
    "parspelet": "parspel",
    "parspelets": "parspel",
    "parspels": "parspel",
    "parsrar": "parser",
    "parsrarna": "parser",
    "parsrarnas": "parser",
    "parsrars": "parser",
    "parstugan": "parstuga",
    "parstugans": "parstuga",
    "parstugas": "parstuga",
    "parstuge": "parstuga",
    "parstugor": "parstuga",
    "parstugorna": "parstuga",
    "parstugornas": "parstuga",
    "parstugors": "parstuga",
    "parstugu": "parstuga",
    "partade": "parta",
    "partades": "parta",
    "partajade": "partaja",
    "partajades": "partaja",
    "partajande": "partaja",
    "partajanden": "partajande",
    "partajandena": "partajande",
    "partajandenas": "partajande",
    "partajandens": "partajande",
    "partajandes": "partajande",
    "partajandet": "partajande",
    "partajandets": "partajande",
    "partajar": "partaja",
    "partajas": "partaja",
    "partajat": "partaja",
    "partajats": "partaja",
    "partajen": "partaj",
    "partajens": "partaj",
    "partajet": "partaj",
    "partajets": "partaj",
    "partajs": "partaj",
    "partande": "parta",
    "partanden": "partande",
    "partandena": "partande",
    "partandenas": "partande",
    "partandens": "partande",
    "partandes": "partande",
    "partandet": "partande",
    "partandets": "partande",
    "partar": "parta",
    "partas": "parta",
    "partat": "parta",
    "partats": "parta",
    "parten": "part",
    "partenogenesen": "partenogenes",
    "partenogenesens": "partenogenes",
    "partens": "part",
    "parter": "part",
    "parterna": "part",
    "parternas": "part",
    "parterren": "parterr",
    "parterrens": "parterr",
    "parterrer": "parterr",
    "parterrerna": "parterr",
    "parterrernas": "parterr",
    "parterrers": "parterr",
    "parterrs": "parterr",
    "parters": "part",
    "partialtonen": "partialton",
    "partialtonens": "partialton",
    "partialtoner": "partialton",
    "partialtonerna": "partialton",
    "partialtonernas": "partialton",
    "partialtoners": "partialton",
    "partialtons": "partialton",
    "partialtrycken": "partialtryck",
    "partialtryckens": "partialtryck",
    "partialtrycket": "partialtryck",
    "partialtryckets": "partialtryck",
    "partialtrycks": "partialtryck",
    "partiapparaten": "partiapparat",
    "partiapparatens": "partiapparat",
    "partiapparater": "partiapparat",
    "partiapparaterna": "partiapparat",
    "partiapparaternas": "partiapparat",
    "partiapparaters": "partiapparat",
    "partiapparats": "partiapparat",
    "partibildningar": "partibildning",
    "partibildningarna": "partibildning",
    "partibildningarnas": "partibildning",
    "partibildningars": "partibildning",
    "partibildningen": "partibildning",
    "partibildningens": "partibildning",
    "partibildnings": "partibildning",
    "partiblocken": "partiblock",
    "partiblockens": "partiblock",
    "partiblocket": "partiblock",
    "partiblockets": "partiblock",
    "partiblocks": "partiblock",
    "partichefen": "partichef",
    "partichefens": "partichef",
    "partichefer": "partichef",
    "particheferna": "partichef",
    "partichefernas": "partichef",
    "partichefers": "partichef",
    "partichefs": "partichef",
    "participen": "particip",
    "participens": "particip",
    "participet": "particip",
    "participets": "particip",
    "participiella": "participiell",
    "participiellare": "participiell",
    "participiellares": "participiell",
    "participiellas": "participiell",
    "participiellast": "participiell",
    "participiellaste": "participiell",
    "participiellastes": "participiell",
    "participiellasts": "participiell",
    "participielle": "participiell",
    "participielles": "participiell",
    "participiells": "participiell",
    "participiellt": "participiell",
    "participiellts": "participiell",
    "particips": "particip",
    "partidisciplinen": "partidisciplin",
    "partidisciplinens": "partidisciplin",
    "partidiscipliner": "partidisciplin",
    "partidisciplinerna": "partidisciplin",
    "partidisciplinernas": "partidisciplin",
    "partidiscipliners": "partidisciplin",
    "partidisciplins": "partidisciplin",
    "partidistrikten": "partidistrikt",
    "partidistriktens": "partidistrikt",
    "partidistriktet": "partidistrikt",
    "partidistriktets": "partidistrikt",
    "partidistrikts": "partidistrikt",
    "partiella": "partiell",
    "partiellare": "partiell",
    "partiellares": "partiell",
    "partiellas": "partiell",
    "partiellast": "partiell",
    "partiellaste": "partiell",
    "partiellastes": "partiell",
    "partiellasts": "partiell",
    "partielle": "partiell",
    "partielles": "partiell",
    "partiells": "partiell",
    "partiellt": "partiell",
    "partiellts": "partiell",
    "partier": "parti",
    "partierna": "parti",
    "partiernas": "parti",
    "partiers": "parti",
    "partiet": "parti",
    "partiets": "parti",
    "partifärgen": "partifärg",
    "partifärgens": "partifärg",
    "partifärger": "partifärg",
    "partifärgerna": "partifärg",
    "partifärgernas": "partifärg",
    "partifärgers": "partifärg",
    "partifärgs": "partifärg",
    "partifåll": "partifålla",
    "partifållan": "partifålla",
    "partifållans": "partifålla",
    "partifållas": "partifålla",
    "partifålle": "partifålla",
    "partifållor": "partifålla",
    "partifållorna": "partifålla",
    "partifållornas": "partifålla",
    "partifållors": "partifålla",
    "partifålls": "partifålla",
    "partiföreträdar": "partiföreträdare",
    "partiföreträdaren": "partiföreträdare",
    "partiföreträdarens": "partiföreträdare",
    "partiföreträdares": "partiföreträdare",
    "partiföreträdarna": "partiföreträdare",
    "partiföreträdarnas": "partiföreträdare",
    "partigruppen": "partigrupp",
    "partigruppens": "partigrupp",
    "partigrupper": "partigrupp",
    "partigrupperna": "partigrupp",
    "partigruppernas": "partigrupp",
    "partigruppers": "partigrupp",
    "partigrupps": "partigrupp",
    "partigängar": "partigängare",
    "partigängaren": "partigängare",
    "partigängarens": "partigängare",
    "partigängares": "partigängare",
    "partigängarna": "partigängare",
    "partigängarnas": "partigängare",
    "partihandeln": "partihandel",
    "partihandelns": "partihandel",
    "partihandels": "partihandel",
    "partikamraten": "partikamrat",
    "partikamratens": "partikamrat",
    "partikamrater": "partikamrat",
    "partikamraterna": "partikamrat",
    "partikamraternas": "partikamrat",
    "partikamraters": "partikamrat",
    "partikamrats": "partikamrat",
    "partikelacceleratorer": "partikelaccelerator",
    "partikelacceleratorerna": "partikelaccelerator",
    "partikelacceleratorernas": "partikelaccelerator",
    "partikelacceleratorers": "partikelaccelerator",
    "partikelacceleratorn": "partikelaccelerator",
    "partikelacceleratorns": "partikelaccelerator",
    "partikelaccelerators": "partikelaccelerator",
    "partikelegenskapen": "partikelegenskap",
    "partikelegenskapens": "partikelegenskap",
    "partikelegenskaper": "partikelegenskap",
    "partikelegenskaperna": "partikelegenskap",
    "partikelegenskapernas": "partikelegenskap",
    "partikelegenskapers": "partikelegenskap",
    "partikelegenskaps": "partikelegenskap",
    "partikelfysikern": "partikelfysiker",
    "partikelfysikerna": "partikelfysiker",
    "partikelfysikernas": "partikelfysiker",
    "partikelfysikerns": "partikelfysiker",
    "partikelfysikers": "partikelfysiker",
    "partikelkolliderar": "partikelkolliderare",
    "partikelkollideraren": "partikelkolliderare",
    "partikelkolliderarens": "partikelkolliderare",
    "partikelkolliderares": "partikelkolliderare",
    "partikelkolliderarna": "partikelkolliderare",
    "partikelkolliderarnas": "partikelkolliderare",
    "partikelkrossar": "partikelkross",
    "partikelkrossarna": "partikelkross",
    "partikelkrossarnas": "partikelkross",
    "partikelkrossars": "partikelkross",
    "partikelkrossen": "partikelkross",
    "partikelkrossens": "partikelkross",
    "partikellaboratorie": "partikellaboratorium",
    "partikellaboratorier": "partikellaboratorium",
    "partikellaboratorierna": "partikellaboratorium",
    "partikellaboratoriernas": "partikellaboratorium",
    "partikellaboratoriers": "partikellaboratorium",
    "partikellaboratoriet": "partikellaboratorium",
    "partikellaboratoriets": "partikellaboratorium",
    "partikellaboratoriums": "partikellaboratorium",
    "partikellocken": "partikellock",
    "partikellockens": "partikellock",
    "partikellocket": "partikellock",
    "partikellockets": "partikellock",
    "partikellocks": "partikellock",
    "partikeln": "partikel",
    "partikelns": "partikel",
    "partikelreaktionen": "partikelreaktion",
    "partikelreaktionens": "partikelreaktion",
    "partikelreaktioner": "partikelreaktion",
    "partikelreaktionerna": "partikelreaktion",
    "partikelreaktionernas": "partikelreaktion",
    "partikelreaktioners": "partikelreaktion",
    "partikelreaktions": "partikelreaktion",
    "partikelregnen": "partikelregn",
    "partikelregnens": "partikelregn",
    "partikelregnet": "partikelregn",
    "partikelregnets": "partikelregn",
    "partikelregns": "partikelregn",
    "partikels": "partikel",
    "partikelstrål": "partikelstråle",
    "partikelstrålar": "partikelstråle",
    "partikelstrålarna": "partikelstråle",
    "partikelstrålarnas": "partikelstråle",
    "partikelstrålars": "partikelstråle",
    "partikelstrålen": "partikelstråle",
    "partikelstrålens": "partikelstråle",
    "partikelstråles": "partikelstråle",
    "partikelstrålningar": "partikelstrålning",
    "partikelstrålningarna": "partikelstrålning",
    "partikelstrålningarnas": "partikelstrålning",
    "partikelstrålningars": "partikelstrålning",
    "partikelstrålningen": "partikelstrålning",
    "partikelstrålningens": "partikelstrålning",
    "partikelstrålnings": "partikelstrålning",
    "partikelstråls": "partikelstråle",
    "partikelströmmar": "partikelström",
    "partikelströmmarna": "partikelström",
    "partikelströmmarnas": "partikelström",
    "partikelströmmars": "partikelström",
    "partikelströmmen": "partikelström",
    "partikelströmmens": "partikelström",
    "partikelströms": "partikelström",
    "partiklar": "partikel",
    "partiklarna": "partikel",
    "partiklarnas": "partikel",
    "partiklars": "partikel",
    "partikongressen": "partikongress",
    "partikongressens": "partikongress",
    "partikongresser": "partikongress",
    "partikongresserna": "partikongress",
    "partikongressernas": "partikongress",
    "partikongressers": "partikongress",
    "partikularismen": "partikularism",
    "partikularismens": "partikularism",
    "partikularismer": "partikularism",
    "partikularismerna": "partikularism",
    "partikularismernas": "partikularism",
    "partikularismers": "partikularism",
    "partikularisms": "partikularism",
    "partikularistiska": "partikularistisk",
    "partikularistiskas": "partikularistisk",
    "partikularistiske": "partikularistisk",
    "partikularistiskes": "partikularistisk",
    "partikularistisks": "partikularistisk",
    "partikularistiskt": "partikularistisk",
    "partikularistiskts": "partikularistisk",
    "partikuljära": "partikuljär",
    "partikuljärare": "partikuljär",
    "partikuljärares": "partikuljär",
    "partikuljäras": "partikuljär",
    "partikuljärast": "partikuljär",
    "partikuljäraste": "partikuljär",
    "partikuljärastes": "partikuljär",
    "partikuljärasts": "partikuljär",
    "partikuljäre": "partikuljär",
    "partikuljäres": "partikuljär",
    "partikuljärs": "partikuljär",
    "partikuljärt": "partikuljär",
    "partikuljärts": "partikuljär",
    "partikulära": "partikulär",
    "partikulärare": "partikulär",
    "partikulärares": "partikulär",
    "partikuläras": "partikulär",
    "partikulärast": "partikulär",
    "partikuläraste": "partikulär",
    "partikulärastes": "partikulär",
    "partikulärasts": "partikulär",
    "partikuläre": "partikulär",
    "partikuläres": "partikulär",
    "partikulärs": "partikulär",
    "partikulärt": "partikulär",
    "partikulärts": "partikulär",
    "partiledar": "partiledare",
    "partiledardebatten": "partiledardebatt",
    "partiledardebattens": "partiledardebatt",
    "partiledardebatter": "partiledardebatt",
    "partiledardebatterna": "partiledardebatt",
    "partiledardebatternas": "partiledardebatt",
    "partiledardebatters": "partiledardebatt",
    "partiledardebatts": "partiledardebatt",
    "partiledaren": "partiledare",
    "partiledarens": "partiledare",
    "partiledares": "partiledare",
    "partiledarkandidaten": "partiledarkandidat",
    "partiledarkandidatens": "partiledarkandidat",
    "partiledarkandidater": "partiledarkandidat",
    "partiledarkandidaterna": "partiledarkandidat",
    "partiledarkandidaternas": "partiledarkandidat",
    "partiledarkandidaters": "partiledarkandidat",
    "partiledarkandidats": "partiledarkandidat",
    "partiledarna": "partiledare",
    "partiledarnas": "partiledare",
    "partiledarposten": "partiledarpost",
    "partiledarpostens": "partiledarpost",
    "partiledarposter": "partiledarpost",
    "partiledarposterna": "partiledarpost",
    "partiledarposternas": "partiledarpost",
    "partiledarposters": "partiledarpost",
    "partiledarposts": "partiledarpost",
    "partiledningar": "partiledning",
    "partiledningarna": "partiledning",
    "partiledningarnas": "partiledning",
    "partiledningars": "partiledning",
    "partiledningen": "partiledning",
    "partiledningens": "partiledning",
    "partilednings": "partiledning",
    "partilösa": "partilös",
    "partilösare": "partilös",
    "partilösares": "partilös",
    "partilösas": "partilös",
    "partilösast": "partilös",
    "partilösaste": "partilös",
    "partilösastes": "partilös",
    "partilösasts": "partilös",
    "partilöse": "partilös",
    "partilöses": "partilös",
    "partilösheten": "partilöshet",
    "partilöshetens": "partilöshet",
    "partilöshets": "partilöshet",
    "partilöst": "partilös",
    "partilösts": "partilös",
    "partimedlemmar": "partimedlem",
    "partimedlemmarna": "partimedlem",
    "partimedlemmarnas": "partimedlem",
    "partimedlemmars": "partimedlem",
    "partimedlemmen": "partimedlem",
    "partimedlemmens": "partimedlem",
    "partimedlems": "partimedlem",
    "partimässiga": "partimässig",
    "partimässigare": "partimässig",
    "partimässigares": "partimässig",
    "partimässigas": "partimässig",
    "partimässigast": "partimässig",
    "partimässigaste": "partimässig",
    "partimässigastes": "partimässig",
    "partimässigasts": "partimässig",
    "partimässige": "partimässig",
    "partimässiges": "partimässig",
    "partimässigs": "partimässig",
    "partimässigt": "partimässig",
    "partimässigts": "partimässig",
    "partiordföranden": "partiordförande",
    "partiordförandena": "partiordförande",
    "partiordförandenas": "partiordförande",
    "partiordförandens": "partiordförande",
    "partiordförandes": "partiordförande",
    "partiorganen": "partiorgan",
    "partiorganens": "partiorgan",
    "partiorganet": "partiorgan",
    "partiorganets": "partiorgan",
    "partiorgans": "partiorgan",
    "partipiskan": "partipiska",
    "partipiskans": "partipiska",
    "partipiskas": "partipiska",
    "partipolitiska": "partipolitisk",
    "partipolitiskare": "partipolitisk",
    "partipolitiskares": "partipolitisk",
    "partipolitiskas": "partipolitisk",
    "partipolitiskast": "partipolitisk",
    "partipolitiskaste": "partipolitisk",
    "partipolitiskastes": "partipolitisk",
    "partipolitiskasts": "partipolitisk",
    "partipolitiske": "partipolitisk",
    "partipolitiskes": "partipolitisk",
    "partipolitisks": "partipolitisk",
    "partipolitiskt": "partipolitisk",
    "partipolitiskts": "partipolitisk",
    "partiprisen": "partipris",
    "partiprisens": "partipris",
    "partipriser": "partipris",
    "partipriserna": "partipris",
    "partiprisernas": "partipris",
    "partiprisers": "partipris",
    "partipriset": "partipris",
    "partiprisets": "partipris",
    "partiprogrammen": "partiprogram",
    "partiprogrammens": "partiprogram",
    "partiprogrammet": "partiprogram",
    "partiprogrammets": "partiprogram",
    "partiprograms": "partiprogram",
    "partis": "parti",
    "partisanen": "partisan",
    "partisanens": "partisan",
    "partisaner": "partisan",
    "partisanerna": "partisan",
    "partisanernas": "partisan",
    "partisaners": "partisan",
    "partisans": "partisan",
    "partisekreterar": "partisekreterare",
    "partisekreteraren": "partisekreterare",
    "partisekreterarens": "partisekreterare",
    "partisekreterares": "partisekreterare",
    "partisekreterarna": "partisekreterare",
    "partisekreterarnas": "partisekreterare",
    "partiska": "partisk",
    "partiskare": "partisk",
    "partiskares": "partisk",
    "partiskas": "partisk",
    "partiskast": "partisk",
    "partiskaste": "partisk",
    "partiskastes": "partisk",
    "partiskasts": "partisk",
    "partiske": "partisk",
    "partiskes": "partisk",
    "partiskheten": "partiskhet",
    "partiskhetens": "partiskhet",
    "partiskheter": "partiskhet",
    "partiskheterna": "partiskhet",
    "partiskheternas": "partiskhet",
    "partiskheters": "partiskhet",
    "partiskhets": "partiskhet",
    "partisks": "partisk",
    "partiskt": "partisk",
    "partiskts": "partisk",
    "partisprängningar": "partisprängning",
    "partisprängningarna": "partisprängning",
    "partisprängningarnas": "partisprängning",
    "partisprängningars": "partisprängning",
    "partisprängningen": "partisprängning",
    "partisprängningens": "partisprängning",
    "partisprängnings": "partisprängning",
    "partispärrar": "partispärr",
    "partispärrarna": "partispärr",
    "partispärrarnas": "partispärr",
    "partispärrars": "partispärr",
    "partispärren": "partispärr",
    "partispärrens": "partispärr",
    "partispärrs": "partispärr",
    "partistödet": "partistöd",
    "partistödets": "partistöd",
    "partistöds": "partistöd",
    "partisympatien": "partisympati",
    "partisympatiens": "partisympati",
    "partisympatier": "partisympati",
    "partisympatierna": "partisympati",
    "partisympatiernas": "partisympati",
    "partisympatiers": "partisympati",
    "partisympatimätningar": "partisympatimätning",
    "partisympatimätningarna": "partisympatimätning",
    "partisympatimätningarnas": "partisympatimätning",
    "partisympatimätningars": "partisympatimätning",
    "partisympatimätningen": "partisympatimätning",
    "partisympatimätningens": "partisympatimätning",
    "partisympatimätnings": "partisympatimätning",
    "partisympatin": "partisympati",
    "partisympatins": "partisympati",
    "partisympatis": "partisympati",
    "partit": "parti",
    "partitillhörigheten": "partitillhörighet",
    "partitillhörighetens": "partitillhörighet",
    "partitillhörighets": "partitillhörighet",
    "partitiva": "partitiv",
    "partitivare": "partitiv",
    "partitivares": "partitiv",
    "partitivas": "partitiv",
    "partitivast": "partitiv",
    "partitivaste": "partitiv",
    "partitivastes": "partitiv",
    "partitivasts": "partitiv",
    "partitive": "partitiv",
    "partitiven": "partitiv",
    "partitivens": "partitiv",
    "partitiver": "partitiv",
    "partitiverna": "partitiv",
    "partitivernas": "partitiv",
    "partitivers": "partitiv",
    "partitives": "partitiv",
    "partitivs": "partitiv",
    "partitivt": "partitiv",
    "partitivts": "partitiv",
    "partitroheten": "partitrohet",
    "partitrohetens": "partitrohet",
    "partitroheter": "partitrohet",
    "partitroheterna": "partitrohet",
    "partitroheternas": "partitrohet",
    "partitroheters": "partitrohet",
    "partitrohets": "partitrohet",
    "partits": "parti",
    "partituren": "partitur",
    "partiturens": "partitur",
    "partituret": "partitur",
    "partiturets": "partitur",
    "partiturs": "partitur",
    "partnern": "partner",
    "partnerna": "partner",
    "partnernas": "partner",
    "partnerns": "partner",
    "partners": "partner",
    "partnersarna": "partner",
    "partnersarnas": "partner",
    "partnersen": "partner",
    "partnersens": "partner",
    "partonymen": "partonym",
    "partonymens": "partonym",
    "partonymer": "partonym",
    "partonymerna": "partonym",
    "partonymernas": "partonym",
    "partonymers": "partonym",
    "partonymien": "partonymi",
    "partonymiens": "partonymi",
    "partonymier": "partonymi",
    "partonymierna": "partonymi",
    "partonymiernas": "partonymi",
    "partonymiers": "partonymi",
    "partonymin": "partonymi",
    "partonymins": "partonymi",
    "partonymis": "partonymi",
    "partonyms": "partonym",
    "parts": "part",
    "partsbehörigheten": "partsbehörighet",
    "partsbehörighetens": "partsbehörighet",
    "partsbehörigheter": "partsbehörighet",
    "partsbehörigheterna": "partsbehörighet",
    "partsbehörigheternas": "partsbehörighet",
    "partsbehörigheters": "partsbehörighet",
    "partsbehörighets": "partsbehörighet",
    "partsinlag": "partsinlaga",
    "partsinlagan": "partsinlaga",
    "partsinlagans": "partsinlaga",
    "partsinlagas": "partsinlaga",
    "partsinlage": "partsinlaga",
    "partsinlagor": "partsinlaga",
    "partsinlagorna": "partsinlaga",
    "partsinlagornas": "partsinlaga",
    "partsinlagors": "partsinlaga",
    "partsinlags": "partsinlaga",
    "partsorganen": "partsorgan",
    "partsorganens": "partsorgan",
    "partsorganet": "partsorgan",
    "partsorganets": "partsorgan",
    "partsorgans": "partsorgan",
    "partyn": "party",
    "partyna": "party",
    "partynas": "party",
    "partyns": "party",
    "partys": "party",
    "partyt": "party",
    "partyts": "party",
    "partytälten": "partytält",
    "partytältens": "partytält",
    "partytältet": "partytält",
    "partytältets": "partytält",
    "partytälts": "partytält",
    "partåiga": "partåig",
    "partåigare": "partåig",
    "partåigares": "partåig",
    "partåigas": "partåig",
    "partåigast": "partåig",
    "partåigaste": "partåig",
    "partåigastes": "partåig",
    "partåigasts": "partåig",
    "partåige": "partåig",
    "partåiges": "partåig",
    "partåigs": "partåig",
    "partåigt": "partåig",
    "partåigts": "partåig",
    "parveln": "parvel",
    "parvelns": "parvel",
    "parvels": "parvel",
    "parvenyer": "parveny",
    "parvenyerna": "parveny",
    "parvenyernas": "parveny",
    "parvenyers": "parveny",
    "parvenyn": "parveny",
    "parvenyns": "parveny",
    "parvenys": "parveny",
    "parvlar": "parvel",
    "parvlarna": "parvel",
    "parvlarnas": "parvel",
    "parvlars": "parvel",
    "paråkningar": "paråkning",
    "paråkningarna": "paråkning",
    "paråkningarnas": "paråkning",
    "paråkningars": "paråkning",
    "paråkningen": "paråkning",
    "paråkningens": "paråkning",
    "paråknings": "paråkning",
    "pascalen": "pascal",
    "pascalens": "pascal",
    "pascals": "pascal",
    "pasch": "pascha",
    "paschan": "pascha",
    "paschans": "pascha",
    "paschas": "pascha",
    "pasche": "pascha",
    "paschor": "pascha",
    "paschorna": "pascha",
    "paschornas": "pascha",
    "paschors": "pascha",
    "paskillen": "paskill",
    "paskillens": "paskill",
    "paskiller": "paskill",
    "paskillerna": "paskill",
    "paskillernas": "paskill",
    "paskillers": "paskill",
    "paskills": "paskill",
    "pasm": "pasma",
    "pasman": "pasma",
    "pasmans": "pasma",
    "pasmas": "pasma",
    "pasme": "pasma",
    "pasmor": "pasma",
    "pasmorna": "pasma",
    "pasmornas": "pasma",
    "pasmors": "pasma",
    "pass": "passa",
    "passabels": "passabel",
    "passabelt": "passabel",
    "passabelts": "passabel",
    "passabla": "passabel",
    "passablare": "passabel",
    "passablares": "passabel",
    "passablas": "passabel",
    "passablast": "passabel",
    "passablaste": "passabel",
    "passablastes": "passabel",
    "passablasts": "passabel",
    "passable": "passabel",
    "passables": "passabel",
    "passad": "passa",
    "passade": "passa",
    "passaden": "passad",
    "passadens": "passad",
    "passader": "passad",
    "passaderna": "passad",
    "passadernas": "passad",
    "passaders": "passad",
    "passades": "passa",
    "passads": "passad",
    "passadvindar": "passadvind",
    "passadvindarna": "passadvind",
    "passadvindarnas": "passadvind",
    "passadvindars": "passadvind",
    "passadvinden": "passadvind",
    "passadvindens": "passadvind",
    "passadvinds": "passadvind",
    "passagen": "passage",
    "passagens": "passage",
    "passager": "passage",
    "passagerar": "passagerare",
    "passagerarbåtar": "passagerarbåt",
    "passagerarbåtarna": "passagerarbåt",
    "passagerarbåtarnas": "passagerarbåt",
    "passagerarbåtars": "passagerarbåt",
    "passagerarbåten": "passagerarbåt",
    "passagerarbåtens": "passagerarbåt",
    "passagerarbåts": "passagerarbåt",
    "passageraren": "passagerare",
    "passagerarens": "passagerare",
    "passagerares": "passagerare",
    "passagerarflygen": "passagerarflyg",
    "passagerarflygens": "passagerarflyg",
    "passagerarflyget": "passagerarflyg",
    "passagerarflygets": "passagerarflyg",
    "passagerarflygplanen": "passagerarflygplan",
    "passagerarflygplanens": "passagerarflygplan",
    "passagerarflygplanet": "passagerarflygplan",
    "passagerarflygplanets": "passagerarflygplan",
    "passagerarflygplans": "passagerarflygplan",
    "passagerarflygs": "passagerarflyg",
    "passagerarna": "passagerare",
    "passagerarnas": "passagerare",
    "passagerarplatsen": "passagerarplats",
    "passagerarplatsens": "passagerarplats",
    "passagerarplatser": "passagerarplats",
    "passagerarplatserna": "passagerarplats",
    "passagerarplatsernas": "passagerarplats",
    "passagerarplatsers": "passagerarplats",
    "passagerarsalongen": "passagerarsalong",
    "passagerarsalongens": "passagerarsalong",
    "passagerarsalonger": "passagerarsalong",
    "passagerarsalongerna": "passagerarsalong",
    "passagerarsalongernas": "passagerarsalong",
    "passagerarsalongers": "passagerarsalong",
    "passagerarsalongs": "passagerarsalong",
    "passagerarsiffer": "passagerarsiffra",
    "passagerarsiffran": "passagerarsiffra",
    "passagerarsiffrans": "passagerarsiffra",
    "passagerarsiffras": "passagerarsiffra",
    "passagerarsiffre": "passagerarsiffra",
    "passagerarsiffror": "passagerarsiffra",
    "passagerarsiffrorna": "passagerarsiffra",
    "passagerarsiffrornas": "passagerarsiffra",
    "passagerarsiffrors": "passagerarsiffra",
    "passagerartomma": "passagerartom",
    "passagerartommare": "passagerartom",
    "passagerartommares": "passagerartom",
    "passagerartommas": "passagerartom",
    "passagerartommast": "passagerartom",
    "passagerartommaste": "passagerartom",
    "passagerartommastes": "passagerartom",
    "passagerartommasts": "passagerartom",
    "passagerartomme": "passagerartom",
    "passagerartommes": "passagerartom",
    "passagerartoms": "passagerartom",
    "passagerartomt": "passagerartom",
    "passagerartomts": "passagerartom",
    "passagerna": "passage",
    "passagernas": "passage",
    "passagers": "passage",
    "passages": "passage",
    "passande": "passa",
    "passanden": "passande",
    "passandena": "passande",
    "passandenas": "passande",
    "passandens": "passande",
    "passandes": "passande",
    "passandet": "passande",
    "passandets": "passande",
    "passar": "passare",
    "passaren": "passare",
    "passarens": "passare",
    "passares": "passare",
    "passarna": "passare",
    "passarnas": "passare",
    "passas": "passa",
    "passat": "passa",
    "passats": "passa",
    "passbitar": "passbit",
    "passbitarna": "passbit",
    "passbitarnas": "passbit",
    "passbitars": "passbit",
    "passbiten": "passbit",
    "passbitens": "passbit",
    "passbits": "passbit",
    "passbåtar": "passbåt",
    "passbåtarna": "passbåt",
    "passbåtarnas": "passbåt",
    "passbåtars": "passbåt",
    "passbåten": "passbåt",
    "passbåtens": "passbåt",
    "passbåts": "passbåt",
    "passen": "pass",
    "passens": "pass",
    "passepartouten": "passepartout",
    "passepartoutens": "passepartout",
    "passepartouter": "passepartout",
    "passepartouterna": "passepartout",
    "passepartouternas": "passepartout",
    "passepartouters": "passepartout",
    "passepartouts": "passepartout",
    "passerad": "passera",
    "passerade": "passerad",
    "passerades": "passerad",
    "passerads": "passerad",
    "passerande": "passera",
    "passeranden": "passerande",
    "passerandena": "passerande",
    "passerandenas": "passerande",
    "passerandens": "passerande",
    "passerandes": "passerande",
    "passerandet": "passerande",
    "passerandets": "passerande",
    "passerar": "passera",
    "passeras": "passera",
    "passerat": "passerad",
    "passerats": "passerad",
    "passerbara": "passerbar",
    "passerbarare": "passerbar",
    "passerbarares": "passerbar",
    "passerbaras": "passerbar",
    "passerbarast": "passerbar",
    "passerbaraste": "passerbar",
    "passerbarastes": "passerbar",
    "passerbarasts": "passerbar",
    "passerbare": "passerbar",
    "passerbares": "passerbar",
    "passerbarheten": "passerbarhet",
    "passerbarhetens": "passerbarhet",
    "passerbarhets": "passerbarhet",
    "passerbars": "passerbar",
    "passerbart": "passerbar",
    "passerbarts": "passerbar",
    "passeringar": "passering",
    "passeringarna": "passering",
    "passeringarnas": "passering",
    "passeringars": "passering",
    "passeringen": "passering",
    "passeringens": "passering",
    "passerings": "passering",
    "passerkorten": "passerkort",
    "passerkortens": "passerkort",
    "passerkortet": "passerkort",
    "passerkortets": "passerkort",
    "passerkorts": "passerkort",
    "passersedeln": "passersedel",
    "passersedelns": "passersedel",
    "passersedels": "passersedel",
    "passersedlar": "passersedel",
    "passersedlarna": "passersedel",
    "passersedlarnas": "passersedel",
    "passersedlars": "passersedel",
    "passet": "pass",
    "passets": "pass",
    "passformen": "passform",
    "passformens": "passform",
    "passforms": "passform",
    "passfoton": "passfoto",
    "passfotona": "passfoto",
    "passfotonas": "passfoto",
    "passfotons": "passfoto",
    "passfotos": "passfoto",
    "passfotot": "passfoto",
    "passfotots": "passfoto",
    "passfriheten": "passfrihet",
    "passfrihetens": "passfrihet",
    "passfriheter": "passfrihet",
    "passfriheterna": "passfrihet",
    "passfriheternas": "passfrihet",
    "passfriheters": "passfrihet",
    "passfrihets": "passfrihet",
    "passgångar": "passgångare",
    "passgångaren": "passgångare",
    "passgångarens": "passgångare",
    "passgångares": "passgångare",
    "passgångarna": "passgångare",
    "passgångarnas": "passgångare",
    "passgången": "passgång",
    "passgångens": "passgång",
    "passgångs": "passgång",
    "passionen": "passion",
    "passionens": "passion",
    "passioner": "passion",
    "passionerade": "passionerad",
    "passionerades": "passionerad",
    "passionerads": "passionerad",
    "passionerat": "passionerad",
    "passionerats": "passionerad",
    "passionerna": "passion",
    "passionernas": "passion",
    "passioners": "passion",
    "passions": "passion",
    "passionsblom": "passionsblomma",
    "passionsblomman": "passionsblomma",
    "passionsblommans": "passionsblomma",
    "passionsblommas": "passionsblomma",
    "passionsblomme": "passionsblomma",
    "passionsblommor": "passionsblomma",
    "passionsblommorna": "passionsblomma",
    "passionsblommornas": "passionsblomma",
    "passionsblommors": "passionsblomma",
    "passionsbloms": "passionsblomma",
    "passionsfrukten": "passionsfrukt",
    "passionsfruktens": "passionsfrukt",
    "passionsfrukter": "passionsfrukt",
    "passionsfrukterna": "passionsfrukt",
    "passionsfrukternas": "passionsfrukt",
    "passionsfrukters": "passionsfrukt",
    "passionsfrukts": "passionsfrukt",
    "passionshistorian": "passionshistoria",
    "passionshistorians": "passionshistoria",
    "passionshistorias": "passionshistoria",
    "passionshistorien": "passionshistoria",
    "passionshistoriens": "passionshistoria",
    "passionshistorier": "passionshistoria",
    "passionshistorierna": "passionshistoria",
    "passionshistoriernas": "passionshistoria",
    "passionshistoriers": "passionshistoria",
    "passionsspelen": "passionsspel",
    "passionsspelens": "passionsspel",
    "passionsspelet": "passionsspel",
    "passionsspelets": "passionsspel",
    "passionsspels": "passionsspel",
    "passionsveckan": "passionsvecka",
    "passionsveckans": "passionsvecka",
    "passionsveckas": "passionsvecka",
    "passiv": "passivum",
    "passiva": "passiv",
    "passivan": "passiva",
    "passivana": "passiva",
    "passivanas": "passiva",
    "passivans": "passiva",
    "passivare": "passiv",
    "passivares": "passiv",
    "passivas": "passiva",
    "passivast": "passiv",
    "passivaste": "passiv",
    "passivastes": "passiv",
    "passivasts": "passiv",
    "passive": "passiv",
    "passiven": "passivum",
    "passivens": "passivum",
    "passiver": "passivum",
    "passiverad": "passivera",
    "passiverade": "passivera",
    "passiverades": "passivera",
    "passiverads": "passivera",
    "passiverande": "passivera",
    "passiveranden": "passiverande",
    "passiverandena": "passiverande",
    "passiverandenas": "passiverande",
    "passiverandens": "passiverande",
    "passiverandes": "passiverande",
    "passiverandet": "passiverande",
    "passiverandets": "passiverande",
    "passiverar": "passivera",
    "passiveras": "passivera",
    "passiverat": "passivera",
    "passiverats": "passivera",
    "passiverbara": "passiverbar",
    "passiverbarare": "passiverbar",
    "passiverbarares": "passiverbar",
    "passiverbaras": "passiverbar",
    "passiverbarast": "passiverbar",
    "passiverbaraste": "passiverbar",
    "passiverbarastes": "passiverbar",
    "passiverbarasts": "passiverbar",
    "passiverbare": "passiverbar",
    "passiverbares": "passiverbar",
    "passiverbarheten": "passiverbarhet",
    "passiverbarhetens": "passiverbarhet",
    "passiverbarhets": "passiverbarhet",
    "passiverbars": "passiverbar",
    "passiverbart": "passiverbar",
    "passiverbarts": "passiverbar",
    "passiveringar": "passivering",
    "passiveringarna": "passivering",
    "passiveringarnas": "passivering",
    "passiveringars": "passivering",
    "passiveringen": "passivering",
    "passiveringens": "passivering",
    "passiverings": "passivering",
    "passiverna": "passivum",
    "passivernas": "passivum",
    "passivers": "passivum",
    "passives": "passiv",
    "passivet": "passivum",
    "passivets": "passivum",
    "passivformen": "passivform",
    "passivformens": "passivform",
    "passivformer": "passivform",
    "passivformerna": "passivform",
    "passivformernas": "passivform",
    "passivformers": "passivform",
    "passivforms": "passivform",
    "passiviserad": "passivisera",
    "passiviserade": "passivisera",
    "passiviserades": "passivisera",
    "passiviserads": "passivisera",
    "passiviserande": "passivisera",
    "passiviseranden": "passiviserande",
    "passiviserandena": "passiviserande",
    "passiviserandenas": "passiviserande",
    "passiviserandens": "passiviserande",
    "passiviserandes": "passiviserande",
    "passiviserandet": "passiviserande",
    "passiviserandets": "passiviserande",
    "passiviserar": "passivisera",
    "passiviseras": "passivisera",
    "passiviserat": "passivisera",
    "passiviserats": "passivisera",
    "passiviserbara": "passiviserbar",
    "passiviserbarare": "passiviserbar",
    "passiviserbarares": "passiviserbar",
    "passiviserbaras": "passiviserbar",
    "passiviserbarast": "passiviserbar",
    "passiviserbaraste": "passiviserbar",
    "passiviserbarastes": "passiviserbar",
    "passiviserbarasts": "passiviserbar",
    "passiviserbare": "passiviserbar",
    "passiviserbares": "passiviserbar",
    "passiviserbarheten": "passiviserbarhet",
    "passiviserbarhetens": "passiviserbarhet",
    "passiviserbarhets": "passiviserbarhet",
    "passiviserbars": "passiviserbar",
    "passiviserbart": "passiviserbar",
    "passiviserbarts": "passiviserbar",
    "passiviseringar": "passivisering",
    "passiviseringarna": "passivisering",
    "passiviseringarnas": "passivisering",
    "passiviseringars": "passivisering",
    "passiviseringen": "passivisering",
    "passiviseringens": "passivisering",
    "passiviserings": "passivisering",
    "passiviteten": "passivitet",
    "passivitetens": "passivitet",
    "passiviteter": "passivitet",
    "passiviteterna": "passivitet",
    "passiviteternas": "passivitet",
    "passiviteters": "passivitet",
    "passivitets": "passivitet",
    "passivs": "passivum",
    "passivt": "passiv",
    "passivts": "passiv",
    "passivumet": "passivum",
    "passivumets": "passivum",
    "passivums": "passivum",
    "passkontrollanten": "passkontrollant",
    "passkontrollantens": "passkontrollant",
    "passkontrollanter": "passkontrollant",
    "passkontrollanterna": "passkontrollant",
    "passkontrollanternas": "passkontrollant",
    "passkontrollanters": "passkontrollant",
    "passkontrollants": "passkontrollant",
    "passkontrollen": "passkontroll",
    "passkontrollens": "passkontroll",
    "passkontroller": "passkontroll",
    "passkontrollerna": "passkontroll",
    "passkontrollernas": "passkontroll",
    "passkontrollers": "passkontroll",
    "passkontrolls": "passkontroll",
    "passliga": "passlig",
    "passligare": "passlig",
    "passligares": "passlig",
    "passligas": "passlig",
    "passligast": "passlig",
    "passligaste": "passlig",
    "passligastes": "passlig",
    "passligasts": "passlig",
    "passlige": "passlig",
    "passliges": "passlig",
    "passligheten": "passlighet",
    "passlighetens": "passlighet",
    "passlighets": "passlighet",
    "passligs": "passlig",
    "passligt": "passlig",
    "passligts": "passlig",
    "passningar": "passning",
    "passningarna": "passning",
    "passningarnas": "passning",
    "passningars": "passning",
    "passningen": "passning",
    "passningens": "passning",
    "passnings": "passning",
    "passoppen": "passopp",
    "passoppens": "passopp",
    "passopper": "passopp",
    "passopperna": "passopp",
    "passoppernas": "passopp",
    "passoppers": "passopp",
    "passopps": "passopp",
    "passpoalen": "passpoal",
    "passpoalens": "passpoal",
    "passpoaler": "passpoal",
    "passpoalerna": "passpoal",
    "passpoalernas": "passpoal",
    "passpoalers": "passpoal",
    "passpoals": "passpoal",
    "passusar": "passus",
    "passusarna": "passus",
    "passusarnas": "passus",
    "passusars": "passus",
    "passusen": "passus",
    "passusens": "passus",
    "past": "pasta",
    "pastan": "pasta",
    "pastans": "pasta",
    "pastarätten": "pastarätt",
    "pastarättens": "pastarätt",
    "pastarätter": "pastarätt",
    "pastarätterna": "pastarätt",
    "pastarätternas": "pastarätt",
    "pastarätters": "pastarätt",
    "pastarätts": "pastarätt",
    "pastas": "pasta",
    "pastasalladen": "pastasallad",
    "pastasalladens": "pastasallad",
    "pastasallader": "pastasallad",
    "pastasalladerna": "pastasallad",
    "pastasalladernas": "pastasallad",
    "pastasalladers": "pastasallad",
    "pastasallads": "pastasallad",
    "paste": "pasta",
    "pastejen": "pastej",
    "pastejens": "pastej",
    "pastejer": "pastej",
    "pastejerna": "pastej",
    "pastejernas": "pastej",
    "pastejers": "pastej",
    "pastejs": "pastej",
    "pastellen": "pastell",
    "pastellens": "pastell",
    "pasteller": "pastell",
    "pastellerna": "pastell",
    "pastellernas": "pastell",
    "pastellers": "pastell",
    "pastellfärgade": "pastellfärgad",
    "pastellfärgades": "pastellfärgad",
    "pastellfärgads": "pastellfärgad",
    "pastellfärgat": "pastellfärgad",
    "pastellfärgats": "pastellfärgad",
    "pastellfärgen": "pastellfärg",
    "pastellfärgens": "pastellfärg",
    "pastellfärger": "pastellfärg",
    "pastellfärgerna": "pastellfärg",
    "pastellfärgernas": "pastellfärg",
    "pastellfärgers": "pastellfärg",
    "pastellfärgs": "pastellfärg",
    "pastellmålningar": "pastellmålning",
    "pastellmålningarna": "pastellmålning",
    "pastellmålningarnas": "pastellmålning",
    "pastellmålningars": "pastellmålning",
    "pastellmålningen": "pastellmålning",
    "pastellmålningens": "pastellmålning",
    "pastellmålnings": "pastellmålning",
    "pastells": "pastell",
    "pastillen": "pastill",
    "pastillens": "pastill",
    "pastiller": "pastill",
    "pastillerna": "pastill",
    "pastillernas": "pastill",
    "pastillers": "pastill",
    "pastills": "pastill",
    "pastischen": "pastisch",
    "pastischens": "pastisch",
    "pastischer": "pastisch",
    "pastischerna": "pastisch",
    "pastischernas": "pastisch",
    "pastischers": "pastisch",
    "pastischkaraktären": "pastischkaraktär",
    "pastischkaraktärens": "pastischkaraktär",
    "pastischkaraktärs": "pastischkaraktär",
    "pastischs": "pastisch",
    "pastisen": "pastis",
    "pastisens": "pastis",
    "pastor": "pasta",
    "pastorala": "pastoral",
    "pastoralare": "pastoral",
    "pastoralares": "pastoral",
    "pastoralas": "pastoral",
    "pastoralast": "pastoral",
    "pastoralaste": "pastoral",
    "pastoralastes": "pastoral",
    "pastoralasts": "pastoral",
    "pastorale": "pastoral",
    "pastoralen": "pastoral",
    "pastoralens": "pastoral",
    "pastoraler": "pastoral",
    "pastoralerna": "pastoral",
    "pastoralernas": "pastoral",
    "pastoralers": "pastoral",
    "pastorales": "pastoral",
    "pastorals": "pastoral",
    "pastoralt": "pastoral",
    "pastoralts": "pastoral",
    "pastoraten": "pastorat",
    "pastoratens": "pastorat",
    "pastoratet": "pastorat",
    "pastoratets": "pastorat",
    "pastorats": "pastorat",
    "pastoratsadjunkten": "pastoratsadjunkt",
    "pastoratsadjunktens": "pastoratsadjunkt",
    "pastoratsadjunkter": "pastoratsadjunkt",
    "pastoratsadjunkterna": "pastoratsadjunkt",
    "pastoratsadjunkternas": "pastoratsadjunkt",
    "pastoratsadjunkters": "pastoratsadjunkt",
    "pastoratsadjunkts": "pastoratsadjunkt",
    "pastorer": "pastor",
    "pastorerna": "pastor",
    "pastorernas": "pastor",
    "pastorers": "pastor",
    "pastorn": "pastor",
    "pastorna": "pasta",
    "pastornas": "pasta",
    "pastorns": "pastor",
    "pastors": "pastor",
    "pastorsadjunkten": "pastorsadjunkt",
    "pastorsadjunktens": "pastorsadjunkt",
    "pastorsadjunkter": "pastorsadjunkt",
    "pastorsadjunkterna": "pastorsadjunkt",
    "pastorsadjunkternas": "pastorsadjunkt",
    "pastorsadjunkters": "pastorsadjunkt",
    "pastorsadjunkts": "pastorsadjunkt",
    "pastorsexpeditionen": "pastorsexpedition",
    "pastorsexpeditionens": "pastorsexpedition",
    "pastorsexpeditioner": "pastorsexpedition",
    "pastorsexpeditionerna": "pastorsexpedition",
    "pastorsexpeditionernas": "pastorsexpedition",
    "pastorsexpeditioners": "pastorsexpedition",
    "pastorsexpeditions": "pastorsexpedition",
    "pastorsämbeten": "pastorsämbete",
    "pastorsämbetena": "pastorsämbete",
    "pastorsämbetenas": "pastorsämbete",
    "pastorsämbetens": "pastorsämbete",
    "pastorsämbetes": "pastorsämbete",
    "pastorsämbetet": "pastorsämbete",
    "pastorsämbetets": "pastorsämbete",
    "pastosa": "pastos",
    "pastosare": "pastos",
    "pastosares": "pastos",
    "pastosas": "pastos",
    "pastosast": "pastos",
    "pastosaste": "pastos",
    "pastosastes": "pastos",
    "pastosasts": "pastos",
    "pastose": "pastos",
    "pastoses": "pastos",
    "pastost": "pastos",
    "pastosts": "pastos",
    "pastramin": "pastrami",
    "pastramins": "pastrami",
    "pastramis": "pastrami",
    "pastöriserad": "pastörisera",
    "pastöriserade": "pastörisera",
    "pastöriserades": "pastörisera",
    "pastöriserads": "pastörisera",
    "pastöriserande": "pastörisera",
    "pastöriseranden": "pastöriserande",
    "pastöriserandena": "pastöriserande",
    "pastöriserandenas": "pastöriserande",
    "pastöriserandens": "pastöriserande",
    "pastöriserandes": "pastöriserande",
    "pastöriserandet": "pastöriserande",
    "pastöriserandets": "pastöriserande",
    "pastöriserar": "pastörisera",
    "pastöriseras": "pastörisera",
    "pastöriserat": "pastörisera",
    "pastöriserats": "pastörisera",
    "pastöriserbara": "pastöriserbar",
    "pastöriserbarare": "pastöriserbar",
    "pastöriserbarares": "pastöriserbar",
    "pastöriserbaras": "pastöriserbar",
    "pastöriserbarast": "pastöriserbar",
    "pastöriserbaraste": "pastöriserbar",
    "pastöriserbarastes": "pastöriserbar",
    "pastöriserbarasts": "pastöriserbar",
    "pastöriserbare": "pastöriserbar",
    "pastöriserbares": "pastöriserbar",
    "pastöriserbarheten": "pastöriserbarhet",
    "pastöriserbarhetens": "pastöriserbarhet",
    "pastöriserbarhets": "pastöriserbarhet",
    "pastöriserbars": "pastöriserbar",
    "pastöriserbart": "pastöriserbar",
    "pastöriserbarts": "pastöriserbar",
    "pastöriseringar": "pastörisering",
    "pastöriseringarna": "pastörisering",
    "pastöriseringarnas": "pastörisering",
    "pastöriseringars": "pastörisering",
    "pastöriseringen": "pastörisering",
    "pastöriseringens": "pastörisering",
    "pastöriserings": "pastörisering",
    "pastösa": "pastös",
    "pastösare": "pastös",
    "pastösares": "pastös",
    "pastösas": "pastös",
    "pastösast": "pastös",
    "pastösaste": "pastös",
    "pastösastes": "pastös",
    "pastösasts": "pastös",
    "pastöse": "pastös",
    "pastöses": "pastös",
    "pastöst": "pastös",
    "pastösts": "pastös",
    "pat": "pata",
    "patan": "pata",
    "patans": "pata",
    "patas": "pata",
    "pate": "pata",
    "patell": "patella",
    "patellan": "patella",
    "patellans": "patella",
    "patellarreflexen": "patellarreflex",
    "patellarreflexens": "patellarreflex",
    "patellas": "patella",
    "patelle": "patella",
    "patellor": "patella",
    "patellorna": "patella",
    "patellornas": "patella",
    "patellors": "patella",
    "patells": "patella",
    "patenen": "paten",
    "patenens": "paten",
    "patener": "paten",
    "patenerna": "paten",
    "patenernas": "paten",
    "pateners": "paten",
    "patens": "paten",
    "patentadvokaten": "patentadvokat",
    "patentadvokatens": "patentadvokat",
    "patentadvokater": "patentadvokat",
    "patentadvokaterna": "patentadvokat",
    "patentadvokaternas": "patentadvokat",
    "patentadvokaters": "patentadvokat",
    "patentadvokats": "patentadvokat",
    "patentansökans": "patentansökan",
    "patenten": "patent",
    "patentens": "patent",
    "patenterad": "patentera",
    "patenterade": "patenterad",
    "patenterades": "patenterad",
    "patenterads": "patenterad",
    "patenterande": "patentera",
    "patenteranden": "patenterande",
    "patenterandena": "patenterande",
    "patenterandenas": "patenterande",
    "patenterandens": "patenterande",
    "patenterandes": "patenterande",
    "patenterandet": "patenterande",
    "patenterandets": "patenterande",
    "patenterar": "patentera",
    "patenteras": "patentera",
    "patenterat": "patenterad",
    "patenterats": "patenterad",
    "patenterbara": "patenterbar",
    "patenterbarare": "patenterbar",
    "patenterbarares": "patenterbar",
    "patenterbaras": "patenterbar",
    "patenterbarast": "patenterbar",
    "patenterbaraste": "patenterbar",
    "patenterbarastes": "patenterbar",
    "patenterbarasts": "patenterbar",
    "patenterbare": "patenterbar",
    "patenterbares": "patenterbar",
    "patenterbarheten": "patenterbarhet",
    "patenterbarhetens": "patenterbarhet",
    "patenterbarhets": "patenterbarhet",
    "patenterbars": "patenterbar",
    "patenterbart": "patenterbar",
    "patenterbarts": "patenterbar",
    "patenteringar": "patentering",
    "patenteringarna": "patentering",
    "patenteringarnas": "patentering",
    "patenteringars": "patentering",
    "patenteringen": "patentering",
    "patenteringens": "patentering",
    "patenterings": "patentering",
    "patentet": "patent",
    "patentets": "patent",
    "patentfärgen": "patentfärg",
    "patentfärgens": "patentfärg",
    "patentfärgs": "patentfärg",
    "patentintrången": "patentintrång",
    "patentintrångens": "patentintrång",
    "patentintrånget": "patentintrång",
    "patentintrångets": "patentintrång",
    "patentintrångs": "patentintrång",
    "patentlåsen": "patentlås",
    "patentlåsens": "patentlås",
    "patentlåset": "patentlås",
    "patentlåsets": "patentlås",
    "patentmedicinen": "patentmedicin",
    "patentmedicinens": "patentmedicin",
    "patentmediciner": "patentmedicin",
    "patentmedicinerna": "patentmedicin",
    "patentmedicinernas": "patentmedicin",
    "patentmediciners": "patentmedicin",
    "patentmedicins": "patentmedicin",
    "patentmålen": "patentmål",
    "patentmålens": "patentmål",
    "patentmålet": "patentmål",
    "patentmålets": "patentmål",
    "patentmåls": "patentmål",
    "patents": "patent",
    "patentsmörgåsar": "patentsmörgås",
    "patentsmörgåsarna": "patentsmörgås",
    "patentsmörgåsarnas": "patentsmörgås",
    "patentsmörgåsars": "patentsmörgås",
    "patentsmörgåsen": "patentsmörgås",
    "patentsmörgåsens": "patentsmörgås",
    "patentstickade": "patentstickad",
    "patentstickades": "patentstickad",
    "patentstickads": "patentstickad",
    "patentstickat": "patentstickad",
    "patentstickats": "patentstickad",
    "patentsökar": "patentsökare",
    "patentsökaren": "patentsökare",
    "patentsökarens": "patentsökare",
    "patentsökares": "patentsökare",
    "patentsökarna": "patentsökare",
    "patentsökarnas": "patentsökare",
    "patern": "pater",
    "paternosteren": "paternoster",
    "paternosterens": "paternoster",
    "paternosteret": "paternoster",
    "paternosterets": "paternoster",
    "paternosterhissar": "paternosterhiss",
    "paternosterhissarna": "paternosterhiss",
    "paternosterhissarnas": "paternosterhiss",
    "paternosterhissars": "paternosterhiss",
    "paternosterhissen": "paternosterhiss",
    "paternosterhissens": "paternosterhiss",
    "paternosters": "paternoster",
    "paternosterverken": "paternosterverk",
    "paternosterverkens": "paternosterverk",
    "paternosterverket": "paternosterverk",
    "paternosterverkets": "paternosterverk",
    "paternosterverks": "paternosterverk",
    "paternostren": "paternoster",
    "paternostrens": "paternoster",
    "paternostret": "paternoster",
    "paternostrets": "paternoster",
    "paterns": "pater",
    "paters": "pater",
    "patetiken": "patetik",
    "patetikens": "patetik",
    "patetiks": "patetik",
    "patetiska": "patetisk",
    "patetiskare": "patetisk",
    "patetiskares": "patetisk",
    "patetiskas": "patetisk",
    "patetiskast": "patetisk",
    "patetiskaste": "patetisk",
    "patetiskastes": "patetisk",
    "patetiskasts": "patetisk",
    "patetiske": "patetisk",
    "patetiskes": "patetisk",
    "patetisks": "patetisk",
    "patetiskt": "patetisk",
    "patetiskts": "patetisk",
    "patiensen": "patiens",
    "patiensens": "patiens",
    "patienser": "patiens",
    "patienserna": "patiens",
    "patiensernas": "patiens",
    "patiensers": "patiens",
    "patientbesöken": "patientbesök",
    "patientbesökens": "patientbesök",
    "patientbesöket": "patientbesök",
    "patientbesökets": "patientbesök",
    "patientbesöks": "patientbesök",
    "patienten": "patient",
    "patientens": "patient",
    "patienter": "patient",
    "patienterna": "patient",
    "patienternas": "patient",
    "patienters": "patient",
    "patientplatsen": "patientplats",
    "patientplatsens": "patientplats",
    "patientplatser": "patientplats",
    "patientplatserna": "patientplats",
    "patientplatsernas": "patientplats",
    "patientplatsers": "patientplats",
    "patientplåtar": "patientplåt",
    "patientplåtarna": "patientplåt",
    "patientplåtarnas": "patientplåt",
    "patientplåtars": "patientplåt",
    "patientplåten": "patientplåt",
    "patientplåtens": "patientplåt",
    "patientplåts": "patientplåt",
    "patients": "patient",
    "patinan": "patina",
    "patinans": "patina",
    "patinas": "patina",
    "patinerad": "patinera",
    "patinerade": "patinera",
    "patinerades": "patinera",
    "patinerads": "patinera",
    "patinerande": "patinera",
    "patineranden": "patinerande",
    "patinerandena": "patinerande",
    "patinerandenas": "patinerande",
    "patinerandens": "patinerande",
    "patinerandes": "patinerande",
    "patinerandet": "patinerande",
    "patinerandets": "patinerande",
    "patinerar": "patinera",
    "patineras": "patinera",
    "patinerat": "patinera",
    "patinerats": "patinera",
    "patinerbara": "patinerbar",
    "patinerbarare": "patinerbar",
    "patinerbarares": "patinerbar",
    "patinerbaras": "patinerbar",
    "patinerbarast": "patinerbar",
    "patinerbaraste": "patinerbar",
    "patinerbarastes": "patinerbar",
    "patinerbarasts": "patinerbar",
    "patinerbare": "patinerbar",
    "patinerbares": "patinerbar",
    "patinerbarheten": "patinerbarhet",
    "patinerbarhetens": "patinerbarhet",
    "patinerbarhets": "patinerbarhet",
    "patinerbars": "patinerbar",
    "patinerbart": "patinerbar",
    "patinerbarts": "patinerbar",
    "patineringar": "patinering",
    "patineringarna": "patinering",
    "patineringarnas": "patinering",
    "patineringars": "patinering",
    "patineringen": "patinering",
    "patineringens": "patinering",
    "patinerings": "patinering",
    "patofysiologien": "patofysiologi",
    "patofysiologiens": "patofysiologi",
    "patofysiologin": "patofysiologi",
    "patofysiologins": "patofysiologi",
    "patofysiologis": "patofysiologi",
    "patogena": "patogen",
    "patogenare": "patogen",
    "patogenares": "patogen",
    "patogenas": "patogen",
    "patogenast": "patogen",
    "patogenaste": "patogen",
    "patogenastes": "patogen",
    "patogenasts": "patogen",
    "patogene": "patogen",
    "patogenes": "patogen",
    "patogens": "patogen",
    "patogent": "patogen",
    "patogents": "patogen",
    "patologen": "patolog",
    "patologens": "patolog",
    "patologer": "patolog",
    "patologerna": "patolog",
    "patologernas": "patolog",
    "patologers": "patolog",
    "patologien": "patologi",
    "patologiens": "patologi",
    "patologier": "patologi",
    "patologierna": "patologi",
    "patologiernas": "patologi",
    "patologiers": "patologi",
    "patologin": "patologi",
    "patologins": "patologi",
    "patologis": "patologi",
    "patologiska": "patologisk",
    "patologiskare": "patologisk",
    "patologiskares": "patologisk",
    "patologiskas": "patologisk",
    "patologiskast": "patologisk",
    "patologiskaste": "patologisk",
    "patologiskastes": "patologisk",
    "patologiskasts": "patologisk",
    "patologiske": "patologisk",
    "patologiskes": "patologisk",
    "patologisks": "patologisk",
    "patologiskt": "patologisk",
    "patologiskts": "patologisk",
    "patologs": "patolog",
    "pator": "pata",
    "patorna": "pata",
    "patornas": "pata",
    "pators": "pata",
    "patoset": "patos",
    "patosets": "patos",
    "patrar": "pater",
    "patrarna": "pater",
    "patrarnas": "pater",
    "patrars": "pater",
    "patrasket": "patrask",
    "patraskets": "patrask",
    "patrasks": "patrask",
    "patriarkala": "patriarkal",
    "patriarkalare": "patriarkal",
    "patriarkalares": "patriarkal",
    "patriarkalas": "patriarkal",
    "patriarkalast": "patriarkal",
    "patriarkalaste": "patriarkal",
    "patriarkalastes": "patriarkal",
    "patriarkalasts": "patriarkal",
    "patriarkale": "patriarkal",
    "patriarkales": "patriarkal",
    "patriarkaliska": "patriarkalisk",
    "patriarkaliskare": "patriarkalisk",
    "patriarkaliskares": "patriarkalisk",
    "patriarkaliskas": "patriarkalisk",
    "patriarkaliskast": "patriarkalisk",
    "patriarkaliskaste": "patriarkalisk",
    "patriarkaliskastes": "patriarkalisk",
    "patriarkaliskasts": "patriarkalisk",
    "patriarkaliske": "patriarkalisk",
    "patriarkaliskes": "patriarkalisk",
    "patriarkalisks": "patriarkalisk",
    "patriarkaliskt": "patriarkalisk",
    "patriarkaliskts": "patriarkalisk",
    "patriarkals": "patriarkal",
    "patriarkalt": "patriarkal",
    "patriarkalts": "patriarkal",
    "patriarkaten": "patriarkat",
    "patriarkatens": "patriarkat",
    "patriarkatet": "patriarkat",
    "patriarkatets": "patriarkat",
    "patriarkats": "patriarkat",
    "patriarken": "patriark",
    "patriarkens": "patriark",
    "patriarker": "patriark",
    "patriarkerna": "patriark",
    "patriarkernas": "patriark",
    "patriarkers": "patriark",
    "patriarks": "patriark",
    "patriarkskägget": "patriarkskägg",
    "patriarkskäggets": "patriarkskägg",
    "patriarkskäggs": "patriarkskägg",
    "patriciern": "patricier",
    "patricierna": "patricier",
    "patriciernas": "patricier",
    "patricierns": "patricier",
    "patriciers": "patricier",
    "patrioten": "patriot",
    "patriotens": "patriot",
    "patrioter": "patriot",
    "patrioterna": "patriot",
    "patrioternas": "patriot",
    "patrioters": "patriot",
    "patriotiska": "patriotisk",
    "patriotiskare": "patriotisk",
    "patriotiskares": "patriotisk",
    "patriotiskas": "patriotisk",
    "patriotiskast": "patriotisk",
    "patriotiskaste": "patriotisk",
    "patriotiskastes": "patriotisk",
    "patriotiskasts": "patriotisk",
    "patriotiske": "patriotisk",
    "patriotiskes": "patriotisk",
    "patriotisks": "patriotisk",
    "patriotiskt": "patriotisk",
    "patriotiskts": "patriotisk",
    "patriotismen": "patriotism",
    "patriotismens": "patriotism",
    "patriotismer": "patriotism",
    "patriotismerna": "patriotism",
    "patriotismernas": "patriotism",
    "patriotismers": "patriotism",
    "patriotisms": "patriotism",
    "patriotistiska": "patriotistisk",
    "patriotistiskas": "patriotistisk",
    "patriotistiske": "patriotistisk",
    "patriotistiskes": "patriotistisk",
    "patriotistisks": "patriotistisk",
    "patriotistiskt": "patriotistisk",
    "patriotistiskts": "patriotistisk",
    "patriots": "patriot",
    "patrisen": "patris",
    "patrisens": "patris",
    "patriser": "patris",
    "patriserna": "patris",
    "patrisernas": "patris",
    "patrisers": "patris",
    "patristiken": "patristik",
    "patristikens": "patristik",
    "patristiks": "patristik",
    "patronatsrätten": "patronatsrätt",
    "patronatsrättens": "patronatsrätt",
    "patronatsrätts": "patronatsrätt",
    "patronbälten": "patronbälte",
    "patronbältena": "patronbälte",
    "patronbältenas": "patronbälte",
    "patronbältens": "patronbälte",
    "patronbältes": "patronbälte",
    "patronbältet": "patronbälte",
    "patronbältets": "patronbälte",
    "patronen": "patron",
    "patronens": "patron",
    "patroner": "patron",
    "patronerna": "patron",
    "patronernas": "patron",
    "patroners": "patron",
    "patronhyls": "patronhylsa",
    "patronhylsan": "patronhylsa",
    "patronhylsans": "patronhylsa",
    "patronhylsas": "patronhylsa",
    "patronhylse": "patronhylsa",
    "patronhylsor": "patronhylsa",
    "patronhylsorna": "patronhylsa",
    "patronhylsornas": "patronhylsa",
    "patronhylsors": "patronhylsa",
    "patronhållar": "patronhållare",
    "patronhållaren": "patronhållare",
    "patronhållarens": "patronhållare",
    "patronhållares": "patronhållare",
    "patronhållarna": "patronhållare",
    "patronhållarnas": "patronhållare",
    "patrons": "patron",
    "patronsprut": "patronspruta",
    "patronsprutan": "patronspruta",
    "patronsprutans": "patronspruta",
    "patronsprutas": "patronspruta",
    "patronsprute": "patronspruta",
    "patronsprutor": "patronspruta",
    "patronsprutorna": "patronspruta",
    "patronsprutornas": "patronspruta",
    "patronsprutors": "patronspruta",
    "patronspruts": "patronspruta",
    "patronväsk": "patronväska",
    "patronväskan": "patronväska",
    "patronväskans": "patronväska",
    "patronväskas": "patronväska",
    "patronväske": "patronväska",
    "patronväskor": "patronväska",
    "patronväskorna": "patronväska",
    "patronväskornas": "patronväska",
    "patronväskors": "patronväska",
    "patronymika": "patronymikon",
    "patronymikas": "patronymikon",
    "patronymikonen": "patronymikon",
    "patronymikonens": "patronymikon",
    "patronymikonet": "patronymikon",
    "patronymikonets": "patronymikon",
    "patronymikons": "patronymikon",
    "patrullbilar": "patrullbil",
    "patrullbilarna": "patrullbil",
    "patrullbilarnas": "patrullbil",
    "patrullbilars": "patrullbil",
    "patrullbilen": "patrullbil",
    "patrullbilens": "patrullbil",
    "patrullbils": "patrullbil",
    "patrullbåtar": "patrullbåt",
    "patrullbåtarna": "patrullbåt",
    "patrullbåtarnas": "patrullbåt",
    "patrullbåtars": "patrullbåt",
    "patrullbåten": "patrullbåt",
    "patrullbåtens": "patrullbåt",
    "patrullbåts": "patrullbåt",
    "patrullen": "patrull",
    "patrullens": "patrull",
    "patruller": "patrull",
    "patrullerad": "patrullera",
    "patrullerade": "patrullera",
    "patrullerades": "patrullera",
    "patrullerads": "patrullera",
    "patrullerande": "patrullera",
    "patrulleranden": "patrullerande",
    "patrullerandena": "patrullerande",
    "patrullerandenas": "patrullerande",
    "patrullerandens": "patrullerande",
    "patrullerandes": "patrullerande",
    "patrullerandet": "patrullerande",
    "patrullerandets": "patrullerande",
    "patrullerar": "patrullera",
    "patrulleras": "patrullera",
    "patrullerat": "patrullera",
    "patrullerats": "patrullera",
    "patrullerbara": "patrullerbar",
    "patrullerbarare": "patrullerbar",
    "patrullerbarares": "patrullerbar",
    "patrullerbaras": "patrullerbar",
    "patrullerbarast": "patrullerbar",
    "patrullerbaraste": "patrullerbar",
    "patrullerbarastes": "patrullerbar",
    "patrullerbarasts": "patrullerbar",
    "patrullerbare": "patrullerbar",
    "patrullerbares": "patrullerbar",
    "patrullerbarheten": "patrullerbarhet",
    "patrullerbarhetens": "patrullerbarhet",
    "patrullerbarhets": "patrullerbarhet",
    "patrullerbars": "patrullerbar",
    "patrullerbart": "patrullerbar",
    "patrullerbarts": "patrullerbar",
    "patrulleringar": "patrullering",
    "patrulleringarna": "patrullering",
    "patrulleringarnas": "patrullering",
    "patrulleringars": "patrullering",
    "patrulleringen": "patrullering",
    "patrulleringens": "patrullering",
    "patrullerings": "patrullering",
    "patrullerna": "patrull",
    "patrullernas": "patrull",
    "patrullers": "patrull",
    "patrulls": "patrull",
    "pats": "pata",
    "patschulin": "patschuli",
    "patschulins": "patschuli",
    "patschulis": "patschuli",
    "patschulit": "patschuli",
    "patschulits": "patschuli",
    "patt": "patte",
    "pattar": "patte",
    "pattarna": "patte",
    "pattarnas": "patte",
    "pattars": "patte",
    "patten": "patte",
    "pattens": "patte",
    "patter": "patt",
    "patterna": "patt",
    "patternas": "patt",
    "patters": "patt",
    "pattes": "patte",
    "patts": "patte",
    "patéer": "paté",
    "patéerna": "paté",
    "patéernas": "paté",
    "patéers": "paté",
    "patén": "paté",
    "paténs": "paté",
    "patés": "paté",
    "paulunen": "paulun",
    "paulunens": "paulun",
    "pauluner": "paulun",
    "paulunerna": "paulun",
    "paulunernas": "paulun",
    "pauluners": "paulun",
    "pauluns": "paulun",
    "pauperiserad": "pauperisera",
    "pauperiserade": "pauperisera",
    "pauperiserades": "pauperisera",
    "pauperiserads": "pauperisera",
    "pauperiserande": "pauperisera",
    "pauperiseranden": "pauperiserande",
    "pauperiserandena": "pauperiserande",
    "pauperiserandenas": "pauperiserande",
    "pauperiserandens": "pauperiserande",
    "pauperiserandes": "pauperiserande",
    "pauperiserandet": "pauperiserande",
    "pauperiserandets": "pauperiserande",
    "pauperiserar": "pauperisera",
    "pauperiseras": "pauperisera",
    "pauperiserat": "pauperisera",
    "pauperiserats": "pauperisera",
    "pauperiserbara": "pauperiserbar",
    "pauperiserbarare": "pauperiserbar",
    "pauperiserbarares": "pauperiserbar",
    "pauperiserbaras": "pauperiserbar",
    "pauperiserbarast": "pauperiserbar",
    "pauperiserbaraste": "pauperiserbar",
    "pauperiserbarastes": "pauperiserbar",
    "pauperiserbarasts": "pauperiserbar",
    "pauperiserbare": "pauperiserbar",
    "pauperiserbares": "pauperiserbar",
    "pauperiserbarheten": "pauperiserbarhet",
    "pauperiserbarhetens": "pauperiserbarhet",
    "pauperiserbarhets": "pauperiserbarhet",
    "pauperiserbars": "pauperiserbar",
    "pauperiserbart": "pauperiserbar",
    "pauperiserbarts": "pauperiserbar",
    "pauperiseringar": "pauperisering",
    "pauperiseringarna": "pauperisering",
    "pauperiseringarnas": "pauperisering",
    "pauperiseringars": "pauperisering",
    "pauperiseringen": "pauperisering",
    "pauperiseringens": "pauperisering",
    "pauperiserings": "pauperisering",
    "pauperismen": "pauperism",
    "pauperismens": "pauperism",
    "pauperismer": "pauperism",
    "pauperismerna": "pauperism",
    "pauperismernas": "pauperism",
    "pauperismers": "pauperism",
    "pauperisms": "pauperism",
    "paus": "pausa",
    "pausad": "pausa",
    "pausade": "pausa",
    "pausades": "pausa",
    "pausads": "pausa",
    "pausande": "pausa",
    "pausanden": "pausande",
    "pausandena": "pausande",
    "pausandenas": "pausande",
    "pausandens": "pausande",
    "pausandes": "pausande",
    "pausandet": "pausande",
    "pausandets": "pausande",
    "pausar": "pausa",
    "pausas": "pausa",
    "pausat": "pausa",
    "pausats": "pausa",
    "pausen": "paus",
    "pausens": "paus",
    "pauser": "paus",
    "pauserad": "pausera",
    "pauserade": "pausera",
    "pauserades": "pausera",
    "pauserads": "pausera",
    "pauserande": "pausera",
    "pauseranden": "pauserande",
    "pauserandena": "pauserande",
    "pauserandenas": "pauserande",
    "pauserandens": "pauserande",
    "pauserandes": "pauserande",
    "pauserandet": "pauserande",
    "pauserandets": "pauserande",
    "pauserar": "pausera",
    "pauseras": "pausera",
    "pauserat": "pausera",
    "pauserats": "pausera",
    "pauserbara": "pauserbar",
    "pauserbarare": "pauserbar",
    "pauserbarares": "pauserbar",
    "pauserbaras": "pauserbar",
    "pauserbarast": "pauserbar",
    "pauserbaraste": "pauserbar",
    "pauserbarastes": "pauserbar",
    "pauserbarasts": "pauserbar",
    "pauserbare": "pauserbar",
    "pauserbares": "pauserbar",
    "pauserbarheten": "pauserbarhet",
    "pauserbarhetens": "pauserbarhet",
    "pauserbarhets": "pauserbarhet",
    "pauserbars": "pauserbar",
    "pauserbart": "pauserbar",
    "pauserbarts": "pauserbar",
    "pauseringar": "pausering",
    "pauseringarna": "pausering",
    "pauseringarnas": "pausering",
    "pauseringars": "pausering",
    "pauseringen": "pausering",
    "pauseringens": "pausering",
    "pauserings": "pausering",
    "pauserna": "paus",
    "pausernas": "paus",
    "pausers": "paus",
    "pausfågeln": "pausfågel",
    "pausfågelns": "pausfågel",
    "pausfågels": "pausfågel",
    "pausfåglar": "pausfågel",
    "pausfåglarna": "pausfågel",
    "pausfåglarnas": "pausfågel",
    "pausfåglars": "pausfågel",
    "pauskommaterad": "pauskommatera",
    "pauskommaterade": "pauskommatera",
    "pauskommaterades": "pauskommatera",
    "pauskommaterads": "pauskommatera",
    "pauskommaterande": "pauskommatera",
    "pauskommateranden": "pauskommaterande",
    "pauskommaterandena": "pauskommaterande",
    "pauskommaterandenas": "pauskommaterande",
    "pauskommaterandens": "pauskommaterande",
    "pauskommaterandes": "pauskommaterande",
    "pauskommaterandet": "pauskommaterande",
    "pauskommaterandets": "pauskommaterande",
    "pauskommaterar": "pauskommatera",
    "pauskommateras": "pauskommatera",
    "pauskommaterat": "pauskommatera",
    "pauskommaterats": "pauskommatera",
    "pauskommaterbara": "pauskommaterbar",
    "pauskommaterbarare": "pauskommaterbar",
    "pauskommaterbarares": "pauskommaterbar",
    "pauskommaterbaras": "pauskommaterbar",
    "pauskommaterbarast": "pauskommaterbar",
    "pauskommaterbaraste": "pauskommaterbar",
    "pauskommaterbarastes": "pauskommaterbar",
    "pauskommaterbarasts": "pauskommaterbar",
    "pauskommaterbare": "pauskommaterbar",
    "pauskommaterbares": "pauskommaterbar",
    "pauskommaterbarheten": "pauskommaterbarhet",
    "pauskommaterbarhetens": "pauskommaterbarhet",
    "pauskommaterbarhets": "pauskommaterbarhet",
    "pauskommaterbars": "pauskommaterbar",
    "pauskommaterbart": "pauskommaterbar",
    "pauskommaterbarts": "pauskommaterbar",
    "pauskommateringar": "pauskommatering",
    "pauskommateringarna": "pauskommatering",
    "pauskommateringarnas": "pauskommatering",
    "pauskommateringars": "pauskommatering",
    "pauskommateringen": "pauskommatering",
    "pauskommateringens": "pauskommatering",
    "pauskommaterings": "pauskommatering",
    "paussignalen": "paussignal",
    "paussignalens": "paussignal",
    "paussignaler": "paussignal",
    "paussignalerna": "paussignal",
    "paussignalernas": "paussignal",
    "paussignalers": "paussignal",
    "paussignals": "paussignal",
    "pausteckens": "paustecken",
    "paustecknen": "paustecken",
    "paustecknens": "paustecken",
    "paustecknet": "paustecken",
    "paustecknets": "paustecken",
    "pav": "pava",
    "pavan": "pava",
    "pavanen": "pavane",
    "pavanens": "pavane",
    "pavaner": "pavane",
    "pavanerna": "pavane",
    "pavanernas": "pavane",
    "pavaners": "pavane",
    "pavanes": "pavane",
    "pavans": "pava",
    "pavas": "pava",
    "pave": "pava",
    "paviljongen": "paviljong",
    "paviljongens": "paviljong",
    "paviljonger": "paviljong",
    "paviljongerna": "paviljong",
    "paviljongernas": "paviljong",
    "paviljongers": "paviljong",
    "paviljongs": "paviljong",
    "pavor": "pava",
    "pavorna": "pava",
    "pavornas": "pava",
    "pavors": "pava",
    "pavs": "pava",
    "pax": "paxa",
    "paxad": "paxa",
    "paxade": "paxa",
    "paxades": "paxa",
    "paxads": "paxa",
    "paxande": "paxa",
    "paxanden": "paxande",
    "paxandena": "paxande",
    "paxandenas": "paxande",
    "paxandens": "paxande",
    "paxandes": "paxande",
    "paxandet": "paxande",
    "paxandets": "paxande",
    "paxar": "paxa",
    "paxas": "paxa",
    "paxat": "paxa",
    "paxats": "paxa",
    "pdf-formatet": "pdf-format",
    "pdf-formatets": "pdf-format",
    "pdf-formats": "pdf-format",
    "peangen": "peang",
    "peangens": "peang",
    "peanger": "peang",
    "peangerna": "peang",
    "peangernas": "peang",
    "peangers": "peang",
    "peangs": "peang",
    "pechbländes": "pechblände",
    "pechbländet": "pechblände",
    "pechbländets": "pechblände",
    "pedagogen": "pedagog",
    "pedagogens": "pedagog",
    "pedagoger": "pedagog",
    "pedagogerna": "pedagog",
    "pedagogernas": "pedagog",
    "pedagogers": "pedagog",
    "pedagogiken": "pedagogik",
    "pedagogikens": "pedagogik",
    "pedagogiks": "pedagogik",
    "pedagogiska": "pedagogisk",
    "pedagogiskare": "pedagogisk",
    "pedagogiskares": "pedagogisk",
    "pedagogiskas": "pedagogisk",
    "pedagogiskast": "pedagogisk",
    "pedagogiskaste": "pedagogisk",
    "pedagogiskastes": "pedagogisk",
    "pedagogiskasts": "pedagogisk",
    "pedagogiske": "pedagogisk",
    "pedagogiskes": "pedagogisk",
    "pedagogisks": "pedagogisk",
    "pedagogiskt": "pedagogisk",
    "pedagogiskts": "pedagogisk",
    "pedagogs": "pedagog",
    "pedalen": "pedal",
    "pedalens": "pedal",
    "pedaler": "pedal",
    "pedalerna": "pedal",
    "pedalernas": "pedal",
    "pedalers": "pedal",
    "pedalmanövrerade": "pedalmanövrerad",
    "pedalmanövrerades": "pedalmanövrerad",
    "pedalmanövrerads": "pedalmanövrerad",
    "pedalmanövrerat": "pedalmanövrerad",
    "pedalmanövrerats": "pedalmanövrerad",
    "pedals": "pedal",
    "pedanten": "pedant",
    "pedantens": "pedant",
    "pedanter": "pedant",
    "pedanterier": "pedanteri",
    "pedanterierna": "pedanteri",
    "pedanteriernas": "pedanteri",
    "pedanteriers": "pedanteri",
    "pedanteriet": "pedanteri",
    "pedanteriets": "pedanteri",
    "pedanteris": "pedanteri",
    "pedanterit": "pedanteri",
    "pedanterits": "pedanteri",
    "pedanterna": "pedant",
    "pedanternas": "pedant",
    "pedanters": "pedant",
    "pedantiska": "pedantisk",
    "pedantiskare": "pedantisk",
    "pedantiskares": "pedantisk",
    "pedantiskas": "pedantisk",
    "pedantiskast": "pedantisk",
    "pedantiskaste": "pedantisk",
    "pedantiskastes": "pedantisk",
    "pedantiskasts": "pedantisk",
    "pedantiske": "pedantisk",
    "pedantiskes": "pedantisk",
    "pedantisks": "pedantisk",
    "pedantiskt": "pedantisk",
    "pedantiskts": "pedantisk",
    "pedants": "pedant",
    "peddon": "peddo",
    "peddona": "peddo",
    "peddonas": "peddo",
    "peddons": "peddo",
    "peddos": "peddo",
    "peddot": "peddo",
    "peddots": "peddo",
    "pedellen": "pedell",
    "pedellens": "pedell",
    "pedeller": "pedell",
    "pedellerna": "pedell",
    "pedellernas": "pedell",
    "pedellers": "pedell",
    "pedells": "pedell",
    "pederasten": "pederast",
    "pederastens": "pederast",
    "pederaster": "pederast",
    "pederasterna": "pederast",
    "pederasternas": "pederast",
    "pederasters": "pederast",
    "pederastien": "pederasti",
    "pederastiens": "pederasti",
    "pederastin": "pederasti",
    "pederastins": "pederasti",
    "pederastis": "pederasti",
    "pederasts": "pederast",
    "pediatriken": "pediatrik",
    "pediatrikens": "pediatrik",
    "pediatrikern": "pediatriker",
    "pediatrikerna": "pediatriker",
    "pediatrikernas": "pediatriker",
    "pediatrikerns": "pediatriker",
    "pediatrikers": "pediatriker",
    "pediatriks": "pediatrik",
    "pediatriska": "pediatrisk",
    "pediatriskare": "pediatrisk",
    "pediatriskares": "pediatrisk",
    "pediatriskas": "pediatrisk",
    "pediatriskast": "pediatrisk",
    "pediatriskaste": "pediatrisk",
    "pediatriskastes": "pediatrisk",
    "pediatriskasts": "pediatrisk",
    "pediatriske": "pediatrisk",
    "pediatriskes": "pediatrisk",
    "pediatrisks": "pediatrisk",
    "pediatriskt": "pediatrisk",
    "pediatriskts": "pediatrisk",
    "pedikuren": "pedikur",
    "pedikurens": "pedikur",
    "pedikuristen": "pedikurist",
    "pedikuristens": "pedikurist",
    "pedikurister": "pedikurist",
    "pedikuristerna": "pedikurist",
    "pedikuristernas": "pedikurist",
    "pedikuristers": "pedikurist",
    "pedikurists": "pedikurist",
    "pedikurs": "pedikur",
    "pedikyren": "pedikyr",
    "pedikyrens": "pedikyr",
    "pedikyristen": "pedikyrist",
    "pedikyristens": "pedikyrist",
    "pedikyrister": "pedikyrist",
    "pedikyristerna": "pedikyrist",
    "pedikyristernas": "pedikyrist",
    "pedikyristers": "pedikyrist",
    "pedikyrists": "pedikyrist",
    "pedikyrs": "pedikyr",
    "pedimenten": "pediment",
    "pedimentens": "pediment",
    "pedimentet": "pediment",
    "pedimentets": "pediment",
    "pediments": "pediment",
    "pedofila": "pedofil",
    "pedofilas": "pedofil",
    "pedofile": "pedofil",
    "pedofilen": "pedofil",
    "pedofilens": "pedofil",
    "pedofiler": "pedofil",
    "pedofilerna": "pedofil",
    "pedofilernas": "pedofil",
    "pedofilers": "pedofil",
    "pedofiles": "pedofil",
    "pedofilhysterier": "pedofilhysteri",
    "pedofilhysterierna": "pedofilhysteri",
    "pedofilhysteriernas": "pedofilhysteri",
    "pedofilhysteriers": "pedofilhysteri",
    "pedofilhysteriet": "pedofilhysteri",
    "pedofilhysteriets": "pedofilhysteri",
    "pedofilhysteris": "pedofilhysteri",
    "pedofilhysterit": "pedofilhysteri",
    "pedofilhysterits": "pedofilhysteri",
    "pedofilien": "pedofili",
    "pedofiliens": "pedofili",
    "pedofilin": "pedofili",
    "pedofilins": "pedofili",
    "pedofilis": "pedofili",
    "pedofils": "pedofil",
    "pedofilskräcken": "pedofilskräck",
    "pedofilskräckens": "pedofilskräck",
    "pedofilskräcks": "pedofilskräck",
    "pedofilt": "pedofil",
    "pedofilts": "pedofil",
    "pedologien": "pedologi",
    "pedologiens": "pedologi",
    "pedologin": "pedologi",
    "pedologins": "pedologi",
    "pedologis": "pedologi",
    "peelingen": "peeling",
    "peelingens": "peeling",
    "peelingkrämen": "peelingkräm",
    "peelingkrämens": "peelingkräm",
    "peelingkrämer": "peelingkräm",
    "peelingkrämerna": "peelingkräm",
    "peelingkrämernas": "peelingkräm",
    "peelingkrämers": "peelingkräm",
    "peelingkräms": "peelingkräm",
    "peelings": "peeling",
    "pegamoiden": "pegamoid",
    "pegamoidens": "pegamoid",
    "pegamoids": "pegamoid",
    "pegasen": "pegas",
    "pegasens": "pegas",
    "pegaser": "pegas",
    "pegaserna": "pegas",
    "pegasernas": "pegas",
    "pegasers": "pegas",
    "pegeln": "pegel",
    "pegelns": "pegel",
    "pegels": "pegel",
    "peglar": "pegel",
    "peglarna": "pegel",
    "peglarnas": "pegel",
    "peglars": "pegel",
    "pegmatiten": "pegmatit",
    "pegmatitens": "pegmatit",
    "pegmatiter": "pegmatit",
    "pegmatiterna": "pegmatit",
    "pegmatiternas": "pegmatit",
    "pegmatiters": "pegmatit",
    "pegmatits": "pegmatit",
    "pejlad": "pejla",
    "pejlade": "pejla",
    "pejlades": "pejla",
    "pejlads": "pejla",
    "pejlande": "pejla",
    "pejlanden": "pejlande",
    "pejlandena": "pejlande",
    "pejlandenas": "pejlande",
    "pejlandens": "pejlande",
    "pejlandes": "pejlande",
    "pejlandet": "pejlande",
    "pejlandets": "pejlande",
    "pejlar": "pejla",
    "pejlas": "pejla",
    "pejlat": "pejla",
    "pejlats": "pejla",
    "pejlingar": "pejling",
    "pejlingarna": "pejling",
    "pejlingarnas": "pejling",
    "pejlingars": "pejling",
    "pejlingen": "pejling",
    "pejlingens": "pejling",
    "pejlings": "pejling",
    "pejlskivan": "pejlskiva",
    "pejlskivans": "pejlskiva",
    "pejlskivas": "pejlskiva",
    "pejlskive": "pejlskiva",
    "pejlskivor": "pejlskiva",
    "pejlskivorna": "pejlskiva",
    "pejlskivornas": "pejlskiva",
    "pejlskivors": "pejlskiva",
    "pejorativa": "pejorativ",
    "pejorativare": "pejorativ",
    "pejorativares": "pejorativ",
    "pejorativas": "pejorativ",
    "pejorativast": "pejorativ",
    "pejorativaste": "pejorativ",
    "pejorativastes": "pejorativ",
    "pejorativasts": "pejorativ",
    "pejorative": "pejorativ",
    "pejorativen": "pejorativ",
    "pejorativens": "pejorativ",
    "pejorativer": "pejorativ",
    "pejorativerna": "pejorativ",
    "pejorativernas": "pejorativ",
    "pejorativers": "pejorativ",
    "pejoratives": "pejorativ",
    "pejorativet": "pejorativ",
    "pejorativets": "pejorativ",
    "pejorativs": "pejorativ",
    "pejorativt": "pejorativ",
    "pejorativts": "pejorativ",
    "pek": "peka",
    "pekade": "peka",
    "pekades": "peka",
    "pekande": "peka",
    "pekanden": "pekande",
    "pekandena": "pekande",
    "pekandenas": "pekande",
    "pekandens": "pekande",
    "pekandes": "pekande",
    "pekandet": "pekande",
    "pekandets": "pekande",
    "pekannöten": "pekannöt",
    "pekannötens": "pekannöt",
    "pekannöts": "pekannöt",
    "pekannötter": "pekannöt",
    "pekannötterna": "pekannöt",
    "pekannötternas": "pekannöt",
    "pekannötters": "pekannöt",
    "pekar": "pekare",
    "pekaren": "pekare",
    "pekarens": "pekare",
    "pekares": "pekare",
    "pekarna": "pekare",
    "pekarnas": "pekare",
    "pekas": "peka",
    "pekat": "peka",
    "pekats": "peka",
    "pekboken": "pekbok",
    "pekbokens": "pekbok",
    "pekboks": "pekbok",
    "pekböcker": "pekbok",
    "pekböckerna": "pekbok",
    "pekböckernas": "pekbok",
    "pekböckers": "pekbok",
    "pekfingern": "pekfinger",
    "pekfingernageln": "pekfingernagel",
    "pekfingernagelns": "pekfingernagel",
    "pekfingernagels": "pekfingernagel",
    "pekfingernaglar": "pekfingernagel",
    "pekfingernaglarna": "pekfingernagel",
    "pekfingernaglarnas": "pekfingernagel",
    "pekfingernaglars": "pekfingernagel",
    "pekfingerns": "pekfinger",
    "pekfingers": "pekfinger",
    "pekfingertesten": "pekfingertest",
    "pekfingertestens": "pekfingertest",
    "pekfingertester": "pekfingertest",
    "pekfingertesterna": "pekfingertest",
    "pekfingertesternas": "pekfingertest",
    "pekfingertesters": "pekfingertest",
    "pekfingertestet": "pekfingertest",
    "pekfingertestets": "pekfingertest",
    "pekfingertests": "pekfingertest",
    "pekfingervalsen": "pekfingervals",
    "pekfingervalsens": "pekfingervals",
    "pekfingrar": "pekfinger",
    "pekfingrarna": "pekfinger",
    "pekfingrarnas": "pekfinger",
    "pekfingrars": "pekfinger",
    "pekfingret": "pekfinger",
    "pekfingrets": "pekfinger",
    "pekinesen": "pekines",
    "pekinesens": "pekines",
    "pekineser": "pekines",
    "pekineserna": "pekines",
    "pekinesernas": "pekines",
    "pekinesers": "pekines",
    "pekingesen": "pekinges",
    "pekingesens": "pekinges",
    "pekingeser": "pekinges",
    "pekingeserna": "pekinges",
    "pekingesernas": "pekinges",
    "pekingesers": "pekinges",
    "pekoralen": "pekoral",
    "pekoralens": "pekoral",
    "pekoralet": "pekoral",
    "pekoralets": "pekoral",
    "pekoralisten": "pekoralist",
    "pekoralistens": "pekoralist",
    "pekoralister": "pekoralist",
    "pekoralisterna": "pekoralist",
    "pekoralisternas": "pekoralist",
    "pekoralisters": "pekoralist",
    "pekoralistiska": "pekoralistisk",
    "pekoralistiskare": "pekoralistisk",
    "pekoralistiskares": "pekoralistisk",
    "pekoralistiskas": "pekoralistisk",
    "pekoralistiskast": "pekoralistisk",
    "pekoralistiskaste": "pekoralistisk",
    "pekoralistiskastes": "pekoralistisk",
    "pekoralistiskasts": "pekoralistisk",
    "pekoralistiske": "pekoralistisk",
    "pekoralistiskes": "pekoralistisk",
    "pekoralistisks": "pekoralistisk",
    "pekoralistiskt": "pekoralistisk",
    "pekoralistiskts": "pekoralistisk",
    "pekoralists": "pekoralist",
    "pekorals": "pekoral",
    "pekpinn": "pekpinne",
    "pekpinnar": "pekpinne",
    "pekpinnarna": "pekpinne",
    "pekpinnarnas": "pekpinne",
    "pekpinnars": "pekpinne",
    "pekpinnen": "pekpinne",
    "pekpinnens": "pekpinne",
    "pekpinnes": "pekpinne",
    "pekpinns": "pekpinne",
    "pektinen": "pektin",
    "pektinens": "pektin",
    "pektiner": "pektin",
    "pektinerna": "pektin",
    "pektinernas": "pektin",
    "pektiners": "pektin",
    "pektinet": "pektin",
    "pektinets": "pektin",
    "pektins": "pektin",
    "pektån": "pektå",
    "pektåns": "pektå",
    "pektår": "pektå",
    "pektårna": "pektå",
    "pektårnas": "pektå",
    "pektårs": "pektå",
    "pektås": "pektå",
    "pekuniära": "pekuniär",
    "pekuniärare": "pekuniär",
    "pekuniärares": "pekuniär",
    "pekuniäras": "pekuniär",
    "pekuniärast": "pekuniär",
    "pekuniäraste": "pekuniär",
    "pekuniärastes": "pekuniär",
    "pekuniärasts": "pekuniär",
    "pekuniäre": "pekuniär",
    "pekuniäres": "pekuniär",
    "pekuniärs": "pekuniär",
    "pekuniärt": "pekuniär",
    "pekuniärts": "pekuniär",
    "pelagiska": "pelagisk",
    "pelagiskare": "pelagisk",
    "pelagiskares": "pelagisk",
    "pelagiskas": "pelagisk",
    "pelagiskast": "pelagisk",
    "pelagiskaste": "pelagisk",
    "pelagiskastes": "pelagisk",
    "pelagiskasts": "pelagisk",
    "pelagiske": "pelagisk",
    "pelagiskes": "pelagisk",
    "pelagisks": "pelagisk",
    "pelagiskt": "pelagisk",
    "pelagiskts": "pelagisk",
    "pelar": "pelarer",
    "pelarborden": "pelarbord",
    "pelarbordens": "pelarbord",
    "pelarbordet": "pelarbord",
    "pelarbordets": "pelarbord",
    "pelarbords": "pelarbord",
    "pelarborrmaskinen": "pelarborrmaskin",
    "pelarborrmaskinens": "pelarborrmaskin",
    "pelarborrmaskiner": "pelarborrmaskin",
    "pelarborrmaskinerna": "pelarborrmaskin",
    "pelarborrmaskinernas": "pelarborrmaskin",
    "pelarborrmaskiners": "pelarborrmaskin",
    "pelarborrmaskins": "pelarborrmaskin",
    "pelardomkraften": "pelardomkraft",
    "pelardomkraftens": "pelardomkraft",
    "pelardomkrafter": "pelardomkraft",
    "pelardomkrafterna": "pelardomkraft",
    "pelardomkrafternas": "pelardomkraft",
    "pelardomkrafters": "pelardomkraft",
    "pelardomkrafts": "pelardomkraft",
    "pelaren": "pelare",
    "pelarens": "pelare",
    "pelarerna": "pelarer",
    "pelarernas": "pelarer",
    "pelarers": "pelarer",
    "pelares": "pelare",
    "pelarformiga": "pelarformig",
    "pelarformigare": "pelarformig",
    "pelarformigares": "pelarformig",
    "pelarformigas": "pelarformig",
    "pelarformigast": "pelarformig",
    "pelarformigaste": "pelarformig",
    "pelarformigastes": "pelarformig",
    "pelarformigasts": "pelarformig",
    "pelarformige": "pelarformig",
    "pelarformiges": "pelarformig",
    "pelarformigs": "pelarformig",
    "pelarformigt": "pelarformig",
    "pelarformigts": "pelarformig",
    "pelargonen": "pelargon",
    "pelargonens": "pelargon",
    "pelargoner": "pelargon",
    "pelargonerna": "pelargon",
    "pelargonernas": "pelargon",
    "pelargoners": "pelargon",
    "pelargonian": "pelargonia",
    "pelargonians": "pelargonia",
    "pelargonias": "pelargonia",
    "pelargonier": "pelargonia",
    "pelargonierna": "pelargonia",
    "pelargoniernas": "pelargonia",
    "pelargoniers": "pelargonia",
    "pelargonior": "pelargonia",
    "pelargoniorna": "pelargonia",
    "pelargoniornas": "pelargonia",
    "pelargoniors": "pelargonia",
    "pelargons": "pelargon",
    "pelargångar": "pelargång",
    "pelargångarna": "pelargång",
    "pelargångarnas": "pelargång",
    "pelargångars": "pelargång",
    "pelargången": "pelargång",
    "pelargångens": "pelargång",
    "pelargångs": "pelargång",
    "pelarhallar": "pelarhall",
    "pelarhallarna": "pelarhall",
    "pelarhallarnas": "pelarhall",
    "pelarhallars": "pelarhall",
    "pelarhallen": "pelarhall",
    "pelarhallens": "pelarhall",
    "pelarhalls": "pelarhall",
    "pelarhelgonen": "pelarhelgon",
    "pelarhelgonens": "pelarhelgon",
    "pelarhelgonet": "pelarhelgon",
    "pelarhelgonets": "pelarhelgon",
    "pelarhelgons": "pelarhelgon",
    "pelarna": "pelare",
    "pelarnas": "pelare",
    "pelars": "pelarer",
    "pelarsalar": "pelarsal",
    "pelarsalarna": "pelarsal",
    "pelarsalarnas": "pelarsal",
    "pelarsalars": "pelarsal",
    "pelarsalen": "pelarsal",
    "pelarsalens": "pelarsal",
    "pelarsals": "pelarsal",
    "pelerinen": "pelerin",
    "pelerinens": "pelerin",
    "peleriner": "pelerin",
    "pelerinerna": "pelerin",
    "pelerinernas": "pelerin",
    "peleriners": "pelerin",
    "pelerins": "pelerin",
    "pelikanen": "pelikan",
    "pelikanens": "pelikan",
    "pelikaner": "pelikan",
    "pelikanerna": "pelikan",
    "pelikanernas": "pelikan",
    "pelikaners": "pelikan",
    "pelikans": "pelikan",
    "pellagran": "pellagra",
    "pellagrans": "pellagra",
    "pellagras": "pellagra",
    "pellejönsar": "pellejöns",
    "pellejönsarna": "pellejöns",
    "pellejönsarnas": "pellejöns",
    "pellejönsars": "pellejöns",
    "pellejönsen": "pellejöns",
    "pellejönsens": "pellejöns",
    "pelletar": "pellet",
    "pelletarna": "pellet",
    "pelletarnas": "pellet",
    "pelletars": "pellet",
    "pelleten": "pellet",
    "pelletens": "pellet",
    "pelleterad": "pelletera",
    "pelleterade": "pelletera",
    "pelleterades": "pelletera",
    "pelleterads": "pelletera",
    "pelleterande": "pelletera",
    "pelleteranden": "pelleterande",
    "pelleterandena": "pelleterande",
    "pelleterandenas": "pelleterande",
    "pelleterandens": "pelleterande",
    "pelleterandes": "pelleterande",
    "pelleterandet": "pelleterande",
    "pelleterandets": "pelleterande",
    "pelleterar": "pelletera",
    "pelleteras": "pelletera",
    "pelleterat": "pelletera",
    "pelleterats": "pelletera",
    "pelleterbara": "pelleterbar",
    "pelleterbarare": "pelleterbar",
    "pelleterbarares": "pelleterbar",
    "pelleterbaras": "pelleterbar",
    "pelleterbarast": "pelleterbar",
    "pelleterbaraste": "pelleterbar",
    "pelleterbarastes": "pelleterbar",
    "pelleterbarasts": "pelleterbar",
    "pelleterbare": "pelleterbar",
    "pelleterbares": "pelleterbar",
    "pelleterbarheten": "pelleterbarhet",
    "pelleterbarhetens": "pelleterbarhet",
    "pelleterbarhets": "pelleterbarhet",
    "pelleterbars": "pelleterbar",
    "pelleterbart": "pelleterbar",
    "pelleterbarts": "pelleterbar",
    "pelleteringar": "pelletering",
    "pelleteringarna": "pelletering",
    "pelleteringarnas": "pelletering",
    "pelleteringars": "pelletering",
    "pelleteringen": "pelletering",
    "pelleteringens": "pelletering",
    "pelleterings": "pelletering",
    "pellets": "pellet",
    "pelletsarna": "pellet",
    "pelletsarnas": "pellet",
    "pelletsen": "pellet",
    "pelletsens": "pellet",
    "pelotas": "pelota",
    "pemmikanen": "pemmikan",
    "pemmikanens": "pemmikan",
    "pemmikans": "pemmikan",
    "penar": "pen",
    "penarna": "pen",
    "penarnas": "pen",
    "penars": "pen",
    "penat": "penater",
    "penaterna": "penater",
    "penaternas": "penater",
    "penaters": "penater",
    "penats": "penater",
    "pence": "penny",
    "pencen": "penny",
    "pencens": "penny",
    "pences": "penny",
    "pendangen": "pendang",
    "pendangens": "pendang",
    "pendanger": "pendang",
    "pendangerna": "pendang",
    "pendangernas": "pendang",
    "pendangers": "pendang",
    "pendangs": "pendang",
    "pendel": "pendla",
    "pendelavstånden": "pendelavstånd",
    "pendelavståndens": "pendelavstånd",
    "pendelavståndet": "pendelavstånd",
    "pendelavståndets": "pendelavstånd",
    "pendelavstånds": "pendelavstånd",
    "pendeln": "pendel",
    "pendelns": "pendel",
    "pendels": "pendel",
    "pendeltidtabellen": "pendeltidtabell",
    "pendeltidtabellens": "pendeltidtabell",
    "pendeltidtabeller": "pendeltidtabell",
    "pendeltidtabellerna": "pendeltidtabell",
    "pendeltidtabellernas": "pendeltidtabell",
    "pendeltidtabellers": "pendeltidtabell",
    "pendeltidtabells": "pendeltidtabell",
    "pendeltrafiken": "pendeltrafik",
    "pendeltrafikens": "pendeltrafik",
    "pendeltrafiks": "pendeltrafik",
    "pendeltågen": "pendeltåg",
    "pendeltågens": "pendeltåg",
    "pendeltåget": "pendeltåg",
    "pendeltågets": "pendeltåg",
    "pendeltågs": "pendeltåg",
    "pendeltågsankomsten": "pendeltågsankomst",
    "pendeltågsankomstens": "pendeltågsankomst",
    "pendeltågsankomster": "pendeltågsankomst",
    "pendeltågsankomsterna": "pendeltågsankomst",
    "pendeltågsankomsternas": "pendeltågsankomst",
    "pendeltågsankomsters": "pendeltågsankomst",
    "pendeltågsankomsts": "pendeltågsankomst",
    "pendeltågsavgångar": "pendeltågsavgång",
    "pendeltågsavgångarna": "pendeltågsavgång",
    "pendeltågsavgångarnas": "pendeltågsavgång",
    "pendeltågsavgångars": "pendeltågsavgång",
    "pendeltågsavgången": "pendeltågsavgång",
    "pendeltågsavgångens": "pendeltågsavgång",
    "pendeltågsavgångs": "pendeltågsavgång",
    "pendeltågstidtabellen": "pendeltågstidtabell",
    "pendeltågstidtabellens": "pendeltågstidtabell",
    "pendeltågstidtabeller": "pendeltågstidtabell",
    "pendeltågstidtabellerna": "pendeltågstidtabell",
    "pendeltågstidtabellernas": "pendeltågstidtabell",
    "pendeltågstidtabellers": "pendeltågstidtabell",
    "pendeltågstidtabells": "pendeltågstidtabell",
    "pendeltågstrafiken": "pendeltågstrafik",
    "pendeltågstrafikens": "pendeltågstrafik",
    "pendeltågstrafiks": "pendeltågstrafik",
    "pendeluren": "pendelur",
    "pendelurens": "pendelur",
    "pendeluret": "pendelur",
    "pendelurets": "pendelur",
    "pendelurs": "pendelur",
    "pendlade": "pendla",
    "pendlades": "pendla",
    "pendlande": "pendla",
    "pendlanden": "pendlande",
    "pendlandena": "pendlande",
    "pendlandenas": "pendlande",
    "pendlandens": "pendlande",
    "pendlandes": "pendlande",
    "pendlandet": "pendlande",
    "pendlandets": "pendlande",
    "pendlar": "pendlare",
    "pendlaren": "pendlare",
    "pendlarens": "pendlare",
    "pendlares": "pendlare",
    "pendlarna": "pendlare",
    "pendlarnas": "pendlare",
    "pendlars": "pendel",
    "pendlas": "pendla",
    "pendlat": "pendla",
    "pendlats": "pendla",
    "pendylen": "pendyl",
    "pendylens": "pendyl",
    "pendyler": "pendyl",
    "pendylerna": "pendyl",
    "pendylernas": "pendyl",
    "pendylers": "pendyl",
    "pendyls": "pendyl",
    "penen": "pen",
    "penens": "pen",
    "peneplanet": "peneplan",
    "peneplanets": "peneplan",
    "peneplans": "peneplan",
    "penetrationen": "penetration",
    "penetrationens": "penetration",
    "penetrationer": "penetration",
    "penetrationerna": "penetration",
    "penetrationernas": "penetration",
    "penetrationers": "penetration",
    "penetrations": "penetration",
    "penetrerad": "penetrera",
    "penetrerade": "penetrera",
    "penetrerades": "penetrera",
    "penetrerads": "penetrera",
    "penetrerande": "penetrera",
    "penetreranden": "penetrerande",
    "penetrerandena": "penetrerande",
    "penetrerandenas": "penetrerande",
    "penetrerandens": "penetrerande",
    "penetrerandes": "penetrerande",
    "penetrerandet": "penetrerande",
    "penetrerandets": "penetrerande",
    "penetrerar": "penetrera",
    "penetreras": "penetrera",
    "penetrerat": "penetrera",
    "penetrerats": "penetrera",
    "penetrerbara": "penetrerbar",
    "penetrerbarare": "penetrerbar",
    "penetrerbarares": "penetrerbar",
    "penetrerbaras": "penetrerbar",
    "penetrerbarast": "penetrerbar",
    "penetrerbaraste": "penetrerbar",
    "penetrerbarastes": "penetrerbar",
    "penetrerbarasts": "penetrerbar",
    "penetrerbare": "penetrerbar",
    "penetrerbares": "penetrerbar",
    "penetrerbarheten": "penetrerbarhet",
    "penetrerbarhetens": "penetrerbarhet",
    "penetrerbarhets": "penetrerbarhet",
    "penetrerbars": "penetrerbar",
    "penetrerbart": "penetrerbar",
    "penetrerbarts": "penetrerbar",
    "penetreringar": "penetrering",
    "penetreringarna": "penetrering",
    "penetreringarnas": "penetrering",
    "penetreringars": "penetrering",
    "penetreringen": "penetrering",
    "penetreringens": "penetrering",
    "penetrerings": "penetrering",
    "penga": "pengar",
    "pengamässiga": "pengamässig",
    "pengamässigare": "pengamässig",
    "pengamässigares": "pengamässig",
    "pengamässigas": "pengamässig",
    "pengamässigast": "pengamässig",
    "pengamässigaste": "pengamässig",
    "pengamässigastes": "pengamässig",
    "pengamässigasts": "pengamässig",
    "pengamässige": "pengamässig",
    "pengamässiges": "pengamässig",
    "pengamässigs": "pengamässig",
    "pengamässigt": "pengamässig",
    "pengamässigts": "pengamässig",
    "pengar": "peng",
    "pengarna": "pengar",
    "pengarnas": "pengar",
    "pengars": "pengar",
    "pengastinna": "pengastinn",
    "pengastinnare": "pengastinn",
    "pengastinnares": "pengastinn",
    "pengastinnas": "pengastinn",
    "pengastinnast": "pengastinn",
    "pengastinnaste": "pengastinn",
    "pengastinnastes": "pengastinn",
    "pengastinnasts": "pengastinn",
    "pengastinne": "pengastinn",
    "pengastinnes": "pengastinn",
    "pengastinnheten": "pengastinnhet",
    "pengastinnhetens": "pengastinnhet",
    "pengastinnhets": "pengastinnhet",
    "pengastinns": "pengastinn",
    "pengastint": "pengastinn",
    "pengastints": "pengastinn",
    "pengen": "peng",
    "pengens": "peng",
    "pengs": "peng",
    "penibels": "penibel",
    "penibelt": "penibel",
    "penibelts": "penibel",
    "penibla": "penibel",
    "peniblare": "penibel",
    "peniblares": "penibel",
    "peniblas": "penibel",
    "peniblast": "penibel",
    "peniblaste": "penibel",
    "peniblastes": "penibel",
    "peniblasts": "penibel",
    "penible": "penibel",
    "penibles": "penibel",
    "penicillinen": "penicillin",
    "penicillinens": "penicillin",
    "penicilliner": "penicillin",
    "penicillinerna": "penicillin",
    "penicillinernas": "penicillin",
    "penicilliners": "penicillin",
    "penicillinet": "penicillin",
    "penicillinets": "penicillin",
    "penicillins": "penicillin",
    "penisar": "penis",
    "penisarna": "penis",
    "penisarnas": "penis",
    "penisars": "penis",
    "penisattrappen": "penisattrapp",
    "penisattrappens": "penisattrapp",
    "penisattrapper": "penisattrapp",
    "penisattrapperna": "penisattrapp",
    "penisattrappernas": "penisattrapp",
    "penisattrappers": "penisattrapp",
    "penisattrapps": "penisattrapp",
    "penisavunden": "penisavund",
    "penisavundens": "penisavund",
    "penisavunds": "penisavund",
    "penisen": "penis",
    "penisens": "penis",
    "penisringar": "penisring",
    "penisringarna": "penisring",
    "penisringarnas": "penisring",
    "penisringars": "penisring",
    "penisringen": "penisring",
    "penisringens": "penisring",
    "penisrings": "penisring",
    "penitensen": "penitens",
    "penitensens": "penitens",
    "penjoaren": "penjoar",
    "penjoarens": "penjoar",
    "penjoarer": "penjoar",
    "penjoarerna": "penjoar",
    "penjoarernas": "penjoar",
    "penjoarers": "penjoar",
    "penjoars": "penjoar",
    "penn": "penna",
    "pennalismen": "pennalism",
    "pennalismens": "pennalism",
    "pennalismer": "pennalism",
    "pennalismerna": "pennalism",
    "pennalismernas": "pennalism",
    "pennalismers": "pennalism",
    "pennalisms": "pennalism",
    "pennalisten": "pennalist",
    "pennalistens": "pennalist",
    "pennalister": "pennalist",
    "pennalisterna": "pennalist",
    "pennalisternas": "pennalist",
    "pennalisters": "pennalist",
    "pennalistiska": "pennalistisk",
    "pennalistiskas": "pennalistisk",
    "pennalistiske": "pennalistisk",
    "pennalistiskes": "pennalistisk",
    "pennalistisks": "pennalistisk",
    "pennalistiskt": "pennalistisk",
    "pennalistiskts": "pennalistisk",
    "pennalists": "pennalist",
    "pennan": "penna",
    "pennans": "penna",
    "pennas": "penna",
    "penndragen": "penndrag",
    "penndragens": "penndrag",
    "penndraget": "penndrag",
    "penndragets": "penndrag",
    "penndrags": "penndrag",
    "penne": "penna",
    "pennformerar": "pennformerare",
    "pennformeraren": "pennformerare",
    "pennformerarens": "pennformerare",
    "pennformerares": "pennformerare",
    "pennformerarna": "pennformerare",
    "pennformerarnas": "pennformerare",
    "pennfäktar": "pennfäktare",
    "pennfäktaren": "pennfäktare",
    "pennfäktarens": "pennfäktare",
    "pennfäktares": "pennfäktare",
    "pennfäktarna": "pennfäktare",
    "pennfäktarnas": "pennfäktare",
    "pennies": "penny",
    "penniesarna": "penny",
    "penniesarnas": "penny",
    "pennin": "penni",
    "pennina": "penni",
    "penninas": "penni",
    "penning": "penningar",
    "penningar": "penning",
    "penningarna": "penningar",
    "penningarnas": "penningar",
    "penningars": "penningar",
    "penningdyrkans": "penningdyrkan",
    "penningen": "penning",
    "penningens": "penning",
    "penningflöden": "penningflöde",
    "penningflödena": "penningflöde",
    "penningflödenas": "penningflöde",
    "penningflödens": "penningflöde",
    "penningflödes": "penningflöde",
    "penningflödet": "penningflöde",
    "penningflödets": "penningflöde",
    "penningförsändelsen": "penningförsändelse",
    "penningförsändelsens": "penningförsändelse",
    "penningförsändelser": "penningförsändelse",
    "penningförsändelserna": "penningförsändelse",
    "penningförsändelsernas": "penningförsändelse",
    "penningförsändelsers": "penningförsändelse",
    "penningförsändelses": "penningförsändelse",
    "penninggräset": "penninggräs",
    "penninggräsets": "penninggräs",
    "penninghushållningar": "penninghushållning",
    "penninghushållningarna": "penninghushållning",
    "penninghushållningarnas": "penninghushållning",
    "penninghushållningars": "penninghushållning",
    "penninghushållningen": "penninghushållning",
    "penninghushållningens": "penninghushållning",
    "penninghushållnings": "penninghushållning",
    "penninghälerier": "penninghäleri",
    "penninghälerierna": "penninghäleri",
    "penninghäleriernas": "penninghäleri",
    "penninghäleriers": "penninghäleri",
    "penninghäleriet": "penninghäleri",
    "penninghäleriets": "penninghäleri",
    "penninghäleris": "penninghäleri",
    "penninghälerit": "penninghäleri",
    "penninghälerits": "penninghäleri",
    "penninginsamlingar": "penninginsamling",
    "penninginsamlingarna": "penninginsamling",
    "penninginsamlingarnas": "penninginsamling",
    "penninginsamlingars": "penninginsamling",
    "penninginsamlingen": "penninginsamling",
    "penninginsamlingens": "penninginsamling",
    "penninginsamlings": "penninginsamling",
    "penninglotten": "penninglott",
    "penninglottens": "penninglott",
    "penninglotter": "penninglott",
    "penninglotteriet": "penninglotteri",
    "penninglotteriets": "penninglotteri",
    "penninglotteris": "penninglotteri",
    "penninglotterit": "penninglotteri",
    "penninglotterits": "penninglotteri",
    "penninglotterna": "penninglott",
    "penninglotternas": "penninglott",
    "penninglotters": "penninglott",
    "penninglotts": "penninglott",
    "penninglånen": "penninglån",
    "penninglånens": "penninglån",
    "penninglånet": "penninglån",
    "penninglånets": "penninglån",
    "penninglåns": "penninglån",
    "penningmarknaden": "penningmarknad",
    "penningmarknadens": "penningmarknad",
    "penningmarknader": "penningmarknad",
    "penningmarknaderna": "penningmarknad",
    "penningmarknadernas": "penningmarknad",
    "penningmarknaders": "penningmarknad",
    "penningmarknads": "penningmarknad",
    "penningmässiga": "penningmässig",
    "penningmässigare": "penningmässig",
    "penningmässigares": "penningmässig",
    "penningmässigas": "penningmässig",
    "penningmässigast": "penningmässig",
    "penningmässigaste": "penningmässig",
    "penningmässigastes": "penningmässig",
    "penningmässigasts": "penningmässig",
    "penningmässige": "penningmässig",
    "penningmässiges": "penningmässig",
    "penningmässigs": "penningmässig",
    "penningmässigt": "penningmässig",
    "penningmässigts": "penningmässig",
    "penningpolitiken": "penningpolitik",
    "penningpolitikens": "penningpolitik",
    "penningpolitiks": "penningpolitik",
    "penningpolitiska": "penningpolitisk",
    "penningpolitiskas": "penningpolitisk",
    "penningpolitiske": "penningpolitisk",
    "penningpolitiskes": "penningpolitisk",
    "penningpolitisks": "penningpolitisk",
    "penningpolitiskt": "penningpolitisk",
    "penningpolitiskts": "penningpolitisk",
    "pennings": "penningar",
    "penningstinna": "penningstinn",
    "penningstinnare": "penningstinn",
    "penningstinnares": "penningstinn",
    "penningstinnas": "penningstinn",
    "penningstinnast": "penningstinn",
    "penningstinnaste": "penningstinn",
    "penningstinnastes": "penningstinn",
    "penningstinnasts": "penningstinn",
    "penningstinne": "penningstinn",
    "penningstinnes": "penningstinn",
    "penningstinnheten": "penningstinnhet",
    "penningstinnhetens": "penningstinnhet",
    "penningstinnhets": "penningstinnhet",
    "penningstinns": "penningstinn",
    "penningstint": "penningstinn",
    "penningstints": "penningstinn",
    "penningsumman": "penningsumma",
    "penningsummans": "penningsumma",
    "penningsummas": "penningsumma",
    "penningsumme": "penningsumma",
    "penningsummor": "penningsumma",
    "penningsummorna": "penningsumma",
    "penningsummornas": "penningsumma",
    "penningsummors": "penningsumma",
    "penningsystemen": "penningsystem",
    "penningsystemens": "penningsystem",
    "penningsystemet": "penningsystem",
    "penningsystemets": "penningsystem",
    "penningsystems": "penningsystem",
    "penningtilldelningar": "penningtilldelning",
    "penningtilldelningarna": "penningtilldelning",
    "penningtilldelningarnas": "penningtilldelning",
    "penningtilldelningars": "penningtilldelning",
    "penningtilldelningen": "penningtilldelning",
    "penningtilldelningens": "penningtilldelning",
    "penningtilldelnings": "penningtilldelning",
    "penningtransaktionen": "penningtransaktion",
    "penningtransaktionens": "penningtransaktion",
    "penningtransaktioner": "penningtransaktion",
    "penningtransaktionerna": "penningtransaktion",
    "penningtransaktionernas": "penningtransaktion",
    "penningtransaktioners": "penningtransaktion",
    "penningtransaktions": "penningtransaktion",
    "penningtvätten": "penningtvätt",
    "penningtvättens": "penningtvätt",
    "penningtvätts": "penningtvätt",
    "penningvärdes": "penningvärde",
    "penningvärdet": "penningvärde",
    "penningvärdets": "penningvärde",
    "penningväsendet": "penningväsen",
    "penningväsendets": "penningväsen",
    "penningväsenet": "penningväsen",
    "penningväsenets": "penningväsen",
    "penningväsens": "penningväsen",
    "penningörten": "penningört",
    "penningörtens": "penningört",
    "penningörts": "penningört",
    "pennins": "penni",
    "pennis": "penni",
    "pennknivar": "pennkniv",
    "pennknivarna": "pennkniv",
    "pennknivarnas": "pennkniv",
    "pennknivars": "pennkniv",
    "pennkniven": "pennkniv",
    "pennknivens": "pennkniv",
    "pennknivs": "pennkniv",
    "pennmodellen": "pennmodell",
    "pennmodellens": "pennmodell",
    "pennmodeller": "pennmodell",
    "pennmodellerna": "pennmodell",
    "pennmodellernas": "pennmodell",
    "pennmodellers": "pennmodell",
    "pennmodells": "pennmodell",
    "pennor": "penna",
    "pennorna": "penna",
    "pennornas": "penna",
    "pennors": "penna",
    "penns": "penna",
    "pennskaften": "pennskaft",
    "pennskaftens": "pennskaft",
    "pennskaftet": "pennskaft",
    "pennskaftets": "pennskaft",
    "pennskafts": "pennskaft",
    "pennstrecken": "pennstreck",
    "pennstreckens": "pennstreck",
    "pennstrecket": "pennstreck",
    "pennstreckets": "pennstreck",
    "pennstrecks": "pennstreck",
    "pennteckningar": "pennteckning",
    "pennteckningarna": "pennteckning",
    "pennteckningarnas": "pennteckning",
    "pennteckningars": "pennteckning",
    "pennteckningen": "pennteckning",
    "pennteckningens": "pennteckning",
    "penntecknings": "pennteckning",
    "pennvässar": "pennvässare",
    "pennvässaren": "pennvässare",
    "pennvässarens": "pennvässare",
    "pennvässares": "pennvässare",
    "pennvässarna": "pennvässare",
    "pennvässarnas": "pennvässare",
    "pennyn": "penny",
    "pennyns": "penny",
    "pennys": "penny",
    "pens": "pen",
    "pensa": "pensum",
    "pensana": "pensum",
    "pensanas": "pensum",
    "pensas": "pensum",
    "pensel": "pensla",
    "penseldragen": "penseldrag",
    "penseldragens": "penseldrag",
    "penseldraget": "penseldrag",
    "penseldragets": "penseldrag",
    "penseldrags": "penseldrag",
    "penselföringar": "penselföring",
    "penselföringarna": "penselföring",
    "penselföringarnas": "penselföring",
    "penselföringars": "penselföring",
    "penselföringen": "penselföring",
    "penselföringens": "penselföring",
    "penselförings": "penselföring",
    "penseln": "pensel",
    "penselns": "pensel",
    "pensels": "pensel",
    "pensionaten": "pensionat",
    "pensionatens": "pensionat",
    "pensionatet": "pensionat",
    "pensionatets": "pensionat",
    "pensionats": "pensionat",
    "pensionatsinnehavar": "pensionatsinnehavare",
    "pensionatsinnehavaren": "pensionatsinnehavare",
    "pensionatsinnehavarens": "pensionatsinnehavare",
    "pensionatsinnehavares": "pensionatsinnehavare",
    "pensionatsinnehavarna": "pensionatsinnehavare",
    "pensionatsinnehavarnas": "pensionatsinnehavare",
    "pensionen": "pension",
    "pensionens": "pension",
    "pensioner": "pension",
    "pensionerad": "pensionera",
    "pensionerade": "pensionera",
    "pensionerades": "pensionera",
    "pensionerads": "pensionera",
    "pensionerande": "pensionera",
    "pensioneranden": "pensionerande",
    "pensionerandena": "pensionerande",
    "pensionerandenas": "pensionerande",
    "pensionerandens": "pensionerande",
    "pensionerandes": "pensionerande",
    "pensionerandet": "pensionerande",
    "pensionerandets": "pensionerande",
    "pensionerar": "pensionera",
    "pensioneras": "pensionera",
    "pensionerat": "pensionera",
    "pensionerats": "pensionera",
    "pensionerbara": "pensionerbar",
    "pensionerbarare": "pensionerbar",
    "pensionerbarares": "pensionerbar",
    "pensionerbaras": "pensionerbar",
    "pensionerbarast": "pensionerbar",
    "pensionerbaraste": "pensionerbar",
    "pensionerbarastes": "pensionerbar",
    "pensionerbarasts": "pensionerbar",
    "pensionerbare": "pensionerbar",
    "pensionerbares": "pensionerbar",
    "pensionerbarheten": "pensionerbarhet",
    "pensionerbarhetens": "pensionerbarhet",
    "pensionerbarhets": "pensionerbarhet",
    "pensionerbars": "pensionerbar",
    "pensionerbart": "pensionerbar",
    "pensionerbarts": "pensionerbar",
    "pensioneringar": "pensionering",
    "pensioneringarna": "pensionering",
    "pensioneringarnas": "pensionering",
    "pensioneringars": "pensionering",
    "pensioneringen": "pensionering",
    "pensioneringens": "pensionering",
    "pensionerings": "pensionering",
    "pensionerna": "pension",
    "pensionernas": "pension",
    "pensioners": "pension",
    "pensions": "pension",
    "pensionsbreven": "pensionsbrev",
    "pensionsbrevens": "pensionsbrev",
    "pensionsbrevet": "pensionsbrev",
    "pensionsbrevets": "pensionsbrev",
    "pensionsbrevs": "pensionsbrev",
    "pensionsförsäkringar": "pensionsförsäkring",
    "pensionsförsäkringarna": "pensionsförsäkring",
    "pensionsförsäkringarnas": "pensionsförsäkring",
    "pensionsförsäkringars": "pensionsförsäkring",
    "pensionsförsäkringen": "pensionsförsäkring",
    "pensionsförsäkringens": "pensionsförsäkring",
    "pensionsförsäkrings": "pensionsförsäkring",
    "pensionsmässiga": "pensionsmässig",
    "pensionsmässigare": "pensionsmässig",
    "pensionsmässigares": "pensionsmässig",
    "pensionsmässigas": "pensionsmässig",
    "pensionsmässigast": "pensionsmässig",
    "pensionsmässigaste": "pensionsmässig",
    "pensionsmässigastes": "pensionsmässig",
    "pensionsmässigasts": "pensionsmässig",
    "pensionsmässige": "pensionsmässig",
    "pensionsmässiges": "pensionsmässig",
    "pensionsmässigs": "pensionsmässig",
    "pensionsmässigt": "pensionsmässig",
    "pensionsmässigts": "pensionsmässig",
    "pensionspoängen": "pensionspoäng",
    "pensionspoängens": "pensionspoäng",
    "pensionspoängs": "pensionspoäng",
    "pensionsrådgivar": "pensionsrådgivare",
    "pensionsrådgivaren": "pensionsrådgivare",
    "pensionsrådgivarens": "pensionsrådgivare",
    "pensionsrådgivares": "pensionsrådgivare",
    "pensionsrådgivarna": "pensionsrådgivare",
    "pensionsrådgivarnas": "pensionsrådgivare",
    "pensionssparanden": "pensionssparande",
    "pensionssparandena": "pensionssparande",
    "pensionssparandenas": "pensionssparande",
    "pensionssparandens": "pensionssparande",
    "pensionssparandes": "pensionssparande",
    "pensionssparandet": "pensionssparande",
    "pensionssparandets": "pensionssparande",
    "pensionstillgångarna": "pensionstillgångar",
    "pensionstillgångarnas": "pensionstillgångar",
    "pensionstillgångars": "pensionstillgångar",
    "pensionstillgångs": "pensionstillgångar",
    "pensionsvalen": "pensionsval",
    "pensionsvalens": "pensionsval",
    "pensionsvalet": "pensionsval",
    "pensionsvalets": "pensionsval",
    "pensionsvals": "pensionsval",
    "pensionsåldern": "pensionsålder",
    "pensionsålderns": "pensionsålder",
    "pensionsålders": "pensionsålder",
    "pensionsåldrar": "pensionsålder",
    "pensionsåldrarna": "pensionsålder",
    "pensionsåldrarnas": "pensionsålder",
    "pensionsåldrars": "pensionsålder",
    "pensionären": "pensionär",
    "pensionärens": "pensionär",
    "pensionärer": "pensionär",
    "pensionärerna": "pensionär",
    "pensionärernas": "pensionär",
    "pensionärers": "pensionär",
    "pensionärs": "pensionär",
    "pensionärslägenheten": "pensionärslägenhet",
    "pensionärslägenhetens": "pensionärslägenhet",
    "pensionärslägenheter": "pensionärslägenhet",
    "pensionärslägenheterna": "pensionärslägenhet",
    "pensionärslägenheternas": "pensionärslägenhet",
    "pensionärslägenheters": "pensionärslägenhet",
    "pensionärslägenhets": "pensionärslägenhet",
    "pensionärstillvaron": "pensionärstillvaro",
    "pensionärstillvarons": "pensionärstillvaro",
    "pensionärstillvaros": "pensionärstillvaro",
    "penslad": "pensla",
    "penslade": "pensla",
    "penslades": "pensla",
    "penslads": "pensla",
    "penslande": "pensla",
    "penslanden": "penslande",
    "penslandena": "penslande",
    "penslandenas": "penslande",
    "penslandens": "penslande",
    "penslandes": "penslande",
    "penslandet": "penslande",
    "penslandets": "penslande",
    "penslar": "pensla",
    "penslarna": "pensel",
    "penslarnas": "pensel",
    "penslars": "pensel",
    "penslas": "pensla",
    "penslat": "pensla",
    "penslats": "pensla",
    "pensumen": "pensum",
    "pensumens": "pensum",
    "pensumet": "pensum",
    "pensumets": "pensum",
    "pensums": "pensum",
    "penséer": "pensé",
    "penséerna": "penséer",
    "penséernas": "penséer",
    "penséers": "penséer",
    "pensén": "pensé",
    "penséns": "pensé",
    "pensés": "pensé",
    "pentagrammen": "pentagram",
    "pentagrammens": "pentagram",
    "pentagrammet": "pentagram",
    "pentagrammets": "pentagram",
    "pentagrams": "pentagram",
    "pentametern": "pentameter",
    "pentameterns": "pentameter",
    "pentameters": "pentameter",
    "pentametrar": "pentameter",
    "pentametrarna": "pentameter",
    "pentametrarnas": "pentameter",
    "pentametrars": "pentameter",
    "pentateuken": "pentateuk",
    "pentateukens": "pentateuk",
    "pentateuks": "pentateuk",
    "pentatoniken": "pentatonik",
    "pentatonikens": "pentatonik",
    "pentatoniks": "pentatonik",
    "pentryn": "pentry",
    "pentryna": "pentry",
    "pentrynas": "pentry",
    "pentryns": "pentry",
    "pentrys": "pentry",
    "pentryt": "pentry",
    "pentryts": "pentry",
    "pentylpulvers": "pentylpulver",
    "pentylpulvret": "pentylpulver",
    "pentylpulvrets": "pentylpulver",
    "penultiman": "penultima",
    "penultimans": "penultima",
    "penultimas": "penultima",
    "penultimor": "penultima",
    "penultimorna": "penultima",
    "penultimornas": "penultima",
    "penultimors": "penultima",
    "peonen": "peon",
    "peonens": "peon",
    "peoner": "peon",
    "peonerna": "peon",
    "peonernas": "peon",
    "peoners": "peon",
    "peons": "peon",
    "pep": "pipa",
    "pepitas": "pepita",
    "peppad": "peppa",
    "peppade": "peppa",
    "peppades": "peppa",
    "peppads": "peppa",
    "peppande": "peppa",
    "peppanden": "peppande",
    "peppandena": "peppande",
    "peppandenas": "peppande",
    "peppandens": "peppande",
    "peppandes": "peppande",
    "peppandet": "peppande",
    "peppandets": "peppande",
    "peppar": "peppa",
    "pepparkak": "pepparkaka",
    "pepparkakan": "pepparkaka",
    "pepparkakans": "pepparkaka",
    "pepparkakas": "pepparkaka",
    "pepparkake": "pepparkaka",
    "pepparkakor": "pepparkaka",
    "pepparkakorna": "pepparkaka",
    "pepparkakornas": "pepparkaka",
    "pepparkakors": "pepparkaka",
    "pepparkaks": "pepparkaka",
    "pepparkaksbaken": "pepparkaksbak",
    "pepparkaksbakens": "pepparkaksbak",
    "pepparkaksbaket": "pepparkaksbak",
    "pepparkaksbakets": "pepparkaksbak",
    "pepparkaksbaks": "pepparkaksbak",
    "pepparkaksdegar": "pepparkaksdeg",
    "pepparkaksdegarna": "pepparkaksdeg",
    "pepparkaksdegarnas": "pepparkaksdeg",
    "pepparkaksdegars": "pepparkaksdeg",
    "pepparkaksdegen": "pepparkaksdeg",
    "pepparkaksdegens": "pepparkaksdeg",
    "pepparkaksdegs": "pepparkaksdeg",
    "pepparkaksgrisar": "pepparkaksgris",
    "pepparkaksgrisarna": "pepparkaksgris",
    "pepparkaksgrisarnas": "pepparkaksgris",
    "pepparkaksgrisars": "pepparkaksgris",
    "pepparkaksgrisen": "pepparkaksgris",
    "pepparkaksgrisens": "pepparkaksgris",
    "pepparkaksgubb": "pepparkaksgubbe",
    "pepparkaksgubbar": "pepparkaksgubbe",
    "pepparkaksgubbarna": "pepparkaksgubbe",
    "pepparkaksgubbarnas": "pepparkaksgubbe",
    "pepparkaksgubbars": "pepparkaksgubbe",
    "pepparkaksgubben": "pepparkaksgubbe",
    "pepparkaksgubbens": "pepparkaksgubbe",
    "pepparkaksgubbes": "pepparkaksgubbe",
    "pepparkaksgubbs": "pepparkaksgubbe",
    "pepparkakshusen": "pepparkakshus",
    "pepparkakshusens": "pepparkakshus",
    "pepparkakshuset": "pepparkakshus",
    "pepparkakshusets": "pepparkakshus",
    "pepparkaksmarodören": "pepparkaksmarodör",
    "pepparkaksmarodörens": "pepparkaksmarodör",
    "pepparkaksmarodörer": "pepparkaksmarodör",
    "pepparkaksmarodörerna": "pepparkaksmarodör",
    "pepparkaksmarodörernas": "pepparkaksmarodör",
    "pepparkaksmarodörers": "pepparkaksmarodör",
    "pepparkaksmarodörs": "pepparkaksmarodör",
    "pepparkaksrekorden": "pepparkaksrekord",
    "pepparkaksrekordens": "pepparkaksrekord",
    "pepparkaksrekordet": "pepparkaksrekord",
    "pepparkaksrekordets": "pepparkaksrekord",
    "pepparkaksrekords": "pepparkaksrekord",
    "pepparkaksstaden": "pepparkaksstad",
    "pepparkaksstadens": "pepparkaksstad",
    "pepparkaksstads": "pepparkaksstad",
    "pepparkaksstan": "pepparkaksstad",
    "pepparkaksstans": "pepparkaksstad",
    "pepparkaksstäder": "pepparkaksstad",
    "pepparkaksstäderna": "pepparkaksstad",
    "pepparkaksstädernas": "pepparkaksstad",
    "pepparkaksstäders": "pepparkaksstad",
    "pepparkornen": "pepparkorn",
    "pepparkornens": "pepparkorn",
    "pepparkornet": "pepparkorn",
    "pepparkornets": "pepparkorn",
    "pepparkorns": "pepparkorn",
    "pepparkornsögonen": "pepparkornsögon",
    "pepparkornsögonens": "pepparkornsögon",
    "pepparkornsögons": "pepparkornsögon",
    "pepparkvarnar": "pepparkvarn",
    "pepparkvarnarna": "pepparkvarn",
    "pepparkvarnarnas": "pepparkvarn",
    "pepparkvarnars": "pepparkvarn",
    "pepparkvarnen": "pepparkvarn",
    "pepparkvarnens": "pepparkvarn",
    "pepparkvarns": "pepparkvarn",
    "pepparminten": "pepparmint",
    "pepparmintens": "pepparmint",
    "pepparmints": "pepparmint",
    "pepparmyntan": "pepparmynta",
    "pepparmyntans": "pepparmynta",
    "pepparmyntas": "pepparmynta",
    "pepparmynten": "pepparmynt",
    "pepparmyntens": "pepparmynt",
    "pepparmynts": "pepparmynt",
    "pepparmyntsoljan": "pepparmyntsolja",
    "pepparmyntsoljans": "pepparmyntsolja",
    "pepparmyntsoljas": "pepparmyntsolja",
    "pepparmyntsolje": "pepparmyntsolja",
    "pepparn": "peppar",
    "pepparns": "peppar",
    "pepparroten": "pepparrot",
    "pepparrotens": "pepparrot",
    "pepparrots": "pepparrot",
    "peppars": "peppar",
    "pepparsprejad": "pepparspreja",
    "pepparsprejade": "pepparspreja",
    "pepparsprejades": "pepparspreja",
    "pepparsprejads": "pepparspreja",
    "pepparsprejande": "pepparspreja",
    "pepparsprejanden": "pepparsprejande",
    "pepparsprejandena": "pepparsprejande",
    "pepparsprejandenas": "pepparsprejande",
    "pepparsprejandens": "pepparsprejande",
    "pepparsprejandes": "pepparsprejande",
    "pepparsprejandet": "pepparsprejande",
    "pepparsprejandets": "pepparsprejande",
    "pepparsprejar": "pepparspreja",
    "pepparsprejas": "pepparspreja",
    "pepparsprejat": "pepparspreja",
    "pepparsprejats": "pepparspreja",
    "pepparsprejen": "pepparsprej",
    "pepparsprejens": "pepparsprej",
    "pepparsprejs": "pepparsprej",
    "peppas": "peppa",
    "peppat": "peppa",
    "peppats": "peppa",
    "pepprad": "peppra",
    "pepprade": "pepprad",
    "pepprades": "pepprad",
    "pepprads": "pepprad",
    "pepprande": "peppra",
    "peppranden": "pepprande",
    "pepprandena": "pepprande",
    "pepprandenas": "pepprande",
    "pepprandens": "pepprande",
    "pepprandes": "pepprande",
    "pepprandet": "pepprande",
    "pepprandets": "pepprande",
    "pepprar": "peppra",
    "peppras": "peppra",
    "pepprat": "pepprad",
    "pepprats": "pepprad",
    "peps": "pipa",
    "pepsinen": "pepsin",
    "pepsinens": "pepsin",
    "pepsinet": "pepsin",
    "pepsinets": "pepsin",
    "pepsins": "pepsin",
    "peptiden": "peptid",
    "peptidens": "peptid",
    "peptider": "peptid",
    "peptiderna": "peptid",
    "peptidernas": "peptid",
    "peptiders": "peptid",
    "peptidet": "peptid",
    "peptidets": "peptid",
    "peptids": "peptid",
    "perborater": "perborat",
    "perboraterna": "perborat",
    "perboraternas": "perborat",
    "perboraters": "perborat",
    "perboratet": "perborat",
    "perboratets": "perborat",
    "perborats": "perborat",
    "perceptionen": "perception",
    "perceptionens": "perception",
    "perceptioner": "perception",
    "perceptionerna": "perception",
    "perceptionernas": "perception",
    "perceptioners": "perception",
    "perceptions": "perception",
    "perceptionsstörningar": "perceptionsstörning",
    "perceptionsstörningarna": "perceptionsstörning",
    "perceptionsstörningarnas": "perceptionsstörning",
    "perceptionsstörningars": "perceptionsstörning",
    "perceptionsstörningen": "perceptionsstörning",
    "perceptionsstörningens": "perceptionsstörning",
    "perceptionsstörnings": "perceptionsstörning",
    "perceptuella": "perceptuell",
    "perceptuellare": "perceptuell",
    "perceptuellares": "perceptuell",
    "perceptuellas": "perceptuell",
    "perceptuellast": "perceptuell",
    "perceptuellaste": "perceptuell",
    "perceptuellastes": "perceptuell",
    "perceptuellasts": "perceptuell",
    "perceptuelle": "perceptuell",
    "perceptuelles": "perceptuell",
    "perceptuells": "perceptuell",
    "perceptuellt": "perceptuell",
    "perceptuellts": "perceptuell",
    "percipierad": "percipiera",
    "percipierade": "percipiera",
    "percipierades": "percipiera",
    "percipierads": "percipiera",
    "percipierande": "percipiera",
    "percipieranden": "percipierande",
    "percipierandena": "percipierande",
    "percipierandenas": "percipierande",
    "percipierandens": "percipierande",
    "percipierandes": "percipierande",
    "percipierandet": "percipierande",
    "percipierandets": "percipierande",
    "percipierar": "percipiera",
    "percipieras": "percipiera",
    "percipierat": "percipiera",
    "percipierats": "percipiera",
    "percipierbara": "percipierbar",
    "percipierbarare": "percipierbar",
    "percipierbarares": "percipierbar",
    "percipierbaras": "percipierbar",
    "percipierbarast": "percipierbar",
    "percipierbaraste": "percipierbar",
    "percipierbarastes": "percipierbar",
    "percipierbarasts": "percipierbar",
    "percipierbare": "percipierbar",
    "percipierbares": "percipierbar",
    "percipierbarheten": "percipierbarhet",
    "percipierbarhetens": "percipierbarhet",
    "percipierbarhets": "percipierbarhet",
    "percipierbars": "percipierbar",
    "percipierbart": "percipierbar",
    "percipierbarts": "percipierbar",
    "percipieringar": "percipiering",
    "percipieringarna": "percipiering",
    "percipieringarnas": "percipiering",
    "percipieringars": "percipiering",
    "percipieringen": "percipiering",
    "percipieringens": "percipiering",
    "percipierings": "percipiering",
    "peremtoriska": "peremtorisk",
    "peremtoriskare": "peremtorisk",
    "peremtoriskares": "peremtorisk",
    "peremtoriskas": "peremtorisk",
    "peremtoriskast": "peremtorisk",
    "peremtoriskaste": "peremtorisk",
    "peremtoriskastes": "peremtorisk",
    "peremtoriskasts": "peremtorisk",
    "peremtoriske": "peremtorisk",
    "peremtoriskes": "peremtorisk",
    "peremtorisks": "peremtorisk",
    "peremtoriskt": "peremtorisk",
    "peremtoriskts": "peremtorisk",
    "perenna": "perenn",
    "perennare": "perenn",
    "perennares": "perenn",
    "perennas": "perenn",
    "perennast": "perenn",
    "perennaste": "perenn",
    "perennastes": "perenn",
    "perennasts": "perenn",
    "perenne": "perenn",
    "perennen": "perenn",
    "perennens": "perenn",
    "perenner": "perenn",
    "perennerade": "perennera",
    "perennerades": "perennera",
    "perennerande": "perennera",
    "perenneranden": "perennerande",
    "perennerandena": "perennerande",
    "perennerandenas": "perennerande",
    "perennerandens": "perennerande",
    "perennerandes": "perennerande",
    "perennerandet": "perennerande",
    "perennerandets": "perennerande",
    "perennerar": "perennera",
    "perenneras": "perennera",
    "perennerat": "perennera",
    "perennerats": "perennera",
    "perenneringar": "perennering",
    "perenneringarna": "perennering",
    "perenneringarnas": "perennering",
    "perenneringars": "perennering",
    "perenneringen": "perennering",
    "perenneringens": "perennering",
    "perennerings": "perennering",
    "perennerna": "perenn",
    "perennernas": "perenn",
    "perenners": "perenn",
    "perennes": "perenn",
    "perenns": "perenn",
    "perent": "perenn",
    "perents": "perenn",
    "perestrojkan": "perestrojka",
    "perestrojkans": "perestrojka",
    "perestrojkas": "perestrojka",
    "perfekt": "perfektum",
    "perfekta": "perfekt",
    "perfektare": "perfekt",
    "perfektares": "perfekt",
    "perfektas": "perfekt",
    "perfektast": "perfekt",
    "perfektaste": "perfekt",
    "perfektastes": "perfekt",
    "perfektasts": "perfekt",
    "perfekte": "perfekt",
    "perfekten": "perfektum",
    "perfektens": "perfektum",
    "perfekter": "perfektum",
    "perfekterna": "perfektum",
    "perfekternas": "perfektum",
    "perfekters": "perfektum",
    "perfektes": "perfekt",
    "perfektet": "perfektum",
    "perfektets": "perfektum",
    "perfektheten": "perfekthet",
    "perfekthetens": "perfekthet",
    "perfekthets": "perfekthet",
    "perfektionen": "perfektion",
    "perfektionens": "perfektion",
    "perfektioner": "perfektion",
    "perfektionerna": "perfektion",
    "perfektionernas": "perfektion",
    "perfektioners": "perfektion",
    "perfektionismen": "perfektionism",
    "perfektionismens": "perfektionism",
    "perfektionismer": "perfektionism",
    "perfektionismerna": "perfektionism",
    "perfektionismernas": "perfektionism",
    "perfektionismers": "perfektionism",
    "perfektionisms": "perfektionism",
    "perfektionisten": "perfektionist",
    "perfektionistens": "perfektionist",
    "perfektionister": "perfektionist",
    "perfektionisterna": "perfektionist",
    "perfektionisternas": "perfektionist",
    "perfektionisters": "perfektionist",
    "perfektionistiska": "perfektionistisk",
    "perfektionistiskas": "perfektionistisk",
    "perfektionistiske": "perfektionistisk",
    "perfektionistiskes": "perfektionistisk",
    "perfektionistisks": "perfektionistisk",
    "perfektionistiskt": "perfektionistisk",
    "perfektionistiskts": "perfektionistisk",
    "perfektionists": "perfektionist",
    "perfektions": "perfektion",
    "perfektiva": "perfektiv",
    "perfektivare": "perfektiv",
    "perfektivares": "perfektiv",
    "perfektivas": "perfektiv",
    "perfektivast": "perfektiv",
    "perfektivaste": "perfektiv",
    "perfektivastes": "perfektiv",
    "perfektivasts": "perfektiv",
    "perfektive": "perfektiv",
    "perfektiven": "perfektiv",
    "perfektivens": "perfektiv",
    "perfektiver": "perfektiv",
    "perfektiverna": "perfektiv",
    "perfektivernas": "perfektiv",
    "perfektivers": "perfektiv",
    "perfektives": "perfektiv",
    "perfektivet": "perfektiv",
    "perfektivets": "perfektiv",
    "perfektiviska": "perfektivisk",
    "perfektiviskare": "perfektivisk",
    "perfektiviskares": "perfektivisk",
    "perfektiviskas": "perfektivisk",
    "perfektiviskast": "perfektivisk",
    "perfektiviskaste": "perfektivisk",
    "perfektiviskastes": "perfektivisk",
    "perfektiviskasts": "perfektivisk",
    "perfektiviske": "perfektivisk",
    "perfektiviskes": "perfektivisk",
    "perfektivisks": "perfektivisk",
    "perfektiviskt": "perfektivisk",
    "perfektiviskts": "perfektivisk",
    "perfektivs": "perfektiv",
    "perfektivt": "perfektiv",
    "perfektivts": "perfektiv",
    "perfektparticipen": "perfektparticip",
    "perfektparticipens": "perfektparticip",
    "perfektparticipet": "perfektparticip",
    "perfektparticipets": "perfektparticip",
    "perfektparticips": "perfektparticip",
    "perfekts": "perfektum",
    "perfektumet": "perfektum",
    "perfektumets": "perfektum",
    "perfektums": "perfektum",
    "perfida": "perfid",
    "perfidare": "perfid",
    "perfidares": "perfid",
    "perfidas": "perfid",
    "perfidast": "perfid",
    "perfidaste": "perfid",
    "perfidastes": "perfid",
    "perfidasts": "perfid",
    "perfide": "perfid",
    "perfides": "perfid",
    "perfiditeten": "perfiditet",
    "perfiditetens": "perfiditet",
    "perfiditeter": "perfiditet",
    "perfiditeterna": "perfiditet",
    "perfiditeternas": "perfiditet",
    "perfiditeters": "perfiditet",
    "perfiditets": "perfiditet",
    "perfids": "perfid",
    "perforationen": "perforation",
    "perforationens": "perforation",
    "perforationer": "perforation",
    "perforationerna": "perforation",
    "perforationernas": "perforation",
    "perforationers": "perforation",
    "perforations": "perforation",
    "perforatorer": "perforator",
    "perforatorerna": "perforator",
    "perforatorernas": "perforator",
    "perforatorers": "perforator",
    "perforatorn": "perforator",
    "perforatorns": "perforator",
    "perforators": "perforator",
    "perforerad": "perforera",
    "perforerade": "perforera",
    "perforerades": "perforera",
    "perforerads": "perforera",
    "perforerande": "perforera",
    "perforeranden": "perforerande",
    "perforerandena": "perforerande",
    "perforerandenas": "perforerande",
    "perforerandens": "perforerande",
    "perforerandes": "perforerande",
    "perforerandet": "perforerande",
    "perforerandets": "perforerande",
    "perforerar": "perforera",
    "perforeras": "perforera",
    "perforerat": "perforera",
    "perforerats": "perforera",
    "perforerbara": "perforerbar",
    "perforerbarare": "perforerbar",
    "perforerbarares": "perforerbar",
    "perforerbaras": "perforerbar",
    "perforerbarast": "perforerbar",
    "perforerbaraste": "perforerbar",
    "perforerbarastes": "perforerbar",
    "perforerbarasts": "perforerbar",
    "perforerbare": "perforerbar",
    "perforerbares": "perforerbar",
    "perforerbarheten": "perforerbarhet",
    "perforerbarhetens": "perforerbarhet",
    "perforerbarhets": "perforerbarhet",
    "perforerbars": "perforerbar",
    "perforerbart": "perforerbar",
    "perforerbarts": "perforerbar",
    "perforeringar": "perforering",
    "perforeringarna": "perforering",
    "perforeringarnas": "perforering",
    "perforeringars": "perforering",
    "perforeringen": "perforering",
    "perforeringens": "perforering",
    "perforerings": "perforering",
    "pergamentbanden": "pergamentband",
    "pergamentbandens": "pergamentband",
    "pergamentbandet": "pergamentband",
    "pergamentbandets": "pergamentband",
    "pergamentbands": "pergamentband",
    "pergamentbitar": "pergamentbit",
    "pergamentbitarna": "pergamentbit",
    "pergamentbitarnas": "pergamentbit",
    "pergamentbitars": "pergamentbit",
    "pergamentbiten": "pergamentbit",
    "pergamentbitens": "pergamentbit",
    "pergamentbits": "pergamentbit",
    "pergamentbreven": "pergamentbrev",
    "pergamentbrevens": "pergamentbrev",
    "pergamentbrevet": "pergamentbrev",
    "pergamentbrevets": "pergamentbrev",
    "pergamentbrevs": "pergamentbrev",
    "pergamenten": "pergament",
    "pergamentens": "pergament",
    "pergamenter": "pergament",
    "pergamenterna": "pergament",
    "pergamenternas": "pergament",
    "pergamenters": "pergament",
    "pergamentet": "pergament",
    "pergamentets": "pergament",
    "pergamentrull": "pergamentrulle",
    "pergamentrullar": "pergamentrulle",
    "pergamentrullarna": "pergamentrulle",
    "pergamentrullarnas": "pergamentrulle",
    "pergamentrullars": "pergamentrulle",
    "pergamentrullen": "pergamentrulle",
    "pergamentrullens": "pergamentrulle",
    "pergamentrulles": "pergamentrulle",
    "pergamentrulls": "pergamentrulle",
    "pergaments": "pergament",
    "pergol": "pergola",
    "pergolan": "pergola",
    "pergolans": "pergola",
    "pergolas": "pergola",
    "pergole": "pergola",
    "pergolor": "pergola",
    "pergolorna": "pergola",
    "pergolornas": "pergola",
    "pergolors": "pergola",
    "pergols": "pergola",
    "perifera": "perifer",
    "periferare": "perifer",
    "periferares": "perifer",
    "periferas": "perifer",
    "periferast": "perifer",
    "periferaste": "perifer",
    "periferastes": "perifer",
    "periferasts": "perifer",
    "perifere": "perifer",
    "periferes": "perifer",
    "periferheten": "periferhet",
    "periferhetens": "periferhet",
    "periferhets": "periferhet",
    "periferien": "periferi",
    "periferiens": "periferi",
    "periferier": "periferi",
    "periferierna": "periferi",
    "periferiernas": "periferi",
    "periferiers": "periferi",
    "periferin": "periferi",
    "periferins": "periferi",
    "periferis": "periferi",
    "periferivinkeln": "periferivinkel",
    "periferivinkelns": "periferivinkel",
    "periferivinkels": "periferivinkel",
    "perifers": "perifer",
    "perifert": "perifer",
    "periferts": "perifer",
    "perifonen": "perifon",
    "perifonens": "perifon",
    "perifoner": "perifon",
    "perifonerna": "perifon",
    "perifonernas": "perifon",
    "perifoners": "perifon",
    "perifons": "perifon",
    "perifrasen": "perifras",
    "perifrasens": "perifras",
    "perifraser": "perifras",
    "perifraserna": "perifras",
    "perifrasernas": "perifras",
    "perifrasers": "perifras",
    "perifrastiska": "perifrastisk",
    "perifrastiskare": "perifrastisk",
    "perifrastiskares": "perifrastisk",
    "perifrastiskas": "perifrastisk",
    "perifrastiskast": "perifrastisk",
    "perifrastiskaste": "perifrastisk",
    "perifrastiskastes": "perifrastisk",
    "perifrastiskasts": "perifrastisk",
    "perifrastiske": "perifrastisk",
    "perifrastiskes": "perifrastisk",
    "perifrastisks": "perifrastisk",
    "perifrastiskt": "perifrastisk",
    "perifrastiskts": "perifrastisk",
    "periheliet": "perihelium",
    "periheliets": "perihelium",
    "periheliums": "perihelium",
    "perimetern": "perimeter",
    "perimeterns": "perimeter",
    "perimeters": "perimeter",
    "perimetrar": "perimeter",
    "perimetrarna": "perimeter",
    "perimetrarnas": "perimeter",
    "perimetrars": "perimeter",
    "perinatala": "perinatal",
    "perinatalare": "perinatal",
    "perinatalares": "perinatal",
    "perinatalas": "perinatal",
    "perinatalast": "perinatal",
    "perinatalaste": "perinatal",
    "perinatalastes": "perinatal",
    "perinatalasts": "perinatal",
    "perinatale": "perinatal",
    "perinatales": "perinatal",
    "perinatals": "perinatal",
    "perinatalt": "perinatal",
    "perinatalts": "perinatal",
    "periodar": "periodare",
    "periodaren": "periodare",
    "periodarens": "periodare",
    "periodares": "periodare",
    "periodarna": "periodare",
    "periodarnas": "periodare",
    "perioden": "period",
    "periodens": "period",
    "perioder": "period",
    "perioderna": "period",
    "periodernas": "period",
    "perioders": "period",
    "periodiciteten": "periodicitet",
    "periodicitetens": "periodicitet",
    "periodiciteter": "periodicitet",
    "periodiciteterna": "periodicitet",
    "periodiciteternas": "periodicitet",
    "periodiciteters": "periodicitet",
    "periodicitets": "periodicitet",
    "periodiserad": "periodisera",
    "periodiserade": "periodisera",
    "periodiserades": "periodisera",
    "periodiserads": "periodisera",
    "periodiserande": "periodisera",
    "periodiseranden": "periodiserande",
    "periodiserandena": "periodiserande",
    "periodiserandenas": "periodiserande",
    "periodiserandens": "periodiserande",
    "periodiserandes": "periodiserande",
    "periodiserandet": "periodiserande",
    "periodiserandets": "periodiserande",
    "periodiserar": "periodisera",
    "periodiseras": "periodisera",
    "periodiserat": "periodisera",
    "periodiserats": "periodisera",
    "periodiserbara": "periodiserbar",
    "periodiserbarare": "periodiserbar",
    "periodiserbarares": "periodiserbar",
    "periodiserbaras": "periodiserbar",
    "periodiserbarast": "periodiserbar",
    "periodiserbaraste": "periodiserbar",
    "periodiserbarastes": "periodiserbar",
    "periodiserbarasts": "periodiserbar",
    "periodiserbare": "periodiserbar",
    "periodiserbares": "periodiserbar",
    "periodiserbarheten": "periodiserbarhet",
    "periodiserbarhetens": "periodiserbarhet",
    "periodiserbarhets": "periodiserbarhet",
    "periodiserbars": "periodiserbar",
    "periodiserbart": "periodiserbar",
    "periodiserbarts": "periodiserbar",
    "periodiseringar": "periodisering",
    "periodiseringarna": "periodisering",
    "periodiseringarnas": "periodisering",
    "periodiseringars": "periodisering",
    "periodiseringen": "periodisering",
    "periodiseringens": "periodisering",
    "periodiserings": "periodisering",
    "periodiska": "periodisk",
    "periodiskare": "periodisk",
    "periodiskares": "periodisk",
    "periodiskas": "periodisk",
    "periodiskast": "periodisk",
    "periodiskaste": "periodisk",
    "periodiskastes": "periodisk",
    "periodiskasts": "periodisk",
    "periodiske": "periodisk",
    "periodiskes": "periodisk",
    "periodisks": "periodisk",
    "periodiskt": "periodisk",
    "periodiskts": "periodisk",
    "periods": "period",
    "periodsupar": "periodsupare",
    "periodsuparen": "periodsupare",
    "periodsuparens": "periodsupare",
    "periodsupares": "periodsupare",
    "periodsuparna": "periodsupare",
    "periodsuparnas": "periodsupare",
    "periodtalen": "periodtal",
    "periodtalens": "periodtal",
    "periodtalet": "periodtal",
    "periodtalets": "periodtal",
    "periodtals": "periodtal",
    "peripetien": "peripeti",
    "peripetiens": "peripeti",
    "peripetier": "peripeti",
    "peripetierna": "peripeti",
    "peripetiernas": "peripeti",
    "peripetiers": "peripeti",
    "peripetin": "peripeti",
    "peripetins": "peripeti",
    "peripetis": "peripeti",
    "periskopen": "periskop",
    "periskopens": "periskop",
    "periskopet": "periskop",
    "periskopets": "periskop",
    "periskopiska": "periskopisk",
    "periskopiskare": "periskopisk",
    "periskopiskares": "periskopisk",
    "periskopiskas": "periskopisk",
    "periskopiskast": "periskopisk",
    "periskopiskaste": "periskopisk",
    "periskopiskastes": "periskopisk",
    "periskopiskasts": "periskopisk",
    "periskopiske": "periskopisk",
    "periskopiskes": "periskopisk",
    "periskopisks": "periskopisk",
    "periskopiskt": "periskopisk",
    "periskopiskts": "periskopisk",
    "periskops": "periskop",
    "peristaltiken": "peristaltik",
    "peristaltikens": "peristaltik",
    "peristaltiks": "peristaltik",
    "peristaltiska": "peristaltisk",
    "peristaltiskare": "peristaltisk",
    "peristaltiskares": "peristaltisk",
    "peristaltiskas": "peristaltisk",
    "peristaltiskast": "peristaltisk",
    "peristaltiskaste": "peristaltisk",
    "peristaltiskastes": "peristaltisk",
    "peristaltiskasts": "peristaltisk",
    "peristaltiske": "peristaltisk",
    "peristaltiskes": "peristaltisk",
    "peristaltisks": "peristaltisk",
    "peristaltiskt": "peristaltisk",
    "peristaltiskts": "peristaltisk",
    "peristylen": "peristyl",
    "peristylens": "peristyl",
    "peristyler": "peristyl",
    "peristylerna": "peristyl",
    "peristylernas": "peristyl",
    "peristylers": "peristyl",
    "peristyls": "peristyl",
    "peritoniten": "peritonit",
    "peritonitens": "peritonit",
    "peritoniter": "peritonit",
    "peritoniterna": "peritonit",
    "peritoniternas": "peritonit",
    "peritoniters": "peritonit",
    "peritonits": "peritonit",
    "perkalen": "perkal",
    "perkalens": "perkal",
    "perkaler": "perkal",
    "perkalerna": "perkal",
    "perkalernas": "perkal",
    "perkalers": "perkal",
    "perkalet": "perkal",
    "perkalets": "perkal",
    "perkals": "perkal",
    "perkolationen": "perkolation",
    "perkolationens": "perkolation",
    "perkolationer": "perkolation",
    "perkolationerna": "perkolation",
    "perkolationernas": "perkolation",
    "perkolationers": "perkolation",
    "perkolations": "perkolation",
    "perkolatorer": "perkolator",
    "perkolatorerna": "perkolator",
    "perkolatorernas": "perkolator",
    "perkolatorers": "perkolator",
    "perkolatorn": "perkolator",
    "perkolatorns": "perkolator",
    "perkolators": "perkolator",
    "perkussionen": "perkussion",
    "perkussionens": "perkussion",
    "perkussioner": "perkussion",
    "perkussionerna": "perkussion",
    "perkussionernas": "perkussion",
    "perkussioners": "perkussion",
    "perkussions": "perkussion",
    "perkussionsinstrumenten": "perkussionsinstrument",
    "perkussionsinstrumentens": "perkussionsinstrument",
    "perkussionsinstrumentet": "perkussionsinstrument",
    "perkussionsinstrumentets": "perkussionsinstrument",
    "perkussionsinstruments": "perkussionsinstrument",
    "perkutana": "perkutan",
    "perkutanare": "perkutan",
    "perkutanares": "perkutan",
    "perkutanas": "perkutan",
    "perkutanast": "perkutan",
    "perkutanaste": "perkutan",
    "perkutanastes": "perkutan",
    "perkutanasts": "perkutan",
    "perkutane": "perkutan",
    "perkutanes": "perkutan",
    "perkutans": "perkutan",
    "perkutant": "perkutan",
    "perkutants": "perkutan",
    "permafrosten": "permafrost",
    "permafrostens": "permafrost",
    "permafrosts": "permafrost",
    "permanensen": "permanens",
    "permanensens": "permanens",
    "permanent": "permanenta",
    "permanenta": "permanent",
    "permanentad": "permanenta",
    "permanentade": "permanenta",
    "permanentades": "permanenta",
    "permanentads": "permanenta",
    "permanentande": "permanenta",
    "permanentanden": "permanentande",
    "permanentandena": "permanentande",
    "permanentandenas": "permanentande",
    "permanentandens": "permanentande",
    "permanentandes": "permanentande",
    "permanentandet": "permanentande",
    "permanentandets": "permanentande",
    "permanentar": "permanenta",
    "permanentare": "permanent",
    "permanentares": "permanent",
    "permanentas": "permanenta",
    "permanentast": "permanent",
    "permanentaste": "permanent",
    "permanentastes": "permanent",
    "permanentasts": "permanent",
    "permanentat": "permanenta",
    "permanentats": "permanenta",
    "permanente": "permanent",
    "permanenten": "permanent",
    "permanentens": "permanent",
    "permanentes": "permanent",
    "permanentheten": "permanenthet",
    "permanenthetens": "permanenthet",
    "permanenthets": "permanenthet",
    "permanentondulerad": "permanentondulera",
    "permanentondulerade": "permanentondulera",
    "permanentondulerades": "permanentondulera",
    "permanentondulerads": "permanentondulera",
    "permanentondulerande": "permanentondulera",
    "permanentonduleranden": "permanentondulerande",
    "permanentondulerandena": "permanentondulerande",
    "permanentondulerandenas": "permanentondulerande",
    "permanentondulerandens": "permanentondulerande",
    "permanentondulerandes": "permanentondulerande",
    "permanentondulerandet": "permanentondulerande",
    "permanentondulerandets": "permanentondulerande",
    "permanentondulerar": "permanentondulera",
    "permanentonduleras": "permanentondulera",
    "permanentondulerat": "permanentondulera",
    "permanentondulerats": "permanentondulera",
    "permanentondulerbara": "permanentondulerbar",
    "permanentondulerbarare": "permanentondulerbar",
    "permanentondulerbarares": "permanentondulerbar",
    "permanentondulerbaras": "permanentondulerbar",
    "permanentondulerbarast": "permanentondulerbar",
    "permanentondulerbaraste": "permanentondulerbar",
    "permanentondulerbarastes": "permanentondulerbar",
    "permanentondulerbarasts": "permanentondulerbar",
    "permanentondulerbare": "permanentondulerbar",
    "permanentondulerbares": "permanentondulerbar",
    "permanentondulerbarheten": "permanentondulerbarhet",
    "permanentondulerbarhetens": "permanentondulerbarhet",
    "permanentondulerbarhets": "permanentondulerbarhet",
    "permanentondulerbars": "permanentondulerbar",
    "permanentondulerbart": "permanentondulerbar",
    "permanentondulerbarts": "permanentondulerbar",
    "permanentonduleringar": "permanentondulering",
    "permanentonduleringarna": "permanentondulering",
    "permanentonduleringarnas": "permanentondulering",
    "permanentonduleringars": "permanentondulering",
    "permanentonduleringen": "permanentondulering",
    "permanentonduleringens": "permanentondulering",
    "permanentondulerings": "permanentondulering",
    "permanents": "permanent",
    "permeabels": "permeabel",
    "permeabelt": "permeabel",
    "permeabelts": "permeabel",
    "permeabiliteten": "permeabilitet",
    "permeabilitetens": "permeabilitet",
    "permeabiliteter": "permeabilitet",
    "permeabiliteterna": "permeabilitet",
    "permeabiliteternas": "permeabilitet",
    "permeabiliteters": "permeabilitet",
    "permeabilitets": "permeabilitet",
    "permeabla": "permeabel",
    "permeablare": "permeabel",
    "permeablares": "permeabel",
    "permeablas": "permeabel",
    "permeablast": "permeabel",
    "permeablaste": "permeabel",
    "permeablastes": "permeabel",
    "permeablasts": "permeabel",
    "permeable": "permeabel",
    "permeables": "permeabel",
    "permissionen": "permission",
    "permissionens": "permission",
    "permissioner": "permission",
    "permissionerna": "permission",
    "permissionernas": "permission",
    "permissioners": "permission",
    "permissions": "permission",
    "permittenten": "permittent",
    "permittentens": "permittent",
    "permittenter": "permittent",
    "permittenterna": "permittent",
    "permittenternas": "permittent",
    "permittenters": "permittent",
    "permittents": "permittent",
    "permitterad": "permittera",
    "permitterade": "permittera",
    "permitterades": "permittera",
    "permitterads": "permittera",
    "permitterande": "permittera",
    "permitteranden": "permitterande",
    "permitterandena": "permitterande",
    "permitterandenas": "permitterande",
    "permitterandens": "permitterande",
    "permitterandes": "permitterande",
    "permitterandet": "permitterande",
    "permitterandets": "permitterande",
    "permitterar": "permittera",
    "permitteras": "permittera",
    "permitterat": "permittera",
    "permitterats": "permittera",
    "permitterbara": "permitterbar",
    "permitterbarare": "permitterbar",
    "permitterbarares": "permitterbar",
    "permitterbaras": "permitterbar",
    "permitterbarast": "permitterbar",
    "permitterbaraste": "permitterbar",
    "permitterbarastes": "permitterbar",
    "permitterbarasts": "permitterbar",
    "permitterbare": "permitterbar",
    "permitterbares": "permitterbar",
    "permitterbarheten": "permitterbarhet",
    "permitterbarhetens": "permitterbarhet",
    "permitterbarhets": "permitterbarhet",
    "permitterbars": "permitterbar",
    "permitterbart": "permitterbar",
    "permitterbarts": "permitterbar",
    "permitteringar": "permittering",
    "permitteringarna": "permittering",
    "permitteringarnas": "permittering",
    "permitteringars": "permittering",
    "permitteringen": "permittering",
    "permitteringens": "permittering",
    "permitterings": "permittering",
    "perms": "perm",
    "permutationen": "permutation",
    "permutationens": "permutation",
    "permutationer": "permutation",
    "permutationerna": "permutation",
    "permutationernas": "permutation",
    "permutationers": "permutation",
    "permutations": "permutation",
    "permutationsrätten": "permutationsrätt",
    "permutationsrättens": "permutationsrätt",
    "permutationsrätts": "permutationsrätt",
    "permuterad": "permutera",
    "permuterade": "permutera",
    "permuterades": "permutera",
    "permuterads": "permutera",
    "permuterande": "permutera",
    "permuteranden": "permuterande",
    "permuterandena": "permuterande",
    "permuterandenas": "permuterande",
    "permuterandens": "permuterande",
    "permuterandes": "permuterande",
    "permuterandet": "permuterande",
    "permuterandets": "permuterande",
    "permuterar": "permutera",
    "permuteras": "permutera",
    "permuterat": "permutera",
    "permuterats": "permutera",
    "permuterbara": "permuterbar",
    "permuterbarare": "permuterbar",
    "permuterbarares": "permuterbar",
    "permuterbaras": "permuterbar",
    "permuterbarast": "permuterbar",
    "permuterbaraste": "permuterbar",
    "permuterbarastes": "permuterbar",
    "permuterbarasts": "permuterbar",
    "permuterbare": "permuterbar",
    "permuterbares": "permuterbar",
    "permuterbarheten": "permuterbarhet",
    "permuterbarhetens": "permuterbarhet",
    "permuterbarhets": "permuterbarhet",
    "permuterbars": "permuterbar",
    "permuterbart": "permuterbar",
    "permuterbarts": "permuterbar",
    "permuteringar": "permutering",
    "permuteringarna": "permutering",
    "permuteringarnas": "permutering",
    "permuteringars": "permutering",
    "permuteringen": "permutering",
    "permuteringens": "permutering",
    "permuterings": "permutering",
    "perniciösa": "perniciös",
    "perniciösare": "perniciös",
    "perniciösares": "perniciös",
    "perniciösas": "perniciös",
    "perniciösast": "perniciös",
    "perniciösaste": "perniciös",
    "perniciösastes": "perniciös",
    "perniciösasts": "perniciös",
    "perniciöse": "perniciös",
    "perniciöses": "perniciös",
    "perniciöst": "perniciös",
    "perniciösts": "perniciös",
    "peroxiden": "peroxid",
    "peroxidens": "peroxid",
    "peroxider": "peroxid",
    "peroxiderna": "peroxid",
    "peroxidernas": "peroxid",
    "peroxiders": "peroxid",
    "peroxids": "peroxid",
    "perpendikeln": "perpendikel",
    "perpendikelns": "perpendikel",
    "perpendikels": "perpendikel",
    "perpendiklar": "perpendikel",
    "perpendiklarna": "perpendikel",
    "perpendiklarnas": "perpendikel",
    "perpendiklars": "perpendikel",
    "perpendikulära": "perpendikulär",
    "perpendikulärare": "perpendikulär",
    "perpendikulärares": "perpendikulär",
    "perpendikuläras": "perpendikulär",
    "perpendikulärast": "perpendikulär",
    "perpendikuläraste": "perpendikulär",
    "perpendikulärastes": "perpendikulär",
    "perpendikulärasts": "perpendikulär",
    "perpendikuläre": "perpendikulär",
    "perpendikuläres": "perpendikulär",
    "perpendikulärs": "perpendikulär",
    "perpendikulärt": "perpendikulär",
    "perpendikulärts": "perpendikulär",
    "perpetuella": "perpetuell",
    "perpetuellare": "perpetuell",
    "perpetuellares": "perpetuell",
    "perpetuellas": "perpetuell",
    "perpetuellast": "perpetuell",
    "perpetuellaste": "perpetuell",
    "perpetuellastes": "perpetuell",
    "perpetuellasts": "perpetuell",
    "perpetuelle": "perpetuell",
    "perpetuelles": "perpetuell",
    "perpetuells": "perpetuell",
    "perpetuellt": "perpetuell",
    "perpetuellts": "perpetuell",
    "perplexa": "perplex",
    "perplexare": "perplex",
    "perplexares": "perplex",
    "perplexas": "perplex",
    "perplexast": "perplex",
    "perplexaste": "perplex",
    "perplexastes": "perplex",
    "perplexasts": "perplex",
    "perplexe": "perplex",
    "perplexes": "perplex",
    "perplexheten": "perplexhet",
    "perplexhetens": "perplexhet",
    "perplexhets": "perplexhet",
    "perplext": "perplex",
    "perplexts": "perplex",
    "perrongen": "perrong",
    "perrongens": "perrong",
    "perronger": "perrong",
    "perrongerna": "perrong",
    "perrongernas": "perrong",
    "perrongers": "perrong",
    "perrongs": "perrong",
    "persedeln": "persedel",
    "persedelns": "persedel",
    "persedelpås": "persedelpåse",
    "persedelpåsar": "persedelpåse",
    "persedelpåsarna": "persedelpåse",
    "persedelpåsarnas": "persedelpåse",
    "persedelpåsars": "persedelpåse",
    "persedelpåsen": "persedelpåse",
    "persedelpåsens": "persedelpåse",
    "persedelpåses": "persedelpåse",
    "persedels": "persedel",
    "persedelvården": "persedelvård",
    "persedelvårdens": "persedelvård",
    "persedelvårds": "persedelvård",
    "persedlar": "persedel",
    "persedlarna": "persedel",
    "persedlarnas": "persedel",
    "persedlars": "persedel",
    "persern": "perser",
    "perserna": "perser",
    "persernas": "perser",
    "perserns": "perser",
    "persers": "perser",
    "perseverationen": "perseveration",
    "perseverationens": "perseveration",
    "perseverationer": "perseveration",
    "perseverationerna": "perseveration",
    "perseverationernas": "perseveration",
    "perseverationers": "perseveration",
    "perseverations": "perseveration",
    "persianen": "persian",
    "persianens": "persian",
    "persianpälsar": "persianpäls",
    "persianpälsarna": "persianpäls",
    "persianpälsarnas": "persianpäls",
    "persianpälsars": "persianpäls",
    "persianpälsen": "persianpäls",
    "persianpälsens": "persianpäls",
    "persians": "persian",
    "persiennen": "persienn",
    "persiennens": "persienn",
    "persienner": "persienn",
    "persiennerna": "persienn",
    "persiennernas": "persienn",
    "persienners": "persienn",
    "persienns": "persienn",
    "persiflages": "persiflage",
    "persiflaget": "persiflage",
    "persiflagets": "persiflage",
    "persiflerad": "persiflera",
    "persiflerade": "persiflera",
    "persiflerades": "persiflera",
    "persiflerads": "persiflera",
    "persiflerande": "persiflera",
    "persifleranden": "persiflerande",
    "persiflerandena": "persiflerande",
    "persiflerandenas": "persiflerande",
    "persiflerandens": "persiflerande",
    "persiflerandes": "persiflerande",
    "persiflerandet": "persiflerande",
    "persiflerandets": "persiflerande",
    "persiflerar": "persiflera",
    "persifleras": "persiflera",
    "persiflerat": "persiflera",
    "persiflerats": "persiflera",
    "persiflerbara": "persiflerbar",
    "persiflerbarare": "persiflerbar",
    "persiflerbarares": "persiflerbar",
    "persiflerbaras": "persiflerbar",
    "persiflerbarast": "persiflerbar",
    "persiflerbaraste": "persiflerbar",
    "persiflerbarastes": "persiflerbar",
    "persiflerbarasts": "persiflerbar",
    "persiflerbare": "persiflerbar",
    "persiflerbares": "persiflerbar",
    "persiflerbarheten": "persiflerbarhet",
    "persiflerbarhetens": "persiflerbarhet",
    "persiflerbarhets": "persiflerbarhet",
    "persiflerbars": "persiflerbar",
    "persiflerbart": "persiflerbar",
    "persiflerbarts": "persiflerbar",
    "persifleringar": "persiflering",
    "persifleringarna": "persiflering",
    "persifleringarnas": "persiflering",
    "persifleringars": "persiflering",
    "persifleringen": "persiflering",
    "persifleringens": "persiflering",
    "persiflerings": "persiflering",
    "persik": "persika",
    "persikan": "persika",
    "persikans": "persika",
    "persikas": "persika",
    "persike": "persika",
    "persikofärgade": "persikofärgad",
    "persikofärgades": "persikofärgad",
    "persikofärgads": "persikofärgad",
    "persikofärgat": "persikofärgad",
    "persikofärgats": "persikofärgad",
    "persikohyn": "persikohy",
    "persikohyns": "persikohy",
    "persikohys": "persikohy",
    "persikor": "persika",
    "persikorna": "persika",
    "persikornas": "persika",
    "persikors": "persika",
    "persiks": "persika",
    "persiljan": "persilja",
    "persiljans": "persilja",
    "persiljas": "persilja",
    "persiljesmöret": "persiljesmör",
    "persiljesmörets": "persiljesmör",
    "persiljesmörs": "persiljesmör",
    "persimonen": "persimon",
    "persimonens": "persimon",
    "persimoner": "persimon",
    "persimonerna": "persimon",
    "persimonernas": "persimon",
    "persimoners": "persimon",
    "persimons": "persimon",
    "persisk": "persiska",
    "persiska": "persisk",
    "persiskan": "persiska",
    "persiskans": "persiska",
    "persiskare": "persisk",
    "persiskares": "persisk",
    "persiskas": "persiska",
    "persiskast": "persisk",
    "persiskaste": "persisk",
    "persiskastes": "persisk",
    "persiskasts": "persisk",
    "persiske": "persiska",
    "persiskes": "persisk",
    "persiskor": "persiska",
    "persiskorna": "persiska",
    "persiskornas": "persiska",
    "persiskors": "persiska",
    "persisks": "persisk",
    "persiskt": "persisk",
    "persiskts": "persisk",
    "personagen": "personage",
    "personagens": "personage",
    "personager": "personage",
    "personagerna": "personage",
    "personagernas": "personage",
    "personagers": "personage",
    "personages": "personage",
    "personalansvaret": "personalansvar",
    "personalansvarets": "personalansvar",
    "personalansvars": "personalansvar",
    "personalansvarsnämnden": "personalansvarsnämnd",
    "personalansvarsnämndens": "personalansvarsnämnd",
    "personalansvarsnämnder": "personalansvarsnämnd",
    "personalansvarsnämnderna": "personalansvarsnämnd",
    "personalansvarsnämndernas": "personalansvarsnämnd",
    "personalansvarsnämnders": "personalansvarsnämnd",
    "personalansvarsnämnds": "personalansvarsnämnd",
    "personalavdelningar": "personalavdelning",
    "personalavdelningarna": "personalavdelning",
    "personalavdelningarnas": "personalavdelning",
    "personalavdelningars": "personalavdelning",
    "personalavdelningen": "personalavdelning",
    "personalavdelningens": "personalavdelning",
    "personalavdelnings": "personalavdelning",
    "personalbristen": "personalbrist",
    "personalbristens": "personalbrist",
    "personalbrists": "personalbrist",
    "personalchefen": "personalchef",
    "personalchefens": "personalchef",
    "personalchefer": "personalchef",
    "personalcheferna": "personalchef",
    "personalchefernas": "personalchef",
    "personalchefers": "personalchef",
    "personalchefs": "personalchef",
    "personalen": "personal",
    "personalens": "personal",
    "personaler": "personal",
    "personalerfarenheten": "personalerfarenhet",
    "personalerfarenhetens": "personalerfarenhet",
    "personalerfarenheter": "personalerfarenhet",
    "personalerfarenheterna": "personalerfarenhet",
    "personalerfarenheternas": "personalerfarenhet",
    "personalerfarenheters": "personalerfarenhet",
    "personalerfarenhets": "personalerfarenhet",
    "personalerna": "personal",
    "personalernas": "personal",
    "personalers": "personal",
    "personalfrågan": "personalfråga",
    "personalfrågans": "personalfråga",
    "personalfrågas": "personalfråga",
    "personalfråge": "personalfråga",
    "personalfrågor": "personalfråga",
    "personalfrågorna": "personalfråga",
    "personalfrågornas": "personalfråga",
    "personalfrågors": "personalfråga",
    "personali": "personalier",
    "personalian": "personalia",
    "personaliana": "personalia",
    "personalianas": "personalia",
    "personalians": "personalia",
    "personalias": "personalia",
    "personaliat": "personalia",
    "personaliats": "personalia",
    "personalierna": "personalier",
    "personaliernas": "personalier",
    "personaliers": "personalier",
    "personalingångar": "personalingång",
    "personalingångarna": "personalingång",
    "personalingångarnas": "personalingång",
    "personalingångars": "personalingång",
    "personalingången": "personalingång",
    "personalingångens": "personalingång",
    "personalingångs": "personalingång",
    "personalismen": "personalism",
    "personalismens": "personalism",
    "personalismer": "personalism",
    "personalismerna": "personalism",
    "personalismernas": "personalism",
    "personalismers": "personalism",
    "personalisms": "personalism",
    "personalistiska": "personalistisk",
    "personalistiskas": "personalistisk",
    "personalistiske": "personalistisk",
    "personalistiskes": "personalistisk",
    "personalistisks": "personalistisk",
    "personalistiskt": "personalistisk",
    "personalistiskts": "personalistisk",
    "personalläkar": "personalläkare",
    "personalläkaren": "personalläkare",
    "personalläkarens": "personalläkare",
    "personalläkares": "personalläkare",
    "personalläkarna": "personalläkare",
    "personalläkarnas": "personalläkare",
    "personalmatsalar": "personalmatsal",
    "personalmatsalarna": "personalmatsal",
    "personalmatsalarnas": "personalmatsal",
    "personalmatsalars": "personalmatsal",
    "personalmatsalen": "personalmatsal",
    "personalmatsalens": "personalmatsal",
    "personalmatsals": "personalmatsal",
    "personalmässiga": "personalmässig",
    "personalmässigare": "personalmässig",
    "personalmässigares": "personalmässig",
    "personalmässigas": "personalmässig",
    "personalmässigast": "personalmässig",
    "personalmässigaste": "personalmässig",
    "personalmässigastes": "personalmässig",
    "personalmässigasts": "personalmässig",
    "personalmässige": "personalmässig",
    "personalmässiges": "personalmässig",
    "personalmässigs": "personalmässig",
    "personalmässigt": "personalmässig",
    "personalmässigts": "personalmässig",
    "personalorganisationen": "personalorganisation",
    "personalorganisationens": "personalorganisation",
    "personalorganisationer": "personalorganisation",
    "personalorganisationerna": "personalorganisation",
    "personalorganisationernas": "personalorganisation",
    "personalorganisationers": "personalorganisation",
    "personalorganisations": "personalorganisation",
    "personalpolitiken": "personalpolitik",
    "personalpolitikens": "personalpolitik",
    "personalpolitiks": "personalpolitik",
    "personalpolitiska": "personalpolitisk",
    "personalpolitiskas": "personalpolitisk",
    "personalpolitiske": "personalpolitisk",
    "personalpolitiskes": "personalpolitisk",
    "personalpolitisks": "personalpolitisk",
    "personalpolitiskt": "personalpolitisk",
    "personalpolitiskts": "personalpolitisk",
    "personalpoolen": "personalpool",
    "personalpoolens": "personalpool",
    "personalpooler": "personalpool",
    "personalpoolerna": "personalpool",
    "personalpoolernas": "personalpool",
    "personalpoolers": "personalpool",
    "personalpools": "personalpool",
    "personalrummen": "personalrum",
    "personalrummens": "personalrum",
    "personalrummet": "personalrum",
    "personalrummets": "personalrum",
    "personalrums": "personalrum",
    "personals": "personal",
    "personaltidningar": "personaltidning",
    "personaltidningarna": "personaltidning",
    "personaltidningarnas": "personaltidning",
    "personaltidningars": "personaltidning",
    "personaltidningen": "personaltidning",
    "personaltidningens": "personaltidning",
    "personaltidnings": "personaltidning",
    "personaltätheten": "personaltäthet",
    "personaltäthetens": "personaltäthet",
    "personaltätheter": "personaltäthet",
    "personaltätheterna": "personaltäthet",
    "personaltätheternas": "personaltäthet",
    "personaltätheters": "personaltäthet",
    "personaltäthets": "personaltäthet",
    "personalunionen": "personalunion",
    "personalunionens": "personalunion",
    "personalunioner": "personalunion",
    "personalunionerna": "personalunion",
    "personalunionernas": "personalunion",
    "personalunioners": "personalunion",
    "personalunions": "personalunion",
    "personalutbildar": "personalutbildare",
    "personalutbildaren": "personalutbildare",
    "personalutbildarens": "personalutbildare",
    "personalutbildares": "personalutbildare",
    "personalutbildarna": "personalutbildare",
    "personalutbildarnas": "personalutbildare",
    "personalutbildningar": "personalutbildning",
    "personalutbildningarna": "personalutbildning",
    "personalutbildningarnas": "personalutbildning",
    "personalutbildningars": "personalutbildning",
    "personalutbildningen": "personalutbildning",
    "personalutbildningens": "personalutbildning",
    "personalutbildnings": "personalutbildning",
    "personalvårdar": "personalvård",
    "personalvårdarna": "personalvård",
    "personalvårdarnas": "personalvård",
    "personalvårdars": "personalvård",
    "personalvården": "personalvård",
    "personalvårdens": "personalvård",
    "personalvårds": "personalvård",
    "personattacken": "personattack",
    "personattackens": "personattack",
    "personattacker": "personattack",
    "personattackerna": "personattack",
    "personattackernas": "personattack",
    "personattackers": "personattack",
    "personattacks": "personattack",
    "personbevisen": "personbevis",
    "personbevisens": "personbevis",
    "personbeviset": "personbevis",
    "personbevisets": "personbevis",
    "personbilar": "personbil",
    "personbilarna": "personbil",
    "personbilarnas": "personbil",
    "personbilars": "personbil",
    "personbilen": "personbil",
    "personbilens": "personbil",
    "personbils": "personbil",
    "persondatorer": "persondator",
    "persondatorerna": "persondator",
    "persondatorernas": "persondator",
    "persondatorers": "persondator",
    "persondatorn": "persondator",
    "persondatorns": "persondator",
    "persondators": "persondator",
    "personella": "personell",
    "personellare": "personell",
    "personellares": "personell",
    "personellas": "personell",
    "personellast": "personell",
    "personellaste": "personell",
    "personellastes": "personell",
    "personellasts": "personell",
    "personelle": "personell",
    "personelles": "personell",
    "personells": "personell",
    "personellt": "personell",
    "personellts": "personell",
    "personen": "person",
    "personens": "person",
    "personer": "person",
    "personerna": "person",
    "personernas": "person",
    "personers": "person",
    "personfixerade": "personfixerad",
    "personfixerades": "personfixerad",
    "personfixerads": "personfixerad",
    "personfixerat": "personfixerad",
    "personfixerats": "personfixerad",
    "personfrågan": "personfråga",
    "personfrågans": "personfråga",
    "personfrågas": "personfråga",
    "personfråge": "personfråga",
    "personfrågor": "personfråga",
    "personfrågorna": "personfråga",
    "personfrågornas": "personfråga",
    "personfrågors": "personfråga",
    "personförsäkringar": "personförsäkring",
    "personförsäkringarna": "personförsäkring",
    "personförsäkringarnas": "personförsäkring",
    "personförsäkringars": "personförsäkring",
    "personförsäkringen": "personförsäkring",
    "personförsäkringens": "personförsäkring",
    "personförsäkrings": "personförsäkring",
    "persongallerier": "persongalleri",
    "persongallerierna": "persongalleri",
    "persongalleriernas": "persongalleri",
    "persongalleriers": "persongalleri",
    "persongalleriet": "persongalleri",
    "persongalleriets": "persongalleri",
    "persongalleris": "persongalleri",
    "persongallerit": "persongalleri",
    "persongallerits": "persongalleri",
    "personhistorian": "personhistoria",
    "personhistorians": "personhistoria",
    "personhistorias": "personhistoria",
    "personhistorien": "personhistoria",
    "personhistoriens": "personhistoria",
    "personhistoriska": "personhistorisk",
    "personhistoriskare": "personhistorisk",
    "personhistoriskares": "personhistorisk",
    "personhistoriskas": "personhistorisk",
    "personhistoriskast": "personhistorisk",
    "personhistoriskaste": "personhistorisk",
    "personhistoriskastes": "personhistorisk",
    "personhistoriskasts": "personhistorisk",
    "personhistoriske": "personhistorisk",
    "personhistoriskes": "personhistorisk",
    "personhistorisks": "personhistorisk",
    "personhistoriskt": "personhistorisk",
    "personhistoriskts": "personhistorisk",
    "personifierad": "personifiera",
    "personifierade": "personifiera",
    "personifierades": "personifiera",
    "personifierads": "personifiera",
    "personifierande": "personifiera",
    "personifieranden": "personifierande",
    "personifierandena": "personifierande",
    "personifierandenas": "personifierande",
    "personifierandens": "personifierande",
    "personifierandes": "personifierande",
    "personifierandet": "personifierande",
    "personifierandets": "personifierande",
    "personifierar": "personifiera",
    "personifieras": "personifiera",
    "personifierat": "personifiera",
    "personifierats": "personifiera",
    "personifierbara": "personifierbar",
    "personifierbarare": "personifierbar",
    "personifierbarares": "personifierbar",
    "personifierbaras": "personifierbar",
    "personifierbarast": "personifierbar",
    "personifierbaraste": "personifierbar",
    "personifierbarastes": "personifierbar",
    "personifierbarasts": "personifierbar",
    "personifierbare": "personifierbar",
    "personifierbares": "personifierbar",
    "personifierbarheten": "personifierbarhet",
    "personifierbarhetens": "personifierbarhet",
    "personifierbarhets": "personifierbarhet",
    "personifierbars": "personifierbar",
    "personifierbart": "personifierbar",
    "personifierbarts": "personifierbar",
    "personifieringar": "personifiering",
    "personifieringarna": "personifiering",
    "personifieringarnas": "personifiering",
    "personifieringars": "personifiering",
    "personifieringen": "personifiering",
    "personifieringens": "personifiering",
    "personifierings": "personifiering",
    "personifikationen": "personifikation",
    "personifikationens": "personifikation",
    "personifikationer": "personifikation",
    "personifikationerna": "personifikation",
    "personifikationernas": "personifikation",
    "personifikationers": "personifikation",
    "personifikations": "personifikation",
    "personkemien": "personkemi",
    "personkemiens": "personkemi",
    "personkemin": "personkemi",
    "personkemins": "personkemi",
    "personkemis": "personkemi",
    "personkilometern": "personkilometer",
    "personkilometerna": "personkilometer",
    "personkilometernas": "personkilometer",
    "personkilometerns": "personkilometer",
    "personkilometers": "personkilometer",
    "personkontakten": "personkontakt",
    "personkontaktens": "personkontakt",
    "personkontakter": "personkontakt",
    "personkontakterna": "personkontakt",
    "personkontakternas": "personkontakt",
    "personkontakters": "personkontakt",
    "personkontakts": "personkontakt",
    "personkonton": "personkonto",
    "personkontona": "personkonto",
    "personkontonas": "personkonto",
    "personkontons": "personkonto",
    "personkontos": "personkonto",
    "personkontot": "personkonto",
    "personkontots": "personkonto",
    "personkulten": "personkult",
    "personkultens": "personkult",
    "personkulter": "personkult",
    "personkulterna": "personkult",
    "personkulternas": "personkult",
    "personkulters": "personkult",
    "personkults": "personkult",
    "personliga": "personlig",
    "personligare": "personlig",
    "personligares": "personlig",
    "personligas": "personlig",
    "personligast": "personlig",
    "personligaste": "personlig",
    "personligastes": "personlig",
    "personligasts": "personlig",
    "personlige": "personlig",
    "personliges": "personlig",
    "personligheten": "personlighet",
    "personlighetens": "personlighet",
    "personligheter": "personlighet",
    "personligheterna": "personlighet",
    "personligheternas": "personlighet",
    "personligheters": "personlighet",
    "personlighets": "personlighet",
    "personlighetsdragen": "personlighetsdrag",
    "personlighetsdragens": "personlighetsdrag",
    "personlighetsdraget": "personlighetsdrag",
    "personlighetsdragets": "personlighetsdrag",
    "personlighetsdrags": "personlighetsdrag",
    "personlighetsklyvningar": "personlighetsklyvning",
    "personlighetsklyvningarna": "personlighetsklyvning",
    "personlighetsklyvningarnas": "personlighetsklyvning",
    "personlighetsklyvningars": "personlighetsklyvning",
    "personlighetsklyvningen": "personlighetsklyvning",
    "personlighetsklyvningens": "personlighetsklyvning",
    "personlighetsklyvnings": "personlighetsklyvning",
    "personlighetsmässiga": "personlighetsmässig",
    "personlighetsmässigare": "personlighetsmässig",
    "personlighetsmässigares": "personlighetsmässig",
    "personlighetsmässigas": "personlighetsmässig",
    "personlighetsmässigast": "personlighetsmässig",
    "personlighetsmässigaste": "personlighetsmässig",
    "personlighetsmässigastes": "personlighetsmässig",
    "personlighetsmässigasts": "personlighetsmässig",
    "personlighetsmässige": "personlighetsmässig",
    "personlighetsmässiges": "personlighetsmässig",
    "personlighetsmässigs": "personlighetsmässig",
    "personlighetsmässigt": "personlighetsmässig",
    "personlighetsmässigts": "personlighetsmässig",
    "personlighetsstörningar": "personlighetsstörning",
    "personlighetsstörningarna": "personlighetsstörning",
    "personlighetsstörningarnas": "personlighetsstörning",
    "personlighetsstörningars": "personlighetsstörning",
    "personlighetsstörningen": "personlighetsstörning",
    "personlighetsstörningens": "personlighetsstörning",
    "personlighetsstörnings": "personlighetsstörning",
    "personlighetstypen": "personlighetstyp",
    "personlighetstypens": "personlighetstyp",
    "personlighetstyper": "personlighetstyp",
    "personlighetstyperna": "personlighetstyp",
    "personlighetstypernas": "personlighetstyp",
    "personlighetstypers": "personlighetstyp",
    "personlighetstyps": "personlighetstyp",
    "personligs": "personlig",
    "personligt": "personlig",
    "personligts": "personlig",
    "personmässiga": "personmässig",
    "personmässigare": "personmässig",
    "personmässigares": "personmässig",
    "personmässigas": "personmässig",
    "personmässigast": "personmässig",
    "personmässigaste": "personmässig",
    "personmässigastes": "personmässig",
    "personmässigasts": "personmässig",
    "personmässige": "personmässig",
    "personmässiges": "personmässig",
    "personmässigs": "personmässig",
    "personmässigt": "personmässig",
    "personmässigts": "personmässig",
    "personnamnen": "personnamn",
    "personnamnens": "personnamn",
    "personnamnet": "personnamn",
    "personnamnets": "personnamn",
    "personnamns": "personnamn",
    "personnummerna": "personnummer",
    "personnummernas": "personnummer",
    "personnummers": "personnummer",
    "personnumren": "personnummer",
    "personnumrens": "personnummer",
    "personnumret": "personnummer",
    "personnumrets": "personnummer",
    "personpolitiken": "personpolitik",
    "personpolitikens": "personpolitik",
    "personpolitiks": "personpolitik",
    "personpolitiska": "personpolitisk",
    "personpolitiskare": "personpolitisk",
    "personpolitiskares": "personpolitisk",
    "personpolitiskas": "personpolitisk",
    "personpolitiskast": "personpolitisk",
    "personpolitiskaste": "personpolitisk",
    "personpolitiskastes": "personpolitisk",
    "personpolitiskasts": "personpolitisk",
    "personpolitiske": "personpolitisk",
    "personpolitiskes": "personpolitisk",
    "personpolitisks": "personpolitisk",
    "personpolitiskt": "personpolitisk",
    "personpolitiskts": "personpolitisk",
    "personregisterna": "personregister",
    "personregisternas": "personregister",
    "personregisters": "personregister",
    "personregistren": "personregister",
    "personregistrens": "personregister",
    "personregistret": "personregister",
    "personregistrets": "personregister",
    "personröst": "personrösta",
    "personröstade": "personrösta",
    "personröstades": "personrösta",
    "personröstande": "personrösta",
    "personröstandes": "personrösta",
    "personröstar": "personrösta",
    "personröstas": "personrösta",
    "personröstat": "personrösta",
    "personröstats": "personrösta",
    "persons": "person",
    "personsammansättningar": "personsammansättning",
    "personsammansättningarna": "personsammansättning",
    "personsammansättningarnas": "personsammansättning",
    "personsammansättningars": "personsammansättning",
    "personsammansättningen": "personsammansättning",
    "personsammansättningens": "personsammansättning",
    "personsammansättnings": "personsammansättning",
    "personskadan": "personskada",
    "personskadans": "personskada",
    "personskadas": "personskada",
    "personskade": "personskada",
    "personskador": "personskada",
    "personskadorna": "personskada",
    "personskadornas": "personskada",
    "personskadors": "personskada",
    "personsökar": "personsökare",
    "personsökaren": "personsökare",
    "personsökarens": "personsökare",
    "personsökares": "personsökare",
    "personsökarna": "personsökare",
    "personsökarnas": "personsökare",
    "persontrafiken": "persontrafik",
    "persontrafikens": "persontrafik",
    "persontrafiks": "persontrafik",
    "persontågen": "persontåg",
    "persontågens": "persontåg",
    "persontåget": "persontåg",
    "persontågets": "persontåg",
    "persontågs": "persontåg",
    "personundersökningar": "personundersökning",
    "personundersökningarna": "personundersökning",
    "personundersökningarnas": "personundersökning",
    "personundersökningars": "personundersökning",
    "personundersökningen": "personundersökning",
    "personundersökningens": "personundersökning",
    "personundersöknings": "personundersökning",
    "personuppgiften": "personuppgift",
    "personuppgiftens": "personuppgift",
    "personuppgifter": "personuppgift",
    "personuppgifterna": "personuppgift",
    "personuppgifternas": "personuppgift",
    "personuppgifters": "personuppgift",
    "personuppgifts": "personuppgift",
    "personvagnar": "personvagn",
    "personvagnarna": "personvagn",
    "personvagnarnas": "personvagn",
    "personvagnars": "personvagn",
    "personvagnen": "personvagn",
    "personvagnens": "personvagn",
    "personvagns": "personvagn",
    "personvalen": "personval",
    "personvalens": "personval",
    "personvalet": "personval",
    "personvalets": "personval",
    "personvals": "personval",
    "personvalskampanjen": "personvalskampanj",
    "personvalskampanjens": "personvalskampanj",
    "personvalskampanjer": "personvalskampanj",
    "personvalskampanjerna": "personvalskampanj",
    "personvalskampanjernas": "personvalskampanj",
    "personvalskampanjers": "personvalskampanj",
    "personvalskampanjs": "personvalskampanj",
    "personvågar": "personvåg",
    "personvågarna": "personvåg",
    "personvågarnas": "personvåg",
    "personvågars": "personvåg",
    "personvågen": "personvåg",
    "personvågens": "personvåg",
    "personvågs": "personvåg",
    "perspektivbilden": "perspektivbild",
    "perspektivbildens": "perspektivbild",
    "perspektivbilder": "perspektivbild",
    "perspektivbilderna": "perspektivbild",
    "perspektivbildernas": "perspektivbild",
    "perspektivbilders": "perspektivbild",
    "perspektivbilds": "perspektivbild",
    "perspektiven": "perspektiv",
    "perspektivens": "perspektiv",
    "perspektivet": "perspektiv",
    "perspektivets": "perspektiv",
    "perspektivfönsterna": "perspektivfönster",
    "perspektivfönsternas": "perspektivfönster",
    "perspektivfönsters": "perspektivfönster",
    "perspektivfönstren": "perspektivfönster",
    "perspektivfönstrens": "perspektivfönster",
    "perspektivfönstret": "perspektivfönster",
    "perspektivfönstrets": "perspektivfönster",
    "perspektivförskjutningar": "perspektivförskjutning",
    "perspektivförskjutningarna": "perspektivförskjutning",
    "perspektivförskjutningarnas": "perspektivförskjutning",
    "perspektivförskjutningars": "perspektivförskjutning",
    "perspektivförskjutningen": "perspektivförskjutning",
    "perspektivförskjutningens": "perspektivförskjutning",
    "perspektivförskjutnings": "perspektivförskjutning",
    "perspektiviska": "perspektivisk",
    "perspektiviskare": "perspektivisk",
    "perspektiviskares": "perspektivisk",
    "perspektiviskas": "perspektivisk",
    "perspektiviskast": "perspektivisk",
    "perspektiviskaste": "perspektivisk",
    "perspektiviskastes": "perspektivisk",
    "perspektiviskasts": "perspektivisk",
    "perspektiviske": "perspektivisk",
    "perspektiviskes": "perspektivisk",
    "perspektivisks": "perspektivisk",
    "perspektiviskt": "perspektivisk",
    "perspektiviskts": "perspektivisk",
    "perspektivlösa": "perspektivlös",
    "perspektivlösare": "perspektivlös",
    "perspektivlösares": "perspektivlös",
    "perspektivlösas": "perspektivlös",
    "perspektivlösast": "perspektivlös",
    "perspektivlösaste": "perspektivlös",
    "perspektivlösastes": "perspektivlös",
    "perspektivlösasts": "perspektivlös",
    "perspektivlöse": "perspektivlös",
    "perspektivlöses": "perspektivlös",
    "perspektivlösheten": "perspektivlöshet",
    "perspektivlöshetens": "perspektivlöshet",
    "perspektivlöshets": "perspektivlöshet",
    "perspektivlöst": "perspektivlös",
    "perspektivlösts": "perspektivlös",
    "perspektivmässiga": "perspektivmässig",
    "perspektivmässigare": "perspektivmässig",
    "perspektivmässigares": "perspektivmässig",
    "perspektivmässigas": "perspektivmässig",
    "perspektivmässigast": "perspektivmässig",
    "perspektivmässigaste": "perspektivmässig",
    "perspektivmässigastes": "perspektivmässig",
    "perspektivmässigasts": "perspektivmässig",
    "perspektivmässige": "perspektivmässig",
    "perspektivmässiges": "perspektivmässig",
    "perspektivmässigs": "perspektivmässig",
    "perspektivmässigt": "perspektivmässig",
    "perspektivmässigts": "perspektivmässig",
    "perspektivs": "perspektiv",
    "perspektivskiften": "perspektivskifte",
    "perspektivskiftena": "perspektivskifte",
    "perspektivskiftenas": "perspektivskifte",
    "perspektivskiftens": "perspektivskifte",
    "perspektivskiftes": "perspektivskifte",
    "perspektivskiftet": "perspektivskifte",
    "perspektivskiftets": "perspektivskifte",
    "perstorpsplatt": "perstorpsplatta",
    "perstorpsplattan": "perstorpsplatta",
    "perstorpsplattans": "perstorpsplatta",
    "perstorpsplattas": "perstorpsplatta",
    "perstorpsplatte": "perstorpsplatta",
    "perstorpsplattor": "perstorpsplatta",
    "perstorpsplattorna": "perstorpsplatta",
    "perstorpsplattornas": "perstorpsplatta",
    "perstorpsplattors": "perstorpsplatta",
    "perstorpsplatts": "perstorpsplatta",
    "perstorpsskivan": "perstorpsskiva",
    "perstorpsskivans": "perstorpsskiva",
    "perstorpsskivas": "perstorpsskiva",
    "perstorpsskive": "perstorpsskiva",
    "perstorpsskivor": "perstorpsskiva",
    "perstorpsskivorna": "perstorpsskiva",
    "perstorpsskivornas": "perstorpsskiva",
    "perstorpsskivors": "perstorpsskiva",
    "persvaderad": "persvadera",
    "persvaderade": "persvadera",
    "persvaderades": "persvadera",
    "persvaderads": "persvadera",
    "persvaderande": "persvadera",
    "persvaderanden": "persvaderande",
    "persvaderandena": "persvaderande",
    "persvaderandenas": "persvaderande",
    "persvaderandens": "persvaderande",
    "persvaderandes": "persvaderande",
    "persvaderandet": "persvaderande",
    "persvaderandets": "persvaderande",
    "persvaderar": "persvadera",
    "persvaderas": "persvadera",
    "persvaderat": "persvadera",
    "persvaderats": "persvadera",
    "persvaderbara": "persvaderbar",
    "persvaderbarare": "persvaderbar",
    "persvaderbarares": "persvaderbar",
    "persvaderbaras": "persvaderbar",
    "persvaderbarast": "persvaderbar",
    "persvaderbaraste": "persvaderbar",
    "persvaderbarastes": "persvaderbar",
    "persvaderbarasts": "persvaderbar",
    "persvaderbare": "persvaderbar",
    "persvaderbares": "persvaderbar",
    "persvaderbarheten": "persvaderbarhet",
    "persvaderbarhetens": "persvaderbarhet",
    "persvaderbarhets": "persvaderbarhet",
    "persvaderbars": "persvaderbar",
    "persvaderbart": "persvaderbar",
    "persvaderbarts": "persvaderbar",
    "persvaderingar": "persvadering",
    "persvaderingarna": "persvadering",
    "persvaderingarnas": "persvadering",
    "persvaderingars": "persvadering",
    "persvaderingen": "persvadering",
    "persvaderingens": "persvadering",
    "persvaderings": "persvadering",
    "perturbationen": "perturbation",
    "perturbationens": "perturbation",
    "perturbationer": "perturbation",
    "perturbationerna": "perturbation",
    "perturbationernas": "perturbation",
    "perturbationers": "perturbation",
    "perturbations": "perturbation",
    "peruanen": "peruan",
    "peruanens": "peruan",
    "peruaner": "peruan",
    "peruanerna": "peruan",
    "peruanernas": "peruan",
    "peruaners": "peruan",
    "peruans": "peruan",
    "peruanska": "peruansk",
    "peruanskan": "peruanska",
    "peruanskans": "peruanska",
    "peruanskare": "peruansk",
    "peruanskares": "peruansk",
    "peruanskas": "peruanska",
    "peruanskast": "peruansk",
    "peruanskaste": "peruansk",
    "peruanskastes": "peruansk",
    "peruanskasts": "peruansk",
    "peruanske": "peruanska",
    "peruanskes": "peruansk",
    "peruanskor": "peruanska",
    "peruanskorna": "peruanska",
    "peruanskornas": "peruanska",
    "peruanskors": "peruanska",
    "peruansks": "peruansk",
    "peruanskt": "peruansk",
    "peruanskts": "peruansk",
    "perukbråken": "perukbråk",
    "perukbråkens": "perukbråk",
    "perukbråket": "perukbråk",
    "perukbråkets": "perukbråk",
    "perukbråks": "perukbråk",
    "peruken": "peruk",
    "perukens": "peruk",
    "peruker": "peruk",
    "perukerna": "peruk",
    "perukernas": "peruk",
    "perukers": "peruk",
    "perukmakar": "perukmakare",
    "perukmakaren": "perukmakare",
    "perukmakarens": "perukmakare",
    "perukmakares": "perukmakare",
    "perukmakarna": "perukmakare",
    "perukmakarnas": "perukmakare",
    "peruks": "peruk",
    "perukstockar": "perukstock",
    "perukstockarna": "perukstock",
    "perukstockarnas": "perukstock",
    "perukstockars": "perukstock",
    "perukstocken": "perukstock",
    "perukstockens": "perukstock",
    "perukstocks": "perukstock",
    "perversa": "pervers",
    "perversare": "pervers",
    "perversares": "pervers",
    "perversas": "pervers",
    "perversast": "pervers",
    "perversaste": "pervers",
    "perversastes": "pervers",
    "perversasts": "pervers",
    "perverse": "pervers",
    "perverses": "pervers",
    "perversheten": "pervershet",
    "pervershetens": "pervershet",
    "pervershets": "pervershet",
    "perversionen": "perversion",
    "perversionens": "perversion",
    "perversioner": "perversion",
    "perversionerna": "perversion",
    "perversionernas": "perversion",
    "perversioners": "perversion",
    "perversions": "perversion",
    "perversiteten": "perversitet",
    "perversitetens": "perversitet",
    "perversiteter": "perversitet",
    "perversiteterna": "perversitet",
    "perversiteternas": "perversitet",
    "perversiteters": "perversitet",
    "perversitets": "perversitet",
    "perverst": "pervers",
    "perversts": "pervers",
    "perverterad": "pervertera",
    "perverterade": "pervertera",
    "perverterades": "pervertera",
    "perverterads": "pervertera",
    "perverterande": "pervertera",
    "perverteranden": "perverterande",
    "perverterandena": "perverterande",
    "perverterandenas": "perverterande",
    "perverterandens": "perverterande",
    "perverterandes": "perverterande",
    "perverterandet": "perverterande",
    "perverterandets": "perverterande",
    "perverterar": "pervertera",
    "perverteras": "pervertera",
    "perverterat": "pervertera",
    "perverterats": "pervertera",
    "perverterbara": "perverterbar",
    "perverterbarare": "perverterbar",
    "perverterbarares": "perverterbar",
    "perverterbaras": "perverterbar",
    "perverterbarast": "perverterbar",
    "perverterbaraste": "perverterbar",
    "perverterbarastes": "perverterbar",
    "perverterbarasts": "perverterbar",
    "perverterbare": "perverterbar",
    "perverterbares": "perverterbar",
    "perverterbarheten": "perverterbarhet",
    "perverterbarhetens": "perverterbarhet",
    "perverterbarhets": "perverterbarhet",
    "perverterbars": "perverterbar",
    "perverterbart": "perverterbar",
    "perverterbarts": "perverterbar",
    "perverteringar": "pervertering",
    "perverteringarna": "pervertering",
    "perverteringarnas": "pervertering",
    "perverteringars": "pervertering",
    "perverteringen": "pervertering",
    "perverteringens": "pervertering",
    "perverterings": "pervertering",
    "pervon": "pervo",
    "pervona": "pervo",
    "pervonas": "pervo",
    "pervons": "pervo",
    "pervos": "pervo",
    "pervot": "pervo",
    "pervots": "pervo",
    "pesetan": "peseta",
    "pesetans": "peseta",
    "pesetas": "peseta",
    "pesetasarna": "peseta",
    "pesetasarnas": "peseta",
    "pesetasen": "peseta",
    "pesetasens": "peseta",
    "peson": "peso",
    "pesons": "peso",
    "pesor": "peso",
    "pesorna": "peso",
    "pesornas": "peso",
    "pesors": "peso",
    "pesos": "peso",
    "pesosen": "peso",
    "pesosens": "peso",
    "pessaren": "pessar",
    "pessarens": "pessar",
    "pessaret": "pessar",
    "pessarets": "pessar",
    "pessars": "pessar",
    "pessimismen": "pessimism",
    "pessimismens": "pessimism",
    "pessimismer": "pessimism",
    "pessimismerna": "pessimism",
    "pessimismernas": "pessimism",
    "pessimismers": "pessimism",
    "pessimisms": "pessimism",
    "pessimisten": "pessimist",
    "pessimistens": "pessimist",
    "pessimister": "pessimist",
    "pessimisterna": "pessimist",
    "pessimisternas": "pessimist",
    "pessimisters": "pessimist",
    "pessimistiska": "pessimistisk",
    "pessimistiskare": "pessimistisk",
    "pessimistiskares": "pessimistisk",
    "pessimistiskas": "pessimistisk",
    "pessimistiskast": "pessimistisk",
    "pessimistiskaste": "pessimistisk",
    "pessimistiskastes": "pessimistisk",
    "pessimistiskasts": "pessimistisk",
    "pessimistiske": "pessimistisk",
    "pessimistiskes": "pessimistisk",
    "pessimistisks": "pessimistisk",
    "pessimistiskt": "pessimistisk",
    "pessimistiskts": "pessimistisk",
    "pessimists": "pessimist",
    "pesten": "pest",
    "pestens": "pest",
    "pester": "pest",
    "pesterna": "pest",
    "pesternas": "pest",
    "pesters": "pest",
    "pesticiden": "pesticid",
    "pesticidens": "pesticid",
    "pesticider": "pesticid",
    "pesticiderna": "pesticid",
    "pesticidernas": "pesticid",
    "pesticiders": "pesticid",
    "pesticids": "pesticid",
    "pestilensen": "pestilens",
    "pestilensens": "pestilens",
    "pestilenser": "pestilens",
    "pestilenserna": "pestilens",
    "pestilensernas": "pestilens",
    "pestilensers": "pestilens",
    "pestilensroten": "pestilensrot",
    "pestilensrotens": "pestilensrot",
    "pestilensrots": "pestilensrot",
    "pests": "pest",
    "pestskråpen": "pestskråp",
    "pestskråpens": "pestskråp",
    "pestskråps": "pestskråp",
    "pet": "peta",
    "petabyten": "petabyte",
    "petabytena": "petabyte",
    "petabytenas": "petabyte",
    "petabytens": "petabyte",
    "petabytes": "petabyte",
    "petad": "peta",
    "petade": "peta",
    "petades": "peta",
    "petads": "peta",
    "petande": "peta",
    "petanden": "petande",
    "petandena": "petande",
    "petandenas": "petande",
    "petandens": "petande",
    "petandes": "petande",
    "petandet": "petande",
    "petandets": "petande",
    "petar": "peta",
    "petas": "peta",
    "petat": "peta",
    "petats": "peta",
    "peterspenningar": "peterspenning",
    "peterspenningarna": "peterspenning",
    "peterspenningarnas": "peterspenning",
    "peterspenningars": "peterspenning",
    "peterspenningen": "peterspenning",
    "peterspenningens": "peterspenning",
    "peterspennings": "peterspenning",
    "petgöras": "petgöra",
    "petgörat": "petgöra",
    "petgörats": "petgöra",
    "petiga": "petig",
    "petigare": "petig",
    "petigares": "petig",
    "petigas": "petig",
    "petigast": "petig",
    "petigaste": "petig",
    "petigastes": "petig",
    "petigasts": "petig",
    "petige": "petig",
    "petiges": "petig",
    "petigs": "petig",
    "petigt": "petig",
    "petigts": "petig",
    "petimätern": "petimäter",
    "petimäterns": "petimäter",
    "petimäters": "petimäter",
    "petimätrar": "petimäter",
    "petimätrarna": "petimäter",
    "petimätrarnas": "petimäter",
    "petimätrars": "petimäter",
    "petit": "petita",
    "petit-chouer": "petit-chou",
    "petit-chouerna": "petit-chou",
    "petit-chouernas": "petit-chou",
    "petit-chouers": "petit-chou",
    "petit-choun": "petit-chou",
    "petit-chouns": "petit-chou",
    "petit-chous": "petit-chou",
    "petitan": "petita",
    "petitans": "petita",
    "petitas": "petita",
    "petitchouer": "petitchou",
    "petitchouerna": "petitchou",
    "petitchouernas": "petitchou",
    "petitchouers": "petitchou",
    "petitchoun": "petitchou",
    "petitchouns": "petitchou",
    "petitchous": "petitchou",
    "petite": "petita",
    "petiten": "petit",
    "petitens": "petit",
    "petitessen": "petitess",
    "petitessens": "petitess",
    "petitesser": "petitess",
    "petitesserna": "petitess",
    "petitessernas": "petitess",
    "petitessers": "petitess",
    "petitionen": "petition",
    "petitionens": "petition",
    "petitioner": "petition",
    "petitionerna": "petition",
    "petitionernas": "petition",
    "petitioners": "petition",
    "petitions": "petition",
    "petitor": "petita",
    "petitorna": "petita",
    "petitornas": "petita",
    "petitors": "petita",
    "petits": "petita",
    "petmojar": "petmoj",
    "petmojarna": "petmoj",
    "petmojarnas": "petmoj",
    "petmojars": "petmoj",
    "petmojen": "petmoj",
    "petmojens": "petmoj",
    "petmojs": "petmoj",
    "petrifierad": "petrifiera",
    "petrifierade": "petrifiera",
    "petrifierades": "petrifiera",
    "petrifierads": "petrifiera",
    "petrifierande": "petrifiera",
    "petrifieranden": "petrifierande",
    "petrifierandena": "petrifierande",
    "petrifierandenas": "petrifierande",
    "petrifierandens": "petrifierande",
    "petrifierandes": "petrifierande",
    "petrifierandet": "petrifierande",
    "petrifierandets": "petrifierande",
    "petrifierar": "petrifiera",
    "petrifieras": "petrifiera",
    "petrifierat": "petrifiera",
    "petrifierats": "petrifiera",
    "petrifierbara": "petrifierbar",
    "petrifierbarare": "petrifierbar",
    "petrifierbarares": "petrifierbar",
    "petrifierbaras": "petrifierbar",
    "petrifierbarast": "petrifierbar",
    "petrifierbaraste": "petrifierbar",
    "petrifierbarastes": "petrifierbar",
    "petrifierbarasts": "petrifierbar",
    "petrifierbare": "petrifierbar",
    "petrifierbares": "petrifierbar",
    "petrifierbarheten": "petrifierbarhet",
    "petrifierbarhetens": "petrifierbarhet",
    "petrifierbarhets": "petrifierbarhet",
    "petrifierbars": "petrifierbar",
    "petrifierbart": "petrifierbar",
    "petrifierbarts": "petrifierbar",
    "petrifieringar": "petrifiering",
    "petrifieringarna": "petrifiering",
    "petrifieringarnas": "petrifiering",
    "petrifieringars": "petrifiering",
    "petrifieringen": "petrifiering",
    "petrifieringens": "petrifiering",
    "petrifierings": "petrifiering",
    "petrifikaten": "petrifikat",
    "petrifikatens": "petrifikat",
    "petrifikatet": "petrifikat",
    "petrifikatets": "petrifikat",
    "petrifikats": "petrifikat",
    "petrografien": "petrografi",
    "petrografiens": "petrografi",
    "petrografin": "petrografi",
    "petrografins": "petrografi",
    "petrografis": "petrografi",
    "petrokemiska": "petrokemisk",
    "petrokemiskare": "petrokemisk",
    "petrokemiskares": "petrokemisk",
    "petrokemiskas": "petrokemisk",
    "petrokemiskast": "petrokemisk",
    "petrokemiskaste": "petrokemisk",
    "petrokemiskastes": "petrokemisk",
    "petrokemiskasts": "petrokemisk",
    "petrokemiske": "petrokemisk",
    "petrokemiskes": "petrokemisk",
    "petrokemisks": "petrokemisk",
    "petrokemiskt": "petrokemisk",
    "petrokemiskts": "petrokemisk",
    "petroleumbaserade": "petroleumbaserad",
    "petroleumbaserades": "petroleumbaserad",
    "petroleumbaserads": "petroleumbaserad",
    "petroleumbaserat": "petroleumbaserad",
    "petroleumbaserats": "petroleumbaserad",
    "petroleumen": "petroleum",
    "petroleumens": "petroleum",
    "petroleumet": "petroleum",
    "petroleumets": "petroleum",
    "petroleums": "petroleum",
    "petsäkerheten": "petsäkerhet",
    "petsäkerhetens": "petsäkerhet",
    "petsäkerhets": "petsäkerhet",
    "petsäkers": "petsäker",
    "petsäkert": "petsäker",
    "petsäkerts": "petsäker",
    "petsäkra": "petsäker",
    "petsäkrare": "petsäker",
    "petsäkrares": "petsäker",
    "petsäkras": "petsäker",
    "petsäkrast": "petsäker",
    "petsäkraste": "petsäker",
    "petsäkrastes": "petsäker",
    "petsäkrasts": "petsäker",
    "petsäkre": "petsäker",
    "petsäkres": "petsäker",
    "pettingen": "petting",
    "pettingens": "petting",
    "pettings": "petting",
    "petuni": "petunia",
    "petunian": "petunia",
    "petunians": "petunia",
    "petunias": "petunia",
    "petunie": "petunia",
    "petunior": "petunia",
    "petuniorna": "petunia",
    "petuniornas": "petunia",
    "petuniors": "petunia",
    "petunis": "petunia",
    "pfennigen": "pfennig",
    "pfennigens": "pfennig",
    "pfennigs": "pfennig",
    "phien": "phi",
    "phiens": "phi",
    "phiet": "phi",
    "phiets": "phi",
    "phin": "phi",
    "phina": "phi",
    "phinas": "phi",
    "phins": "phi",
    "phis": "phi",
    "phit": "phi",
    "phits": "phi",
    "physalisar": "physalis",
    "physalisarna": "physalis",
    "physalisarnas": "physalis",
    "physalisars": "physalis",
    "physalisen": "physalis",
    "physalisens": "physalis",
    "piaffen": "piaff",
    "piaffens": "piaff",
    "piaffer": "piaff",
    "piafferna": "piaff",
    "piaffernas": "piaff",
    "piaffers": "piaff",
    "piaffs": "piaff",
    "pianinon": "pianino",
    "pianinona": "pianino",
    "pianinonas": "pianino",
    "pianinons": "pianino",
    "pianinos": "pianino",
    "pianinot": "pianino",
    "pianinots": "pianino",
    "pianissimon": "pianissimo",
    "pianissimona": "pianissimo",
    "pianissimonas": "pianissimo",
    "pianissimons": "pianissimo",
    "pianissimos": "pianissimo",
    "pianissimot": "pianissimo",
    "pianissimots": "pianissimo",
    "pianisten": "pianist",
    "pianistens": "pianist",
    "pianister": "pianist",
    "pianisterna": "pianist",
    "pianisternas": "pianist",
    "pianisters": "pianist",
    "pianists": "pianist",
    "pianokonserten": "pianokonsert",
    "pianokonsertens": "pianokonsert",
    "pianokonserter": "pianokonsert",
    "pianokonserterna": "pianokonsert",
    "pianokonserternas": "pianokonsert",
    "pianokonserters": "pianokonsert",
    "pianokonserts": "pianokonsert",
    "pianol": "pianola",
    "pianolan": "pianola",
    "pianolans": "pianola",
    "pianolas": "pianola",
    "pianole": "pianola",
    "pianolektionen": "pianolektion",
    "pianolektionens": "pianolektion",
    "pianolektioner": "pianolektion",
    "pianolektionerna": "pianolektion",
    "pianolektionernas": "pianolektion",
    "pianolektioners": "pianolektion",
    "pianolektions": "pianolektion",
    "pianolor": "pianola",
    "pianolorna": "pianola",
    "pianolornas": "pianola",
    "pianolors": "pianola",
    "pianols": "pianola",
    "pianomusiken": "pianomusik",
    "pianomusikens": "pianomusik",
    "pianomusiks": "pianomusik",
    "pianon": "piano",
    "pianona": "piano",
    "pianonas": "piano",
    "pianons": "piano",
    "pianopedalen": "pianopedal",
    "pianopedalens": "pianopedal",
    "pianopedaler": "pianopedal",
    "pianopedalerna": "pianopedal",
    "pianopedalernas": "pianopedal",
    "pianopedalers": "pianopedal",
    "pianopedals": "pianopedal",
    "pianos": "piano",
    "pianosonaten": "pianosonat",
    "pianosonatens": "pianosonat",
    "pianosonater": "pianosonat",
    "pianosonaterna": "pianosonat",
    "pianosonaternas": "pianosonat",
    "pianosonaters": "pianosonat",
    "pianosonats": "pianosonat",
    "pianospelen": "pianospel",
    "pianospelens": "pianospel",
    "pianospelet": "pianospel",
    "pianospelets": "pianospel",
    "pianospelningar": "pianospelning",
    "pianospelningarna": "pianospelning",
    "pianospelningarnas": "pianospelning",
    "pianospelningars": "pianospelning",
    "pianospelningen": "pianospelning",
    "pianospelningens": "pianospelning",
    "pianospelnings": "pianospelning",
    "pianospels": "pianospel",
    "pianostolar": "pianostol",
    "pianostolarna": "pianostol",
    "pianostolarnas": "pianostol",
    "pianostolars": "pianostol",
    "pianostolen": "pianostol",
    "pianostolens": "pianostol",
    "pianostols": "pianostol",
    "pianot": "piano",
    "pianots": "piano",
    "piasavakvastar": "piasavakvast",
    "piasavakvastarna": "piasavakvast",
    "piasavakvastarnas": "piasavakvast",
    "piasavakvastars": "piasavakvast",
    "piasavakvasten": "piasavakvast",
    "piasavakvastens": "piasavakvast",
    "piasavakvasts": "piasavakvast",
    "piassavakvastar": "piassavakvast",
    "piassavakvastarna": "piassavakvast",
    "piassavakvastarnas": "piassavakvast",
    "piassavakvastars": "piassavakvast",
    "piassavakvasten": "piassavakvast",
    "piassavakvastens": "piassavakvast",
    "piassavakvasts": "piassavakvast",
    "piassavan": "piassava",
    "piassavans": "piassava",
    "piassavas": "piassava",
    "piastern": "piaster",
    "piasterns": "piaster",
    "piasters": "piaster",
    "piastrar": "piaster",
    "piastrarna": "piaster",
    "piastrarnas": "piaster",
    "piastrars": "piaster",
    "piazz": "piazza",
    "piazzan": "piazza",
    "piazzans": "piazza",
    "piazzas": "piazza",
    "piazze": "piazza",
    "piazzor": "piazza",
    "piazzorna": "piazza",
    "piazzornas": "piazza",
    "piazzors": "piazza",
    "picadoren": "picador",
    "picadorens": "picador",
    "picadorer": "picador",
    "picadorerna": "picador",
    "picadorernas": "picador",
    "picadorers": "picador",
    "picadors": "picador",
    "piccol": "piccola",
    "piccolaflöjten": "piccolaflöjt",
    "piccolaflöjtens": "piccolaflöjt",
    "piccolaflöjter": "piccolaflöjt",
    "piccolaflöjterna": "piccolaflöjt",
    "piccolaflöjternas": "piccolaflöjt",
    "piccolaflöjters": "piccolaflöjt",
    "piccolaflöjts": "piccolaflöjt",
    "piccolan": "piccola",
    "piccolans": "piccola",
    "piccolas": "piccola",
    "piccole": "piccola",
    "piccolon": "piccolo",
    "piccolons": "piccolo",
    "piccolor": "piccolo",
    "piccolorna": "piccolo",
    "piccolornas": "piccolo",
    "piccolors": "piccolo",
    "piccolos": "piccolo",
    "piccols": "piccola",
    "pick": "picka",
    "pickad": "picka",
    "pickade": "picka",
    "pickades": "picka",
    "pickadollen": "pickadoll",
    "pickadollens": "pickadoll",
    "pickadoller": "pickadoll",
    "pickadollerna": "pickadoll",
    "pickadollernas": "pickadoll",
    "pickadollers": "pickadoll",
    "pickadolls": "pickadoll",
    "pickads": "picka",
    "pickan": "picka",
    "pickande": "picka",
    "pickanden": "pickande",
    "pickandena": "pickande",
    "pickandenas": "pickande",
    "pickandens": "pickande",
    "pickandes": "pickande",
    "pickandet": "pickande",
    "pickandets": "pickande",
    "pickans": "picka",
    "pickar": "picka",
    "pickarna": "pick",
    "pickarnas": "pick",
    "pickars": "pick",
    "pickas": "picka",
    "pickat": "picka",
    "pickats": "picka",
    "pickelhuv": "pickelhuva",
    "pickelhuvan": "pickelhuva",
    "pickelhuvans": "pickelhuva",
    "pickelhuvas": "pickelhuva",
    "pickelhuve": "pickelhuva",
    "pickelhuvor": "pickelhuva",
    "pickelhuvorna": "pickelhuva",
    "pickelhuvornas": "pickelhuva",
    "pickelhuvors": "pickelhuva",
    "pickelhuvs": "pickelhuva",
    "pickelsen": "pickels",
    "pickelsens": "pickels",
    "picken": "pick",
    "pickens": "pick",
    "picklesen": "pickles",
    "picklesens": "pickles",
    "picknickar": "picknick",
    "picknickarna": "picknick",
    "picknickarnas": "picknick",
    "picknickars": "picknick",
    "picknicken": "picknick",
    "picknickens": "picknick",
    "picknicks": "picknick",
    "pickor": "picka",
    "pickorna": "picka",
    "pickornas": "picka",
    "pickors": "picka",
    "picks": "pick",
    "pickupen": "pickup",
    "pickupens": "pickup",
    "pickuper": "pickup",
    "pickuperna": "pickup",
    "pickupernas": "pickup",
    "pickupers": "pickup",
    "pickups": "pickup",
    "picoten": "picot",
    "picotens": "picot",
    "picoter": "picot",
    "picoterna": "picot",
    "picoternas": "picot",
    "picoters": "picot",
    "picots": "picot",
    "pidginen": "pidgin",
    "pidginengelsk": "pidginengelska",
    "pidginengelskan": "pidginengelska",
    "pidginengelskans": "pidginengelska",
    "pidginengelskas": "pidginengelska",
    "pidginens": "pidgin",
    "pidginet": "pidgin",
    "pidginets": "pidgin",
    "pidgins": "pidgin",
    "piedestalen": "piedestal",
    "piedestalens": "piedestal",
    "piedestaler": "piedestal",
    "piedestalerna": "piedestal",
    "piedestalernas": "piedestal",
    "piedestalers": "piedestal",
    "piedestals": "piedestal",
    "pien": "pi",
    "piens": "pi",
    "piercingar": "piercing",
    "piercingarna": "piercing",
    "piercingarnas": "piercing",
    "piercingars": "piercing",
    "piercingen": "piercing",
    "piercingens": "piercing",
    "piercings": "piercing",
    "piercingsmycken": "piercingsmycke",
    "piercingsmyckena": "piercingsmycke",
    "piercingsmyckenas": "piercingsmycke",
    "piercingsmyckens": "piercingsmycke",
    "piercingsmyckes": "piercingsmycke",
    "piercingsmycket": "piercingsmycke",
    "piercingsmyckets": "piercingsmycke",
    "pierroten": "pierrot",
    "pierrotens": "pierrot",
    "pierroter": "pierrot",
    "pierroterna": "pierrot",
    "pierroternas": "pierrot",
    "pierroters": "pierrot",
    "pierrots": "pierrot",
    "piet": "pi",
    "pieteten": "pietet",
    "pietetens": "pietet",
    "pieteter": "pietet",
    "pieteterna": "pietet",
    "pieteternas": "pietet",
    "pieteters": "pietet",
    "pietets": "pietet",
    "pietetsfulla": "pietetsfull",
    "pietetsfullare": "pietetsfull",
    "pietetsfullares": "pietetsfull",
    "pietetsfullas": "pietetsfull",
    "pietetsfullast": "pietetsfull",
    "pietetsfullaste": "pietetsfull",
    "pietetsfullastes": "pietetsfull",
    "pietetsfullasts": "pietetsfull",
    "pietetsfulle": "pietetsfull",
    "pietetsfulles": "pietetsfull",
    "pietetsfullheten": "pietetsfullhet",
    "pietetsfullhetens": "pietetsfullhet",
    "pietetsfullhets": "pietetsfullhet",
    "pietetsfulls": "pietetsfull",
    "pietetsfullt": "pietetsfull",
    "pietetsfullts": "pietetsfull",
    "pietismen": "pietism",
    "pietismens": "pietism",
    "pietismer": "pietism",
    "pietismerna": "pietism",
    "pietismernas": "pietism",
    "pietismers": "pietism",
    "pietisms": "pietism",
    "pietisten": "pietist",
    "pietistens": "pietist",
    "pietister": "pietist",
    "pietisterna": "pietist",
    "pietisternas": "pietist",
    "pietisters": "pietist",
    "pietistiska": "pietistisk",
    "pietistiskas": "pietistisk",
    "pietistiske": "pietistisk",
    "pietistiskes": "pietistisk",
    "pietistisks": "pietistisk",
    "pietistiskt": "pietistisk",
    "pietistiskts": "pietistisk",
    "pietists": "pietist",
    "piets": "pi",
    "piezoelektriciteten": "piezoelektricitet",
    "piezoelektricitetens": "piezoelektricitet",
    "piezoelektriciteter": "piezoelektricitet",
    "piezoelektriciteterna": "piezoelektricitet",
    "piezoelektriciteternas": "piezoelektricitet",
    "piezoelektriciteters": "piezoelektricitet",
    "piezoelektricitets": "piezoelektricitet",
    "piffen": "piff",
    "piffens": "piff",
    "piffiga": "piffig",
    "piffigare": "piffig",
    "piffigares": "piffig",
    "piffigas": "piffig",
    "piffigast": "piffig",
    "piffigaste": "piffig",
    "piffigastes": "piffig",
    "piffigasts": "piffig",
    "piffige": "piffig",
    "piffiges": "piffig",
    "piffigheten": "piffighet",
    "piffighetens": "piffighet",
    "piffighets": "piffighet",
    "piffigs": "piffig",
    "piffigt": "piffig",
    "piffigts": "piffig",
    "piffs": "piff",
    "pig": "piga",
    "pigan": "piga",
    "pigans": "piga",
    "pigas": "piga",
    "pigdebatten": "pigdebatt",
    "pigdebattens": "pigdebatt",
    "pigdebatter": "pigdebatt",
    "pigdebatterna": "pigdebatt",
    "pigdebatternas": "pigdebatt",
    "pigdebatters": "pigdebatt",
    "pigdebatts": "pigdebatt",
    "pige": "piga",
    "pigga": "pigg",
    "piggar": "pigg",
    "piggare": "pigg",
    "piggares": "pigg",
    "piggarna": "pigg",
    "piggarnas": "pigg",
    "piggars": "pigg",
    "piggas": "pigg",
    "piggast": "pigg",
    "piggaste": "pigg",
    "piggastes": "pigg",
    "piggasts": "pigg",
    "pigge": "pigg",
    "piggen": "pigg",
    "piggens": "pigg",
    "pigges": "pigg",
    "pigghajar": "pigghaj",
    "pigghajarna": "pigghaj",
    "pigghajarnas": "pigghaj",
    "pigghajars": "pigghaj",
    "pigghajen": "pigghaj",
    "pigghajens": "pigghaj",
    "pigghajs": "pigghaj",
    "piggheten": "pigghet",
    "pigghetens": "pigghet",
    "pigghets": "pigghet",
    "piggs": "pigg",
    "piggsvinen": "piggsvin",
    "piggsvinens": "piggsvin",
    "piggsvinet": "piggsvin",
    "piggsvinets": "piggsvin",
    "piggsvins": "piggsvin",
    "piggt": "pigg",
    "piggts": "pigg",
    "piggvarar": "piggvar",
    "piggvararna": "piggvar",
    "piggvararnas": "piggvar",
    "piggvarars": "piggvar",
    "piggvaren": "piggvar",
    "piggvarens": "piggvar",
    "piggvars": "piggvar",
    "pigmenten": "pigment",
    "pigmentens": "pigment",
    "pigmenterade": "pigmenterad",
    "pigmenterades": "pigmenterad",
    "pigmenterads": "pigmenterad",
    "pigmenterat": "pigmenterad",
    "pigmenterats": "pigmenterad",
    "pigmenteringar": "pigmentering",
    "pigmenteringarna": "pigmentering",
    "pigmenteringarnas": "pigmentering",
    "pigmenteringars": "pigmentering",
    "pigmenteringen": "pigmentering",
    "pigmenteringens": "pigmentering",
    "pigmenterings": "pigmentering",
    "pigmentet": "pigment",
    "pigmentets": "pigment",
    "pigments": "pigment",
    "pigor": "piga",
    "pigorna": "piga",
    "pigornas": "piga",
    "pigors": "piga",
    "pigromanen": "pigroman",
    "pigromanens": "pigroman",
    "pigromaner": "pigroman",
    "pigromanerna": "pigroman",
    "pigromanernas": "pigroman",
    "pigromaners": "pigroman",
    "pigromans": "pigroman",
    "pigs": "piga",
    "pigtittar": "pigtittare",
    "pigtittaren": "pigtittare",
    "pigtittarens": "pigtittare",
    "pigtittares": "pigtittare",
    "pigtittarna": "pigtittare",
    "pigtittarnas": "pigtittare",
    "pigtjusar": "pigtjusare",
    "pigtjusaren": "pigtjusare",
    "pigtjusarens": "pigtjusare",
    "pigtjusares": "pigtjusare",
    "pigtjusarna": "pigtjusare",
    "pigtjusarnas": "pigtjusare",
    "pik": "pika",
    "pikad": "pika",
    "pikade": "pika",
    "pikades": "pika",
    "pikadoren": "pikador",
    "pikadorens": "pikador",
    "pikadorer": "pikador",
    "pikadorerna": "pikador",
    "pikadorernas": "pikador",
    "pikadorers": "pikador",
    "pikadors": "pikador",
    "pikads": "pika",
    "pikande": "pika",
    "pikanden": "pikande",
    "pikandena": "pikande",
    "pikandenas": "pikande",
    "pikandens": "pikande",
    "pikandes": "pikande",
    "pikandet": "pikande",
    "pikandets": "pikande",
    "pikanta": "pikant",
    "pikantare": "pikant",
    "pikantares": "pikant",
    "pikantas": "pikant",
    "pikantast": "pikant",
    "pikantaste": "pikant",
    "pikantastes": "pikant",
    "pikantasts": "pikant",
    "pikante": "pikant",
    "pikanterier": "pikanteri",
    "pikanterierna": "pikanteri",
    "pikanteriernas": "pikanteri",
    "pikanteriers": "pikanteri",
    "pikanteriet": "pikanteri",
    "pikanteriets": "pikanteri",
    "pikanteris": "pikanteri",
    "pikanterit": "pikanteri",
    "pikanterits": "pikanteri",
    "pikantes": "pikant",
    "pikants": "pikant",
    "pikantsåsen": "pikantsås",
    "pikantsåsens": "pikantsås",
    "pikar": "pika",
    "pikaresken": "pikaresk",
    "pikareskens": "pikaresk",
    "pikaresker": "pikaresk",
    "pikareskerna": "pikaresk",
    "pikareskernas": "pikaresk",
    "pikareskers": "pikaresk",
    "pikareskromanen": "pikareskroman",
    "pikareskromanens": "pikareskroman",
    "pikareskromaner": "pikareskroman",
    "pikareskromanerna": "pikareskroman",
    "pikareskromanernas": "pikareskroman",
    "pikareskromaners": "pikareskroman",
    "pikareskromans": "pikareskroman",
    "pikaresks": "pikaresk",
    "pikarna": "pik",
    "pikarnas": "pik",
    "pikars": "pik",
    "pikas": "pika",
    "pikat": "pika",
    "pikats": "pika",
    "piken": "pik",
    "pikens": "pik",
    "pikerad": "pikera",
    "pikerade": "pikera",
    "pikerades": "pikera",
    "pikerads": "pikera",
    "pikerande": "pikera",
    "pikeranden": "pikerande",
    "pikerandena": "pikerande",
    "pikerandenas": "pikerande",
    "pikerandens": "pikerande",
    "pikerandes": "pikerande",
    "pikerandet": "pikerande",
    "pikerandets": "pikerande",
    "pikerar": "pikera",
    "pikeras": "pikera",
    "pikerat": "pikera",
    "pikerats": "pikera",
    "pikerbara": "pikerbar",
    "pikerbarare": "pikerbar",
    "pikerbarares": "pikerbar",
    "pikerbaras": "pikerbar",
    "pikerbarast": "pikerbar",
    "pikerbaraste": "pikerbar",
    "pikerbarastes": "pikerbar",
    "pikerbarasts": "pikerbar",
    "pikerbare": "pikerbar",
    "pikerbares": "pikerbar",
    "pikerbarheten": "pikerbarhet",
    "pikerbarhetens": "pikerbarhet",
    "pikerbarhets": "pikerbarhet",
    "pikerbars": "pikerbar",
    "pikerbart": "pikerbar",
    "pikerbarts": "pikerbar",
    "pikeringar": "pikering",
    "pikeringarna": "pikering",
    "pikeringarnas": "pikering",
    "pikeringars": "pikering",
    "pikeringen": "pikering",
    "pikeringens": "pikering",
    "pikerings": "pikering",
    "piketbilar": "piketbil",
    "piketbilarna": "piketbil",
    "piketbilarnas": "piketbil",
    "piketbilars": "piketbil",
    "piketbilen": "piketbil",
    "piketbilens": "piketbil",
    "piketbils": "piketbil",
    "piketen": "piket",
    "piketens": "piket",
    "piketer": "piket",
    "piketerna": "piket",
    "piketernas": "piket",
    "piketers": "piket",
    "pikets": "piket",
    "pikhack": "pikhacka",
    "pikhackan": "pikhacka",
    "pikhackans": "pikhacka",
    "pikhackas": "pikhacka",
    "pikhacke": "pikhacka",
    "pikhackor": "pikhacka",
    "pikhackorna": "pikhacka",
    "pikhackornas": "pikhacka",
    "pikhackors": "pikhacka",
    "pikhacks": "pikhacka",
    "pikkadollen": "pikkadoll",
    "pikkadollens": "pikkadoll",
    "pikkadoller": "pikkadoll",
    "pikkadollerna": "pikkadoll",
    "pikkadollernas": "pikkadoll",
    "pikkadollers": "pikkadoll",
    "pikkadolls": "pikkadoll",
    "pikrinsyran": "pikrinsyra",
    "pikrinsyrans": "pikrinsyra",
    "pikrinsyras": "pikrinsyra",
    "pikrinsyre": "pikrinsyra",
    "piks": "pik",
    "pikstavar": "pikstav",
    "pikstavarna": "pikstav",
    "pikstavarnas": "pikstav",
    "pikstavars": "pikstav",
    "pikstaven": "pikstav",
    "pikstavens": "pikstav",
    "pikstavs": "pikstav",
    "pikturen": "piktur",
    "pikturens": "piktur",
    "pikturer": "piktur",
    "pikturerna": "piktur",
    "pikturernas": "piktur",
    "pikturers": "piktur",
    "pikturs": "piktur",
    "pikyx": "pikyxa",
    "pikyxan": "pikyxa",
    "pikyxans": "pikyxa",
    "pikyxas": "pikyxa",
    "pikyxe": "pikyxa",
    "pikyxor": "pikyxa",
    "pikyxorna": "pikyxa",
    "pikyxornas": "pikyxa",
    "pikyxors": "pikyxa",
    "pikéer": "piké",
    "pikéerna": "piké",
    "pikéernas": "piké",
    "pikéers": "piké",
    "pikén": "piké",
    "pikéns": "piké",
    "pikés": "piké",
    "pikören": "pikör",
    "pikörens": "pikör",
    "pikörer": "pikör",
    "pikörerna": "pikör",
    "pikörernas": "pikör",
    "pikörers": "pikör",
    "pikörs": "pikör",
    "pilade": "pila",
    "pilades": "pila",
    "pilaffen": "pilaff",
    "pilaffens": "pilaff",
    "pilaffer": "pilaff",
    "pilafferna": "pilaff",
    "pilaffernas": "pilaff",
    "pilaffers": "pilaff",
    "pilaffs": "pilaff",
    "pilande": "pila",
    "pilanden": "pilande",
    "pilandena": "pilande",
    "pilandenas": "pilande",
    "pilandens": "pilande",
    "pilandes": "pilande",
    "pilandet": "pilande",
    "pilandets": "pilande",
    "pilar": "pila",
    "pilarna": "pil",
    "pilarnas": "pil",
    "pilars": "pil",
    "pilas": "pila",
    "pilastern": "pilaster",
    "pilasterns": "pilaster",
    "pilasters": "pilaster",
    "pilastrar": "pilaster",
    "pilastrarna": "pilaster",
    "pilastrarnas": "pilaster",
    "pilastrars": "pilaster",
    "pilat": "pila",
    "pilats": "pila",
    "pilbåg": "pilbåge",
    "pilbågar": "pilbåge",
    "pilbågarna": "pilbåge",
    "pilbågarnas": "pilbåge",
    "pilbågars": "pilbåge",
    "pilbågen": "pilbåge",
    "pilbågens": "pilbåge",
    "pilbåges": "pilbåge",
    "pilbågs": "pilbåge",
    "pilen": "pil",
    "pilens": "pil",
    "pilfinkar": "pilfink",
    "pilfinkarna": "pilfink",
    "pilfinkarnas": "pilfink",
    "pilfinkars": "pilfink",
    "pilfinken": "pilfink",
    "pilfinkens": "pilfink",
    "pilfinks": "pilfink",
    "pilgiftet": "pilgift",
    "pilgiftets": "pilgift",
    "pilgifts": "pilgift",
    "pilgrimen": "pilgrim",
    "pilgrimens": "pilgrim",
    "pilgrimer": "pilgrim",
    "pilgrimerna": "pilgrim",
    "pilgrimernas": "pilgrim",
    "pilgrimers": "pilgrim",
    "pilgrims": "pilgrim",
    "pilgrimsfalkar": "pilgrimsfalk",
    "pilgrimsfalkarna": "pilgrimsfalk",
    "pilgrimsfalkarnas": "pilgrimsfalk",
    "pilgrimsfalkars": "pilgrimsfalk",
    "pilgrimsfalken": "pilgrimsfalk",
    "pilgrimsfalkens": "pilgrimsfalk",
    "pilgrimsfalks": "pilgrimsfalk",
    "pilgrimsfärden": "pilgrimsfärd",
    "pilgrimsfärdens": "pilgrimsfärd",
    "pilgrimsfärder": "pilgrimsfärd",
    "pilgrimsfärderna": "pilgrimsfärd",
    "pilgrimsfärdernas": "pilgrimsfärd",
    "pilgrimsfärders": "pilgrimsfärd",
    "pilgrimsfärds": "pilgrimsfärd",
    "pilgrimsstavar": "pilgrimsstav",
    "pilgrimsstavarna": "pilgrimsstav",
    "pilgrimsstavarnas": "pilgrimsstav",
    "pilgrimsstavars": "pilgrimsstav",
    "pilgrimsstaven": "pilgrimsstav",
    "pilgrimsstavens": "pilgrimsstav",
    "pilgrimsstavs": "pilgrimsstav",
    "pilk": "pilka",
    "pilkad": "pilka",
    "pilkade": "pilka",
    "pilkades": "pilka",
    "pilkads": "pilka",
    "pilkande": "pilka",
    "pilkanden": "pilkande",
    "pilkandena": "pilkande",
    "pilkandenas": "pilkande",
    "pilkandens": "pilkande",
    "pilkandes": "pilkande",
    "pilkandet": "pilkande",
    "pilkandets": "pilkande",
    "pilkar": "pilka",
    "pilkarna": "pilk",
    "pilkarnas": "pilk",
    "pilkars": "pilk",
    "pilkas": "pilka",
    "pilkastningar": "pilkastning",
    "pilkastningarna": "pilkastning",
    "pilkastningarnas": "pilkastning",
    "pilkastningars": "pilkastning",
    "pilkastningen": "pilkastning",
    "pilkastningens": "pilkastning",
    "pilkastnings": "pilkastning",
    "pilkat": "pilka",
    "pilkats": "pilka",
    "pilken": "pilk",
    "pilkens": "pilk",
    "pilkogerna": "pilkoger",
    "pilkogernas": "pilkoger",
    "pilkogers": "pilkoger",
    "pilkogren": "pilkoger",
    "pilkogrens": "pilkoger",
    "pilkogret": "pilkoger",
    "pilkogrets": "pilkoger",
    "pilks": "pilk",
    "pill": "pilla",
    "pillade": "pilla",
    "pillades": "pilla",
    "pillande": "pilla",
    "pillanden": "pillande",
    "pillandena": "pillande",
    "pillandenas": "pillande",
    "pillandens": "pillande",
    "pillandes": "pillande",
    "pillandet": "pillande",
    "pillandets": "pillande",
    "pillar": "pilla",
    "pillas": "pilla",
    "pillat": "pilla",
    "pillats": "pilla",
    "pilleknarkar": "pilleknarkare",
    "pilleknarkaren": "pilleknarkare",
    "pilleknarkarens": "pilleknarkare",
    "pilleknarkares": "pilleknarkare",
    "pilleknarkarna": "pilleknarkare",
    "pilleknarkarnas": "pilleknarkare",
    "pillemariska": "pillemarisk",
    "pillemariskare": "pillemarisk",
    "pillemariskares": "pillemarisk",
    "pillemariskas": "pillemarisk",
    "pillemariskast": "pillemarisk",
    "pillemariskaste": "pillemarisk",
    "pillemariskastes": "pillemarisk",
    "pillemariskasts": "pillemarisk",
    "pillemariske": "pillemarisk",
    "pillemariskes": "pillemarisk",
    "pillemarisks": "pillemarisk",
    "pillemariskt": "pillemarisk",
    "pillemariskts": "pillemarisk",
    "piller": "pillra",
    "pillerbagg": "pillerbagge",
    "pillerbaggar": "pillerbagge",
    "pillerbaggarna": "pillerbagge",
    "pillerbaggarnas": "pillerbagge",
    "pillerbaggars": "pillerbagge",
    "pillerbaggen": "pillerbagge",
    "pillerbaggens": "pillerbagge",
    "pillerbagges": "pillerbagge",
    "pillerbaggs": "pillerbagge",
    "pillerburkar": "pillerburk",
    "pillerburkarna": "pillerburk",
    "pillerburkarnas": "pillerburk",
    "pillerburkars": "pillerburk",
    "pillerburken": "pillerburk",
    "pillerburkens": "pillerburk",
    "pillerburks": "pillerburk",
    "pillerna": "piller",
    "pillernas": "piller",
    "pillers": "piller",
    "pillertrillar": "pillertrillare",
    "pillertrillaren": "pillertrillare",
    "pillertrillarens": "pillertrillare",
    "pillertrillares": "pillertrillare",
    "pillertrillarna": "pillertrillare",
    "pillertrillarnas": "pillertrillare",
    "pillet": "pill",
    "pillets": "pill",
    "pillrade": "pillra",
    "pillrades": "pillra",
    "pillrande": "pillra",
    "pillranden": "pillrande",
    "pillrandena": "pillrande",
    "pillrandenas": "pillrande",
    "pillrandens": "pillrande",
    "pillrandes": "pillrande",
    "pillrandet": "pillrande",
    "pillrandets": "pillrande",
    "pillrar": "pillra",
    "pillras": "pillra",
    "pillrat": "pillra",
    "pillrats": "pillra",
    "pillren": "piller",
    "pillrens": "piller",
    "pillret": "piller",
    "pillrets": "piller",
    "pillriga": "pillrig",
    "pillrigare": "pillrig",
    "pillrigares": "pillrig",
    "pillrigas": "pillrig",
    "pillrigast": "pillrig",
    "pillrigaste": "pillrig",
    "pillrigastes": "pillrig",
    "pillrigasts": "pillrig",
    "pillrige": "pillrig",
    "pillriges": "pillrig",
    "pillrigheten": "pillrighet",
    "pillrighetens": "pillrighet",
    "pillrighets": "pillrighet",
    "pillrigs": "pillrig",
    "pillrigt": "pillrig",
    "pillrigts": "pillrig",
    "pills": "pill",
    "pilotballongen": "pilotballong",
    "pilotballongens": "pilotballong",
    "pilotballonger": "pilotballong",
    "pilotballongerna": "pilotballong",
    "pilotballongernas": "pilotballong",
    "pilotballongers": "pilotballong",
    "pilotballongs": "pilotballong",
    "piloten": "pilot",
    "pilotens": "pilot",
    "piloter": "pilot",
    "piloterna": "pilot",
    "piloternas": "pilot",
    "piloters": "pilot",
    "pilotfallen": "pilotfall",
    "pilotfallens": "pilotfall",
    "pilotfallet": "pilotfall",
    "pilotfallets": "pilotfall",
    "pilotfalls": "pilotfall",
    "pilotjack": "pilotjacka",
    "pilotjackan": "pilotjacka",
    "pilotjackans": "pilotjacka",
    "pilotjackas": "pilotjacka",
    "pilotjacke": "pilotjacka",
    "pilotjackor": "pilotjacka",
    "pilotjackorna": "pilotjacka",
    "pilotjackornas": "pilotjacka",
    "pilotjackors": "pilotjacka",
    "pilotjacks": "pilotjacka",
    "pilots": "pilot",
    "pilotstrejken": "pilotstrejk",
    "pilotstrejkens": "pilotstrejk",
    "pilotstrejker": "pilotstrejk",
    "pilotstrejkerna": "pilotstrejk",
    "pilotstrejkernas": "pilotstrejk",
    "pilotstrejkers": "pilotstrejk",
    "pilotstrejks": "pilotstrejk",
    "pilotstudien": "pilotstudie",
    "pilotstudiens": "pilotstudie",
    "pilotstudier": "pilotstudie",
    "pilotstudierna": "pilotstudie",
    "pilotstudiernas": "pilotstudie",
    "pilotstudiers": "pilotstudie",
    "pilotstudies": "pilotstudie",
    "pilotundersökningar": "pilotundersökning",
    "pilotundersökningarna": "pilotundersökning",
    "pilotundersökningarnas": "pilotundersökning",
    "pilotundersökningars": "pilotundersökning",
    "pilotundersökningen": "pilotundersökning",
    "pilotundersökningens": "pilotundersökning",
    "pilotundersöknings": "pilotundersökning",
    "pils": "pil",
    "pilska": "pilsk",
    "pilskare": "pilsk",
    "pilskares": "pilsk",
    "pilskas": "pilsk",
    "pilskast": "pilsk",
    "pilskaste": "pilsk",
    "pilskastes": "pilsk",
    "pilskasts": "pilsk",
    "pilske": "pilsk",
    "pilskes": "pilsk",
    "pilskheten": "pilskhet",
    "pilskhetens": "pilskhet",
    "pilskhets": "pilskhet",
    "pilsks": "pilsk",
    "pilskt": "pilsk",
    "pilskts": "pilsk",
    "pilsnabba": "pilsnabb",
    "pilsnabbare": "pilsnabb",
    "pilsnabbares": "pilsnabb",
    "pilsnabbas": "pilsnabb",
    "pilsnabbast": "pilsnabb",
    "pilsnabbaste": "pilsnabb",
    "pilsnabbastes": "pilsnabb",
    "pilsnabbasts": "pilsnabb",
    "pilsnabbe": "pilsnabb",
    "pilsnabbes": "pilsnabb",
    "pilsnabbheten": "pilsnabbhet",
    "pilsnabbhetens": "pilsnabbhet",
    "pilsnabbhets": "pilsnabbhet",
    "pilsnabbs": "pilsnabb",
    "pilsnabbt": "pilsnabb",
    "pilsnabbts": "pilsnabb",
    "pilsnerfilmen": "pilsnerfilm",
    "pilsnerfilmens": "pilsnerfilm",
    "pilsnerfilmer": "pilsnerfilm",
    "pilsnerfilmerna": "pilsnerfilm",
    "pilsnerfilmernas": "pilsnerfilm",
    "pilsnerfilmers": "pilsnerfilm",
    "pilsnerfilms": "pilsnerfilm",
    "pilsnerflask": "pilsnerflaska",
    "pilsnerflaskan": "pilsnerflaska",
    "pilsnerflaskans": "pilsnerflaska",
    "pilsnerflaskas": "pilsnerflaska",
    "pilsnerflaske": "pilsnerflaska",
    "pilsnerflaskor": "pilsnerflaska",
    "pilsnerflaskorna": "pilsnerflaska",
    "pilsnerflaskornas": "pilsnerflaska",
    "pilsnerflaskors": "pilsnerflaska",
    "pilsnerkorvar": "pilsnerkorv",
    "pilsnerkorvarna": "pilsnerkorv",
    "pilsnerkorvarnas": "pilsnerkorv",
    "pilsnerkorvars": "pilsnerkorv",
    "pilsnerkorven": "pilsnerkorv",
    "pilsnerkorvens": "pilsnerkorv",
    "pilsnerkorvs": "pilsnerkorv",
    "pilsnern": "pilsner",
    "pilsnerna": "pilsner",
    "pilsnernas": "pilsner",
    "pilsnerns": "pilsner",
    "pilsners": "pilsner",
    "pilspetsar": "pilspets",
    "pilspetsarna": "pilspets",
    "pilspetsarnas": "pilspets",
    "pilspetsars": "pilspets",
    "pilspetsen": "pilspets",
    "pilspetsens": "pilspets",
    "piltar": "pilt",
    "piltarna": "pilt",
    "piltarnas": "pilt",
    "piltars": "pilt",
    "pilten": "pilt",
    "piltens": "pilt",
    "pilträden": "pilträd",
    "pilträdens": "pilträd",
    "pilträdet": "pilträd",
    "pilträdets": "pilträd",
    "pilträds": "pilträd",
    "pilts": "pilt",
    "pilörten": "pilört",
    "pilörtens": "pilört",
    "pilörts": "pilört",
    "pimp": "pimpa",
    "pimpad": "pimpa",
    "pimpade": "pimpa",
    "pimpades": "pimpa",
    "pimpads": "pimpa",
    "pimpande": "pimpa",
    "pimpanden": "pimpande",
    "pimpandena": "pimpande",
    "pimpandenas": "pimpande",
    "pimpandens": "pimpande",
    "pimpandes": "pimpande",
    "pimpandet": "pimpande",
    "pimpandets": "pimpande",
    "pimpar": "pimpa",
    "pimpas": "pimpa",
    "pimpat": "pimpa",
    "pimpats": "pimpa",
    "pimpel": "pimpla",
    "pimpelfiskes": "pimpelfiske",
    "pimpelfisket": "pimpelfiske",
    "pimpelfiskets": "pimpelfiske",
    "pimpeln": "pimpel",
    "pimpelns": "pimpel",
    "pimpels": "pimpel",
    "pimpelspöet": "pimpelspö",
    "pimpelspöets": "pimpelspö",
    "pimpelspön": "pimpelspö",
    "pimpelspöna": "pimpelspö",
    "pimpelspönas": "pimpelspö",
    "pimpelspöns": "pimpelspö",
    "pimpelspös": "pimpelspö",
    "pimpelspöt": "pimpelspö",
    "pimpelspöts": "pimpelspö",
    "pimpinell": "pimpinella",
    "pimpinellan": "pimpinella",
    "pimpinellans": "pimpinella",
    "pimpinellas": "pimpinella",
    "pimpinelle": "pimpinella",
    "pimpinellor": "pimpinella",
    "pimpinellorna": "pimpinella",
    "pimpinellornas": "pimpinella",
    "pimpinellors": "pimpinella",
    "pimpinells": "pimpinella",
    "pimpinetta": "pimpinett",
    "pimpinettare": "pimpinett",
    "pimpinettares": "pimpinett",
    "pimpinettas": "pimpinett",
    "pimpinettast": "pimpinett",
    "pimpinettaste": "pimpinett",
    "pimpinettastes": "pimpinett",
    "pimpinettasts": "pimpinett",
    "pimpinette": "pimpinett",
    "pimpinettes": "pimpinett",
    "pimpinettheten": "pimpinetthet",
    "pimpinetthetens": "pimpinetthet",
    "pimpinetthets": "pimpinetthet",
    "pimpinetts": "pimpinett",
    "pimplad": "pimpla",
    "pimplade": "pimpla",
    "pimplades": "pimpla",
    "pimplads": "pimpla",
    "pimplande": "pimpla",
    "pimplanden": "pimplande",
    "pimplandena": "pimplande",
    "pimplandenas": "pimplande",
    "pimplandens": "pimplande",
    "pimplandes": "pimplande",
    "pimplandet": "pimplande",
    "pimplandets": "pimplande",
    "pimplar": "pimpla",
    "pimplarna": "pimpel",
    "pimplarnas": "pimpel",
    "pimplars": "pimpel",
    "pimplas": "pimpla",
    "pimplat": "pimpla",
    "pimplats": "pimpla",
    "pimpstenen": "pimpsten",
    "pimpstenens": "pimpsten",
    "pimpstens": "pimpsten",
    "pin": "pina",
    "pina": "pi",
    "pinad": "pina",
    "pinade": "pina",
    "pinades": "pina",
    "pinads": "pina",
    "pinakoteken": "pinakotek",
    "pinakotekens": "pinakotek",
    "pinakoteket": "pinakotek",
    "pinakotekets": "pinakotek",
    "pinakoteks": "pinakotek",
    "pinalen": "pinal",
    "pinalens": "pinal",
    "pinaler": "pinal",
    "pinalerna": "pinal",
    "pinalernas": "pinal",
    "pinalers": "pinal",
    "pinals": "pinal",
    "pinan": "pina",
    "pinande": "pina",
    "pinanden": "pinande",
    "pinandena": "pinande",
    "pinandenas": "pinande",
    "pinandens": "pinande",
    "pinandes": "pinande",
    "pinandet": "pinande",
    "pinandets": "pinande",
    "pinans": "pina",
    "pinar": "pina",
    "pinas": "pina",
    "pinat": "pina",
    "pinats": "pina",
    "pincenéer": "pincené",
    "pincenéerna": "pincené",
    "pincenéernas": "pincené",
    "pincenéers": "pincené",
    "pincenén": "pincené",
    "pincenéns": "pincené",
    "pincenés": "pincené",
    "pincerad": "pincera",
    "pincerade": "pincera",
    "pincerades": "pincera",
    "pincerads": "pincera",
    "pincerande": "pincera",
    "pinceranden": "pincerande",
    "pincerandena": "pincerande",
    "pincerandenas": "pincerande",
    "pincerandens": "pincerande",
    "pincerandes": "pincerande",
    "pincerandet": "pincerande",
    "pincerandets": "pincerande",
    "pincerar": "pincera",
    "pinceras": "pincera",
    "pincerat": "pincera",
    "pincerats": "pincera",
    "pincerbara": "pincerbar",
    "pincerbarare": "pincerbar",
    "pincerbarares": "pincerbar",
    "pincerbaras": "pincerbar",
    "pincerbarast": "pincerbar",
    "pincerbaraste": "pincerbar",
    "pincerbarastes": "pincerbar",
    "pincerbarasts": "pincerbar",
    "pincerbare": "pincerbar",
    "pincerbares": "pincerbar",
    "pincerbarheten": "pincerbarhet",
    "pincerbarhetens": "pincerbarhet",
    "pincerbarhets": "pincerbarhet",
    "pincerbars": "pincerbar",
    "pincerbart": "pincerbar",
    "pincerbarts": "pincerbar",
    "pinceringar": "pincering",
    "pinceringarna": "pincering",
    "pinceringarnas": "pincering",
    "pinceringars": "pincering",
    "pinceringen": "pincering",
    "pinceringens": "pincering",
    "pincerings": "pincering",
    "pincetten": "pincett",
    "pincettens": "pincett",
    "pincetter": "pincett",
    "pincetterna": "pincett",
    "pincetternas": "pincett",
    "pincetters": "pincett",
    "pincetts": "pincett",
    "pine": "pina",
    "ping-pongbollar": "ping-pongboll",
    "ping-pongbollarna": "ping-pongboll",
    "ping-pongbollarnas": "ping-pongboll",
    "ping-pongbollars": "ping-pongboll",
    "ping-pongbollen": "ping-pongboll",
    "ping-pongbollens": "ping-pongboll",
    "ping-pongbolls": "ping-pongboll",
    "ping-pongen": "ping-pong",
    "ping-pongens": "ping-pong",
    "ping-pongs": "ping-pong",
    "pingel": "pingla",
    "pingels": "pingel",
    "pingisen": "pingis",
    "pingisens": "pingis",
    "pinglade": "pingla",
    "pinglades": "pingla",
    "pinglan": "pingla",
    "pinglande": "pingla",
    "pinglanden": "pinglande",
    "pinglandena": "pinglande",
    "pinglandenas": "pinglande",
    "pinglandens": "pinglande",
    "pinglandes": "pinglande",
    "pinglandet": "pinglande",
    "pinglandets": "pinglande",
    "pinglans": "pingla",
    "pinglar": "pingla",
    "pinglas": "pingla",
    "pinglat": "pingla",
    "pinglats": "pingla",
    "pingle": "pingla",
    "pinglet": "pingel",
    "pinglets": "pingel",
    "pinglor": "pingla",
    "pinglorna": "pingla",
    "pinglornas": "pingla",
    "pinglors": "pingla",
    "pingpongbollar": "pingpongboll",
    "pingpongbollarna": "pingpongboll",
    "pingpongbollarnas": "pingpongboll",
    "pingpongbollars": "pingpongboll",
    "pingpongbollen": "pingpongboll",
    "pingpongbollens": "pingpongboll",
    "pingpongbolls": "pingpongboll",
    "pingpongen": "pingpong",
    "pingpongens": "pingpong",
    "pingpongs": "pingpong",
    "pingstaftnar": "pingstafton",
    "pingstaftnarna": "pingstafton",
    "pingstaftnarnas": "pingstafton",
    "pingstaftnars": "pingstafton",
    "pingstaftonen": "pingstafton",
    "pingstaftonens": "pingstafton",
    "pingstaftons": "pingstafton",
    "pingstar": "pingst",
    "pingstarna": "pingst",
    "pingstarnas": "pingst",
    "pingstars": "pingst",
    "pingstdagar": "pingstdag",
    "pingstdagarna": "pingstdag",
    "pingstdagarnas": "pingstdag",
    "pingstdagars": "pingstdag",
    "pingstdagen": "pingstdag",
    "pingstdagens": "pingstdag",
    "pingstdags": "pingstdag",
    "pingsten": "pingst",
    "pingstens": "pingst",
    "pingsthelgen": "pingsthelg",
    "pingsthelgens": "pingsthelg",
    "pingsthelger": "pingsthelg",
    "pingsthelgerna": "pingsthelg",
    "pingsthelgernas": "pingsthelg",
    "pingsthelgers": "pingsthelg",
    "pingsthelgs": "pingsthelg",
    "pingstliljan": "pingstlilja",
    "pingstliljans": "pingstlilja",
    "pingstliljas": "pingstlilja",
    "pingstlilje": "pingstlilja",
    "pingstliljor": "pingstlilja",
    "pingstliljorna": "pingstlilja",
    "pingstliljornas": "pingstlilja",
    "pingstliljors": "pingstlilja",
    "pingströrelsen": "pingströrelse",
    "pingströrelsens": "pingströrelse",
    "pingströrelses": "pingströrelse",
    "pingsts": "pingst",
    "pingstvänliga": "pingstvänlig",
    "pingstvänligare": "pingstvänlig",
    "pingstvänligares": "pingstvänlig",
    "pingstvänligas": "pingstvänlig",
    "pingstvänligast": "pingstvänlig",
    "pingstvänligaste": "pingstvänlig",
    "pingstvänligastes": "pingstvänlig",
    "pingstvänligasts": "pingstvänlig",
    "pingstvänlige": "pingstvänlig",
    "pingstvänliges": "pingstvänlig",
    "pingstvänligheten": "pingstvänlighet",
    "pingstvänlighetens": "pingstvänlighet",
    "pingstvänlighets": "pingstvänlighet",
    "pingstvänligs": "pingstvänlig",
    "pingstvänligt": "pingstvänlig",
    "pingstvänligts": "pingstvänlig",
    "pingstvännen": "pingstvän",
    "pingstvännens": "pingstvän",
    "pingstvänner": "pingstvän",
    "pingstvännerna": "pingstvän",
    "pingstvännernas": "pingstvän",
    "pingstvänners": "pingstvän",
    "pingstväns": "pingstvän",
    "pingvinen": "pingvin",
    "pingvinens": "pingvin",
    "pingviner": "pingvin",
    "pingvinerna": "pingvin",
    "pingvinernas": "pingvin",
    "pingviners": "pingvin",
    "pingvins": "pingvin",
    "pingvinturisten": "pingvinturist",
    "pingvinturistens": "pingvinturist",
    "pingvinturister": "pingvinturist",
    "pingvinturisterna": "pingvinturist",
    "pingvinturisternas": "pingvinturist",
    "pingvinturisters": "pingvinturist",
    "pingvinturists": "pingvinturist",
    "pinjen": "pinje",
    "pinjens": "pinje",
    "pinjenöten": "pinjenöt",
    "pinjenötens": "pinjenöt",
    "pinjenöts": "pinjenöt",
    "pinjenötter": "pinjenöt",
    "pinjenötterna": "pinjenöt",
    "pinjenötternas": "pinjenöt",
    "pinjenötters": "pinjenöt",
    "pinjer": "pinje",
    "pinjerna": "pinje",
    "pinjernas": "pinje",
    "pinjers": "pinje",
    "pinjes": "pinje",
    "pinjongen": "pinjong",
    "pinjongens": "pinjong",
    "pinjonger": "pinjong",
    "pinjongerna": "pinjong",
    "pinjongernas": "pinjong",
    "pinjongers": "pinjong",
    "pinjongs": "pinjong",
    "pink": "pinka",
    "pinkade": "pinka",
    "pinkades": "pinka",
    "pinkande": "pinka",
    "pinkanden": "pinkande",
    "pinkandena": "pinkande",
    "pinkandenas": "pinkande",
    "pinkandens": "pinkande",
    "pinkandes": "pinkande",
    "pinkandet": "pinkande",
    "pinkandets": "pinkande",
    "pinkar": "pinka",
    "pinkas": "pinka",
    "pinkat": "pinka",
    "pinkats": "pinka",
    "pinknödiga": "pinknödig",
    "pinknödigare": "pinknödig",
    "pinknödigares": "pinknödig",
    "pinknödigas": "pinknödig",
    "pinknödigast": "pinknödig",
    "pinknödigaste": "pinknödig",
    "pinknödigastes": "pinknödig",
    "pinknödigasts": "pinknödig",
    "pinknödige": "pinknödig",
    "pinknödiges": "pinknödig",
    "pinknödigheten": "pinknödighet",
    "pinknödighetens": "pinknödighet",
    "pinknödighets": "pinknödighet",
    "pinknödigs": "pinknödig",
    "pinknödigt": "pinknödig",
    "pinknödigts": "pinknödig",
    "pinliga": "pinlig",
    "pinligare": "pinlig",
    "pinligares": "pinlig",
    "pinligas": "pinlig",
    "pinligast": "pinlig",
    "pinligaste": "pinlig",
    "pinligastes": "pinlig",
    "pinligasts": "pinlig",
    "pinlige": "pinlig",
    "pinliges": "pinlig",
    "pinligheten": "pinlighet",
    "pinlighetens": "pinlighet",
    "pinligheter": "pinlighet",
    "pinligheterna": "pinlighet",
    "pinligheternas": "pinlighet",
    "pinligheters": "pinlighet",
    "pinlighets": "pinlighet",
    "pinligs": "pinlig",
    "pinligt": "pinlig",
    "pinligts": "pinlig",
    "pinn": "pinne",
    "pinnad": "pinna",
    "pinnade": "pinna",
    "pinnades": "pinna",
    "pinnads": "pinna",
    "pinnande": "pinna",
    "pinnanden": "pinnande",
    "pinnandena": "pinnande",
    "pinnandenas": "pinnande",
    "pinnandens": "pinnande",
    "pinnandes": "pinnande",
    "pinnandet": "pinnande",
    "pinnandets": "pinnande",
    "pinnar": "pinne",
    "pinnarna": "pinne",
    "pinnarnas": "pinne",
    "pinnars": "pinne",
    "pinnas": "pinna",
    "pinnat": "pinna",
    "pinnats": "pinna",
    "pinnen": "pinne",
    "pinnens": "pinne",
    "pinnes": "pinne",
    "pinnharvar": "pinnharv",
    "pinnharvarna": "pinnharv",
    "pinnharvarnas": "pinnharv",
    "pinnharvars": "pinnharv",
    "pinnharven": "pinnharv",
    "pinnharvens": "pinnharv",
    "pinnharvs": "pinnharv",
    "pinnhålen": "pinnhål",
    "pinnhålens": "pinnhål",
    "pinnhålet": "pinnhål",
    "pinnhålets": "pinnhål",
    "pinnhåls": "pinnhål",
    "pinniga": "pinnig",
    "pinnigare": "pinnig",
    "pinnigares": "pinnig",
    "pinnigas": "pinnig",
    "pinnigast": "pinnig",
    "pinnigaste": "pinnig",
    "pinnigastes": "pinnig",
    "pinnigasts": "pinnig",
    "pinnige": "pinnig",
    "pinniges": "pinnig",
    "pinnigheten": "pinnighet",
    "pinnighetens": "pinnighet",
    "pinnighets": "pinnighet",
    "pinnigs": "pinnig",
    "pinnigt": "pinnig",
    "pinnigts": "pinnig",
    "pinnmon": "pinnmo",
    "pinnmons": "pinnmo",
    "pinnmos": "pinnmo",
    "pinns": "pinne",
    "pinnsoff": "pinnsoffa",
    "pinnsoffan": "pinnsoffa",
    "pinnsoffans": "pinnsoffa",
    "pinnsoffas": "pinnsoffa",
    "pinnsoffe": "pinnsoffa",
    "pinnsoffor": "pinnsoffa",
    "pinnsofforna": "pinnsoffa",
    "pinnsoffornas": "pinnsoffa",
    "pinnsoffors": "pinnsoffa",
    "pinnsoffs": "pinnsoffa",
    "pinnstolar": "pinnstol",
    "pinnstolarna": "pinnstol",
    "pinnstolarnas": "pinnstol",
    "pinnstolars": "pinnstol",
    "pinnstolen": "pinnstol",
    "pinnstolens": "pinnstol",
    "pinnstols": "pinnstol",
    "pinnveden": "pinnved",
    "pinnvedens": "pinnved",
    "pinnveds": "pinnved",
    "pinoandar": "pinoande",
    "pinoandarna": "pinoande",
    "pinoandarnas": "pinoande",
    "pinoandars": "pinoande",
    "pinoanden": "pinoande",
    "pinoandens": "pinoande",
    "pinoandes": "pinoande",
    "pinor": "pina",
    "pinorna": "pina",
    "pinornas": "pina",
    "pinors": "pina",
    "pinröken": "pinrök",
    "pinrökens": "pinrök",
    "pinröks": "pinrök",
    "pins": "pina",
    "pinsamheten": "pinsamhet",
    "pinsamhetens": "pinsamhet",
    "pinsamheter": "pinsamhet",
    "pinsamheterna": "pinsamhet",
    "pinsamheternas": "pinsamhet",
    "pinsamheters": "pinsamhet",
    "pinsamhets": "pinsamhet",
    "pinsamma": "pinsam",
    "pinsammare": "pinsam",
    "pinsammares": "pinsam",
    "pinsammas": "pinsam",
    "pinsammast": "pinsam",
    "pinsammaste": "pinsam",
    "pinsammastes": "pinsam",
    "pinsammasts": "pinsam",
    "pinsamme": "pinsam",
    "pinsammes": "pinsam",
    "pinsams": "pinsam",
    "pinsamt": "pinsam",
    "pinsamts": "pinsam",
    "pinschern": "pinscher",
    "pinscherns": "pinscher",
    "pinschers": "pinscher",
    "pinschrar": "pinscher",
    "pinschrarna": "pinscher",
    "pinschrarnas": "pinscher",
    "pinschrars": "pinscher",
    "pinupbilden": "pinupbild",
    "pinupbildens": "pinupbild",
    "pinupbilder": "pinupbild",
    "pinupbilderna": "pinupbild",
    "pinupbildernas": "pinupbild",
    "pinupbilders": "pinupbild",
    "pinupbilds": "pinupbild",
    "pinupp": "pinuppa",
    "pinuppan": "pinuppa",
    "pinuppans": "pinuppa",
    "pinuppas": "pinuppa",
    "pinuppe": "pinuppa",
    "pinuppor": "pinuppa",
    "pinupporna": "pinuppa",
    "pinuppornas": "pinuppa",
    "pinuppors": "pinuppa",
    "pinupps": "pinuppa",
    "pionen": "pion",
    "pionens": "pion",
    "pioner": "pion",
    "pionerna": "pion",
    "pionernas": "pion",
    "pioners": "pion",
    "pionjären": "pionjär",
    "pionjärens": "pionjär",
    "pionjärer": "pionjär",
    "pionjärerna": "pionjär",
    "pionjärernas": "pionjär",
    "pionjärers": "pionjär",
    "pionjärmässiga": "pionjärmässig",
    "pionjärmässigare": "pionjärmässig",
    "pionjärmässigares": "pionjärmässig",
    "pionjärmässigas": "pionjärmässig",
    "pionjärmässigast": "pionjärmässig",
    "pionjärmässigaste": "pionjärmässig",
    "pionjärmässigastes": "pionjärmässig",
    "pionjärmässigasts": "pionjärmässig",
    "pionjärmässige": "pionjärmässig",
    "pionjärmässiges": "pionjärmässig",
    "pionjärmässigs": "pionjärmässig",
    "pionjärmässigt": "pionjärmässig",
    "pionjärmässigts": "pionjärmässig",
    "pionjärs": "pionjär",
    "pionröda": "pionröd",
    "pionrödare": "pionröd",
    "pionrödares": "pionröd",
    "pionrödas": "pionröd",
    "pionrödast": "pionröd",
    "pionrödaste": "pionröd",
    "pionrödastes": "pionröd",
    "pionrödasts": "pionröd",
    "pionröde": "pionröd",
    "pionrödes": "pionröd",
    "pionröds": "pionröd",
    "pionrött": "pionröd",
    "pionrötts": "pionröd",
    "pions": "pion",
    "pip": "pipa",
    "pipan": "pipa",
    "pipande": "pipa",
    "pipanden": "pipande",
    "pipandena": "pipande",
    "pipandenas": "pipande",
    "pipandens": "pipande",
    "pipandes": "pipande",
    "pipandet": "pipande",
    "pipandets": "pipande",
    "pipans": "pipa",
    "pipar": "pipare",
    "piparen": "pipare",
    "piparens": "pipare",
    "pipares": "pipare",
    "piparna": "pipare",
    "piparnas": "pipare",
    "pipars": "pip",
    "pipas": "pipa",
    "pipe": "pipa",
    "pipelinen": "pipeline",
    "pipelinens": "pipeline",
    "pipeliner": "pipeline",
    "pipelinerna": "pipeline",
    "pipelinernas": "pipeline",
    "pipeliners": "pipeline",
    "pipelines": "pipeline",
    "pipelinesen": "pipeline",
    "pipelinesens": "pipeline",
    "pipen": "pip",
    "pipens": "pip",
    "piper": "pipa",
    "pipes": "pipa",
    "pipet": "pip",
    "pipets": "pip",
    "pipetten": "pipett",
    "pipettens": "pipett",
    "pipetter": "pipett",
    "pipetterna": "pipett",
    "pipetternas": "pipett",
    "pipetters": "pipett",
    "pipetts": "pipett",
    "piphasen": "piphas",
    "piphasens": "piphas",
    "piphuvuden": "piphuvud",
    "piphuvudena": "piphuvud",
    "piphuvudenas": "piphuvud",
    "piphuvudens": "piphuvud",
    "piphuvudet": "piphuvud",
    "piphuvudets": "piphuvud",
    "piphuvuds": "piphuvud",
    "pipiga": "pipig",
    "pipigare": "pipig",
    "pipigares": "pipig",
    "pipigas": "pipig",
    "pipigast": "pipig",
    "pipigaste": "pipig",
    "pipigastes": "pipig",
    "pipigasts": "pipig",
    "pipige": "pipig",
    "pipiges": "pipig",
    "pipigs": "pipig",
    "pipigt": "pipig",
    "pipigts": "pipig",
    "pipit": "pipa",
    "pipits": "pipa",
    "pipkrag": "pipkrage",
    "pipkragar": "pipkrage",
    "pipkragarna": "pipkrage",
    "pipkragarnas": "pipkrage",
    "pipkragars": "pipkrage",
    "pipkragen": "pipkrage",
    "pipkragens": "pipkrage",
    "pipkrages": "pipkrage",
    "pipkrags": "pipkrage",
    "piplängden": "piplängd",
    "piplängdens": "piplängd",
    "piplängder": "piplängd",
    "piplängderna": "piplängd",
    "piplängdernas": "piplängd",
    "piplängders": "piplängd",
    "piplängds": "piplängd",
    "piplärk": "piplärka",
    "piplärkan": "piplärka",
    "piplärkans": "piplärka",
    "piplärkas": "piplärka",
    "piplärke": "piplärka",
    "piplärkor": "piplärka",
    "piplärkorna": "piplärka",
    "piplärkornas": "piplärka",
    "piplärkors": "piplärka",
    "piplärks": "piplärka",
    "pipoljan": "pipolja",
    "pipoljans": "pipolja",
    "pipoljas": "pipolja",
    "pipolje": "pipolja",
    "pipor": "pipa",
    "piporna": "pipa",
    "pipornas": "pipa",
    "pipors": "pipa",
    "pipp": "pippa",
    "pippad": "pippa",
    "pippade": "pippa",
    "pippades": "pippa",
    "pippads": "pippa",
    "pippande": "pippa",
    "pippanden": "pippande",
    "pippandena": "pippande",
    "pippandenas": "pippande",
    "pippandens": "pippande",
    "pippandes": "pippande",
    "pippandet": "pippande",
    "pippandets": "pippande",
    "pippar": "pippa",
    "pippas": "pippa",
    "pippat": "pippa",
    "pippats": "pippa",
    "pippiar": "pippi",
    "pippiarna": "pippi",
    "pippiarnas": "pippi",
    "pippiars": "pippi",
    "pippin": "pippi",
    "pippingar": "pipping",
    "pippingarna": "pipping",
    "pippingarnas": "pipping",
    "pippingars": "pipping",
    "pippingen": "pipping",
    "pippingens": "pipping",
    "pippings": "pipping",
    "pippins": "pippi",
    "pippis": "pippi",
    "piprensar": "piprensare",
    "piprensaren": "piprensare",
    "piprensarens": "piprensare",
    "piprensares": "piprensare",
    "piprensarna": "piprensare",
    "piprensarnas": "piprensare",
    "piprökar": "piprökare",
    "piprökaren": "piprökare",
    "piprökarens": "piprökare",
    "piprökares": "piprökare",
    "piprökarna": "piprökare",
    "piprökarnas": "piprökare",
    "pips": "pipa",
    "pipskaften": "pipskaft",
    "pipskaftens": "pipskaft",
    "pipskaftet": "pipskaft",
    "pipskaftets": "pipskaft",
    "pipskafts": "pipskaft",
    "pipskäggen": "pipskägg",
    "pipskäggens": "pipskägg",
    "pipskägget": "pipskägg",
    "pipskäggets": "pipskägg",
    "pipskäggs": "pipskägg",
    "pipspännar": "pipspännare",
    "pipspännaren": "pipspännare",
    "pipspännarens": "pipspännare",
    "pipspännares": "pipspännare",
    "pipspännarna": "pipspännare",
    "pipspännarnas": "pipspännare",
    "pipstoppar": "pipstoppare",
    "pipstopparen": "pipstoppare",
    "pipstopparens": "pipstoppare",
    "pipstoppares": "pipstoppare",
    "pipstopparna": "pipstoppare",
    "pipstopparnas": "pipstoppare",
    "pipstoppars": "pipstopp",
    "pipstoppen": "pipstopp",
    "pipstoppens": "pipstopp",
    "pipstoppet": "pipstopp",
    "pipstoppets": "pipstopp",
    "pipstopps": "pipstopp",
    "pipsvampar": "pipsvamp",
    "pipsvamparna": "pipsvamp",
    "pipsvamparnas": "pipsvamp",
    "pipsvampars": "pipsvamp",
    "pipsvampen": "pipsvamp",
    "pipsvampens": "pipsvamp",
    "pipsvamps": "pipsvamp",
    "piptobaken": "piptobak",
    "piptobakens": "piptobak",
    "piptobaks": "piptobak",
    "pipverket": "pipverk",
    "pipverkets": "pipverk",
    "pipverks": "pipverk",
    "pirar": "pir",
    "pirarna": "pir",
    "pirarnas": "pir",
    "pirars": "pir",
    "piratbyx": "piratbyxa",
    "piratbyxan": "piratbyxa",
    "piratbyxans": "piratbyxa",
    "piratbyxas": "piratbyxa",
    "piratbyxe": "piratbyxa",
    "piratbyxor": "piratbyxa",
    "piratbyxorna": "piratbyxa",
    "piratbyxornas": "piratbyxa",
    "piratbyxors": "piratbyxa",
    "piraten": "pirat",
    "piratens": "pirat",
    "pirater": "pirat",
    "piraterna": "pirat",
    "piraternas": "pirat",
    "piraters": "pirat",
    "pirats": "pirat",
    "piratsändar": "piratsändare",
    "piratsändaren": "piratsändare",
    "piratsändarens": "piratsändare",
    "piratsändares": "piratsändare",
    "piratsändarna": "piratsändare",
    "piratsändarnas": "piratsändare",
    "piray": "piraya",
    "pirayan": "piraya",
    "pirayans": "piraya",
    "pirayas": "piraya",
    "piraye": "piraya",
    "pirayor": "piraya",
    "pirayorna": "piraya",
    "pirayornas": "piraya",
    "pirayors": "piraya",
    "pirays": "piraya",
    "piren": "pir",
    "pirens": "pir",
    "pirer": "pir",
    "pirerna": "pir",
    "pirernas": "pir",
    "pirers": "pir",
    "pirhuvuden": "pirhuvud",
    "pirhuvudena": "pirhuvud",
    "pirhuvudenas": "pirhuvud",
    "pirhuvudens": "pirhuvud",
    "pirhuvudet": "pirhuvud",
    "pirhuvudets": "pirhuvud",
    "pirhuvuds": "pirhuvud",
    "pirk": "pirka",
    "pirkad": "pirka",
    "pirkade": "pirka",
    "pirkades": "pirka",
    "pirkads": "pirka",
    "pirkan": "pirka",
    "pirkande": "pirka",
    "pirkanden": "pirkande",
    "pirkandena": "pirkande",
    "pirkandenas": "pirkande",
    "pirkandens": "pirkande",
    "pirkandes": "pirkande",
    "pirkandet": "pirkande",
    "pirkandets": "pirkande",
    "pirkans": "pirka",
    "pirkar": "pirka",
    "pirkarna": "pirk",
    "pirkarnas": "pirk",
    "pirkars": "pirk",
    "pirkas": "pirka",
    "pirkat": "pirka",
    "pirkats": "pirka",
    "pirke": "pirka",
    "pirken": "pirk",
    "pirkens": "pirk",
    "pirkor": "pirka",
    "pirkorna": "pirka",
    "pirkornas": "pirka",
    "pirkors": "pirka",
    "pirks": "pirka",
    "pirogen": "pirog",
    "pirogens": "pirog",
    "piroger": "pirog",
    "pirogerna": "pirog",
    "pirogernas": "pirog",
    "pirogers": "pirog",
    "pirogs": "pirog",
    "pirr": "pirra",
    "pirrade": "pirra",
    "pirrades": "pirra",
    "pirran": "pirra",
    "pirrande": "pirra",
    "pirranden": "pirrande",
    "pirrandena": "pirrande",
    "pirrandenas": "pirrande",
    "pirrandens": "pirrande",
    "pirrandes": "pirrande",
    "pirrandet": "pirrande",
    "pirrandets": "pirrande",
    "pirrans": "pirra",
    "pirrar": "pirra",
    "pirras": "pirra",
    "pirrat": "pirra",
    "pirrats": "pirra",
    "pirre": "pirra",
    "pirriga": "pirrig",
    "pirrigare": "pirrig",
    "pirrigares": "pirrig",
    "pirrigas": "pirrig",
    "pirrigast": "pirrig",
    "pirrigaste": "pirrig",
    "pirrigastes": "pirrig",
    "pirrigasts": "pirrig",
    "pirrige": "pirrig",
    "pirriges": "pirrig",
    "pirrigheten": "pirrighet",
    "pirrighetens": "pirrighet",
    "pirrighets": "pirrighet",
    "pirrigs": "pirrig",
    "pirrigt": "pirrig",
    "pirrigts": "pirrig",
    "pirror": "pirra",
    "pirrorna": "pirra",
    "pirrornas": "pirra",
    "pirrors": "pirra",
    "pirrs": "pirra",
    "pirs": "pir",
    "piruetten": "piruett",
    "piruettens": "piruett",
    "piruetter": "piruett",
    "piruetterade": "piruettera",
    "piruetterades": "piruettera",
    "piruetterande": "piruettera",
    "piruetteranden": "piruetterande",
    "piruetterandena": "piruetterande",
    "piruetterandenas": "piruetterande",
    "piruetterandens": "piruetterande",
    "piruetterandes": "piruetterande",
    "piruetterandet": "piruetterande",
    "piruetterandets": "piruetterande",
    "piruetterar": "piruettera",
    "piruetteras": "piruettera",
    "piruetterat": "piruettera",
    "piruetterats": "piruettera",
    "piruetteringar": "piruettering",
    "piruetteringarna": "piruettering",
    "piruetteringarnas": "piruettering",
    "piruetteringars": "piruettering",
    "piruetteringen": "piruettering",
    "piruetteringens": "piruettering",
    "piruetterings": "piruettering",
    "piruetterna": "piruett",
    "piruetternas": "piruett",
    "piruetters": "piruett",
    "piruetts": "piruett",
    "pis": "pi",
    "pisk": "piska",
    "piskad": "piska",
    "piskade": "piskad",
    "piskades": "piskad",
    "piskads": "piskad",
    "piskan": "piska",
    "piskande": "piska",
    "piskanden": "piskande",
    "piskandena": "piskande",
    "piskandenas": "piskande",
    "piskandens": "piskande",
    "piskandes": "piskande",
    "piskandet": "piskande",
    "piskandets": "piskande",
    "piskans": "piska",
    "piskar": "piska",
    "piskas": "piska",
    "piskat": "piskad",
    "piskats": "piskad",
    "piskbalkongen": "piskbalkong",
    "piskbalkongens": "piskbalkong",
    "piskbalkonger": "piskbalkong",
    "piskbalkongerna": "piskbalkong",
    "piskbalkongernas": "piskbalkong",
    "piskbalkongers": "piskbalkong",
    "piskbalkongs": "piskbalkong",
    "piske": "piska",
    "pisket": "pisk",
    "piskets": "pisk",
    "piskklatschar": "piskklatsch",
    "piskklatscharna": "piskklatsch",
    "piskklatscharnas": "piskklatsch",
    "piskklatschars": "piskklatsch",
    "piskklatschen": "piskklatsch",
    "piskklatschens": "piskklatsch",
    "piskklatschs": "piskklatsch",
    "piskmaskar": "piskmask",
    "piskmaskarna": "piskmask",
    "piskmaskarnas": "piskmask",
    "piskmaskars": "piskmask",
    "piskmasken": "piskmask",
    "piskmaskens": "piskmask",
    "piskmasks": "piskmask",
    "piskor": "piska",
    "piskorna": "piska",
    "piskornas": "piska",
    "piskors": "piska",
    "piskperuken": "piskperuk",
    "piskperukens": "piskperuk",
    "piskperuker": "piskperuk",
    "piskperukerna": "piskperuk",
    "piskperukernas": "piskperuk",
    "piskperukers": "piskperuk",
    "piskperuks": "piskperuk",
    "piskrappen": "piskrapp",
    "piskrappens": "piskrapp",
    "piskrappet": "piskrapp",
    "piskrappets": "piskrapp",
    "piskrapps": "piskrapp",
    "pisks": "pisk",
    "piskslängar": "pisksläng",
    "piskslängarna": "pisksläng",
    "piskslängarnas": "pisksläng",
    "piskslängars": "pisksläng",
    "piskslängen": "pisksläng",
    "piskslängens": "pisksläng",
    "piskslängs": "pisksläng",
    "pisksnärtar": "pisksnärt",
    "pisksnärtarna": "pisksnärt",
    "pisksnärtarnas": "pisksnärt",
    "pisksnärtars": "pisksnärt",
    "pisksnärten": "pisksnärt",
    "pisksnärtens": "pisksnärt",
    "pisksnärtoperationen": "pisksnärtoperation",
    "pisksnärtoperationens": "pisksnärtoperation",
    "pisksnärtoperationer": "pisksnärtoperation",
    "pisksnärtoperationerna": "pisksnärtoperation",
    "pisksnärtoperationernas": "pisksnärtoperation",
    "pisksnärtoperationers": "pisksnärtoperation",
    "pisksnärtoperations": "pisksnärtoperation",
    "pisksnärts": "pisksnärt",
    "pisksnärtskadade": "pisksnärtskadad",
    "pisksnärtskadades": "pisksnärtskadad",
    "pisksnärtskadads": "pisksnärtskadad",
    "pisksnärtskadan": "pisksnärtskada",
    "pisksnärtskadans": "pisksnärtskada",
    "pisksnärtskadas": "pisksnärtskada",
    "pisksnärtskadat": "pisksnärtskadad",
    "pisksnärtskadats": "pisksnärtskadad",
    "pisksnärtskade": "pisksnärtskada",
    "pisksnärtskador": "pisksnärtskada",
    "pisksnärtskadorna": "pisksnärtskada",
    "pisksnärtskadornas": "pisksnärtskada",
    "pisksnärtskadors": "pisksnärtskada",
    "pisksnärtsoperationen": "pisksnärtsoperation",
    "pisksnärtsoperationens": "pisksnärtsoperation",
    "pisksnärtsoperationer": "pisksnärtsoperation",
    "pisksnärtsoperationerna": "pisksnärtsoperation",
    "pisksnärtsoperationernas": "pisksnärtsoperation",
    "pisksnärtsoperationers": "pisksnärtsoperation",
    "pisksnärtsoperations": "pisksnärtsoperation",
    "pisksnärtsskadan": "pisksnärtsskada",
    "pisksnärtsskadans": "pisksnärtsskada",
    "pisksnärtsskadas": "pisksnärtsskada",
    "pisksnärtsskade": "pisksnärtsskada",
    "pisksnärtsskador": "pisksnärtsskada",
    "pisksnärtsskadorna": "pisksnärtsskada",
    "pisksnärtsskadornas": "pisksnärtsskada",
    "pisksnärtsskadors": "pisksnärtsskada",
    "piskställningar": "piskställning",
    "piskställningarna": "piskställning",
    "piskställningarnas": "piskställning",
    "piskställningars": "piskställning",
    "piskställningen": "piskställning",
    "piskställningens": "piskställning",
    "piskställnings": "piskställning",
    "pissade": "pissa",
    "pissades": "pissa",
    "pissande": "pissa",
    "pissanden": "pissande",
    "pissandena": "pissande",
    "pissandenas": "pissande",
    "pissandens": "pissande",
    "pissandes": "pissande",
    "pissandet": "pissande",
    "pissandets": "pissande",
    "pissar": "pissa",
    "pissas": "pissa",
    "pissat": "pissa",
    "pissats": "pissa",
    "pisset": "piss",
    "pissets": "piss",
    "pissiga": "pissig",
    "pissigare": "pissig",
    "pissigares": "pissig",
    "pissigas": "pissig",
    "pissigast": "pissig",
    "pissigaste": "pissig",
    "pissigastes": "pissig",
    "pissigasts": "pissig",
    "pissige": "pissig",
    "pissiges": "pissig",
    "pissigheten": "pissighet",
    "pissighetens": "pissighet",
    "pissighets": "pissighet",
    "pissigs": "pissig",
    "pissigt": "pissig",
    "pissigts": "pissig",
    "pissoaren": "pissoar",
    "pissoarens": "pissoar",
    "pissoarer": "pissoar",
    "pissoarerna": "pissoar",
    "pissoarernas": "pissoar",
    "pissoarers": "pissoar",
    "pissoars": "pissoar",
    "pistagen": "pistage",
    "pistagens": "pistage",
    "pistagenöten": "pistagenöt",
    "pistagenötens": "pistagenöt",
    "pistagenöts": "pistagenöt",
    "pistagenötter": "pistagenöt",
    "pistagenötterna": "pistagenöt",
    "pistagenötternas": "pistagenöt",
    "pistagenötters": "pistagenöt",
    "pistager": "pistage",
    "pistagerna": "pistage",
    "pistagernas": "pistage",
    "pistagers": "pistage",
    "pistages": "pistage",
    "pistaschen": "pistasch",
    "pistaschens": "pistasch",
    "pistascher": "pistasch",
    "pistascherna": "pistasch",
    "pistaschernas": "pistasch",
    "pistaschers": "pistasch",
    "pistaschnöten": "pistaschnöt",
    "pistaschnötens": "pistaschnöt",
    "pistaschnöts": "pistaschnöt",
    "pistaschnötter": "pistaschnöt",
    "pistaschnötterna": "pistaschnöt",
    "pistaschnötternas": "pistaschnöt",
    "pistaschnötters": "pistaschnöt",
    "pistaschs": "pistasch",
    "pisten": "pist",
    "pistens": "pist",
    "pister": "pist",
    "pisterna": "pist",
    "pisternas": "pist",
    "pisters": "pist",
    "pistillen": "pistill",
    "pistillens": "pistill",
    "pistiller": "pistill",
    "pistillerna": "pistill",
    "pistillernas": "pistill",
    "pistillers": "pistill",
    "pistills": "pistill",
    "pistolbeväpnade": "pistolbeväpnad",
    "pistolbeväpnades": "pistolbeväpnad",
    "pistolbeväpnads": "pistolbeväpnad",
    "pistolbeväpnat": "pistolbeväpnad",
    "pistolbeväpnats": "pistolbeväpnad",
    "pistolen": "pistol",
    "pistolens": "pistol",
    "pistoler": "pistol",
    "pistolerna": "pistol",
    "pistolernas": "pistol",
    "pistolers": "pistol",
    "pistolformade": "pistolformad",
    "pistolformades": "pistolformad",
    "pistolformads": "pistolformad",
    "pistolformat": "pistolformad",
    "pistolformats": "pistolformad",
    "pistolkul": "pistolkula",
    "pistolkulan": "pistolkula",
    "pistolkulans": "pistolkula",
    "pistolkulas": "pistolkula",
    "pistolkule": "pistolkula",
    "pistolkulor": "pistolkula",
    "pistolkulorna": "pistolkula",
    "pistolkulornas": "pistolkula",
    "pistolkulors": "pistolkula",
    "pistolkuls": "pistolkula",
    "pistolrånen": "pistolrån",
    "pistolrånens": "pistolrån",
    "pistolrånet": "pistolrån",
    "pistolrånets": "pistolrån",
    "pistolråns": "pistolrån",
    "pistols": "pistol",
    "pistolskotten": "pistolskott",
    "pistolskottens": "pistolskott",
    "pistolskottet": "pistolskott",
    "pistolskottets": "pistolskott",
    "pistolskotts": "pistolskott",
    "pistolskyttes": "pistolskytte",
    "pistolskyttet": "pistolskytte",
    "pistolskyttets": "pistolskytte",
    "pistolväsk": "pistolväska",
    "pistolväskan": "pistolväska",
    "pistolväskans": "pistolväska",
    "pistolväskas": "pistolväska",
    "pistolväske": "pistolväska",
    "pistolväskor": "pistolväska",
    "pistolväskorna": "pistolväska",
    "pistolväskornas": "pistolväska",
    "pistolväskors": "pistolväska",
    "pistongen": "pistong",
    "pistongens": "pistong",
    "pistonger": "pistong",
    "pistongerna": "pistong",
    "pistongernas": "pistong",
    "pistongers": "pistong",
    "pistongs": "pistong",
    "pists": "pist",
    "pit": "pi",
    "pitepaltar": "pitepalt",
    "pitepaltarna": "pitepalt",
    "pitepaltarnas": "pitepalt",
    "pitepaltars": "pitepalt",
    "pitepalten": "pitepalt",
    "pitepaltens": "pitepalt",
    "pitepalts": "pitepalt",
    "pitpropsen": "pitprops",
    "pitpropsens": "pitprops",
    "pits": "pi",
    "pittar": "pitt",
    "pittarna": "pitt",
    "pittarnas": "pitt",
    "pittars": "pitt",
    "pitten": "pitt",
    "pittens": "pitt",
    "pittoreska": "pittoresk",
    "pittoreskare": "pittoresk",
    "pittoreskares": "pittoresk",
    "pittoreskas": "pittoresk",
    "pittoreskast": "pittoresk",
    "pittoreskaste": "pittoresk",
    "pittoreskastes": "pittoresk",
    "pittoreskasts": "pittoresk",
    "pittoreske": "pittoresk",
    "pittoreskes": "pittoresk",
    "pittoresks": "pittoresk",
    "pittoreskt": "pittoresk",
    "pittoreskts": "pittoresk",
    "pitts": "pitt",
    "pivoten": "pivot",
    "pivotens": "pivot",
    "pivoter": "pivot",
    "pivoterade": "pivotera",
    "pivoterades": "pivotera",
    "pivoterande": "pivotera",
    "pivoteranden": "pivoterande",
    "pivoterandena": "pivoterande",
    "pivoterandenas": "pivoterande",
    "pivoterandens": "pivoterande",
    "pivoterandes": "pivoterande",
    "pivoterandet": "pivoterande",
    "pivoterandets": "pivoterande",
    "pivoterar": "pivotera",
    "pivoteras": "pivotera",
    "pivoterat": "pivotera",
    "pivoterats": "pivotera",
    "pivoteringar": "pivotering",
    "pivoteringarna": "pivotering",
    "pivoteringarnas": "pivotering",
    "pivoteringars": "pivotering",
    "pivoteringen": "pivotering",
    "pivoteringens": "pivotering",
    "pivoterings": "pivotering",
    "pivoterna": "pivot",
    "pivoternas": "pivot",
    "pivoters": "pivot",
    "pivotfönsterna": "pivotfönster",
    "pivotfönsternas": "pivotfönster",
    "pivotfönsters": "pivotfönster",
    "pivotfönstren": "pivotfönster",
    "pivotfönstrens": "pivotfönster",
    "pivotfönstret": "pivotfönster",
    "pivotfönstrets": "pivotfönster",
    "pivothjulen": "pivothjul",
    "pivothjulens": "pivothjul",
    "pivothjulet": "pivothjul",
    "pivothjulets": "pivothjul",
    "pivothjuls": "pivothjul",
    "pivothängda": "pivothängd",
    "pivothängdare": "pivothängd",
    "pivothängdares": "pivothängd",
    "pivothängdas": "pivothängd",
    "pivothängdast": "pivothängd",
    "pivothängdaste": "pivothängd",
    "pivothängdastes": "pivothängd",
    "pivothängdasts": "pivothängd",
    "pivothängde": "pivothängd",
    "pivothängdes": "pivothängd",
    "pivothängds": "pivothängd",
    "pivothängt": "pivothängd",
    "pivothängts": "pivothängd",
    "pivots": "pivot",
    "pivotvagnar": "pivotvagn",
    "pivotvagnarna": "pivotvagn",
    "pivotvagnarnas": "pivotvagn",
    "pivotvagnars": "pivotvagn",
    "pivotvagnen": "pivotvagn",
    "pivotvagnens": "pivotvagn",
    "pivotvagns": "pivotvagn",
    "pivåer": "pivå",
    "pivåerna": "pivå",
    "pivåernas": "pivå",
    "pivåers": "pivå",
    "pivåfönsterna": "pivåfönster",
    "pivåfönsternas": "pivåfönster",
    "pivåfönsters": "pivåfönster",
    "pivåfönstren": "pivåfönster",
    "pivåfönstrens": "pivåfönster",
    "pivåfönstret": "pivåfönster",
    "pivåfönstrets": "pivåfönster",
    "pivåhängda": "pivåhängd",
    "pivåhängdare": "pivåhängd",
    "pivåhängdares": "pivåhängd",
    "pivåhängdas": "pivåhängd",
    "pivåhängdast": "pivåhängd",
    "pivåhängdaste": "pivåhängd",
    "pivåhängdastes": "pivåhängd",
    "pivåhängdasts": "pivåhängd",
    "pivåhängde": "pivåhängd",
    "pivåhängdes": "pivåhängd",
    "pivåhängds": "pivåhängd",
    "pivåhängt": "pivåhängd",
    "pivåhängts": "pivåhängd",
    "pivån": "pivå",
    "pivåns": "pivå",
    "pivås": "pivå",
    "pivåvagnar": "pivåvagn",
    "pivåvagnarna": "pivåvagn",
    "pivåvagnarnas": "pivåvagn",
    "pivåvagnars": "pivåvagn",
    "pivåvagnen": "pivåvagn",
    "pivåvagnens": "pivåvagn",
    "pivåvagns": "pivåvagn",
    "pixen": "pix",
    "pixens": "pix",
    "pixet": "pix",
    "pixets": "pix",
    "pizzabagar": "pizzabagare",
    "pizzabagaren": "pizzabagare",
    "pizzabagarens": "pizzabagare",
    "pizzabagares": "pizzabagare",
    "pizzabagarna": "pizzabagare",
    "pizzabagarnas": "pizzabagare",
    "pizzabitar": "pizzabit",
    "pizzabitarna": "pizzabit",
    "pizzabitarnas": "pizzabit",
    "pizzabitars": "pizzabit",
    "pizzabiten": "pizzabit",
    "pizzabitens": "pizzabit",
    "pizzabits": "pizzabit",
    "pizzakartongen": "pizzakartong",
    "pizzakartongens": "pizzakartong",
    "pizzakartonger": "pizzakartong",
    "pizzakartongerna": "pizzakartong",
    "pizzakartongernas": "pizzakartong",
    "pizzakartongers": "pizzakartong",
    "pizzakartongs": "pizzakartong",
    "pizzan": "pizza",
    "pizzans": "pizza",
    "pizzas": "pizza",
    "pizzeri": "pizzeria",
    "pizzerian": "pizzeria",
    "pizzerians": "pizzeria",
    "pizzerias": "pizzeria",
    "pizzerie": "pizzeria",
    "pizzerior": "pizzeria",
    "pizzeriorna": "pizzeria",
    "pizzeriornas": "pizzeria",
    "pizzeriors": "pizzeria",
    "pizzeris": "pizzeria",
    "pizzicaton": "pizzicato",
    "pizzicatona": "pizzicato",
    "pizzicatonas": "pizzicato",
    "pizzicatons": "pizzicato",
    "pizzicatos": "pizzicato",
    "pizzicatot": "pizzicato",
    "pizzicatots": "pizzicato",
    "pizzor": "pizza",
    "pizzorna": "pizza",
    "pizzornas": "pizza",
    "pizzors": "pizza",
    "pjattar": "pjatt",
    "pjattarna": "pjatt",
    "pjattarnas": "pjatt",
    "pjattars": "pjatt",
    "pjatten": "pjatt",
    "pjattens": "pjatt",
    "pjatthattar": "pjatthatt",
    "pjatthattarna": "pjatthatt",
    "pjatthattarnas": "pjatthatt",
    "pjatthattars": "pjatthatt",
    "pjatthatten": "pjatthatt",
    "pjatthattens": "pjatthatt",
    "pjatthatts": "pjatthatt",
    "pjatts": "pjatt",
    "pjoller": "pjollra",
    "pjollers": "pjoller",
    "pjollrade": "pjollra",
    "pjollrades": "pjollra",
    "pjollrande": "pjollra",
    "pjollranden": "pjollrande",
    "pjollrandena": "pjollrande",
    "pjollrandenas": "pjollrande",
    "pjollrandens": "pjollrande",
    "pjollrandes": "pjollrande",
    "pjollrandet": "pjollrande",
    "pjollrandets": "pjollrande",
    "pjollrar": "pjollra",
    "pjollras": "pjollra",
    "pjollrat": "pjollra",
    "pjollrats": "pjollra",
    "pjollret": "pjoller",
    "pjollrets": "pjoller",
    "pjoltersällskapen": "pjoltersällskap",
    "pjoltersällskapens": "pjoltersällskap",
    "pjoltersällskapet": "pjoltersällskap",
    "pjoltersällskapets": "pjoltersällskap",
    "pjoltersällskaps": "pjoltersällskap",
    "pjoskade": "pjoska",
    "pjoskades": "pjoska",
    "pjoskande": "pjoska",
    "pjoskanden": "pjoskande",
    "pjoskandena": "pjoskande",
    "pjoskandenas": "pjoskande",
    "pjoskandens": "pjoskande",
    "pjoskandes": "pjoskande",
    "pjoskandet": "pjoskande",
    "pjoskandets": "pjoskande",
    "pjoskar": "pjoska",
    "pjoskas": "pjoska",
    "pjoskat": "pjoska",
    "pjoskats": "pjoska",
    "pjosket": "pjosk",
    "pjoskets": "pjosk",
    "pjoskiga": "pjoskig",
    "pjoskigare": "pjoskig",
    "pjoskigares": "pjoskig",
    "pjoskigas": "pjoskig",
    "pjoskigast": "pjoskig",
    "pjoskigaste": "pjoskig",
    "pjoskigastes": "pjoskig",
    "pjoskigasts": "pjoskig",
    "pjoskige": "pjoskig",
    "pjoskiges": "pjoskig",
    "pjoskigheten": "pjoskighet",
    "pjoskighetens": "pjoskighet",
    "pjoskighets": "pjoskighet",
    "pjoskigs": "pjoskig",
    "pjoskigt": "pjoskig",
    "pjoskigts": "pjoskig",
    "pjosks": "pjosk",
    "pjunkade": "pjunka",
    "pjunkades": "pjunka",
    "pjunkande": "pjunka",
    "pjunkanden": "pjunkande",
    "pjunkandena": "pjunkande",
    "pjunkandenas": "pjunkande",
    "pjunkandens": "pjunkande",
    "pjunkandes": "pjunkande",
    "pjunkandet": "pjunkande",
    "pjunkandets": "pjunkande",
    "pjunkar": "pjunka",
    "pjunkas": "pjunka",
    "pjunkat": "pjunka",
    "pjunkats": "pjunka",
    "pjunket": "pjunk",
    "pjunkets": "pjunk",
    "pjunkiga": "pjunkig",
    "pjunkigare": "pjunkig",
    "pjunkigares": "pjunkig",
    "pjunkigas": "pjunkig",
    "pjunkigast": "pjunkig",
    "pjunkigaste": "pjunkig",
    "pjunkigastes": "pjunkig",
    "pjunkigasts": "pjunkig",
    "pjunkige": "pjunkig",
    "pjunkiges": "pjunkig",
    "pjunkigheten": "pjunkighet",
    "pjunkighetens": "pjunkighet",
    "pjunkighets": "pjunkighet",
    "pjunkigs": "pjunkig",
    "pjunkigt": "pjunkig",
    "pjunkigts": "pjunkig",
    "pjunks": "pjunk",
    "pjäsen": "pjäs",
    "pjäsens": "pjäs",
    "pjäser": "pjäs",
    "pjäserna": "pjäs",
    "pjäsernas": "pjäs",
    "pjäsers": "pjäs",
    "pjäx": "pjäxa",
    "pjäxan": "pjäxa",
    "pjäxans": "pjäxa",
    "pjäxas": "pjäxa",
    "pjäxe": "pjäxa",
    "pjäxor": "pjäxa",
    "pjäxorna": "pjäxa",
    "pjäxornas": "pjäxa",
    "pjäxors": "pjäxa",
    "pjåkiga": "pjåkig",
    "pjåkigare": "pjåkig",
    "pjåkigares": "pjåkig",
    "pjåkigas": "pjåkig",
    "pjåkigast": "pjåkig",
    "pjåkigaste": "pjåkig",
    "pjåkigastes": "pjåkig",
    "pjåkigasts": "pjåkig",
    "pjåkige": "pjåkig",
    "pjåkiges": "pjåkig",
    "pjåkigs": "pjåkig",
    "pjåkigt": "pjåkig",
    "pjåkigts": "pjåkig",
    "placeboeffekten": "placeboeffekt",
    "placeboeffektens": "placeboeffekt",
    "placeboeffekter": "placeboeffekt",
    "placeboeffekterna": "placeboeffekt",
    "placeboeffekternas": "placeboeffekt",
    "placeboeffekters": "placeboeffekt",
    "placeboeffekts": "placeboeffekt",
    "placebon": "placebo",
    "placebons": "placebo",
    "placebos": "placebo",
    "placent": "placenta",
    "placentan": "placenta",
    "placentans": "placenta",
    "placentas": "placenta",
    "placente": "placenta",
    "placentor": "placenta",
    "placentorna": "placenta",
    "placentornas": "placenta",
    "placentors": "placenta",
    "placents": "placenta",
    "placerad": "placera",
    "placerade": "placera",
    "placerades": "placera",
    "placerads": "placera",
    "placerande": "placera",
    "placeranden": "placerande",
    "placerandena": "placerande",
    "placerandenas": "placerande",
    "placerandens": "placerande",
    "placerandes": "placerande",
    "placerandet": "placerande",
    "placerandets": "placerande",
    "placerar": "placera",
    "placeras": "placera",
    "placerat": "placera",
    "placerats": "placera",
    "placerbara": "placerbar",
    "placerbarare": "placerbar",
    "placerbarares": "placerbar",
    "placerbaras": "placerbar",
    "placerbarast": "placerbar",
    "placerbaraste": "placerbar",
    "placerbarastes": "placerbar",
    "placerbarasts": "placerbar",
    "placerbare": "placerbar",
    "placerbares": "placerbar",
    "placerbarheten": "placerbarhet",
    "placerbarhetens": "placerbarhet",
    "placerbarhets": "placerbarhet",
    "placerbars": "placerbar",
    "placerbart": "placerbar",
    "placerbarts": "placerbar",
    "placeringar": "placering",
    "placeringarna": "placering",
    "placeringarnas": "placering",
    "placeringars": "placering",
    "placeringen": "placering",
    "placeringens": "placering",
    "placerings": "placering",
    "placeringskorten": "placeringskort",
    "placeringskortens": "placeringskort",
    "placeringskortet": "placeringskort",
    "placeringskortets": "placeringskort",
    "placeringskorts": "placeringskort",
    "placeringsobjekten": "placeringsobjekt",
    "placeringsobjektens": "placeringsobjekt",
    "placeringsobjektet": "placeringsobjekt",
    "placeringsobjektets": "placeringsobjekt",
    "placeringsobjekts": "placeringsobjekt",
    "placken": "plack",
    "plackens": "plack",
    "placket": "plack",
    "plackets": "plack",
    "placks": "plack",
    "pladder": "pladdra",
    "pladderbloggar": "pladderblogg",
    "pladderbloggarna": "pladderblogg",
    "pladderbloggarnas": "pladderblogg",
    "pladderbloggars": "pladderblogg",
    "pladderbloggen": "pladderblogg",
    "pladderbloggens": "pladderblogg",
    "pladderbloggs": "pladderblogg",
    "pladders": "pladder",
    "pladdrade": "pladdra",
    "pladdrades": "pladdra",
    "pladdrande": "pladdra",
    "pladdranden": "pladdrande",
    "pladdrandena": "pladdrande",
    "pladdrandenas": "pladdrande",
    "pladdrandens": "pladdrande",
    "pladdrandes": "pladdrande",
    "pladdrandet": "pladdrande",
    "pladdrandets": "pladdrande",
    "pladdrar": "pladdra",
    "pladdras": "pladdra",
    "pladdrat": "pladdra",
    "pladdrats": "pladdra",
    "pladdret": "pladder",
    "pladdrets": "pladder",
    "pladdriga": "pladdrig",
    "pladdrigare": "pladdrig",
    "pladdrigares": "pladdrig",
    "pladdrigas": "pladdrig",
    "pladdrigast": "pladdrig",
    "pladdrigaste": "pladdrig",
    "pladdrigastes": "pladdrig",
    "pladdrigasts": "pladdrig",
    "pladdrige": "pladdrig",
    "pladdriges": "pladdrig",
    "pladdrigheten": "pladdrighet",
    "pladdrighetens": "pladdrighet",
    "pladdrighets": "pladdrighet",
    "pladdrigs": "pladdrig",
    "pladdrigt": "pladdrig",
    "pladdrigts": "pladdrig",
    "pladusk": "pladuska",
    "pladuskan": "pladuska",
    "pladuskans": "pladuska",
    "pladuskas": "pladuska",
    "pladuske": "pladuska",
    "pladuskor": "pladuska",
    "pladuskorna": "pladuska",
    "pladuskornas": "pladuska",
    "pladuskors": "pladuska",
    "plafonden": "plafond",
    "plafondens": "plafond",
    "plafonder": "plafond",
    "plafonderna": "plafond",
    "plafondernas": "plafond",
    "plafonders": "plafond",
    "plafonds": "plafond",
    "plagen": "plage",
    "plagens": "plage",
    "plager": "plage",
    "plagerna": "plage",
    "plagernas": "plage",
    "plagers": "plage",
    "plages": "plage",
    "plaggen": "plagg",
    "plaggens": "plagg",
    "plagget": "plagg",
    "plaggets": "plagg",
    "plaggs": "plagg",
    "plagiatanklagelsen": "plagiatanklagelse",
    "plagiatanklagelsens": "plagiatanklagelse",
    "plagiatanklagelser": "plagiatanklagelse",
    "plagiatanklagelserna": "plagiatanklagelse",
    "plagiatanklagelsernas": "plagiatanklagelse",
    "plagiatanklagelsers": "plagiatanklagelse",
    "plagiatanklagelses": "plagiatanklagelse",
    "plagiaten": "plagiat",
    "plagiatens": "plagiat",
    "plagiatet": "plagiat",
    "plagiatets": "plagiat",
    "plagiatorer": "plagiator",
    "plagiatorerna": "plagiator",
    "plagiatorernas": "plagiator",
    "plagiatorers": "plagiator",
    "plagiatorn": "plagiator",
    "plagiatorns": "plagiator",
    "plagiators": "plagiator",
    "plagiats": "plagiat",
    "plagierad": "plagiera",
    "plagierade": "plagiera",
    "plagierades": "plagiera",
    "plagierads": "plagiera",
    "plagierande": "plagiera",
    "plagieranden": "plagierande",
    "plagierandena": "plagierande",
    "plagierandenas": "plagierande",
    "plagierandens": "plagierande",
    "plagierandes": "plagierande",
    "plagierandet": "plagierande",
    "plagierandets": "plagierande",
    "plagierar": "plagiera",
    "plagieras": "plagiera",
    "plagierat": "plagiera",
    "plagierats": "plagiera",
    "plagierbara": "plagierbar",
    "plagierbarare": "plagierbar",
    "plagierbarares": "plagierbar",
    "plagierbaras": "plagierbar",
    "plagierbarast": "plagierbar",
    "plagierbaraste": "plagierbar",
    "plagierbarastes": "plagierbar",
    "plagierbarasts": "plagierbar",
    "plagierbare": "plagierbar",
    "plagierbares": "plagierbar",
    "plagierbarheten": "plagierbarhet",
    "plagierbarhetens": "plagierbarhet",
    "plagierbarhets": "plagierbarhet",
    "plagierbars": "plagierbar",
    "plagierbart": "plagierbar",
    "plagierbarts": "plagierbar",
    "plagieringar": "plagiering",
    "plagieringarna": "plagiering",
    "plagieringarnas": "plagiering",
    "plagieringars": "plagiering",
    "plagieringen": "plagiering",
    "plagieringens": "plagiering",
    "plagierings": "plagiering",
    "plaidoyeren": "plaidoyer",
    "plaidoyerens": "plaidoyer",
    "plaidoyerer": "plaidoyer",
    "plaidoyererna": "plaidoyer",
    "plaidoyerernas": "plaidoyer",
    "plaidoyerers": "plaidoyer",
    "plaidoyers": "plaidoyer",
    "plakaten": "plakat",
    "plakatens": "plakat",
    "plakatet": "plakat",
    "plakatets": "plakat",
    "plakats": "plakat",
    "plaketten": "plakett",
    "plakettens": "plakett",
    "plaketter": "plakett",
    "plaketterna": "plakett",
    "plaketternas": "plakett",
    "plaketters": "plakett",
    "plaketts": "plakett",
    "plan": "plana",
    "plana": "plan",
    "planad": "plana",
    "planade": "plana",
    "planades": "plana",
    "planads": "plana",
    "planande": "plana",
    "plananden": "planande",
    "planandena": "planande",
    "planandenas": "planande",
    "planandens": "planande",
    "planandes": "planande",
    "planandet": "planande",
    "planandets": "planande",
    "planar": "plana",
    "planare": "plan",
    "planares": "plan",
    "planas": "plana",
    "planast": "plan",
    "planaste": "plan",
    "planastes": "plan",
    "planasts": "plan",
    "planat": "plana",
    "planats": "plana",
    "plane": "plan",
    "planekonomien": "planekonomi",
    "planekonomiens": "planekonomi",
    "planekonomier": "planekonomi",
    "planekonomierna": "planekonomi",
    "planekonomiernas": "planekonomi",
    "planekonomiers": "planekonomi",
    "planekonomin": "planekonomi",
    "planekonomins": "planekonomi",
    "planekonomis": "planekonomi",
    "planen": "plan",
    "planenliga": "planenlig",
    "planenligare": "planenlig",
    "planenligares": "planenlig",
    "planenligas": "planenlig",
    "planenligast": "planenlig",
    "planenligaste": "planenlig",
    "planenligastes": "planenlig",
    "planenligasts": "planenlig",
    "planenlige": "planenlig",
    "planenliges": "planenlig",
    "planenligheten": "planenlighet",
    "planenlighetens": "planenlighet",
    "planenlighets": "planenlighet",
    "planenligs": "planenlig",
    "planenligt": "planenlig",
    "planenligts": "planenlig",
    "planens": "plan",
    "planer": "plan",
    "planerad": "planera",
    "planerade": "planera",
    "planerades": "planera",
    "planerads": "planera",
    "planerande": "planera",
    "planeranden": "planerande",
    "planerandena": "planerande",
    "planerandenas": "planerande",
    "planerandens": "planerande",
    "planerandes": "planerande",
    "planerandet": "planerande",
    "planerandets": "planerande",
    "planerar": "planerare",
    "planeraren": "planerare",
    "planerarens": "planerare",
    "planerares": "planerare",
    "planerarna": "planerare",
    "planerarnas": "planerare",
    "planeras": "planera",
    "planerat": "planera",
    "planerats": "planera",
    "planerbara": "planerbar",
    "planerbarare": "planerbar",
    "planerbarares": "planerbar",
    "planerbaras": "planerbar",
    "planerbarast": "planerbar",
    "planerbaraste": "planerbar",
    "planerbarastes": "planerbar",
    "planerbarasts": "planerbar",
    "planerbare": "planerbar",
    "planerbares": "planerbar",
    "planerbarheten": "planerbarhet",
    "planerbarhetens": "planerbarhet",
    "planerbarhets": "planerbarhet",
    "planerbars": "planerbar",
    "planerbart": "planerbar",
    "planerbarts": "planerbar",
    "planeringar": "planering",
    "planeringarna": "planering",
    "planeringarnas": "planering",
    "planeringars": "planering",
    "planeringen": "planering",
    "planeringens": "planering",
    "planerings": "planering",
    "planeringsmässiga": "planeringsmässig",
    "planeringsmässigare": "planeringsmässig",
    "planeringsmässigares": "planeringsmässig",
    "planeringsmässigas": "planeringsmässig",
    "planeringsmässigast": "planeringsmässig",
    "planeringsmässigaste": "planeringsmässig",
    "planeringsmässigastes": "planeringsmässig",
    "planeringsmässigasts": "planeringsmässig",
    "planeringsmässige": "planeringsmässig",
    "planeringsmässiges": "planeringsmässig",
    "planeringsmässigs": "planeringsmässig",
    "planeringsmässigt": "planeringsmässig",
    "planeringsmässigts": "planeringsmässig",
    "planeringsorganen": "planeringsorgan",
    "planeringsorganens": "planeringsorgan",
    "planeringsorganet": "planeringsorgan",
    "planeringsorganets": "planeringsorgan",
    "planeringsorgans": "planeringsorgan",
    "planerna": "plan",
    "planernas": "plan",
    "planers": "plan",
    "planes": "plan",
    "planet": "plan",
    "planetarie": "planetarium",
    "planetarier": "planetarium",
    "planetarierna": "planetarium",
    "planetariernas": "planetarium",
    "planetariers": "planetarium",
    "planetariet": "planetarium",
    "planetariets": "planetarium",
    "planetariska": "planetarisk",
    "planetariskare": "planetarisk",
    "planetariskares": "planetarisk",
    "planetariskas": "planetarisk",
    "planetariskast": "planetarisk",
    "planetariskaste": "planetarisk",
    "planetariskastes": "planetarisk",
    "planetariskasts": "planetarisk",
    "planetariske": "planetarisk",
    "planetariskes": "planetarisk",
    "planetarisks": "planetarisk",
    "planetariskt": "planetarisk",
    "planetariskts": "planetarisk",
    "planetariums": "planetarium",
    "planetbanan": "planetbana",
    "planetbanans": "planetbana",
    "planetbanas": "planetbana",
    "planetbane": "planetbana",
    "planetbanor": "planetbana",
    "planetbanorna": "planetbana",
    "planetbanornas": "planetbana",
    "planetbanors": "planetbana",
    "planetbildningar": "planetbildning",
    "planetbildningarna": "planetbildning",
    "planetbildningarnas": "planetbildning",
    "planetbildningars": "planetbildning",
    "planetbildningen": "planetbildning",
    "planetbildningens": "planetbildning",
    "planetbildnings": "planetbildning",
    "planeten": "planet",
    "planetens": "planet",
    "planeter": "planet",
    "planeterna": "planet",
    "planeternas": "planet",
    "planeters": "planet",
    "planetesimalen": "planetesimal",
    "planetesimalens": "planetesimal",
    "planetesimaler": "planetesimal",
    "planetesimalerna": "planetesimal",
    "planetesimalernas": "planetesimal",
    "planetesimalers": "planetesimal",
    "planetesimals": "planetesimal",
    "planets": "planet",
    "planetsystemen": "planetsystem",
    "planetsystemens": "planetsystem",
    "planetsystemet": "planetsystem",
    "planetsystemets": "planetsystem",
    "planetsystems": "planetsystem",
    "plangeometrien": "plangeometri",
    "plangeometriens": "plangeometri",
    "plangeometrin": "plangeometri",
    "plangeometrins": "plangeometri",
    "plangeometris": "plangeometri",
    "planhalv": "planhalva",
    "planhalvan": "planhalva",
    "planhalvans": "planhalva",
    "planhalvas": "planhalva",
    "planhalve": "planhalva",
    "planhalvor": "planhalva",
    "planhalvorna": "planhalva",
    "planhalvornas": "planhalva",
    "planhalvors": "planhalva",
    "planhalvs": "planhalva",
    "planheten": "planhet",
    "planhetens": "planhet",
    "planhets": "planhet",
    "planhushållningar": "planhushållning",
    "planhushållningarna": "planhushållning",
    "planhushållningarnas": "planhushållning",
    "planhushållningars": "planhushållning",
    "planhushållningen": "planhushållning",
    "planhushållningens": "planhushållning",
    "planhushållnings": "planhushållning",
    "planhyveln": "planhyvel",
    "planhyvelns": "planhyvel",
    "planhyvels": "planhyvel",
    "planhyvlar": "planhyvel",
    "planhyvlarna": "planhyvel",
    "planhyvlarnas": "planhyvel",
    "planhyvlars": "planhyvel",
    "planimetrien": "planimetri",
    "planimetriens": "planimetri",
    "planimetrin": "planimetri",
    "planimetrins": "planimetri",
    "planimetris": "planimetri",
    "plank": "planka",
    "plankad": "planka",
    "plankade": "planka",
    "plankades": "planka",
    "plankads": "planka",
    "plankan": "planka",
    "plankande": "planka",
    "plankanden": "plankande",
    "plankandena": "plankande",
    "plankandenas": "plankande",
    "plankandens": "plankande",
    "plankandes": "plankande",
    "plankandet": "plankande",
    "plankandets": "plankande",
    "plankans": "planka",
    "plankar": "planka",
    "plankas": "planka",
    "plankat": "planka",
    "plankats": "planka",
    "planke": "planka",
    "planken": "plank",
    "plankens": "plank",
    "planket": "plank",
    "plankets": "plank",
    "plankgolven": "plankgolv",
    "plankgolvens": "plankgolv",
    "plankgolvet": "plankgolv",
    "plankgolvets": "plankgolv",
    "plankgolvs": "plankgolv",
    "plankgångar": "plankgång",
    "plankgångarna": "plankgång",
    "plankgångarnas": "plankgång",
    "plankgångars": "plankgång",
    "plankgången": "plankgång",
    "plankgångens": "plankgång",
    "plankgångs": "plankgång",
    "plankonkava": "plankonkav",
    "plankonkavare": "plankonkav",
    "plankonkavares": "plankonkav",
    "plankonkavas": "plankonkav",
    "plankonkavast": "plankonkav",
    "plankonkavaste": "plankonkav",
    "plankonkavastes": "plankonkav",
    "plankonkavasts": "plankonkav",
    "plankonkave": "plankonkav",
    "plankonkaves": "plankonkav",
    "plankonkavs": "plankonkav",
    "plankonkavt": "plankonkav",
    "plankonkavts": "plankonkav",
    "plankonvexa": "plankonvex",
    "plankonvexare": "plankonvex",
    "plankonvexares": "plankonvex",
    "plankonvexas": "plankonvex",
    "plankonvexast": "plankonvex",
    "plankonvexaste": "plankonvex",
    "plankonvexastes": "plankonvex",
    "plankonvexasts": "plankonvex",
    "plankonvexe": "plankonvex",
    "plankonvexes": "plankonvex",
    "plankonvext": "plankonvex",
    "plankonvexts": "plankonvex",
    "plankor": "planka",
    "plankorna": "planka",
    "plankornas": "planka",
    "plankors": "planka",
    "plankorsningar": "plankorsning",
    "plankorsningarna": "plankorsning",
    "plankorsningarnas": "plankorsning",
    "plankorsningars": "plankorsning",
    "plankorsningen": "plankorsning",
    "plankorsningens": "plankorsning",
    "plankorsnings": "plankorsning",
    "planks": "planka",
    "plankstekar": "plankstek",
    "plankstekarna": "plankstek",
    "plankstekarnas": "plankstek",
    "plankstekars": "plankstek",
    "planksteken": "plankstek",
    "plankstekens": "plankstek",
    "planksteks": "plankstek",
    "plankstrykar": "plankstrykare",
    "plankstrykaren": "plankstrykare",
    "plankstrykarens": "plankstrykare",
    "plankstrykares": "plankstrykare",
    "plankstrykarna": "plankstrykare",
    "plankstrykarnas": "plankstrykare",
    "planktern": "plankter",
    "plankterna": "plankter",
    "plankternas": "plankter",
    "plankterns": "plankter",
    "plankters": "plankter",
    "planktondjuren": "planktondjur",
    "planktondjurens": "planktondjur",
    "planktondjuret": "planktondjur",
    "planktondjurets": "planktondjur",
    "planktondjurs": "planktondjur",
    "planktonen": "plankton",
    "planktonens": "plankton",
    "planktonet": "plankton",
    "planktonets": "plankton",
    "planktons": "plankton",
    "planktonväxten": "planktonväxt",
    "planktonväxtens": "planktonväxt",
    "planktonväxter": "planktonväxt",
    "planktonväxterna": "planktonväxt",
    "planktonväxternas": "planktonväxt",
    "planktonväxters": "planktonväxt",
    "planktonväxts": "planktonväxt",
    "planla": "planlägga",
    "planlade": "planlägga",
    "planlades": "planlägga",
    "planlagd": "planlägga",
    "planlagda": "planlägga",
    "planlagdas": "planlägga",
    "planlagde": "planlägga",
    "planlagdes": "planlägga",
    "planlagds": "planlägga",
    "planlagt": "planlägga",
    "planlagts": "planlägga",
    "planlas": "planlägga",
    "planlägg": "planlägga",
    "planläggande": "planlägga",
    "planlägganden": "planläggande",
    "planläggandena": "planläggande",
    "planläggandenas": "planläggande",
    "planläggandens": "planläggande",
    "planläggandes": "planläggande",
    "planläggandet": "planläggande",
    "planläggandets": "planläggande",
    "planläggas": "planlägga",
    "planlägger": "planlägga",
    "planlägges": "planlägga",
    "planläggningar": "planläggning",
    "planläggningarna": "planläggning",
    "planläggningarnas": "planläggning",
    "planläggningars": "planläggning",
    "planläggningen": "planläggning",
    "planläggningens": "planläggning",
    "planläggnings": "planläggning",
    "planläggs": "planlägga",
    "planlösa": "planlös",
    "planlösare": "planlös",
    "planlösares": "planlös",
    "planlösas": "planlös",
    "planlösast": "planlös",
    "planlösaste": "planlös",
    "planlösastes": "planlös",
    "planlösasts": "planlös",
    "planlöse": "planlös",
    "planlöses": "planlös",
    "planlösheten": "planlöshet",
    "planlöshetens": "planlöshet",
    "planlöshets": "planlöshet",
    "planlösningar": "planlösning",
    "planlösningarna": "planlösning",
    "planlösningarnas": "planlösning",
    "planlösningars": "planlösning",
    "planlösningen": "planlösning",
    "planlösningens": "planlösning",
    "planlösnings": "planlösning",
    "planlöst": "planlös",
    "planlösts": "planlös",
    "planmässiga": "planmässig",
    "planmässigare": "planmässig",
    "planmässigares": "planmässig",
    "planmässigas": "planmässig",
    "planmässigast": "planmässig",
    "planmässigaste": "planmässig",
    "planmässigastes": "planmässig",
    "planmässigasts": "planmässig",
    "planmässige": "planmässig",
    "planmässiges": "planmässig",
    "planmässigheten": "planmässighet",
    "planmässighetens": "planmässighet",
    "planmässighets": "planmässighet",
    "planmässigs": "planmässig",
    "planmässigt": "planmässig",
    "planmässigts": "planmässig",
    "planmätningar": "planmätning",
    "planmätningarna": "planmätning",
    "planmätningarnas": "planmätning",
    "planmätningars": "planmätning",
    "planmätningen": "planmätning",
    "planmätningens": "planmätning",
    "planmätnings": "planmätning",
    "planparallella": "planparallell",
    "planparallellare": "planparallell",
    "planparallellares": "planparallell",
    "planparallellas": "planparallell",
    "planparallellast": "planparallell",
    "planparallellaste": "planparallell",
    "planparallellastes": "planparallell",
    "planparallellasts": "planparallell",
    "planparallelle": "planparallell",
    "planparallelles": "planparallell",
    "planparallells": "planparallell",
    "planparallellt": "planparallell",
    "planparallellts": "planparallell",
    "planritningar": "planritning",
    "planritningarna": "planritning",
    "planritningarnas": "planritning",
    "planritningars": "planritning",
    "planritningen": "planritning",
    "planritningens": "planritning",
    "planritnings": "planritning",
    "plans": "plan",
    "planschen": "plansch",
    "planschens": "plansch",
    "planscher": "plansch",
    "planscherna": "plansch",
    "planschernas": "plansch",
    "planschers": "plansch",
    "planschetten": "planschett",
    "planschettens": "planschett",
    "planschetter": "planschett",
    "planschetterna": "planschett",
    "planschetternas": "planschett",
    "planschetters": "planschett",
    "planschetts": "planschett",
    "planschs": "plansch",
    "planschverken": "planschverk",
    "planschverkens": "planschverk",
    "planschverket": "planschverk",
    "planschverkets": "planschverk",
    "planschverks": "planschverk",
    "planskilda": "planskild",
    "planskildare": "planskild",
    "planskildares": "planskild",
    "planskildas": "planskild",
    "planskildast": "planskild",
    "planskildaste": "planskild",
    "planskildastes": "planskild",
    "planskildasts": "planskild",
    "planskilde": "planskild",
    "planskildes": "planskild",
    "planskilds": "planskild",
    "planskilt": "planskild",
    "planskilts": "planskild",
    "plant": "planta",
    "plantad": "planta",
    "plantade": "planta",
    "plantades": "planta",
    "plantads": "planta",
    "plantagen": "plantage",
    "plantagens": "plantage",
    "plantager": "plantage",
    "plantagerna": "plantage",
    "plantagernas": "plantage",
    "plantagers": "plantage",
    "plantages": "plantage",
    "plantan": "planta",
    "plantande": "planta",
    "plantanden": "plantande",
    "plantandena": "plantande",
    "plantandenas": "plantande",
    "plantandens": "plantande",
    "plantandes": "plantande",
    "plantandet": "plantande",
    "plantandets": "plantande",
    "plantans": "planta",
    "plantar": "planta",
    "plantas": "planta",
    "plantat": "planta",
    "plantats": "planta",
    "plante": "planta",
    "planterad": "plantera",
    "planterade": "plantera",
    "planterades": "plantera",
    "planterads": "plantera",
    "planterande": "plantera",
    "planteranden": "planterande",
    "planterandena": "planterande",
    "planterandenas": "planterande",
    "planterandens": "planterande",
    "planterandes": "planterande",
    "planterandet": "planterande",
    "planterandets": "planterande",
    "planterar": "plantera",
    "planteras": "plantera",
    "planterat": "plantera",
    "planterats": "plantera",
    "planterbara": "planterbar",
    "planterbarare": "planterbar",
    "planterbarares": "planterbar",
    "planterbaras": "planterbar",
    "planterbarast": "planterbar",
    "planterbaraste": "planterbar",
    "planterbarastes": "planterbar",
    "planterbarasts": "planterbar",
    "planterbare": "planterbar",
    "planterbares": "planterbar",
    "planterbarheten": "planterbarhet",
    "planterbarhetens": "planterbarhet",
    "planterbarhets": "planterbarhet",
    "planterbars": "planterbar",
    "planterbart": "planterbar",
    "planterbarts": "planterbar",
    "planteringar": "plantering",
    "planteringarna": "plantering",
    "planteringarnas": "plantering",
    "planteringars": "plantering",
    "planteringen": "plantering",
    "planteringens": "plantering",
    "planterings": "plantering",
    "planteringsspad": "planteringsspade",
    "planteringsspadar": "planteringsspade",
    "planteringsspadarna": "planteringsspade",
    "planteringsspadarnas": "planteringsspade",
    "planteringsspadars": "planteringsspade",
    "planteringsspaden": "planteringsspade",
    "planteringsspadens": "planteringsspade",
    "planteringsspades": "planteringsspade",
    "planteringsspads": "planteringsspade",
    "plantor": "planta",
    "plantorna": "planta",
    "plantornas": "planta",
    "plantors": "planta",
    "plantrycket": "plantryck",
    "plantryckets": "plantryck",
    "plantrycks": "plantryck",
    "plants": "planta",
    "plantsar": "plants",
    "plantsarna": "plants",
    "plantsarnas": "plants",
    "plantsars": "plants",
    "plantsen": "plants",
    "plantsens": "plants",
    "plantskolan": "plantskola",
    "plantskolans": "plantskola",
    "plantskolas": "plantskola",
    "plantskole": "plantskola",
    "plantskolor": "plantskola",
    "plantskolorna": "plantskola",
    "plantskolornas": "plantskola",
    "plantskolors": "plantskola",
    "plaskade": "plaska",
    "plaskades": "plaska",
    "plaskande": "plaska",
    "plaskanden": "plaskande",
    "plaskandena": "plaskande",
    "plaskandenas": "plaskande",
    "plaskandens": "plaskande",
    "plaskandes": "plaskande",
    "plaskandet": "plaskande",
    "plaskandets": "plaskande",
    "plaskar": "plaska",
    "plaskas": "plaska",
    "plaskat": "plaska",
    "plaskats": "plaska",
    "plaskdammar": "plaskdamm",
    "plaskdammarna": "plaskdamm",
    "plaskdammarnas": "plaskdamm",
    "plaskdammars": "plaskdamm",
    "plaskdammen": "plaskdamm",
    "plaskdammens": "plaskdamm",
    "plaskdamms": "plaskdamm",
    "plasket": "plask",
    "plaskets": "plask",
    "plasks": "plask",
    "plaskvåta": "plaskvåt",
    "plaskvåtare": "plaskvåt",
    "plaskvåtares": "plaskvåt",
    "plaskvåtas": "plaskvåt",
    "plaskvåtast": "plaskvåt",
    "plaskvåtaste": "plaskvåt",
    "plaskvåtastes": "plaskvåt",
    "plaskvåtasts": "plaskvåt",
    "plaskvåte": "plaskvåt",
    "plaskvåtes": "plaskvåt",
    "plaskvåts": "plaskvåt",
    "plaskvått": "plaskvåt",
    "plaskvåtts": "plaskvåt",
    "plasma-TV:s": "plasma-TV",
    "plasma-TVs": "plasma-TV",
    "plasma-tevear": "plasma-teve",
    "plasma-tevearna": "plasma-teve",
    "plasma-tevearnas": "plasma-teve",
    "plasma-tevears": "plasma-teve",
    "plasma-teven": "plasma-teve",
    "plasma-tevena": "plasma-teve",
    "plasma-tevenas": "plasma-teve",
    "plasma-tevens": "plasma-teve",
    "plasma-teves": "plasma-teve",
    "plasma-tv-s": "plasma-tv",
    "plasman": "plasma",
    "plasmans": "plasma",
    "plasmas": "plasma",
    "plasmat": "plasma",
    "plasmatevear": "plasmateve",
    "plasmatevearna": "plasmateve",
    "plasmatevearnas": "plasmateve",
    "plasmatevears": "plasmateve",
    "plasmateven": "plasmateve",
    "plasmatevena": "plasmateve",
    "plasmatevenas": "plasmateve",
    "plasmatevens": "plasmateve",
    "plasmateves": "plasmateve",
    "plasmats": "plasma",
    "plasmer": "plasma",
    "plasmerna": "plasma",
    "plasmernas": "plasma",
    "plasmers": "plasma",
    "plast": "plasta",
    "plastad": "plasta",
    "plastade": "plasta",
    "plastades": "plasta",
    "plastads": "plasta",
    "plastande": "plasta",
    "plastanden": "plastande",
    "plastandena": "plastande",
    "plastandenas": "plastande",
    "plastandens": "plastande",
    "plastandes": "plastande",
    "plastandet": "plastande",
    "plastandets": "plastande",
    "plastar": "plasta",
    "plastas": "plasta",
    "plastat": "plasta",
    "plastats": "plasta",
    "plastbackar": "plastback",
    "plastbackarna": "plastback",
    "plastbackarnas": "plastback",
    "plastbackars": "plastback",
    "plastbacken": "plastback",
    "plastbackens": "plastback",
    "plastbacks": "plastback",
    "plastbanden": "plastband",
    "plastbandens": "plastband",
    "plastbandet": "plastband",
    "plastbandets": "plastband",
    "plastbands": "plastband",
    "plastbesticken": "plastbestick",
    "plastbestickens": "plastbestick",
    "plastbesticket": "plastbestick",
    "plastbestickets": "plastbestick",
    "plastbesticks": "plastbestick",
    "plastbindemedels": "plastbindemedel",
    "plastbindemedlen": "plastbindemedel",
    "plastbindemedlens": "plastbindemedel",
    "plastbindemedlet": "plastbindemedel",
    "plastbindemedlets": "plastbindemedel",
    "plastbundens": "plastbunden",
    "plastbundet": "plastbunden",
    "plastbundets": "plastbunden",
    "plastbundna": "plastbunden",
    "plastbundnare": "plastbunden",
    "plastbundnares": "plastbunden",
    "plastbundnas": "plastbunden",
    "plastbundnast": "plastbunden",
    "plastbundnaste": "plastbunden",
    "plastbundnastes": "plastbunden",
    "plastbundnasts": "plastbunden",
    "plastbundne": "plastbunden",
    "plastbundnes": "plastbunden",
    "plastbåg": "plastbåge",
    "plastbågar": "plastbåge",
    "plastbågarna": "plastbåge",
    "plastbågarnas": "plastbåge",
    "plastbågars": "plastbåge",
    "plastbågen": "plastbåge",
    "plastbågens": "plastbåge",
    "plastbåges": "plastbåge",
    "plastbågs": "plastbåge",
    "plastcykeln": "plastcykel",
    "plastcykelns": "plastcykel",
    "plastcykels": "plastcykel",
    "plastcyklar": "plastcykel",
    "plastcyklarna": "plastcykel",
    "plastcyklarnas": "plastcykel",
    "plastcyklars": "plastcykel",
    "plastellinan": "plastellina",
    "plastellinans": "plastellina",
    "plastellinas": "plastellina",
    "plastellinen": "plastellin",
    "plastellinens": "plastellin",
    "plastellins": "plastellin",
    "plasten": "plast",
    "plastens": "plast",
    "plaster": "plast",
    "plasterna": "plast",
    "plasternas": "plast",
    "plasters": "plast",
    "plastfibern": "plastfiber",
    "plastfiberns": "plastfiber",
    "plastfibers": "plastfiber",
    "plastfibrer": "plastfiber",
    "plastfibrerna": "plastfiber",
    "plastfibrernas": "plastfiber",
    "plastfibrers": "plastfiber",
    "plastflask": "plastflaska",
    "plastflaskan": "plastflaska",
    "plastflaskans": "plastflaska",
    "plastflaskas": "plastflaska",
    "plastflaske": "plastflaska",
    "plastflaskor": "plastflaska",
    "plastflaskorna": "plastflaska",
    "plastflaskornas": "plastflaska",
    "plastflaskors": "plastflaska",
    "plastfolien": "plastfolie",
    "plastfoliens": "plastfolie",
    "plastfolier": "plastfolie",
    "plastfolierna": "plastfolie",
    "plastfoliernas": "plastfolie",
    "plastfoliers": "plastfolie",
    "plastfolies": "plastfolie",
    "plastfoliet": "plastfolie",
    "plastfoliets": "plastfolie",
    "plastgaffeln": "plastgaffel",
    "plastgaffelns": "plastgaffel",
    "plastgaffels": "plastgaffel",
    "plastgafflar": "plastgaffel",
    "plastgafflarna": "plastgaffel",
    "plastgafflarnas": "plastgaffel",
    "plastgafflars": "plastgaffel",
    "plastglasen": "plastglas",
    "plastglasens": "plastglas",
    "plastglaset": "plastglas",
    "plastglasets": "plastglas",
    "plasticiteten": "plasticitet",
    "plasticitetens": "plasticitet",
    "plasticiteter": "plasticitet",
    "plasticiteterna": "plasticitet",
    "plasticiteternas": "plasticitet",
    "plasticiteters": "plasticitet",
    "plasticitets": "plasticitet",
    "plastiken": "plastik",
    "plastikens": "plastik",
    "plastikkirurgen": "plastikkirurg",
    "plastikkirurgens": "plastikkirurg",
    "plastikkirurger": "plastikkirurg",
    "plastikkirurgerna": "plastikkirurg",
    "plastikkirurgernas": "plastikkirurg",
    "plastikkirurgers": "plastikkirurg",
    "plastikkirurgien": "plastikkirurgi",
    "plastikkirurgiens": "plastikkirurgi",
    "plastikkirurgin": "plastikkirurgi",
    "plastikkirurgins": "plastikkirurgi",
    "plastikkirurgis": "plastikkirurgi",
    "plastikkirurgs": "plastikkirurg",
    "plastikoperationen": "plastikoperation",
    "plastikoperationens": "plastikoperation",
    "plastikoperationer": "plastikoperation",
    "plastikoperationerna": "plastikoperation",
    "plastikoperationernas": "plastikoperation",
    "plastikoperationers": "plastikoperation",
    "plastikoperations": "plastikoperation",
    "plastiks": "plastik",
    "plastikträsken": "plastikträsk",
    "plastikträskens": "plastikträsk",
    "plastikträsket": "plastikträsk",
    "plastikträskets": "plastikträsk",
    "plastikträsks": "plastikträsk",
    "plastindustrien": "plastindustri",
    "plastindustriens": "plastindustri",
    "plastindustrier": "plastindustri",
    "plastindustrierna": "plastindustri",
    "plastindustriernas": "plastindustri",
    "plastindustriers": "plastindustri",
    "plastindustrin": "plastindustri",
    "plastindustrins": "plastindustri",
    "plastindustris": "plastindustri",
    "plastiska": "plastisk",
    "plastiskare": "plastisk",
    "plastiskares": "plastisk",
    "plastiskas": "plastisk",
    "plastiskast": "plastisk",
    "plastiskaste": "plastisk",
    "plastiskastes": "plastisk",
    "plastiskasts": "plastisk",
    "plastiske": "plastisk",
    "plastiskes": "plastisk",
    "plastisks": "plastisk",
    "plastiskt": "plastisk",
    "plastiskts": "plastisk",
    "plastkorkar": "plastkork",
    "plastkorkarna": "plastkork",
    "plastkorkarnas": "plastkork",
    "plastkorkars": "plastkork",
    "plastkorken": "plastkork",
    "plastkorkens": "plastkork",
    "plastkorks": "plastkork",
    "plastkorten": "plastkort",
    "plastkortens": "plastkort",
    "plastkortet": "plastkort",
    "plastkortets": "plastkort",
    "plastkorts": "plastkort",
    "plastlaminaten": "plastlaminat",
    "plastlaminatens": "plastlaminat",
    "plastlaminatet": "plastlaminat",
    "plastlaminatets": "plastlaminat",
    "plastlaminats": "plastlaminat",
    "plastlurar": "plastlur",
    "plastlurarna": "plastlur",
    "plastlurarnas": "plastlur",
    "plastlurars": "plastlur",
    "plastluren": "plastlur",
    "plastlurens": "plastlur",
    "plastlurs": "plastlur",
    "plastnaven": "plastnav",
    "plastnavens": "plastnav",
    "plastnavet": "plastnav",
    "plastnavets": "plastnav",
    "plastnavs": "plastnav",
    "plastpilar": "plastpil",
    "plastpilarna": "plastpil",
    "plastpilarnas": "plastpil",
    "plastpilars": "plastpil",
    "plastpilen": "plastpil",
    "plastpilens": "plastpil",
    "plastpils": "plastpil",
    "plastprylar": "plastpryl",
    "plastprylarna": "plastpryl",
    "plastprylarnas": "plastpryl",
    "plastprylars": "plastpryl",
    "plastprylen": "plastpryl",
    "plastprylens": "plastpryl",
    "plastpryls": "plastpryl",
    "plastpulk": "plastpulka",
    "plastpulkan": "plastpulka",
    "plastpulkans": "plastpulka",
    "plastpulkas": "plastpulka",
    "plastpulke": "plastpulka",
    "plastpulkor": "plastpulka",
    "plastpulkorna": "plastpulka",
    "plastpulkornas": "plastpulka",
    "plastpulkors": "plastpulka",
    "plastpulks": "plastpulka",
    "plastpås": "plastpåse",
    "plastpåsar": "plastpåse",
    "plastpåsarna": "plastpåse",
    "plastpåsarnas": "plastpåse",
    "plastpåsars": "plastpåse",
    "plastpåsen": "plastpåse",
    "plastpåsens": "plastpåse",
    "plastpåses": "plastpåse",
    "plastringar": "plastring",
    "plastringarna": "plastring",
    "plastringarnas": "plastring",
    "plastringars": "plastring",
    "plastringen": "plastring",
    "plastringens": "plastring",
    "plastrings": "plastring",
    "plastrongen": "plastrong",
    "plastrongens": "plastrong",
    "plastronger": "plastrong",
    "plastrongerna": "plastrong",
    "plastrongernas": "plastrong",
    "plastrongers": "plastrong",
    "plastrongs": "plastrong",
    "plasträfs": "plasträfsa",
    "plasträfsan": "plasträfsa",
    "plasträfsans": "plasträfsa",
    "plasträfsas": "plasträfsa",
    "plasträfse": "plasträfsa",
    "plasträfsor": "plasträfsa",
    "plasträfsorna": "plasträfsa",
    "plasträfsornas": "plasträfsa",
    "plasträfsors": "plasträfsa",
    "plasts": "plast",
    "plastskedar": "plastsked",
    "plastskedarna": "plastsked",
    "plastskedarnas": "plastsked",
    "plastskedars": "plastsked",
    "plastskeden": "plastsked",
    "plastskedens": "plastsked",
    "plastskeds": "plastsked",
    "plastskivan": "plastskiva",
    "plastskivans": "plastskiva",
    "plastskivas": "plastskiva",
    "plastskive": "plastskiva",
    "plastskivor": "plastskiva",
    "plastskivorna": "plastskiva",
    "plastskivornas": "plastskiva",
    "plastskivors": "plastskiva",
    "plastskon": "plastsko",
    "plastskons": "plastsko",
    "plastskor": "plastsko",
    "plastskorna": "plastsko",
    "plastskornas": "plastsko",
    "plastskors": "plastsko",
    "plastskos": "plastsko",
    "plastspiralen": "plastspiral",
    "plastspiralens": "plastspiral",
    "plastspiraler": "plastspiral",
    "plastspiralerna": "plastspiral",
    "plastspiralernas": "plastspiral",
    "plastspiralers": "plastspiral",
    "plastspirals": "plastspiral",
    "plastsäckar": "plastsäck",
    "plastsäckarna": "plastsäck",
    "plastsäckarnas": "plastsäck",
    "plastsäckars": "plastsäck",
    "plastsäcken": "plastsäck",
    "plastsäckens": "plastsäck",
    "plastsäcks": "plastsäck",
    "plasttrumpeten": "plasttrumpet",
    "plasttrumpetens": "plasttrumpet",
    "plasttrumpeter": "plasttrumpet",
    "plasttrumpeterna": "plasttrumpet",
    "plasttrumpeternas": "plasttrumpet",
    "plasttrumpeters": "plasttrumpet",
    "plasttrumpets": "plasttrumpet",
    "plaståldern": "plastålder",
    "plastålderns": "plastålder",
    "plastålders": "plastålder",
    "platanen": "platan",
    "platanens": "platan",
    "plataner": "platan",
    "platanerna": "platan",
    "platanernas": "platan",
    "plataners": "platan",
    "platans": "platan",
    "platinablonda": "platinablond",
    "platinablondare": "platinablond",
    "platinablondares": "platinablond",
    "platinablondas": "platinablond",
    "platinablondast": "platinablond",
    "platinablondaste": "platinablond",
    "platinablondastes": "platinablond",
    "platinablondasts": "platinablond",
    "platinablonde": "platinablond",
    "platinablondes": "platinablond",
    "platinablondheten": "platinablondhet",
    "platinablondhetens": "platinablondhet",
    "platinablondhets": "platinablondhet",
    "platinablonds": "platinablond",
    "platinablont": "platinablond",
    "platinablonts": "platinablond",
    "platinan": "platina",
    "platinans": "platina",
    "platinas": "platina",
    "platinerad": "platinera",
    "platinerade": "platinera",
    "platinerades": "platinera",
    "platinerads": "platinera",
    "platinerande": "platinera",
    "platineranden": "platinerande",
    "platinerandena": "platinerande",
    "platinerandenas": "platinerande",
    "platinerandens": "platinerande",
    "platinerandes": "platinerande",
    "platinerandet": "platinerande",
    "platinerandets": "platinerande",
    "platinerar": "platinera",
    "platineras": "platinera",
    "platinerat": "platinera",
    "platinerats": "platinera",
    "platinerbara": "platinerbar",
    "platinerbarare": "platinerbar",
    "platinerbarares": "platinerbar",
    "platinerbaras": "platinerbar",
    "platinerbarast": "platinerbar",
    "platinerbaraste": "platinerbar",
    "platinerbarastes": "platinerbar",
    "platinerbarasts": "platinerbar",
    "platinerbare": "platinerbar",
    "platinerbares": "platinerbar",
    "platinerbarheten": "platinerbarhet",
    "platinerbarhetens": "platinerbarhet",
    "platinerbarhets": "platinerbarhet",
    "platinerbars": "platinerbar",
    "platinerbart": "platinerbar",
    "platinerbarts": "platinerbar",
    "platineringar": "platinering",
    "platineringarna": "platinering",
    "platineringarnas": "platinering",
    "platineringars": "platinering",
    "platineringen": "platinering",
    "platineringens": "platinering",
    "platinerings": "platinering",
    "platonikern": "platoniker",
    "platonikerna": "platoniker",
    "platonikernas": "platoniker",
    "platonikerns": "platoniker",
    "platonikers": "platoniker",
    "platoniska": "platonisk",
    "platoniskare": "platonisk",
    "platoniskares": "platonisk",
    "platoniskas": "platonisk",
    "platoniskast": "platonisk",
    "platoniskaste": "platonisk",
    "platoniskastes": "platonisk",
    "platoniskasts": "platonisk",
    "platoniske": "platonisk",
    "platoniskes": "platonisk",
    "platonisks": "platonisk",
    "platoniskt": "platonisk",
    "platoniskts": "platonisk",
    "platonismen": "platonism",
    "platonismens": "platonism",
    "platonismer": "platonism",
    "platonismerna": "platonism",
    "platonismernas": "platonism",
    "platonismers": "platonism",
    "platonisms": "platonism",
    "platonska": "platonsk",
    "platonskare": "platonsk",
    "platonskares": "platonsk",
    "platonskas": "platonsk",
    "platonskast": "platonsk",
    "platonskaste": "platonsk",
    "platonskastes": "platonsk",
    "platonskasts": "platonsk",
    "platonske": "platonsk",
    "platonskes": "platonsk",
    "platonsks": "platonsk",
    "platonskt": "platonsk",
    "platonskts": "platonsk",
    "platsade": "platsa",
    "platsades": "platsa",
    "platsande": "platsa",
    "platsanden": "platsande",
    "platsandena": "platsande",
    "platsandenas": "platsande",
    "platsandens": "platsande",
    "platsandes": "platsande",
    "platsandet": "platsande",
    "platsandets": "platsande",
    "platsansökans": "platsansökan",
    "platsansökningar": "platsansökning",
    "platsansökningarna": "platsansökning",
    "platsansökningarnas": "platsansökning",
    "platsansökningars": "platsansökning",
    "platsansökningen": "platsansökning",
    "platsansökningens": "platsansökning",
    "platsansöknings": "platsansökning",
    "platsar": "platsa",
    "platsas": "platsa",
    "platsat": "platsa",
    "platsats": "platsa",
    "platsbiljetten": "platsbiljett",
    "platsbiljettens": "platsbiljett",
    "platsbiljetter": "platsbiljett",
    "platsbiljetterna": "platsbiljett",
    "platsbiljetternas": "platsbiljett",
    "platsbiljetters": "platsbiljett",
    "platsbiljetts": "platsbiljett",
    "platschefen": "platschef",
    "platschefens": "platschef",
    "platschefer": "platschef",
    "platscheferna": "platschef",
    "platschefernas": "platschef",
    "platschefers": "platschef",
    "platschefs": "platschef",
    "platsen": "plats",
    "platsens": "plats",
    "platser": "plats",
    "platserna": "plats",
    "platsernas": "plats",
    "platsers": "plats",
    "platsmässiga": "platsmässig",
    "platsmässigare": "platsmässig",
    "platsmässigares": "platsmässig",
    "platsmässigas": "platsmässig",
    "platsmässigast": "platsmässig",
    "platsmässigaste": "platsmässig",
    "platsmässigastes": "platsmässig",
    "platsmässigasts": "platsmässig",
    "platsmässige": "platsmässig",
    "platsmässiges": "platsmässig",
    "platsmässigs": "platsmässig",
    "platsmässigt": "platsmässig",
    "platsmässigts": "platsmässig",
    "platssiffer": "platssiffra",
    "platssiffran": "platssiffra",
    "platssiffrans": "platssiffra",
    "platssiffras": "platssiffra",
    "platssiffre": "platssiffra",
    "platssiffror": "platssiffra",
    "platssiffrorna": "platssiffra",
    "platssiffrornas": "platssiffra",
    "platssiffrors": "platssiffra",
    "platt": "platta",
    "platt-TV:na": "platt-TV",
    "platt-TV:ns": "platt-TV",
    "platt-TVn": "platt-TV",
    "platt-TVna": "platt-TV",
    "platt-TVnas": "platt-TV",
    "platt-TVns": "platt-TV",
    "platt-TVs": "platt-TV",
    "platt-tevear": "platt-teve",
    "platt-tevearna": "platt-teve",
    "platt-tevearnas": "platt-teve",
    "platt-tevears": "platt-teve",
    "platt-teven": "platt-teve",
    "platt-tevena": "platt-teve",
    "platt-tevenas": "platt-teve",
    "platt-tevens": "platt-teve",
    "platt-teves": "platt-teve",
    "platt-tv-n": "platt-tv",
    "platt-tv-na": "platt-tv",
    "platt-tv-nas": "platt-tv",
    "platt-tv-ns": "platt-tv",
    "platt-tv-s": "platt-tv",
    "platt-tv:n": "platt-tv",
    "platt-tv:nas": "platt-tv",
    "platt-tv:s": "platt-tv",
    "platta": "platt",
    "plattan": "platta",
    "plattans": "platta",
    "plattare": "platt",
    "plattares": "platt",
    "plattas": "platta",
    "plattast": "platt",
    "plattaste": "platt",
    "plattastes": "platt",
    "plattasts": "platt",
    "platte": "platta",
    "plattektoniken": "plattektonik",
    "plattektonikens": "plattektonik",
    "plattektoniks": "plattektonik",
    "plattes": "platt",
    "plattfilar": "plattfil",
    "plattfilarna": "plattfil",
    "plattfilarnas": "plattfil",
    "plattfilars": "plattfil",
    "plattfilen": "plattfil",
    "plattfilens": "plattfil",
    "plattfils": "plattfil",
    "plattfiskar": "plattfisk",
    "plattfiskarna": "plattfisk",
    "plattfiskarnas": "plattfisk",
    "plattfiskars": "plattfisk",
    "plattfisken": "plattfisk",
    "plattfiskens": "plattfisk",
    "plattfisks": "plattfisk",
    "plattformar": "plattform",
    "plattformarna": "plattform",
    "plattformarnas": "plattform",
    "plattformars": "plattform",
    "plattformen": "plattform",
    "plattformens": "plattform",
    "plattforms": "plattform",
    "plattfotade": "plattfotad",
    "plattfotades": "plattfotad",
    "plattfotads": "plattfotad",
    "plattfotat": "plattfotad",
    "plattfotats": "plattfotad",
    "plattfoten": "plattfot",
    "plattfotens": "plattfot",
    "plattfots": "plattfot",
    "plattheten": "platthet",
    "platthetens": "platthet",
    "plattheter": "platthet",
    "plattheterna": "platthet",
    "plattheternas": "platthet",
    "plattheters": "platthet",
    "platthets": "platthet",
    "plattingar": "platting",
    "plattingarna": "platting",
    "plattingarnas": "platting",
    "plattingars": "platting",
    "plattingen": "platting",
    "plattingens": "platting",
    "plattings": "platting",
    "plattityden": "plattityd",
    "plattitydens": "plattityd",
    "plattityder": "plattityd",
    "plattityderna": "plattityd",
    "plattitydernas": "plattityd",
    "plattityders": "plattityd",
    "plattityds": "plattityd",
    "plattjärnen": "plattjärn",
    "plattjärnens": "plattjärn",
    "plattjärnet": "plattjärn",
    "plattjärnets": "plattjärn",
    "plattjärns": "plattjärn",
    "plattläggningar": "plattläggning",
    "plattläggningarna": "plattläggning",
    "plattläggningarnas": "plattläggning",
    "plattläggningars": "plattläggning",
    "plattläggningen": "plattläggning",
    "plattläggningens": "plattläggning",
    "plattläggnings": "plattläggning",
    "plattläggningsproblemen": "plattläggningsproblem",
    "plattläggningsproblemens": "plattläggningsproblem",
    "plattläggningsproblemet": "plattläggningsproblem",
    "plattläggningsproblemets": "plattläggningsproblem",
    "plattläggningsproblems": "plattläggningsproblem",
    "plattmaskar": "plattmask",
    "plattmaskarna": "plattmask",
    "plattmaskarnas": "plattmask",
    "plattmaskars": "plattmask",
    "plattmasken": "plattmask",
    "plattmaskens": "plattmask",
    "plattmasks": "plattmask",
    "plattnaglade": "plattnaglad",
    "plattnaglades": "plattnaglad",
    "plattnaglads": "plattnaglad",
    "plattnaglat": "plattnaglad",
    "plattnaglats": "plattnaglad",
    "plattor": "platta",
    "plattorna": "platta",
    "plattornas": "platta",
    "plattors": "platta",
    "platts": "platta",
    "plattsömmar": "plattsöm",
    "plattsömmarna": "plattsöm",
    "plattsömmarnas": "plattsöm",
    "plattsömmars": "plattsöm",
    "plattsömmen": "plattsöm",
    "plattsömmens": "plattsöm",
    "plattsöms": "plattsöm",
    "plattysk": "plattyska",
    "plattyska": "plattysk",
    "plattyskan": "plattyska",
    "plattyskans": "plattyska",
    "plattyskare": "plattysk",
    "plattyskares": "plattysk",
    "plattyskas": "plattyska",
    "plattyskast": "plattysk",
    "plattyskaste": "plattysk",
    "plattyskastes": "plattysk",
    "plattyskasts": "plattysk",
    "plattyske": "plattysk",
    "plattyskes": "plattysk",
    "plattysks": "plattysk",
    "plattyskt": "plattysk",
    "plattyskts": "plattysk",
    "plattänger": "plattång",
    "plattängerna": "plattång",
    "plattängernas": "plattång",
    "plattängers": "plattång",
    "plattången": "plattång",
    "plattångens": "plattång",
    "plattångs": "plattång",
    "platåer": "platå",
    "platåerna": "platå",
    "platåernas": "platå",
    "platåers": "platå",
    "platåguppen": "platågupp",
    "platåguppens": "platågupp",
    "platåguppet": "platågupp",
    "platåguppets": "platågupp",
    "platågupps": "platågupp",
    "platån": "platå",
    "platåns": "platå",
    "platås": "platå",
    "plausibels": "plausibel",
    "plausibelt": "plausibel",
    "plausibelts": "plausibel",
    "plausibla": "plausibel",
    "plausiblare": "plausibel",
    "plausiblares": "plausibel",
    "plausiblas": "plausibel",
    "plausiblast": "plausibel",
    "plausiblaste": "plausibel",
    "plausiblastes": "plausibel",
    "plausiblasts": "plausibel",
    "plausible": "plausibel",
    "plausibles": "plausibel",
    "play-offen": "play-off",
    "play-offens": "play-off",
    "play-offet": "play-off",
    "play-offets": "play-off",
    "play-offs": "play-off",
    "playbacken": "playback",
    "playbackens": "playback",
    "playbacks": "playback",
    "playboyar": "playboy",
    "playboyarna": "playboy",
    "playboyarnas": "playboy",
    "playboyars": "playboy",
    "playboyen": "playboy",
    "playboyens": "playboy",
    "playboys": "playboy",
    "playboysarna": "playboy",
    "playboysarnas": "playboy",
    "playboysen": "playboy",
    "playboysens": "playboy",
    "plebejen": "plebej",
    "plebejens": "plebej",
    "plebejer": "plebej",
    "plebejerna": "plebej",
    "plebejernas": "plebej",
    "plebejers": "plebej",
    "plebejiska": "plebejisk",
    "plebejiskare": "plebejisk",
    "plebejiskares": "plebejisk",
    "plebejiskas": "plebejisk",
    "plebejiskast": "plebejisk",
    "plebejiskaste": "plebejisk",
    "plebejiskastes": "plebejisk",
    "plebejiskasts": "plebejisk",
    "plebejiske": "plebejisk",
    "plebejiskes": "plebejisk",
    "plebejisks": "plebejisk",
    "plebejiskt": "plebejisk",
    "plebejiskts": "plebejisk",
    "plebejs": "plebej",
    "plebisciten": "plebiscit",
    "plebiscitens": "plebiscit",
    "plebiscitet": "plebiscit",
    "plebiscitets": "plebiscit",
    "plebiscits": "plebiscit",
    "plebsen": "plebs",
    "plebsens": "plebs",
    "plejaden": "plejad",
    "plejadens": "plejad",
    "plejader": "plejad",
    "plejaderna": "plejad",
    "plejadernas": "plejad",
    "plejaders": "plejad",
    "plejads": "plejad",
    "plektra": "plektrum",
    "plektrana": "plektrum",
    "plektranas": "plektrum",
    "plektras": "plektrum",
    "plektrena": "plektrum",
    "plektrenas": "plektrum",
    "plektrer": "plektrum",
    "plektrers": "plektrum",
    "plektret": "plektrum",
    "plektrets": "plektrum",
    "plektronen": "plektron",
    "plektronens": "plektron",
    "plektronet": "plektron",
    "plektronets": "plektron",
    "plektrons": "plektron",
    "plektrumen": "plektrum",
    "plektrumens": "plektrum",
    "plektrumet": "plektrum",
    "plektrumets": "plektrum",
    "plektrums": "plektrum",
    "plena": "plenum",
    "plenana": "plenum",
    "plenanas": "plenum",
    "plenas": "plenum",
    "plenimålen": "plenimål",
    "plenimålens": "plenimål",
    "plenimålet": "plenimål",
    "plenimålets": "plenimål",
    "plenimåls": "plenimål",
    "plenumen": "plenum",
    "plenumens": "plenum",
    "plenumet": "plenum",
    "plenumets": "plenum",
    "plenums": "plenum",
    "pleonasmen": "pleonasm",
    "pleonasmens": "pleonasm",
    "pleonasmer": "pleonasm",
    "pleonasmerna": "pleonasm",
    "pleonasmernas": "pleonasm",
    "pleonasmers": "pleonasm",
    "pleonasms": "pleonasm",
    "pleonastiska": "pleonastisk",
    "pleonastiskare": "pleonastisk",
    "pleonastiskares": "pleonastisk",
    "pleonastiskas": "pleonastisk",
    "pleonastiskast": "pleonastisk",
    "pleonastiskaste": "pleonastisk",
    "pleonastiskastes": "pleonastisk",
    "pleonastiskasts": "pleonastisk",
    "pleonastiske": "pleonastisk",
    "pleonastiskes": "pleonastisk",
    "pleonastisks": "pleonastisk",
    "pleonastiskt": "pleonastisk",
    "pleonastiskts": "pleonastisk",
    "plesiosaurien": "plesiosaurie",
    "plesiosauriens": "plesiosaurie",
    "plesiosaurier": "plesiosaurie",
    "plesiosaurierna": "plesiosaurie",
    "plesiosauriernas": "plesiosaurie",
    "plesiosauriers": "plesiosaurie",
    "plesiosauries": "plesiosaurie",
    "pleuriten": "pleurit",
    "pleuritens": "pleurit",
    "pleuriter": "pleurit",
    "pleuriterna": "pleurit",
    "pleuriternas": "pleurit",
    "pleuriters": "pleurit",
    "pleurits": "pleurit",
    "plexiglaset": "plexiglas",
    "plexiglasets": "plexiglas",
    "pligg": "pligga",
    "pliggad": "pligga",
    "pliggade": "pligga",
    "pliggades": "pligga",
    "pliggads": "pligga",
    "pliggande": "pligga",
    "pligganden": "pliggande",
    "pliggandena": "pliggande",
    "pliggandenas": "pliggande",
    "pliggandens": "pliggande",
    "pliggandes": "pliggande",
    "pliggandet": "pliggande",
    "pliggandets": "pliggande",
    "pliggar": "pligga",
    "pliggarna": "pligg",
    "pliggarnas": "pligg",
    "pliggars": "pligg",
    "pliggas": "pligga",
    "pliggat": "pligga",
    "pliggats": "pligga",
    "pliggen": "pligg",
    "pliggens": "pligg",
    "pliggs": "pligg",
    "pliktade": "plikta",
    "pliktades": "plikta",
    "pliktande": "plikta",
    "pliktanden": "pliktande",
    "pliktandena": "pliktande",
    "pliktandenas": "pliktande",
    "pliktandens": "pliktande",
    "pliktandes": "pliktande",
    "pliktandet": "pliktande",
    "pliktandets": "pliktande",
    "pliktar": "plikta",
    "pliktas": "plikta",
    "pliktat": "plikta",
    "pliktats": "plikta",
    "plikten": "plikt",
    "pliktens": "plikt",
    "plikter": "plikt",
    "plikterna": "plikt",
    "plikternas": "plikt",
    "plikters": "plikt",
    "pliktexemplaren": "pliktexemplar",
    "pliktexemplarens": "pliktexemplar",
    "pliktexemplaret": "pliktexemplar",
    "pliktexemplarets": "pliktexemplar",
    "pliktexemplars": "pliktexemplar",
    "pliktfäll": "pliktfälla",
    "pliktfällande": "pliktfälla",
    "pliktfällanden": "pliktfällande",
    "pliktfällandena": "pliktfällande",
    "pliktfällandenas": "pliktfällande",
    "pliktfällandens": "pliktfällande",
    "pliktfällandes": "pliktfällande",
    "pliktfällandet": "pliktfällande",
    "pliktfällandets": "pliktfällande",
    "pliktfällas": "pliktfälla",
    "pliktfälld": "pliktfälla",
    "pliktfällda": "pliktfälla",
    "pliktfälldas": "pliktfälla",
    "pliktfällde": "pliktfälla",
    "pliktfälldes": "pliktfälla",
    "pliktfällds": "pliktfälla",
    "pliktfäller": "pliktfälla",
    "pliktfälles": "pliktfälla",
    "pliktfälls": "pliktfälla",
    "pliktfällt": "pliktfälla",
    "pliktfällts": "pliktfälla",
    "pliktförgätens": "pliktförgäten",
    "pliktförgätet": "pliktförgäten",
    "pliktförgätets": "pliktförgäten",
    "pliktförgätna": "pliktförgäten",
    "pliktförgätnare": "pliktförgäten",
    "pliktförgätnares": "pliktförgäten",
    "pliktförgätnas": "pliktförgäten",
    "pliktförgätnast": "pliktförgäten",
    "pliktförgätnaste": "pliktförgäten",
    "pliktförgätnastes": "pliktförgäten",
    "pliktförgätnasts": "pliktförgäten",
    "pliktförgätne": "pliktförgäten",
    "pliktförgätnes": "pliktförgäten",
    "plikthuggar": "plikthuggare",
    "plikthuggaren": "plikthuggare",
    "plikthuggarens": "plikthuggare",
    "plikthuggares": "plikthuggare",
    "plikthuggarna": "plikthuggare",
    "plikthuggarnas": "plikthuggare",
    "pliktiga": "pliktig",
    "pliktigare": "pliktig",
    "pliktigares": "pliktig",
    "pliktigas": "pliktig",
    "pliktigast": "pliktig",
    "pliktigaste": "pliktig",
    "pliktigastes": "pliktig",
    "pliktigasts": "pliktig",
    "pliktige": "pliktig",
    "pliktiges": "pliktig",
    "pliktigs": "pliktig",
    "pliktigt": "pliktig",
    "pliktigts": "pliktig",
    "pliktkänslan": "pliktkänsla",
    "pliktkänslans": "pliktkänsla",
    "pliktkänslas": "pliktkänsla",
    "pliktkänsle": "pliktkänsla",
    "pliktkänslo": "pliktkänsla",
    "pliktmedvetens": "pliktmedveten",
    "pliktmedvetet": "pliktmedveten",
    "pliktmedvetets": "pliktmedveten",
    "pliktmedvetna": "pliktmedveten",
    "pliktmedvetnare": "pliktmedveten",
    "pliktmedvetnares": "pliktmedveten",
    "pliktmedvetnas": "pliktmedveten",
    "pliktmedvetnast": "pliktmedveten",
    "pliktmedvetnaste": "pliktmedveten",
    "pliktmedvetnastes": "pliktmedveten",
    "pliktmedvetnasts": "pliktmedveten",
    "pliktmedvetne": "pliktmedveten",
    "pliktmedvetnes": "pliktmedveten",
    "pliktmässiga": "pliktmässig",
    "pliktmässigare": "pliktmässig",
    "pliktmässigares": "pliktmässig",
    "pliktmässigas": "pliktmässig",
    "pliktmässigast": "pliktmässig",
    "pliktmässigaste": "pliktmässig",
    "pliktmässigastes": "pliktmässig",
    "pliktmässigasts": "pliktmässig",
    "pliktmässige": "pliktmässig",
    "pliktmässiges": "pliktmässig",
    "pliktmässigs": "pliktmässig",
    "pliktmässigt": "pliktmässig",
    "pliktmässigts": "pliktmässig",
    "plikts": "plikt",
    "pliktskyldiga": "pliktskyldig",
    "pliktskyldigare": "pliktskyldig",
    "pliktskyldigares": "pliktskyldig",
    "pliktskyldigas": "pliktskyldig",
    "pliktskyldigast": "pliktskyldig",
    "pliktskyldigaste": "pliktskyldig",
    "pliktskyldigastes": "pliktskyldig",
    "pliktskyldigasts": "pliktskyldig",
    "pliktskyldige": "pliktskyldig",
    "pliktskyldiges": "pliktskyldig",
    "pliktskyldigheten": "pliktskyldighet",
    "pliktskyldighetens": "pliktskyldighet",
    "pliktskyldighets": "pliktskyldighet",
    "pliktskyldigs": "pliktskyldig",
    "pliktskyldigt": "pliktskyldig",
    "pliktskyldigts": "pliktskyldig",
    "plikttrogens": "plikttrogen",
    "plikttroget": "plikttrogen",
    "plikttrogets": "plikttrogen",
    "plikttrogna": "plikttrogen",
    "plikttrognare": "plikttrogen",
    "plikttrognares": "plikttrogen",
    "plikttrognas": "plikttrogen",
    "plikttrognast": "plikttrogen",
    "plikttrognaste": "plikttrogen",
    "plikttrognastes": "plikttrogen",
    "plikttrognasts": "plikttrogen",
    "plikttrogne": "plikttrogen",
    "plikttrognes": "plikttrogen",
    "pliktår": "pliktåra",
    "pliktåran": "pliktåra",
    "pliktårans": "pliktåra",
    "pliktåras": "pliktåra",
    "pliktåre": "pliktåra",
    "pliktåror": "pliktåra",
    "pliktårorna": "pliktåra",
    "pliktårornas": "pliktåra",
    "pliktårors": "pliktåra",
    "pliktårs": "pliktåra",
    "plin": "pli",
    "plingen": "pling",
    "plingens": "pling",
    "plinget": "pling",
    "plingets": "pling",
    "plings": "pling",
    "plins": "pli",
    "plintar": "plint",
    "plintarna": "plint",
    "plintarnas": "plint",
    "plintars": "plint",
    "plinten": "plint",
    "plintens": "plint",
    "plints": "plint",
    "pliocens": "pliocen",
    "plir": "plira",
    "plirade": "plira",
    "plirades": "plira",
    "plirande": "plira",
    "pliranden": "plirande",
    "plirandena": "plirande",
    "plirandenas": "plirande",
    "plirandens": "plirande",
    "plirandes": "plirande",
    "plirandet": "plirande",
    "plirandets": "plirande",
    "plirar": "plira",
    "pliras": "plira",
    "plirat": "plira",
    "plirats": "plira",
    "pliriga": "plirig",
    "plirigare": "plirig",
    "plirigares": "plirig",
    "plirigas": "plirig",
    "plirigast": "plirig",
    "plirigaste": "plirig",
    "plirigastes": "plirig",
    "plirigasts": "plirig",
    "plirige": "plirig",
    "pliriges": "plirig",
    "plirigs": "plirig",
    "plirigt": "plirig",
    "plirigts": "plirig",
    "plis": "pli",
    "plisserad": "plissera",
    "plisserade": "plissera",
    "plisserades": "plissera",
    "plisserads": "plissera",
    "plisserande": "plissera",
    "plisseranden": "plisserande",
    "plisserandena": "plisserande",
    "plisserandenas": "plisserande",
    "plisserandens": "plisserande",
    "plisserandes": "plisserande",
    "plisserandet": "plisserande",
    "plisserandets": "plisserande",
    "plisserar": "plissera",
    "plisseras": "plissera",
    "plisserat": "plissera",
    "plisserats": "plissera",
    "plisserbara": "plisserbar",
    "plisserbarare": "plisserbar",
    "plisserbarares": "plisserbar",
    "plisserbaras": "plisserbar",
    "plisserbarast": "plisserbar",
    "plisserbaraste": "plisserbar",
    "plisserbarastes": "plisserbar",
    "plisserbarasts": "plisserbar",
    "plisserbare": "plisserbar",
    "plisserbares": "plisserbar",
    "plisserbarheten": "plisserbarhet",
    "plisserbarhetens": "plisserbarhet",
    "plisserbarhets": "plisserbarhet",
    "plisserbars": "plisserbar",
    "plisserbart": "plisserbar",
    "plisserbarts": "plisserbar",
    "plisseringar": "plissering",
    "plisseringarna": "plissering",
    "plisseringarnas": "plissering",
    "plisseringars": "plissering",
    "plisseringen": "plissering",
    "plisseringens": "plissering",
    "plisserings": "plissering",
    "plisséer": "plissé",
    "plisséerna": "plissé",
    "plisséernas": "plissé",
    "plisséers": "plissé",
    "plissén": "plissé",
    "plisséns": "plissé",
    "plissés": "plissé",
    "plistern": "plister",
    "plisterns": "plister",
    "plisters": "plister",
    "plistrar": "plister",
    "plistrarna": "plister",
    "plistrarnas": "plister",
    "plistrars": "plister",
    "plit": "plita",
    "plitade": "plita",
    "plitades": "plita",
    "plitan": "plita",
    "plitande": "plita",
    "plitanden": "plitande",
    "plitandena": "plitande",
    "plitandenas": "plitande",
    "plitandens": "plitande",
    "plitandes": "plitande",
    "plitandet": "plitande",
    "plitandets": "plitande",
    "plitans": "plita",
    "plitar": "plita",
    "plitarna": "plit",
    "plitarnas": "plit",
    "plitars": "plit",
    "plitas": "plita",
    "plitat": "plita",
    "plitats": "plita",
    "plite": "plita",
    "pliten": "plit",
    "plitens": "plit",
    "plitet": "plit",
    "plitets": "plit",
    "plitor": "plita",
    "plitorna": "plita",
    "plitornas": "plita",
    "plitors": "plita",
    "plits": "plita",
    "plock": "plocka",
    "plockad": "plocka",
    "plockade": "plocka",
    "plockades": "plocka",
    "plockads": "plocka",
    "plockande": "plocka",
    "plockanden": "plockande",
    "plockandena": "plockande",
    "plockandenas": "plockande",
    "plockandens": "plockande",
    "plockandes": "plockande",
    "plockandet": "plockande",
    "plockandets": "plockande",
    "plockar": "plockare",
    "plockaren": "plockare",
    "plockarens": "plockare",
    "plockares": "plockare",
    "plockarna": "plockare",
    "plockarnas": "plockare",
    "plockas": "plocka",
    "plockat": "plocka",
    "plockats": "plocka",
    "plocket": "plock",
    "plockets": "plock",
    "plockiga": "plockig",
    "plockigare": "plockig",
    "plockigares": "plockig",
    "plockigas": "plockig",
    "plockigast": "plockig",
    "plockigaste": "plockig",
    "plockigastes": "plockig",
    "plockigasts": "plockig",
    "plockige": "plockig",
    "plockiges": "plockig",
    "plockigheten": "plockighet",
    "plockighetens": "plockighet",
    "plockighets": "plockighet",
    "plockigs": "plockig",
    "plockigt": "plockig",
    "plockigts": "plockig",
    "plockmaten": "plockmat",
    "plockmatens": "plockmat",
    "plockmats": "plockmat",
    "plocks": "plock",
    "plog": "ploga",
    "plogad": "ploga",
    "plogade": "ploga",
    "plogades": "ploga",
    "plogads": "ploga",
    "plogande": "ploga",
    "ploganden": "plogande",
    "plogandena": "plogande",
    "plogandenas": "plogande",
    "plogandens": "plogande",
    "plogandes": "plogande",
    "plogandet": "plogande",
    "plogandets": "plogande",
    "plogar": "ploga",
    "plogarna": "plog",
    "plogarnas": "plog",
    "plogars": "plog",
    "plogas": "ploga",
    "plogat": "ploga",
    "plogats": "ploga",
    "plogbenen": "plogben",
    "plogbenens": "plogben",
    "plogbenet": "plogben",
    "plogbenets": "plogben",
    "plogbens": "plogben",
    "plogbillar": "plogbill",
    "plogbillarna": "plogbill",
    "plogbillarnas": "plogbill",
    "plogbillars": "plogbill",
    "plogbillen": "plogbill",
    "plogbillens": "plogbill",
    "plogbills": "plogbill",
    "plogen": "plog",
    "plogens": "plog",
    "plogfår": "plogfåra",
    "plogfåran": "plogfåra",
    "plogfårans": "plogfåra",
    "plogfåras": "plogfåra",
    "plogfåre": "plogfåra",
    "plogfåror": "plogfåra",
    "plogfårorna": "plogfåra",
    "plogfårornas": "plogfåra",
    "plogfårors": "plogfåra",
    "plogfårs": "plogfåra",
    "plogs": "plog",
    "plogtilt": "plogtilta",
    "plogtiltan": "plogtilta",
    "plogtiltans": "plogtilta",
    "plogtiltas": "plogtilta",
    "plogtilte": "plogtilta",
    "plogtiltor": "plogtilta",
    "plogtiltorna": "plogtilta",
    "plogtiltornas": "plogtilta",
    "plogtiltors": "plogtilta",
    "plogtilts": "plogtilta",
    "plojar": "ploj",
    "plojarna": "ploj",
    "plojarnas": "ploj",
    "plojars": "ploj",
    "plojen": "ploj",
    "plojens": "ploj",
    "plojer": "ploj",
    "plojerna": "ploj",
    "plojernas": "ploj",
    "plojers": "ploj",
    "plojs": "ploj",
    "plomben": "plomb",
    "plombens": "plomb",
    "plomber": "plomb",
    "plomberad": "plombera",
    "plomberade": "plombera",
    "plomberades": "plombera",
    "plomberads": "plombera",
    "plomberande": "plombera",
    "plomberanden": "plomberande",
    "plomberandena": "plomberande",
    "plomberandenas": "plomberande",
    "plomberandens": "plomberande",
    "plomberandes": "plomberande",
    "plomberandet": "plomberande",
    "plomberandets": "plomberande",
    "plomberar": "plombera",
    "plomberas": "plombera",
    "plomberat": "plombera",
    "plomberats": "plombera",
    "plomberbara": "plomberbar",
    "plomberbarare": "plomberbar",
    "plomberbarares": "plomberbar",
    "plomberbaras": "plomberbar",
    "plomberbarast": "plomberbar",
    "plomberbaraste": "plomberbar",
    "plomberbarastes": "plomberbar",
    "plomberbarasts": "plomberbar",
    "plomberbare": "plomberbar",
    "plomberbares": "plomberbar",
    "plomberbarheten": "plomberbarhet",
    "plomberbarhetens": "plomberbarhet",
    "plomberbarhets": "plomberbarhet",
    "plomberbars": "plomberbar",
    "plomberbart": "plomberbar",
    "plomberbarts": "plomberbar",
    "plomberingar": "plombering",
    "plomberingarna": "plombering",
    "plomberingarnas": "plombering",
    "plomberingars": "plombering",
    "plomberingen": "plombering",
    "plomberingens": "plombering",
    "plomberings": "plombering",
    "plomberna": "plomb",
    "plombernas": "plomb",
    "plombers": "plomb",
    "plombs": "plomb",
    "plommonbrännvinet": "plommonbrännvin",
    "plommonbrännvinets": "plommonbrännvin",
    "plommonbrännvins": "plommonbrännvin",
    "plommonen": "plommon",
    "plommonens": "plommon",
    "plommonet": "plommon",
    "plommonets": "plommon",
    "plommons": "plommon",
    "plommonstopen": "plommonstop",
    "plommonstopens": "plommonstop",
    "plommonstopet": "plommonstop",
    "plommonstopets": "plommonstop",
    "plommonstops": "plommonstop",
    "plommonsylten": "plommonsylt",
    "plommonsyltens": "plommonsylt",
    "plommonsylts": "plommonsylt",
    "plott": "plotta",
    "plottad": "plotta",
    "plottade": "plotta",
    "plottades": "plotta",
    "plottads": "plotta",
    "plottande": "plotta",
    "plottanden": "plottande",
    "plottandena": "plottande",
    "plottandenas": "plottande",
    "plottandens": "plottande",
    "plottandes": "plottande",
    "plottandet": "plottande",
    "plottandets": "plottande",
    "plottar": "plotta",
    "plottas": "plotta",
    "plottat": "plotta",
    "plottats": "plotta",
    "plotter": "plottra",
    "plotters": "plotter",
    "plottrade": "plottra",
    "plottrades": "plottra",
    "plottrande": "plottra",
    "plottranden": "plottrande",
    "plottrandena": "plottrande",
    "plottrandenas": "plottrande",
    "plottrandens": "plottrande",
    "plottrandes": "plottrande",
    "plottrandet": "plottrande",
    "plottrandets": "plottrande",
    "plottrar": "plottra",
    "plottras": "plottra",
    "plottrat": "plottra",
    "plottrats": "plottra",
    "plottret": "plotter",
    "plottrets": "plotter",
    "plottriga": "plottrig",
    "plottrigare": "plottrig",
    "plottrigares": "plottrig",
    "plottrigas": "plottrig",
    "plottrigast": "plottrig",
    "plottrigaste": "plottrig",
    "plottrigastes": "plottrig",
    "plottrigasts": "plottrig",
    "plottrige": "plottrig",
    "plottriges": "plottrig",
    "plottrigheten": "plottrighet",
    "plottrighetens": "plottrighet",
    "plottrighets": "plottrighet",
    "plottrigs": "plottrig",
    "plottrigt": "plottrig",
    "plottrigts": "plottrig",
    "plufsiga": "plufsig",
    "plufsigare": "plufsig",
    "plufsigares": "plufsig",
    "plufsigas": "plufsig",
    "plufsigast": "plufsig",
    "plufsigaste": "plufsig",
    "plufsigastes": "plufsig",
    "plufsigasts": "plufsig",
    "plufsige": "plufsig",
    "plufsiges": "plufsig",
    "plufsigheten": "plufsighet",
    "plufsighetens": "plufsighet",
    "plufsighets": "plufsighet",
    "plufsigs": "plufsig",
    "plufsigt": "plufsig",
    "plufsigts": "plufsig",
    "plugg": "plugga",
    "pluggad": "plugga",
    "pluggade": "plugga",
    "pluggades": "plugga",
    "pluggads": "plugga",
    "pluggande": "plugga",
    "plugganden": "pluggande",
    "pluggandena": "pluggande",
    "pluggandenas": "pluggande",
    "pluggandens": "pluggande",
    "pluggandes": "pluggande",
    "pluggandet": "pluggande",
    "pluggandets": "pluggande",
    "pluggar": "plugga",
    "pluggarna": "plugg",
    "pluggarnas": "plugg",
    "pluggars": "plugg",
    "pluggas": "plugga",
    "pluggat": "plugga",
    "pluggats": "plugga",
    "pluggen": "plugg",
    "pluggens": "plugg",
    "plugget": "plugg",
    "pluggets": "plugg",
    "plugghästar": "plugghäst",
    "plugghästarna": "plugghäst",
    "plugghästarnas": "plugghäst",
    "plugghästars": "plugghäst",
    "plugghästen": "plugghäst",
    "plugghästens": "plugghäst",
    "plugghästs": "plugghäst",
    "pluggs": "plugg",
    "pluggskivlingar": "pluggskivling",
    "pluggskivlingarna": "pluggskivling",
    "pluggskivlingarnas": "pluggskivling",
    "pluggskivlingars": "pluggskivling",
    "pluggskivlingen": "pluggskivling",
    "pluggskivlingens": "pluggskivling",
    "pluggskivlings": "pluggskivling",
    "pluggämnen": "pluggämne",
    "pluggämnena": "pluggämne",
    "pluggämnenas": "pluggämne",
    "pluggämnens": "pluggämne",
    "pluggämnes": "pluggämne",
    "pluggämnet": "pluggämne",
    "pluggämnets": "pluggämne",
    "plumpa": "plump",
    "plumpade": "plumpa",
    "plumpades": "plumpa",
    "plumpande": "plumpa",
    "plumpanden": "plumpande",
    "plumpandena": "plumpande",
    "plumpandenas": "plumpande",
    "plumpandens": "plumpande",
    "plumpandes": "plumpande",
    "plumpandet": "plumpande",
    "plumpandets": "plumpande",
    "plumpar": "plumpa",
    "plumpare": "plump",
    "plumpares": "plump",
    "plumparna": "plump",
    "plumparnas": "plump",
    "plumpars": "plump",
    "plumpas": "plumpa",
    "plumpast": "plump",
    "plumpaste": "plump",
    "plumpastes": "plump",
    "plumpasts": "plump",
    "plumpat": "plumpa",
    "plumpats": "plumpa",
    "plumpe": "plump",
    "plumpen": "plump",
    "plumpens": "plump",
    "plumpes": "plump",
    "plumpheten": "plumphet",
    "plumphetens": "plumphet",
    "plumpheter": "plumphet",
    "plumpheterna": "plumphet",
    "plumpheternas": "plumphet",
    "plumpheters": "plumphet",
    "plumphets": "plumphet",
    "plumps": "plump",
    "plumpt": "plump",
    "plumpts": "plump",
    "plumpuddingar": "plumpudding",
    "plumpuddingarna": "plumpudding",
    "plumpuddingarnas": "plumpudding",
    "plumpuddingars": "plumpudding",
    "plumpuddingen": "plumpudding",
    "plumpuddingens": "plumpudding",
    "plumpuddings": "plumpudding",
    "plums": "plumsa",
    "plumsade": "plumsa",
    "plumsades": "plumsa",
    "plumsande": "plumsa",
    "plumsanden": "plumsande",
    "plumsandena": "plumsande",
    "plumsandenas": "plumsande",
    "plumsandens": "plumsande",
    "plumsandes": "plumsande",
    "plumsandet": "plumsande",
    "plumsandets": "plumsande",
    "plumsar": "plumsa",
    "plumsarna": "plums",
    "plumsarnas": "plums",
    "plumsars": "plums",
    "plumsas": "plumsa",
    "plumsat": "plumsa",
    "plumsats": "plumsa",
    "plumsen": "plums",
    "plumsens": "plums",
    "plumset": "plums",
    "plumsets": "plums",
    "plunder": "plundra",
    "plundrad": "plundra",
    "plundrade": "plundra",
    "plundrades": "plundra",
    "plundrads": "plundra",
    "plundrande": "plundra",
    "plundranden": "plundrande",
    "plundrandena": "plundrande",
    "plundrandenas": "plundrande",
    "plundrandens": "plundrande",
    "plundrandes": "plundrande",
    "plundrandet": "plundrande",
    "plundrandets": "plundrande",
    "plundrar": "plundra",
    "plundras": "plundra",
    "plundrat": "plundra",
    "plundrats": "plundra",
    "plundringar": "plundring",
    "plundringarna": "plundring",
    "plundringarnas": "plundring",
    "plundringars": "plundring",
    "plundringen": "plundring",
    "plundringens": "plundring",
    "plundrings": "plundring",
    "plundringstågen": "plundringståg",
    "plundringstågens": "plundringståg",
    "plundringståget": "plundringståg",
    "plundringstågets": "plundringståg",
    "plundringstågs": "plundringståg",
    "plunt": "plunta",
    "pluntan": "plunta",
    "pluntans": "plunta",
    "pluntas": "plunta",
    "plunte": "plunta",
    "pluntor": "plunta",
    "pluntorna": "plunta",
    "pluntornas": "plunta",
    "pluntors": "plunta",
    "plunts": "plunta",
    "plurala": "plural",
    "pluralare": "plural",
    "pluralares": "plural",
    "pluralas": "plural",
    "pluralast": "plural",
    "pluralaste": "plural",
    "pluralastes": "plural",
    "pluralasts": "plural",
    "plurale": "plural",
    "pluralen": "plural",
    "pluralens": "plural",
    "pluraler": "plural",
    "pluralerna": "plural",
    "pluralernas": "plural",
    "pluralers": "plural",
    "plurales": "plural",
    "pluralisen": "pluralis",
    "pluralisens": "pluralis",
    "pluralismen": "pluralism",
    "pluralismens": "pluralism",
    "pluralismer": "pluralism",
    "pluralismerna": "pluralism",
    "pluralismernas": "pluralism",
    "pluralismers": "pluralism",
    "pluralisms": "pluralism",
    "pluralistiska": "pluralistisk",
    "pluralistiskare": "pluralistisk",
    "pluralistiskares": "pluralistisk",
    "pluralistiskas": "pluralistisk",
    "pluralistiskast": "pluralistisk",
    "pluralistiskaste": "pluralistisk",
    "pluralistiskastes": "pluralistisk",
    "pluralistiskasts": "pluralistisk",
    "pluralistiske": "pluralistisk",
    "pluralistiskes": "pluralistisk",
    "pluralistisks": "pluralistisk",
    "pluralistiskt": "pluralistisk",
    "pluralistiskts": "pluralistisk",
    "pluraliteten": "pluralitet",
    "pluralitetens": "pluralitet",
    "pluraliteter": "pluralitet",
    "pluraliteterna": "pluralitet",
    "pluraliteternas": "pluralitet",
    "pluraliteters": "pluralitet",
    "pluralitets": "pluralitet",
    "plurals": "plural",
    "pluralt": "plural",
    "pluralts": "plural",
    "pluringar": "pluring",
    "pluringarna": "pluring",
    "pluringarnas": "pluring",
    "pluringars": "pluring",
    "pluringen": "pluring",
    "pluringens": "pluring",
    "plurings": "pluring",
    "pluripotenta": "pluripotent",
    "pluripotentas": "pluripotent",
    "pluripotente": "pluripotent",
    "pluripotentes": "pluripotent",
    "pluripotents": "pluripotent",
    "plurr": "plurra",
    "plurrade": "plurra",
    "plurrades": "plurra",
    "plurrande": "plurra",
    "plurranden": "plurrande",
    "plurrandena": "plurrande",
    "plurrandenas": "plurrande",
    "plurrandens": "plurrande",
    "plurrandes": "plurrande",
    "plurrandet": "plurrande",
    "plurrandets": "plurrande",
    "plurrar": "plurra",
    "plurras": "plurra",
    "plurrat": "plurra",
    "plurrats": "plurra",
    "plurret": "plurr",
    "plurrets": "plurr",
    "plurrs": "plurr",
    "plusgraden": "plusgrad",
    "plusgradens": "plusgrad",
    "plusgrader": "plusgrad",
    "plusgraderna": "plusgrad",
    "plusgradernas": "plusgrad",
    "plusgraders": "plusgrad",
    "plusgrads": "plusgrad",
    "pluskvamperfekt": "pluskvamperfektum",
    "pluskvamperfekten": "pluskvamperfektum",
    "pluskvamperfektens": "pluskvamperfektum",
    "pluskvamperfekter": "pluskvamperfektum",
    "pluskvamperfekterna": "pluskvamperfektum",
    "pluskvamperfekternas": "pluskvamperfektum",
    "pluskvamperfekters": "pluskvamperfektum",
    "pluskvamperfektet": "pluskvamperfektum",
    "pluskvamperfektets": "pluskvamperfektum",
    "pluskvamperfekts": "pluskvamperfektum",
    "pluskvamperfektumet": "pluskvamperfektum",
    "pluskvamperfektumets": "pluskvamperfektum",
    "pluskvamperfektums": "pluskvamperfektum",
    "pluspolen": "pluspol",
    "pluspolens": "pluspol",
    "pluspoler": "pluspol",
    "pluspolerna": "pluspol",
    "pluspolernas": "pluspol",
    "pluspolers": "pluspol",
    "pluspols": "pluspol",
    "plussade": "plussa",
    "plussades": "plussa",
    "plussande": "plussa",
    "plussanden": "plussande",
    "plussandena": "plussande",
    "plussandenas": "plussande",
    "plussandens": "plussande",
    "plussandes": "plussande",
    "plussandet": "plussande",
    "plussandets": "plussande",
    "plussar": "plussa",
    "plussas": "plussa",
    "plussat": "plussa",
    "plussats": "plussa",
    "plussiga": "plussig",
    "plussigare": "plussig",
    "plussigares": "plussig",
    "plussigas": "plussig",
    "plussigast": "plussig",
    "plussigaste": "plussig",
    "plussigastes": "plussig",
    "plussigasts": "plussig",
    "plussige": "plussig",
    "plussiges": "plussig",
    "plussigheten": "plussighet",
    "plussighetens": "plussighet",
    "plussighets": "plussighet",
    "plussigs": "plussig",
    "plussigt": "plussig",
    "plussigts": "plussig",
    "plusteckens": "plustecken",
    "plustecknen": "plustecken",
    "plustecknens": "plustecken",
    "plustecknet": "plustecken",
    "plustecknets": "plustecken",
    "plut": "pluta",
    "plutade": "pluta",
    "plutades": "pluta",
    "plutande": "pluta",
    "plutanden": "plutande",
    "plutandena": "plutande",
    "plutandenas": "plutande",
    "plutandens": "plutande",
    "plutandes": "plutande",
    "plutandet": "plutande",
    "plutandets": "plutande",
    "plutar": "pluta",
    "plutas": "pluta",
    "plutat": "pluta",
    "plutats": "pluta",
    "plutokraten": "plutokrat",
    "plutokratens": "plutokrat",
    "plutokrater": "plutokrat",
    "plutokraterna": "plutokrat",
    "plutokraternas": "plutokrat",
    "plutokraters": "plutokrat",
    "plutokratien": "plutokrati",
    "plutokratiens": "plutokrati",
    "plutokratier": "plutokrati",
    "plutokratierna": "plutokrati",
    "plutokratiernas": "plutokrati",
    "plutokratiers": "plutokrati",
    "plutokratin": "plutokrati",
    "plutokratins": "plutokrati",
    "plutokratis": "plutokrati",
    "plutokrats": "plutokrat",
    "plutonen": "pluton",
    "plutonens": "pluton",
    "plutoner": "pluton",
    "plutonerna": "pluton",
    "plutonernas": "pluton",
    "plutoners": "pluton",
    "plutoniet": "plutonium",
    "plutoniets": "plutonium",
    "plutoniska": "plutonisk",
    "plutoniskare": "plutonisk",
    "plutoniskares": "plutonisk",
    "plutoniskas": "plutonisk",
    "plutoniskast": "plutonisk",
    "plutoniskaste": "plutonisk",
    "plutoniskastes": "plutonisk",
    "plutoniskasts": "plutonisk",
    "plutoniske": "plutonisk",
    "plutoniskes": "plutonisk",
    "plutonisks": "plutonisk",
    "plutoniskt": "plutonisk",
    "plutoniskts": "plutonisk",
    "plutoniumet": "plutonium",
    "plutoniumets": "plutonium",
    "plutoniums": "plutonium",
    "plutons": "pluton",
    "pluttar": "plutt",
    "pluttarna": "plutt",
    "pluttarnas": "plutt",
    "pluttars": "plutt",
    "plutten": "plutt",
    "pluttens": "plutt",
    "pluttiga": "pluttig",
    "pluttigare": "pluttig",
    "pluttigares": "pluttig",
    "pluttigas": "pluttig",
    "pluttigast": "pluttig",
    "pluttigaste": "pluttig",
    "pluttigastes": "pluttig",
    "pluttigasts": "pluttig",
    "pluttige": "pluttig",
    "pluttiges": "pluttig",
    "pluttigheten": "pluttighet",
    "pluttighetens": "pluttighet",
    "pluttighets": "pluttighet",
    "pluttigs": "pluttig",
    "pluttigt": "pluttig",
    "pluttigts": "pluttig",
    "plutts": "plutt",
    "pluviala": "pluvial",
    "pluvialare": "pluvial",
    "pluvialares": "pluvial",
    "pluvialas": "pluvial",
    "pluvialast": "pluvial",
    "pluvialaste": "pluvial",
    "pluvialastes": "pluvial",
    "pluvialasts": "pluvial",
    "pluviale": "pluvial",
    "pluviales": "pluvial",
    "pluvialperioden": "pluvialperiod",
    "pluvialperiodens": "pluvialperiod",
    "pluvialperioder": "pluvialperiod",
    "pluvialperioderna": "pluvialperiod",
    "pluvialperiodernas": "pluvialperiod",
    "pluvialperioders": "pluvialperiod",
    "pluvialperiods": "pluvialperiod",
    "pluvials": "pluvial",
    "pluvialt": "pluvial",
    "pluvialts": "pluvial",
    "plymaschen": "plymasch",
    "plymaschens": "plymasch",
    "plymascher": "plymasch",
    "plymascherade": "plymascherad",
    "plymascherades": "plymascherad",
    "plymascherads": "plymascherad",
    "plymascherat": "plymascherad",
    "plymascherats": "plymascherad",
    "plymascherna": "plymasch",
    "plymaschernas": "plymasch",
    "plymaschers": "plymasch",
    "plymaschs": "plymasch",
    "plymen": "plym",
    "plymens": "plym",
    "plymer": "plym",
    "plymerna": "plym",
    "plymernas": "plym",
    "plymers": "plym",
    "plyms": "plym",
    "plymåer": "plymå",
    "plymåerna": "plymå",
    "plymåernas": "plymå",
    "plymåers": "plymå",
    "plymån": "plymå",
    "plymåns": "plymå",
    "plymås": "plymå",
    "plys": "plysa",
    "plysad": "plysa",
    "plysade": "plysa",
    "plysades": "plysa",
    "plysads": "plysa",
    "plysande": "plysa",
    "plysanden": "plysande",
    "plysandena": "plysande",
    "plysandenas": "plysande",
    "plysandens": "plysande",
    "plysandes": "plysande",
    "plysandet": "plysande",
    "plysandets": "plysande",
    "plysar": "plysa",
    "plysas": "plysa",
    "plysat": "plysa",
    "plysats": "plysa",
    "plyschen": "plysch",
    "plyschens": "plysch",
    "plyscher": "plysch",
    "plyscherna": "plysch",
    "plyschernas": "plysch",
    "plyschers": "plysch",
    "plyschs": "plysch",
    "plysmaskinen": "plysmaskin",
    "plysmaskinens": "plysmaskin",
    "plysmaskiner": "plysmaskin",
    "plysmaskinerna": "plysmaskin",
    "plysmaskinernas": "plysmaskin",
    "plysmaskiners": "plysmaskin",
    "plysmaskins": "plysmaskin",
    "plyten": "plyte",
    "plytena": "plyte",
    "plytenas": "plyte",
    "plytens": "plyte",
    "plytes": "plyte",
    "plytet": "plyte",
    "plytets": "plyte",
    "plywooden": "plywood",
    "plywoodens": "plywood",
    "plywoodfabriken": "plywoodfabrik",
    "plywoodfabrikens": "plywoodfabrik",
    "plywoodfabriker": "plywoodfabrik",
    "plywoodfabrikerna": "plywoodfabrik",
    "plywoodfabrikernas": "plywoodfabrik",
    "plywoodfabrikers": "plywoodfabrik",
    "plywoodfabriks": "plywoodfabrik",
    "plywoods": "plywood",
    "plädar": "pläd",
    "plädarna": "pläd",
    "plädarnas": "pläd",
    "plädars": "pläd",
    "pläden": "pläd",
    "plädens": "pläd",
    "pläder": "pläd",
    "pläderade": "plädera",
    "pläderades": "plädera",
    "pläderande": "plädera",
    "pläderanden": "pläderande",
    "pläderandena": "pläderande",
    "pläderandenas": "pläderande",
    "pläderandens": "pläderande",
    "pläderandes": "pläderande",
    "pläderandet": "pläderande",
    "pläderandets": "pläderande",
    "pläderar": "plädera",
    "pläderas": "plädera",
    "pläderat": "plädera",
    "pläderats": "plädera",
    "pläderingar": "plädering",
    "pläderingarna": "plädering",
    "pläderingarnas": "plädering",
    "pläderingars": "plädering",
    "pläderingen": "plädering",
    "pläderingens": "plädering",
    "pläderings": "plädering",
    "pläderna": "pläd",
    "plädernas": "pläd",
    "pläders": "pläd",
    "plädoajéer": "plädoajé",
    "plädoajéerna": "plädoajé",
    "plädoajéernas": "plädoajé",
    "plädoajéers": "plädoajé",
    "plädoajén": "plädoajé",
    "plädoajéns": "plädoajé",
    "plädoajés": "plädoajé",
    "pläds": "pläd",
    "plägade": "pläga",
    "plägades": "pläga",
    "plägande": "pläga",
    "pläganden": "plägande",
    "plägandena": "plägande",
    "plägandenas": "plägande",
    "plägandens": "plägande",
    "plägandes": "plägande",
    "plägandet": "plägande",
    "plägandets": "plägande",
    "plägar": "pläga",
    "plägas": "pläga",
    "plägat": "pläga",
    "plägats": "pläga",
    "plägseden": "plägsed",
    "plägsedens": "plägsed",
    "plägseder": "plägsed",
    "plägsederna": "plägsed",
    "plägsedernas": "plägsed",
    "plägseders": "plägsed",
    "plägseds": "plägsed",
    "pläterad": "plätera",
    "pläterade": "plätera",
    "pläterades": "plätera",
    "pläterads": "plätera",
    "pläterande": "plätera",
    "pläteranden": "pläterande",
    "pläterandena": "pläterande",
    "pläterandenas": "pläterande",
    "pläterandens": "pläterande",
    "pläterandes": "pläterande",
    "pläterandet": "pläterande",
    "pläterandets": "pläterande",
    "pläterar": "plätera",
    "pläteras": "plätera",
    "pläterat": "plätera",
    "pläterats": "plätera",
    "pläterbara": "pläterbar",
    "pläterbarare": "pläterbar",
    "pläterbarares": "pläterbar",
    "pläterbaras": "pläterbar",
    "pläterbarast": "pläterbar",
    "pläterbaraste": "pläterbar",
    "pläterbarastes": "pläterbar",
    "pläterbarasts": "pläterbar",
    "pläterbare": "pläterbar",
    "pläterbares": "pläterbar",
    "pläterbarheten": "pläterbarhet",
    "pläterbarhetens": "pläterbarhet",
    "pläterbarhets": "pläterbarhet",
    "pläterbars": "pläterbar",
    "pläterbart": "pläterbar",
    "pläterbarts": "pläterbar",
    "pläteringar": "plätering",
    "pläteringarna": "plätering",
    "pläteringarnas": "plätering",
    "pläteringars": "plätering",
    "pläteringen": "plätering",
    "pläteringens": "plätering",
    "pläterings": "plätering",
    "plätern": "pläter",
    "pläterns": "pläter",
    "pläters": "pläter",
    "plättar": "plätt",
    "plättarna": "plätt",
    "plättarnas": "plätt",
    "plättars": "plätt",
    "plätten": "plätt",
    "plättens": "plätt",
    "plättlaggar": "plättlagg",
    "plättlaggarna": "plättlagg",
    "plättlaggarnas": "plättlagg",
    "plättlaggars": "plättlagg",
    "plättlaggen": "plättlagg",
    "plättlaggens": "plättlagg",
    "plättlaggs": "plättlagg",
    "plätts": "plätt",
    "plåg": "plåga",
    "plågad": "plåga",
    "plågade": "plåga",
    "plågades": "plåga",
    "plågads": "plåga",
    "plågan": "plåga",
    "plågande": "plåga",
    "plåganden": "plågande",
    "plågandena": "plågande",
    "plågandenas": "plågande",
    "plågandens": "plågande",
    "plågandes": "plågande",
    "plågandet": "plågande",
    "plågandets": "plågande",
    "plågans": "plåga",
    "plågar": "plåga",
    "plågas": "plåga",
    "plågat": "plåga",
    "plågats": "plåga",
    "plåge": "plåga",
    "plågo": "plåga",
    "plågoandar": "plågoande",
    "plågoandarna": "plågoande",
    "plågoandarnas": "plågoande",
    "plågoandars": "plågoande",
    "plågoanden": "plågoande",
    "plågoandens": "plågoande",
    "plågoandes": "plågoande",
    "plågor": "plåga",
    "plågorisen": "plågoris",
    "plågorisens": "plågoris",
    "plågoriset": "plågoris",
    "plågorisets": "plågoris",
    "plågorna": "plåga",
    "plågornas": "plåga",
    "plågors": "plåga",
    "plågs": "plåga",
    "plågsamheten": "plågsamhet",
    "plågsamhetens": "plågsamhet",
    "plågsamheter": "plågsamhet",
    "plågsamheterna": "plågsamhet",
    "plågsamheternas": "plågsamhet",
    "plågsamheters": "plågsamhet",
    "plågsamhets": "plågsamhet",
    "plågsamma": "plågsam",
    "plågsammare": "plågsam",
    "plågsammares": "plågsam",
    "plågsammas": "plågsam",
    "plågsammast": "plågsam",
    "plågsammaste": "plågsam",
    "plågsammastes": "plågsam",
    "plågsammasts": "plågsam",
    "plågsamme": "plågsam",
    "plågsammes": "plågsam",
    "plågsams": "plågsam",
    "plågsamt": "plågsam",
    "plågsamts": "plågsam",
    "plånboken": "plånbok",
    "plånbokens": "plånbok",
    "plånboks": "plånbok",
    "plånboksfrågan": "plånboksfråga",
    "plånboksfrågans": "plånboksfråga",
    "plånboksfrågas": "plånboksfråga",
    "plånboksfråge": "plånboksfråga",
    "plånboksfrågor": "plånboksfråga",
    "plånboksfrågorna": "plånboksfråga",
    "plånboksfrågornas": "plånboksfråga",
    "plånboksfrågors": "plånboksfråga",
    "plånböcker": "plånbok",
    "plånböckerna": "plånbok",
    "plånböckernas": "plånbok",
    "plånböckers": "plånbok",
    "plånen": "plån",
    "plånens": "plån",
    "plånet": "plån",
    "plånets": "plån",
    "plåns": "plån",
    "plåsters": "plåster",
    "plåstrad": "plåstra",
    "plåstrade": "plåstra",
    "plåstrades": "plåstra",
    "plåstrads": "plåstra",
    "plåstrande": "plåstra",
    "plåstranden": "plåstrande",
    "plåstrandena": "plåstrande",
    "plåstrandenas": "plåstrande",
    "plåstrandens": "plåstrande",
    "plåstrandes": "plåstrande",
    "plåstrandet": "plåstrande",
    "plåstrandets": "plåstrande",
    "plåstrar": "plåstra",
    "plåstras": "plåstra",
    "plåstrat": "plåstra",
    "plåstrats": "plåstra",
    "plåstren": "plåster",
    "plåstrens": "plåster",
    "plåstret": "plåster",
    "plåstrets": "plåster",
    "plåt": "plåta",
    "plåtad": "plåta",
    "plåtade": "plåta",
    "plåtades": "plåta",
    "plåtads": "plåta",
    "plåtande": "plåta",
    "plåtanden": "plåtande",
    "plåtandena": "plåtande",
    "plåtandenas": "plåtande",
    "plåtandens": "plåtande",
    "plåtandes": "plåtande",
    "plåtandet": "plåtande",
    "plåtandets": "plåtande",
    "plåtar": "plåta",
    "plåtarna": "plåt",
    "plåtarnas": "plåt",
    "plåtars": "plåt",
    "plåtas": "plåta",
    "plåtat": "plåta",
    "plåtats": "plåta",
    "plåtbearbetningen": "plåtbearbetning",
    "plåtbearbetningens": "plåtbearbetning",
    "plåtbearbetnings": "plåtbearbetning",
    "plåten": "plåt",
    "plåtens": "plåt",
    "plåtfälgar": "plåtfälg",
    "plåtfälgarna": "plåtfälg",
    "plåtfälgarnas": "plåtfälg",
    "plåtfälgars": "plåtfälg",
    "plåtfälgen": "plåtfälg",
    "plåtfälgens": "plåtfälg",
    "plåtfälgs": "plåtfälg",
    "plåtfärgen": "plåtfärg",
    "plåtfärgens": "plåtfärg",
    "plåtfärger": "plåtfärg",
    "plåtfärgerna": "plåtfärg",
    "plåtfärgernas": "plåtfärg",
    "plåtfärgers": "plåtfärg",
    "plåtfärgs": "plåtfärg",
    "plåthuvar": "plåthuv",
    "plåthuvarna": "plåthuv",
    "plåthuvarnas": "plåthuv",
    "plåthuvars": "plåthuv",
    "plåthuven": "plåthuv",
    "plåthuvens": "plåthuv",
    "plåthuvs": "plåthuv",
    "plåtkanten": "plåtkant",
    "plåtkantens": "plåtkant",
    "plåtkanter": "plåtkant",
    "plåtkanterna": "plåtkant",
    "plåtkanternas": "plåtkant",
    "plåtkanters": "plåtkant",
    "plåtkants": "plåtkant",
    "plåtkärlen": "plåtkärl",
    "plåtkärlens": "plåtkärl",
    "plåtkärlet": "plåtkärl",
    "plåtkärlets": "plåtkärl",
    "plåtkärls": "plåtkärl",
    "plåtlisten": "plåtlist",
    "plåtlistens": "plåtlist",
    "plåtlister": "plåtlist",
    "plåtlisterna": "plåtlist",
    "plåtlisternas": "plåtlist",
    "plåtlisters": "plåtlist",
    "plåtlists": "plåtlist",
    "plåtmag": "plåtmage",
    "plåtmagar": "plåtmage",
    "plåtmagarna": "plåtmage",
    "plåtmagarnas": "plåtmage",
    "plåtmagars": "plåtmage",
    "plåtmagen": "plåtmage",
    "plåtmagens": "plåtmage",
    "plåtmages": "plåtmage",
    "plåtmags": "plåtmage",
    "plåtmynten": "plåtmynt",
    "plåtmyntens": "plåtmynt",
    "plåtmyntet": "plåtmynt",
    "plåtmyntets": "plåtmynt",
    "plåtmynts": "plåtmynt",
    "plåtnaven": "plåtnav",
    "plåtnavens": "plåtnav",
    "plåtnavet": "plåtnav",
    "plåtnavets": "plåtnav",
    "plåtnavs": "plåtnav",
    "plåts": "plåt",
    "plåtsaxar": "plåtsax",
    "plåtsaxarna": "plåtsax",
    "plåtsaxarnas": "plåtsax",
    "plåtsaxars": "plåtsax",
    "plåtsaxen": "plåtsax",
    "plåtsaxens": "plåtsax",
    "plåtschabraken": "plåtschabrak",
    "plåtschabrakens": "plåtschabrak",
    "plåtschabraket": "plåtschabrak",
    "plåtschabrakets": "plåtschabrak",
    "plåtschabraks": "plåtschabrak",
    "plåtskadan": "plåtskada",
    "plåtskadans": "plåtskada",
    "plåtskadas": "plåtskada",
    "plåtskade": "plåtskada",
    "plåtskador": "plåtskada",
    "plåtskadorna": "plåtskada",
    "plåtskadornas": "plåtskada",
    "plåtskadors": "plåtskada",
    "plåtslagar": "plåtslagare",
    "plåtslagaren": "plåtslagare",
    "plåtslagarens": "plåtslagare",
    "plåtslagares": "plåtslagare",
    "plåtslagarna": "plåtslagare",
    "plåtslagarnas": "plåtslagare",
    "plåtslagerier": "plåtslageri",
    "plåtslagerierna": "plåtslageri",
    "plåtslageriernas": "plåtslageri",
    "plåtslageriers": "plåtslageri",
    "plåtslageriet": "plåtslageri",
    "plåtslageriets": "plåtslageri",
    "plåtslageris": "plåtslageri",
    "plåtslagerit": "plåtslageri",
    "plåtslagerits": "plåtslageri",
    "plåttaken": "plåttak",
    "plåttakens": "plåttak",
    "plåttaket": "plåttak",
    "plåttakets": "plåttak",
    "plåttaks": "plåttak",
    "plåtverktygen": "plåtverktyg",
    "plåtverktygens": "plåtverktyg",
    "plåtverktyget": "plåtverktyg",
    "plåtverktygets": "plåtverktyg",
    "plåtverktygs": "plåtverktyg",
    "plöj": "plöja",
    "plöjande": "plöja",
    "plöjanden": "plöjande",
    "plöjandena": "plöjande",
    "plöjandenas": "plöjande",
    "plöjandens": "plöjande",
    "plöjandes": "plöjande",
    "plöjandet": "plöjande",
    "plöjandets": "plöjande",
    "plöjas": "plöja",
    "plöjd": "plöja",
    "plöjda": "plöja",
    "plöjdas": "plöja",
    "plöjde": "plöja",
    "plöjdes": "plöja",
    "plöjds": "plöja",
    "plöjer": "plöja",
    "plöjes": "plöja",
    "plöjningar": "plöjning",
    "plöjningarna": "plöjning",
    "plöjningarnas": "plöjning",
    "plöjningars": "plöjning",
    "plöjningen": "plöjning",
    "plöjningens": "plöjning",
    "plöjnings": "plöjning",
    "plöjs": "plöja",
    "plöjt": "plöja",
    "plöjts": "plöja",
    "plörösen": "plörös",
    "plörösens": "plörös",
    "plösar": "plös",
    "plösarna": "plös",
    "plösarnas": "plös",
    "plösars": "plös",
    "plösen": "plös",
    "plösens": "plös",
    "plötsliga": "plötslig",
    "plötsligare": "plötslig",
    "plötsligares": "plötslig",
    "plötsligas": "plötslig",
    "plötsligast": "plötslig",
    "plötsligaste": "plötslig",
    "plötsligastes": "plötslig",
    "plötsligasts": "plötslig",
    "plötslige": "plötslig",
    "plötsliges": "plötslig",
    "plötsligheten": "plötslighet",
    "plötslighetens": "plötslighet",
    "plötsligheter": "plötslighet",
    "plötsligheterna": "plötslighet",
    "plötsligheternas": "plötslighet",
    "plötsligheters": "plötslighet",
    "plötslighets": "plötslighet",
    "plötsligs": "plötslig",
    "plötsligt": "plötslig",
    "plötsligts": "plötslig",
    "pneumatiken": "pneumatik",
    "pneumatikens": "pneumatik",
    "pneumatiks": "pneumatik",
    "pneumatiska": "pneumatisk",
    "pneumatiskare": "pneumatisk",
    "pneumatiskares": "pneumatisk",
    "pneumatiskas": "pneumatisk",
    "pneumatiskast": "pneumatisk",
    "pneumatiskaste": "pneumatisk",
    "pneumatiskastes": "pneumatisk",
    "pneumatiskasts": "pneumatisk",
    "pneumatiske": "pneumatisk",
    "pneumatiskes": "pneumatisk",
    "pneumatisks": "pneumatisk",
    "pneumatiskt": "pneumatisk",
    "pneumatiskts": "pneumatisk",
    "pneumonien": "pneumoni",
    "pneumoniens": "pneumoni",
    "pneumonier": "pneumoni",
    "pneumonierna": "pneumoni",
    "pneumoniernas": "pneumoni",
    "pneumoniers": "pneumoni",
    "pneumonin": "pneumoni",
    "pneumonins": "pneumoni",
    "pneumonis": "pneumoni",
    "pocherad": "pochera",
    "pocherade": "pochera",
    "pocherades": "pochera",
    "pocherads": "pochera",
    "pocherande": "pochera",
    "pocheranden": "pocherande",
    "pocherandena": "pocherande",
    "pocherandenas": "pocherande",
    "pocherandens": "pocherande",
    "pocherandes": "pocherande",
    "pocherandet": "pocherande",
    "pocherandets": "pocherande",
    "pocherar": "pochera",
    "pocheras": "pochera",
    "pocherat": "pochera",
    "pocherats": "pochera",
    "pocherbara": "pocherbar",
    "pocherbarare": "pocherbar",
    "pocherbarares": "pocherbar",
    "pocherbaras": "pocherbar",
    "pocherbarast": "pocherbar",
    "pocherbaraste": "pocherbar",
    "pocherbarastes": "pocherbar",
    "pocherbarasts": "pocherbar",
    "pocherbare": "pocherbar",
    "pocherbares": "pocherbar",
    "pocherbarheten": "pocherbarhet",
    "pocherbarhetens": "pocherbarhet",
    "pocherbarhets": "pocherbarhet",
    "pocherbars": "pocherbar",
    "pocherbart": "pocherbar",
    "pocherbarts": "pocherbar",
    "pocheringar": "pochering",
    "pocheringarna": "pochering",
    "pocheringarnas": "pochering",
    "pocheringars": "pochering",
    "pocheringen": "pochering",
    "pocheringens": "pochering",
    "pocherings": "pochering",
    "pockade": "pocka",
    "pockades": "pocka",
    "pockande": "pocka",
    "pockanden": "pockande",
    "pockandena": "pockande",
    "pockandenas": "pockande",
    "pockandens": "pockande",
    "pockandes": "pockande",
    "pockandet": "pockande",
    "pockandets": "pockande",
    "pockar": "pocka",
    "pockas": "pocka",
    "pockat": "pocka",
    "pockats": "pocka",
    "pockers": "pocker",
    "pocketar": "pocket",
    "pocketarna": "pocket",
    "pocketarnas": "pocket",
    "pocketars": "pocket",
    "pocketboken": "pocketbok",
    "pocketbokens": "pocketbok",
    "pocketboks": "pocketbok",
    "pocketböcker": "pocketbok",
    "pocketböckerna": "pocketbok",
    "pocketböckernas": "pocketbok",
    "pocketböckers": "pocketbok",
    "pocketen": "pocket",
    "pocketens": "pocket",
    "pockets": "pocket",
    "podagern": "podager",
    "podagerns": "podager",
    "podagers": "podager",
    "podesten": "podest",
    "podestens": "podest",
    "podester": "podest",
    "podesterna": "podest",
    "podesternas": "podest",
    "podesters": "podest",
    "podests": "podest",
    "podie": "podium",
    "podier": "podium",
    "podierna": "podium",
    "podiernas": "podium",
    "podiers": "podium",
    "podiet": "podium",
    "podiets": "podium",
    "podiums": "podium",
    "podsoljorden": "podsoljord",
    "podsoljordens": "podsoljord",
    "podsoljords": "podsoljord",
    "poemen": "poem",
    "poemens": "poem",
    "poemet": "poem",
    "poemets": "poem",
    "poems": "poem",
    "poesien": "poesi",
    "poesiens": "poesi",
    "poesier": "poesi",
    "poesierna": "poesi",
    "poesiernas": "poesi",
    "poesiers": "poesi",
    "poesin": "poesi",
    "poesins": "poesi",
    "poesis": "poesi",
    "poesitraditionen": "poesitradition",
    "poesitraditionens": "poesitradition",
    "poesitraditioner": "poesitradition",
    "poesitraditionerna": "poesitradition",
    "poesitraditionernas": "poesitradition",
    "poesitraditioners": "poesitradition",
    "poesitraditions": "poesitradition",
    "poeten": "poet",
    "poetens": "poet",
    "poeter": "poet",
    "poeterna": "poet",
    "poeternas": "poet",
    "poeters": "poet",
    "poetiken": "poetik",
    "poetikens": "poetik",
    "poetiks": "poetik",
    "poetiska": "poetisk",
    "poetiskare": "poetisk",
    "poetiskares": "poetisk",
    "poetiskas": "poetisk",
    "poetiskast": "poetisk",
    "poetiskaste": "poetisk",
    "poetiskastes": "poetisk",
    "poetiskasts": "poetisk",
    "poetiske": "poetisk",
    "poetiskes": "poetisk",
    "poetisks": "poetisk",
    "poetiskt": "poetisk",
    "poetiskts": "poetisk",
    "poetiss": "poetissa",
    "poetissan": "poetissa",
    "poetissans": "poetissa",
    "poetissas": "poetissa",
    "poetisse": "poetissa",
    "poetissor": "poetissa",
    "poetissorna": "poetissa",
    "poetissornas": "poetissa",
    "poetissors": "poetissa",
    "poets": "poet",
    "pogrammen": "pogram",
    "pogrammens": "pogram",
    "pogrammet": "pogram",
    "pogrammets": "pogram",
    "pograms": "pogram",
    "pogromen": "pogrom",
    "pogromens": "pogrom",
    "pogromer": "pogrom",
    "pogromerna": "pogrom",
    "pogromernas": "pogrom",
    "pogromers": "pogrom",
    "pogroms": "pogrom",
    "pointerad": "pointera",
    "pointerade": "pointera",
    "pointerades": "pointera",
    "pointerads": "pointera",
    "pointerande": "pointera",
    "pointeranden": "pointerande",
    "pointerandena": "pointerande",
    "pointerandenas": "pointerande",
    "pointerandens": "pointerande",
    "pointerandes": "pointerande",
    "pointerandet": "pointerande",
    "pointerandets": "pointerande",
    "pointerar": "pointera",
    "pointeras": "pointera",
    "pointerat": "pointera",
    "pointerats": "pointera",
    "pointerbara": "pointerbar",
    "pointerbarare": "pointerbar",
    "pointerbarares": "pointerbar",
    "pointerbaras": "pointerbar",
    "pointerbarast": "pointerbar",
    "pointerbaraste": "pointerbar",
    "pointerbarastes": "pointerbar",
    "pointerbarasts": "pointerbar",
    "pointerbare": "pointerbar",
    "pointerbares": "pointerbar",
    "pointerbarheten": "pointerbarhet",
    "pointerbarhetens": "pointerbarhet",
    "pointerbarhets": "pointerbarhet",
    "pointerbars": "pointerbar",
    "pointerbart": "pointerbar",
    "pointerbarts": "pointerbar",
    "pointeringar": "pointering",
    "pointeringarna": "pointering",
    "pointeringarnas": "pointering",
    "pointeringars": "pointering",
    "pointeringen": "pointering",
    "pointeringens": "pointering",
    "pointerings": "pointering",
    "pointern": "pointer",
    "pointerns": "pointer",
    "pointers": "pointer",
    "pointillismen": "pointillism",
    "pointillismens": "pointillism",
    "pointillismer": "pointillism",
    "pointillismerna": "pointillism",
    "pointillismernas": "pointillism",
    "pointillismers": "pointillism",
    "pointillisms": "pointillism",
    "pointillistiska": "pointillistisk",
    "pointillistiskas": "pointillistisk",
    "pointillistiske": "pointillistisk",
    "pointillistiskes": "pointillistisk",
    "pointillistisks": "pointillistisk",
    "pointillistiskt": "pointillistisk",
    "pointillistiskts": "pointillistisk",
    "pointrar": "pointer",
    "pointrarna": "pointer",
    "pointrarnas": "pointer",
    "pointrars": "pointer",
    "pojk": "pojke",
    "pojkaktiga": "pojkaktig",
    "pojkaktigare": "pojkaktig",
    "pojkaktigares": "pojkaktig",
    "pojkaktigas": "pojkaktig",
    "pojkaktigast": "pojkaktig",
    "pojkaktigaste": "pojkaktig",
    "pojkaktigastes": "pojkaktig",
    "pojkaktigasts": "pojkaktig",
    "pojkaktige": "pojkaktig",
    "pojkaktiges": "pojkaktig",
    "pojkaktigheten": "pojkaktighet",
    "pojkaktighetens": "pojkaktighet",
    "pojkaktighets": "pojkaktighet",
    "pojkaktigs": "pojkaktig",
    "pojkaktigt": "pojkaktig",
    "pojkaktigts": "pojkaktig",
    "pojkar": "pojke",
    "pojkarna": "pojke",
    "pojkarnas": "pojke",
    "pojkars": "pojke",
    "pojkboken": "pojkbok",
    "pojkbokens": "pojkbok",
    "pojkboks": "pojkbok",
    "pojkbytingar": "pojkbyting",
    "pojkbytingarna": "pojkbyting",
    "pojkbytingarnas": "pojkbyting",
    "pojkbytingars": "pojkbyting",
    "pojkbytingen": "pojkbyting",
    "pojkbytingens": "pojkbyting",
    "pojkbytings": "pojkbyting",
    "pojkböcker": "pojkbok",
    "pojkböckerna": "pojkbok",
    "pojkböckernas": "pojkbok",
    "pojkböckers": "pojkbok",
    "pojkcykeln": "pojkcykel",
    "pojkcykelns": "pojkcykel",
    "pojkcykels": "pojkcykel",
    "pojkcyklar": "pojkcykel",
    "pojkcyklarna": "pojkcykel",
    "pojkcyklarnas": "pojkcykel",
    "pojkcyklars": "pojkcykel",
    "pojken": "pojke",
    "pojkens": "pojke",
    "pojkes": "pojke",
    "pojkflick": "pojkflicka",
    "pojkflickan": "pojkflicka",
    "pojkflickans": "pojkflicka",
    "pojkflickas": "pojkflicka",
    "pojkflicke": "pojkflicka",
    "pojkflickor": "pojkflicka",
    "pojkflickorna": "pojkflicka",
    "pojkflickornas": "pojkflicka",
    "pojkflickors": "pojkflicka",
    "pojkflicks": "pojkflicka",
    "pojkfnaskar": "pojkfnasker",
    "pojkfnaskarna": "pojkfnasker",
    "pojkfnaskarnas": "pojkfnasker",
    "pojkfnaskars": "pojkfnasker",
    "pojkfnaskern": "pojkfnasker",
    "pojkfnaskerns": "pojkfnasker",
    "pojkfnaskers": "pojkfnasker",
    "pojkfnaskrar": "pojkfnasker",
    "pojkfnaskrarna": "pojkfnasker",
    "pojkfnaskrarnas": "pojkfnasker",
    "pojkfnaskrars": "pojkfnasker",
    "pojkhalsar": "pojkhals",
    "pojkhalsarna": "pojkhals",
    "pojkhalsarnas": "pojkhals",
    "pojkhalsars": "pojkhals",
    "pojkhalsen": "pojkhals",
    "pojkhalsens": "pojkhals",
    "pojklagen": "pojklag",
    "pojklagens": "pojklag",
    "pojklaget": "pojklag",
    "pojklagets": "pojklag",
    "pojklags": "pojklag",
    "pojklagsmässiga": "pojklagsmässig",
    "pojklagsmässigare": "pojklagsmässig",
    "pojklagsmässigares": "pojklagsmässig",
    "pojklagsmässigas": "pojklagsmässig",
    "pojklagsmässigast": "pojklagsmässig",
    "pojklagsmässigaste": "pojklagsmässig",
    "pojklagsmässigastes": "pojklagsmässig",
    "pojklagsmässigasts": "pojklagsmässig",
    "pojklagsmässige": "pojklagsmässig",
    "pojklagsmässiges": "pojklagsmässig",
    "pojklagsmässigs": "pojklagsmässig",
    "pojklagsmässigt": "pojklagsmässig",
    "pojklagsmässigts": "pojklagsmässig",
    "pojknamnen": "pojknamn",
    "pojknamnens": "pojknamn",
    "pojknamnet": "pojknamn",
    "pojknamnets": "pojknamn",
    "pojknamns": "pojknamn",
    "pojkorkestern": "pojkorkester",
    "pojkorkesterns": "pojkorkester",
    "pojkorkesters": "pojkorkester",
    "pojkorkestrar": "pojkorkester",
    "pojkorkestrarna": "pojkorkester",
    "pojkorkestrarnas": "pojkorkester",
    "pojkorkestrars": "pojkorkester",
    "pojks": "pojke",
    "pojkskildringar": "pojkskildring",
    "pojkskildringarna": "pojkskildring",
    "pojkskildringarnas": "pojkskildring",
    "pojkskildringars": "pojkskildring",
    "pojkskildringen": "pojkskildring",
    "pojkskildringens": "pojkskildring",
    "pojkskildrings": "pojkskildring",
    "pojkspolingar": "pojkspoling",
    "pojkspolingarna": "pojkspoling",
    "pojkspolingarnas": "pojkspoling",
    "pojkspolingars": "pojkspoling",
    "pojkspolingen": "pojkspoling",
    "pojkspolingens": "pojkspoling",
    "pojkspolings": "pojkspoling",
    "pojkstrecken": "pojkstreck",
    "pojkstreckens": "pojkstreck",
    "pojkstrecket": "pojkstreck",
    "pojkstreckets": "pojkstreck",
    "pojkstrecks": "pojkstreck",
    "pojktyckes": "pojktycke",
    "pojktycket": "pojktycke",
    "pojktyckets": "pojktycke",
    "pojkvaskar": "pojkvasker",
    "pojkvaskarna": "pojkvasker",
    "pojkvaskarnas": "pojkvasker",
    "pojkvaskars": "pojkvasker",
    "pojkvaskern": "pojkvasker",
    "pojkvaskerns": "pojkvasker",
    "pojkvaskers": "pojkvasker",
    "pojkvaskrar": "pojkvasker",
    "pojkvaskrarna": "pojkvasker",
    "pojkvaskrarnas": "pojkvasker",
    "pojkvaskrars": "pojkvasker",
    "pojkvännen": "pojkvän",
    "pojkvännens": "pojkvän",
    "pojkvänner": "pojkvän",
    "pojkvännerna": "pojkvän",
    "pojkvännernas": "pojkvän",
    "pojkvänners": "pojkvän",
    "pojkväns": "pojkvän",
    "pojkvärldar": "pojkvärld",
    "pojkvärldarna": "pojkvärld",
    "pojkvärldarnas": "pojkvärld",
    "pojkvärldars": "pojkvärld",
    "pojkvärlden": "pojkvärld",
    "pojkvärldens": "pojkvärld",
    "pojkvärlds": "pojkvärld",
    "pokalen": "pokal",
    "pokalens": "pokal",
    "pokaler": "pokal",
    "pokalerna": "pokal",
    "pokalernas": "pokal",
    "pokalers": "pokal",
    "pokals": "pokal",
    "pokeransikten": "pokeransikte",
    "pokeransiktena": "pokeransikte",
    "pokeransiktenas": "pokeransikte",
    "pokeransiktens": "pokeransikte",
    "pokeransiktes": "pokeransikte",
    "pokeransiktet": "pokeransikte",
    "pokeransiktets": "pokeransikte",
    "pokeransikts": "pokeransikte",
    "pokerfaces": "pokerface",
    "pokerfacet": "pokerface",
    "pokerfacets": "pokerface",
    "pokern": "poker",
    "pokerns": "poker",
    "pokerpartier": "pokerparti",
    "pokerpartierna": "pokerparti",
    "pokerpartiernas": "pokerparti",
    "pokerpartiers": "pokerparti",
    "pokerpartiet": "pokerparti",
    "pokerpartiets": "pokerparti",
    "pokerpartis": "pokerparti",
    "pokerpartit": "pokerparti",
    "pokerpartits": "pokerparti",
    "pokerprofilen": "pokerprofil",
    "pokerprofilens": "pokerprofil",
    "pokerprofiler": "pokerprofil",
    "pokerprofilerna": "pokerprofil",
    "pokerprofilernas": "pokerprofil",
    "pokerprofilers": "pokerprofil",
    "pokerprofils": "pokerprofil",
    "pokers": "poker",
    "pokulerade": "pokulera",
    "pokulerades": "pokulera",
    "pokulerande": "pokulera",
    "pokuleranden": "pokulerande",
    "pokulerandena": "pokulerande",
    "pokulerandenas": "pokulerande",
    "pokulerandens": "pokulerande",
    "pokulerandes": "pokulerande",
    "pokulerandet": "pokulerande",
    "pokulerandets": "pokulerande",
    "pokulerar": "pokulera",
    "pokuleras": "pokulera",
    "pokulerat": "pokulera",
    "pokulerats": "pokulera",
    "pokuleringar": "pokulering",
    "pokuleringarna": "pokulering",
    "pokuleringarnas": "pokulering",
    "pokuleringars": "pokulering",
    "pokuleringen": "pokulering",
    "pokuleringens": "pokulering",
    "pokulerings": "pokulering",
    "polacken": "polack",
    "polackens": "polack",
    "polacker": "polack",
    "polackerna": "polack",
    "polackernas": "polack",
    "polackers": "polack",
    "polacks": "polack",
    "polade": "pola",
    "polades": "pola",
    "polande": "pola",
    "polanden": "polande",
    "polandena": "polande",
    "polandenas": "polande",
    "polandens": "polande",
    "polandes": "polande",
    "polandet": "polande",
    "polandets": "polande",
    "polar": "polare",
    "polara": "polar",
    "polarare": "polar",
    "polarares": "polar",
    "polaras": "polar",
    "polarast": "polar",
    "polaraste": "polar",
    "polarastes": "polar",
    "polarasts": "polar",
    "polardagen": "polardag",
    "polardagens": "polardag",
    "polardags": "polardag",
    "polardim": "polardimma",
    "polardimman": "polardimma",
    "polardimmans": "polardimma",
    "polardimmas": "polardimma",
    "polardimme": "polardimma",
    "polardimmor": "polardimma",
    "polardimmorna": "polardimma",
    "polardimmornas": "polardimma",
    "polardimmors": "polardimma",
    "polardims": "polardimma",
    "polare": "polar",
    "polaren": "polare",
    "polarens": "polare",
    "polares": "polare",
    "polarexpeditionen": "polarexpedition",
    "polarexpeditionens": "polarexpedition",
    "polarexpeditioner": "polarexpedition",
    "polarexpeditionerna": "polarexpedition",
    "polarexpeditionernas": "polarexpedition",
    "polarexpeditioners": "polarexpedition",
    "polarexpeditions": "polarexpedition",
    "polarflygen": "polarflyg",
    "polarflygens": "polarflyg",
    "polarflyget": "polarflyg",
    "polarflygets": "polarflyg",
    "polarflygs": "polarflyg",
    "polarforskningar": "polarforskning",
    "polarforskningarna": "polarforskning",
    "polarforskningarnas": "polarforskning",
    "polarforskningars": "polarforskning",
    "polarforskningen": "polarforskning",
    "polarforskningens": "polarforskning",
    "polarforsknings": "polarforskning",
    "polarfronten": "polarfront",
    "polarfrontens": "polarfront",
    "polarfronter": "polarfront",
    "polarfronterna": "polarfront",
    "polarfronternas": "polarfront",
    "polarfronters": "polarfront",
    "polarfronts": "polarfront",
    "polarhaven": "polarhav",
    "polarhavens": "polarhav",
    "polarhavet": "polarhav",
    "polarhavets": "polarhav",
    "polarhavs": "polarhav",
    "polarisationen": "polarisation",
    "polarisationens": "polarisation",
    "polarisationer": "polarisation",
    "polarisationerna": "polarisation",
    "polarisationernas": "polarisation",
    "polarisationers": "polarisation",
    "polarisations": "polarisation",
    "polarisationsfilterna": "polarisationsfilter",
    "polarisationsfilternas": "polarisationsfilter",
    "polarisationsfilters": "polarisationsfilter",
    "polarisationsfiltren": "polarisationsfilter",
    "polarisationsfiltrens": "polarisationsfilter",
    "polarisationsfiltret": "polarisationsfilter",
    "polarisationsfiltrets": "polarisationsfilter",
    "polarisatorer": "polarisator",
    "polarisatorerna": "polarisator",
    "polarisatorernas": "polarisator",
    "polarisatorers": "polarisator",
    "polarisatorn": "polarisator",
    "polarisatorns": "polarisator",
    "polarisators": "polarisator",
    "polariserad": "polarisera",
    "polariserade": "polarisera",
    "polariserades": "polarisera",
    "polariserads": "polarisera",
    "polariserande": "polarisera",
    "polariseranden": "polariserande",
    "polariserandena": "polariserande",
    "polariserandenas": "polariserande",
    "polariserandens": "polariserande",
    "polariserandes": "polariserande",
    "polariserandet": "polariserande",
    "polariserandets": "polariserande",
    "polariserar": "polarisera",
    "polariseras": "polarisera",
    "polariserat": "polarisera",
    "polariserats": "polarisera",
    "polariserbara": "polariserbar",
    "polariserbarare": "polariserbar",
    "polariserbarares": "polariserbar",
    "polariserbaras": "polariserbar",
    "polariserbarast": "polariserbar",
    "polariserbaraste": "polariserbar",
    "polariserbarastes": "polariserbar",
    "polariserbarasts": "polariserbar",
    "polariserbare": "polariserbar",
    "polariserbares": "polariserbar",
    "polariserbarheten": "polariserbarhet",
    "polariserbarhetens": "polariserbarhet",
    "polariserbarhets": "polariserbarhet",
    "polariserbars": "polariserbar",
    "polariserbart": "polariserbar",
    "polariserbarts": "polariserbar",
    "polariseringar": "polarisering",
    "polariseringarna": "polarisering",
    "polariseringarnas": "polarisering",
    "polariseringars": "polarisering",
    "polariseringen": "polarisering",
    "polariseringens": "polarisering",
    "polariserings": "polarisering",
    "polariteten": "polaritet",
    "polaritetens": "polaritet",
    "polariteter": "polaritet",
    "polariteterna": "polaritet",
    "polariteternas": "polaritet",
    "polariteters": "polaritet",
    "polaritets": "polaritet",
    "polarluften": "polarluft",
    "polarluftens": "polarluft",
    "polarlufts": "polarluft",
    "polarmiljöer": "polarmiljö",
    "polarmiljöerna": "polarmiljö",
    "polarmiljöernas": "polarmiljö",
    "polarmiljöers": "polarmiljö",
    "polarmiljön": "polarmiljö",
    "polarmiljöns": "polarmiljö",
    "polarmiljös": "polarmiljö",
    "polarna": "polare",
    "polarnas": "polare",
    "polarnatten": "polarnatt",
    "polarnattens": "polarnatt",
    "polarnatts": "polarnatt",
    "polaroidfilmen": "polaroidfilm",
    "polaroidfilmens": "polaroidfilm",
    "polaroidfilmer": "polaroidfilm",
    "polaroidfilmerna": "polaroidfilm",
    "polaroidfilmernas": "polaroidfilm",
    "polaroidfilmers": "polaroidfilm",
    "polaroidfilms": "polaroidfilm",
    "polaroidkameran": "polaroidkamera",
    "polaroidkamerans": "polaroidkamera",
    "polaroidkameras": "polaroidkamera",
    "polaroidkameror": "polaroidkamera",
    "polaroidkamerorna": "polaroidkamera",
    "polaroidkamerornas": "polaroidkamera",
    "polaroidkamerors": "polaroidkamera",
    "polarområden": "polarområde",
    "polarområdena": "polarområde",
    "polarområdenas": "polarområde",
    "polarområdens": "polarområde",
    "polarområdes": "polarområde",
    "polarområdet": "polarområde",
    "polarområdets": "polarområde",
    "polarrävar": "polarräv",
    "polarrävarna": "polarräv",
    "polarrävarnas": "polarräv",
    "polarrävars": "polarräv",
    "polarräven": "polarräv",
    "polarrävens": "polarräv",
    "polarrävs": "polarräv",
    "polars": "polar",
    "polarskenet": "polarsken",
    "polarskenets": "polarsken",
    "polarskens": "polarsken",
    "polart": "polar",
    "polartrakten": "polartrakt",
    "polartraktens": "polartrakt",
    "polartrakter": "polartrakt",
    "polartrakterna": "polartrakt",
    "polartrakternas": "polartrakt",
    "polartrakters": "polartrakt",
    "polartrakts": "polartrakt",
    "polarts": "polar",
    "polarvintern": "polarvinter",
    "polarvinterns": "polarvinter",
    "polarvinters": "polarvinter",
    "polas": "pola",
    "polat": "pola",
    "polats": "pola",
    "polcirkeln": "polcirkel",
    "polcirkelns": "polcirkel",
    "polcirkels": "polcirkel",
    "polcirklar": "polcirkel",
    "polcirklarna": "polcirkel",
    "polcirklarnas": "polcirkel",
    "polcirklars": "polcirkel",
    "poldern": "polder",
    "polderns": "polder",
    "polders": "polder",
    "poldrar": "polder",
    "poldrarna": "polder",
    "poldrarnas": "polder",
    "poldrars": "polder",
    "polemiken": "polemik",
    "polemikens": "polemik",
    "polemiker": "polemik",
    "polemikern": "polemiker",
    "polemikerna": "polemiker",
    "polemikernas": "polemiker",
    "polemikerns": "polemiker",
    "polemikers": "polemiker",
    "polemiks": "polemik",
    "polemiserade": "polemisera",
    "polemiserades": "polemisera",
    "polemiserande": "polemisera",
    "polemiseranden": "polemiserande",
    "polemiserandena": "polemiserande",
    "polemiserandenas": "polemiserande",
    "polemiserandens": "polemiserande",
    "polemiserandes": "polemiserande",
    "polemiserandet": "polemiserande",
    "polemiserandets": "polemiserande",
    "polemiserar": "polemisera",
    "polemiseras": "polemisera",
    "polemiserat": "polemisera",
    "polemiserats": "polemisera",
    "polemiseringar": "polemisering",
    "polemiseringarna": "polemisering",
    "polemiseringarnas": "polemisering",
    "polemiseringars": "polemisering",
    "polemiseringen": "polemisering",
    "polemiseringens": "polemisering",
    "polemiserings": "polemisering",
    "polemiska": "polemisk",
    "polemiskare": "polemisk",
    "polemiskares": "polemisk",
    "polemiskas": "polemisk",
    "polemiskast": "polemisk",
    "polemiskaste": "polemisk",
    "polemiskastes": "polemisk",
    "polemiskasts": "polemisk",
    "polemiske": "polemisk",
    "polemiskes": "polemisk",
    "polemisks": "polemisk",
    "polemiskt": "polemisk",
    "polemiskts": "polemisk",
    "polen": "pol",
    "polens": "pol",
    "polentagrynen": "polentagryn",
    "polentagrynens": "polentagryn",
    "polentagrynet": "polentagryn",
    "polentagrynets": "polentagryn",
    "polentagryns": "polentagryn",
    "polentan": "polenta",
    "polentans": "polenta",
    "polentas": "polenta",
    "poler": "pol",
    "polerad": "polera",
    "polerade": "polerad",
    "polerades": "polerad",
    "polerads": "polerad",
    "polerande": "polera",
    "poleranden": "polerande",
    "polerandena": "polerande",
    "polerandenas": "polerande",
    "polerandens": "polerande",
    "polerandes": "polerande",
    "polerandet": "polerande",
    "polerandets": "polerande",
    "polerar": "polera",
    "poleras": "polera",
    "polerat": "polerad",
    "polerats": "polerad",
    "polerbara": "polerbar",
    "polerbarare": "polerbar",
    "polerbarares": "polerbar",
    "polerbaras": "polerbar",
    "polerbarast": "polerbar",
    "polerbaraste": "polerbar",
    "polerbarastes": "polerbar",
    "polerbarasts": "polerbar",
    "polerbare": "polerbar",
    "polerbares": "polerbar",
    "polerbarheten": "polerbarhet",
    "polerbarhetens": "polerbarhet",
    "polerbarhets": "polerbarhet",
    "polerbars": "polerbar",
    "polerbart": "polerbar",
    "polerbarts": "polerbar",
    "polerdukar": "polerduk",
    "polerdukarna": "polerduk",
    "polerdukarnas": "polerduk",
    "polerdukars": "polerduk",
    "polerduken": "polerduk",
    "polerdukens": "polerduk",
    "polerduks": "polerduk",
    "poleringar": "polering",
    "poleringarna": "polering",
    "poleringarnas": "polering",
    "poleringars": "polering",
    "poleringen": "polering",
    "poleringens": "polering",
    "polerings": "polering",
    "polermaskinen": "polermaskin",
    "polermaskinens": "polermaskin",
    "polermaskiner": "polermaskin",
    "polermaskinerna": "polermaskin",
    "polermaskinernas": "polermaskin",
    "polermaskiners": "polermaskin",
    "polermaskins": "polermaskin",
    "polermedels": "polermedel",
    "polermedlen": "polermedel",
    "polermedlens": "polermedel",
    "polermedlet": "polermedel",
    "polermedlets": "polermedel",
    "polerna": "pol",
    "polernas": "pol",
    "polerpastan": "polerpasta",
    "polerpastans": "polerpasta",
    "polerpastas": "polerpasta",
    "polerpaste": "polerpasta",
    "polerpastor": "polerpasta",
    "polerpastorna": "polerpasta",
    "polerpastornas": "polerpasta",
    "polerpastors": "polerpasta",
    "polerrondellen": "polerrondell",
    "polerrondellens": "polerrondell",
    "polerrondeller": "polerrondell",
    "polerrondellerna": "polerrondell",
    "polerrondellernas": "polerrondell",
    "polerrondellers": "polerrondell",
    "polerrondells": "polerrondell",
    "polers": "pol",
    "polersvampar": "polersvamp",
    "polersvamparna": "polersvamp",
    "polersvamparnas": "polersvamp",
    "polersvampars": "polersvamp",
    "polersvampen": "polersvamp",
    "polersvampens": "polersvamp",
    "polersvamps": "polersvamp",
    "polertrassels": "polertrassel",
    "polertrasslet": "polertrassel",
    "polertrasslets": "polertrassel",
    "polhöjden": "polhöjd",
    "polhöjdens": "polhöjd",
    "polhöjds": "polhöjd",
    "policier": "policy",
    "policierna": "policy",
    "policiernas": "policy",
    "policiers": "policy",
    "policies": "policy",
    "policiesarna": "policy",
    "policiesarnas": "policy",
    "policyer": "policy",
    "policyerna": "policy",
    "policyernas": "policy",
    "policyers": "policy",
    "policyn": "policy",
    "policyns": "policy",
    "policys": "policy",
    "policysar": "policy",
    "policysarna": "policy",
    "policysarnas": "policy",
    "policysars": "policy",
    "polikliniken": "poliklinik",
    "poliklinikens": "poliklinik",
    "polikliniker": "poliklinik",
    "poliklinikerna": "poliklinik",
    "poliklinikernas": "poliklinik",
    "poliklinikers": "poliklinik",
    "polikliniks": "poliklinik",
    "polikliniska": "poliklinisk",
    "polikliniskare": "poliklinisk",
    "polikliniskares": "poliklinisk",
    "polikliniskas": "poliklinisk",
    "polikliniskast": "poliklinisk",
    "polikliniskaste": "poliklinisk",
    "polikliniskastes": "poliklinisk",
    "polikliniskasts": "poliklinisk",
    "polikliniske": "poliklinisk",
    "polikliniskes": "poliklinisk",
    "poliklinisks": "poliklinisk",
    "polikliniskt": "poliklinisk",
    "polikliniskts": "poliklinisk",
    "poliomyeliten": "poliomyelit",
    "poliomyelitens": "poliomyelit",
    "poliomyelits": "poliomyelit",
    "polion": "polio",
    "polions": "polio",
    "polios": "polio",
    "polisanmäl": "polisanmäla",
    "polisanmälande": "polisanmäla",
    "polisanmälanden": "polisanmälande",
    "polisanmälandena": "polisanmälande",
    "polisanmälandenas": "polisanmälande",
    "polisanmälandens": "polisanmälande",
    "polisanmälandes": "polisanmälande",
    "polisanmälandet": "polisanmälande",
    "polisanmälandets": "polisanmälande",
    "polisanmälans": "polisanmälan",
    "polisanmälas": "polisanmäla",
    "polisanmäld": "polisanmäla",
    "polisanmälda": "polisanmäla",
    "polisanmäldas": "polisanmäla",
    "polisanmälde": "polisanmäla",
    "polisanmäldes": "polisanmäla",
    "polisanmälds": "polisanmäla",
    "polisanmäler": "polisanmäla",
    "polisanmäles": "polisanmäla",
    "polisanmälningar": "polisanmälning",
    "polisanmälningarna": "polisanmälning",
    "polisanmälningarnas": "polisanmälning",
    "polisanmälningars": "polisanmälning",
    "polisanmälningen": "polisanmälning",
    "polisanmälningens": "polisanmälning",
    "polisanmälnings": "polisanmälning",
    "polisanmäls": "polisanmäla",
    "polisanmält": "polisanmäla",
    "polisanmälts": "polisanmäla",
    "polisarbeten": "polisarbete",
    "polisarbetena": "polisarbete",
    "polisarbetenas": "polisarbete",
    "polisarbetens": "polisarbete",
    "polisarbetes": "polisarbete",
    "polisarbetet": "polisarbete",
    "polisarbetets": "polisarbete",
    "polisarbets": "polisarbete",
    "polisarresten": "polisarrest",
    "polisarrestens": "polisarrest",
    "polisarrester": "polisarrest",
    "polisarresterna": "polisarrest",
    "polisarresternas": "polisarrest",
    "polisarresters": "polisarrest",
    "polisarrests": "polisarrest",
    "polisbefälen": "polisbefäl",
    "polisbefälens": "polisbefäl",
    "polisbefälet": "polisbefäl",
    "polisbefälets": "polisbefäl",
    "polisbefäls": "polisbefäl",
    "polisbevak": "polisbevaka",
    "polisbevakad": "polisbevaka",
    "polisbevakade": "polisbevaka",
    "polisbevakades": "polisbevaka",
    "polisbevakads": "polisbevaka",
    "polisbevakande": "polisbevaka",
    "polisbevakanden": "polisbevakande",
    "polisbevakandena": "polisbevakande",
    "polisbevakandenas": "polisbevakande",
    "polisbevakandens": "polisbevakande",
    "polisbevakandes": "polisbevakande",
    "polisbevakandet": "polisbevakande",
    "polisbevakandets": "polisbevakande",
    "polisbevakar": "polisbevaka",
    "polisbevakas": "polisbevaka",
    "polisbevakat": "polisbevaka",
    "polisbevakats": "polisbevaka",
    "polisbevakningar": "polisbevakning",
    "polisbevakningarna": "polisbevakning",
    "polisbevakningarnas": "polisbevakning",
    "polisbevakningars": "polisbevakning",
    "polisbevakningen": "polisbevakning",
    "polisbevakningens": "polisbevakning",
    "polisbevaknings": "polisbevakning",
    "polisbilar": "polisbil",
    "polisbilarna": "polisbil",
    "polisbilarnas": "polisbil",
    "polisbilars": "polisbil",
    "polisbilen": "polisbil",
    "polisbilens": "polisbil",
    "polisbils": "polisbil",
    "polisbrick": "polisbricka",
    "polisbrickan": "polisbricka",
    "polisbrickans": "polisbricka",
    "polisbrickas": "polisbricka",
    "polisbricke": "polisbricka",
    "polisbrickor": "polisbricka",
    "polisbrickorna": "polisbricka",
    "polisbrickornas": "polisbricka",
    "polisbrickors": "polisbricka",
    "polisbricks": "polisbricka",
    "polischefen": "polischef",
    "polischefens": "polischef",
    "polischefer": "polischef",
    "polischeferna": "polischef",
    "polischefernas": "polischef",
    "polischefers": "polischef",
    "polischefs": "polischef",
    "polischocken": "polischock",
    "polischockens": "polischock",
    "polischocker": "polischock",
    "polischockerna": "polischock",
    "polischockernas": "polischock",
    "polischockers": "polischock",
    "polischocks": "polischock",
    "polisdistrikten": "polisdistrikt",
    "polisdistriktens": "polisdistrikt",
    "polisdistriktet": "polisdistrikt",
    "polisdistriktets": "polisdistrikt",
    "polisdistrikts": "polisdistrikt",
    "polisen": "polis",
    "polisens": "polis",
    "poliser": "polis",
    "poliserna": "polis",
    "polisernas": "polis",
    "polisers": "polis",
    "polisfordonen": "polisfordon",
    "polisfordonens": "polisfordon",
    "polisfordonet": "polisfordon",
    "polisfordonets": "polisfordon",
    "polisfordons": "polisfordon",
    "polisförhören": "polisförhör",
    "polisförhörens": "polisförhör",
    "polisförhöret": "polisförhör",
    "polisförhörets": "polisförhör",
    "polisförhörs": "polisförhör",
    "polisförordningar": "polisförordning",
    "polisförordningarna": "polisförordning",
    "polisförordningarnas": "polisförordning",
    "polisförordningars": "polisförordning",
    "polisförordningen": "polisförordning",
    "polisförordningens": "polisförordning",
    "polisförordnings": "polisförordning",
    "polishelikoptern": "polishelikopter",
    "polishelikopterns": "polishelikopter",
    "polishelikopters": "polishelikopter",
    "polishelikoptrar": "polishelikopter",
    "polishelikoptrarna": "polishelikopter",
    "polishelikoptrarnas": "polishelikopter",
    "polishelikoptrars": "polishelikopter",
    "polishen": "polish",
    "polishens": "polish",
    "polishjälmar": "polishjälm",
    "polishjälmarna": "polishjälm",
    "polishjälmarnas": "polishjälm",
    "polishjälmars": "polishjälm",
    "polishjälmen": "polishjälm",
    "polishjälmens": "polishjälm",
    "polishjälms": "polishjälm",
    "polishs": "polish",
    "polishundar": "polishund",
    "polishundarna": "polishund",
    "polishundarnas": "polishund",
    "polishundars": "polishund",
    "polishunden": "polishund",
    "polishundens": "polishund",
    "polishunds": "polishund",
    "polisingripanden": "polisingripande",
    "polisingripandena": "polisingripande",
    "polisingripandenas": "polisingripande",
    "polisingripandens": "polisingripande",
    "polisingripandes": "polisingripande",
    "polisingripandet": "polisingripande",
    "polisingripandets": "polisingripande",
    "polisintendenten": "polisintendent",
    "polisintendentens": "polisintendent",
    "polisintendenter": "polisintendent",
    "polisintendenterna": "polisintendent",
    "polisintendenternas": "polisintendent",
    "polisintendenters": "polisintendent",
    "polisintendents": "polisintendent",
    "polisiära": "polisiär",
    "polisiärare": "polisiär",
    "polisiärares": "polisiär",
    "polisiäras": "polisiär",
    "polisiärast": "polisiär",
    "polisiäraste": "polisiär",
    "polisiärastes": "polisiär",
    "polisiärasts": "polisiär",
    "polisiäre": "polisiär",
    "polisiäres": "polisiär",
    "polisiärs": "polisiär",
    "polisiärt": "polisiär",
    "polisiärts": "polisiär",
    "poliskedjan": "poliskedja",
    "poliskedjans": "poliskedja",
    "poliskedjas": "poliskedja",
    "poliskedje": "poliskedja",
    "poliskedjor": "poliskedja",
    "poliskedjorna": "poliskedja",
    "poliskedjornas": "poliskedja",
    "poliskedjors": "poliskedja",
    "poliskommissarien": "poliskommissarie",
    "poliskommissariens": "poliskommissarie",
    "poliskommissarier": "poliskommissarie",
    "poliskommissarierna": "poliskommissarie",
    "poliskommissariernas": "poliskommissarie",
    "poliskommissariers": "poliskommissarie",
    "poliskommissaries": "poliskommissarie",
    "poliskonstapeln": "poliskonstapel",
    "poliskonstapelns": "poliskonstapel",
    "poliskonstapels": "poliskonstapel",
    "poliskonstaplar": "poliskonstapel",
    "poliskonstaplarna": "poliskonstapel",
    "poliskonstaplarnas": "poliskonstapel",
    "poliskonstaplars": "poliskonstapel",
    "poliskunden": "poliskund",
    "poliskundens": "poliskund",
    "poliskunder": "poliskund",
    "poliskunderna": "poliskund",
    "poliskundernas": "poliskund",
    "poliskunders": "poliskund",
    "poliskunds": "poliskund",
    "poliskvinnan": "poliskvinna",
    "poliskvinnans": "poliskvinna",
    "poliskvinnas": "poliskvinna",
    "poliskvinne": "poliskvinna",
    "poliskvinno": "poliskvinna",
    "poliskvinnor": "poliskvinna",
    "poliskvinnorna": "poliskvinna",
    "poliskvinnornas": "poliskvinna",
    "poliskvinnors": "poliskvinna",
    "polismajoren": "polismajor",
    "polismajorens": "polismajor",
    "polismajorer": "polismajor",
    "polismajorerna": "polismajor",
    "polismajorernas": "polismajor",
    "polismajorers": "polismajor",
    "polismajors": "polismajor",
    "polismakten": "polismakt",
    "polismaktens": "polismakt",
    "polismakts": "polismakt",
    "polismannen": "polisman",
    "polismannens": "polisman",
    "polismans": "polisman",
    "polismyndigheten": "polismyndighet",
    "polismyndighetens": "polismyndighet",
    "polismyndigheter": "polismyndighet",
    "polismyndigheterna": "polismyndighet",
    "polismyndigheternas": "polismyndighet",
    "polismyndigheters": "polismyndighet",
    "polismyndighets": "polismyndighet",
    "polismän": "polisman",
    "polismännen": "polisman",
    "polismännens": "polisman",
    "polismäns": "polisman",
    "polismästar": "polismästare",
    "polismästaren": "polismästare",
    "polismästarens": "polismästare",
    "polismästares": "polismästare",
    "polismästarna": "polismästare",
    "polismästarnas": "polismästare",
    "polisnaturen": "polisnatur",
    "polisnaturens": "polisnatur",
    "polisnaturer": "polisnatur",
    "polisnaturerna": "polisnatur",
    "polisnaturernas": "polisnatur",
    "polisnaturers": "polisnatur",
    "polisnaturs": "polisnatur",
    "polisongen": "polisong",
    "polisongens": "polisong",
    "polisonger": "polisong",
    "polisongerna": "polisong",
    "polisongernas": "polisong",
    "polisongers": "polisong",
    "polisongs": "polisong",
    "polisorganisationen": "polisorganisation",
    "polisorganisationens": "polisorganisation",
    "polisorganisationer": "polisorganisation",
    "polisorganisationerna": "polisorganisation",
    "polisorganisationernas": "polisorganisation",
    "polisorganisationers": "polisorganisation",
    "polisorganisations": "polisorganisation",
    "polispatrullen": "polispatrull",
    "polispatrullens": "polispatrull",
    "polispatruller": "polispatrull",
    "polispatrullerna": "polispatrull",
    "polispatrullernas": "polispatrull",
    "polispatrullers": "polispatrull",
    "polispatrulls": "polispatrull",
    "polisspaningar": "polisspaning",
    "polisspaningarna": "polisspaning",
    "polisspaningarnas": "polisspaning",
    "polisspaningars": "polisspaning",
    "polisspaningen": "polisspaning",
    "polisspaningens": "polisspaning",
    "polisspanings": "polisspaning",
    "polisstaten": "polisstat",
    "polisstatens": "polisstat",
    "polisstater": "polisstat",
    "polisstaterna": "polisstat",
    "polisstaternas": "polisstat",
    "polisstaters": "polisstat",
    "polisstationen": "polisstation",
    "polisstationens": "polisstation",
    "polisstationer": "polisstation",
    "polisstationerna": "polisstation",
    "polisstationernas": "polisstation",
    "polisstationers": "polisstation",
    "polisstations": "polisstation",
    "polisstats": "polisstat",
    "polisstyrkan": "polisstyrka",
    "polisstyrkans": "polisstyrka",
    "polisstyrkas": "polisstyrka",
    "polisstyrke": "polisstyrka",
    "polisstyrkor": "polisstyrka",
    "polisstyrkorna": "polisstyrka",
    "polisstyrkornas": "polisstyrka",
    "polisstyrkors": "polisstyrka",
    "polistejpen": "polistejp",
    "polistejpens": "polistejp",
    "polistejps": "polistejp",
    "polistjänstemannen": "polistjänsteman",
    "polistjänstemannens": "polistjänsteman",
    "polistjänstemans": "polistjänsteman",
    "polistjänstemän": "polistjänsteman",
    "polistjänstemännen": "polistjänsteman",
    "polistjänstemännens": "polistjänsteman",
    "polistjänstemäns": "polistjänsteman",
    "polistjänsten": "polistjänst",
    "polistjänstens": "polistjänst",
    "polistjänster": "polistjänst",
    "polistjänsterna": "polistjänst",
    "polistjänsternas": "polistjänst",
    "polistjänsters": "polistjänst",
    "polistjänstgöringar": "polistjänstgöring",
    "polistjänstgöringarna": "polistjänstgöring",
    "polistjänstgöringarnas": "polistjänstgöring",
    "polistjänstgöringars": "polistjänstgöring",
    "polistjänstgöringen": "polistjänstgöring",
    "polistjänstgöringens": "polistjänstgöring",
    "polistjänstgörings": "polistjänstgöring",
    "polistjänsts": "polistjänst",
    "polisundersökningar": "polisundersökning",
    "polisundersökningarna": "polisundersökning",
    "polisundersökningarnas": "polisundersökning",
    "polisundersökningars": "polisundersökning",
    "polisundersökningen": "polisundersökning",
    "polisundersökningens": "polisundersökning",
    "polisundersöknings": "polisundersökning",
    "polisuniformen": "polisuniform",
    "polisuniformens": "polisuniform",
    "polisuniformer": "polisuniform",
    "polisuniformerna": "polisuniform",
    "polisuniformernas": "polisuniform",
    "polisuniformers": "polisuniform",
    "polisuniforms": "polisuniform",
    "polisutryckningar": "polisutryckning",
    "polisutryckningarna": "polisutryckning",
    "polisutryckningarnas": "polisutryckning",
    "polisutryckningars": "polisutryckning",
    "polisutryckningen": "polisutryckning",
    "polisutryckningens": "polisutryckning",
    "polisutrycknings": "polisutryckning",
    "polisväsenden": "polisväsende",
    "polisväsendena": "polisväsende",
    "polisväsendenas": "polisväsende",
    "polisväsendens": "polisväsende",
    "polisväsendes": "polisväsende",
    "polisväsendet": "polisväsende",
    "polisväsendets": "polisväsende",
    "polisyrken": "polisyrke",
    "polisyrkena": "polisyrke",
    "polisyrkenas": "polisyrke",
    "polisyrkens": "polisyrke",
    "polisyrkes": "polisyrke",
    "polisyrket": "polisyrke",
    "polisyrkets": "polisyrke",
    "polisärenden": "polisärende",
    "polisärendena": "polisärende",
    "polisärendenas": "polisärende",
    "polisärendens": "polisärende",
    "polisärendes": "polisärende",
    "polisärendet": "polisärende",
    "polisärendets": "polisärende",
    "politbyråer": "politbyrå",
    "politbyråerna": "politbyrå",
    "politbyråernas": "politbyrå",
    "politbyråers": "politbyrå",
    "politbyrån": "politbyrå",
    "politbyråns": "politbyrå",
    "politbyrås": "politbyrå",
    "politessen": "politess",
    "politessens": "politess",
    "politiken": "politik",
    "politikens": "politik",
    "politikerföraktet": "politikerförakt",
    "politikerföraktets": "politikerförakt",
    "politikerförakts": "politikerförakt",
    "politikerhustrun": "politikerhustru",
    "politikerhustruns": "politikerhustru",
    "politikerhustrur": "politikerhustru",
    "politikerhustrurna": "politikerhustru",
    "politikerhustrurnas": "politikerhustru",
    "politikerhustrurs": "politikerhustru",
    "politikerhustrus": "politikerhustru",
    "politikern": "politiker",
    "politikerna": "politiker",
    "politikernas": "politiker",
    "politikerns": "politiker",
    "politikers": "politiker",
    "politiks": "politik",
    "politikusar": "politikus",
    "politikusarna": "politikus",
    "politikusarnas": "politikus",
    "politikusars": "politikus",
    "politikusen": "politikus",
    "politikusens": "politikus",
    "politiserad": "politisera",
    "politiserade": "politisera",
    "politiserades": "politisera",
    "politiserads": "politisera",
    "politiserande": "politisera",
    "politiseranden": "politiserande",
    "politiserandena": "politiserande",
    "politiserandenas": "politiserande",
    "politiserandens": "politiserande",
    "politiserandes": "politiserande",
    "politiserandet": "politiserande",
    "politiserandets": "politiserande",
    "politiserar": "politisera",
    "politiseras": "politisera",
    "politiserat": "politisera",
    "politiserats": "politisera",
    "politiserbara": "politiserbar",
    "politiserbarare": "politiserbar",
    "politiserbarares": "politiserbar",
    "politiserbaras": "politiserbar",
    "politiserbarast": "politiserbar",
    "politiserbaraste": "politiserbar",
    "politiserbarastes": "politiserbar",
    "politiserbarasts": "politiserbar",
    "politiserbare": "politiserbar",
    "politiserbares": "politiserbar",
    "politiserbarheten": "politiserbarhet",
    "politiserbarhetens": "politiserbarhet",
    "politiserbarhets": "politiserbarhet",
    "politiserbars": "politiserbar",
    "politiserbart": "politiserbar",
    "politiserbarts": "politiserbar",
    "politiseringar": "politisering",
    "politiseringarna": "politisering",
    "politiseringarnas": "politisering",
    "politiseringars": "politisering",
    "politiseringen": "politisering",
    "politiseringens": "politisering",
    "politiserings": "politisering",
    "politiska": "politisk",
    "politiskare": "politisk",
    "politiskares": "politisk",
    "politiskas": "politisk",
    "politiskast": "politisk",
    "politiskaste": "politisk",
    "politiskastes": "politisk",
    "politiskasts": "politisk",
    "politiske": "politisk",
    "politiskes": "politisk",
    "politisks": "politisk",
    "politiskt": "politisk",
    "politiskts": "politisk",
    "politruken": "politruk",
    "politrukens": "politruk",
    "politruker": "politruk",
    "politrukerna": "politruk",
    "politrukernas": "politruk",
    "politrukers": "politruk",
    "politruks": "politruk",
    "polityren": "polityr",
    "polityrens": "polityr",
    "polityrer": "polityr",
    "polityrerna": "polityr",
    "polityrernas": "polityr",
    "polityrers": "polityr",
    "polityrs": "polityr",
    "polk": "polka",
    "polkagrisar": "polkagris",
    "polkagrisarna": "polkagris",
    "polkagrisarnas": "polkagris",
    "polkagrisars": "polkagris",
    "polkagrisen": "polkagris",
    "polkagrisens": "polkagris",
    "polkahåret": "polkahår",
    "polkahårets": "polkahår",
    "polkahårs": "polkahår",
    "polkan": "polka",
    "polkans": "polka",
    "polkas": "polka",
    "polke": "polka",
    "polketten": "polkett",
    "polkettens": "polkett",
    "polketter": "polkett",
    "polketterna": "polkett",
    "polketternas": "polkett",
    "polketters": "polkett",
    "polketts": "polkett",
    "polkor": "polka",
    "polkorna": "polka",
    "polkornas": "polka",
    "polkors": "polka",
    "polkroppar": "polkropp",
    "polkropparna": "polkropp",
    "polkropparnas": "polkropp",
    "polkroppars": "polkropp",
    "polkroppen": "polkropp",
    "polkroppens": "polkropp",
    "polkropps": "polkropp",
    "polks": "polka",
    "pollar": "pollare",
    "pollaren": "pollare",
    "pollarens": "pollare",
    "pollares": "pollare",
    "pollarna": "pollare",
    "pollarnas": "pollare",
    "pollenallergien": "pollenallergi",
    "pollenallergiens": "pollenallergi",
    "pollenallergier": "pollenallergi",
    "pollenallergierna": "pollenallergi",
    "pollenallergiernas": "pollenallergi",
    "pollenallergiers": "pollenallergi",
    "pollenallergin": "pollenallergi",
    "pollenallergins": "pollenallergi",
    "pollenallergis": "pollenallergi",
    "pollenanalysen": "pollenanalys",
    "pollenanalysens": "pollenanalys",
    "pollenet": "pollen",
    "pollenets": "pollen",
    "pollenfynden": "pollenfynd",
    "pollenfyndens": "pollenfynd",
    "pollenfyndet": "pollenfynd",
    "pollenfyndets": "pollenfynd",
    "pollenfynds": "pollenfynd",
    "pollenkornen": "pollenkorn",
    "pollenkornens": "pollenkorn",
    "pollenkornet": "pollenkorn",
    "pollenkornets": "pollenkorn",
    "pollenkorns": "pollenkorn",
    "pollenplågan": "pollenplåga",
    "pollenplågans": "pollenplåga",
    "pollenplågas": "pollenplåga",
    "pollenplåge": "pollenplåga",
    "pollenplågo": "pollenplåga",
    "pollenplågor": "pollenplåga",
    "pollenplågorna": "pollenplåga",
    "pollenplågornas": "pollenplåga",
    "pollenplågors": "pollenplåga",
    "pollens": "pollen",
    "pollenslangar": "pollenslang",
    "pollenslangarna": "pollenslang",
    "pollenslangarnas": "pollenslang",
    "pollenslangars": "pollenslang",
    "pollenslangen": "pollenslang",
    "pollenslangens": "pollenslang",
    "pollenslangs": "pollenslang",
    "polletten": "pollett",
    "pollettens": "pollett",
    "polletter": "pollett",
    "polletterad": "pollettera",
    "polletterade": "pollettera",
    "polletterades": "pollettera",
    "polletterads": "pollettera",
    "polletterande": "pollettera",
    "polletteranden": "polletterande",
    "polletterandena": "polletterande",
    "polletterandenas": "polletterande",
    "polletterandens": "polletterande",
    "polletterandes": "polletterande",
    "polletterandet": "polletterande",
    "polletterandets": "polletterande",
    "polletterar": "pollettera",
    "polletteras": "pollettera",
    "polletterat": "pollettera",
    "polletterats": "pollettera",
    "polletterbara": "polletterbar",
    "polletterbarare": "polletterbar",
    "polletterbarares": "polletterbar",
    "polletterbaras": "polletterbar",
    "polletterbarast": "polletterbar",
    "polletterbaraste": "polletterbar",
    "polletterbarastes": "polletterbar",
    "polletterbarasts": "polletterbar",
    "polletterbare": "polletterbar",
    "polletterbares": "polletterbar",
    "polletterbarheten": "polletterbarhet",
    "polletterbarhetens": "polletterbarhet",
    "polletterbarhets": "polletterbarhet",
    "polletterbars": "polletterbar",
    "polletterbart": "polletterbar",
    "polletterbarts": "polletterbar",
    "polletteringar": "pollettering",
    "polletteringarna": "pollettering",
    "polletteringarnas": "pollettering",
    "polletteringars": "pollettering",
    "polletteringen": "pollettering",
    "polletteringens": "pollettering",
    "polletterings": "pollettering",
    "polletterna": "pollett",
    "polletternas": "pollett",
    "polletters": "pollett",
    "polletts": "pollett",
    "pollinationen": "pollination",
    "pollinationens": "pollination",
    "pollinationer": "pollination",
    "pollinationerna": "pollination",
    "pollinationernas": "pollination",
    "pollinationers": "pollination",
    "pollinations": "pollination",
    "pollinerad": "pollinera",
    "pollinerade": "pollinera",
    "pollinerades": "pollinera",
    "pollinerads": "pollinera",
    "pollinerande": "pollinera",
    "pollineranden": "pollinerande",
    "pollinerandena": "pollinerande",
    "pollinerandenas": "pollinerande",
    "pollinerandens": "pollinerande",
    "pollinerandes": "pollinerande",
    "pollinerandet": "pollinerande",
    "pollinerandets": "pollinerande",
    "pollinerar": "pollinera",
    "pollineras": "pollinera",
    "pollinerat": "pollinera",
    "pollinerats": "pollinera",
    "pollinerbara": "pollinerbar",
    "pollinerbarare": "pollinerbar",
    "pollinerbarares": "pollinerbar",
    "pollinerbaras": "pollinerbar",
    "pollinerbarast": "pollinerbar",
    "pollinerbaraste": "pollinerbar",
    "pollinerbarastes": "pollinerbar",
    "pollinerbarasts": "pollinerbar",
    "pollinerbare": "pollinerbar",
    "pollinerbares": "pollinerbar",
    "pollinerbarheten": "pollinerbarhet",
    "pollinerbarhetens": "pollinerbarhet",
    "pollinerbarhets": "pollinerbarhet",
    "pollinerbars": "pollinerbar",
    "pollinerbart": "pollinerbar",
    "pollinerbarts": "pollinerbar",
    "pollineringar": "pollinering",
    "pollineringarna": "pollinering",
    "pollineringarnas": "pollinering",
    "pollineringars": "pollinering",
    "pollineringen": "pollinering",
    "pollineringens": "pollinering",
    "pollinerings": "pollinering",
    "pollutionen": "pollution",
    "pollutionens": "pollution",
    "pollutioner": "pollution",
    "pollutionerna": "pollution",
    "pollutionernas": "pollution",
    "pollutioners": "pollution",
    "pollutions": "pollution",
    "polobollar": "poloboll",
    "polobollarna": "poloboll",
    "polobollarnas": "poloboll",
    "polobollars": "poloboll",
    "polobollen": "poloboll",
    "polobollens": "poloboll",
    "polobolls": "poloboll",
    "polohästar": "polohäst",
    "polohästarna": "polohäst",
    "polohästarnas": "polohäst",
    "polohästars": "polohäst",
    "polohästen": "polohäst",
    "polohästens": "polohäst",
    "polohästs": "polohäst",
    "poloklubb": "poloklubba",
    "poloklubban": "poloklubba",
    "poloklubbans": "poloklubba",
    "poloklubbas": "poloklubba",
    "poloklubbe": "poloklubba",
    "poloklubbor": "poloklubba",
    "poloklubborna": "poloklubba",
    "poloklubbornas": "poloklubba",
    "poloklubbors": "poloklubba",
    "poloklubbs": "poloklubba",
    "polokrag": "polokrage",
    "polokragar": "polokrage",
    "polokragarna": "polokrage",
    "polokragarnas": "polokrage",
    "polokragars": "polokrage",
    "polokragen": "polokrage",
    "polokragens": "polokrage",
    "polokrages": "polokrage",
    "polokrags": "polokrage",
    "polon": "polo",
    "poloniet": "polonium",
    "poloniets": "polonium",
    "poloniumet": "polonium",
    "poloniumets": "polonium",
    "poloniums": "polonium",
    "polons": "polo",
    "polonäsen": "polonäs",
    "polonäsens": "polonäs",
    "polonäser": "polonäs",
    "polonäserna": "polonäs",
    "polonäsernas": "polonäs",
    "polonäsers": "polonäs",
    "polos": "polo",
    "polot": "polo",
    "polotröj": "polotröja",
    "polotröjan": "polotröja",
    "polotröjans": "polotröja",
    "polotröjas": "polotröja",
    "polotröje": "polotröja",
    "polotröjor": "polotröja",
    "polotröjorna": "polotröja",
    "polotröjornas": "polotröja",
    "polotröjors": "polotröja",
    "polotröjs": "polotröja",
    "polots": "polo",
    "pols": "pol",
    "polsk": "polska",
    "polsk-franska": "polsk-fransk",
    "polsk-franskare": "polsk-fransk",
    "polsk-franskares": "polsk-fransk",
    "polsk-franskas": "polsk-fransk",
    "polsk-franskast": "polsk-fransk",
    "polsk-franskaste": "polsk-fransk",
    "polsk-franskastes": "polsk-fransk",
    "polsk-franskasts": "polsk-fransk",
    "polsk-franske": "polsk-fransk",
    "polsk-franskes": "polsk-fransk",
    "polsk-fransks": "polsk-fransk",
    "polsk-franskt": "polsk-fransk",
    "polsk-franskts": "polsk-fransk",
    "polska": "polsk",
    "polskan": "polska",
    "polskans": "polska",
    "polskare": "polsk",
    "polskares": "polsk",
    "polskas": "polska",
    "polskast": "polsk",
    "polskaste": "polsk",
    "polskastes": "polsk",
    "polskasts": "polsk",
    "polske": "polska",
    "polskes": "polsk",
    "polskheten": "polskhet",
    "polskhetens": "polskhet",
    "polskhets": "polskhet",
    "polskon": "polsko",
    "polskons": "polsko",
    "polskor": "polsko",
    "polskorna": "polsko",
    "polskornas": "polsko",
    "polskors": "polsko",
    "polskos": "polsko",
    "polsks": "polsk",
    "polskt": "polsk",
    "polskts": "polsk",
    "polster": "polstra",
    "polstrad": "polstra",
    "polstrade": "polstra",
    "polstrades": "polstra",
    "polstrads": "polstra",
    "polstrande": "polstra",
    "polstranden": "polstrande",
    "polstrandena": "polstrande",
    "polstrandenas": "polstrande",
    "polstrandens": "polstrande",
    "polstrandes": "polstrande",
    "polstrandet": "polstrande",
    "polstrandets": "polstrande",
    "polstrar": "polstra",
    "polstras": "polstra",
    "polstrat": "polstra",
    "polstrats": "polstra",
    "polvändningar": "polvändning",
    "polvändningarna": "polvändning",
    "polvändningarnas": "polvändning",
    "polvändningars": "polvändning",
    "polvändningen": "polvändning",
    "polvändningens": "polvändning",
    "polvändnings": "polvändning",
    "polvändningsskydden": "polvändningsskydd",
    "polvändningsskyddens": "polvändningsskydd",
    "polvändningsskyddet": "polvändningsskydd",
    "polvändningsskyddets": "polvändningsskydd",
    "polvändningsskydds": "polvändningsskydd",
    "polyamiden": "polyamid",
    "polyamidens": "polyamid",
    "polyamider": "polyamid",
    "polyamiderna": "polyamid",
    "polyamidernas": "polyamid",
    "polyamiders": "polyamid",
    "polyamids": "polyamid",
    "polyandrien": "polyandri",
    "polyandriens": "polyandri",
    "polyandrin": "polyandri",
    "polyandrins": "polyandri",
    "polyandris": "polyandri",
    "polycentrismen": "polycentrism",
    "polycentrismens": "polycentrism",
    "polycentrismer": "polycentrism",
    "polycentrismerna": "polycentrism",
    "polycentrismernas": "polycentrism",
    "polycentrismers": "polycentrism",
    "polycentrisms": "polycentrism",
    "polyedern": "polyeder",
    "polyederns": "polyeder",
    "polyeders": "polyeder",
    "polyedrar": "polyeder",
    "polyedrarna": "polyeder",
    "polyedrarnas": "polyeder",
    "polyedrars": "polyeder",
    "polyesterbaserade": "polyesterbaserad",
    "polyesterbaserades": "polyesterbaserad",
    "polyesterbaserads": "polyesterbaserad",
    "polyesterbaserat": "polyesterbaserad",
    "polyesterbaserats": "polyesterbaserad",
    "polyestern": "polyester",
    "polyesterns": "polyester",
    "polyesters": "polyester",
    "polyestrar": "polyester",
    "polyestrarna": "polyester",
    "polyestrarnas": "polyester",
    "polyestrars": "polyester",
    "polyetenen": "polyeten",
    "polyetenens": "polyeten",
    "polyetenet": "polyeten",
    "polyetenets": "polyeten",
    "polyetens": "polyeten",
    "polyetern": "polyeter",
    "polyeterns": "polyeter",
    "polyeters": "polyeter",
    "polyetrar": "polyeter",
    "polyetrarna": "polyeter",
    "polyetrarnas": "polyeter",
    "polyetrars": "polyeter",
    "polyfona": "polyfon",
    "polyfonare": "polyfon",
    "polyfonares": "polyfon",
    "polyfonas": "polyfon",
    "polyfonast": "polyfon",
    "polyfonaste": "polyfon",
    "polyfonastes": "polyfon",
    "polyfonasts": "polyfon",
    "polyfone": "polyfon",
    "polyfones": "polyfon",
    "polyfonien": "polyfoni",
    "polyfoniens": "polyfoni",
    "polyfonier": "polyfoni",
    "polyfonierna": "polyfoni",
    "polyfoniernas": "polyfoni",
    "polyfoniers": "polyfoni",
    "polyfonin": "polyfoni",
    "polyfonins": "polyfoni",
    "polyfonis": "polyfoni",
    "polyfons": "polyfon",
    "polyfont": "polyfon",
    "polyfonts": "polyfon",
    "polyfosfaten": "polyfosfat",
    "polyfosfatens": "polyfosfat",
    "polyfosfater": "polyfosfat",
    "polyfosfaterna": "polyfosfat",
    "polyfosfaternas": "polyfosfat",
    "polyfosfaters": "polyfosfat",
    "polyfosfats": "polyfosfat",
    "polygama": "polygam",
    "polygamare": "polygam",
    "polygamares": "polygam",
    "polygamas": "polygam",
    "polygamast": "polygam",
    "polygamaste": "polygam",
    "polygamastes": "polygam",
    "polygamasts": "polygam",
    "polygame": "polygam",
    "polygames": "polygam",
    "polygamien": "polygami",
    "polygamiens": "polygami",
    "polygamin": "polygami",
    "polygamins": "polygami",
    "polygamis": "polygami",
    "polygams": "polygam",
    "polygamt": "polygam",
    "polygamts": "polygam",
    "polyglotta": "polyglott",
    "polyglottare": "polyglott",
    "polyglottares": "polyglott",
    "polyglottas": "polyglott",
    "polyglottast": "polyglott",
    "polyglottaste": "polyglott",
    "polyglottastes": "polyglott",
    "polyglottasts": "polyglott",
    "polyglotte": "polyglott",
    "polyglotten": "polyglott",
    "polyglottens": "polyglott",
    "polyglotter": "polyglott",
    "polyglotterna": "polyglott",
    "polyglotternas": "polyglott",
    "polyglotters": "polyglott",
    "polyglottes": "polyglott",
    "polyglotts": "polyglott",
    "polygonen": "polygon",
    "polygonens": "polygon",
    "polygoner": "polygon",
    "polygonerna": "polygon",
    "polygonernas": "polygon",
    "polygoners": "polygon",
    "polygons": "polygon",
    "polygrafen": "polygraf",
    "polygrafens": "polygraf",
    "polygrafer": "polygraf",
    "polygraferna": "polygraf",
    "polygrafernas": "polygraf",
    "polygrafers": "polygraf",
    "polygrafs": "polygraf",
    "polyhistorer": "polyhistor",
    "polyhistorerna": "polyhistor",
    "polyhistorernas": "polyhistor",
    "polyhistorers": "polyhistor",
    "polyhistorn": "polyhistor",
    "polyhistorns": "polyhistor",
    "polyhistors": "polyhistor",
    "polyklorerade": "polyklorerad",
    "polyklorerades": "polyklorerad",
    "polyklorerads": "polyklorerad",
    "polyklorerat": "polyklorerad",
    "polyklorerats": "polyklorerad",
    "polykroma": "polykrom",
    "polykromare": "polykrom",
    "polykromares": "polykrom",
    "polykromas": "polykrom",
    "polykromast": "polykrom",
    "polykromaste": "polykrom",
    "polykromastes": "polykrom",
    "polykromasts": "polykrom",
    "polykrome": "polykrom",
    "polykromes": "polykrom",
    "polykroms": "polykrom",
    "polykromt": "polykrom",
    "polykromts": "polykrom",
    "polymerbeläggningar": "polymerbeläggning",
    "polymerbeläggningarna": "polymerbeläggning",
    "polymerbeläggningarnas": "polymerbeläggning",
    "polymerbeläggningars": "polymerbeläggning",
    "polymerbeläggningen": "polymerbeläggning",
    "polymerbeläggningens": "polymerbeläggning",
    "polymerbeläggnings": "polymerbeläggning",
    "polymeren": "polymer",
    "polymerens": "polymer",
    "polymerer": "polymer",
    "polymererna": "polymer",
    "polymerernas": "polymer",
    "polymerers": "polymer",
    "polymerisationen": "polymerisation",
    "polymerisationens": "polymerisation",
    "polymerisationer": "polymerisation",
    "polymerisationerna": "polymerisation",
    "polymerisationernas": "polymerisation",
    "polymerisationers": "polymerisation",
    "polymerisations": "polymerisation",
    "polymerlösningar": "polymerlösning",
    "polymerlösningarna": "polymerlösning",
    "polymerlösningarnas": "polymerlösning",
    "polymerlösningars": "polymerlösning",
    "polymerlösningen": "polymerlösning",
    "polymerlösningens": "polymerlösning",
    "polymerlösnings": "polymerlösning",
    "polymers": "polymer",
    "polymorfa": "polymorf",
    "polymorfare": "polymorf",
    "polymorfares": "polymorf",
    "polymorfas": "polymorf",
    "polymorfast": "polymorf",
    "polymorfaste": "polymorf",
    "polymorfastes": "polymorf",
    "polymorfasts": "polymorf",
    "polymorfe": "polymorf",
    "polymorfes": "polymorf",
    "polymorfs": "polymorf",
    "polymorft": "polymorf",
    "polymorfts": "polymorf",
    "polynesiern": "polynesier",
    "polynesierna": "polynesier",
    "polynesiernas": "polynesier",
    "polynesierns": "polynesier",
    "polynesiers": "polynesier",
    "polynesiska": "polynesisk",
    "polynesiskan": "polynesiska",
    "polynesiskans": "polynesiska",
    "polynesiskare": "polynesisk",
    "polynesiskares": "polynesisk",
    "polynesiskas": "polynesiska",
    "polynesiskast": "polynesisk",
    "polynesiskaste": "polynesisk",
    "polynesiskastes": "polynesisk",
    "polynesiskasts": "polynesisk",
    "polynesiske": "polynesiska",
    "polynesiskes": "polynesisk",
    "polynesiskor": "polynesiska",
    "polynesiskorna": "polynesiska",
    "polynesiskornas": "polynesiska",
    "polynesiskors": "polynesiska",
    "polynesisks": "polynesisk",
    "polynesiskt": "polynesisk",
    "polynesiskts": "polynesisk",
    "polyni": "polynia",
    "polynian": "polynia",
    "polynians": "polynia",
    "polynias": "polynia",
    "polynie": "polynia",
    "polynior": "polynia",
    "polyniorna": "polynia",
    "polyniornas": "polynia",
    "polyniors": "polynia",
    "polynis": "polynia",
    "polynomen": "polynom",
    "polynomens": "polynom",
    "polynomer": "polynom",
    "polynomerna": "polynom",
    "polynomernas": "polynom",
    "polynomers": "polynom",
    "polynomet": "polynom",
    "polynomets": "polynom",
    "polynoms": "polynom",
    "polypen": "polyp",
    "polypens": "polyp",
    "polyper": "polyp",
    "polyperna": "polyp",
    "polypernas": "polyp",
    "polypers": "polyp",
    "polypropenen": "polypropen",
    "polypropenens": "polypropen",
    "polypropenet": "polypropen",
    "polypropenets": "polypropen",
    "polypropenmaterialen": "polypropenmaterial",
    "polypropenmaterialens": "polypropenmaterial",
    "polypropenmaterialet": "polypropenmaterial",
    "polypropenmaterialets": "polypropenmaterial",
    "polypropenmaterials": "polypropenmaterial",
    "polypropens": "polypropen",
    "polyps": "polyp",
    "polystyrenen": "polystyren",
    "polystyrenens": "polystyren",
    "polystyrenet": "polystyren",
    "polystyrenets": "polystyren",
    "polystyrens": "polystyren",
    "polysyndesen": "polysyndes",
    "polysyndesens": "polysyndes",
    "polysyndeser": "polysyndes",
    "polysyndeserna": "polysyndes",
    "polysyndesernas": "polysyndes",
    "polysyndesers": "polysyndes",
    "polyteismen": "polyteism",
    "polyteismens": "polyteism",
    "polyteismer": "polyteism",
    "polyteismerna": "polyteism",
    "polyteismernas": "polyteism",
    "polyteismers": "polyteism",
    "polyteisms": "polyteism",
    "polyteistiska": "polyteistisk",
    "polyteistiskas": "polyteistisk",
    "polyteistiske": "polyteistisk",
    "polyteistiskes": "polyteistisk",
    "polyteistisks": "polyteistisk",
    "polyteistiskt": "polyteistisk",
    "polyteistiskts": "polyteistisk",
    "polytekniska": "polyteknisk",
    "polytekniskare": "polyteknisk",
    "polytekniskares": "polyteknisk",
    "polytekniskas": "polyteknisk",
    "polytekniskast": "polyteknisk",
    "polytekniskaste": "polyteknisk",
    "polytekniskastes": "polyteknisk",
    "polytekniskasts": "polyteknisk",
    "polytekniske": "polyteknisk",
    "polytekniskes": "polyteknisk",
    "polyteknisks": "polyteknisk",
    "polytekniskt": "polyteknisk",
    "polytekniskts": "polyteknisk",
    "polyuretanen": "polyuretan",
    "polyuretanens": "polyuretan",
    "polyuretans": "polyuretan",
    "polyvinylkloriden": "polyvinylklorid",
    "polyvinylkloridens": "polyvinylklorid",
    "polyvinylklorids": "polyvinylklorid",
    "polära": "polär",
    "polärare": "polär",
    "polärares": "polär",
    "poläras": "polär",
    "polärast": "polär",
    "poläraste": "polär",
    "polärastes": "polär",
    "polärasts": "polär",
    "poläre": "polär",
    "poläres": "polär",
    "polärs": "polär",
    "polärt": "polär",
    "polärts": "polär",
    "pomad": "pomada",
    "pomadan": "pomada",
    "pomadans": "pomada",
    "pomadas": "pomada",
    "pomade": "pomada",
    "pomaderad": "pomadera",
    "pomaderade": "pomadera",
    "pomaderades": "pomadera",
    "pomaderads": "pomadera",
    "pomaderande": "pomadera",
    "pomaderanden": "pomaderande",
    "pomaderandena": "pomaderande",
    "pomaderandenas": "pomaderande",
    "pomaderandens": "pomaderande",
    "pomaderandes": "pomaderande",
    "pomaderandet": "pomaderande",
    "pomaderandets": "pomaderande",
    "pomaderar": "pomadera",
    "pomaderas": "pomadera",
    "pomaderat": "pomadera",
    "pomaderats": "pomadera",
    "pomaderbara": "pomaderbar",
    "pomaderbarare": "pomaderbar",
    "pomaderbarares": "pomaderbar",
    "pomaderbaras": "pomaderbar",
    "pomaderbarast": "pomaderbar",
    "pomaderbaraste": "pomaderbar",
    "pomaderbarastes": "pomaderbar",
    "pomaderbarasts": "pomaderbar",
    "pomaderbare": "pomaderbar",
    "pomaderbares": "pomaderbar",
    "pomaderbarheten": "pomaderbarhet",
    "pomaderbarhetens": "pomaderbarhet",
    "pomaderbarhets": "pomaderbarhet",
    "pomaderbars": "pomaderbar",
    "pomaderbart": "pomaderbar",
    "pomaderbarts": "pomaderbar",
    "pomaderingar": "pomadering",
    "pomaderingarna": "pomadering",
    "pomaderingarnas": "pomadering",
    "pomaderingars": "pomadering",
    "pomaderingen": "pomadering",
    "pomaderingens": "pomadering",
    "pomaderings": "pomadering",
    "pomador": "pomada",
    "pomadorna": "pomada",
    "pomadornas": "pomada",
    "pomadors": "pomada",
    "pomads": "pomada",
    "pomeransen": "pomerans",
    "pomeransens": "pomerans",
    "pomeranser": "pomerans",
    "pomeranserna": "pomerans",
    "pomeransernas": "pomerans",
    "pomeransers": "pomerans",
    "pomeransskalen": "pomeransskal",
    "pomeransskalens": "pomeransskal",
    "pomeransskalet": "pomeransskal",
    "pomeransskalets": "pomeransskal",
    "pomeransskals": "pomeransskal",
    "pommerska": "pommersk",
    "pommerskare": "pommersk",
    "pommerskares": "pommersk",
    "pommerskas": "pommersk",
    "pommerskast": "pommersk",
    "pommerskaste": "pommersk",
    "pommerskastes": "pommersk",
    "pommerskasts": "pommersk",
    "pommerske": "pommersk",
    "pommerskes": "pommersk",
    "pommersks": "pommersk",
    "pommerskt": "pommersk",
    "pommerskts": "pommersk",
    "pomologen": "pomolog",
    "pomologens": "pomolog",
    "pomologer": "pomolog",
    "pomologerna": "pomolog",
    "pomologernas": "pomolog",
    "pomologers": "pomolog",
    "pomologien": "pomologi",
    "pomologiens": "pomologi",
    "pomologin": "pomologi",
    "pomologins": "pomologi",
    "pomologis": "pomologi",
    "pomologs": "pomolog",
    "pompan": "pompa",
    "pompans": "pompa",
    "pompas": "pompa",
    "pompen": "pomp",
    "pompens": "pomp",
    "pomperipossaeffekten": "pomperipossaeffekt",
    "pomperipossaeffektens": "pomperipossaeffekt",
    "pomperipossaeffekts": "pomperipossaeffekt",
    "pompongen": "pompong",
    "pompongens": "pompong",
    "pomponger": "pompong",
    "pompongerna": "pompong",
    "pompongernas": "pompong",
    "pompongers": "pompong",
    "pompongs": "pompong",
    "pomps": "pomp",
    "pompösa": "pompös",
    "pompösare": "pompös",
    "pompösares": "pompös",
    "pompösas": "pompös",
    "pompösast": "pompös",
    "pompösaste": "pompös",
    "pompösastes": "pompös",
    "pompösasts": "pompös",
    "pompöse": "pompös",
    "pompöses": "pompös",
    "pompöst": "pompös",
    "pompösts": "pompös",
    "ponchon": "poncho",
    "ponchons": "poncho",
    "ponchor": "poncho",
    "ponchorna": "poncho",
    "ponchornas": "poncho",
    "ponchors": "poncho",
    "ponchos": "poncho",
    "ponchosen": "poncho",
    "ponchosens": "poncho",
    "ponden": "pond",
    "pondens": "pond",
    "ponderabels": "ponderabel",
    "ponderabelt": "ponderabel",
    "ponderabelts": "ponderabel",
    "ponderabla": "ponderabel",
    "ponderablare": "ponderabel",
    "ponderablares": "ponderabel",
    "ponderablas": "ponderabel",
    "ponderablast": "ponderabel",
    "ponderablaste": "ponderabel",
    "ponderablastes": "ponderabel",
    "ponderablasts": "ponderabel",
    "ponderable": "ponderabel",
    "ponderables": "ponderabel",
    "pondet": "pond",
    "pondets": "pond",
    "ponds": "pond",
    "pondusen": "pondus",
    "pondusens": "pondus",
    "ponerade": "ponera",
    "ponerades": "ponera",
    "ponerande": "ponera",
    "poneranden": "ponerande",
    "ponerandena": "ponerande",
    "ponerandenas": "ponerande",
    "ponerandens": "ponerande",
    "ponerandes": "ponerande",
    "ponerandet": "ponerande",
    "ponerandets": "ponerande",
    "ponerar": "ponera",
    "poneras": "ponera",
    "ponerat": "ponera",
    "ponerats": "ponera",
    "poneringar": "ponering",
    "poneringarna": "ponering",
    "poneringarnas": "ponering",
    "poneringars": "ponering",
    "poneringen": "ponering",
    "poneringens": "ponering",
    "ponerings": "ponering",
    "ponnier": "ponny",
    "ponnierna": "ponny",
    "ponniernas": "ponny",
    "ponniers": "ponny",
    "ponnies": "ponny",
    "ponniesarna": "ponny",
    "ponniesarnas": "ponny",
    "ponnyer": "ponny",
    "ponnyerna": "ponny",
    "ponnyernas": "ponny",
    "ponnyers": "ponny",
    "ponnyn": "ponny",
    "ponnyns": "ponny",
    "ponnys": "ponny",
    "ponnysar": "ponny",
    "ponnysarna": "ponny",
    "ponnysarnas": "ponny",
    "ponnysars": "ponny",
    "pontifikaten": "pontifikat",
    "pontifikatens": "pontifikat",
    "pontifikatet": "pontifikat",
    "pontifikatets": "pontifikat",
    "pontifikats": "pontifikat",
    "pontonbroar": "pontonbro",
    "pontonbroarna": "pontonbro",
    "pontonbroarnas": "pontonbro",
    "pontonbroars": "pontonbro",
    "pontonbron": "pontonbro",
    "pontonbrons": "pontonbro",
    "pontonbros": "pontonbro",
    "pontonen": "ponton",
    "pontonens": "ponton",
    "pontoner": "ponton",
    "pontonerna": "ponton",
    "pontonernas": "ponton",
    "pontoners": "ponton",
    "pontonjären": "pontonjär",
    "pontonjärens": "pontonjär",
    "pontonjärer": "pontonjär",
    "pontonjärerna": "pontonjär",
    "pontonjärernas": "pontonjär",
    "pontonjärers": "pontonjär",
    "pontonjärs": "pontonjär",
    "pontons": "ponton",
    "poolen": "pool",
    "poolens": "pool",
    "pooler": "pool",
    "poolerna": "pool",
    "poolernas": "pool",
    "poolers": "pool",
    "poolkanten": "poolkant",
    "poolkantens": "poolkant",
    "poolkanter": "poolkant",
    "poolkanterna": "poolkant",
    "poolkanternas": "poolkant",
    "poolkanters": "poolkant",
    "poolkants": "poolkant",
    "pools": "pool",
    "popcornen": "popcorn",
    "popcornens": "popcorn",
    "popcornet": "popcorn",
    "popcornets": "popcorn",
    "popcorns": "popcorn",
    "popen": "pop",
    "popens": "pop",
    "poper": "pop",
    "poperna": "pop",
    "popernas": "pop",
    "popers": "pop",
    "popgruppen": "popgrupp",
    "popgruppens": "popgrupp",
    "popgrupper": "popgrupp",
    "popgrupperna": "popgrupp",
    "popgruppernas": "popgrupp",
    "popgruppers": "popgrupp",
    "popgrupps": "popgrupp",
    "popkonserten": "popkonsert",
    "popkonsertens": "popkonsert",
    "popkonserter": "popkonsert",
    "popkonserterna": "popkonsert",
    "popkonserternas": "popkonsert",
    "popkonserters": "popkonsert",
    "popkonserts": "popkonsert",
    "popkonsten": "popkonst",
    "popkonstens": "popkonst",
    "popkonsts": "popkonst",
    "poplinen": "poplin",
    "poplinens": "poplin",
    "popliner": "poplin",
    "poplinerna": "poplin",
    "poplinernas": "poplin",
    "popliners": "poplin",
    "poplinet": "poplin",
    "poplinets": "poplin",
    "poplinrockar": "poplinrock",
    "poplinrockarna": "poplinrock",
    "poplinrockarnas": "poplinrock",
    "poplinrockars": "poplinrock",
    "poplinrocken": "poplinrock",
    "poplinrockens": "poplinrock",
    "poplinrocks": "poplinrock",
    "poplins": "poplin",
    "poplåtar": "poplåt",
    "poplåtarna": "poplåt",
    "poplåtarnas": "poplåt",
    "poplåtars": "poplåt",
    "poplåten": "poplåt",
    "poplåtens": "poplåt",
    "poplåts": "poplåt",
    "popmusiken": "popmusik",
    "popmusikens": "popmusik",
    "popmusiks": "popmusik",
    "poppad": "poppa",
    "poppade": "poppa",
    "poppades": "poppa",
    "poppads": "poppa",
    "poppande": "poppa",
    "poppanden": "poppande",
    "poppandena": "poppande",
    "poppandenas": "poppande",
    "poppandens": "poppande",
    "poppandes": "poppande",
    "poppandet": "poppande",
    "poppandets": "poppande",
    "poppar": "poppa",
    "poppas": "poppa",
    "poppat": "poppa",
    "poppats": "poppa",
    "poppeln": "poppel",
    "poppelns": "poppel",
    "poppels": "poppel",
    "poppen": "popp",
    "poppens": "popp",
    "poppiga": "poppig",
    "poppigare": "poppig",
    "poppigares": "poppig",
    "poppigas": "poppig",
    "poppigast": "poppig",
    "poppigaste": "poppig",
    "poppigastes": "poppig",
    "poppigasts": "poppig",
    "poppige": "poppig",
    "poppiges": "poppig",
    "poppigheten": "poppighet",
    "poppighetens": "poppighet",
    "poppighets": "poppighet",
    "poppigs": "poppig",
    "poppigt": "poppig",
    "poppigts": "poppig",
    "popplar": "poppel",
    "popplarna": "poppel",
    "popplarnas": "poppel",
    "popplars": "poppel",
    "popps": "popp",
    "pops": "pop",
    "popsångar": "popsångare",
    "popsångaren": "popsångare",
    "popsångarens": "popsångare",
    "popsångares": "popsångare",
    "popsångarna": "popsångare",
    "popsångarnas": "popsångare",
    "popularisatorer": "popularisator",
    "popularisatorerna": "popularisator",
    "popularisatorernas": "popularisator",
    "popularisatorers": "popularisator",
    "popularisatorn": "popularisator",
    "popularisatorns": "popularisator",
    "popularisators": "popularisator",
    "populariserad": "popularisera",
    "populariserade": "popularisera",
    "populariserades": "popularisera",
    "populariserads": "popularisera",
    "populariserande": "popularisera",
    "populariseranden": "populariserande",
    "populariserandena": "populariserande",
    "populariserandenas": "populariserande",
    "populariserandens": "populariserande",
    "populariserandes": "populariserande",
    "populariserandet": "populariserande",
    "populariserandets": "populariserande",
    "populariserar": "popularisera",
    "populariseras": "popularisera",
    "populariserat": "popularisera",
    "populariserats": "popularisera",
    "populariserbara": "populariserbar",
    "populariserbarare": "populariserbar",
    "populariserbarares": "populariserbar",
    "populariserbaras": "populariserbar",
    "populariserbarast": "populariserbar",
    "populariserbaraste": "populariserbar",
    "populariserbarastes": "populariserbar",
    "populariserbarasts": "populariserbar",
    "populariserbare": "populariserbar",
    "populariserbares": "populariserbar",
    "populariserbarheten": "populariserbarhet",
    "populariserbarhetens": "populariserbarhet",
    "populariserbarhets": "populariserbarhet",
    "populariserbars": "populariserbar",
    "populariserbart": "populariserbar",
    "populariserbarts": "populariserbar",
    "populariseringar": "popularisering",
    "populariseringarna": "popularisering",
    "populariseringarnas": "popularisering",
    "populariseringars": "popularisering",
    "populariseringen": "popularisering",
    "populariseringens": "popularisering",
    "populariserings": "popularisering",
    "populariteten": "popularitet",
    "popularitetens": "popularitet",
    "populariteter": "popularitet",
    "populariteterna": "popularitet",
    "populariteternas": "popularitet",
    "populariteters": "popularitet",
    "popularitets": "popularitet",
    "popularitetsmässiga": "popularitetsmässig",
    "popularitetsmässigare": "popularitetsmässig",
    "popularitetsmässigares": "popularitetsmässig",
    "popularitetsmässigas": "popularitetsmässig",
    "popularitetsmässigast": "popularitetsmässig",
    "popularitetsmässigaste": "popularitetsmässig",
    "popularitetsmässigastes": "popularitetsmässig",
    "popularitetsmässigasts": "popularitetsmässig",
    "popularitetsmässige": "popularitetsmässig",
    "popularitetsmässiges": "popularitetsmässig",
    "popularitetsmässigs": "popularitetsmässig",
    "popularitetsmässigt": "popularitetsmässig",
    "popularitetsmässigts": "popularitetsmässig",
    "populasen": "populas",
    "populasens": "populas",
    "populationen": "population",
    "populationens": "population",
    "populationer": "population",
    "populationerna": "population",
    "populationernas": "population",
    "populationers": "population",
    "populations": "population",
    "populismen": "populism",
    "populismens": "populism",
    "populismer": "populism",
    "populismerna": "populism",
    "populismernas": "populism",
    "populismers": "populism",
    "populisms": "populism",
    "populisten": "populist",
    "populistens": "populist",
    "populister": "populist",
    "populisterna": "populist",
    "populisternas": "populist",
    "populisters": "populist",
    "populistiska": "populistisk",
    "populistiskare": "populistisk",
    "populistiskares": "populistisk",
    "populistiskas": "populistisk",
    "populistiskast": "populistisk",
    "populistiskaste": "populistisk",
    "populistiskastes": "populistisk",
    "populistiskasts": "populistisk",
    "populistiske": "populistisk",
    "populistiskes": "populistisk",
    "populistisks": "populistisk",
    "populistiskt": "populistisk",
    "populistiskts": "populistisk",
    "populists": "populist",
    "populära": "populär",
    "populärare": "populär",
    "populärares": "populär",
    "populäras": "populär",
    "populärast": "populär",
    "populäraste": "populär",
    "populärastes": "populär",
    "populärasts": "populär",
    "populäre": "populär",
    "populäres": "populär",
    "populärkonserten": "populärkonsert",
    "populärkonsertens": "populärkonsert",
    "populärkonserter": "populärkonsert",
    "populärkonserterna": "populärkonsert",
    "populärkonserternas": "populärkonsert",
    "populärkonserters": "populärkonsert",
    "populärkonserts": "populärkonsert",
    "populärkulturen": "populärkultur",
    "populärkulturens": "populärkultur",
    "populärkulturer": "populärkultur",
    "populärkulturerna": "populärkultur",
    "populärkulturernas": "populärkultur",
    "populärkulturers": "populärkultur",
    "populärkulturs": "populärkultur",
    "populärmusiken": "populärmusik",
    "populärmusikens": "populärmusik",
    "populärmusiks": "populärmusik",
    "populärpressen": "populärpress",
    "populärpressens": "populärpress",
    "populärs": "populär",
    "populärt": "populär",
    "populärts": "populär",
    "populärvetenskapen": "populärvetenskap",
    "populärvetenskapens": "populärvetenskap",
    "populärvetenskapliga": "populärvetenskaplig",
    "populärvetenskapligare": "populärvetenskaplig",
    "populärvetenskapligares": "populärvetenskaplig",
    "populärvetenskapligas": "populärvetenskaplig",
    "populärvetenskapligast": "populärvetenskaplig",
    "populärvetenskapligaste": "populärvetenskaplig",
    "populärvetenskapligastes": "populärvetenskaplig",
    "populärvetenskapligasts": "populärvetenskaplig",
    "populärvetenskaplige": "populärvetenskaplig",
    "populärvetenskapliges": "populärvetenskaplig",
    "populärvetenskapligheten": "populärvetenskaplighet",
    "populärvetenskaplighetens": "populärvetenskaplighet",
    "populärvetenskaplighets": "populärvetenskaplighet",
    "populärvetenskapligs": "populärvetenskaplig",
    "populärvetenskapligt": "populärvetenskaplig",
    "populärvetenskapligts": "populärvetenskaplig",
    "populärvetenskaps": "populärvetenskap",
    "poren": "por",
    "porens": "por",
    "porer": "por",
    "porerna": "por",
    "porernas": "por",
    "porers": "por",
    "porfyren": "porfyr",
    "porfyrens": "porfyr",
    "porfyrer": "porfyr",
    "porfyrerna": "porfyr",
    "porfyrernas": "porfyr",
    "porfyrers": "porfyr",
    "porfyrs": "porfyr",
    "poriga": "porig",
    "porigare": "porig",
    "porigares": "porig",
    "porigas": "porig",
    "porigast": "porig",
    "porigaste": "porig",
    "porigastes": "porig",
    "porigasts": "porig",
    "porige": "porig",
    "poriges": "porig",
    "porigs": "porig",
    "porigt": "porig",
    "porigts": "porig",
    "porlade": "porla",
    "porlades": "porla",
    "porlande": "porla",
    "porlanden": "porlande",
    "porlandena": "porlande",
    "porlandenas": "porlande",
    "porlandens": "porlande",
    "porlandes": "porlande",
    "porlandet": "porlande",
    "porlandets": "porlande",
    "porlar": "porla",
    "porlas": "porla",
    "porlat": "porla",
    "porlats": "porla",
    "porlet": "porl",
    "porlets": "porl",
    "porls": "porl",
    "pormaskar": "pormask",
    "pormaskarna": "pormask",
    "pormaskarnas": "pormask",
    "pormaskars": "pormask",
    "pormasken": "pormask",
    "pormaskens": "pormask",
    "pormasks": "pormask",
    "pornografien": "pornografi",
    "pornografiens": "pornografi",
    "pornografin": "pornografi",
    "pornografins": "pornografi",
    "pornografis": "pornografi",
    "pornografiska": "pornografisk",
    "pornografiskare": "pornografisk",
    "pornografiskares": "pornografisk",
    "pornografiskas": "pornografisk",
    "pornografiskast": "pornografisk",
    "pornografiskaste": "pornografisk",
    "pornografiskastes": "pornografisk",
    "pornografiskasts": "pornografisk",
    "pornografiske": "pornografisk",
    "pornografiskes": "pornografisk",
    "pornografisks": "pornografisk",
    "pornografiskt": "pornografisk",
    "pornografiskts": "pornografisk",
    "porositeten": "porositet",
    "porositetens": "porositet",
    "porositeter": "porositet",
    "porositeterna": "porositet",
    "porositeternas": "porositet",
    "porositeters": "porositet",
    "porositets": "porositet",
    "porren": "porr",
    "porrens": "porr",
    "porrfilmen": "porrfilm",
    "porrfilmens": "porrfilm",
    "porrfilmer": "porrfilm",
    "porrfilmerna": "porrfilm",
    "porrfilmernas": "porrfilm",
    "porrfilmers": "porrfilm",
    "porrfilms": "porrfilm",
    "porriga": "porrig",
    "porrigare": "porrig",
    "porrigares": "porrig",
    "porrigas": "porrig",
    "porrigast": "porrig",
    "porrigaste": "porrig",
    "porrigastes": "porrig",
    "porrigasts": "porrig",
    "porrige": "porrig",
    "porriges": "porrig",
    "porrigheten": "porrighet",
    "porrighetens": "porrighet",
    "porrighets": "porrighet",
    "porrigs": "porrig",
    "porrigt": "porrig",
    "porrigts": "porrig",
    "porrklubbar": "porrklubb",
    "porrklubbarna": "porrklubb",
    "porrklubbarnas": "porrklubb",
    "porrklubbars": "porrklubb",
    "porrklubben": "porrklubb",
    "porrklubbens": "porrklubb",
    "porrklubbs": "porrklubb",
    "porrs": "porr",
    "porrstjärnan": "porrstjärna",
    "porrstjärnans": "porrstjärna",
    "porrstjärnas": "porrstjärna",
    "porrstjärne": "porrstjärna",
    "porrstjärnor": "porrstjärna",
    "porrstjärnorna": "porrstjärna",
    "porrstjärnornas": "porrstjärna",
    "porrstjärnors": "porrstjärna",
    "porrsurfade": "porrsurfa",
    "porrsurfades": "porrsurfa",
    "porrsurfande": "porrsurfa",
    "porrsurfanden": "porrsurfande",
    "porrsurfandena": "porrsurfande",
    "porrsurfandenas": "porrsurfande",
    "porrsurfandens": "porrsurfande",
    "porrsurfandes": "porrsurfande",
    "porrsurfandet": "porrsurfande",
    "porrsurfandets": "porrsurfande",
    "porrsurfar": "porrsurfa",
    "porrsurfas": "porrsurfa",
    "porrsurfat": "porrsurfa",
    "porrsurfats": "porrsurfa",
    "porrtidningar": "porrtidning",
    "porrtidningarna": "porrtidning",
    "porrtidningarnas": "porrtidning",
    "porrtidningars": "porrtidning",
    "porrtidningen": "porrtidning",
    "porrtidningens": "porrtidning",
    "porrtidnings": "porrtidning",
    "pors": "por",
    "porsen": "pors",
    "porsens": "pors",
    "porsliner": "porslin",
    "porslinerna": "porslin",
    "porslinernas": "porslin",
    "porsliners": "porslin",
    "porslinet": "porslin",
    "porslinets": "porslin",
    "porslins": "porslin",
    "porslinsaffären": "porslinsaffär",
    "porslinsaffärens": "porslinsaffär",
    "porslinsaffärer": "porslinsaffär",
    "porslinsaffärerna": "porslinsaffär",
    "porslinsaffärernas": "porslinsaffär",
    "porslinsaffärers": "porslinsaffär",
    "porslinsaffärs": "porslinsaffär",
    "porslinsblom": "porslinsblomma",
    "porslinsblomman": "porslinsblomma",
    "porslinsblommans": "porslinsblomma",
    "porslinsblommas": "porslinsblomma",
    "porslinsblomme": "porslinsblomma",
    "porslinsblommor": "porslinsblomma",
    "porslinsblommorna": "porslinsblomma",
    "porslinsblommornas": "porslinsblomma",
    "porslinsblommors": "porslinsblomma",
    "porslinsbloms": "porslinsblomma",
    "porslinsdegeln": "porslinsdegel",
    "porslinsdegelns": "porslinsdegel",
    "porslinsdegels": "porslinsdegel",
    "porslinsdeglar": "porslinsdegel",
    "porslinsdeglarna": "porslinsdegel",
    "porslinsdeglarnas": "porslinsdegel",
    "porslinsdeglars": "porslinsdegel",
    "porslinsfiguren": "porslinsfigur",
    "porslinsfigurens": "porslinsfigur",
    "porslinsfigurer": "porslinsfigur",
    "porslinsfigurerna": "porslinsfigur",
    "porslinsfigurernas": "porslinsfigur",
    "porslinsfigurers": "porslinsfigur",
    "porslinsfigurs": "porslinsfigur",
    "porslinsfilterna": "porslinsfilter",
    "porslinsfilternas": "porslinsfilter",
    "porslinsfilters": "porslinsfilter",
    "porslinsfiltren": "porslinsfilter",
    "porslinsfiltrens": "porslinsfilter",
    "porslinsfiltret": "porslinsfilter",
    "porslinsfiltrets": "porslinsfilter",
    "porslinsfärgen": "porslinsfärg",
    "porslinsfärgens": "porslinsfärg",
    "porslinsfärger": "porslinsfärg",
    "porslinsfärgerna": "porslinsfärg",
    "porslinsfärgernas": "porslinsfärg",
    "porslinsfärgers": "porslinsfärg",
    "porslinsfärgs": "porslinsfärg",
    "porslinskrossningar": "porslinskrossning",
    "porslinskrossningarna": "porslinskrossning",
    "porslinskrossningarnas": "porslinskrossning",
    "porslinskrossningars": "porslinskrossning",
    "porslinskrossningen": "porslinskrossning",
    "porslinskrossningens": "porslinskrossning",
    "porslinskrossnings": "porslinskrossning",
    "porslinskul": "porslinskula",
    "porslinskulan": "porslinskula",
    "porslinskulans": "porslinskula",
    "porslinskulas": "porslinskula",
    "porslinskule": "porslinskula",
    "porslinskulor": "porslinskula",
    "porslinskulorna": "porslinskula",
    "porslinskulornas": "porslinskula",
    "porslinskulors": "porslinskula",
    "porslinskuls": "porslinskula",
    "porslinsskålar": "porslinsskål",
    "porslinsskålarna": "porslinsskål",
    "porslinsskålarnas": "porslinsskål",
    "porslinsskålars": "porslinsskål",
    "porslinsskålen": "porslinsskål",
    "porslinsskålens": "porslinsskål",
    "porslinsskåls": "porslinsskål",
    "porslinsskåpen": "porslinsskåp",
    "porslinsskåpens": "porslinsskåp",
    "porslinsskåpet": "porslinsskåp",
    "porslinsskåpets": "porslinsskåp",
    "porslinsskåps": "porslinsskåp",
    "porslinssäkringar": "porslinssäkring",
    "porslinssäkringarna": "porslinssäkring",
    "porslinssäkringarnas": "porslinssäkring",
    "porslinssäkringars": "porslinssäkring",
    "porslinssäkringen": "porslinssäkring",
    "porslinssäkringens": "porslinssäkring",
    "porslinssäkrings": "porslinssäkring",
    "porslinstillverkningar": "porslinstillverkning",
    "porslinstillverkningarna": "porslinstillverkning",
    "porslinstillverkningarnas": "porslinstillverkning",
    "porslinstillverkningars": "porslinstillverkning",
    "porslinstillverkningen": "porslinstillverkning",
    "porslinstillverkningens": "porslinstillverkning",
    "porslinstillverknings": "porslinstillverkning",
    "porsvampar": "porsvamp",
    "porsvamparna": "porsvamp",
    "porsvamparnas": "porsvamp",
    "porsvampars": "porsvamp",
    "porsvampen": "porsvamp",
    "porsvampens": "porsvamp",
    "porsvamps": "porsvamp",
    "port": "porta",
    "portabels": "portabel",
    "portabelt": "portabel",
    "portabelts": "portabel",
    "portabla": "portabel",
    "portablare": "portabel",
    "portablares": "portabel",
    "portablas": "portabel",
    "portablast": "portabel",
    "portablaste": "portabel",
    "portablastes": "portabel",
    "portablasts": "portabel",
    "portable": "portabel",
    "portables": "portabel",
    "portad": "porta",
    "portade": "porta",
    "portades": "porta",
    "portads": "porta",
    "portalbegreppen": "portalbegrepp",
    "portalbegreppens": "portalbegrepp",
    "portalbegreppet": "portalbegrepp",
    "portalbegreppets": "portalbegrepp",
    "portalbegrepps": "portalbegrepp",
    "portalen": "portal",
    "portalens": "portal",
    "portaler": "portal",
    "portalerna": "portal",
    "portalernas": "portal",
    "portalers": "portal",
    "portalfiguren": "portalfigur",
    "portalfigurens": "portalfigur",
    "portalfigurer": "portalfigur",
    "portalfigurerna": "portalfigur",
    "portalfigurernas": "portalfigur",
    "portalfigurers": "portalfigur",
    "portalfigurs": "portalfigur",
    "portalgestalten": "portalgestalt",
    "portalgestaltens": "portalgestalt",
    "portalgestalter": "portalgestalt",
    "portalgestalterna": "portalgestalt",
    "portalgestalternas": "portalgestalt",
    "portalgestalters": "portalgestalt",
    "portalgestalts": "portalgestalt",
    "portals": "portal",
    "portamenton": "portamento",
    "portamentona": "portamento",
    "portamentonas": "portamento",
    "portamentons": "portamento",
    "portamentos": "portamento",
    "portamentot": "portamento",
    "portamentots": "portamento",
    "portande": "porta",
    "portanden": "portande",
    "portandena": "portande",
    "portandenas": "portande",
    "portandens": "portande",
    "portandes": "portande",
    "portandet": "portande",
    "portandets": "portande",
    "portar": "porta",
    "portarna": "port",
    "portarnas": "port",
    "portars": "port",
    "portas": "porta",
    "portat": "porta",
    "portativa": "portativ",
    "portativare": "portativ",
    "portativares": "portativ",
    "portativas": "portativ",
    "portativast": "portativ",
    "portativaste": "portativ",
    "portativastes": "portativ",
    "portativasts": "portativ",
    "portative": "portativ",
    "portatives": "portativ",
    "portativs": "portativ",
    "portativt": "portativ",
    "portativts": "portativ",
    "portats": "porta",
    "porten": "port",
    "portens": "port",
    "portepéer": "portepé",
    "portepéerna": "portepé",
    "portepéernas": "portepé",
    "portepéers": "portepé",
    "portepén": "portepé",
    "portepéns": "portepé",
    "portepés": "portepé",
    "portern": "porter",
    "porterna": "porter",
    "porternas": "porter",
    "porterns": "porter",
    "porters": "porter",
    "portföljen": "portfölj",
    "portföljens": "portfölj",
    "portföljer": "portfölj",
    "portföljerna": "portfölj",
    "portföljernas": "portfölj",
    "portföljers": "portfölj",
    "portföljs": "portfölj",
    "portförbjud": "portförbjuda",
    "portförbjudande": "portförbjuda",
    "portförbjudanden": "portförbjudande",
    "portförbjudandena": "portförbjudande",
    "portförbjudandenas": "portförbjudande",
    "portförbjudandens": "portförbjudande",
    "portförbjudandes": "portförbjudande",
    "portförbjudandet": "portförbjudande",
    "portförbjudandets": "portförbjudande",
    "portförbjudas": "portförbjuda",
    "portförbjude": "portförbjuda",
    "portförbjuden": "portförbjuda",
    "portförbjudens": "portförbjuda",
    "portförbjuder": "portförbjuda",
    "portförbjudes": "portförbjuda",
    "portförbjudet": "portförbjuda",
    "portförbjudets": "portförbjuda",
    "portförbjudit": "portförbjuda",
    "portförbjudits": "portförbjuda",
    "portförbjudna": "portförbjuda",
    "portförbjudnas": "portförbjuda",
    "portförbjudne": "portförbjuda",
    "portförbjudnes": "portförbjuda",
    "portförbjuds": "portförbjuda",
    "portförbjöd": "portförbjuda",
    "portförbjöde": "portförbjuda",
    "portförbjödes": "portförbjuda",
    "portförbjöds": "portförbjuda",
    "portförbuden": "portförbud",
    "portförbudens": "portförbud",
    "portförbudet": "portförbud",
    "portförbudets": "portförbud",
    "portförbuds": "portförbud",
    "portföres": "portföre",
    "portföret": "portföre",
    "portförets": "portföre",
    "portgångar": "portgång",
    "portgångarna": "portgång",
    "portgångarnas": "portgång",
    "portgångars": "portgång",
    "portgången": "portgång",
    "portgångens": "portgång",
    "portgångs": "portgång",
    "portieren": "portier",
    "portierens": "portier",
    "portierer": "portier",
    "portiererna": "portier",
    "portierernas": "portier",
    "portierers": "portier",
    "portiern": "portier",
    "portierns": "portier",
    "portiers": "portier",
    "portiken": "portik",
    "portikens": "portik",
    "portiker": "portik",
    "portikerna": "portik",
    "portikernas": "portik",
    "portikers": "portik",
    "portiks": "portik",
    "portionen": "portion",
    "portionens": "portion",
    "portioner": "portion",
    "portionerad": "portionera",
    "portionerade": "portionera",
    "portionerades": "portionera",
    "portionerads": "portionera",
    "portionerande": "portionera",
    "portioneranden": "portionerande",
    "portionerandena": "portionerande",
    "portionerandenas": "portionerande",
    "portionerandens": "portionerande",
    "portionerandes": "portionerande",
    "portionerandet": "portionerande",
    "portionerandets": "portionerande",
    "portionerar": "portionera",
    "portioneras": "portionera",
    "portionerat": "portionera",
    "portionerats": "portionera",
    "portionerbara": "portionerbar",
    "portionerbarare": "portionerbar",
    "portionerbarares": "portionerbar",
    "portionerbaras": "portionerbar",
    "portionerbarast": "portionerbar",
    "portionerbaraste": "portionerbar",
    "portionerbarastes": "portionerbar",
    "portionerbarasts": "portionerbar",
    "portionerbare": "portionerbar",
    "portionerbares": "portionerbar",
    "portionerbarheten": "portionerbarhet",
    "portionerbarhetens": "portionerbarhet",
    "portionerbarhets": "portionerbarhet",
    "portionerbars": "portionerbar",
    "portionerbart": "portionerbar",
    "portionerbarts": "portionerbar",
    "portioneringar": "portionering",
    "portioneringarna": "portionering",
    "portioneringarnas": "portionering",
    "portioneringars": "portionering",
    "portioneringen": "portionering",
    "portioneringens": "portionering",
    "portionerings": "portionering",
    "portionerna": "portion",
    "portionernas": "portion",
    "portioners": "portion",
    "portions": "portion",
    "portionssnuser": "portionssnus",
    "portionssnuserna": "portionssnus",
    "portionssnusernas": "portionssnus",
    "portionssnusers": "portionssnus",
    "portionssnuset": "portionssnus",
    "portionssnusets": "portionssnus",
    "portiären": "portiär",
    "portiärens": "portiär",
    "portiärer": "portiär",
    "portiärerna": "portiär",
    "portiärernas": "portiär",
    "portiärers": "portiär",
    "portiärs": "portiär",
    "portklappar": "portklapp",
    "portklapparna": "portklapp",
    "portklapparnas": "portklapp",
    "portklappars": "portklapp",
    "portklappen": "portklapp",
    "portklappens": "portklapp",
    "portklapps": "portklapp",
    "portmonnäer": "portmonnä",
    "portmonnäerna": "portmonnä",
    "portmonnäernas": "portmonnä",
    "portmonnäers": "portmonnä",
    "portmonnän": "portmonnä",
    "portmonnäns": "portmonnä",
    "portmonnäs": "portmonnä",
    "portofria": "portofri",
    "portofriare": "portofri",
    "portofriares": "portofri",
    "portofrias": "portofri",
    "portofriast": "portofri",
    "portofriaste": "portofri",
    "portofriastes": "portofri",
    "portofriasts": "portofri",
    "portofrie": "portofri",
    "portofries": "portofri",
    "portofris": "portofri",
    "portofritt": "portofri",
    "portofritts": "portofri",
    "porton": "porto",
    "portona": "porto",
    "portonas": "porto",
    "portons": "porto",
    "portos": "porto",
    "portot": "porto",
    "portots": "porto",
    "porträtten": "porträtt",
    "porträttens": "porträtt",
    "porträtterad": "porträttera",
    "porträtterade": "porträttera",
    "porträtterades": "porträttera",
    "porträtterads": "porträttera",
    "porträtterande": "porträttera",
    "porträtteranden": "porträtterande",
    "porträtterandena": "porträtterande",
    "porträtterandenas": "porträtterande",
    "porträtterandens": "porträtterande",
    "porträtterandes": "porträtterande",
    "porträtterandet": "porträtterande",
    "porträtterandets": "porträtterande",
    "porträtterar": "porträttera",
    "porträtteras": "porträttera",
    "porträtterat": "porträttera",
    "porträtterats": "porträttera",
    "porträtterbara": "porträtterbar",
    "porträtterbarare": "porträtterbar",
    "porträtterbarares": "porträtterbar",
    "porträtterbaras": "porträtterbar",
    "porträtterbarast": "porträtterbar",
    "porträtterbaraste": "porträtterbar",
    "porträtterbarastes": "porträtterbar",
    "porträtterbarasts": "porträtterbar",
    "porträtterbare": "porträtterbar",
    "porträtterbares": "porträtterbar",
    "porträtterbarheten": "porträtterbarhet",
    "porträtterbarhetens": "porträtterbarhet",
    "porträtterbarhets": "porträtterbarhet",
    "porträtterbars": "porträtterbar",
    "porträtterbart": "porträtterbar",
    "porträtterbarts": "porträtterbar",
    "porträtteringar": "porträttering",
    "porträtteringarna": "porträttering",
    "porträtteringarnas": "porträttering",
    "porträtteringars": "porträttering",
    "porträtteringen": "porträttering",
    "porträtteringens": "porträttering",
    "porträtterings": "porträttering",
    "porträttet": "porträtt",
    "porträttets": "porträtt",
    "porträttlika": "porträttlik",
    "porträttlikare": "porträttlik",
    "porträttlikares": "porträttlik",
    "porträttlikas": "porträttlik",
    "porträttlikast": "porträttlik",
    "porträttlikaste": "porträttlik",
    "porträttlikastes": "porträttlik",
    "porträttlikasts": "porträttlik",
    "porträttlike": "porträttlik",
    "porträttlikes": "porträttlik",
    "porträttlikheten": "porträttlikhet",
    "porträttlikhetens": "porträttlikhet",
    "porträttlikhets": "porträttlikhet",
    "porträttliks": "porträttlik",
    "porträttlikt": "porträttlik",
    "porträttlikts": "porträttlik",
    "porträtts": "porträtt",
    "porträttören": "porträttör",
    "porträttörens": "porträttör",
    "porträttörer": "porträttör",
    "porträttörerna": "porträttör",
    "porträttörernas": "porträttör",
    "porträttörers": "porträttör",
    "porträttörs": "porträttör",
    "ports": "port",
    "porttelefonen": "porttelefon",
    "porttelefonens": "porttelefon",
    "porttelefoner": "porttelefon",
    "porttelefonerna": "porttelefon",
    "porttelefonernas": "porttelefon",
    "porttelefoners": "porttelefon",
    "porttelefons": "porttelefon",
    "portugisen": "portugis",
    "portugisens": "portugis",
    "portugiser": "portugis",
    "portugiserna": "portugis",
    "portugisernas": "portugis",
    "portugisers": "portugis",
    "portugisisk": "portugisiska",
    "portugisiska": "portugisisk",
    "portugisiskan": "portugisiska",
    "portugisiskans": "portugisiska",
    "portugisiskare": "portugisisk",
    "portugisiskares": "portugisisk",
    "portugisiskas": "portugisiska",
    "portugisiskast": "portugisisk",
    "portugisiskaste": "portugisisk",
    "portugisiskastes": "portugisisk",
    "portugisiskasts": "portugisisk",
    "portugisiske": "portugisiska",
    "portugisiskes": "portugisisk",
    "portugisiskor": "portugisiska",
    "portugisiskorna": "portugisiska",
    "portugisiskornas": "portugisiska",
    "portugisiskors": "portugisiska",
    "portugisisks": "portugisisk",
    "portugisiskt": "portugisisk",
    "portugisiskts": "portugisisk",
    "portuppgångar": "portuppgång",
    "portuppgångarna": "portuppgång",
    "portuppgångarnas": "portuppgång",
    "portuppgångars": "portuppgång",
    "portuppgången": "portuppgång",
    "portuppgångens": "portuppgång",
    "portuppgångs": "portuppgång",
    "portvakten": "portvakt",
    "portvaktens": "portvakt",
    "portvakter": "portvakt",
    "portvakterna": "portvakt",
    "portvakternas": "portvakt",
    "portvakters": "portvakt",
    "portvakts": "portvakt",
    "portvaktssyssl": "portvaktssyssla",
    "portvaktssysslan": "portvaktssyssla",
    "portvaktssysslans": "portvaktssyssla",
    "portvaktssysslas": "portvaktssyssla",
    "portvaktssyssle": "portvaktssyssla",
    "portvaktssysslo": "portvaktssyssla",
    "portvaktssysslor": "portvaktssyssla",
    "portvaktssysslorna": "portvaktssyssla",
    "portvaktssysslornas": "portvaktssyssla",
    "portvaktssysslors": "portvaktssyssla",
    "portviner": "portvin",
    "portvinerna": "portvin",
    "portvinernas": "portvin",
    "portviners": "portvin",
    "portvinet": "portvin",
    "portvinets": "portvin",
    "portvins": "portvin",
    "portvinstån": "portvinstå",
    "portvinståns": "portvinstå",
    "portvinstår": "portvinstå",
    "portvinstårna": "portvinstå",
    "portvinstårnas": "portvinstå",
    "portvinstårs": "portvinstå",
    "portvinstås": "portvinstå",
    "portören": "portör",
    "portörens": "portör",
    "portörer": "portör",
    "portörerna": "portör",
    "portörernas": "portör",
    "portörers": "portör",
    "portörs": "portör",
    "porösa": "porös",
    "porösare": "porös",
    "porösares": "porös",
    "porösas": "porös",
    "porösast": "porös",
    "porösaste": "porös",
    "porösastes": "porös",
    "porösasts": "porös",
    "poröse": "porös",
    "poröses": "porös",
    "poröst": "porös",
    "porösts": "porös",
    "posen": "pose",
    "posens": "pose",
    "poser": "pose",
    "poserade": "posera",
    "poserades": "posera",
    "poserande": "posera",
    "poseranden": "poserande",
    "poserandena": "poserande",
    "poserandenas": "poserande",
    "poserandens": "poserande",
    "poserandes": "poserande",
    "poserandet": "poserande",
    "poserandets": "poserande",
    "poserar": "posera",
    "poseras": "posera",
    "poserat": "posera",
    "poserats": "posera",
    "poseringar": "posering",
    "poseringarna": "posering",
    "poseringarnas": "posering",
    "poseringars": "posering",
    "poseringen": "posering",
    "poseringens": "posering",
    "poserings": "posering",
    "poserna": "pose",
    "posernas": "pose",
    "posers": "pose",
    "poses": "pose",
    "positionen": "position",
    "positionens": "position",
    "positioner": "position",
    "positionerna": "position",
    "positionernas": "position",
    "positioners": "position",
    "positions": "position",
    "positionsbestämningar": "positionsbestämning",
    "positionsbestämningarna": "positionsbestämning",
    "positionsbestämningarnas": "positionsbestämning",
    "positionsbestämningars": "positionsbestämning",
    "positionsbestämningen": "positionsbestämning",
    "positionsbestämningens": "positionsbestämning",
    "positionsbestämnings": "positionsbestämning",
    "positionsljusen": "positionsljus",
    "positionsljusens": "positionsljus",
    "positionsljuset": "positionsljus",
    "positionsljusets": "positionsljus",
    "positiva": "positiv",
    "positivare": "positiv",
    "positivares": "positiv",
    "positivas": "positiv",
    "positivast": "positiv",
    "positivaste": "positiv",
    "positivastes": "positiv",
    "positivasts": "positiv",
    "positive": "positiv",
    "positiven": "positiv",
    "positivens": "positiv",
    "positiver": "positiv",
    "positiverna": "positiv",
    "positivernas": "positiv",
    "positivers": "positiv",
    "positives": "positiv",
    "positivet": "positiv",
    "positivets": "positiv",
    "positivhalar": "positivhalare",
    "positivhalaren": "positivhalare",
    "positivhalarens": "positivhalare",
    "positivhalares": "positivhalare",
    "positivhalarna": "positivhalare",
    "positivhalarnas": "positivhalare",
    "positivismen": "positivism",
    "positivismens": "positivism",
    "positivismer": "positivism",
    "positivismerna": "positivism",
    "positivismernas": "positivism",
    "positivismers": "positivism",
    "positivisms": "positivism",
    "positivisten": "positivist",
    "positivistens": "positivist",
    "positivister": "positivist",
    "positivisterna": "positivist",
    "positivisternas": "positivist",
    "positivisters": "positivist",
    "positivistiska": "positivistisk",
    "positivistiskare": "positivistisk",
    "positivistiskares": "positivistisk",
    "positivistiskas": "positivistisk",
    "positivistiskast": "positivistisk",
    "positivistiskaste": "positivistisk",
    "positivistiskastes": "positivistisk",
    "positivistiskasts": "positivistisk",
    "positivistiske": "positivistisk",
    "positivistiskes": "positivistisk",
    "positivistisks": "positivistisk",
    "positivistiskt": "positivistisk",
    "positivistiskts": "positivistisk",
    "positivists": "positivist",
    "positivs": "positiv",
    "positivt": "positiv",
    "positivts": "positiv",
    "positivvis": "positivvisa",
    "positivvisan": "positivvisa",
    "positivvisans": "positivvisa",
    "positivvisas": "positivvisa",
    "positivvise": "positivvisa",
    "positivvisor": "positivvisa",
    "positivvisorna": "positivvisa",
    "positivvisornas": "positivvisa",
    "positivvisors": "positivvisa",
    "positronen": "positron",
    "positronens": "positron",
    "positroner": "positron",
    "positronerna": "positron",
    "positronernas": "positron",
    "positroners": "positron",
    "positrons": "positron",
    "possessionaten": "possessionat",
    "possessionatens": "possessionat",
    "possessionater": "possessionat",
    "possessionaterna": "possessionat",
    "possessionaternas": "possessionat",
    "possessionaters": "possessionat",
    "possessionats": "possessionat",
    "possessionen": "possession",
    "possessionens": "possession",
    "possessioner": "possession",
    "possessionerna": "possession",
    "possessionernas": "possession",
    "possessioners": "possession",
    "possessions": "possession",
    "possessiva": "possessiv",
    "possessivare": "possessiv",
    "possessivares": "possessiv",
    "possessivas": "possessiv",
    "possessivast": "possessiv",
    "possessivaste": "possessiv",
    "possessivastes": "possessiv",
    "possessivasts": "possessiv",
    "possessive": "possessiv",
    "possessives": "possessiv",
    "possessivs": "possessiv",
    "possessivt": "possessiv",
    "possessivts": "possessiv",
    "postad": "posta",
    "postade": "posta",
    "postades": "posta",
    "postadressen": "postadress",
    "postadressens": "postadress",
    "postadresser": "postadress",
    "postadresserna": "postadress",
    "postadressernas": "postadress",
    "postadressers": "postadress",
    "postads": "posta",
    "postala": "postal",
    "postalare": "postal",
    "postalares": "postal",
    "postalas": "postal",
    "postalast": "postal",
    "postalaste": "postal",
    "postalastes": "postal",
    "postalasts": "postal",
    "postale": "postal",
    "postales": "postal",
    "postals": "postal",
    "postalt": "postal",
    "postalts": "postal",
    "postamenten": "postament",
    "postamentens": "postament",
    "postamentet": "postament",
    "postamentets": "postament",
    "postaments": "postament",
    "postande": "posta",
    "postanden": "postande",
    "postandena": "postande",
    "postandenas": "postande",
    "postandens": "postande",
    "postandes": "postande",
    "postandet": "postande",
    "postandets": "postande",
    "postanstalten": "postanstalt",
    "postanstaltens": "postanstalt",
    "postanstalter": "postanstalt",
    "postanstalterna": "postanstalt",
    "postanstalternas": "postanstalt",
    "postanstalters": "postanstalt",
    "postanstalts": "postanstalt",
    "postanvisningar": "postanvisning",
    "postanvisningarna": "postanvisning",
    "postanvisningarnas": "postanvisning",
    "postanvisningars": "postanvisning",
    "postanvisningen": "postanvisning",
    "postanvisningens": "postanvisning",
    "postanvisnings": "postanvisning",
    "postar": "posta",
    "postas": "posta",
    "postat": "posta",
    "postats": "posta",
    "postboxar": "postbox",
    "postboxarna": "postbox",
    "postboxarnas": "postbox",
    "postboxars": "postbox",
    "postboxen": "postbox",
    "postboxens": "postbox",
    "postbåtar": "postbåt",
    "postbåtarna": "postbåt",
    "postbåtarnas": "postbåt",
    "postbåtars": "postbåt",
    "postbåten": "postbåt",
    "postbåtens": "postbåt",
    "postbåts": "postbåt",
    "postdaterad": "postdatera",
    "postdaterade": "postdatera",
    "postdaterades": "postdatera",
    "postdaterads": "postdatera",
    "postdaterande": "postdatera",
    "postdateranden": "postdaterande",
    "postdaterandena": "postdaterande",
    "postdaterandenas": "postdaterande",
    "postdaterandens": "postdaterande",
    "postdaterandes": "postdaterande",
    "postdaterandet": "postdaterande",
    "postdaterandets": "postdaterande",
    "postdaterar": "postdatera",
    "postdateras": "postdatera",
    "postdaterat": "postdatera",
    "postdaterats": "postdatera",
    "postdaterbara": "postdaterbar",
    "postdaterbarare": "postdaterbar",
    "postdaterbarares": "postdaterbar",
    "postdaterbaras": "postdaterbar",
    "postdaterbarast": "postdaterbar",
    "postdaterbaraste": "postdaterbar",
    "postdaterbarastes": "postdaterbar",
    "postdaterbarasts": "postdaterbar",
    "postdaterbare": "postdaterbar",
    "postdaterbares": "postdaterbar",
    "postdaterbarheten": "postdaterbarhet",
    "postdaterbarhetens": "postdaterbarhet",
    "postdaterbarhets": "postdaterbarhet",
    "postdaterbars": "postdaterbar",
    "postdaterbart": "postdaterbar",
    "postdaterbarts": "postdaterbar",
    "postdateringar": "postdatering",
    "postdateringarna": "postdatering",
    "postdateringarnas": "postdatering",
    "postdateringars": "postdatering",
    "postdateringen": "postdatering",
    "postdateringens": "postdatering",
    "postdaterings": "postdatering",
    "posten": "post",
    "postens": "post",
    "poster": "post",
    "posterad": "postera",
    "posterade": "postera",
    "posterades": "postera",
    "posterads": "postera",
    "posterande": "postera",
    "posteranden": "posterande",
    "posterandena": "posterande",
    "posterandenas": "posterande",
    "posterandens": "posterande",
    "posterandes": "posterande",
    "posterandet": "posterande",
    "posterandets": "posterande",
    "posterar": "postera",
    "posteras": "postera",
    "posterat": "postera",
    "posterats": "postera",
    "posterbara": "posterbar",
    "posterbarare": "posterbar",
    "posterbarares": "posterbar",
    "posterbaras": "posterbar",
    "posterbarast": "posterbar",
    "posterbaraste": "posterbar",
    "posterbarastes": "posterbar",
    "posterbarasts": "posterbar",
    "posterbare": "posterbar",
    "posterbares": "posterbar",
    "posterbarheten": "posterbarhet",
    "posterbarhetens": "posterbarhet",
    "posterbarhets": "posterbarhet",
    "posterbars": "posterbar",
    "posterbart": "posterbar",
    "posterbarts": "posterbar",
    "posteringar": "postering",
    "posteringarna": "postering",
    "posteringarnas": "postering",
    "posteringars": "postering",
    "posteringen": "postering",
    "posteringens": "postering",
    "posterings": "postering",
    "postern": "poster",
    "posterna": "post",
    "posternas": "post",
    "posterns": "poster",
    "posters": "poster",
    "postersarna": "poster",
    "postersarnas": "poster",
    "postersen": "poster",
    "postersens": "poster",
    "postexpeditionen": "postexpedition",
    "postexpeditionens": "postexpedition",
    "postexpeditioner": "postexpedition",
    "postexpeditionerna": "postexpedition",
    "postexpeditionernas": "postexpedition",
    "postexpeditioners": "postexpedition",
    "postexpeditions": "postexpedition",
    "postfacken": "postfack",
    "postfackens": "postfack",
    "postfacket": "postfack",
    "postfackets": "postfack",
    "postfacks": "postfack",
    "postförskotten": "postförskott",
    "postförskottens": "postförskott",
    "postförskottet": "postförskott",
    "postförskottets": "postförskott",
    "postförskotts": "postförskott",
    "postförsändelsen": "postförsändelse",
    "postförsändelsens": "postförsändelse",
    "postförsändelser": "postförsändelse",
    "postförsändelserna": "postförsändelse",
    "postförsändelsernas": "postförsändelse",
    "postförsändelsers": "postförsändelse",
    "postförsändelses": "postförsändelse",
    "postgirokonton": "postgirokonto",
    "postgirokontona": "postgirokonto",
    "postgirokontonas": "postgirokonto",
    "postgirokontons": "postgirokonto",
    "postgirokontos": "postgirokonto",
    "postgirokontot": "postgirokonto",
    "postgirokontots": "postgirokonto",
    "postgiron": "postgiro",
    "postgirona": "postgiro",
    "postgironas": "postgiro",
    "postgirons": "postgiro",
    "postgiros": "postgiro",
    "postgirot": "postgiro",
    "postgirots": "postgiro",
    "postglaciala": "postglacial",
    "postglacialare": "postglacial",
    "postglacialares": "postglacial",
    "postglacialas": "postglacial",
    "postglacialast": "postglacial",
    "postglacialaste": "postglacial",
    "postglacialastes": "postglacial",
    "postglacialasts": "postglacial",
    "postglaciale": "postglacial",
    "postglaciales": "postglacial",
    "postglacials": "postglacial",
    "postglacialt": "postglacial",
    "postglacialts": "postglacial",
    "postgymnasiala": "postgymnasial",
    "postgymnasialare": "postgymnasial",
    "postgymnasialares": "postgymnasial",
    "postgymnasialas": "postgymnasial",
    "postgymnasialast": "postgymnasial",
    "postgymnasialaste": "postgymnasial",
    "postgymnasialastes": "postgymnasial",
    "postgymnasialasts": "postgymnasial",
    "postgymnasiale": "postgymnasial",
    "postgymnasiales": "postgymnasial",
    "postgymnasials": "postgymnasial",
    "postgymnasialt": "postgymnasial",
    "postgymnasialts": "postgymnasial",
    "postgången": "postgång",
    "postgångens": "postgång",
    "postgångs": "postgång",
    "posthornen": "posthorn",
    "posthornens": "posthorn",
    "posthornet": "posthorn",
    "posthornets": "posthorn",
    "posthorns": "posthorn",
    "postiljonen": "postiljon",
    "postiljonens": "postiljon",
    "postiljoner": "postiljon",
    "postiljonerna": "postiljon",
    "postiljonernas": "postiljon",
    "postiljoners": "postiljon",
    "postiljons": "postiljon",
    "postill": "postilla",
    "postillan": "postilla",
    "postillans": "postilla",
    "postillas": "postilla",
    "postille": "postilla",
    "postillor": "postilla",
    "postillorna": "postilla",
    "postillornas": "postilla",
    "postillors": "postilla",
    "postills": "postilla",
    "postindustriella": "postindustriell",
    "postindustriellare": "postindustriell",
    "postindustriellares": "postindustriell",
    "postindustriellas": "postindustriell",
    "postindustriellast": "postindustriell",
    "postindustriellaste": "postindustriell",
    "postindustriellastes": "postindustriell",
    "postindustriellasts": "postindustriell",
    "postindustrielle": "postindustriell",
    "postindustrielles": "postindustriell",
    "postindustriells": "postindustriell",
    "postindustriellt": "postindustriell",
    "postindustriellts": "postindustriell",
    "postischen": "postisch",
    "postischens": "postisch",
    "postischer": "postisch",
    "postischerna": "postisch",
    "postischernas": "postisch",
    "postischers": "postisch",
    "postischs": "postisch",
    "postkoden": "postkod",
    "postkodens": "postkod",
    "postkoder": "postkod",
    "postkoderna": "postkod",
    "postkodernas": "postkod",
    "postkoders": "postkod",
    "postkods": "postkod",
    "postkontoren": "postkontor",
    "postkontorens": "postkontor",
    "postkontoret": "postkontor",
    "postkontorets": "postkontor",
    "postkontors": "postkontor",
    "postkorten": "postkort",
    "postkortens": "postkort",
    "postkortet": "postkort",
    "postkortets": "postkort",
    "postkorts": "postkort",
    "postkupéer": "postkupé",
    "postkupéerna": "postkupé",
    "postkupéernas": "postkupé",
    "postkupéers": "postkupé",
    "postkupén": "postkupé",
    "postkupéns": "postkupé",
    "postkupés": "postkupé",
    "postludie": "postludium",
    "postludier": "postludium",
    "postludierna": "postludium",
    "postludiernas": "postludium",
    "postludiers": "postludium",
    "postludiet": "postludium",
    "postludiets": "postludium",
    "postludiums": "postludium",
    "postlåd": "postlåda",
    "postlådan": "postlåda",
    "postlådans": "postlåda",
    "postlådas": "postlåda",
    "postlåde": "postlåda",
    "postlådor": "postlåda",
    "postlådorna": "postlåda",
    "postlådornas": "postlåda",
    "postlådors": "postlåda",
    "postlåds": "postlåda",
    "postmoderna": "postmodern",
    "postmodernas": "postmodern",
    "postmoderne": "postmodern",
    "postmodernes": "postmodern",
    "postmodernismen": "postmodernism",
    "postmodernismens": "postmodernism",
    "postmodernismer": "postmodernism",
    "postmodernismerna": "postmodernism",
    "postmodernismernas": "postmodernism",
    "postmodernismers": "postmodernism",
    "postmodernisms": "postmodernism",
    "postmodernisten": "postmodernist",
    "postmodernistens": "postmodernist",
    "postmodernister": "postmodernist",
    "postmodernisterna": "postmodernist",
    "postmodernisternas": "postmodernist",
    "postmodernisters": "postmodernist",
    "postmodernistiska": "postmodernistisk",
    "postmodernistiskas": "postmodernistisk",
    "postmodernistiske": "postmodernistisk",
    "postmodernistiskes": "postmodernistisk",
    "postmodernistisks": "postmodernistisk",
    "postmodernistiskt": "postmodernistisk",
    "postmodernistiskts": "postmodernistisk",
    "postmodernists": "postmodernist",
    "postmoderns": "postmodern",
    "postmodernt": "postmodern",
    "postmodernts": "postmodern",
    "postmästar": "postmästare",
    "postmästaren": "postmästare",
    "postmästarens": "postmästare",
    "postmästares": "postmästare",
    "postmästarna": "postmästare",
    "postmästarnas": "postmästare",
    "postnatala": "postnatal",
    "postnatalare": "postnatal",
    "postnatalares": "postnatal",
    "postnatalas": "postnatal",
    "postnatalast": "postnatal",
    "postnatalaste": "postnatal",
    "postnatalastes": "postnatal",
    "postnatalasts": "postnatal",
    "postnatale": "postnatal",
    "postnatales": "postnatal",
    "postnatals": "postnatal",
    "postnatalt": "postnatal",
    "postnatalts": "postnatal",
    "postnummerna": "postnummer",
    "postnummernas": "postnummer",
    "postnummers": "postnummer",
    "postnumren": "postnummer",
    "postnumrens": "postnummer",
    "postnumret": "postnummer",
    "postnumrets": "postnummer",
    "postorderföretagen": "postorderföretag",
    "postorderföretagens": "postorderföretag",
    "postorderföretaget": "postorderföretag",
    "postorderföretagets": "postorderföretag",
    "postorderföretags": "postorderföretag",
    "postordern": "postorder",
    "postorderns": "postorder",
    "postorders": "postorder",
    "postponerad": "postponera",
    "postponerade": "postponera",
    "postponerades": "postponera",
    "postponerads": "postponera",
    "postponerande": "postponera",
    "postponeranden": "postponerande",
    "postponerandena": "postponerande",
    "postponerandenas": "postponerande",
    "postponerandens": "postponerande",
    "postponerandes": "postponerande",
    "postponerandet": "postponerande",
    "postponerandets": "postponerande",
    "postponerar": "postponera",
    "postponeras": "postponera",
    "postponerat": "postponera",
    "postponerats": "postponera",
    "postponerbara": "postponerbar",
    "postponerbarare": "postponerbar",
    "postponerbarares": "postponerbar",
    "postponerbaras": "postponerbar",
    "postponerbarast": "postponerbar",
    "postponerbaraste": "postponerbar",
    "postponerbarastes": "postponerbar",
    "postponerbarasts": "postponerbar",
    "postponerbare": "postponerbar",
    "postponerbares": "postponerbar",
    "postponerbarheten": "postponerbarhet",
    "postponerbarhetens": "postponerbarhet",
    "postponerbarhets": "postponerbarhet",
    "postponerbars": "postponerbar",
    "postponerbart": "postponerbar",
    "postponerbarts": "postponerbar",
    "postponeringar": "postponering",
    "postponeringarna": "postponering",
    "postponeringarnas": "postponering",
    "postponeringars": "postponering",
    "postponeringen": "postponering",
    "postponeringens": "postponering",
    "postponerings": "postponering",
    "postpositionen": "postposition",
    "postpositionens": "postposition",
    "postpositioner": "postposition",
    "postpositionerna": "postposition",
    "postpositionernas": "postposition",
    "postpositioners": "postposition",
    "postpositions": "postposition",
    "postrar": "poster",
    "postrarna": "poster",
    "postrarnas": "poster",
    "postrars": "poster",
    "postremissväxeln": "postremissväxel",
    "postremissväxelns": "postremissväxel",
    "postremissväxels": "postremissväxel",
    "postremissväxlar": "postremissväxel",
    "postremissväxlarna": "postremissväxel",
    "postremissväxlarnas": "postremissväxel",
    "postremissväxlars": "postremissväxel",
    "postrånen": "postrån",
    "postrånens": "postrån",
    "postrånet": "postrån",
    "postrånets": "postrån",
    "postråns": "postrån",
    "poströst": "poströsta",
    "poströstad": "poströsta",
    "poströstade": "poströsta",
    "poströstades": "poströsta",
    "poströstads": "poströsta",
    "poströstande": "poströsta",
    "poströstanden": "poströstande",
    "poströstandena": "poströstande",
    "poströstandenas": "poströstande",
    "poströstandens": "poströstande",
    "poströstandes": "poströstande",
    "poströstandet": "poströstande",
    "poströstandets": "poströstande",
    "poströstar": "poströsta",
    "poströstas": "poströsta",
    "poströstat": "poströsta",
    "poströstats": "poströsta",
    "poströsten": "poströst",
    "poströstens": "poströst",
    "poströster": "poströst",
    "poströsterna": "poströst",
    "poströsternas": "poströst",
    "poströsters": "poströst",
    "poströsts": "poströst",
    "posts": "post",
    "postseminarie": "postseminarium",
    "postseminarier": "postseminarium",
    "postseminarierna": "postseminarium",
    "postseminariernas": "postseminarium",
    "postseminariers": "postseminarium",
    "postseminariet": "postseminarium",
    "postseminariets": "postseminarium",
    "postseminariums": "postseminarium",
    "postskripta": "postskriptum",
    "postskriptana": "postskriptum",
    "postskriptanas": "postskriptum",
    "postskriptas": "postskriptum",
    "postskriptumen": "postskriptum",
    "postskriptumens": "postskriptum",
    "postskriptumet": "postskriptum",
    "postskriptumets": "postskriptum",
    "postskriptums": "postskriptum",
    "poststationen": "poststation",
    "poststationens": "poststation",
    "poststationer": "poststation",
    "poststationerna": "poststation",
    "poststationernas": "poststation",
    "poststationers": "poststation",
    "poststations": "poststation",
    "poststämpeln": "poststämpel",
    "poststämpelns": "poststämpel",
    "poststämpels": "poststämpel",
    "poststämplad": "poststämpla",
    "poststämplade": "poststämpla",
    "poststämplades": "poststämpla",
    "poststämplads": "poststämpla",
    "poststämplande": "poststämpla",
    "poststämplanden": "poststämplande",
    "poststämplandena": "poststämplande",
    "poststämplandenas": "poststämplande",
    "poststämplandens": "poststämplande",
    "poststämplandes": "poststämplande",
    "poststämplandet": "poststämplande",
    "poststämplandets": "poststämplande",
    "poststämplar": "poststämpla",
    "poststämplarna": "poststämpel",
    "poststämplarnas": "poststämpel",
    "poststämplars": "poststämpel",
    "poststämplas": "poststämpla",
    "poststämplat": "poststämpla",
    "poststämplats": "poststämpla",
    "posttjänstemannen": "posttjänsteman",
    "posttjänstemannens": "posttjänsteman",
    "posttjänstemans": "posttjänsteman",
    "posttjänstemän": "posttjänsteman",
    "posttjänstemännen": "posttjänsteman",
    "posttjänstemännens": "posttjänsteman",
    "posttjänstemäns": "posttjänsteman",
    "posttraumatiska": "posttraumatisk",
    "posttraumatiskas": "posttraumatisk",
    "posttraumatiske": "posttraumatisk",
    "posttraumatiskes": "posttraumatisk",
    "posttraumatisks": "posttraumatisk",
    "posttraumatiskt": "posttraumatisk",
    "posttraumatiskts": "posttraumatisk",
    "postulaten": "postulat",
    "postulatens": "postulat",
    "postulatet": "postulat",
    "postulatets": "postulat",
    "postulats": "postulat",
    "postulerad": "postulera",
    "postulerade": "postulera",
    "postulerades": "postulera",
    "postulerads": "postulera",
    "postulerande": "postulera",
    "postuleranden": "postulerande",
    "postulerandena": "postulerande",
    "postulerandenas": "postulerande",
    "postulerandens": "postulerande",
    "postulerandes": "postulerande",
    "postulerandet": "postulerande",
    "postulerandets": "postulerande",
    "postulerar": "postulera",
    "postuleras": "postulera",
    "postulerat": "postulera",
    "postulerats": "postulera",
    "postulerbara": "postulerbar",
    "postulerbarare": "postulerbar",
    "postulerbarares": "postulerbar",
    "postulerbaras": "postulerbar",
    "postulerbarast": "postulerbar",
    "postulerbaraste": "postulerbar",
    "postulerbarastes": "postulerbar",
    "postulerbarasts": "postulerbar",
    "postulerbare": "postulerbar",
    "postulerbares": "postulerbar",
    "postulerbarheten": "postulerbarhet",
    "postulerbarhetens": "postulerbarhet",
    "postulerbarhets": "postulerbarhet",
    "postulerbars": "postulerbar",
    "postulerbart": "postulerbar",
    "postulerbarts": "postulerbar",
    "postuleringar": "postulering",
    "postuleringarna": "postulering",
    "postuleringarnas": "postulering",
    "postuleringars": "postulering",
    "postuleringen": "postulering",
    "postuleringens": "postulering",
    "postulerings": "postulering",
    "postuma": "postum",
    "postumare": "postum",
    "postumares": "postum",
    "postumas": "postum",
    "postumast": "postum",
    "postumaste": "postum",
    "postumastes": "postum",
    "postumasts": "postum",
    "postume": "postum",
    "postumes": "postum",
    "postums": "postum",
    "postumt": "postum",
    "postumts": "postum",
    "postutdelningar": "postutdelning",
    "postutdelningarna": "postutdelning",
    "postutdelningarnas": "postutdelning",
    "postutdelningars": "postutdelning",
    "postutdelningen": "postutdelning",
    "postutdelningens": "postutdelning",
    "postutdelnings": "postutdelning",
    "postverken": "postverk",
    "postverkens": "postverk",
    "postverket": "postverk",
    "postverkets": "postverk",
    "postverks": "postverk",
    "postväxeln": "postväxel",
    "postväxelns": "postväxel",
    "postväxels": "postväxel",
    "postväxlar": "postväxel",
    "postväxlarna": "postväxel",
    "postväxlarnas": "postväxel",
    "postväxlars": "postväxel",
    "posören": "posör",
    "posörens": "posör",
    "posörer": "posör",
    "posörerna": "posör",
    "posörernas": "posör",
    "posörers": "posör",
    "posörs": "posör",
    "potagen": "potage",
    "potagens": "potage",
    "potager": "potage",
    "potagerna": "potage",
    "potagernas": "potage",
    "potagers": "potage",
    "potages": "potage",
    "potatisar": "potatis",
    "potatisarna": "potatis",
    "potatisarnas": "potatis",
    "potatisars": "potatis",
    "potatisbrännvinet": "potatisbrännvin",
    "potatisbrännvinets": "potatisbrännvin",
    "potatisbrännvins": "potatisbrännvin",
    "potatischipsen": "potatischips",
    "potatischipsens": "potatischips",
    "potatischipset": "potatischips",
    "potatischipsets": "potatischips",
    "potatisen": "potatis",
    "potatisens": "potatis",
    "potatiskanonen": "potatiskanon",
    "potatiskanonens": "potatiskanon",
    "potatiskanoner": "potatiskanon",
    "potatiskanonerna": "potatiskanon",
    "potatiskanonernas": "potatiskanon",
    "potatiskanoners": "potatiskanon",
    "potatiskanons": "potatiskanon",
    "potatisklyft": "potatisklyfta",
    "potatisklyftan": "potatisklyfta",
    "potatisklyftans": "potatisklyfta",
    "potatisklyftas": "potatisklyfta",
    "potatisklyfte": "potatisklyfta",
    "potatisklyftor": "potatisklyfta",
    "potatisklyftorna": "potatisklyfta",
    "potatisklyftornas": "potatisklyfta",
    "potatisklyftors": "potatisklyfta",
    "potatisklyfts": "potatisklyfta",
    "potatismjölet": "potatismjöl",
    "potatismjölets": "potatismjöl",
    "potatismjöls": "potatismjöl",
    "potatismoset": "potatismos",
    "potatismosets": "potatismos",
    "potatisnäs": "potatisnäsa",
    "potatisnäsan": "potatisnäsa",
    "potatisnäsans": "potatisnäsa",
    "potatisnäsas": "potatisnäsa",
    "potatisnäse": "potatisnäsa",
    "potatisnäsor": "potatisnäsa",
    "potatisnäsorna": "potatisnäsa",
    "potatisnäsornas": "potatisnäsa",
    "potatisnäsors": "potatisnäsa",
    "potatispuréer": "potatispuré",
    "potatispuréerna": "potatispuré",
    "potatispuréernas": "potatispuré",
    "potatispuréers": "potatispuré",
    "potatispurén": "potatispuré",
    "potatispuréns": "potatispuré",
    "potatispurés": "potatispuré",
    "potatissalladen": "potatissallad",
    "potatissalladens": "potatissallad",
    "potatissallader": "potatissallad",
    "potatissalladerna": "potatissallad",
    "potatissalladernas": "potatissallad",
    "potatissalladers": "potatissallad",
    "potatissallads": "potatissallad",
    "potatisväxten": "potatisväxt",
    "potatisväxtens": "potatisväxt",
    "potatisväxter": "potatisväxt",
    "potatisväxterna": "potatisväxt",
    "potatisväxternas": "potatisväxt",
    "potatisväxters": "potatisväxt",
    "potatisväxts": "potatisväxt",
    "potemkinkulissen": "potemkinkuliss",
    "potemkinkulissens": "potemkinkuliss",
    "potemkinkulisser": "potemkinkuliss",
    "potemkinkulisserna": "potemkinkuliss",
    "potemkinkulissernas": "potemkinkuliss",
    "potemkinkulissers": "potemkinkuliss",
    "potensen": "potens",
    "potensens": "potens",
    "potenser": "potens",
    "potenserna": "potens",
    "potensernas": "potens",
    "potensers": "potens",
    "potenta": "potent",
    "potentare": "potent",
    "potentares": "potent",
    "potentas": "potent",
    "potentast": "potent",
    "potentaste": "potent",
    "potentastes": "potent",
    "potentasts": "potent",
    "potentaten": "potentat",
    "potentatens": "potentat",
    "potentater": "potentat",
    "potentaterna": "potentat",
    "potentaternas": "potentat",
    "potentaters": "potentat",
    "potentats": "potentat",
    "potente": "potent",
    "potentes": "potent",
    "potentialen": "potential",
    "potentialens": "potential",
    "potentialer": "potential",
    "potentialerna": "potential",
    "potentialernas": "potential",
    "potentialers": "potential",
    "potentials": "potential",
    "potentialytan": "potentialyta",
    "potentialytans": "potentialyta",
    "potentialytas": "potentialyta",
    "potentialyte": "potentialyta",
    "potentialytor": "potentialyta",
    "potentialytorna": "potentialyta",
    "potentialytornas": "potentialyta",
    "potentialytors": "potentialyta",
    "potentiella": "potentiell",
    "potentiellare": "potentiell",
    "potentiellares": "potentiell",
    "potentiellas": "potentiell",
    "potentiellast": "potentiell",
    "potentiellaste": "potentiell",
    "potentiellastes": "potentiell",
    "potentiellasts": "potentiell",
    "potentielle": "potentiell",
    "potentielles": "potentiell",
    "potentiells": "potentiell",
    "potentiellt": "potentiell",
    "potentiellts": "potentiell",
    "potentiometern": "potentiometer",
    "potentiometerns": "potentiometer",
    "potentiometers": "potentiometer",
    "potentiometrar": "potentiometer",
    "potentiometrarna": "potentiometer",
    "potentiometrarnas": "potentiometer",
    "potentiometrars": "potentiometer",
    "potents": "potent",
    "potkesen": "potkes",
    "potkesens": "potkes",
    "potkäsen": "potkäs",
    "potkäsens": "potkäs",
    "potpurrier": "potpurri",
    "potpurrierna": "potpurri",
    "potpurriernas": "potpurri",
    "potpurriers": "potpurri",
    "potpurriet": "potpurri",
    "potpurriets": "potpurri",
    "potpurris": "potpurri",
    "potpurrit": "potpurri",
    "potpurrits": "potpurri",
    "pott": "potta",
    "pottan": "potta",
    "pottans": "potta",
    "pottas": "potta",
    "pottask": "pottaska",
    "pottaskan": "pottaska",
    "pottaskans": "pottaska",
    "pottaskas": "pottaska",
    "potte": "potta",
    "potten": "pott",
    "pottens": "pott",
    "potter": "pott",
    "potterna": "pott",
    "potternas": "pott",
    "potters": "pott",
    "pottor": "potta",
    "pottorna": "potta",
    "pottornas": "potta",
    "pottors": "potta",
    "potts": "potta",
    "pottskräcken": "pottskräck",
    "pottskräckens": "pottskräck",
    "pottskräcks": "pottskräck",
    "poularden": "poulard",
    "poulardens": "poulard",
    "poularder": "poulard",
    "poularderna": "poulard",
    "poulardernas": "poulard",
    "poularders": "poulard",
    "poulards": "poulard",
    "poängen": "poäng",
    "poängens": "poäng",
    "poänger": "poäng",
    "poängerna": "poäng",
    "poängernas": "poäng",
    "poängers": "poäng",
    "poänget": "poäng",
    "poängets": "poäng",
    "poänglösa": "poänglös",
    "poänglösare": "poänglös",
    "poänglösares": "poänglös",
    "poänglösas": "poänglös",
    "poänglösast": "poänglös",
    "poänglösaste": "poänglös",
    "poänglösastes": "poänglös",
    "poänglösasts": "poänglös",
    "poänglöse": "poänglös",
    "poänglöses": "poänglös",
    "poänglösheten": "poänglöshet",
    "poänglöshetens": "poänglöshet",
    "poänglöshets": "poänglöshet",
    "poänglöst": "poänglös",
    "poänglösts": "poänglös",
    "poängmässiga": "poängmässig",
    "poängmässigare": "poängmässig",
    "poängmässigares": "poängmässig",
    "poängmässigas": "poängmässig",
    "poängmässigast": "poängmässig",
    "poängmässigaste": "poängmässig",
    "poängmässigastes": "poängmässig",
    "poängmässigasts": "poängmässig",
    "poängmässige": "poängmässig",
    "poängmässiges": "poängmässig",
    "poängmässigs": "poängmässig",
    "poängmässigt": "poängmässig",
    "poängmässigts": "poängmässig",
    "poängs": "poäng",
    "poängsegern": "poängseger",
    "poängsegerns": "poängseger",
    "poängsegers": "poängseger",
    "poängsegrar": "poängseger",
    "poängsegrarna": "poängseger",
    "poängsegrarnas": "poängseger",
    "poängsegrars": "poängseger",
    "poängställningar": "poängställning",
    "poängställningarna": "poängställning",
    "poängställningarnas": "poängställning",
    "poängställningars": "poängställning",
    "poängställningen": "poängställning",
    "poängställningens": "poängställning",
    "poängställnings": "poängställning",
    "poängterad": "poängtera",
    "poängterade": "poängtera",
    "poängterades": "poängtera",
    "poängterads": "poängtera",
    "poängterande": "poängtera",
    "poängteranden": "poängterande",
    "poängterandena": "poängterande",
    "poängterandenas": "poängterande",
    "poängterandens": "poängterande",
    "poängterandes": "poängterande",
    "poängterandet": "poängterande",
    "poängterandets": "poängterande",
    "poängterar": "poängtera",
    "poängteras": "poängtera",
    "poängterat": "poängtera",
    "poängterats": "poängtera",
    "poängterbara": "poängterbar",
    "poängterbarare": "poängterbar",
    "poängterbarares": "poängterbar",
    "poängterbaras": "poängterbar",
    "poängterbarast": "poängterbar",
    "poängterbaraste": "poängterbar",
    "poängterbarastes": "poängterbar",
    "poängterbarasts": "poängterbar",
    "poängterbare": "poängterbar",
    "poängterbares": "poängterbar",
    "poängterbarheten": "poängterbarhet",
    "poängterbarhetens": "poängterbarhet",
    "poängterbarhets": "poängterbarhet",
    "poängterbars": "poängterbar",
    "poängterbart": "poängterbar",
    "poängterbarts": "poängterbar",
    "poängteringar": "poängtering",
    "poängteringarna": "poängtering",
    "poängteringarnas": "poängtering",
    "poängteringars": "poängtering",
    "poängteringen": "poängtering",
    "poängteringens": "poängtering",
    "poängterings": "poängtering",
    "poängtipsen": "poängtips",
    "poängtipsens": "poängtips",
    "poängtipset": "poängtips",
    "poängtipsets": "poängtips",
    "prack": "pracka",
    "prackan": "pracka",
    "prackans": "pracka",
    "prackas": "pracka",
    "pracke": "pracka",
    "prackor": "pracka",
    "prackorna": "pracka",
    "prackornas": "pracka",
    "prackors": "pracka",
    "pracks": "pracka",
    "pragmatiken": "pragmatik",
    "pragmatikens": "pragmatik",
    "pragmatikern": "pragmatiker",
    "pragmatikerna": "pragmatiker",
    "pragmatikernas": "pragmatiker",
    "pragmatikerns": "pragmatiker",
    "pragmatikers": "pragmatiker",
    "pragmatiks": "pragmatik",
    "pragmatiska": "pragmatisk",
    "pragmatiskare": "pragmatisk",
    "pragmatiskares": "pragmatisk",
    "pragmatiskas": "pragmatisk",
    "pragmatiskast": "pragmatisk",
    "pragmatiskaste": "pragmatisk",
    "pragmatiskastes": "pragmatisk",
    "pragmatiskasts": "pragmatisk",
    "pragmatiske": "pragmatisk",
    "pragmatiskes": "pragmatisk",
    "pragmatisks": "pragmatisk",
    "pragmatiskt": "pragmatisk",
    "pragmatiskts": "pragmatisk",
    "pragmatismen": "pragmatism",
    "pragmatismens": "pragmatism",
    "pragmatismer": "pragmatism",
    "pragmatismerna": "pragmatism",
    "pragmatismernas": "pragmatism",
    "pragmatismers": "pragmatism",
    "pragmatisms": "pragmatism",
    "prakriten": "prakrit",
    "prakritens": "prakrit",
    "prakriter": "prakrit",
    "prakriterna": "prakrit",
    "prakriternas": "prakrit",
    "prakriters": "prakrit",
    "prakritet": "prakrit",
    "prakritets": "prakrit",
    "prakrits": "prakrit",
    "praktbagg": "praktbagge",
    "praktbaggar": "praktbagge",
    "praktbaggarna": "praktbagge",
    "praktbaggarnas": "praktbagge",
    "praktbaggars": "praktbagge",
    "praktbaggen": "praktbagge",
    "praktbaggens": "praktbagge",
    "praktbagges": "praktbagge",
    "praktbaggs": "praktbagge",
    "praktbägar": "praktbägare",
    "praktbägaren": "praktbägare",
    "praktbägarens": "praktbägare",
    "praktbägares": "praktbägare",
    "praktbägarna": "praktbägare",
    "praktbägarnas": "praktbägare",
    "prakten": "prakt",
    "praktens": "prakt",
    "praktexempels": "praktexempel",
    "praktexemplaren": "praktexemplar",
    "praktexemplarens": "praktexemplar",
    "praktexemplaret": "praktexemplar",
    "praktexemplarets": "praktexemplar",
    "praktexemplars": "praktexemplar",
    "praktexemplen": "praktexempel",
    "praktexemplens": "praktexempel",
    "praktexemplet": "praktexempel",
    "praktexemplets": "praktexempel",
    "praktfulla": "praktfull",
    "praktfullare": "praktfull",
    "praktfullares": "praktfull",
    "praktfullas": "praktfull",
    "praktfullast": "praktfull",
    "praktfullaste": "praktfull",
    "praktfullastes": "praktfull",
    "praktfullasts": "praktfull",
    "praktfulle": "praktfull",
    "praktfulles": "praktfull",
    "praktfullheten": "praktfullhet",
    "praktfullhetens": "praktfullhet",
    "praktfullheter": "praktfullhet",
    "praktfullheterna": "praktfullhet",
    "praktfullheternas": "praktfullhet",
    "praktfullheters": "praktfullhet",
    "praktfullhets": "praktfullhet",
    "praktfulls": "praktfull",
    "praktfullt": "praktfull",
    "praktfullts": "praktfull",
    "praktikabels": "praktikabel",
    "praktikabelt": "praktikabel",
    "praktikabelts": "praktikabel",
    "praktikabla": "praktikabel",
    "praktikablare": "praktikabel",
    "praktikablares": "praktikabel",
    "praktikablas": "praktikabel",
    "praktikablast": "praktikabel",
    "praktikablaste": "praktikabel",
    "praktikablastes": "praktikabel",
    "praktikablasts": "praktikabel",
    "praktikable": "praktikabel",
    "praktikables": "praktikabel",
    "praktikanten": "praktikant",
    "praktikantens": "praktikant",
    "praktikanter": "praktikant",
    "praktikanterna": "praktikant",
    "praktikanternas": "praktikant",
    "praktikanters": "praktikant",
    "praktikants": "praktikant",
    "praktiken": "praktik",
    "praktikens": "praktik",
    "praktiker": "praktik",
    "praktikern": "praktiker",
    "praktikerna": "praktiker",
    "praktikernas": "praktiker",
    "praktikerns": "praktiker",
    "praktikers": "praktiker",
    "praktiks": "praktik",
    "praktiktjänstgöringar": "praktiktjänstgöring",
    "praktiktjänstgöringarna": "praktiktjänstgöring",
    "praktiktjänstgöringarnas": "praktiktjänstgöring",
    "praktiktjänstgöringars": "praktiktjänstgöring",
    "praktiktjänstgöringen": "praktiktjänstgöring",
    "praktiktjänstgöringens": "praktiktjänstgöring",
    "praktiktjänstgörings": "praktiktjänstgöring",
    "praktiserad": "praktisera",
    "praktiserade": "praktisera",
    "praktiserades": "praktisera",
    "praktiserads": "praktisera",
    "praktiserande": "praktisera",
    "praktiseranden": "praktiserande",
    "praktiserandena": "praktiserande",
    "praktiserandenas": "praktiserande",
    "praktiserandens": "praktiserande",
    "praktiserandes": "praktiserande",
    "praktiserandet": "praktiserande",
    "praktiserandets": "praktiserande",
    "praktiserar": "praktisera",
    "praktiseras": "praktisera",
    "praktiserat": "praktisera",
    "praktiserats": "praktisera",
    "praktiserbara": "praktiserbar",
    "praktiserbarare": "praktiserbar",
    "praktiserbarares": "praktiserbar",
    "praktiserbaras": "praktiserbar",
    "praktiserbarast": "praktiserbar",
    "praktiserbaraste": "praktiserbar",
    "praktiserbarastes": "praktiserbar",
    "praktiserbarasts": "praktiserbar",
    "praktiserbare": "praktiserbar",
    "praktiserbares": "praktiserbar",
    "praktiserbarheten": "praktiserbarhet",
    "praktiserbarhetens": "praktiserbarhet",
    "praktiserbarhets": "praktiserbarhet",
    "praktiserbars": "praktiserbar",
    "praktiserbart": "praktiserbar",
    "praktiserbarts": "praktiserbar",
    "praktiseringar": "praktisering",
    "praktiseringarna": "praktisering",
    "praktiseringarnas": "praktisering",
    "praktiseringars": "praktisering",
    "praktiseringen": "praktisering",
    "praktiseringens": "praktisering",
    "praktiserings": "praktisering",
    "praktiska": "praktisk",
    "praktiskare": "praktisk",
    "praktiskares": "praktisk",
    "praktiskas": "praktisk",
    "praktiskast": "praktisk",
    "praktiskaste": "praktisk",
    "praktiskastes": "praktisk",
    "praktiskasts": "praktisk",
    "praktiske": "praktisk",
    "praktiskes": "praktisk",
    "praktisks": "praktisk",
    "praktiskt": "praktisk",
    "praktiskts": "praktisk",
    "praktmålningar": "praktmålning",
    "praktmålningarna": "praktmålning",
    "praktmålningarnas": "praktmålning",
    "praktmålningars": "praktmålning",
    "praktmålningen": "praktmålning",
    "praktmålningens": "praktmålning",
    "praktmålnings": "praktmålning",
    "praktpjäsen": "praktpjäs",
    "praktpjäsens": "praktpjäs",
    "praktpjäser": "praktpjäs",
    "praktpjäserna": "praktpjäs",
    "praktpjäsernas": "praktpjäs",
    "praktpjäsers": "praktpjäs",
    "prakts": "prakt",
    "praktverken": "praktverk",
    "praktverkens": "praktverk",
    "praktverket": "praktverk",
    "praktverkets": "praktverk",
    "praktverks": "praktverk",
    "pralinen": "pralin",
    "pralinens": "pralin",
    "praliner": "pralin",
    "pralinerna": "pralin",
    "pralinernas": "pralin",
    "praliners": "pralin",
    "pralins": "pralin",
    "praoade": "praoa",
    "praoades": "praoa",
    "praoande": "praoa",
    "praoandes": "praoa",
    "praoar": "praoa",
    "praoas": "praoa",
    "praoat": "praoa",
    "praoats": "praoa",
    "praon": "prao",
    "praons": "prao",
    "praos": "prao",
    "praseodymet": "praseodym",
    "praseodymets": "praseodym",
    "praseodyms": "praseodym",
    "prassel": "prassla",
    "prassels": "prassel",
    "prasslade": "prassla",
    "prasslades": "prassla",
    "prasslande": "prassla",
    "prasslanden": "prasslande",
    "prasslandena": "prasslande",
    "prasslandenas": "prasslande",
    "prasslandens": "prasslande",
    "prasslandes": "prasslande",
    "prasslandet": "prasslande",
    "prasslandets": "prasslande",
    "prasslar": "prassla",
    "prasslas": "prassla",
    "prasslat": "prassla",
    "prasslats": "prassla",
    "prasslet": "prassel",
    "prasslets": "prassel",
    "prat": "prata",
    "pratade": "prata",
    "pratades": "prata",
    "pratan": "prata",
    "pratande": "prata",
    "pratanden": "pratande",
    "pratandena": "pratande",
    "pratandenas": "pratande",
    "pratandens": "pratande",
    "pratandes": "pratande",
    "pratandet": "pratande",
    "pratandets": "pratande",
    "pratans": "prata",
    "pratar": "prata",
    "pratas": "prata",
    "pratat": "prata",
    "pratats": "prata",
    "pratbubbel": "pratbubbla",
    "pratbubblan": "pratbubbla",
    "pratbubblans": "pratbubbla",
    "pratbubblas": "pratbubbla",
    "pratbubble": "pratbubbla",
    "pratbubblor": "pratbubbla",
    "pratbubblorna": "pratbubbla",
    "pratbubblornas": "pratbubbla",
    "pratbubblors": "pratbubbla",
    "prate": "prata",
    "praten": "prat",
    "pratens": "prat",
    "pratet": "prat",
    "pratets": "prat",
    "pratglada": "pratglad",
    "pratgladare": "pratglad",
    "pratgladares": "pratglad",
    "pratgladas": "pratglad",
    "pratgladast": "pratglad",
    "pratgladaste": "pratglad",
    "pratgladastes": "pratglad",
    "pratgladasts": "pratglad",
    "pratglade": "pratglad",
    "pratglades": "pratglad",
    "pratglads": "pratglad",
    "pratglatt": "pratglad",
    "pratglatts": "pratglad",
    "pratiga": "pratig",
    "pratigare": "pratig",
    "pratigares": "pratig",
    "pratigas": "pratig",
    "pratigast": "pratig",
    "pratigaste": "pratig",
    "pratigastes": "pratig",
    "pratigasts": "pratig",
    "pratige": "pratig",
    "pratiges": "pratig",
    "pratigs": "pratig",
    "pratigt": "pratig",
    "pratigts": "pratig",
    "pratkvarnar": "pratkvarn",
    "pratkvarnarna": "pratkvarn",
    "pratkvarnarnas": "pratkvarn",
    "pratkvarnars": "pratkvarn",
    "pratkvarnen": "pratkvarn",
    "pratkvarnens": "pratkvarn",
    "pratkvarns": "pratkvarn",
    "pratmakar": "pratmakare",
    "pratmakaren": "pratmakare",
    "pratmakarens": "pratmakare",
    "pratmakares": "pratmakare",
    "pratmakarna": "pratmakare",
    "pratmakarnas": "pratmakare",
    "prator": "prata",
    "pratorna": "prata",
    "pratornas": "prata",
    "prators": "prata",
    "prats": "prata",
    "pratsamheten": "pratsamhet",
    "pratsamhetens": "pratsamhet",
    "pratsamhets": "pratsamhet",
    "pratsamma": "pratsam",
    "pratsammare": "pratsam",
    "pratsammares": "pratsam",
    "pratsammas": "pratsam",
    "pratsammast": "pratsam",
    "pratsammaste": "pratsam",
    "pratsammastes": "pratsam",
    "pratsammasts": "pratsam",
    "pratsamme": "pratsam",
    "pratsammes": "pratsam",
    "pratsams": "pratsam",
    "pratsamt": "pratsam",
    "pratsamts": "pratsam",
    "pratsjuk": "pratsjuka",
    "pratsjuka": "pratsjuk",
    "pratsjukan": "pratsjuka",
    "pratsjukans": "pratsjuka",
    "pratsjukare": "pratsjuk",
    "pratsjukares": "pratsjuk",
    "pratsjukas": "pratsjuka",
    "pratsjukast": "pratsjuk",
    "pratsjukaste": "pratsjuk",
    "pratsjukastes": "pratsjuk",
    "pratsjukasts": "pratsjuk",
    "pratsjuke": "pratsjuka",
    "pratsjukes": "pratsjuk",
    "pratsjukheten": "pratsjukhet",
    "pratsjukhetens": "pratsjukhet",
    "pratsjukhets": "pratsjukhet",
    "pratsjukor": "pratsjuka",
    "pratsjukorna": "pratsjuka",
    "pratsjukornas": "pratsjuka",
    "pratsjukors": "pratsjuka",
    "pratsjuks": "pratsjuka",
    "pratsjukt": "pratsjuk",
    "pratsjukts": "pratsjuk",
    "pratsoff": "pratsoffa",
    "pratsoffan": "pratsoffa",
    "pratsoffans": "pratsoffa",
    "pratsoffas": "pratsoffa",
    "pratsoffe": "pratsoffa",
    "pratsoffor": "pratsoffa",
    "pratsofforna": "pratsoffa",
    "pratsoffornas": "pratsoffa",
    "pratsoffors": "pratsoffa",
    "pratsoffs": "pratsoffa",
    "pratstunden": "pratstund",
    "pratstundens": "pratstund",
    "pratstunder": "pratstund",
    "pratstunderna": "pratstund",
    "pratstundernas": "pratstund",
    "pratstunders": "pratstund",
    "pratstunds": "pratstund",
    "praxisen": "praxis",
    "praxisens": "praxis",
    "prebenden": "prebende",
    "prebendena": "prebende",
    "prebendenas": "prebende",
    "prebendens": "prebende",
    "prebendes": "prebende",
    "prebendet": "prebende",
    "prebendets": "prebende",
    "precedensen": "precedens",
    "precedensens": "precedens",
    "precedensfallen": "precedensfall",
    "precedensfallens": "precedensfall",
    "precedensfallet": "precedensfall",
    "precedensfallets": "precedensfall",
    "precedensfalls": "precedensfall",
    "preceptorer": "preceptor",
    "preceptorerna": "preceptor",
    "preceptorernas": "preceptor",
    "preceptorers": "preceptor",
    "preceptorn": "preceptor",
    "preceptorns": "preceptor",
    "preceptors": "preceptor",
    "precepturen": "preceptur",
    "precepturens": "preceptur",
    "precepturer": "preceptur",
    "precepturerna": "preceptur",
    "precepturernas": "preceptur",
    "precepturers": "preceptur",
    "precepturs": "preceptur",
    "preciosan": "preciosa",
    "preciosana": "preciosa",
    "preciosanas": "preciosa",
    "preciosans": "preciosa",
    "preciosas": "preciosa",
    "preciosat": "preciosa",
    "preciosats": "preciosa",
    "preciositeten": "preciositet",
    "preciositetens": "preciositet",
    "preciositeter": "preciositet",
    "preciositeterna": "preciositet",
    "preciositeternas": "preciositet",
    "preciositeters": "preciositet",
    "preciositets": "preciositet",
    "precisa": "precis",
    "precisare": "precis",
    "precisares": "precis",
    "precisas": "precis",
    "precisast": "precis",
    "precisaste": "precis",
    "precisastes": "precis",
    "precisasts": "precis",
    "precise": "precis",
    "preciserad": "precisera",
    "preciserade": "precisera",
    "preciserades": "precisera",
    "preciserads": "precisera",
    "preciserande": "precisera",
    "preciseranden": "preciserande",
    "preciserandena": "preciserande",
    "preciserandenas": "preciserande",
    "preciserandens": "preciserande",
    "preciserandes": "preciserande",
    "preciserandet": "preciserande",
    "preciserandets": "preciserande",
    "preciserar": "precisera",
    "preciseras": "precisera",
    "preciserat": "precisera",
    "preciserats": "precisera",
    "preciserbara": "preciserbar",
    "preciserbarare": "preciserbar",
    "preciserbarares": "preciserbar",
    "preciserbaras": "preciserbar",
    "preciserbarast": "preciserbar",
    "preciserbaraste": "preciserbar",
    "preciserbarastes": "preciserbar",
    "preciserbarasts": "preciserbar",
    "preciserbare": "preciserbar",
    "preciserbares": "preciserbar",
    "preciserbarheten": "preciserbarhet",
    "preciserbarhetens": "preciserbarhet",
    "preciserbarhets": "preciserbarhet",
    "preciserbars": "preciserbar",
    "preciserbart": "preciserbar",
    "preciserbarts": "preciserbar",
    "preciseringar": "precisering",
    "preciseringarna": "precisering",
    "preciseringarnas": "precisering",
    "preciseringars": "precisering",
    "preciseringen": "precisering",
    "preciseringens": "precisering",
    "preciserings": "precisering",
    "precises": "precis",
    "precisionen": "precision",
    "precisionens": "precision",
    "precisioner": "precision",
    "precisionerna": "precision",
    "precisionernas": "precision",
    "precisioners": "precision",
    "precisions": "precision",
    "precisionsarbeten": "precisionsarbete",
    "precisionsarbetena": "precisionsarbete",
    "precisionsarbetenas": "precisionsarbete",
    "precisionsarbetens": "precisionsarbete",
    "precisionsarbetes": "precisionsarbete",
    "precisionsarbetet": "precisionsarbete",
    "precisionsarbetets": "precisionsarbete",
    "precisionsarbets": "precisionsarbete",
    "precisionsmejseln": "precisionsmejsel",
    "precisionsmejselns": "precisionsmejsel",
    "precisionsmejsels": "precisionsmejsel",
    "precisionsmejslar": "precisionsmejsel",
    "precisionsmejslarna": "precisionsmejsel",
    "precisionsmejslarnas": "precisionsmejsel",
    "precisionsmejslars": "precisionsmejsel",
    "precisionsmåtten": "precisionsmått",
    "precisionsmåttens": "precisionsmått",
    "precisionsmåttet": "precisionsmått",
    "precisionsmåttets": "precisionsmått",
    "precisionsmåtts": "precisionsmått",
    "precisionsrörelsen": "precisionsrörelse",
    "precisionsrörelsens": "precisionsrörelse",
    "precisionsrörelser": "precisionsrörelse",
    "precisionsrörelserna": "precisionsrörelse",
    "precisionsrörelsernas": "precisionsrörelse",
    "precisionsrörelsers": "precisionsrörelse",
    "precisionsrörelses": "precisionsrörelse",
    "precisionsskjutningar": "precisionsskjutning",
    "precisionsskjutningarna": "precisionsskjutning",
    "precisionsskjutningarnas": "precisionsskjutning",
    "precisionsskjutningars": "precisionsskjutning",
    "precisionsskjutningen": "precisionsskjutning",
    "precisionsskjutningens": "precisionsskjutning",
    "precisionsskjutnings": "precisionsskjutning",
    "precisionsskyttes": "precisionsskytte",
    "precisionsskyttet": "precisionsskytte",
    "precisionsskyttets": "precisionsskytte",
    "precist": "precis",
    "precists": "precis",
    "preciösa": "preciös",
    "preciösare": "preciös",
    "preciösares": "preciös",
    "preciösas": "preciös",
    "preciösast": "preciös",
    "preciösaste": "preciös",
    "preciösastes": "preciös",
    "preciösasts": "preciös",
    "preciöse": "preciös",
    "preciöses": "preciös",
    "preciöst": "preciös",
    "preciösts": "preciös",
    "predationen": "predation",
    "predationens": "predation",
    "predationer": "predation",
    "predationerna": "predation",
    "predationernas": "predation",
    "predationers": "predation",
    "predations": "predation",
    "predatorer": "predator",
    "predatorerna": "predator",
    "predatorernas": "predator",
    "predatorers": "predator",
    "predatorn": "predator",
    "predatorns": "predator",
    "predators": "predator",
    "predestinationen": "predestination",
    "predestinationens": "predestination",
    "predestinationer": "predestination",
    "predestinationerna": "predestination",
    "predestinationernas": "predestination",
    "predestinationers": "predestination",
    "predestinations": "predestination",
    "predestinerad": "predestinera",
    "predestinerade": "predestinera",
    "predestinerades": "predestinera",
    "predestinerads": "predestinera",
    "predestinerande": "predestinera",
    "predestineranden": "predestinerande",
    "predestinerandena": "predestinerande",
    "predestinerandenas": "predestinerande",
    "predestinerandens": "predestinerande",
    "predestinerandes": "predestinerande",
    "predestinerandet": "predestinerande",
    "predestinerandets": "predestinerande",
    "predestinerar": "predestinera",
    "predestineras": "predestinera",
    "predestinerat": "predestinera",
    "predestinerats": "predestinera",
    "predestinerbara": "predestinerbar",
    "predestinerbarare": "predestinerbar",
    "predestinerbarares": "predestinerbar",
    "predestinerbaras": "predestinerbar",
    "predestinerbarast": "predestinerbar",
    "predestinerbaraste": "predestinerbar",
    "predestinerbarastes": "predestinerbar",
    "predestinerbarasts": "predestinerbar",
    "predestinerbare": "predestinerbar",
    "predestinerbares": "predestinerbar",
    "predestinerbarheten": "predestinerbarhet",
    "predestinerbarhetens": "predestinerbarhet",
    "predestinerbarhets": "predestinerbarhet",
    "predestinerbars": "predestinerbar",
    "predestinerbart": "predestinerbar",
    "predestinerbarts": "predestinerbar",
    "predestineringar": "predestinering",
    "predestineringarna": "predestinering",
    "predestineringarnas": "predestinering",
    "predestineringars": "predestinering",
    "predestineringen": "predestinering",
    "predestineringens": "predestinering",
    "predestinerings": "predestinering",
    "predicerad": "predicera",
    "predicerade": "predicera",
    "predicerades": "predicera",
    "predicerads": "predicera",
    "predicerande": "predicera",
    "prediceranden": "predicerande",
    "predicerandena": "predicerande",
    "predicerandenas": "predicerande",
    "predicerandens": "predicerande",
    "predicerandes": "predicerande",
    "predicerandet": "predicerande",
    "predicerandets": "predicerande",
    "predicerar": "predicera",
    "prediceras": "predicera",
    "predicerat": "predicera",
    "predicerats": "predicera",
    "predicerbara": "predicerbar",
    "predicerbarare": "predicerbar",
    "predicerbarares": "predicerbar",
    "predicerbaras": "predicerbar",
    "predicerbarast": "predicerbar",
    "predicerbaraste": "predicerbar",
    "predicerbarastes": "predicerbar",
    "predicerbarasts": "predicerbar",
    "predicerbare": "predicerbar",
    "predicerbares": "predicerbar",
    "predicerbarheten": "predicerbarhet",
    "predicerbarhetens": "predicerbarhet",
    "predicerbarhets": "predicerbarhet",
    "predicerbars": "predicerbar",
    "predicerbart": "predicerbar",
    "predicerbarts": "predicerbar",
    "prediceringar": "predicering",
    "prediceringarna": "predicering",
    "prediceringarnas": "predicering",
    "prediceringars": "predicering",
    "prediceringen": "predicering",
    "prediceringens": "predicering",
    "predicerings": "predicering",
    "predik": "predika",
    "predikad": "predika",
    "predikade": "predika",
    "predikades": "predika",
    "predikads": "predika",
    "predikamenten": "predikament",
    "predikamentens": "predikament",
    "predikamenter": "predikament",
    "predikamenterna": "predikament",
    "predikamenternas": "predikament",
    "predikamenters": "predikament",
    "predikamentet": "predikament",
    "predikamentets": "predikament",
    "predikaments": "predikament",
    "predikande": "predika",
    "predikanden": "predikande",
    "predikandena": "predikande",
    "predikandenas": "predikande",
    "predikandens": "predikande",
    "predikandes": "predikande",
    "predikandet": "predikande",
    "predikandets": "predikande",
    "predikans": "predikan",
    "predikanten": "predikant",
    "predikantens": "predikant",
    "predikanter": "predikant",
    "predikanterna": "predikant",
    "predikanternas": "predikant",
    "predikanters": "predikant",
    "predikantmässiga": "predikantmässig",
    "predikantmässigare": "predikantmässig",
    "predikantmässigares": "predikantmässig",
    "predikantmässigas": "predikantmässig",
    "predikantmässigast": "predikantmässig",
    "predikantmässigaste": "predikantmässig",
    "predikantmässigastes": "predikantmässig",
    "predikantmässigasts": "predikantmässig",
    "predikantmässige": "predikantmässig",
    "predikantmässiges": "predikantmässig",
    "predikantmässigs": "predikantmässig",
    "predikantmässigt": "predikantmässig",
    "predikantmässigts": "predikantmässig",
    "predikants": "predikant",
    "predikar": "predikare",
    "predikaren": "predikare",
    "predikarens": "predikare",
    "predikares": "predikare",
    "predikarna": "predikare",
    "predikarnas": "predikare",
    "predikas": "predika",
    "predikat": "predika",
    "predikatadverbialen": "predikatadverbial",
    "predikatadverbialens": "predikatadverbial",
    "predikatadverbialet": "predikatadverbial",
    "predikatadverbialets": "predikatadverbial",
    "predikatadverbials": "predikatadverbial",
    "predikaten": "predikat",
    "predikatens": "predikat",
    "predikatet": "predikat",
    "predikatets": "predikat",
    "predikativa": "predikativ",
    "predikativare": "predikativ",
    "predikativares": "predikativ",
    "predikativas": "predikativ",
    "predikativast": "predikativ",
    "predikativaste": "predikativ",
    "predikativastes": "predikativ",
    "predikativasts": "predikativ",
    "predikative": "predikativ",
    "predikativen": "predikativ",
    "predikativens": "predikativ",
    "predikativer": "predikativ",
    "predikativerna": "predikativ",
    "predikativernas": "predikativ",
    "predikativers": "predikativ",
    "predikatives": "predikativ",
    "predikativet": "predikativ",
    "predikativets": "predikativ",
    "predikativs": "predikativ",
    "predikativt": "predikativ",
    "predikativts": "predikativ",
    "predikatlogiken": "predikatlogik",
    "predikatlogikens": "predikatlogik",
    "predikatlogiks": "predikatlogik",
    "predikatlogiska": "predikatlogisk",
    "predikatlogiskare": "predikatlogisk",
    "predikatlogiskares": "predikatlogisk",
    "predikatlogiskas": "predikatlogisk",
    "predikatlogiskast": "predikatlogisk",
    "predikatlogiskaste": "predikatlogisk",
    "predikatlogiskastes": "predikatlogisk",
    "predikatlogiskasts": "predikatlogisk",
    "predikatlogiske": "predikatlogisk",
    "predikatlogiskes": "predikatlogisk",
    "predikatlogisks": "predikatlogisk",
    "predikatlogiskt": "predikatlogisk",
    "predikatlogiskts": "predikatlogisk",
    "predikats": "predikat",
    "predikatsfyllnaden": "predikatsfyllnad",
    "predikatsfyllnadens": "predikatsfyllnad",
    "predikatsfyllnader": "predikatsfyllnad",
    "predikatsfyllnaderna": "predikatsfyllnad",
    "predikatsfyllnadernas": "predikatsfyllnad",
    "predikatsfyllnaders": "predikatsfyllnad",
    "predikatsfyllnads": "predikatsfyllnad",
    "predikningar": "predikning",
    "predikningarna": "predikning",
    "predikningarnas": "predikning",
    "predikningars": "predikning",
    "predikningen": "predikning",
    "predikningens": "predikning",
    "prediknings": "predikning",
    "prediko": "predika",
    "predikokonsten": "predikokonst",
    "predikokonstens": "predikokonst",
    "predikokonster": "predikokonst",
    "predikokonsterna": "predikokonst",
    "predikokonsternas": "predikokonst",
    "predikokonsters": "predikokonst",
    "predikokonsts": "predikokonst",
    "predikosamlingar": "predikosamling",
    "predikosamlingarna": "predikosamling",
    "predikosamlingarnas": "predikosamling",
    "predikosamlingars": "predikosamling",
    "predikosamlingen": "predikosamling",
    "predikosamlingens": "predikosamling",
    "predikosamlings": "predikosamling",
    "predikotexten": "predikotext",
    "predikotextens": "predikotext",
    "predikotexter": "predikotext",
    "predikotexterna": "predikotext",
    "predikotexternas": "predikotext",
    "predikotexters": "predikotext",
    "predikotexts": "predikotext",
    "predikoturen": "predikotur",
    "predikoturens": "predikotur",
    "predikoturer": "predikotur",
    "predikoturerna": "predikotur",
    "predikoturernas": "predikotur",
    "predikoturers": "predikotur",
    "predikoturs": "predikotur",
    "predikstolar": "predikstol",
    "predikstolarna": "predikstol",
    "predikstolarnas": "predikstol",
    "predikstolars": "predikstol",
    "predikstolen": "predikstol",
    "predikstolens": "predikstol",
    "predikstols": "predikstol",
    "predisponerad": "predisponera",
    "predisponerade": "predisponera",
    "predisponerades": "predisponera",
    "predisponerads": "predisponera",
    "predisponerande": "predisponera",
    "predisponeranden": "predisponerande",
    "predisponerandena": "predisponerande",
    "predisponerandenas": "predisponerande",
    "predisponerandens": "predisponerande",
    "predisponerandes": "predisponerande",
    "predisponerandet": "predisponerande",
    "predisponerandets": "predisponerande",
    "predisponerar": "predisponera",
    "predisponeras": "predisponera",
    "predisponerat": "predisponera",
    "predisponerats": "predisponera",
    "predisponerbara": "predisponerbar",
    "predisponerbarare": "predisponerbar",
    "predisponerbarares": "predisponerbar",
    "predisponerbaras": "predisponerbar",
    "predisponerbarast": "predisponerbar",
    "predisponerbaraste": "predisponerbar",
    "predisponerbarastes": "predisponerbar",
    "predisponerbarasts": "predisponerbar",
    "predisponerbare": "predisponerbar",
    "predisponerbares": "predisponerbar",
    "predisponerbarheten": "predisponerbarhet",
    "predisponerbarhetens": "predisponerbarhet",
    "predisponerbarhets": "predisponerbarhet",
    "predisponerbars": "predisponerbar",
    "predisponerbart": "predisponerbar",
    "predisponerbarts": "predisponerbar",
    "predisponeringar": "predisponering",
    "predisponeringarna": "predisponering",
    "predisponeringarnas": "predisponering",
    "predisponeringars": "predisponering",
    "predisponeringen": "predisponering",
    "predisponeringens": "predisponering",
    "predisponerings": "predisponering",
    "predispositionen": "predisposition",
    "predispositionens": "predisposition",
    "predispositioner": "predisposition",
    "predispositionerna": "predisposition",
    "predispositionernas": "predisposition",
    "predispositioners": "predisposition",
    "predispositions": "predisposition",
    "predominerade": "predominera",
    "predominerades": "predominera",
    "predominerande": "predominera",
    "predomineranden": "predominerande",
    "predominerandena": "predominerande",
    "predominerandenas": "predominerande",
    "predominerandens": "predominerande",
    "predominerandes": "predominerande",
    "predominerandet": "predominerande",
    "predominerandets": "predominerande",
    "predominerar": "predominera",
    "predomineras": "predominera",
    "predominerat": "predominera",
    "predominerats": "predominera",
    "predomineringar": "predominering",
    "predomineringarna": "predominering",
    "predomineringarnas": "predominering",
    "predomineringars": "predominering",
    "predomineringen": "predominering",
    "predomineringens": "predominering",
    "predominerings": "predominering",
    "preexistensen": "preexistens",
    "preexistensens": "preexistens",
    "prefabricerad": "prefabricera",
    "prefabricerade": "prefabricera",
    "prefabricerades": "prefabricera",
    "prefabricerads": "prefabricera",
    "prefabricerande": "prefabricera",
    "prefabriceranden": "prefabricerande",
    "prefabricerandena": "prefabricerande",
    "prefabricerandenas": "prefabricerande",
    "prefabricerandens": "prefabricerande",
    "prefabricerandes": "prefabricerande",
    "prefabricerandet": "prefabricerande",
    "prefabricerandets": "prefabricerande",
    "prefabricerar": "prefabricera",
    "prefabriceras": "prefabricera",
    "prefabricerat": "prefabricera",
    "prefabricerats": "prefabricera",
    "prefabricerbara": "prefabricerbar",
    "prefabricerbarare": "prefabricerbar",
    "prefabricerbarares": "prefabricerbar",
    "prefabricerbaras": "prefabricerbar",
    "prefabricerbarast": "prefabricerbar",
    "prefabricerbaraste": "prefabricerbar",
    "prefabricerbarastes": "prefabricerbar",
    "prefabricerbarasts": "prefabricerbar",
    "prefabricerbare": "prefabricerbar",
    "prefabricerbares": "prefabricerbar",
    "prefabricerbarheten": "prefabricerbarhet",
    "prefabricerbarhetens": "prefabricerbarhet",
    "prefabricerbarhets": "prefabricerbarhet",
    "prefabricerbars": "prefabricerbar",
    "prefabricerbart": "prefabricerbar",
    "prefabricerbarts": "prefabricerbar",
    "prefabriceringar": "prefabricering",
    "prefabriceringarna": "prefabricering",
    "prefabriceringarnas": "prefabricering",
    "prefabriceringars": "prefabricering",
    "prefabriceringen": "prefabricering",
    "prefabriceringens": "prefabricering",
    "prefabricerings": "prefabricering",
    "prefekten": "prefekt",
    "prefektens": "prefekt",
    "prefekter": "prefekt",
    "prefekterna": "prefekt",
    "prefekternas": "prefekt",
    "prefekters": "prefekt",
    "prefekts": "prefekt",
    "prefekturen": "prefektur",
    "prefekturens": "prefektur",
    "prefekturer": "prefektur",
    "prefekturerna": "prefektur",
    "prefekturernas": "prefektur",
    "prefekturers": "prefektur",
    "prefekturs": "prefektur",
    "preferensaktien": "preferensaktie",
    "preferensaktiens": "preferensaktie",
    "preferensaktier": "preferensaktie",
    "preferensaktierna": "preferensaktie",
    "preferensaktiernas": "preferensaktie",
    "preferensaktiers": "preferensaktie",
    "preferensakties": "preferensaktie",
    "preferensen": "preferens",
    "preferensens": "preferens",
    "preferenser": "preferens",
    "preferenserna": "preferens",
    "preferensernas": "preferens",
    "preferensers": "preferens",
    "prefererad": "preferera",
    "prefererade": "preferera",
    "prefererades": "preferera",
    "prefererads": "preferera",
    "prefererande": "preferera",
    "prefereranden": "prefererande",
    "prefererandena": "prefererande",
    "prefererandenas": "prefererande",
    "prefererandens": "prefererande",
    "prefererandes": "prefererande",
    "prefererandet": "prefererande",
    "prefererandets": "prefererande",
    "prefererar": "preferera",
    "prefereras": "preferera",
    "prefererat": "preferera",
    "prefererats": "preferera",
    "prefererbara": "prefererbar",
    "prefererbarare": "prefererbar",
    "prefererbarares": "prefererbar",
    "prefererbaras": "prefererbar",
    "prefererbarast": "prefererbar",
    "prefererbaraste": "prefererbar",
    "prefererbarastes": "prefererbar",
    "prefererbarasts": "prefererbar",
    "prefererbare": "prefererbar",
    "prefererbares": "prefererbar",
    "prefererbarheten": "prefererbarhet",
    "prefererbarhetens": "prefererbarhet",
    "prefererbarhets": "prefererbarhet",
    "prefererbars": "prefererbar",
    "prefererbart": "prefererbar",
    "prefererbarts": "prefererbar",
    "prefigerad": "prefigera",
    "prefigerade": "prefigera",
    "prefigerades": "prefigera",
    "prefigerads": "prefigera",
    "prefigerande": "prefigera",
    "prefigeranden": "prefigerande",
    "prefigerandena": "prefigerande",
    "prefigerandenas": "prefigerande",
    "prefigerandens": "prefigerande",
    "prefigerandes": "prefigerande",
    "prefigerandet": "prefigerande",
    "prefigerandets": "prefigerande",
    "prefigerar": "prefigera",
    "prefigeras": "prefigera",
    "prefigerat": "prefigera",
    "prefigerats": "prefigera",
    "prefigerbara": "prefigerbar",
    "prefigerbarare": "prefigerbar",
    "prefigerbarares": "prefigerbar",
    "prefigerbaras": "prefigerbar",
    "prefigerbarast": "prefigerbar",
    "prefigerbaraste": "prefigerbar",
    "prefigerbarastes": "prefigerbar",
    "prefigerbarasts": "prefigerbar",
    "prefigerbare": "prefigerbar",
    "prefigerbares": "prefigerbar",
    "prefigerbarheten": "prefigerbarhet",
    "prefigerbarhetens": "prefigerbarhet",
    "prefigerbarhets": "prefigerbarhet",
    "prefigerbars": "prefigerbar",
    "prefigerbart": "prefigerbar",
    "prefigerbarts": "prefigerbar",
    "prefigeringar": "prefigering",
    "prefigeringarna": "prefigering",
    "prefigeringarnas": "prefigering",
    "prefigeringars": "prefigering",
    "prefigeringen": "prefigering",
    "prefigeringens": "prefigering",
    "prefigerings": "prefigering",
    "prefixen": "prefix",
    "prefixens": "prefix",
    "prefixet": "prefix",
    "prefixets": "prefix",
    "preglaciala": "preglacial",
    "preglacialare": "preglacial",
    "preglacialares": "preglacial",
    "preglacialas": "preglacial",
    "preglacialast": "preglacial",
    "preglacialaste": "preglacial",
    "preglacialastes": "preglacial",
    "preglacialasts": "preglacial",
    "preglaciale": "preglacial",
    "preglaciales": "preglacial",
    "preglacials": "preglacial",
    "preglacialt": "preglacial",
    "preglacialts": "preglacial",
    "pregnansen": "pregnans",
    "pregnansens": "pregnans",
    "pregnanta": "pregnant",
    "pregnantare": "pregnant",
    "pregnantares": "pregnant",
    "pregnantas": "pregnant",
    "pregnantast": "pregnant",
    "pregnantaste": "pregnant",
    "pregnantastes": "pregnant",
    "pregnantasts": "pregnant",
    "pregnante": "pregnant",
    "pregnantes": "pregnant",
    "pregnants": "pregnant",
    "prehistoriska": "prehistorisk",
    "prehistoriskare": "prehistorisk",
    "prehistoriskares": "prehistorisk",
    "prehistoriskas": "prehistorisk",
    "prehistoriskast": "prehistorisk",
    "prehistoriskaste": "prehistorisk",
    "prehistoriskastes": "prehistorisk",
    "prehistoriskasts": "prehistorisk",
    "prehistoriske": "prehistorisk",
    "prehistoriskes": "prehistorisk",
    "prehistorisks": "prehistorisk",
    "prehistoriskt": "prehistorisk",
    "prehistoriskts": "prehistorisk",
    "prej": "preja",
    "prejad": "preja",
    "prejade": "preja",
    "prejades": "preja",
    "prejads": "preja",
    "prejande": "preja",
    "prejanden": "prejande",
    "prejandena": "prejande",
    "prejandenas": "prejande",
    "prejandens": "prejande",
    "prejandes": "prejande",
    "prejandet": "prejande",
    "prejandets": "prejande",
    "prejar": "preja",
    "prejas": "preja",
    "prejat": "preja",
    "prejats": "preja",
    "prejningar": "prejning",
    "prejningarna": "prejning",
    "prejningarnas": "prejning",
    "prejningars": "prejning",
    "prejningen": "prejning",
    "prejningens": "prejning",
    "prejnings": "prejning",
    "prejudikaten": "prejudikat",
    "prejudikatens": "prejudikat",
    "prejudikatet": "prejudikat",
    "prejudikatets": "prejudikat",
    "prejudikats": "prejudikat",
    "prekära": "prekär",
    "prekärare": "prekär",
    "prekärares": "prekär",
    "prekäras": "prekär",
    "prekärast": "prekär",
    "prekäraste": "prekär",
    "prekärastes": "prekär",
    "prekärasts": "prekär",
    "prekäre": "prekär",
    "prekäres": "prekär",
    "prekärs": "prekär",
    "prekärt": "prekär",
    "prekärts": "prekär",
    "prelaten": "prelat",
    "prelatens": "prelat",
    "prelater": "prelat",
    "prelaterna": "prelat",
    "prelaternas": "prelat",
    "prelaters": "prelat",
    "prelats": "prelat",
    "preliminär": "preliminärer",
    "preliminära": "preliminär",
    "preliminärare": "preliminär",
    "preliminärares": "preliminär",
    "preliminäras": "preliminär",
    "preliminärast": "preliminär",
    "preliminäraste": "preliminär",
    "preliminärastes": "preliminär",
    "preliminärasts": "preliminär",
    "preliminäre": "preliminär",
    "preliminärerna": "preliminärer",
    "preliminärernas": "preliminärer",
    "preliminärers": "preliminärer",
    "preliminäres": "preliminär",
    "preliminärs": "preliminärer",
    "preliminärskatten": "preliminärskatt",
    "preliminärskattens": "preliminärskatt",
    "preliminärskatter": "preliminärskatt",
    "preliminärskatterna": "preliminärskatt",
    "preliminärskatternas": "preliminärskatt",
    "preliminärskatters": "preliminärskatt",
    "preliminärskatts": "preliminärskatt",
    "preliminärt": "preliminär",
    "preliminärts": "preliminär",
    "preludie": "preludium",
    "preludier": "preludium",
    "preludierad": "preludiera",
    "preludierade": "preludiera",
    "preludierades": "preludiera",
    "preludierads": "preludiera",
    "preludierande": "preludiera",
    "preludieranden": "preludierande",
    "preludierandena": "preludierande",
    "preludierandenas": "preludierande",
    "preludierandens": "preludierande",
    "preludierandes": "preludierande",
    "preludierandet": "preludierande",
    "preludierandets": "preludierande",
    "preludierar": "preludiera",
    "preludieras": "preludiera",
    "preludierat": "preludiera",
    "preludierats": "preludiera",
    "preludierbara": "preludierbar",
    "preludierbarare": "preludierbar",
    "preludierbarares": "preludierbar",
    "preludierbaras": "preludierbar",
    "preludierbarast": "preludierbar",
    "preludierbaraste": "preludierbar",
    "preludierbarastes": "preludierbar",
    "preludierbarasts": "preludierbar",
    "preludierbare": "preludierbar",
    "preludierbares": "preludierbar",
    "preludierbarheten": "preludierbarhet",
    "preludierbarhetens": "preludierbarhet",
    "preludierbarhets": "preludierbarhet",
    "preludierbars": "preludierbar",
    "preludierbart": "preludierbar",
    "preludierbarts": "preludierbar",
    "preludieringar": "preludiering",
    "preludieringarna": "preludiering",
    "preludieringarnas": "preludiering",
    "preludieringars": "preludiering",
    "preludieringen": "preludiering",
    "preludieringens": "preludiering",
    "preludierings": "preludiering",
    "preludierna": "preludium",
    "preludiernas": "preludium",
    "preludiers": "preludium",
    "preludiet": "preludium",
    "preludiets": "preludium",
    "preludiums": "preludium",
    "premenstruella": "premenstruell",
    "premenstruellas": "premenstruell",
    "premenstruelle": "premenstruell",
    "premenstruelles": "premenstruell",
    "premenstruells": "premenstruell",
    "premenstruellt": "premenstruell",
    "premenstruellts": "premenstruell",
    "premie": "premium",
    "premiebetalar": "premiebetalare",
    "premiebetalaren": "premiebetalare",
    "premiebetalarens": "premiebetalare",
    "premiebetalares": "premiebetalare",
    "premiebetalarna": "premiebetalare",
    "premiebetalarnas": "premiebetalare",
    "premiegilla": "premiegill",
    "premiegillare": "premiegill",
    "premiegillares": "premiegill",
    "premiegillas": "premiegill",
    "premiegillast": "premiegill",
    "premiegillaste": "premiegill",
    "premiegillastes": "premiegill",
    "premiegillasts": "premiegill",
    "premiegille": "premiegill",
    "premiegilles": "premiegill",
    "premiegills": "premiegill",
    "premiegillt": "premiegill",
    "premiegillts": "premiegill",
    "premielånen": "premielån",
    "premielånens": "premielån",
    "premielånet": "premielån",
    "premielånets": "premielån",
    "premielåns": "premielån",
    "premien": "premie",
    "premiens": "premie",
    "premieobligationen": "premieobligation",
    "premieobligationens": "premieobligation",
    "premieobligationer": "premieobligation",
    "premieobligationerna": "premieobligation",
    "premieobligationernas": "premieobligation",
    "premieobligationers": "premieobligation",
    "premieobligations": "premieobligation",
    "premier": "premium",
    "premierad": "premiera",
    "premierade": "premiera",
    "premierades": "premiera",
    "premierads": "premiera",
    "premierande": "premiera",
    "premieranden": "premierande",
    "premierandena": "premierande",
    "premierandenas": "premierande",
    "premierandens": "premierande",
    "premierandes": "premierande",
    "premierandet": "premierande",
    "premierandets": "premierande",
    "premierar": "premiera",
    "premieras": "premiera",
    "premierat": "premiera",
    "premierats": "premiera",
    "premierbara": "premierbar",
    "premierbarare": "premierbar",
    "premierbarares": "premierbar",
    "premierbaras": "premierbar",
    "premierbarast": "premierbar",
    "premierbaraste": "premierbar",
    "premierbarastes": "premierbar",
    "premierbarasts": "premierbar",
    "premierbare": "premierbar",
    "premierbares": "premierbar",
    "premierbarheten": "premierbarhet",
    "premierbarhetens": "premierbarhet",
    "premierbarhets": "premierbarhet",
    "premierbars": "premierbar",
    "premierbart": "premierbar",
    "premierbarts": "premierbar",
    "premieringar": "premiering",
    "premieringarna": "premiering",
    "premieringarnas": "premiering",
    "premieringars": "premiering",
    "premieringen": "premiering",
    "premieringens": "premiering",
    "premierings": "premiering",
    "premierna": "premium",
    "premiernas": "premium",
    "premiers": "premium",
    "premies": "premie",
    "premiet": "premium",
    "premiets": "premium",
    "premissen": "premiss",
    "premissens": "premiss",
    "premisser": "premiss",
    "premisserna": "premiss",
    "premissernas": "premiss",
    "premissers": "premiss",
    "premiumen": "premium",
    "premiumens": "premium",
    "premiums": "premium",
    "premiärbiljetten": "premiärbiljett",
    "premiärbiljettens": "premiärbiljett",
    "premiärbiljetter": "premiärbiljett",
    "premiärbiljetterna": "premiärbiljett",
    "premiärbiljetternas": "premiärbiljett",
    "premiärbiljetters": "premiärbiljett",
    "premiärbiljetts": "premiärbiljett",
    "premiären": "premiär",
    "premiärens": "premiär",
    "premiärer": "premiär",
    "premiärerna": "premiär",
    "premiärernas": "premiär",
    "premiärers": "premiär",
    "premiärfångsten": "premiärfångst",
    "premiärfångstens": "premiärfångst",
    "premiärfångster": "premiärfångst",
    "premiärfångsterna": "premiärfångst",
    "premiärfångsternas": "premiärfångst",
    "premiärfångsters": "premiärfångst",
    "premiärfångsts": "premiärfångst",
    "premiärkör": "premiärköra",
    "premiärkörande": "premiärköra",
    "premiärköranden": "premiärkörande",
    "premiärkörandena": "premiärkörande",
    "premiärkörandenas": "premiärkörande",
    "premiärkörandens": "premiärkörande",
    "premiärkörandes": "premiärkörande",
    "premiärkörandet": "premiärkörande",
    "premiärkörandets": "premiärkörande",
    "premiärköras": "premiärköra",
    "premiärkörd": "premiärköra",
    "premiärkörda": "premiärköra",
    "premiärkördas": "premiärköra",
    "premiärkörde": "premiärköra",
    "premiärkördes": "premiärköra",
    "premiärkörds": "premiärköra",
    "premiärköres": "premiärköra",
    "premiärkörs": "premiärköra",
    "premiärkört": "premiärköra",
    "premiärkörts": "premiärköra",
    "premiärministern": "premiärminister",
    "premiärministerns": "premiärminister",
    "premiärministerposten": "premiärministerpost",
    "premiärministerpostens": "premiärministerpost",
    "premiärministerposter": "premiärministerpost",
    "premiärministerposterna": "premiärministerpost",
    "premiärministerposternas": "premiärministerpost",
    "premiärministerposters": "premiärministerpost",
    "premiärministerposts": "premiärministerpost",
    "premiärministers": "premiärminister",
    "premiärministrar": "premiärminister",
    "premiärministrarna": "premiärminister",
    "premiärministrarnas": "premiärminister",
    "premiärministrars": "premiärminister",
    "premiärs": "premiär",
    "premiärtesten": "premiärtest",
    "premiärtestens": "premiärtest",
    "premiärtester": "premiärtest",
    "premiärtesterna": "premiärtest",
    "premiärtesternas": "premiärtest",
    "premiärtesters": "premiärtest",
    "premiärtestet": "premiärtest",
    "premiärtestets": "premiärtest",
    "premiärtests": "premiärtest",
    "premiärvisad": "premiärvisa",
    "premiärvisade": "premiärvisa",
    "premiärvisades": "premiärvisa",
    "premiärvisads": "premiärvisa",
    "premiärvisande": "premiärvisa",
    "premiärvisandes": "premiärvisa",
    "premiärvisar": "premiärvisa",
    "premiärvisas": "premiärvisa",
    "premiärvisat": "premiärvisa",
    "premiärvisats": "premiärvisa",
    "premolaren": "premolar",
    "premolarens": "premolar",
    "premolarer": "premolar",
    "premolarerna": "premolar",
    "premolarernas": "premolar",
    "premolarers": "premolar",
    "premolars": "premolar",
    "prenatala": "prenatal",
    "prenatalare": "prenatal",
    "prenatalares": "prenatal",
    "prenatalas": "prenatal",
    "prenatalast": "prenatal",
    "prenatalaste": "prenatal",
    "prenatalastes": "prenatal",
    "prenatalasts": "prenatal",
    "prenatale": "prenatal",
    "prenatales": "prenatal",
    "prenatals": "prenatal",
    "prenatalt": "prenatal",
    "prenatalts": "prenatal",
    "prenumeranten": "prenumerant",
    "prenumerantens": "prenumerant",
    "prenumeranter": "prenumerant",
    "prenumeranterna": "prenumerant",
    "prenumeranternas": "prenumerant",
    "prenumeranters": "prenumerant",
    "prenumerants": "prenumerant",
    "prenumerationen": "prenumeration",
    "prenumerationens": "prenumeration",
    "prenumerationer": "prenumeration",
    "prenumerationerna": "prenumeration",
    "prenumerationernas": "prenumeration",
    "prenumerationers": "prenumeration",
    "prenumerations": "prenumeration",
    "prenumererade": "prenumerera",
    "prenumererades": "prenumerera",
    "prenumererande": "prenumerera",
    "prenumereranden": "prenumererande",
    "prenumererandena": "prenumererande",
    "prenumererandenas": "prenumererande",
    "prenumererandens": "prenumererande",
    "prenumererandes": "prenumererande",
    "prenumererandet": "prenumererande",
    "prenumererandets": "prenumererande",
    "prenumererar": "prenumerera",
    "prenumereras": "prenumerera",
    "prenumererat": "prenumerera",
    "prenumererats": "prenumerera",
    "prenumereringar": "prenumerering",
    "prenumereringarna": "prenumerering",
    "prenumereringarnas": "prenumerering",
    "prenumereringars": "prenumerering",
    "prenumereringen": "prenumerering",
    "prenumereringens": "prenumerering",
    "prenumererings": "prenumerering",
    "preparanden": "preparand",
    "preparandens": "preparand",
    "preparander": "preparand",
    "preparanderna": "preparand",
    "preparandernas": "preparand",
    "preparanders": "preparand",
    "preparands": "preparand",
    "preparaten": "preparat",
    "preparatens": "preparat",
    "preparatet": "preparat",
    "preparatets": "preparat",
    "preparationen": "preparation",
    "preparationens": "preparation",
    "preparationer": "preparation",
    "preparationerna": "preparation",
    "preparationernas": "preparation",
    "preparationers": "preparation",
    "preparations": "preparation",
    "preparatorer": "preparator",
    "preparatorerna": "preparator",
    "preparatorernas": "preparator",
    "preparatorers": "preparator",
    "preparatorn": "preparator",
    "preparatorns": "preparator",
    "preparators": "preparator",
    "preparatrisen": "preparatris",
    "preparatrisens": "preparatris",
    "preparatriser": "preparatris",
    "preparatriserna": "preparatris",
    "preparatrisernas": "preparatris",
    "preparatrisers": "preparatris",
    "preparats": "preparat",
    "preparerad": "preparera",
    "preparerade": "preparera",
    "preparerades": "preparera",
    "preparerads": "preparera",
    "preparerande": "preparera",
    "prepareranden": "preparerande",
    "preparerandena": "preparerande",
    "preparerandenas": "preparerande",
    "preparerandens": "preparerande",
    "preparerandes": "preparerande",
    "preparerandet": "preparerande",
    "preparerandets": "preparerande",
    "preparerar": "preparera",
    "prepareras": "preparera",
    "preparerat": "preparera",
    "preparerats": "preparera",
    "preparerbara": "preparerbar",
    "preparerbarare": "preparerbar",
    "preparerbarares": "preparerbar",
    "preparerbaras": "preparerbar",
    "preparerbarast": "preparerbar",
    "preparerbaraste": "preparerbar",
    "preparerbarastes": "preparerbar",
    "preparerbarasts": "preparerbar",
    "preparerbare": "preparerbar",
    "preparerbares": "preparerbar",
    "preparerbarheten": "preparerbarhet",
    "preparerbarhetens": "preparerbarhet",
    "preparerbarhets": "preparerbarhet",
    "preparerbars": "preparerbar",
    "preparerbart": "preparerbar",
    "preparerbarts": "preparerbar",
    "prepareringar": "preparering",
    "prepareringarna": "preparering",
    "prepareringarnas": "preparering",
    "prepareringars": "preparering",
    "prepareringen": "preparering",
    "prepareringens": "preparering",
    "preparerings": "preparering",
    "prepositionella": "prepositionell",
    "prepositionellare": "prepositionell",
    "prepositionellares": "prepositionell",
    "prepositionellas": "prepositionell",
    "prepositionellast": "prepositionell",
    "prepositionellaste": "prepositionell",
    "prepositionellastes": "prepositionell",
    "prepositionellasts": "prepositionell",
    "prepositionelle": "prepositionell",
    "prepositionelles": "prepositionell",
    "prepositionells": "prepositionell",
    "prepositionellt": "prepositionell",
    "prepositionellts": "prepositionell",
    "prepositionen": "preposition",
    "prepositionens": "preposition",
    "prepositioner": "preposition",
    "prepositionerna": "preposition",
    "prepositionernas": "preposition",
    "prepositioners": "preposition",
    "prepositions": "preposition",
    "prepositionskasusen": "prepositionskasus",
    "prepositionskasusens": "prepositionskasus",
    "prepositionskasuset": "prepositionskasus",
    "prepositionskasusets": "prepositionskasus",
    "prepositionsuttrycken": "prepositionsuttryck",
    "prepositionsuttryckens": "prepositionsuttryck",
    "prepositionsuttrycket": "prepositionsuttryck",
    "prepositionsuttryckets": "prepositionsuttryck",
    "prepositionsuttrycks": "prepositionsuttryck",
    "prerogativen": "prerogativ",
    "prerogativens": "prerogativ",
    "prerogativet": "prerogativ",
    "prerogativets": "prerogativ",
    "prerogativs": "prerogativ",
    "presbyterer": "presbyter",
    "presbytererna": "presbyter",
    "presbyterernas": "presbyter",
    "presbyterers": "presbyter",
    "presbyterianen": "presbyterian",
    "presbyterianens": "presbyterian",
    "presbyterianer": "presbyterian",
    "presbyterianerna": "presbyterian",
    "presbyterianernas": "presbyterian",
    "presbyterianers": "presbyterian",
    "presbyterians": "presbyterian",
    "presbytern": "presbyter",
    "presbyterns": "presbyter",
    "presbyters": "presbyter",
    "presenningar": "presenning",
    "presenningarna": "presenning",
    "presenningarnas": "presenning",
    "presenningars": "presenning",
    "presenningen": "presenning",
    "presenningens": "presenning",
    "presennings": "presenning",
    "presensen": "presens",
    "presensens": "presens",
    "presenset": "presens",
    "presensets": "presens",
    "presensparticipen": "presensparticip",
    "presensparticipens": "presensparticip",
    "presensparticipet": "presensparticip",
    "presensparticipets": "presensparticip",
    "presensparticips": "presensparticip",
    "presenta": "present",
    "presentabels": "presentabel",
    "presentabelt": "presentabel",
    "presentabelts": "presentabel",
    "presentabla": "presentabel",
    "presentablare": "presentabel",
    "presentablares": "presentabel",
    "presentablas": "presentabel",
    "presentablast": "presentabel",
    "presentablaste": "presentabel",
    "presentablastes": "presentabel",
    "presentablasts": "presentabel",
    "presentable": "presentabel",
    "presentables": "presentabel",
    "presentad": "presenta",
    "presentade": "presenta",
    "presentades": "presenta",
    "presentads": "presenta",
    "presentande": "presenta",
    "presentanden": "presentande",
    "presentandena": "presentande",
    "presentandenas": "presentande",
    "presentandens": "presentande",
    "presentandes": "presentande",
    "presentandet": "presentande",
    "presentandets": "presentande",
    "presentar": "presenta",
    "presentare": "present",
    "presentares": "present",
    "presentas": "presenta",
    "presentaskar": "presentask",
    "presentaskarna": "presentask",
    "presentaskarnas": "presentask",
    "presentaskars": "presentask",
    "presentasken": "presentask",
    "presentaskens": "presentask",
    "presentasks": "presentask",
    "presentast": "present",
    "presentaste": "present",
    "presentastes": "present",
    "presentasts": "present",
    "presentat": "presenta",
    "presentationen": "presentation",
    "presentationens": "presentation",
    "presentationer": "presentation",
    "presentationerna": "presentation",
    "presentationernas": "presentation",
    "presentationers": "presentation",
    "presentations": "presentation",
    "presentats": "presenta",
    "presentatören": "presentatör",
    "presentatörens": "presentatör",
    "presentatörer": "presentatör",
    "presentatörerna": "presentatör",
    "presentatörernas": "presentatör",
    "presentatörers": "presentatör",
    "presentatörs": "presentatör",
    "presente": "present",
    "presenten": "present",
    "presentens": "present",
    "presenter": "present",
    "presenterad": "presentera",
    "presenterade": "presentera",
    "presenterades": "presentera",
    "presenterads": "presentera",
    "presenterande": "presentera",
    "presenteranden": "presenterande",
    "presenterandena": "presenterande",
    "presenterandenas": "presenterande",
    "presenterandens": "presenterande",
    "presenterandes": "presenterande",
    "presenterandet": "presenterande",
    "presenterandets": "presenterande",
    "presenterar": "presentera",
    "presenteras": "presentera",
    "presenterat": "presentera",
    "presenterats": "presentera",
    "presenterbara": "presenterbar",
    "presenterbarare": "presenterbar",
    "presenterbarares": "presenterbar",
    "presenterbaras": "presenterbar",
    "presenterbarast": "presenterbar",
    "presenterbaraste": "presenterbar",
    "presenterbarastes": "presenterbar",
    "presenterbarasts": "presenterbar",
    "presenterbare": "presenterbar",
    "presenterbares": "presenterbar",
    "presenterbarheten": "presenterbarhet",
    "presenterbarhetens": "presenterbarhet",
    "presenterbarhets": "presenterbarhet",
    "presenterbars": "presenterbar",
    "presenterbart": "presenterbar",
    "presenterbarts": "presenterbar",
    "presenterbrick": "presenterbricka",
    "presenterbrickan": "presenterbricka",
    "presenterbrickans": "presenterbricka",
    "presenterbrickas": "presenterbricka",
    "presenterbricke": "presenterbricka",
    "presenterbrickor": "presenterbricka",
    "presenterbrickorna": "presenterbricka",
    "presenterbrickornas": "presenterbricka",
    "presenterbrickors": "presenterbricka",
    "presenterbricks": "presenterbricka",
    "presenteringar": "presentering",
    "presenteringarna": "presentering",
    "presenteringarnas": "presentering",
    "presenteringars": "presentering",
    "presenteringen": "presentering",
    "presenteringens": "presentering",
    "presenterings": "presentering",
    "presenterna": "present",
    "presenternas": "present",
    "presenters": "present",
    "presentes": "present",
    "presentkorten": "presentkort",
    "presentkortens": "presentkort",
    "presentkortet": "presentkort",
    "presentkortets": "presentkort",
    "presentkorts": "presentkort",
    "presents": "present",
    "preservativen": "preservativ",
    "preservativens": "preservativ",
    "preservativet": "preservativ",
    "preservativets": "preservativ",
    "preservativs": "preservativ",
    "preserverad": "preservera",
    "preserverade": "preservera",
    "preserverades": "preservera",
    "preserverads": "preservera",
    "preserverande": "preservera",
    "preserveranden": "preserverande",
    "preserverandena": "preserverande",
    "preserverandenas": "preserverande",
    "preserverandens": "preserverande",
    "preserverandes": "preserverande",
    "preserverandet": "preserverande",
    "preserverandets": "preserverande",
    "preserverar": "preservera",
    "preserveras": "preservera",
    "preserverat": "preservera",
    "preserverats": "preservera",
    "preserverbara": "preserverbar",
    "preserverbarare": "preserverbar",
    "preserverbarares": "preserverbar",
    "preserverbaras": "preserverbar",
    "preserverbarast": "preserverbar",
    "preserverbaraste": "preserverbar",
    "preserverbarastes": "preserverbar",
    "preserverbarasts": "preserverbar",
    "preserverbare": "preserverbar",
    "preserverbares": "preserverbar",
    "preserverbarheten": "preserverbarhet",
    "preserverbarhetens": "preserverbarhet",
    "preserverbarhets": "preserverbarhet",
    "preserverbars": "preserverbar",
    "preserverbart": "preserverbar",
    "preserverbarts": "preserverbar",
    "preserveringar": "preservering",
    "preserveringarna": "preservering",
    "preserveringarnas": "preservering",
    "preserveringars": "preservering",
    "preserveringen": "preservering",
    "preserveringens": "preservering",
    "preserverings": "preservering",
    "presesar": "preses",
    "presesarna": "preses",
    "presesarnas": "preses",
    "presesars": "preses",
    "presidentbostaden": "presidentbostad",
    "presidentbostadens": "presidentbostad",
    "presidentbostads": "presidentbostad",
    "presidentbostan": "presidentbostad",
    "presidentbostans": "presidentbostad",
    "presidentbostäder": "presidentbostad",
    "presidentbostäderna": "presidentbostad",
    "presidentbostädernas": "presidentbostad",
    "presidentbostäders": "presidentbostad",
    "presidenten": "president",
    "presidentens": "president",
    "presidenter": "president",
    "presidenterna": "president",
    "presidenternas": "president",
    "presidenters": "president",
    "presidenthustrun": "presidenthustru",
    "presidenthustruns": "presidenthustru",
    "presidenthustrur": "presidenthustru",
    "presidenthustrurna": "presidenthustru",
    "presidenthustrurnas": "presidenthustru",
    "presidenthustrurs": "presidenthustru",
    "presidenthustrus": "presidenthustru",
    "presidentmässiga": "presidentmässig",
    "presidentmässigare": "presidentmässig",
    "presidentmässigares": "presidentmässig",
    "presidentmässigas": "presidentmässig",
    "presidentmässigast": "presidentmässig",
    "presidentmässigaste": "presidentmässig",
    "presidentmässigastes": "presidentmässig",
    "presidentmässigasts": "presidentmässig",
    "presidentmässige": "presidentmässig",
    "presidentmässiges": "presidentmässig",
    "presidentmässigs": "presidentmässig",
    "presidentmässigt": "presidentmässig",
    "presidentmässigts": "presidentmässig",
    "presidents": "president",
    "presidentskapen": "presidentskap",
    "presidentskapens": "presidentskap",
    "presidentskapet": "presidentskap",
    "presidentskapets": "presidentskap",
    "presidentskaps": "presidentskap",
    "presidentstyren": "presidentstyre",
    "presidentstyrena": "presidentstyre",
    "presidentstyrenas": "presidentstyre",
    "presidentstyrens": "presidentstyre",
    "presidentstyres": "presidentstyre",
    "presidentstyret": "presidentstyre",
    "presidentstyrets": "presidentstyre",
    "presidenturen": "presidentur",
    "presidenturens": "presidentur",
    "presidenturer": "presidentur",
    "presidenturerna": "presidentur",
    "presidenturernas": "presidentur",
    "presidenturers": "presidentur",
    "presidenturs": "presidentur",
    "presidentvalen": "presidentval",
    "presidentvalens": "presidentval",
    "presidentvalet": "presidentval",
    "presidentvalets": "presidentval",
    "presidentvals": "presidentval",
    "presiderade": "presidera",
    "presiderades": "presidera",
    "presiderande": "presidera",
    "presideranden": "presiderande",
    "presiderandena": "presiderande",
    "presiderandenas": "presiderande",
    "presiderandens": "presiderande",
    "presiderandes": "presiderande",
    "presiderandet": "presiderande",
    "presiderandets": "presiderande",
    "presiderar": "presidera",
    "presideras": "presidera",
    "presiderat": "presidera",
    "presiderats": "presidera",
    "presideringar": "presidering",
    "presideringarna": "presidering",
    "presideringarnas": "presidering",
    "presideringars": "presidering",
    "presideringen": "presidering",
    "presideringens": "presidering",
    "presiderings": "presidering",
    "presides": "preses",
    "presidie": "presidium",
    "presidier": "presidium",
    "presidierna": "presidium",
    "presidiernas": "presidium",
    "presidiers": "presidium",
    "presidiet": "presidium",
    "presidiets": "presidium",
    "presidiums": "presidium",
    "preskriberad": "preskribera",
    "preskriberade": "preskribera",
    "preskriberades": "preskribera",
    "preskriberads": "preskribera",
    "preskriberande": "preskribera",
    "preskriberanden": "preskriberande",
    "preskriberandena": "preskriberande",
    "preskriberandenas": "preskriberande",
    "preskriberandens": "preskriberande",
    "preskriberandes": "preskriberande",
    "preskriberandet": "preskriberande",
    "preskriberandets": "preskriberande",
    "preskriberar": "preskribera",
    "preskriberas": "preskribera",
    "preskriberat": "preskribera",
    "preskriberats": "preskribera",
    "preskriberbara": "preskriberbar",
    "preskriberbarare": "preskriberbar",
    "preskriberbarares": "preskriberbar",
    "preskriberbaras": "preskriberbar",
    "preskriberbarast": "preskriberbar",
    "preskriberbaraste": "preskriberbar",
    "preskriberbarastes": "preskriberbar",
    "preskriberbarasts": "preskriberbar",
    "preskriberbare": "preskriberbar",
    "preskriberbares": "preskriberbar",
    "preskriberbarheten": "preskriberbarhet",
    "preskriberbarhetens": "preskriberbarhet",
    "preskriberbarhets": "preskriberbarhet",
    "preskriberbars": "preskriberbar",
    "preskriberbart": "preskriberbar",
    "preskriberbarts": "preskriberbar",
    "preskriberingar": "preskribering",
    "preskriberingarna": "preskribering",
    "preskriberingarnas": "preskribering",
    "preskriberingars": "preskribering",
    "preskriberingen": "preskribering",
    "preskriberingens": "preskribering",
    "preskriberings": "preskribering",
    "preskriptionen": "preskription",
    "preskriptionens": "preskription",
    "preskriptioner": "preskription",
    "preskriptionerna": "preskription",
    "preskriptionernas": "preskription",
    "preskriptioners": "preskription",
    "preskriptions": "preskription",
    "preskriptionstiden": "preskriptionstid",
    "preskriptionstidens": "preskriptionstid",
    "preskriptionstider": "preskriptionstid",
    "preskriptionstiderna": "preskriptionstid",
    "preskriptionstidernas": "preskriptionstid",
    "preskriptionstiders": "preskriptionstid",
    "preskriptionstids": "preskriptionstid",
    "presnsen": "presens",
    "presnsens": "presens",
    "presnset": "presens",
    "presnsets": "presens",
    "press": "pressa",
    "pressad": "pressa",
    "pressade": "pressa",
    "pressades": "pressa",
    "pressads": "pressa",
    "pressande": "pressa",
    "pressanden": "pressande",
    "pressandena": "pressande",
    "pressandenas": "pressande",
    "pressandens": "pressande",
    "pressandes": "pressande",
    "pressandet": "pressande",
    "pressandets": "pressande",
    "pressar": "pressare",
    "pressaren": "pressare",
    "pressarens": "pressare",
    "pressares": "pressare",
    "pressarna": "pressare",
    "pressarnas": "pressare",
    "pressars": "press",
    "pressas": "pressa",
    "pressat": "pressa",
    "pressats": "pressa",
    "presschefen": "presschef",
    "presschefens": "presschef",
    "presschefer": "presschef",
    "presscheferna": "presschef",
    "presschefernas": "presschef",
    "presschefers": "presschef",
    "presschefs": "presschef",
    "pressdetaljen": "pressdetalj",
    "pressdetaljens": "pressdetalj",
    "pressdetaljs": "pressdetalj",
    "pressen": "press",
    "pressens": "press",
    "presserier": "presseri",
    "presserierna": "presseri",
    "presseriernas": "presseri",
    "presseriers": "presseri",
    "presseriet": "presseri",
    "presseriets": "presseri",
    "presseris": "presseri",
    "presserit": "presseri",
    "presserits": "presseri",
    "pressfoders": "pressfoder",
    "pressfodret": "pressfoder",
    "pressfodrets": "pressfoder",
    "pressfotografen": "pressfotograf",
    "pressfotografens": "pressfotograf",
    "pressfotografer": "pressfotograf",
    "pressfotograferna": "pressfotograf",
    "pressfotografernas": "pressfotograf",
    "pressfotografers": "pressfotograf",
    "pressfotografs": "pressfotograf",
    "pressglaset": "pressglas",
    "pressglasets": "pressglas",
    "pressgrann": "pressgranne",
    "pressgrannar": "pressgranne",
    "pressgrannarna": "pressgranne",
    "pressgrannarnas": "pressgranne",
    "pressgrannars": "pressgranne",
    "pressgrannen": "pressgranne",
    "pressgrannens": "pressgranne",
    "pressgrannes": "pressgranne",
    "pressgranns": "pressgranne",
    "pressgurk": "pressgurka",
    "pressgurkan": "pressgurka",
    "pressgurkans": "pressgurka",
    "pressgurkas": "pressgurka",
    "pressgurke": "pressgurka",
    "pressgurkor": "pressgurka",
    "pressgurkorna": "pressgurka",
    "pressgurkornas": "pressgurka",
    "pressgurkors": "pressgurka",
    "pressgurks": "pressgurka",
    "pressgängen": "pressgäng",
    "pressgängens": "pressgäng",
    "pressgänget": "pressgäng",
    "pressgängets": "pressgäng",
    "pressgängs": "pressgäng",
    "pressionen": "pression",
    "pressionens": "pression",
    "pressioner": "pression",
    "pressionerna": "pression",
    "pressionernas": "pression",
    "pressioners": "pression",
    "pressions": "pression",
    "pressjärnen": "pressjärn",
    "pressjärnens": "pressjärn",
    "pressjärnet": "pressjärn",
    "pressjärnets": "pressjärn",
    "pressjärns": "pressjärn",
    "presskommissarien": "presskommissarie",
    "presskommissariens": "presskommissarie",
    "presskommissarier": "presskommissarie",
    "presskommissarierna": "presskommissarie",
    "presskommissariernas": "presskommissarie",
    "presskommissariers": "presskommissarie",
    "presskommissaries": "presskommissarie",
    "presskonferensen": "presskonferens",
    "presskonferensens": "presskonferens",
    "presskonferenser": "presskonferens",
    "presskonferenserna": "presskonferens",
    "presskonferensernas": "presskonferens",
    "presskonferensers": "presskonferens",
    "presskorten": "presskort",
    "presskortens": "presskort",
    "presskortet": "presskort",
    "presskortets": "presskort",
    "presskorts": "presskort",
    "pressla": "presslägga",
    "presslade": "presslägga",
    "presslades": "presslägga",
    "presslagd": "presslägga",
    "presslagda": "presslägga",
    "presslagdas": "presslägga",
    "presslagde": "presslägga",
    "presslagdes": "presslägga",
    "presslagds": "presslägga",
    "presslagt": "presslägga",
    "presslagts": "presslägga",
    "presslas": "presslägga",
    "presslägg": "presslägga",
    "pressläggande": "presslägga",
    "presslägganden": "pressläggande",
    "pressläggandena": "pressläggande",
    "pressläggandenas": "pressläggande",
    "pressläggandens": "pressläggande",
    "pressläggandes": "pressläggande",
    "pressläggandet": "pressläggande",
    "pressläggandets": "pressläggande",
    "pressläggas": "presslägga",
    "presslägger": "presslägga",
    "presslägges": "presslägga",
    "pressläggningar": "pressläggning",
    "pressläggningarna": "pressläggning",
    "pressläggningarnas": "pressläggning",
    "pressläggningars": "pressläggning",
    "pressläggningen": "pressläggning",
    "pressläggningens": "pressläggning",
    "pressläggnings": "pressläggning",
    "pressläggs": "presslägga",
    "pressläktar": "pressläktare",
    "pressläktaren": "pressläktare",
    "pressläktarens": "pressläktare",
    "pressläktares": "pressläktare",
    "pressläktarna": "pressläktare",
    "pressläktarnas": "pressläktare",
    "pressmaskinen": "pressmaskin",
    "pressmaskinens": "pressmaskin",
    "pressmaskiner": "pressmaskin",
    "pressmaskinerna": "pressmaskin",
    "pressmaskinernas": "pressmaskin",
    "pressmaskiners": "pressmaskin",
    "pressmaskins": "pressmaskin",
    "pressmeddelanden": "pressmeddelande",
    "pressmeddelandena": "pressmeddelande",
    "pressmeddelandenas": "pressmeddelande",
    "pressmeddelandens": "pressmeddelande",
    "pressmeddelandes": "pressmeddelande",
    "pressmeddelandet": "pressmeddelande",
    "pressmeddelandets": "pressmeddelande",
    "pressmottagningar": "pressmottagning",
    "pressmottagningarna": "pressmottagning",
    "pressmottagningarnas": "pressmottagning",
    "pressmottagningars": "pressmottagning",
    "pressmottagningen": "pressmottagning",
    "pressmottagningens": "pressmottagning",
    "pressmottagnings": "pressmottagning",
    "pressmöten": "pressmöte",
    "pressmötena": "pressmöte",
    "pressmötenas": "pressmöte",
    "pressmötens": "pressmöte",
    "pressmötes": "pressmöte",
    "pressmötet": "pressmöte",
    "pressmötets": "pressmöte",
    "pressningar": "pressning",
    "pressningarna": "pressning",
    "pressningarnas": "pressning",
    "pressningars": "pressning",
    "pressningen": "pressning",
    "pressningens": "pressning",
    "pressnings": "pressning",
    "pressorganen": "pressorgan",
    "pressorganens": "pressorgan",
    "pressorganet": "pressorgan",
    "pressorganets": "pressorgan",
    "pressorgans": "pressorgan",
    "presspanen": "presspan",
    "presspanens": "presspan",
    "presspans": "presspan",
    "pressreleasen": "pressrelease",
    "pressreleasens": "pressrelease",
    "pressreleaser": "pressrelease",
    "pressreleaserna": "pressrelease",
    "pressreleasernas": "pressrelease",
    "pressreleasers": "pressrelease",
    "pressreleases": "pressrelease",
    "pressrevideren": "pressrevider",
    "pressreviderens": "pressrevider",
    "pressrevideret": "pressrevider",
    "pressreviderets": "pressrevider",
    "pressreviders": "pressrevider",
    "presstalesmannen": "presstalesman",
    "presstalesmannens": "presstalesman",
    "presstalesmans": "presstalesman",
    "presstalesmän": "presstalesman",
    "presstalesmännen": "presstalesman",
    "presstalesmännens": "presstalesman",
    "presstalesmäns": "presstalesman",
    "presstoppen": "presstopp",
    "presstoppens": "presstopp",
    "presstoppet": "presstopp",
    "presstoppets": "presstopp",
    "presstopps": "presstopp",
    "pressträffar": "pressträff",
    "pressträffarna": "pressträff",
    "pressträffarnas": "pressträff",
    "pressträffars": "pressträff",
    "pressträffen": "pressträff",
    "pressträffens": "pressträff",
    "pressträffs": "pressträff",
    "presstödet": "presstöd",
    "presstödets": "presstöd",
    "presstöds": "presstöd",
    "presstödsregeln": "presstödsregel",
    "presstödsregelns": "presstödsregel",
    "presstödsregels": "presstödsregel",
    "presstödsregler": "presstödsregel",
    "presstödsreglerna": "presstödsregel",
    "presstödsreglernas": "presstödsregel",
    "presstödsreglers": "presstödsregel",
    "pressvecken": "pressveck",
    "pressveckens": "pressveck",
    "pressvecket": "pressveck",
    "pressveckets": "pressveck",
    "pressvecks": "pressveck",
    "pressylt": "pressylta",
    "pressyltan": "pressylta",
    "pressyltans": "pressylta",
    "pressyltas": "pressylta",
    "pressylte": "pressylta",
    "pressyltor": "pressylta",
    "pressyltorna": "pressylta",
    "pressyltornas": "pressylta",
    "pressyltors": "pressylta",
    "pressylts": "pressylta",
    "prestandamässiga": "prestandamässig",
    "prestandamässigare": "prestandamässig",
    "prestandamässigares": "prestandamässig",
    "prestandamässigas": "prestandamässig",
    "prestandamässigast": "prestandamässig",
    "prestandamässigaste": "prestandamässig",
    "prestandamässigastes": "prestandamässig",
    "prestandamässigasts": "prestandamässig",
    "prestandamässige": "prestandamässig",
    "prestandamässiges": "prestandamässig",
    "prestandamässigs": "prestandamässig",
    "prestandamässigt": "prestandamässig",
    "prestandamässigts": "prestandamässig",
    "prestandan": "prestanda",
    "prestandana": "prestanda",
    "prestandanas": "prestanda",
    "prestandans": "prestanda",
    "prestandas": "prestanda",
    "prestandat": "prestanda",
    "prestandats": "prestanda",
    "prestationen": "prestation",
    "prestationens": "prestation",
    "prestationer": "prestation",
    "prestationerna": "prestation",
    "prestationernas": "prestation",
    "prestationers": "prestation",
    "prestations": "prestation",
    "prestationsångesten": "prestationsångest",
    "prestationsångestens": "prestationsångest",
    "prestationsångests": "prestationsångest",
    "prestaven": "prestav",
    "prestavens": "prestav",
    "prestaver": "prestav",
    "prestaverade": "prestavera",
    "prestaverades": "prestavera",
    "prestaverande": "prestavera",
    "prestaveranden": "prestaverande",
    "prestaverandena": "prestaverande",
    "prestaverandenas": "prestaverande",
    "prestaverandens": "prestaverande",
    "prestaverandes": "prestaverande",
    "prestaverandet": "prestaverande",
    "prestaverandets": "prestaverande",
    "prestaverar": "prestavera",
    "prestaveras": "prestavera",
    "prestaverat": "prestavera",
    "prestaverats": "prestavera",
    "prestaveringar": "prestavering",
    "prestaveringarna": "prestavering",
    "prestaveringarnas": "prestavering",
    "prestaveringars": "prestavering",
    "prestaveringen": "prestavering",
    "prestaveringens": "prestavering",
    "prestaverings": "prestavering",
    "prestaverna": "prestav",
    "prestavernas": "prestav",
    "prestavers": "prestav",
    "prestavs": "prestav",
    "presterad": "prestera",
    "presterade": "prestera",
    "presterades": "prestera",
    "presterads": "prestera",
    "presterande": "prestera",
    "presteranden": "presterande",
    "presterandena": "presterande",
    "presterandenas": "presterande",
    "presterandens": "presterande",
    "presterandes": "presterande",
    "presterandet": "presterande",
    "presterandets": "presterande",
    "presterar": "prestera",
    "presteras": "prestera",
    "presterat": "prestera",
    "presterats": "prestera",
    "presterbara": "presterbar",
    "presterbarare": "presterbar",
    "presterbarares": "presterbar",
    "presterbaras": "presterbar",
    "presterbarast": "presterbar",
    "presterbaraste": "presterbar",
    "presterbarastes": "presterbar",
    "presterbarasts": "presterbar",
    "presterbare": "presterbar",
    "presterbares": "presterbar",
    "presterbarheten": "presterbarhet",
    "presterbarhetens": "presterbarhet",
    "presterbarhets": "presterbarhet",
    "presterbars": "presterbar",
    "presterbart": "presterbar",
    "presterbarts": "presterbar",
    "presteringar": "prestering",
    "presteringarna": "prestering",
    "presteringarnas": "prestering",
    "presteringars": "prestering",
    "presteringen": "prestering",
    "presteringens": "prestering",
    "presterings": "prestering",
    "prestigefyllda": "prestigefylld",
    "prestigefylldare": "prestigefylld",
    "prestigefylldares": "prestigefylld",
    "prestigefylldas": "prestigefylld",
    "prestigefylldast": "prestigefylld",
    "prestigefylldaste": "prestigefylld",
    "prestigefylldastes": "prestigefylld",
    "prestigefylldasts": "prestigefylld",
    "prestigefyllde": "prestigefylld",
    "prestigefylldes": "prestigefylld",
    "prestigefylldheten": "prestigefylldhet",
    "prestigefylldhetens": "prestigefylldhet",
    "prestigefylldhets": "prestigefylldhet",
    "prestigefyllds": "prestigefylld",
    "prestigefyllt": "prestigefylld",
    "prestigefyllts": "prestigefylld",
    "prestigemässiga": "prestigemässig",
    "prestigemässigare": "prestigemässig",
    "prestigemässigares": "prestigemässig",
    "prestigemässigas": "prestigemässig",
    "prestigemässigast": "prestigemässig",
    "prestigemässigaste": "prestigemässig",
    "prestigemässigastes": "prestigemässig",
    "prestigemässigasts": "prestigemässig",
    "prestigemässige": "prestigemässig",
    "prestigemässiges": "prestigemässig",
    "prestigemässigs": "prestigemässig",
    "prestigemässigt": "prestigemässig",
    "prestigemässigts": "prestigemässig",
    "prestigen": "prestige",
    "prestigens": "prestige",
    "prestiges": "prestige",
    "prestigeuppdragen": "prestigeuppdrag",
    "prestigeuppdragens": "prestigeuppdrag",
    "prestigeuppdraget": "prestigeuppdrag",
    "prestigeuppdragets": "prestigeuppdrag",
    "prestigeuppdrags": "prestigeuppdrag",
    "preston": "presto",
    "prestona": "presto",
    "prestonas": "presto",
    "prestons": "presto",
    "prestos": "presto",
    "prestot": "presto",
    "prestots": "presto",
    "presumerad": "presumera",
    "presumerade": "presumera",
    "presumerades": "presumera",
    "presumerads": "presumera",
    "presumerande": "presumera",
    "presumeranden": "presumerande",
    "presumerandena": "presumerande",
    "presumerandenas": "presumerande",
    "presumerandens": "presumerande",
    "presumerandes": "presumerande",
    "presumerandet": "presumerande",
    "presumerandets": "presumerande",
    "presumerar": "presumera",
    "presumeras": "presumera",
    "presumerat": "presumera",
    "presumerats": "presumera",
    "presumerbara": "presumerbar",
    "presumerbarare": "presumerbar",
    "presumerbarares": "presumerbar",
    "presumerbaras": "presumerbar",
    "presumerbarast": "presumerbar",
    "presumerbaraste": "presumerbar",
    "presumerbarastes": "presumerbar",
    "presumerbarasts": "presumerbar",
    "presumerbare": "presumerbar",
    "presumerbares": "presumerbar",
    "presumerbarheten": "presumerbarhet",
    "presumerbarhetens": "presumerbarhet",
    "presumerbarhets": "presumerbarhet",
    "presumerbars": "presumerbar",
    "presumerbart": "presumerbar",
    "presumerbarts": "presumerbar",
    "presumeringar": "presumering",
    "presumeringarna": "presumering",
    "presumeringarnas": "presumering",
    "presumeringars": "presumering",
    "presumeringen": "presumering",
    "presumeringens": "presumering",
    "presumerings": "presumering",
    "presumtiva": "presumtiv",
    "presumtivare": "presumtiv",
    "presumtivares": "presumtiv",
    "presumtivas": "presumtiv",
    "presumtivast": "presumtiv",
    "presumtivaste": "presumtiv",
    "presumtivastes": "presumtiv",
    "presumtivasts": "presumtiv",
    "presumtive": "presumtiv",
    "presumtives": "presumtiv",
    "presumtivs": "presumtiv",
    "presumtivt": "presumtiv",
    "presumtivts": "presumtiv",
    "pretendenten": "pretendent",
    "pretendentens": "pretendent",
    "pretendenter": "pretendent",
    "pretendenterna": "pretendent",
    "pretendenternas": "pretendent",
    "pretendenters": "pretendent",
    "pretendents": "pretendent",
    "pretenderade": "pretendera",
    "pretenderades": "pretendera",
    "pretenderande": "pretendera",
    "pretenderanden": "pretenderande",
    "pretenderandena": "pretenderande",
    "pretenderandenas": "pretenderande",
    "pretenderandens": "pretenderande",
    "pretenderandes": "pretenderande",
    "pretenderandet": "pretenderande",
    "pretenderandets": "pretenderande",
    "pretenderar": "pretendera",
    "pretenderas": "pretendera",
    "pretenderat": "pretendera",
    "pretenderats": "pretendera",
    "pretenderingar": "pretendering",
    "pretenderingarna": "pretendering",
    "pretenderingarnas": "pretendering",
    "pretenderingars": "pretendering",
    "pretenderingen": "pretendering",
    "pretenderingens": "pretendering",
    "pretenderings": "pretendering",
    "pretentionen": "pretention",
    "pretentionens": "pretention",
    "pretentioner": "pretention",
    "pretentionerna": "pretention",
    "pretentionernas": "pretention",
    "pretentioners": "pretention",
    "pretentions": "pretention",
    "pretentiösa": "pretentiös",
    "pretentiösare": "pretentiös",
    "pretentiösares": "pretentiös",
    "pretentiösas": "pretentiös",
    "pretentiösast": "pretentiös",
    "pretentiösaste": "pretentiös",
    "pretentiösastes": "pretentiös",
    "pretentiösasts": "pretentiös",
    "pretentiöse": "pretentiös",
    "pretentiöses": "pretentiös",
    "pretentiöst": "pretentiös",
    "pretentiösts": "pretentiös",
    "preteriter": "preteritum",
    "preteriterna": "preteritum",
    "preteriternas": "preteritum",
    "preteriters": "preteritum",
    "preteritumet": "preteritum",
    "preteritumets": "preteritum",
    "preteritums": "preteritum",
    "pretexten": "pretext",
    "pretextens": "pretext",
    "pretexter": "pretext",
    "pretexterna": "pretext",
    "pretexternas": "pretext",
    "pretexters": "pretext",
    "pretexts": "pretext",
    "pretiosan": "pretiosa",
    "pretiosana": "pretiosa",
    "pretiosanas": "pretiosa",
    "pretiosans": "pretiosa",
    "pretiosas": "pretiosa",
    "pretiosat": "pretiosa",
    "pretiosats": "pretiosa",
    "pretiositeten": "pretiositet",
    "pretiositetens": "pretiositet",
    "pretiositeter": "pretiositet",
    "pretiositeterna": "pretiositet",
    "pretiositeternas": "pretiositet",
    "pretiositeters": "pretiositet",
    "pretiositets": "pretiositet",
    "pretiösa": "pretiös",
    "pretiösare": "pretiös",
    "pretiösares": "pretiös",
    "pretiösas": "pretiös",
    "pretiösast": "pretiös",
    "pretiösaste": "pretiös",
    "pretiösastes": "pretiös",
    "pretiösasts": "pretiös",
    "pretiöse": "pretiös",
    "pretiöses": "pretiös",
    "pretiöst": "pretiös",
    "pretiösts": "pretiös",
    "pretorer": "pretor",
    "pretorerna": "pretor",
    "pretorernas": "pretor",
    "pretorers": "pretor",
    "pretorianen": "pretorian",
    "pretorianens": "pretorian",
    "pretorianer": "pretorian",
    "pretorianerna": "pretorian",
    "pretorianernas": "pretorian",
    "pretorianers": "pretorian",
    "pretorians": "pretorian",
    "pretorn": "pretor",
    "pretorns": "pretor",
    "pretors": "pretor",
    "pretton": "pretto",
    "prettona": "pretto",
    "prettonas": "pretto",
    "prettons": "pretto",
    "prettos": "pretto",
    "prettot": "pretto",
    "prettots": "pretto",
    "preussar": "preussare",
    "preussaren": "preussare",
    "preussarens": "preussare",
    "preussares": "preussare",
    "preussarna": "preussare",
    "preussarnas": "preussare",
    "preusseriet": "preusseri",
    "preusseriets": "preusseri",
    "preusseris": "preusseri",
    "preusserit": "preusseri",
    "preusserits": "preusseri",
    "preussiska": "preussisk",
    "preussiskare": "preussisk",
    "preussiskares": "preussisk",
    "preussiskas": "preussisk",
    "preussiskast": "preussisk",
    "preussiskaste": "preussisk",
    "preussiskastes": "preussisk",
    "preussiskasts": "preussisk",
    "preussiske": "preussisk",
    "preussiskes": "preussisk",
    "preussisks": "preussisk",
    "preussiskt": "preussisk",
    "preussiskts": "preussisk",
    "preventiva": "preventiv",
    "preventivare": "preventiv",
    "preventivares": "preventiv",
    "preventivas": "preventiv",
    "preventivast": "preventiv",
    "preventivaste": "preventiv",
    "preventivastes": "preventiv",
    "preventivasts": "preventiv",
    "preventive": "preventiv",
    "preventives": "preventiv",
    "preventivkrigen": "preventivkrig",
    "preventivkrigens": "preventivkrig",
    "preventivkriget": "preventivkrig",
    "preventivkrigets": "preventivkrig",
    "preventivkrigs": "preventivkrig",
    "preventivmedels": "preventivmedel",
    "preventivmedlen": "preventivmedel",
    "preventivmedlens": "preventivmedel",
    "preventivmedlet": "preventivmedel",
    "preventivmedlets": "preventivmedel",
    "preventivpillerna": "preventivpiller",
    "preventivpillernas": "preventivpiller",
    "preventivpillers": "preventivpiller",
    "preventivpillren": "preventivpiller",
    "preventivpillrens": "preventivpiller",
    "preventivpillret": "preventivpiller",
    "preventivpillrets": "preventivpiller",
    "preventivs": "preventiv",
    "preventivt": "preventiv",
    "preventivts": "preventiv",
    "prick": "pricka",
    "prickad": "pricka",
    "prickade": "pricka",
    "prickades": "pricka",
    "prickads": "pricka",
    "prickande": "pricka",
    "prickanden": "prickande",
    "prickandena": "prickande",
    "prickandenas": "prickande",
    "prickandens": "prickande",
    "prickandes": "prickande",
    "prickandet": "prickande",
    "prickandets": "prickande",
    "prickar": "prickare",
    "prickaren": "prickare",
    "prickarens": "prickare",
    "prickares": "prickare",
    "prickarna": "prickare",
    "prickarnas": "prickare",
    "prickars": "prick",
    "prickas": "pricka",
    "prickat": "pricka",
    "prickats": "pricka",
    "pricken": "prick",
    "prickens": "prick",
    "prickfria": "prickfri",
    "prickfriare": "prickfri",
    "prickfriares": "prickfri",
    "prickfrias": "prickfri",
    "prickfriast": "prickfri",
    "prickfriaste": "prickfri",
    "prickfriastes": "prickfri",
    "prickfriasts": "prickfri",
    "prickfrie": "prickfri",
    "prickfries": "prickfri",
    "prickfris": "prickfri",
    "prickfritt": "prickfri",
    "prickfritts": "prickfri",
    "prickiga": "prickig",
    "prickigare": "prickig",
    "prickigares": "prickig",
    "prickigas": "prickig",
    "prickigast": "prickig",
    "prickigaste": "prickig",
    "prickigastes": "prickig",
    "prickigasts": "prickig",
    "prickige": "prickig",
    "prickiges": "prickig",
    "prickigheten": "prickighet",
    "prickighetens": "prickighet",
    "prickighets": "prickighet",
    "prickigs": "prickig",
    "prickigt": "prickig",
    "prickigts": "prickig",
    "pricks": "prick",
    "prickskyttar": "prickskytt",
    "prickskyttarna": "prickskytt",
    "prickskyttarnas": "prickskytt",
    "prickskyttars": "prickskytt",
    "prickskytten": "prickskytt",
    "prickskyttens": "prickskytt",
    "prickskyttes": "prickskytte",
    "prickskyttet": "prickskytte",
    "prickskyttets": "prickskytte",
    "prickskytts": "prickskytt",
    "pricksäkerheten": "pricksäkerhet",
    "pricksäkerhetens": "pricksäkerhet",
    "pricksäkerhets": "pricksäkerhet",
    "pricksäkers": "pricksäker",
    "pricksäkert": "pricksäker",
    "pricksäkerts": "pricksäker",
    "pricksäkra": "pricksäker",
    "pricksäkrare": "pricksäker",
    "pricksäkrares": "pricksäker",
    "pricksäkras": "pricksäker",
    "pricksäkrast": "pricksäker",
    "pricksäkraste": "pricksäker",
    "pricksäkrastes": "pricksäker",
    "pricksäkrasts": "pricksäker",
    "pricksäkre": "pricksäker",
    "pricksäkres": "pricksäker",
    "priffen": "priffe",
    "priffens": "priffe",
    "priffes": "priffe",
    "prill": "prilla",
    "prillan": "prilla",
    "prillans": "prilla",
    "prillas": "prilla",
    "prille": "prilla",
    "prilliga": "prillig",
    "prilligare": "prillig",
    "prilligares": "prillig",
    "prilligas": "prillig",
    "prilligast": "prillig",
    "prilligaste": "prillig",
    "prilligastes": "prillig",
    "prilligasts": "prillig",
    "prillige": "prillig",
    "prilliges": "prillig",
    "prilligheten": "prillighet",
    "prillighetens": "prillighet",
    "prilligheter": "prillighet",
    "prilligheterna": "prillighet",
    "prilligheternas": "prillighet",
    "prilligheters": "prillighet",
    "prillighets": "prillighet",
    "prilligs": "prillig",
    "prilligt": "prillig",
    "prilligts": "prillig",
    "prillor": "prilla",
    "prillorna": "prilla",
    "prillornas": "prilla",
    "prillors": "prilla",
    "prills": "prilla",
    "primadonn": "primadonna",
    "primadonnan": "primadonna",
    "primadonnans": "primadonna",
    "primadonnas": "primadonna",
    "primadonne": "primadonna",
    "primadonnor": "primadonna",
    "primadonnorna": "primadonna",
    "primadonnornas": "primadonna",
    "primadonnors": "primadonna",
    "primadonns": "primadonna",
    "primalskriken": "primalskrik",
    "primalskrikens": "primalskrik",
    "primalskriket": "primalskrik",
    "primalskrikets": "primalskrik",
    "primalskriks": "primalskrik",
    "primalterapien": "primalterapi",
    "primalterapiens": "primalterapi",
    "primalterapin": "primalterapi",
    "primalterapins": "primalterapi",
    "primalterapis": "primalterapi",
    "primarien": "primarie",
    "primariens": "primarie",
    "primarier": "primarie",
    "primarierna": "primarie",
    "primariernas": "primarie",
    "primariers": "primarie",
    "primaries": "primarie",
    "primaten": "primat",
    "primatens": "primat",
    "primater": "primat",
    "primaterna": "primat",
    "primaternas": "primat",
    "primaters": "primat",
    "primatet": "primat",
    "primatets": "primat",
    "primats": "primat",
    "primen": "prim",
    "primens": "prim",
    "primer": "prim",
    "primern": "primer",
    "primerna": "prim",
    "primernas": "prim",
    "primerns": "primer",
    "primers": "primer",
    "primfaktorer": "primfaktor",
    "primfaktorerna": "primfaktor",
    "primfaktorernas": "primfaktor",
    "primfaktorers": "primfaktor",
    "primfaktorn": "primfaktor",
    "primfaktorns": "primfaktor",
    "primfaktors": "primfaktor",
    "primitiva": "primitiv",
    "primitivare": "primitiv",
    "primitivares": "primitiv",
    "primitivas": "primitiv",
    "primitivast": "primitiv",
    "primitivaste": "primitiv",
    "primitivastes": "primitiv",
    "primitivasts": "primitiv",
    "primitive": "primitiv",
    "primitives": "primitiv",
    "primitivismen": "primitivism",
    "primitivismens": "primitivism",
    "primitivismer": "primitivism",
    "primitivismerna": "primitivism",
    "primitivismernas": "primitivism",
    "primitivismers": "primitivism",
    "primitivisms": "primitivism",
    "primitivistiska": "primitivistisk",
    "primitivistiskare": "primitivistisk",
    "primitivistiskares": "primitivistisk",
    "primitivistiskas": "primitivistisk",
    "primitivistiskast": "primitivistisk",
    "primitivistiskaste": "primitivistisk",
    "primitivistiskastes": "primitivistisk",
    "primitivistiskasts": "primitivistisk",
    "primitivistiske": "primitivistisk",
    "primitivistiskes": "primitivistisk",
    "primitivistisks": "primitivistisk",
    "primitivistiskt": "primitivistisk",
    "primitivistiskts": "primitivistisk",
    "primitiviteten": "primitivitet",
    "primitivitetens": "primitivitet",
    "primitiviteter": "primitivitet",
    "primitiviteterna": "primitivitet",
    "primitiviteternas": "primitivitet",
    "primitiviteters": "primitivitet",
    "primitivitets": "primitivitet",
    "primitivs": "primitiv",
    "primitivt": "primitiv",
    "primitivts": "primitiv",
    "primklock": "primklocka",
    "primklockan": "primklocka",
    "primklockans": "primklocka",
    "primklockas": "primklocka",
    "primklocke": "primklocka",
    "primklockor": "primklocka",
    "primklockorna": "primklocka",
    "primklockornas": "primklocka",
    "primklockors": "primklocka",
    "primklocks": "primklocka",
    "prims": "prim",
    "primtalen": "primtal",
    "primtalens": "primtal",
    "primtalet": "primtal",
    "primtalets": "primtal",
    "primtals": "primtal",
    "primul": "primula",
    "primulan": "primula",
    "primulans": "primula",
    "primulas": "primula",
    "primule": "primula",
    "primulor": "primula",
    "primulorna": "primula",
    "primulornas": "primula",
    "primulors": "primula",
    "primuls": "primula",
    "primusköken": "primuskök",
    "primuskökens": "primuskök",
    "primusköket": "primuskök",
    "primuskökets": "primuskök",
    "primusköks": "primuskök",
    "primära": "primär",
    "primärare": "primär",
    "primärares": "primär",
    "primäras": "primär",
    "primärast": "primär",
    "primäraste": "primär",
    "primärastes": "primär",
    "primärasts": "primär",
    "primäre": "primär",
    "primäres": "primär",
    "primärgruppen": "primärgrupp",
    "primärgruppens": "primärgrupp",
    "primärgrupper": "primärgrupp",
    "primärgrupperna": "primärgrupp",
    "primärgruppernas": "primärgrupp",
    "primärgruppers": "primärgrupp",
    "primärgrupps": "primärgrupp",
    "primärkommunen": "primärkommun",
    "primärkommunens": "primärkommun",
    "primärkommuner": "primärkommun",
    "primärkommunerna": "primärkommun",
    "primärkommunernas": "primärkommun",
    "primärkommuners": "primärkommun",
    "primärkommuns": "primärkommun",
    "primärkrediten": "primärkredit",
    "primärkreditens": "primärkredit",
    "primärkrediter": "primärkredit",
    "primärkrediterna": "primärkredit",
    "primärkrediternas": "primärkredit",
    "primärkrediters": "primärkredit",
    "primärkredits": "primärkredit",
    "primärkäll": "primärkälla",
    "primärkällan": "primärkälla",
    "primärkällans": "primärkälla",
    "primärkällas": "primärkälla",
    "primärkälle": "primärkälla",
    "primärkällor": "primärkälla",
    "primärkällorna": "primärkälla",
    "primärkällornas": "primärkälla",
    "primärkällors": "primärkälla",
    "primärkälls": "primärkälla",
    "primärlånen": "primärlån",
    "primärlånens": "primärlån",
    "primärlånet": "primärlån",
    "primärlånets": "primärlån",
    "primärlåns": "primärlån",
    "primärminnen": "primärminne",
    "primärminnena": "primärminne",
    "primärminnenas": "primärminne",
    "primärminnens": "primärminne",
    "primärminnes": "primärminne",
    "primärminnet": "primärminne",
    "primärminnets": "primärminne",
    "primärs": "primär",
    "primärt": "primär",
    "primärts": "primär",
    "primärvalen": "primärval",
    "primärvalens": "primärval",
    "primärvalet": "primärval",
    "primärvalets": "primärval",
    "primärvals": "primärval",
    "primärvården": "primärvård",
    "primärvårdens": "primärvård",
    "primärvårds": "primärvård",
    "primören": "primör",
    "primörens": "primör",
    "primörer": "primör",
    "primörerna": "primör",
    "primörernas": "primör",
    "primörers": "primör",
    "primörs": "primör",
    "principalen": "principal",
    "principalens": "principal",
    "principaler": "principal",
    "principalerna": "principal",
    "principalernas": "principal",
    "principalers": "principal",
    "principals": "principal",
    "principen": "princip",
    "principens": "princip",
    "principer": "princip",
    "principerna": "princip",
    "principernas": "princip",
    "principers": "princip",
    "principfasta": "principfast",
    "principfastare": "principfast",
    "principfastares": "principfast",
    "principfastas": "principfast",
    "principfastast": "principfast",
    "principfastaste": "principfast",
    "principfastastes": "principfast",
    "principfastasts": "principfast",
    "principfaste": "principfast",
    "principfastes": "principfast",
    "principfastheten": "principfasthet",
    "principfasthetens": "principfasthet",
    "principfasthets": "principfasthet",
    "principfasts": "principfast",
    "principförklaringar": "principförklaring",
    "principförklaringarna": "principförklaring",
    "principförklaringarnas": "principförklaring",
    "principförklaringars": "principförklaring",
    "principförklaringen": "principförklaring",
    "principförklaringens": "principförklaring",
    "principförklarings": "principförklaring",
    "principiella": "principiell",
    "principiellare": "principiell",
    "principiellares": "principiell",
    "principiellas": "principiell",
    "principiellast": "principiell",
    "principiellaste": "principiell",
    "principiellastes": "principiell",
    "principiellasts": "principiell",
    "principielle": "principiell",
    "principielles": "principiell",
    "principiells": "principiell",
    "principiellt": "principiell",
    "principiellts": "principiell",
    "principlösa": "principlös",
    "principlösare": "principlös",
    "principlösares": "principlös",
    "principlösas": "principlös",
    "principlösast": "principlös",
    "principlösaste": "principlös",
    "principlösastes": "principlös",
    "principlösasts": "principlös",
    "principlöse": "principlös",
    "principlöses": "principlös",
    "principlösheten": "principlöshet",
    "principlöshetens": "principlöshet",
    "principlöshets": "principlöshet",
    "principlöst": "principlös",
    "principlösts": "principlös",
    "principmänniskan": "principmänniska",
    "principmänniskans": "principmänniska",
    "principmänniskas": "principmänniska",
    "principmännisko": "principmänniska",
    "principmänniskor": "principmänniska",
    "principmänniskorna": "principmänniska",
    "principmänniskornas": "principmänniska",
    "principmänniskors": "principmänniska",
    "principprogrammen": "principprogram",
    "principprogrammens": "principprogram",
    "principprogrammet": "principprogram",
    "principprogrammets": "principprogram",
    "principprograms": "principprogram",
    "principryttar": "principryttare",
    "principryttaren": "principryttare",
    "principryttarens": "principryttare",
    "principryttares": "principryttare",
    "principryttarna": "principryttare",
    "principryttarnas": "principryttare",
    "princips": "princip",
    "prinsar": "prins",
    "prinsarna": "prins",
    "prinsarnas": "prins",
    "prinsars": "prins",
    "prinsen": "prins",
    "prinsens": "prins",
    "prinsess": "prinsessa",
    "prinsessan": "prinsessa",
    "prinsessans": "prinsessa",
    "prinsessas": "prinsessa",
    "prinsesse": "prinsessa",
    "prinsessklänningar": "prinsessklänning",
    "prinsessklänningarna": "prinsessklänning",
    "prinsessklänningarnas": "prinsessklänning",
    "prinsessklänningars": "prinsessklänning",
    "prinsessklänningen": "prinsessklänning",
    "prinsessklänningens": "prinsessklänning",
    "prinsessklännings": "prinsessklänning",
    "prinsessor": "prinsessa",
    "prinsessorna": "prinsessa",
    "prinsessornas": "prinsessa",
    "prinsessors": "prinsessa",
    "prinsesstårt": "prinsesstårta",
    "prinsesstårtan": "prinsesstårta",
    "prinsesstårtans": "prinsesstårta",
    "prinsesstårtas": "prinsesstårta",
    "prinsesstårtbitar": "prinsesstårtbit",
    "prinsesstårtbitarna": "prinsesstårtbit",
    "prinsesstårtbitarnas": "prinsesstårtbit",
    "prinsesstårtbitars": "prinsesstårtbit",
    "prinsesstårtbiten": "prinsesstårtbit",
    "prinsesstårtbitens": "prinsesstårtbit",
    "prinsesstårtbits": "prinsesstårtbit",
    "prinsesstårte": "prinsesstårta",
    "prinsesstårtor": "prinsesstårta",
    "prinsesstårtorna": "prinsesstårta",
    "prinsesstårtornas": "prinsesstårta",
    "prinsesstårtors": "prinsesstårta",
    "prinsesstårts": "prinsesstårta",
    "prinsgemålen": "prinsgemål",
    "prinsgemålens": "prinsgemål",
    "prinsgemåler": "prinsgemål",
    "prinsgemålerna": "prinsgemål",
    "prinsgemålernas": "prinsgemål",
    "prinsgemålers": "prinsgemål",
    "prinsgemåls": "prinsgemål",
    "prinskorvar": "prinskorv",
    "prinskorvarna": "prinskorv",
    "prinskorvarnas": "prinskorv",
    "prinskorvars": "prinskorv",
    "prinskorven": "prinskorv",
    "prinskorvens": "prinskorv",
    "prinskorvs": "prinskorv",
    "prinsregenten": "prinsregent",
    "prinsregentens": "prinsregent",
    "prinsregenter": "prinsregent",
    "prinsregenterna": "prinsregent",
    "prinsregenternas": "prinsregent",
    "prinsregenters": "prinsregent",
    "prinsregents": "prinsregent",
    "print-on-demands": "print-on-demand",
    "priorer": "prior",
    "priorerna": "prior",
    "priorernas": "prior",
    "priorers": "prior",
    "priorinnan": "priorinna",
    "priorinnans": "priorinna",
    "priorinnas": "priorinna",
    "priorinne": "priorinna",
    "priorinnor": "priorinna",
    "priorinnorna": "priorinna",
    "priorinnornas": "priorinna",
    "priorinnors": "priorinna",
    "prioriterad": "prioritera",
    "prioriterade": "prioritera",
    "prioriterades": "prioritera",
    "prioriterads": "prioritera",
    "prioriterande": "prioritera",
    "prioriteranden": "prioriterande",
    "prioriterandena": "prioriterande",
    "prioriterandenas": "prioriterande",
    "prioriterandens": "prioriterande",
    "prioriterandes": "prioriterande",
    "prioriterandet": "prioriterande",
    "prioriterandets": "prioriterande",
    "prioriterar": "prioritera",
    "prioriteras": "prioritera",
    "prioriterat": "prioritera",
    "prioriterats": "prioritera",
    "prioriterbara": "prioriterbar",
    "prioriterbarare": "prioriterbar",
    "prioriterbarares": "prioriterbar",
    "prioriterbaras": "prioriterbar",
    "prioriterbarast": "prioriterbar",
    "prioriterbaraste": "prioriterbar",
    "prioriterbarastes": "prioriterbar",
    "prioriterbarasts": "prioriterbar",
    "prioriterbare": "prioriterbar",
    "prioriterbares": "prioriterbar",
    "prioriterbarheten": "prioriterbarhet",
    "prioriterbarhetens": "prioriterbarhet",
    "prioriterbarhets": "prioriterbarhet",
    "prioriterbars": "prioriterbar",
    "prioriterbart": "prioriterbar",
    "prioriterbarts": "prioriterbar",
    "prioriteringar": "prioritering",
    "prioriteringarna": "prioritering",
    "prioriteringarnas": "prioritering",
    "prioriteringars": "prioritering",
    "prioriteringen": "prioritering",
    "prioriteringens": "prioritering",
    "prioriterings": "prioritering",
    "prioriteringsmässiga": "prioriteringsmässig",
    "prioriteringsmässigare": "prioriteringsmässig",
    "prioriteringsmässigares": "prioriteringsmässig",
    "prioriteringsmässigas": "prioriteringsmässig",
    "prioriteringsmässigast": "prioriteringsmässig",
    "prioriteringsmässigaste": "prioriteringsmässig",
    "prioriteringsmässigastes": "prioriteringsmässig",
    "prioriteringsmässigasts": "prioriteringsmässig",
    "prioriteringsmässige": "prioriteringsmässig",
    "prioriteringsmässiges": "prioriteringsmässig",
    "prioriteringsmässigs": "prioriteringsmässig",
    "prioriteringsmässigt": "prioriteringsmässig",
    "prioriteringsmässigts": "prioriteringsmässig",
    "prioriteten": "prioritet",
    "prioritetens": "prioritet",
    "prioriteter": "prioritet",
    "prioriteterna": "prioritet",
    "prioriteternas": "prioritet",
    "prioriteters": "prioritet",
    "prioritets": "prioritet",
    "prioritetsordningar": "prioritetsordning",
    "prioritetsordningarna": "prioritetsordning",
    "prioritetsordningarnas": "prioritetsordning",
    "prioritetsordningars": "prioritetsordning",
    "prioritetsordningen": "prioritetsordning",
    "prioritetsordningens": "prioritetsordning",
    "prioritetsordnings": "prioritetsordning",
    "priorn": "prior",
    "priorns": "prior",
    "priors": "prior",
    "pris": "prisa",
    "prisad": "prisa",
    "prisade": "prisa",
    "prisades": "prisa",
    "prisads": "prisa",
    "prisande": "prisa",
    "prisanden": "prisande",
    "prisandena": "prisande",
    "prisandenas": "prisande",
    "prisandens": "prisande",
    "prisandes": "prisande",
    "prisandet": "prisande",
    "prisandets": "prisande",
    "prisar": "prisa",
    "prisarna": "pris",
    "prisarnas": "pris",
    "prisars": "pris",
    "prisas": "prisa",
    "prisat": "prisa",
    "prisats": "prisa",
    "prisbelön": "prisbelöna",
    "prisbelönad": "prisbelöna",
    "prisbelönade": "prisbelöna",
    "prisbelönades": "prisbelöna",
    "prisbelönads": "prisbelöna",
    "prisbelönande": "prisbelöna",
    "prisbelönanden": "prisbelönande",
    "prisbelönandena": "prisbelönande",
    "prisbelönandenas": "prisbelönande",
    "prisbelönandens": "prisbelönande",
    "prisbelönandes": "prisbelönande",
    "prisbelönandet": "prisbelönande",
    "prisbelönandets": "prisbelönande",
    "prisbelönar": "prisbelöna",
    "prisbelönas": "prisbelöna",
    "prisbelönat": "prisbelöna",
    "prisbelönats": "prisbelöna",
    "prisbelönt": "prisbelöna",
    "prisbelönta": "prisbelöna",
    "prisbelöntas": "prisbelöna",
    "prisbelönte": "prisbelöna",
    "prisbelöntes": "prisbelöna",
    "prisbelönts": "prisbelöna",
    "prisbilliga": "prisbillig",
    "prisbilligare": "prisbillig",
    "prisbilligares": "prisbillig",
    "prisbilligas": "prisbillig",
    "prisbilligast": "prisbillig",
    "prisbilligaste": "prisbillig",
    "prisbilligastes": "prisbillig",
    "prisbilligasts": "prisbillig",
    "prisbillige": "prisbillig",
    "prisbilliges": "prisbillig",
    "prisbilligheten": "prisbillighet",
    "prisbillighetens": "prisbillighet",
    "prisbillighets": "prisbillighet",
    "prisbilligs": "prisbillig",
    "prisbilligt": "prisbillig",
    "prisbilligts": "prisbillig",
    "prisbluffar": "prisbluff",
    "prisbluffarna": "prisbluff",
    "prisbluffarnas": "prisbluff",
    "prisbluffars": "prisbluff",
    "prisbluffen": "prisbluff",
    "prisbluffens": "prisbluff",
    "prisbluffs": "prisbluff",
    "prisbomben": "prisbomb",
    "prisbombens": "prisbomb",
    "prisbomber": "prisbomb",
    "prisbomberna": "prisbomb",
    "prisbombernas": "prisbomb",
    "prisbombers": "prisbomb",
    "prisbombs": "prisbomb",
    "prisboxar": "prisboxare",
    "prisboxaren": "prisboxare",
    "prisboxarens": "prisboxare",
    "prisboxares": "prisboxare",
    "prisboxarna": "prisboxare",
    "prisboxarnas": "prisboxare",
    "prisceremonien": "prisceremoni",
    "prisceremoniens": "prisceremoni",
    "prisceremonier": "prisceremoni",
    "prisceremonierna": "prisceremoni",
    "prisceremoniernas": "prisceremoni",
    "prisceremoniers": "prisceremoni",
    "prisceremonin": "prisceremoni",
    "prisceremonins": "prisceremoni",
    "prisceremonis": "prisceremoni",
    "prischocken": "prischock",
    "prischockens": "prischock",
    "prischocker": "prischock",
    "prischockerna": "prischock",
    "prischockernas": "prischock",
    "prischockers": "prischock",
    "prischocks": "prischock",
    "priselasticiteten": "priselasticitet",
    "priselasticitetens": "priselasticitet",
    "priselasticiteter": "priselasticitet",
    "priselasticiteterna": "priselasticitet",
    "priselasticiteternas": "priselasticitet",
    "priselasticiteters": "priselasticitet",
    "priselasticitets": "priselasticitet",
    "prisen": "pris",
    "prisens": "pris",
    "priser": "pris",
    "priserna": "pris",
    "prisernas": "pris",
    "prisers": "pris",
    "priset": "pris",
    "prisets": "pris",
    "prisfallen": "prisfall",
    "prisfallens": "prisfall",
    "prisfallet": "prisfall",
    "prisfallets": "prisfall",
    "prisfalls": "prisfall",
    "prisfesten": "prisfest",
    "prisfestens": "prisfest",
    "prisfester": "prisfest",
    "prisfesterna": "prisfest",
    "prisfesternas": "prisfest",
    "prisfesters": "prisfest",
    "prisfests": "prisfest",
    "prisförändringar": "prisförändring",
    "prisförändringarna": "prisförändring",
    "prisförändringarnas": "prisförändring",
    "prisförändringars": "prisförändring",
    "prisförändringen": "prisförändring",
    "prisförändringens": "prisförändring",
    "prisförändrings": "prisförändring",
    "prisgav": "prisge",
    "prisgavs": "prisge",
    "prisgeende": "prisge",
    "prisgeendes": "prisge",
    "prisger": "prisge",
    "prisges": "prisge",
    "prisgett": "prisge",
    "prisgetts": "prisge",
    "prisgiv": "prisge",
    "prisgiva": "prisge",
    "prisgivande": "prisge",
    "prisgivanden": "prisgivande",
    "prisgivandena": "prisgivande",
    "prisgivandenas": "prisgivande",
    "prisgivandens": "prisgivande",
    "prisgivandes": "prisgivande",
    "prisgivandet": "prisgivande",
    "prisgivandets": "prisgivande",
    "prisgivas": "prisge",
    "prisgive": "prisge",
    "prisgiven": "prisge",
    "prisgivens": "prisge",
    "prisgiver": "prisge",
    "prisgives": "prisge",
    "prisgivet": "prisge",
    "prisgivets": "prisge",
    "prisgivit": "prisge",
    "prisgivits": "prisge",
    "prisgivna": "prisge",
    "prisgivnas": "prisge",
    "prisgivne": "prisge",
    "prisgivnes": "prisge",
    "prisgivs": "prisge",
    "prisgåve": "prisge",
    "prisgåves": "prisge",
    "prishöjningar": "prishöjning",
    "prishöjningarna": "prishöjning",
    "prishöjningarnas": "prishöjning",
    "prishöjningars": "prishöjning",
    "prishöjningen": "prishöjning",
    "prishöjningens": "prishöjning",
    "prishöjnings": "prishöjning",
    "prisjakten": "prisjakt",
    "prisjaktens": "prisjakt",
    "prisjakter": "prisjakt",
    "prisjakterna": "prisjakt",
    "prisjakternas": "prisjakt",
    "prisjakters": "prisjakt",
    "prisjakts": "prisjakt",
    "priskontrollen": "priskontroll",
    "priskontrollens": "priskontroll",
    "priskontrolls": "priskontroll",
    "priskrigen": "priskrig",
    "priskrigens": "priskrig",
    "priskriget": "priskrig",
    "priskrigets": "priskrig",
    "priskrigs": "priskrig",
    "priskuranten": "priskurant",
    "priskurantens": "priskurant",
    "priskuranter": "priskurant",
    "priskuranterna": "priskurant",
    "priskuranternas": "priskurant",
    "priskuranters": "priskurant",
    "priskurants": "priskurant",
    "prislappar": "prislapp",
    "prislapparna": "prislapp",
    "prislapparnas": "prislapp",
    "prislappars": "prislapp",
    "prislappen": "prislapp",
    "prislappens": "prislapp",
    "prislapps": "prislapp",
    "prislistan": "prislista",
    "prislistans": "prislista",
    "prislistas": "prislista",
    "prisliste": "prislista",
    "prislistor": "prislista",
    "prislistorna": "prislista",
    "prislistornas": "prislista",
    "prislistors": "prislista",
    "prismaformade": "prismaformad",
    "prismaformades": "prismaformad",
    "prismaformads": "prismaformad",
    "prismaformat": "prismaformad",
    "prismaformats": "prismaformad",
    "prismakikar": "prismakikare",
    "prismakikaren": "prismakikare",
    "prismakikarens": "prismakikare",
    "prismakikares": "prismakikare",
    "prismakikarna": "prismakikare",
    "prismakikarnas": "prismakikare",
    "prisman": "prisma",
    "prismans": "prisma",
    "prismas": "prisma",
    "prismat": "prisma",
    "prismatiska": "prismatisk",
    "prismatiskare": "prismatisk",
    "prismatiskares": "prismatisk",
    "prismatiskas": "prismatisk",
    "prismatiskast": "prismatisk",
    "prismatiskaste": "prismatisk",
    "prismatiskastes": "prismatisk",
    "prismatiskasts": "prismatisk",
    "prismatiske": "prismatisk",
    "prismatiskes": "prismatisk",
    "prismatisks": "prismatisk",
    "prismatiskt": "prismatisk",
    "prismatiskts": "prismatisk",
    "prismats": "prisma",
    "prismedvetens": "prismedveten",
    "prismedvetet": "prismedveten",
    "prismedvetets": "prismedveten",
    "prismedvetna": "prismedveten",
    "prismedvetnare": "prismedveten",
    "prismedvetnares": "prismedveten",
    "prismedvetnas": "prismedveten",
    "prismedvetnast": "prismedveten",
    "prismedvetnaste": "prismedveten",
    "prismedvetnastes": "prismedveten",
    "prismedvetnasts": "prismedveten",
    "prismedvetne": "prismedveten",
    "prismedvetnes": "prismedveten",
    "prismer": "prisma",
    "prismerna": "prisma",
    "prismernas": "prisma",
    "prismers": "prisma",
    "prismor": "prisma",
    "prismorna": "prisma",
    "prismornas": "prisma",
    "prismors": "prisma",
    "prismärk": "prismärka",
    "prismärkande": "prismärka",
    "prismärkanden": "prismärkande",
    "prismärkandena": "prismärkande",
    "prismärkandenas": "prismärkande",
    "prismärkandens": "prismärkande",
    "prismärkandes": "prismärkande",
    "prismärkandet": "prismärkande",
    "prismärkandets": "prismärkande",
    "prismärkas": "prismärka",
    "prismärker": "prismärka",
    "prismärkes": "prismärka",
    "prismärks": "prismärka",
    "prismärkt": "prismärka",
    "prismärkta": "prismärka",
    "prismärktas": "prismärka",
    "prismärkte": "prismärka",
    "prismärktes": "prismärka",
    "prismärkts": "prismärka",
    "prismässiga": "prismässig",
    "prismässigare": "prismässig",
    "prismässigares": "prismässig",
    "prismässigas": "prismässig",
    "prismässigast": "prismässig",
    "prismässigaste": "prismässig",
    "prismässigastes": "prismässig",
    "prismässigasts": "prismässig",
    "prismässige": "prismässig",
    "prismässiges": "prismässig",
    "prismässigs": "prismässig",
    "prismässigt": "prismässig",
    "prismässigts": "prismässig",
    "prisnivåer": "prisnivå",
    "prisnivåerna": "prisnivå",
    "prisnivåernas": "prisnivå",
    "prisnivåers": "prisnivå",
    "prisnivån": "prisnivå",
    "prisnivåns": "prisnivå",
    "prisnivås": "prisnivå",
    "prispallar": "prispall",
    "prispallarna": "prispall",
    "prispallarnas": "prispall",
    "prispallars": "prispall",
    "prispallen": "prispall",
    "prispallens": "prispall",
    "prispalls": "prispall",
    "prispressen": "prispress",
    "prispressens": "prispress",
    "prisrallyn": "prisrally",
    "prisrallyna": "prisrally",
    "prisrallynas": "prisrally",
    "prisrallyns": "prisrally",
    "prisrallys": "prisrally",
    "prisrallyt": "prisrally",
    "prisrallyts": "prisrally",
    "prisrasen": "prisras",
    "prisrasens": "prisras",
    "prisraset": "prisras",
    "prisrasets": "prisras",
    "prisreglerad": "prisreglera",
    "prisreglerade": "prisreglera",
    "prisreglerades": "prisreglera",
    "prisreglerads": "prisreglera",
    "prisreglerande": "prisreglera",
    "prisregleranden": "prisreglerande",
    "prisreglerandena": "prisreglerande",
    "prisreglerandenas": "prisreglerande",
    "prisreglerandens": "prisreglerande",
    "prisreglerandes": "prisreglerande",
    "prisreglerandet": "prisreglerande",
    "prisreglerandets": "prisreglerande",
    "prisreglerar": "prisreglera",
    "prisregleras": "prisreglera",
    "prisreglerat": "prisreglera",
    "prisreglerats": "prisreglera",
    "prisreglerbara": "prisreglerbar",
    "prisreglerbarare": "prisreglerbar",
    "prisreglerbarares": "prisreglerbar",
    "prisreglerbaras": "prisreglerbar",
    "prisreglerbarast": "prisreglerbar",
    "prisreglerbaraste": "prisreglerbar",
    "prisreglerbarastes": "prisreglerbar",
    "prisreglerbarasts": "prisreglerbar",
    "prisreglerbare": "prisreglerbar",
    "prisreglerbares": "prisreglerbar",
    "prisreglerbarheten": "prisreglerbarhet",
    "prisreglerbarhetens": "prisreglerbarhet",
    "prisreglerbarhets": "prisreglerbarhet",
    "prisreglerbars": "prisreglerbar",
    "prisreglerbart": "prisreglerbar",
    "prisreglerbarts": "prisreglerbar",
    "prisregleringar": "prisreglering",
    "prisregleringarna": "prisreglering",
    "prisregleringarnas": "prisreglering",
    "prisregleringars": "prisreglering",
    "prisregleringen": "prisreglering",
    "prisregleringens": "prisreglering",
    "prisreglerings": "prisreglering",
    "priss": "prisse",
    "prissar": "prisse",
    "prissarna": "prisse",
    "prissarnas": "prisse",
    "prissars": "prisse",
    "prissatt": "prissätta",
    "prissatta": "prissätta",
    "prissattas": "prissätta",
    "prissatte": "prissätta",
    "prissattes": "prissätta",
    "prissatts": "prissätta",
    "prissen": "prisse",
    "prissens": "prisse",
    "prissensationen": "prissensation",
    "prissensationens": "prissensation",
    "prissensationer": "prissensation",
    "prissensationerna": "prissensation",
    "prissensationernas": "prissensation",
    "prissensationers": "prissensation",
    "prissensations": "prissensation",
    "prisses": "prisse",
    "prisstegringar": "prisstegring",
    "prisstegringarna": "prisstegring",
    "prisstegringarnas": "prisstegring",
    "prisstegringars": "prisstegring",
    "prisstegringen": "prisstegring",
    "prisstegringens": "prisstegring",
    "prisstegrings": "prisstegring",
    "prisstoppen": "prisstopp",
    "prisstoppens": "prisstopp",
    "prisstoppet": "prisstopp",
    "prisstoppets": "prisstopp",
    "prisstopps": "prisstopp",
    "prissätt": "prissätta",
    "prissättande": "prissätta",
    "prissättanden": "prissättande",
    "prissättandena": "prissättande",
    "prissättandenas": "prissättande",
    "prissättandens": "prissättande",
    "prissättandes": "prissättande",
    "prissättandet": "prissättande",
    "prissättandets": "prissättande",
    "prissättas": "prissätta",
    "prissätter": "prissätta",
    "prissättes": "prissätta",
    "prissättningar": "prissättning",
    "prissättningarna": "prissättning",
    "prissättningarnas": "prissättning",
    "prissättningars": "prissättning",
    "prissättningen": "prissättning",
    "prissättningens": "prissättning",
    "prissättnings": "prissättning",
    "prissätts": "prissätta",
    "pristagar": "pristagare",
    "pristagaren": "pristagare",
    "pristagarens": "pristagare",
    "pristagares": "pristagare",
    "pristagarna": "pristagare",
    "pristagarnas": "pristagare",
    "pristaken": "pristak",
    "pristakens": "pristak",
    "pristaket": "pristak",
    "pristakets": "pristak",
    "pristaks": "pristak",
    "pristävlingar": "pristävling",
    "pristävlingarna": "pristävling",
    "pristävlingarnas": "pristävling",
    "pristävlingars": "pristävling",
    "pristävlingen": "pristävling",
    "pristävlingens": "pristävling",
    "pristävlings": "pristävling",
    "prisutdelningar": "prisutdelning",
    "prisutdelningarna": "prisutdelning",
    "prisutdelningarnas": "prisutdelning",
    "prisutdelningars": "prisutdelning",
    "prisutdelningen": "prisutdelning",
    "prisutdelningens": "prisutdelning",
    "prisutdelnings": "prisutdelning",
    "prisvariationen": "prisvariation",
    "prisvariationens": "prisvariation",
    "prisvariationer": "prisvariation",
    "prisvariationerna": "prisvariation",
    "prisvariationernas": "prisvariation",
    "prisvariationers": "prisvariation",
    "prisvariations": "prisvariation",
    "prisvärda": "prisvärd",
    "prisvärdare": "prisvärd",
    "prisvärdares": "prisvärd",
    "prisvärdas": "prisvärd",
    "prisvärdast": "prisvärd",
    "prisvärdaste": "prisvärd",
    "prisvärdastes": "prisvärd",
    "prisvärdasts": "prisvärd",
    "prisvärde": "prisvärd",
    "prisvärdes": "prisvärd",
    "prisvärdheten": "prisvärdhet",
    "prisvärdhetens": "prisvärdhet",
    "prisvärdhets": "prisvärdhet",
    "prisvärds": "prisvärd",
    "prisvärt": "prisvärd",
    "prisvärts": "prisvärd",
    "prisökningar": "prisökning",
    "prisökningarna": "prisökning",
    "prisökningarnas": "prisökning",
    "prisökningars": "prisökning",
    "prisökningen": "prisökning",
    "prisökningens": "prisökning",
    "prisöknings": "prisökning",
    "privata": "privat",
    "privatanställde": "privatanställd",
    "privatanställdes": "privatanställd",
    "privatanställds": "privatanställd",
    "privatanställt": "privatanställd",
    "privatanställts": "privatanställd",
    "privatare": "privat",
    "privatares": "privat",
    "privatas": "privat",
    "privatast": "privat",
    "privataste": "privat",
    "privatastes": "privat",
    "privatasts": "privat",
    "privatbanken": "privatbank",
    "privatbankens": "privatbank",
    "privatbanker": "privatbank",
    "privatbankerna": "privatbank",
    "privatbankernas": "privatbank",
    "privatbankers": "privatbank",
    "privatbanks": "privatbank",
    "privatbilar": "privatbil",
    "privatbilarna": "privatbil",
    "privatbilarnas": "privatbil",
    "privatbilars": "privatbil",
    "privatbilen": "privatbil",
    "privatbilens": "privatbil",
    "privatbils": "privatbil",
    "privatdetektiven": "privatdetektiv",
    "privatdetektivens": "privatdetektiv",
    "privatdetektiver": "privatdetektiv",
    "privatdetektiverna": "privatdetektiv",
    "privatdetektivernas": "privatdetektiv",
    "privatdetektivers": "privatdetektiv",
    "privatdetektivs": "privatdetektiv",
    "privatdiskontören": "privatdiskontör",
    "privatdiskontörens": "privatdiskontör",
    "privatdiskontörer": "privatdiskontör",
    "privatdiskontörerna": "privatdiskontör",
    "privatdiskontörernas": "privatdiskontör",
    "privatdiskontörers": "privatdiskontör",
    "privatdiskontörs": "privatdiskontör",
    "private": "privat",
    "privatekonomiska": "privatekonomisk",
    "privatekonomiskare": "privatekonomisk",
    "privatekonomiskares": "privatekonomisk",
    "privatekonomiskas": "privatekonomisk",
    "privatekonomiskast": "privatekonomisk",
    "privatekonomiskaste": "privatekonomisk",
    "privatekonomiskastes": "privatekonomisk",
    "privatekonomiskasts": "privatekonomisk",
    "privatekonomiske": "privatekonomisk",
    "privatekonomiskes": "privatekonomisk",
    "privatekonomisks": "privatekonomisk",
    "privatekonomiskt": "privatekonomisk",
    "privatekonomiskts": "privatekonomisk",
    "privates": "privat",
    "privatiserad": "privatisera",
    "privatiserade": "privatisera",
    "privatiserades": "privatisera",
    "privatiserads": "privatisera",
    "privatiserande": "privatisera",
    "privatiseranden": "privatiserande",
    "privatiserandena": "privatiserande",
    "privatiserandenas": "privatiserande",
    "privatiserandens": "privatiserande",
    "privatiserandes": "privatiserande",
    "privatiserandet": "privatiserande",
    "privatiserandets": "privatiserande",
    "privatiserar": "privatisera",
    "privatiseras": "privatisera",
    "privatiserat": "privatisera",
    "privatiserats": "privatisera",
    "privatiserbara": "privatiserbar",
    "privatiserbarare": "privatiserbar",
    "privatiserbarares": "privatiserbar",
    "privatiserbaras": "privatiserbar",
    "privatiserbarast": "privatiserbar",
    "privatiserbaraste": "privatiserbar",
    "privatiserbarastes": "privatiserbar",
    "privatiserbarasts": "privatiserbar",
    "privatiserbare": "privatiserbar",
    "privatiserbares": "privatiserbar",
    "privatiserbarheten": "privatiserbarhet",
    "privatiserbarhetens": "privatiserbarhet",
    "privatiserbarhets": "privatiserbarhet",
    "privatiserbars": "privatiserbar",
    "privatiserbart": "privatiserbar",
    "privatiserbarts": "privatiserbar",
    "privatiseringar": "privatisering",
    "privatiseringarna": "privatisering",
    "privatiseringarnas": "privatisering",
    "privatiseringars": "privatisering",
    "privatiseringen": "privatisering",
    "privatiseringens": "privatisering",
    "privatiserings": "privatisering",
    "privatiseringsprogrammen": "privatiseringsprogram",
    "privatiseringsprogrammens": "privatiseringsprogram",
    "privatiseringsprogrammet": "privatiseringsprogram",
    "privatiseringsprogrammets": "privatiseringsprogram",
    "privatiseringsprograms": "privatiseringsprogram",
    "privatiseringsspektakels": "privatiseringsspektakel",
    "privatiseringsspektaklen": "privatiseringsspektakel",
    "privatiseringsspektaklens": "privatiseringsspektakel",
    "privatiseringsspektaklet": "privatiseringsspektakel",
    "privatiseringsspektaklets": "privatiseringsspektakel",
    "privatisten": "privatist",
    "privatistens": "privatist",
    "privatister": "privatist",
    "privatisterna": "privatist",
    "privatisternas": "privatist",
    "privatisters": "privatist",
    "privatists": "privatist",
    "privatkapitalen": "privatkapital",
    "privatkapitalens": "privatkapital",
    "privatkapitalet": "privatkapital",
    "privatkapitalets": "privatkapital",
    "privatkapitals": "privatkapital",
    "privatlektionen": "privatlektion",
    "privatlektionens": "privatlektion",
    "privatlektioner": "privatlektion",
    "privatlektionerna": "privatlektion",
    "privatlektionernas": "privatlektion",
    "privatlektioners": "privatlektion",
    "privatlektions": "privatlektion",
    "privatlivet": "privatliv",
    "privatlivets": "privatliv",
    "privatlivs": "privatliv",
    "privatläkar": "privatläkare",
    "privatläkaren": "privatläkare",
    "privatläkarens": "privatläkare",
    "privatläkares": "privatläkare",
    "privatläkarna": "privatläkare",
    "privatläkarnas": "privatläkare",
    "privatlärar": "privatlärare",
    "privatläraren": "privatlärare",
    "privatlärarens": "privatlärare",
    "privatlärares": "privatlärare",
    "privatlärarna": "privatlärare",
    "privatlärarnas": "privatlärare",
    "privatlånen": "privatlån",
    "privatlånens": "privatlån",
    "privatlånet": "privatlån",
    "privatlånets": "privatlån",
    "privatlåns": "privatlån",
    "privatmannen": "privatman",
    "privatmannens": "privatman",
    "privatmans": "privatman",
    "privatmän": "privatman",
    "privatmännen": "privatman",
    "privatmännens": "privatman",
    "privatmäns": "privatman",
    "privatpersonen": "privatperson",
    "privatpersonens": "privatperson",
    "privatpersoner": "privatperson",
    "privatpersonerna": "privatperson",
    "privatpersonernas": "privatperson",
    "privatpersoners": "privatperson",
    "privatpersons": "privatperson",
    "privatpraktiken": "privatpraktik",
    "privatpraktikens": "privatpraktik",
    "privatpraktiker": "privatpraktik",
    "privatpraktikern": "privatpraktiker",
    "privatpraktikerna": "privatpraktiker",
    "privatpraktikernas": "privatpraktiker",
    "privatpraktikerns": "privatpraktiker",
    "privatpraktikers": "privatpraktiker",
    "privatpraktiks": "privatpraktik",
    "privats": "privat",
    "privatsaken": "privatsak",
    "privatsakens": "privatsak",
    "privatsaker": "privatsak",
    "privatsakerna": "privatsak",
    "privatsakernas": "privatsak",
    "privatsakers": "privatsak",
    "privatsaks": "privatsak",
    "privatscenen": "privatscen",
    "privatscenens": "privatscen",
    "privatscener": "privatscen",
    "privatscenerna": "privatscen",
    "privatscenernas": "privatscen",
    "privatsceners": "privatscen",
    "privatscens": "privatscen",
    "privatsekreterar": "privatsekreterare",
    "privatsekreteraren": "privatsekreterare",
    "privatsekreterarens": "privatsekreterare",
    "privatsekreterares": "privatsekreterare",
    "privatsekreterarna": "privatsekreterare",
    "privatsekreterarnas": "privatsekreterare",
    "privatskolan": "privatskola",
    "privatskolans": "privatskola",
    "privatskolas": "privatskola",
    "privatskole": "privatskola",
    "privatskolor": "privatskola",
    "privatskolorna": "privatskola",
    "privatskolornas": "privatskola",
    "privatskolors": "privatskola",
    "privattrycken": "privattryck",
    "privattryckens": "privattryck",
    "privattrycket": "privattryck",
    "privattryckets": "privattryck",
    "privattrycks": "privattryck",
    "privatägda": "privatägd",
    "privatägdare": "privatägd",
    "privatägdares": "privatägd",
    "privatägdas": "privatägd",
    "privatägdast": "privatägd",
    "privatägdaste": "privatägd",
    "privatägdastes": "privatägd",
    "privatägdasts": "privatägd",
    "privatägde": "privatägd",
    "privatägdes": "privatägd",
    "privatägds": "privatägd",
    "privatägt": "privatägd",
    "privatägts": "privatägd",
    "privilegie": "privilegium",
    "privilegiebreven": "privilegiebrev",
    "privilegiebrevens": "privilegiebrev",
    "privilegiebrevet": "privilegiebrev",
    "privilegiebrevets": "privilegiebrev",
    "privilegiebrevs": "privilegiebrev",
    "privilegier": "privilegium",
    "privilegierad": "privilegiera",
    "privilegierade": "privilegierad",
    "privilegierades": "privilegierad",
    "privilegierads": "privilegierad",
    "privilegierande": "privilegiera",
    "privilegieranden": "privilegierande",
    "privilegierandena": "privilegierande",
    "privilegierandenas": "privilegierande",
    "privilegierandens": "privilegierande",
    "privilegierandes": "privilegierande",
    "privilegierandet": "privilegierande",
    "privilegierandets": "privilegierande",
    "privilegierar": "privilegiera",
    "privilegieras": "privilegiera",
    "privilegierat": "privilegierad",
    "privilegierats": "privilegierad",
    "privilegierbara": "privilegierbar",
    "privilegierbarare": "privilegierbar",
    "privilegierbarares": "privilegierbar",
    "privilegierbaras": "privilegierbar",
    "privilegierbarast": "privilegierbar",
    "privilegierbaraste": "privilegierbar",
    "privilegierbarastes": "privilegierbar",
    "privilegierbarasts": "privilegierbar",
    "privilegierbare": "privilegierbar",
    "privilegierbares": "privilegierbar",
    "privilegierbarheten": "privilegierbarhet",
    "privilegierbarhetens": "privilegierbarhet",
    "privilegierbarhets": "privilegierbarhet",
    "privilegierbars": "privilegierbar",
    "privilegierbart": "privilegierbar",
    "privilegierbarts": "privilegierbar",
    "privilegieringar": "privilegiering",
    "privilegieringarna": "privilegiering",
    "privilegieringarnas": "privilegiering",
    "privilegieringars": "privilegiering",
    "privilegieringen": "privilegiering",
    "privilegieringens": "privilegiering",
    "privilegierings": "privilegiering",
    "privilegierna": "privilegium",
    "privilegiernas": "privilegium",
    "privilegiers": "privilegium",
    "privilegiet": "privilegium",
    "privilegiets": "privilegium",
    "privilegiums": "privilegium",
    "prkuppen": "prkupp",
    "prkuppens": "prkupp",
    "prkupper": "prkupp",
    "prkupperna": "prkupp",
    "prkuppernas": "prkupp",
    "prkuppers": "prkupp",
    "prkupps": "prkupp",
    "probabels": "probabel",
    "probabelt": "probabel",
    "probabelts": "probabel",
    "probabilistiska": "probabilistisk",
    "probabilistiskare": "probabilistisk",
    "probabilistiskares": "probabilistisk",
    "probabilistiskas": "probabilistisk",
    "probabilistiskast": "probabilistisk",
    "probabilistiskaste": "probabilistisk",
    "probabilistiskastes": "probabilistisk",
    "probabilistiskasts": "probabilistisk",
    "probabilistiske": "probabilistisk",
    "probabilistiskes": "probabilistisk",
    "probabilistisks": "probabilistisk",
    "probabilistiskt": "probabilistisk",
    "probabilistiskts": "probabilistisk",
    "probabiliteten": "probabilitet",
    "probabilitetens": "probabilitet",
    "probabiliteter": "probabilitet",
    "probabiliteterna": "probabilitet",
    "probabiliteternas": "probabilitet",
    "probabiliteters": "probabilitet",
    "probabilitets": "probabilitet",
    "probabla": "probabel",
    "probablare": "probabel",
    "probablares": "probabel",
    "probablas": "probabel",
    "probablast": "probabel",
    "probablaste": "probabel",
    "probablastes": "probabel",
    "probablasts": "probabel",
    "probable": "probabel",
    "probables": "probabel",
    "probata": "probat",
    "probatare": "probat",
    "probatares": "probat",
    "probatas": "probat",
    "probatast": "probat",
    "probataste": "probat",
    "probatastes": "probat",
    "probatasts": "probat",
    "probate": "probat",
    "probates": "probat",
    "probats": "probat",
    "proberad": "probera",
    "proberade": "probera",
    "proberades": "probera",
    "proberads": "probera",
    "proberande": "probera",
    "proberanden": "proberande",
    "proberandena": "proberande",
    "proberandenas": "proberande",
    "proberandens": "proberande",
    "proberandes": "proberande",
    "proberandet": "proberande",
    "proberandets": "proberande",
    "proberar": "probera",
    "proberas": "probera",
    "proberat": "probera",
    "proberats": "probera",
    "proberbara": "proberbar",
    "proberbarare": "proberbar",
    "proberbarares": "proberbar",
    "proberbaras": "proberbar",
    "proberbarast": "proberbar",
    "proberbaraste": "proberbar",
    "proberbarastes": "proberbar",
    "proberbarasts": "proberbar",
    "proberbare": "proberbar",
    "proberbares": "proberbar",
    "proberbarheten": "proberbarhet",
    "proberbarhetens": "proberbarhet",
    "proberbarhets": "proberbarhet",
    "proberbars": "proberbar",
    "proberbart": "proberbar",
    "proberbarts": "proberbar",
    "proberingar": "probering",
    "proberingarna": "probering",
    "proberingarnas": "probering",
    "proberingars": "probering",
    "proberingen": "probering",
    "proberingens": "probering",
    "proberings": "probering",
    "proberstenen": "probersten",
    "proberstenens": "probersten",
    "proberstens": "probersten",
    "problemanläggningar": "problemanläggning",
    "problemanläggningarna": "problemanläggning",
    "problemanläggningarnas": "problemanläggning",
    "problemanläggningars": "problemanläggning",
    "problemanläggningen": "problemanläggning",
    "problemanläggningens": "problemanläggning",
    "problemanläggnings": "problemanläggning",
    "problematiken": "problematik",
    "problematikens": "problematik",
    "problematiks": "problematik",
    "problematiserad": "problematisera",
    "problematiserade": "problematisera",
    "problematiserades": "problematisera",
    "problematiserads": "problematisera",
    "problematiserande": "problematisera",
    "problematiseranden": "problematiserande",
    "problematiserandena": "problematiserande",
    "problematiserandenas": "problematiserande",
    "problematiserandens": "problematiserande",
    "problematiserandes": "problematiserande",
    "problematiserandet": "problematiserande",
    "problematiserandets": "problematiserande",
    "problematiserar": "problematisera",
    "problematiseras": "problematisera",
    "problematiserat": "problematisera",
    "problematiserats": "problematisera",
    "problematiserbara": "problematiserbar",
    "problematiserbarare": "problematiserbar",
    "problematiserbarares": "problematiserbar",
    "problematiserbaras": "problematiserbar",
    "problematiserbarast": "problematiserbar",
    "problematiserbaraste": "problematiserbar",
    "problematiserbarastes": "problematiserbar",
    "problematiserbarasts": "problematiserbar",
    "problematiserbare": "problematiserbar",
    "problematiserbares": "problematiserbar",
    "problematiserbarheten": "problematiserbarhet",
    "problematiserbarhetens": "problematiserbarhet",
    "problematiserbarhets": "problematiserbarhet",
    "problematiserbars": "problematiserbar",
    "problematiserbart": "problematiserbar",
    "problematiserbarts": "problematiserbar",
    "problematiseringar": "problematisering",
    "problematiseringarna": "problematisering",
    "problematiseringarnas": "problematisering",
    "problematiseringars": "problematisering",
    "problematiseringen": "problematisering",
    "problematiseringens": "problematisering",
    "problematiserings": "problematisering",
    "problematiska": "problematisk",
    "problematiskare": "problematisk",
    "problematiskares": "problematisk",
    "problematiskas": "problematisk",
    "problematiskast": "problematisk",
    "problematiskaste": "problematisk",
    "problematiskastes": "problematisk",
    "problematiskasts": "problematisk",
    "problematiske": "problematisk",
    "problematiskes": "problematisk",
    "problematisks": "problematisk",
    "problematiskt": "problematisk",
    "problematiskts": "problematisk",
    "problembarnen": "problembarn",
    "problembarnens": "problembarn",
    "problembarnet": "problembarn",
    "problembarnets": "problembarn",
    "problembarns": "problembarn",
    "problemdegar": "problemdeg",
    "problemdegarna": "problemdeg",
    "problemdegarnas": "problemdeg",
    "problemdegars": "problemdeg",
    "problemdegen": "problemdeg",
    "problemdegens": "problemdeg",
    "problemdegs": "problemdeg",
    "problemdiktningar": "problemdiktning",
    "problemdiktningarna": "problemdiktning",
    "problemdiktningarnas": "problemdiktning",
    "problemdiktningars": "problemdiktning",
    "problemdiktningen": "problemdiktning",
    "problemdiktningens": "problemdiktning",
    "problemdiktnings": "problemdiktning",
    "problemen": "problem",
    "problemens": "problem",
    "problemet": "problem",
    "problemets": "problem",
    "problemformuleringar": "problemformulering",
    "problemformuleringarna": "problemformulering",
    "problemformuleringarnas": "problemformulering",
    "problemformuleringars": "problemformulering",
    "problemformuleringen": "problemformulering",
    "problemformuleringens": "problemformulering",
    "problemformulerings": "problemformulering",
    "problemformuleringsprivilegie": "problemformuleringsprivilegium",
    "problemformuleringsprivilegier": "problemformuleringsprivilegium",
    "problemformuleringsprivilegierna": "problemformuleringsprivilegium",
    "problemformuleringsprivilegiernas": "problemformuleringsprivilegium",
    "problemformuleringsprivilegiers": "problemformuleringsprivilegium",
    "problemformuleringsprivilegiet": "problemformuleringsprivilegium",
    "problemformuleringsprivilegiets": "problemformuleringsprivilegium",
    "problemformuleringsprivilegiums": "problemformuleringsprivilegium",
    "problemfria": "problemfri",
    "problemfriare": "problemfri",
    "problemfriares": "problemfri",
    "problemfrias": "problemfri",
    "problemfriast": "problemfri",
    "problemfriaste": "problemfri",
    "problemfriastes": "problemfri",
    "problemfriasts": "problemfri",
    "problemfrie": "problemfri",
    "problemfries": "problemfri",
    "problemfris": "problemfri",
    "problemfritt": "problemfri",
    "problemfritts": "problemfri",
    "problemkomplexen": "problemkomplex",
    "problemkomplexens": "problemkomplex",
    "problemkomplexet": "problemkomplex",
    "problemkomplexets": "problemkomplex",
    "problemorienterade": "problemorienterad",
    "problemorienterades": "problemorienterad",
    "problemorienterads": "problemorienterad",
    "problemorienterat": "problemorienterad",
    "problemorienterats": "problemorienterad",
    "problemorienteringar": "problemorientering",
    "problemorienteringarna": "problemorientering",
    "problemorienteringarnas": "problemorientering",
    "problemorienteringars": "problemorientering",
    "problemorienteringen": "problemorientering",
    "problemorienteringens": "problemorientering",
    "problemorienterings": "problemorientering",
    "problems": "problem",
    "problemställningar": "problemställning",
    "problemställningarna": "problemställning",
    "problemställningarnas": "problemställning",
    "problemställningars": "problemställning",
    "problemställningen": "problemställning",
    "problemställningens": "problemställning",
    "problemställnings": "problemställning",
    "proceduren": "procedur",
    "procedurens": "procedur",
    "procedurer": "procedur",
    "procedurerna": "procedur",
    "procedurernas": "procedur",
    "procedurers": "procedur",
    "procedurs": "procedur",
    "procentade": "procenta",
    "procentades": "procenta",
    "procentande": "procenta",
    "procentanden": "procentande",
    "procentandena": "procentande",
    "procentandenas": "procentande",
    "procentandens": "procentande",
    "procentandes": "procentande",
    "procentandet": "procentande",
    "procentandets": "procentande",
    "procentar": "procentare",
    "procentaren": "procentare",
    "procentarens": "procentare",
    "procentares": "procentare",
    "procentarna": "procentare",
    "procentarnas": "procentare",
    "procentas": "procenta",
    "procentat": "procenta",
    "procentats": "procenta",
    "procenten": "procent",
    "procentenheten": "procentenhet",
    "procentenhetens": "procentenhet",
    "procentenheter": "procentenhet",
    "procentenheterna": "procentenhet",
    "procentenheternas": "procentenhet",
    "procentenheters": "procentenhet",
    "procentenhets": "procentenhet",
    "procentens": "procent",
    "procenteriet": "procenteri",
    "procenteriets": "procenteri",
    "procenteris": "procenteri",
    "procenterit": "procenteri",
    "procenterits": "procenteri",
    "procentiga": "procentig",
    "procentigare": "procentig",
    "procentigares": "procentig",
    "procentigas": "procentig",
    "procentigast": "procentig",
    "procentigaste": "procentig",
    "procentigastes": "procentig",
    "procentigasts": "procentig",
    "procentige": "procentig",
    "procentiges": "procentig",
    "procentigs": "procentig",
    "procentigt": "procentig",
    "procentigts": "procentig",
    "procentiska": "procentisk",
    "procentiskare": "procentisk",
    "procentiskares": "procentisk",
    "procentiskas": "procentisk",
    "procentiskast": "procentisk",
    "procentiskaste": "procentisk",
    "procentiskastes": "procentisk",
    "procentiskasts": "procentisk",
    "procentiske": "procentisk",
    "procentiskes": "procentisk",
    "procentisks": "procentisk",
    "procentiskt": "procentisk",
    "procentiskts": "procentisk",
    "procents": "procent",
    "procentuella": "procentuell",
    "procentuellare": "procentuell",
    "procentuellares": "procentuell",
    "procentuellas": "procentuell",
    "procentuellast": "procentuell",
    "procentuellaste": "procentuell",
    "procentuellastes": "procentuell",
    "procentuellasts": "procentuell",
    "procentuelle": "procentuell",
    "procentuelles": "procentuell",
    "procentuells": "procentuell",
    "procentuellt": "procentuell",
    "procentuellts": "procentuell",
    "procentvärden": "procentvärde",
    "procentvärdena": "procentvärde",
    "procentvärdenas": "procentvärde",
    "procentvärdens": "procentvärde",
    "procentvärdes": "procentvärde",
    "procentvärdet": "procentvärde",
    "procentvärdets": "procentvärde",
    "processad": "processa",
    "processade": "processa",
    "processades": "processa",
    "processads": "processa",
    "processande": "processa",
    "processanden": "processande",
    "processandena": "processande",
    "processandenas": "processande",
    "processandens": "processande",
    "processandes": "processande",
    "processandet": "processande",
    "processandets": "processande",
    "processar": "processa",
    "processas": "processa",
    "processat": "processa",
    "processats": "processa",
    "processen": "process",
    "processens": "process",
    "processer": "process",
    "processerna": "process",
    "processernas": "process",
    "processers": "process",
    "processindustrien": "processindustri",
    "processindustriens": "processindustri",
    "processindustrier": "processindustri",
    "processindustrierna": "processindustri",
    "processindustriernas": "processindustri",
    "processindustriers": "processindustri",
    "processindustrin": "processindustri",
    "processindustrins": "processindustri",
    "processindustris": "processindustri",
    "processingenjören": "processingenjör",
    "processingenjörens": "processingenjör",
    "processingenjörer": "processingenjör",
    "processingenjörerna": "processingenjör",
    "processingenjörernas": "processingenjör",
    "processingenjörers": "processingenjör",
    "processingenjörn": "processingenjör",
    "processingenjörns": "processingenjör",
    "processingenjörs": "processingenjör",
    "processinriktade": "processinriktad",
    "processinriktades": "processinriktad",
    "processinriktads": "processinriktad",
    "processinriktat": "processinriktad",
    "processinriktats": "processinriktad",
    "processionen": "procession",
    "processionens": "procession",
    "processioner": "procession",
    "processionerna": "procession",
    "processionernas": "procession",
    "processioners": "procession",
    "processions": "procession",
    "processorer": "processor",
    "processorerna": "processor",
    "processorernas": "processor",
    "processorers": "processor",
    "processorn": "processor",
    "processorns": "processor",
    "processors": "processor",
    "processrätten": "processrätt",
    "processrättens": "processrätt",
    "processrätts": "processrätt",
    "processuella": "processuell",
    "processuellare": "processuell",
    "processuellares": "processuell",
    "processuellas": "processuell",
    "processuellast": "processuell",
    "processuellaste": "processuell",
    "processuellastes": "processuell",
    "processuellasts": "processuell",
    "processuelle": "processuell",
    "processuelles": "processuell",
    "processuells": "processuell",
    "processuellt": "processuell",
    "processuellts": "processuell",
    "producenten": "producent",
    "producentens": "producent",
    "producenter": "producent",
    "producenterna": "producent",
    "producenternas": "producent",
    "producenters": "producent",
    "producents": "producent",
    "producerad": "producera",
    "producerade": "producera",
    "producerades": "producera",
    "producerads": "producera",
    "producerande": "producera",
    "produceranden": "producerande",
    "producerandena": "producerande",
    "producerandenas": "producerande",
    "producerandens": "producerande",
    "producerandes": "producerande",
    "producerandet": "producerande",
    "producerandets": "producerande",
    "producerar": "producera",
    "produceras": "producera",
    "producerat": "producera",
    "producerats": "producera",
    "producerbara": "producerbar",
    "producerbarare": "producerbar",
    "producerbarares": "producerbar",
    "producerbaras": "producerbar",
    "producerbarast": "producerbar",
    "producerbaraste": "producerbar",
    "producerbarastes": "producerbar",
    "producerbarasts": "producerbar",
    "producerbare": "producerbar",
    "producerbares": "producerbar",
    "producerbarheten": "producerbarhet",
    "producerbarhetens": "producerbarhet",
    "producerbarhets": "producerbarhet",
    "producerbars": "producerbar",
    "producerbart": "producerbar",
    "producerbarts": "producerbar",
    "produceringar": "producering",
    "produceringarna": "producering",
    "produceringarnas": "producering",
    "produceringars": "producering",
    "produceringen": "producering",
    "produceringens": "producering",
    "producerings": "producering",
    "produkten": "produkt",
    "produktens": "produkt",
    "produkter": "produkt",
    "produkterna": "produkt",
    "produkternas": "produkt",
    "produkters": "produkt",
    "produktionen": "produktion",
    "produktionens": "produktion",
    "produktioner": "produktion",
    "produktionerna": "produktion",
    "produktionernas": "produktion",
    "produktioners": "produktion",
    "produktions": "produktion",
    "produktionsapparaten": "produktionsapparat",
    "produktionsapparatens": "produktionsapparat",
    "produktionsapparater": "produktionsapparat",
    "produktionsapparaterna": "produktionsapparat",
    "produktionsapparaternas": "produktionsapparat",
    "produktionsapparaters": "produktionsapparat",
    "produktionsapparats": "produktionsapparat",
    "produktionsbolagen": "produktionsbolag",
    "produktionsbolagens": "produktionsbolag",
    "produktionsbolaget": "produktionsbolag",
    "produktionsbolagets": "produktionsbolag",
    "produktionsbolags": "produktionsbolag",
    "produktionsfaktorer": "produktionsfaktor",
    "produktionsfaktorerna": "produktionsfaktor",
    "produktionsfaktorernas": "produktionsfaktor",
    "produktionsfaktorers": "produktionsfaktor",
    "produktionsfaktorn": "produktionsfaktor",
    "produktionsfaktorns": "produktionsfaktor",
    "produktionsfaktors": "produktionsfaktor",
    "produktionsförhållanden": "produktionsförhållande",
    "produktionsförhållandena": "produktionsförhållande",
    "produktionsförhållandenas": "produktionsförhållande",
    "produktionsförhållandens": "produktionsförhållande",
    "produktionsförhållandes": "produktionsförhållande",
    "produktionsförhållandet": "produktionsförhållande",
    "produktionsförhållandets": "produktionsförhållande",
    "produktionskostnaden": "produktionskostnad",
    "produktionskostnadens": "produktionskostnad",
    "produktionskostnader": "produktionskostnad",
    "produktionskostnaderna": "produktionskostnad",
    "produktionskostnadernas": "produktionskostnad",
    "produktionskostnaders": "produktionskostnad",
    "produktionskostnads": "produktionskostnad",
    "produktionsmedels": "produktionsmedel",
    "produktionsmedlen": "produktionsmedel",
    "produktionsmedlens": "produktionsmedel",
    "produktionsmedlet": "produktionsmedel",
    "produktionsmedlets": "produktionsmedel",
    "produktionsmässiga": "produktionsmässig",
    "produktionsmässigare": "produktionsmässig",
    "produktionsmässigares": "produktionsmässig",
    "produktionsmässigas": "produktionsmässig",
    "produktionsmässigast": "produktionsmässig",
    "produktionsmässigaste": "produktionsmässig",
    "produktionsmässigastes": "produktionsmässig",
    "produktionsmässigasts": "produktionsmässig",
    "produktionsmässige": "produktionsmässig",
    "produktionsmässiges": "produktionsmässig",
    "produktionsmässigs": "produktionsmässig",
    "produktionsmässigt": "produktionsmässig",
    "produktionsmässigts": "produktionsmässig",
    "produktionsskatten": "produktionsskatt",
    "produktionsskattens": "produktionsskatt",
    "produktionsskatter": "produktionsskatt",
    "produktionsskatterna": "produktionsskatt",
    "produktionsskatternas": "produktionsskatt",
    "produktionsskatters": "produktionsskatt",
    "produktionsskatts": "produktionsskatt",
    "produktionstekniken": "produktionsteknik",
    "produktionsteknikens": "produktionsteknik",
    "produktionstekniker": "produktionsteknik",
    "produktionsteknikerna": "produktionsteknik",
    "produktionsteknikernas": "produktionsteknik",
    "produktionsteknikers": "produktionsteknik",
    "produktionstekniks": "produktionsteknik",
    "produktiva": "produktiv",
    "produktivare": "produktiv",
    "produktivares": "produktiv",
    "produktivas": "produktiv",
    "produktivast": "produktiv",
    "produktivaste": "produktiv",
    "produktivastes": "produktiv",
    "produktivasts": "produktiv",
    "produktive": "produktiv",
    "produktives": "produktiv",
    "produktiviteten": "produktivitet",
    "produktivitetens": "produktivitet",
    "produktiviteter": "produktivitet",
    "produktiviteterna": "produktivitet",
    "produktiviteternas": "produktivitet",
    "produktiviteters": "produktivitet",
    "produktivitets": "produktivitet",
    "produktivkraften": "produktivkraft",
    "produktivkraftens": "produktivkraft",
    "produktivkrafter": "produktivkraft",
    "produktivkrafterna": "produktivkraft",
    "produktivkrafternas": "produktivkraft",
    "produktivkrafters": "produktivkraft",
    "produktivkrafts": "produktivkraft",
    "produktivs": "produktiv",
    "produktivt": "produktiv",
    "produktivts": "produktiv",
    "produktmängden": "produktmängd",
    "produktmängdens": "produktmängd",
    "produktmängder": "produktmängd",
    "produktmängderna": "produktmängd",
    "produktmängdernas": "produktmängd",
    "produktmängders": "produktmängd",
    "produktmängds": "produktmängd",
    "produktmässiga": "produktmässig",
    "produktmässigare": "produktmässig",
    "produktmässigares": "produktmässig",
    "produktmässigas": "produktmässig",
    "produktmässigast": "produktmässig",
    "produktmässigaste": "produktmässig",
    "produktmässigastes": "produktmässig",
    "produktmässigasts": "produktmässig",
    "produktmässige": "produktmässig",
    "produktmässiges": "produktmässig",
    "produktmässigs": "produktmässig",
    "produktmässigt": "produktmässig",
    "produktmässigts": "produktmässig",
    "produktplaneringar": "produktplanering",
    "produktplaneringarna": "produktplanering",
    "produktplaneringarnas": "produktplanering",
    "produktplaneringars": "produktplanering",
    "produktplaneringen": "produktplanering",
    "produktplaneringens": "produktplanering",
    "produktplanerings": "produktplanering",
    "produkts": "produkt",
    "produktutvecklingen": "produktutveckling",
    "produktutvecklingens": "produktutveckling",
    "produktutvecklings": "produktutveckling",
    "profana": "profan",
    "profanare": "profan",
    "profanares": "profan",
    "profanas": "profan",
    "profanast": "profan",
    "profanaste": "profan",
    "profanastes": "profan",
    "profanasts": "profan",
    "profanationen": "profanation",
    "profanationens": "profanation",
    "profanationer": "profanation",
    "profanationerna": "profanation",
    "profanationernas": "profanation",
    "profanationers": "profanation",
    "profanations": "profanation",
    "profane": "profan",
    "profanerad": "profanera",
    "profanerade": "profanera",
    "profanerades": "profanera",
    "profanerads": "profanera",
    "profanerande": "profanera",
    "profaneranden": "profanerande",
    "profanerandena": "profanerande",
    "profanerandenas": "profanerande",
    "profanerandens": "profanerande",
    "profanerandes": "profanerande",
    "profanerandet": "profanerande",
    "profanerandets": "profanerande",
    "profanerar": "profanera",
    "profaneras": "profanera",
    "profanerat": "profanera",
    "profanerats": "profanera",
    "profanerbara": "profanerbar",
    "profanerbarare": "profanerbar",
    "profanerbarares": "profanerbar",
    "profanerbaras": "profanerbar",
    "profanerbarast": "profanerbar",
    "profanerbaraste": "profanerbar",
    "profanerbarastes": "profanerbar",
    "profanerbarasts": "profanerbar",
    "profanerbare": "profanerbar",
    "profanerbares": "profanerbar",
    "profanerbarheten": "profanerbarhet",
    "profanerbarhetens": "profanerbarhet",
    "profanerbarhets": "profanerbarhet",
    "profanerbars": "profanerbar",
    "profanerbart": "profanerbar",
    "profanerbarts": "profanerbar",
    "profaneringar": "profanering",
    "profaneringarna": "profanering",
    "profaneringarnas": "profanering",
    "profaneringars": "profanering",
    "profaneringen": "profanering",
    "profaneringens": "profanering",
    "profanerings": "profanering",
    "profanes": "profan",
    "profans": "profan",
    "profant": "profan",
    "profants": "profan",
    "professionaliserad": "professionalisera",
    "professionaliserade": "professionalisera",
    "professionaliserades": "professionalisera",
    "professionaliserads": "professionalisera",
    "professionaliserande": "professionalisera",
    "professionaliseranden": "professionaliserande",
    "professionaliserandena": "professionaliserande",
    "professionaliserandenas": "professionaliserande",
    "professionaliserandens": "professionaliserande",
    "professionaliserandes": "professionaliserande",
    "professionaliserandet": "professionaliserande",
    "professionaliserandets": "professionaliserande",
    "professionaliserar": "professionalisera",
    "professionaliseras": "professionalisera",
    "professionaliserat": "professionalisera",
    "professionaliserats": "professionalisera",
    "professionaliserbara": "professionaliserbar",
    "professionaliserbarare": "professionaliserbar",
    "professionaliserbarares": "professionaliserbar",
    "professionaliserbaras": "professionaliserbar",
    "professionaliserbarast": "professionaliserbar",
    "professionaliserbaraste": "professionaliserbar",
    "professionaliserbarastes": "professionaliserbar",
    "professionaliserbarasts": "professionaliserbar",
    "professionaliserbare": "professionaliserbar",
    "professionaliserbares": "professionaliserbar",
    "professionaliserbarheten": "professionaliserbarhet",
    "professionaliserbarhetens": "professionaliserbarhet",
    "professionaliserbarhets": "professionaliserbarhet",
    "professionaliserbars": "professionaliserbar",
    "professionaliserbart": "professionaliserbar",
    "professionaliserbarts": "professionaliserbar",
    "professionaliseringar": "professionalisering",
    "professionaliseringarna": "professionalisering",
    "professionaliseringarnas": "professionalisering",
    "professionaliseringars": "professionalisering",
    "professionaliseringen": "professionalisering",
    "professionaliseringens": "professionalisering",
    "professionaliserings": "professionalisering",
    "professionalismen": "professionalism",
    "professionalismens": "professionalism",
    "professionalismer": "professionalism",
    "professionalismerna": "professionalism",
    "professionalismernas": "professionalism",
    "professionalismers": "professionalism",
    "professionalisms": "professionalism",
    "professionaliteten": "professionalitet",
    "professionalitetens": "professionalitet",
    "professionalitets": "professionalitet",
    "professionella": "professionell",
    "professionellare": "professionell",
    "professionellares": "professionell",
    "professionellas": "professionell",
    "professionellast": "professionell",
    "professionellaste": "professionell",
    "professionellastes": "professionell",
    "professionellasts": "professionell",
    "professionelle": "professionell",
    "professionelles": "professionell",
    "professionells": "professionell",
    "professionellt": "professionell",
    "professionellts": "professionell",
    "professionen": "profession",
    "professionens": "profession",
    "professioner": "profession",
    "professionerna": "profession",
    "professionernas": "profession",
    "professioners": "profession",
    "professions": "profession",
    "professorer": "professor",
    "professorerna": "professor",
    "professorernas": "professor",
    "professorers": "professor",
    "professorliga": "professorlig",
    "professorligare": "professorlig",
    "professorligares": "professorlig",
    "professorligas": "professorlig",
    "professorligast": "professorlig",
    "professorligaste": "professorlig",
    "professorligastes": "professorlig",
    "professorligasts": "professorlig",
    "professorlige": "professorlig",
    "professorliges": "professorlig",
    "professorligheten": "professorlighet",
    "professorlighetens": "professorlighet",
    "professorlighets": "professorlighet",
    "professorligs": "professorlig",
    "professorligt": "professorlig",
    "professorligts": "professorlig",
    "professorn": "professor",
    "professorns": "professor",
    "professors": "professor",
    "professorskan": "professorska",
    "professorskans": "professorska",
    "professorskas": "professorska",
    "professorske": "professorska",
    "professorskor": "professorska",
    "professorskorna": "professorska",
    "professorskornas": "professorska",
    "professorskors": "professorska",
    "professorstillsättningar": "professorstillsättning",
    "professorstillsättningarna": "professorstillsättning",
    "professorstillsättningarnas": "professorstillsättning",
    "professorstillsättningars": "professorstillsättning",
    "professorstillsättningen": "professorstillsättning",
    "professorstillsättningens": "professorstillsättning",
    "professorstillsättnings": "professorstillsättning",
    "professuren": "professur",
    "professurens": "professur",
    "professurer": "professur",
    "professurerna": "professur",
    "professurernas": "professur",
    "professurers": "professur",
    "professurs": "professur",
    "profeten": "profet",
    "profetens": "profet",
    "profeter": "profet",
    "profeterade": "profetera",
    "profeterades": "profetera",
    "profeterande": "profetera",
    "profeteranden": "profeterande",
    "profeterandena": "profeterande",
    "profeterandenas": "profeterande",
    "profeterandens": "profeterande",
    "profeterandes": "profeterande",
    "profeterandet": "profeterande",
    "profeterandets": "profeterande",
    "profeterar": "profetera",
    "profeteras": "profetera",
    "profeterat": "profetera",
    "profeterats": "profetera",
    "profeteringar": "profetering",
    "profeteringarna": "profetering",
    "profeteringarnas": "profetering",
    "profeteringars": "profetering",
    "profeteringen": "profetering",
    "profeteringens": "profetering",
    "profeterings": "profetering",
    "profeterna": "profet",
    "profeternas": "profet",
    "profeters": "profet",
    "profeti": "profetia",
    "profetian": "profetia",
    "profetians": "profetia",
    "profetias": "profetia",
    "profetie": "profetia",
    "profetior": "profetia",
    "profetiorna": "profetia",
    "profetiornas": "profetia",
    "profetiors": "profetia",
    "profetis": "profetia",
    "profetiska": "profetisk",
    "profetiskare": "profetisk",
    "profetiskares": "profetisk",
    "profetiskas": "profetisk",
    "profetiskast": "profetisk",
    "profetiskaste": "profetisk",
    "profetiskastes": "profetisk",
    "profetiskasts": "profetisk",
    "profetiske": "profetisk",
    "profetiskes": "profetisk",
    "profetisks": "profetisk",
    "profetiskt": "profetisk",
    "profetiskts": "profetisk",
    "profets": "profet",
    "proffsdemonstranten": "proffsdemonstrant",
    "proffsdemonstrantens": "proffsdemonstrant",
    "proffsdemonstranter": "proffsdemonstrant",
    "proffsdemonstranterna": "proffsdemonstrant",
    "proffsdemonstranternas": "proffsdemonstrant",
    "proffsdemonstranters": "proffsdemonstrant",
    "proffsdemonstrants": "proffsdemonstrant",
    "proffsen": "proffs",
    "proffsens": "proffs",
    "proffset": "proffs",
    "proffsets": "proffs",
    "proffsiga": "proffsig",
    "proffsigare": "proffsig",
    "proffsigares": "proffsig",
    "proffsigas": "proffsig",
    "proffsigast": "proffsig",
    "proffsigaste": "proffsig",
    "proffsigastes": "proffsig",
    "proffsigasts": "proffsig",
    "proffsige": "proffsig",
    "proffsiges": "proffsig",
    "proffsigheten": "proffsighet",
    "proffsighetens": "proffsighet",
    "proffsighets": "proffsighet",
    "proffsigs": "proffsig",
    "proffsigt": "proffsig",
    "proffsigts": "proffsig",
    "proffsspelar": "proffsspelare",
    "proffsspelaren": "proffsspelare",
    "proffsspelarens": "proffsspelare",
    "proffsspelares": "proffsspelare",
    "proffsspelarna": "proffsspelare",
    "proffsspelarnas": "proffsspelare",
    "proffsvinnar": "proffsvinnare",
    "proffsvinnaren": "proffsvinnare",
    "proffsvinnarens": "proffsvinnare",
    "proffsvinnares": "proffsvinnare",
    "proffsvinnarna": "proffsvinnare",
    "proffsvinnarnas": "proffsvinnare",
    "profilen": "profil",
    "profilens": "profil",
    "profiler": "profil",
    "profilerad": "profilera",
    "profilerade": "profilerad",
    "profilerades": "profilerad",
    "profilerads": "profilerad",
    "profilerande": "profilera",
    "profileranden": "profilerande",
    "profilerandena": "profilerande",
    "profilerandenas": "profilerande",
    "profilerandens": "profilerande",
    "profilerandes": "profilerande",
    "profilerandet": "profilerande",
    "profilerandets": "profilerande",
    "profilerar": "profilera",
    "profileras": "profilera",
    "profilerat": "profilerad",
    "profilerats": "profilerad",
    "profilerbara": "profilerbar",
    "profilerbarare": "profilerbar",
    "profilerbarares": "profilerbar",
    "profilerbaras": "profilerbar",
    "profilerbarast": "profilerbar",
    "profilerbaraste": "profilerbar",
    "profilerbarastes": "profilerbar",
    "profilerbarasts": "profilerbar",
    "profilerbare": "profilerbar",
    "profilerbares": "profilerbar",
    "profilerbarheten": "profilerbarhet",
    "profilerbarhetens": "profilerbarhet",
    "profilerbarhets": "profilerbarhet",
    "profilerbars": "profilerbar",
    "profilerbart": "profilerbar",
    "profilerbarts": "profilerbar",
    "profileringar": "profilering",
    "profileringarna": "profilering",
    "profileringarnas": "profilering",
    "profileringars": "profilering",
    "profileringen": "profilering",
    "profileringens": "profilering",
    "profilerings": "profilering",
    "profilerna": "profil",
    "profilernas": "profil",
    "profilers": "profil",
    "profiljärnet": "profiljärn",
    "profiljärnets": "profiljärn",
    "profiljärns": "profiljärn",
    "profils": "profil",
    "profilspåren": "profilspår",
    "profilspårens": "profilspår",
    "profilspåret": "profilspår",
    "profilspårets": "profilspår",
    "profilspårs": "profilspår",
    "profiten": "profit",
    "profitens": "profit",
    "profiter": "profit",
    "profiterade": "profitera",
    "profiterades": "profitera",
    "profiterande": "profitera",
    "profiteranden": "profiterande",
    "profiterandena": "profiterande",
    "profiterandenas": "profiterande",
    "profiterandens": "profiterande",
    "profiterandes": "profiterande",
    "profiterandet": "profiterande",
    "profiterandets": "profiterande",
    "profiterar": "profitera",
    "profiteras": "profitera",
    "profiterat": "profitera",
    "profiterats": "profitera",
    "profiteringar": "profitering",
    "profiteringarna": "profitering",
    "profiteringarnas": "profitering",
    "profiteringars": "profitering",
    "profiteringen": "profitering",
    "profiteringens": "profitering",
    "profiterings": "profitering",
    "profiterna": "profit",
    "profiternas": "profit",
    "profiters": "profit",
    "profithajar": "profithaj",
    "profithajarna": "profithaj",
    "profithajarnas": "profithaj",
    "profithajars": "profithaj",
    "profithajen": "profithaj",
    "profithajens": "profithaj",
    "profithajs": "profithaj",
    "profits": "profit",
    "profitören": "profitör",
    "profitörens": "profitör",
    "profitörer": "profitör",
    "profitörerna": "profitör",
    "profitörernas": "profitör",
    "profitörers": "profitör",
    "profitörs": "profitör",
    "profossen": "profoss",
    "profossens": "profoss",
    "profosser": "profoss",
    "profosserna": "profoss",
    "profossernas": "profoss",
    "profossers": "profoss",
    "profylaktiska": "profylaktisk",
    "profylaktiskare": "profylaktisk",
    "profylaktiskares": "profylaktisk",
    "profylaktiskas": "profylaktisk",
    "profylaktiskast": "profylaktisk",
    "profylaktiskaste": "profylaktisk",
    "profylaktiskastes": "profylaktisk",
    "profylaktiskasts": "profylaktisk",
    "profylaktiske": "profylaktisk",
    "profylaktiskes": "profylaktisk",
    "profylaktisks": "profylaktisk",
    "profylaktiskt": "profylaktisk",
    "profylaktiskts": "profylaktisk",
    "profylaxen": "profylax",
    "profylaxens": "profylax",
    "progal": "progala",
    "progalan": "progala",
    "progalans": "progala",
    "progalas": "progala",
    "progale": "progala",
    "progalor": "progala",
    "progalorna": "progala",
    "progalornas": "progala",
    "progalors": "progala",
    "progals": "progala",
    "progen": "prog",
    "progens": "prog",
    "progesteronet": "progesteron",
    "progesteronets": "progesteron",
    "progesterons": "progesteron",
    "proggar": "proggare",
    "proggaren": "proggare",
    "proggarens": "proggare",
    "proggares": "proggare",
    "proggarna": "proggare",
    "proggarnas": "proggare",
    "proggbanden": "proggband",
    "proggbandens": "proggband",
    "proggbandet": "proggband",
    "proggbandets": "proggband",
    "proggbands": "proggband",
    "proggen": "progg",
    "proggens": "progg",
    "proggs": "progg",
    "prognata": "prognat",
    "prognatare": "prognat",
    "prognatares": "prognat",
    "prognatas": "prognat",
    "prognatast": "prognat",
    "prognataste": "prognat",
    "prognatastes": "prognat",
    "prognatasts": "prognat",
    "prognate": "prognat",
    "prognates": "prognat",
    "prognats": "prognat",
    "prognosen": "prognos",
    "prognosens": "prognos",
    "prognoser": "prognos",
    "prognoserna": "prognos",
    "prognosernas": "prognos",
    "prognosers": "prognos",
    "prognostiserad": "prognostisera",
    "prognostiserade": "prognostisera",
    "prognostiserades": "prognostisera",
    "prognostiserads": "prognostisera",
    "prognostiserande": "prognostisera",
    "prognostiseranden": "prognostiserande",
    "prognostiserandena": "prognostiserande",
    "prognostiserandenas": "prognostiserande",
    "prognostiserandens": "prognostiserande",
    "prognostiserandes": "prognostiserande",
    "prognostiserandet": "prognostiserande",
    "prognostiserandets": "prognostiserande",
    "prognostiserar": "prognostisera",
    "prognostiseras": "prognostisera",
    "prognostiserat": "prognostisera",
    "prognostiserats": "prognostisera",
    "prognostiserbara": "prognostiserbar",
    "prognostiserbarare": "prognostiserbar",
    "prognostiserbarares": "prognostiserbar",
    "prognostiserbaras": "prognostiserbar",
    "prognostiserbarast": "prognostiserbar",
    "prognostiserbaraste": "prognostiserbar",
    "prognostiserbarastes": "prognostiserbar",
    "prognostiserbarasts": "prognostiserbar",
    "prognostiserbare": "prognostiserbar",
    "prognostiserbares": "prognostiserbar",
    "prognostiserbarheten": "prognostiserbarhet",
    "prognostiserbarhetens": "prognostiserbarhet",
    "prognostiserbarhets": "prognostiserbarhet",
    "prognostiserbars": "prognostiserbar",
    "prognostiserbart": "prognostiserbar",
    "prognostiserbarts": "prognostiserbar",
    "prognostiseringar": "prognostisering",
    "prognostiseringarna": "prognostisering",
    "prognostiseringarnas": "prognostisering",
    "prognostiseringars": "prognostisering",
    "prognostiseringen": "prognostisering",
    "prognostiseringens": "prognostisering",
    "prognostiserings": "prognostisering",
    "prognostiska": "prognostisk",
    "prognostiskare": "prognostisk",
    "prognostiskares": "prognostisk",
    "prognostiskas": "prognostisk",
    "prognostiskast": "prognostisk",
    "prognostiskaste": "prognostisk",
    "prognostiskastes": "prognostisk",
    "prognostiskasts": "prognostisk",
    "prognostiske": "prognostisk",
    "prognostiskes": "prognostisk",
    "prognostisks": "prognostisk",
    "prognostiskt": "prognostisk",
    "prognostiskts": "prognostisk",
    "programbudgetar": "programbudget",
    "programbudgetarna": "programbudget",
    "programbudgetarnas": "programbudget",
    "programbudgetars": "programbudget",
    "programbudgeten": "programbudget",
    "programbudgetens": "programbudget",
    "programbudgeter": "programbudget",
    "programbudgeteringar": "programbudgetering",
    "programbudgeteringarna": "programbudgetering",
    "programbudgeteringarnas": "programbudgetering",
    "programbudgeteringars": "programbudgetering",
    "programbudgeteringen": "programbudgetering",
    "programbudgeteringens": "programbudgetering",
    "programbudgeterings": "programbudgetering",
    "programbudgeterna": "programbudget",
    "programbudgeternas": "programbudget",
    "programbudgeters": "programbudget",
    "programbudgets": "programbudget",
    "programchefen": "programchef",
    "programchefens": "programchef",
    "programchefer": "programchef",
    "programcheferna": "programchef",
    "programchefernas": "programchef",
    "programchefers": "programchef",
    "programchefs": "programchef",
    "programenliga": "programenlig",
    "programenligare": "programenlig",
    "programenligares": "programenlig",
    "programenligas": "programenlig",
    "programenligast": "programenlig",
    "programenligaste": "programenlig",
    "programenligastes": "programenlig",
    "programenligasts": "programenlig",
    "programenlige": "programenlig",
    "programenliges": "programenlig",
    "programenligheten": "programenlighet",
    "programenlighetens": "programenlighet",
    "programenlighets": "programenlighet",
    "programenligs": "programenlig",
    "programenligt": "programenlig",
    "programenligts": "programenlig",
    "programformaten": "programformat",
    "programformatens": "programformat",
    "programformatet": "programformat",
    "programformatets": "programformat",
    "programformats": "programformat",
    "programförklaringar": "programförklaring",
    "programförklaringarna": "programförklaring",
    "programförklaringarnas": "programförklaring",
    "programförklaringars": "programförklaring",
    "programförklaringen": "programförklaring",
    "programförklaringens": "programförklaring",
    "programförklarings": "programförklaring",
    "programkoden": "programkod",
    "programkodens": "programkod",
    "programkods": "programkod",
    "programlandet": "programland",
    "programlandets": "programland",
    "programlands": "programland",
    "programledar": "programledare",
    "programledaren": "programledare",
    "programledarens": "programledare",
    "programledares": "programledare",
    "programledarmässiga": "programledarmässig",
    "programledarmässigare": "programledarmässig",
    "programledarmässigares": "programledarmässig",
    "programledarmässigas": "programledarmässig",
    "programledarmässigast": "programledarmässig",
    "programledarmässigaste": "programledarmässig",
    "programledarmässigastes": "programledarmässig",
    "programledarmässigasts": "programledarmässig",
    "programledarmässige": "programledarmässig",
    "programledarmässiges": "programledarmässig",
    "programledarmässigs": "programledarmässig",
    "programledarmässigt": "programledarmässig",
    "programledarmässigts": "programledarmässig",
    "programledarna": "programledare",
    "programledarnas": "programledare",
    "programländer": "programland",
    "programländerna": "programland",
    "programländernas": "programland",
    "programländers": "programland",
    "programmatiska": "programmatisk",
    "programmatiskare": "programmatisk",
    "programmatiskares": "programmatisk",
    "programmatiskas": "programmatisk",
    "programmatiskast": "programmatisk",
    "programmatiskaste": "programmatisk",
    "programmatiskastes": "programmatisk",
    "programmatiskasts": "programmatisk",
    "programmatiske": "programmatisk",
    "programmatiskes": "programmatisk",
    "programmatisks": "programmatisk",
    "programmatiskt": "programmatisk",
    "programmatiskts": "programmatisk",
    "programmen": "program",
    "programmens": "program",
    "programmerad": "programmera",
    "programmerade": "programmera",
    "programmerades": "programmera",
    "programmerads": "programmera",
    "programmerande": "programmera",
    "programmeranden": "programmerande",
    "programmerandena": "programmerande",
    "programmerandenas": "programmerande",
    "programmerandens": "programmerande",
    "programmerandes": "programmerande",
    "programmerandet": "programmerande",
    "programmerandets": "programmerande",
    "programmerar": "programmerare",
    "programmeraren": "programmerare",
    "programmerarens": "programmerare",
    "programmerares": "programmerare",
    "programmerarna": "programmerare",
    "programmerarnas": "programmerare",
    "programmeras": "programmera",
    "programmerat": "programmera",
    "programmerats": "programmera",
    "programmerbara": "programmerbar",
    "programmerbarare": "programmerbar",
    "programmerbarares": "programmerbar",
    "programmerbaras": "programmerbar",
    "programmerbarast": "programmerbar",
    "programmerbaraste": "programmerbar",
    "programmerbarastes": "programmerbar",
    "programmerbarasts": "programmerbar",
    "programmerbare": "programmerbar",
    "programmerbares": "programmerbar",
    "programmerbarheten": "programmerbarhet",
    "programmerbarhetens": "programmerbarhet",
    "programmerbarhets": "programmerbarhet",
    "programmerbars": "programmerbar",
    "programmerbart": "programmerbar",
    "programmerbarts": "programmerbar",
    "programmeringar": "programmering",
    "programmeringarna": "programmering",
    "programmeringarnas": "programmering",
    "programmeringars": "programmering",
    "programmeringen": "programmering",
    "programmeringens": "programmering",
    "programmerings": "programmering",
    "programmeringsspråken": "programmeringsspråk",
    "programmeringsspråkens": "programmeringsspråk",
    "programmeringsspråket": "programmeringsspråk",
    "programmeringsspråkets": "programmeringsspråk",
    "programmeringsspråks": "programmeringsspråk",
    "programmet": "program",
    "programmets": "program",
    "programmoteken": "programmotek",
    "programmotekens": "programmotek",
    "programmoteket": "programmotek",
    "programmotekets": "programmotek",
    "programmoteks": "programmotek",
    "programmusiken": "programmusik",
    "programmusikens": "programmusik",
    "programmusiks": "programmusik",
    "programmässiga": "programmässig",
    "programmässigare": "programmässig",
    "programmässigares": "programmässig",
    "programmässigas": "programmässig",
    "programmässigast": "programmässig",
    "programmässigaste": "programmässig",
    "programmässigastes": "programmässig",
    "programmässigasts": "programmässig",
    "programmässige": "programmässig",
    "programmässiges": "programmässig",
    "programmässigs": "programmässig",
    "programmässigt": "programmässig",
    "programmässigts": "programmässig",
    "programproduktionen": "programproduktion",
    "programproduktionens": "programproduktion",
    "programproduktioner": "programproduktion",
    "programproduktionerna": "programproduktion",
    "programproduktionernas": "programproduktion",
    "programproduktioners": "programproduktion",
    "programproduktions": "programproduktion",
    "programpunkten": "programpunkt",
    "programpunktens": "programpunkt",
    "programpunkter": "programpunkt",
    "programpunkterna": "programpunkt",
    "programpunkternas": "programpunkt",
    "programpunkters": "programpunkt",
    "programpunkts": "programpunkt",
    "programs": "program",
    "programskriften": "programskrift",
    "programskriftens": "programskrift",
    "programskrifter": "programskrift",
    "programskrifterna": "programskrift",
    "programskrifternas": "programskrift",
    "programskrifters": "programskrift",
    "programskrifts": "programskrift",
    "programspråken": "programspråk",
    "programspråkens": "programspråk",
    "programspråket": "programspråk",
    "programspråkets": "programspråk",
    "programspråks": "programspråk",
    "programstyrningar": "programstyrning",
    "programstyrningarna": "programstyrning",
    "programstyrningarnas": "programstyrning",
    "programstyrningars": "programstyrning",
    "programstyrningen": "programstyrning",
    "programstyrningens": "programstyrning",
    "programstyrnings": "programstyrning",
    "programutgivar": "programutgivare",
    "programutgivaren": "programutgivare",
    "programutgivarens": "programutgivare",
    "programutgivares": "programutgivare",
    "programutgivarna": "programutgivare",
    "programutgivarnas": "programutgivare",
    "programutvecklar": "programutvecklare",
    "programutvecklaren": "programutvecklare",
    "programutvecklarens": "programutvecklare",
    "programutvecklares": "programutvecklare",
    "programutvecklarna": "programutvecklare",
    "programutvecklarnas": "programutvecklare",
    "programvar": "programvara",
    "programvaran": "programvara",
    "programvarans": "programvara",
    "programvaras": "programvara",
    "programvare": "programvara",
    "programvaror": "programvara",
    "programvarorna": "programvara",
    "programvarornas": "programvara",
    "programvarors": "programvara",
    "programvars": "programvara",
    "programväljar": "programväljare",
    "programväljaren": "programväljare",
    "programväljarens": "programväljare",
    "programväljares": "programväljare",
    "programväljarna": "programväljare",
    "programväljarnas": "programväljare",
    "progressen": "progress",
    "progressens": "progress",
    "progressionen": "progression",
    "progressionens": "progression",
    "progressioner": "progression",
    "progressionerna": "progression",
    "progressionernas": "progression",
    "progressioners": "progression",
    "progressions": "progression",
    "progressiva": "progressiv",
    "progressivare": "progressiv",
    "progressivares": "progressiv",
    "progressivas": "progressiv",
    "progressivast": "progressiv",
    "progressivaste": "progressiv",
    "progressivastes": "progressiv",
    "progressivasts": "progressiv",
    "progressive": "progressiv",
    "progressives": "progressiv",
    "progressivfjädringar": "progressivfjädring",
    "progressivfjädringarna": "progressivfjädring",
    "progressivfjädringarnas": "progressivfjädring",
    "progressivfjädringars": "progressivfjädring",
    "progressivfjädringen": "progressivfjädring",
    "progressivfjädringens": "progressivfjädring",
    "progressivfjädrings": "progressivfjädring",
    "progressiviteten": "progressivitet",
    "progressivitetens": "progressivitet",
    "progressiviteter": "progressivitet",
    "progressiviteterna": "progressivitet",
    "progressiviteternas": "progressivitet",
    "progressiviteters": "progressivitet",
    "progressivitets": "progressivitet",
    "progressivs": "progressiv",
    "progressivt": "progressiv",
    "progressivts": "progressiv",
    "progs": "prog",
    "prohibitiva": "prohibitiv",
    "prohibitivare": "prohibitiv",
    "prohibitivares": "prohibitiv",
    "prohibitivas": "prohibitiv",
    "prohibitivast": "prohibitiv",
    "prohibitivaste": "prohibitiv",
    "prohibitivastes": "prohibitiv",
    "prohibitivasts": "prohibitiv",
    "prohibitive": "prohibitiv",
    "prohibitives": "prohibitiv",
    "prohibitivs": "prohibitiv",
    "prohibitivt": "prohibitiv",
    "prohibitivts": "prohibitiv",
    "proinsulinen": "proinsulin",
    "proinsulinens": "proinsulin",
    "proinsuliner": "proinsulin",
    "proinsulinerna": "proinsulin",
    "proinsulinernas": "proinsulin",
    "proinsuliners": "proinsulin",
    "proinsulinet": "proinsulin",
    "proinsulinets": "proinsulin",
    "proinsulins": "proinsulin",
    "projekten": "projekt",
    "projektens": "projekt",
    "projekterad": "projektera",
    "projekterade": "projektera",
    "projekterades": "projektera",
    "projekterads": "projektera",
    "projekterande": "projektera",
    "projekteranden": "projekterande",
    "projekterandena": "projekterande",
    "projekterandenas": "projekterande",
    "projekterandens": "projekterande",
    "projekterandes": "projekterande",
    "projekterandet": "projekterande",
    "projekterandets": "projekterande",
    "projekterar": "projektera",
    "projekteras": "projektera",
    "projekterat": "projektera",
    "projekterats": "projektera",
    "projekterbara": "projekterbar",
    "projekterbarare": "projekterbar",
    "projekterbarares": "projekterbar",
    "projekterbaras": "projekterbar",
    "projekterbarast": "projekterbar",
    "projekterbaraste": "projekterbar",
    "projekterbarastes": "projekterbar",
    "projekterbarasts": "projekterbar",
    "projekterbare": "projekterbar",
    "projekterbares": "projekterbar",
    "projekterbarheten": "projekterbarhet",
    "projekterbarhetens": "projekterbarhet",
    "projekterbarhets": "projekterbarhet",
    "projekterbars": "projekterbar",
    "projekterbart": "projekterbar",
    "projekterbarts": "projekterbar",
    "projekteringar": "projektering",
    "projekteringarna": "projektering",
    "projekteringarnas": "projektering",
    "projekteringars": "projektering",
    "projekteringen": "projektering",
    "projekteringens": "projektering",
    "projekterings": "projektering",
    "projektet": "projekt",
    "projektets": "projekt",
    "projektilbanan": "projektilbana",
    "projektilbanans": "projektilbana",
    "projektilbanas": "projektilbana",
    "projektilbane": "projektilbana",
    "projektilbanor": "projektilbana",
    "projektilbanorna": "projektilbana",
    "projektilbanornas": "projektilbana",
    "projektilbanors": "projektilbana",
    "projektilen": "projektil",
    "projektilens": "projektil",
    "projektiler": "projektil",
    "projektilerna": "projektil",
    "projektilernas": "projektil",
    "projektilers": "projektil",
    "projektils": "projektil",
    "projektionen": "projektion",
    "projektionens": "projektion",
    "projektioner": "projektion",
    "projektionerna": "projektion",
    "projektionernas": "projektion",
    "projektioners": "projektion",
    "projektions": "projektion",
    "projektionsapparaten": "projektionsapparat",
    "projektionsapparatens": "projektionsapparat",
    "projektionsapparater": "projektionsapparat",
    "projektionsapparaterna": "projektionsapparat",
    "projektionsapparaternas": "projektionsapparat",
    "projektionsapparaters": "projektionsapparat",
    "projektionsapparats": "projektionsapparat",
    "projektiva": "projektiv",
    "projektivare": "projektiv",
    "projektivares": "projektiv",
    "projektivas": "projektiv",
    "projektivast": "projektiv",
    "projektivaste": "projektiv",
    "projektivastes": "projektiv",
    "projektivasts": "projektiv",
    "projektive": "projektiv",
    "projektives": "projektiv",
    "projektivs": "projektiv",
    "projektivt": "projektiv",
    "projektivts": "projektiv",
    "projektledar": "projektledare",
    "projektledaren": "projektledare",
    "projektledarens": "projektledare",
    "projektledares": "projektledare",
    "projektledarna": "projektledare",
    "projektledarnas": "projektledare",
    "projektorer": "projektor",
    "projektorerna": "projektor",
    "projektorernas": "projektor",
    "projektorers": "projektor",
    "projektorn": "projektor",
    "projektorns": "projektor",
    "projektors": "projektor",
    "projekts": "projekt",
    "projektören": "projektör",
    "projektörens": "projektör",
    "projektörer": "projektör",
    "projektörerna": "projektör",
    "projektörernas": "projektör",
    "projektörers": "projektör",
    "projektörs": "projektör",
    "projicerad": "projicera",
    "projicerade": "projicera",
    "projicerades": "projicera",
    "projicerads": "projicera",
    "projicerande": "projicera",
    "projiceranden": "projicerande",
    "projicerandena": "projicerande",
    "projicerandenas": "projicerande",
    "projicerandens": "projicerande",
    "projicerandes": "projicerande",
    "projicerandet": "projicerande",
    "projicerandets": "projicerande",
    "projicerar": "projicera",
    "projiceras": "projicera",
    "projicerat": "projicera",
    "projicerats": "projicera",
    "projicerbara": "projicerbar",
    "projicerbarare": "projicerbar",
    "projicerbarares": "projicerbar",
    "projicerbaras": "projicerbar",
    "projicerbarast": "projicerbar",
    "projicerbaraste": "projicerbar",
    "projicerbarastes": "projicerbar",
    "projicerbarasts": "projicerbar",
    "projicerbare": "projicerbar",
    "projicerbares": "projicerbar",
    "projicerbarheten": "projicerbarhet",
    "projicerbarhetens": "projicerbarhet",
    "projicerbarhets": "projicerbarhet",
    "projicerbars": "projicerbar",
    "projicerbart": "projicerbar",
    "projicerbarts": "projicerbar",
    "projiceringar": "projicering",
    "projiceringarna": "projicering",
    "projiceringarnas": "projicering",
    "projiceringars": "projicering",
    "projiceringen": "projicering",
    "projiceringens": "projicering",
    "projicerings": "projicering",
    "prokanslerer": "prokansler",
    "prokanslererna": "prokansler",
    "prokanslerernas": "prokansler",
    "prokanslerers": "prokansler",
    "prokanslern": "prokansler",
    "prokanslerns": "prokansler",
    "prokanslers": "prokansler",
    "proklamationen": "proklamation",
    "proklamationens": "proklamation",
    "proklamationer": "proklamation",
    "proklamationerna": "proklamation",
    "proklamationernas": "proklamation",
    "proklamationers": "proklamation",
    "proklamations": "proklamation",
    "proklamerad": "proklamera",
    "proklamerade": "proklamera",
    "proklamerades": "proklamera",
    "proklamerads": "proklamera",
    "proklamerande": "proklamera",
    "proklameranden": "proklamerande",
    "proklamerandena": "proklamerande",
    "proklamerandenas": "proklamerande",
    "proklamerandens": "proklamerande",
    "proklamerandes": "proklamerande",
    "proklamerandet": "proklamerande",
    "proklamerandets": "proklamerande",
    "proklamerar": "proklamera",
    "proklameras": "proklamera",
    "proklamerat": "proklamera",
    "proklamerats": "proklamera",
    "proklamerbara": "proklamerbar",
    "proklamerbarare": "proklamerbar",
    "proklamerbarares": "proklamerbar",
    "proklamerbaras": "proklamerbar",
    "proklamerbarast": "proklamerbar",
    "proklamerbaraste": "proklamerbar",
    "proklamerbarastes": "proklamerbar",
    "proklamerbarasts": "proklamerbar",
    "proklamerbare": "proklamerbar",
    "proklamerbares": "proklamerbar",
    "proklamerbarheten": "proklamerbarhet",
    "proklamerbarhetens": "proklamerbarhet",
    "proklamerbarhets": "proklamerbarhet",
    "proklamerbars": "proklamerbar",
    "proklamerbart": "proklamerbar",
    "proklamerbarts": "proklamerbar",
    "proklameringar": "proklamering",
    "proklameringarna": "proklamering",
    "proklameringarnas": "proklamering",
    "proklameringars": "proklamering",
    "proklameringen": "proklamering",
    "proklameringens": "proklamering",
    "proklamerings": "proklamering",
    "proklitiska": "proklitisk",
    "proklitiskare": "proklitisk",
    "proklitiskares": "proklitisk",
    "proklitiskas": "proklitisk",
    "proklitiskast": "proklitisk",
    "proklitiskaste": "proklitisk",
    "proklitiskastes": "proklitisk",
    "proklitiskasts": "proklitisk",
    "proklitiske": "proklitisk",
    "proklitiskes": "proklitisk",
    "proklitisks": "proklitisk",
    "proklitiskt": "proklitisk",
    "proklitiskts": "proklitisk",
    "prokrustesbäddar": "prokrustesbädd",
    "prokrustesbäddarna": "prokrustesbädd",
    "prokrustesbäddarnas": "prokrustesbädd",
    "prokrustesbäddars": "prokrustesbädd",
    "prokrustesbädden": "prokrustesbädd",
    "prokrustesbäddens": "prokrustesbädd",
    "prokrustesbädds": "prokrustesbädd",
    "prokrustiska": "prokrustisk",
    "prokrustiskare": "prokrustisk",
    "prokrustiskares": "prokrustisk",
    "prokrustiskas": "prokrustisk",
    "prokrustiskast": "prokrustisk",
    "prokrustiskaste": "prokrustisk",
    "prokrustiskastes": "prokrustisk",
    "prokrustiskasts": "prokrustisk",
    "prokrustiske": "prokrustisk",
    "prokrustiskes": "prokrustisk",
    "prokrustisks": "prokrustisk",
    "prokrustiskt": "prokrustisk",
    "prokrustiskts": "prokrustisk",
    "prokuran": "prokura",
    "prokurans": "prokura",
    "prokuras": "prokura",
    "prokuratorer": "prokurator",
    "prokuratorerna": "prokurator",
    "prokuratorernas": "prokurator",
    "prokuratorers": "prokurator",
    "prokuratorn": "prokurator",
    "prokuratorns": "prokurator",
    "prokurators": "prokurator",
    "prokuristen": "prokurist",
    "prokuristens": "prokurist",
    "prokurister": "prokurist",
    "prokuristerna": "prokurist",
    "prokuristernas": "prokurist",
    "prokuristers": "prokurist",
    "prokurists": "prokurist",
    "prolaktinen": "prolaktin",
    "prolaktinens": "prolaktin",
    "prolaktiner": "prolaktin",
    "prolaktinerna": "prolaktin",
    "prolaktinernas": "prolaktin",
    "prolaktiners": "prolaktin",
    "prolaktinet": "prolaktin",
    "prolaktinets": "prolaktin",
    "prolaktins": "prolaktin",
    "prolapsen": "prolaps",
    "prolapsens": "prolaps",
    "prolapser": "prolaps",
    "prolapserna": "prolaps",
    "prolapsernas": "prolaps",
    "prolapsers": "prolaps",
    "proletariatet": "proletariat",
    "proletariatets": "proletariat",
    "proletariats": "proletariat",
    "proletariserad": "proletarisera",
    "proletariserade": "proletarisera",
    "proletariserades": "proletarisera",
    "proletariserads": "proletarisera",
    "proletariserande": "proletarisera",
    "proletariseranden": "proletariserande",
    "proletariserandena": "proletariserande",
    "proletariserandenas": "proletariserande",
    "proletariserandens": "proletariserande",
    "proletariserandes": "proletariserande",
    "proletariserandet": "proletariserande",
    "proletariserandets": "proletariserande",
    "proletariserar": "proletarisera",
    "proletariseras": "proletarisera",
    "proletariserat": "proletarisera",
    "proletariserats": "proletarisera",
    "proletariserbara": "proletariserbar",
    "proletariserbarare": "proletariserbar",
    "proletariserbarares": "proletariserbar",
    "proletariserbaras": "proletariserbar",
    "proletariserbarast": "proletariserbar",
    "proletariserbaraste": "proletariserbar",
    "proletariserbarastes": "proletariserbar",
    "proletariserbarasts": "proletariserbar",
    "proletariserbare": "proletariserbar",
    "proletariserbares": "proletariserbar",
    "proletariserbarheten": "proletariserbarhet",
    "proletariserbarhetens": "proletariserbarhet",
    "proletariserbarhets": "proletariserbarhet",
    "proletariserbars": "proletariserbar",
    "proletariserbart": "proletariserbar",
    "proletariserbarts": "proletariserbar",
    "proletariseringar": "proletarisering",
    "proletariseringarna": "proletarisering",
    "proletariseringarnas": "proletarisering",
    "proletariseringars": "proletarisering",
    "proletariseringen": "proletarisering",
    "proletariseringens": "proletarisering",
    "proletariserings": "proletarisering",
    "proletära": "proletär",
    "proletärare": "proletär",
    "proletärares": "proletär",
    "proletäras": "proletär",
    "proletärast": "proletär",
    "proletäraste": "proletär",
    "proletärastes": "proletär",
    "proletärasts": "proletär",
    "proletäre": "proletär",
    "proletären": "proletär",
    "proletärens": "proletär",
    "proletärer": "proletär",
    "proletärerna": "proletär",
    "proletärernas": "proletär",
    "proletärers": "proletär",
    "proletäres": "proletär",
    "proletärs": "proletär",
    "proletärt": "proletär",
    "proletärts": "proletär",
    "prologen": "prolog",
    "prologens": "prolog",
    "prologer": "prolog",
    "prologerna": "prolog",
    "prologernas": "prolog",
    "prologers": "prolog",
    "prologs": "prolog",
    "prolongationen": "prolongation",
    "prolongationens": "prolongation",
    "prolongationer": "prolongation",
    "prolongationerna": "prolongation",
    "prolongationernas": "prolongation",
    "prolongationers": "prolongation",
    "prolongations": "prolongation",
    "prolongerad": "prolongera",
    "prolongerade": "prolongera",
    "prolongerades": "prolongera",
    "prolongerads": "prolongera",
    "prolongerande": "prolongera",
    "prolongeranden": "prolongerande",
    "prolongerandena": "prolongerande",
    "prolongerandenas": "prolongerande",
    "prolongerandens": "prolongerande",
    "prolongerandes": "prolongerande",
    "prolongerandet": "prolongerande",
    "prolongerandets": "prolongerande",
    "prolongerar": "prolongera",
    "prolongeras": "prolongera",
    "prolongerat": "prolongera",
    "prolongerats": "prolongera",
    "prolongerbara": "prolongerbar",
    "prolongerbarare": "prolongerbar",
    "prolongerbarares": "prolongerbar",
    "prolongerbaras": "prolongerbar",
    "prolongerbarast": "prolongerbar",
    "prolongerbaraste": "prolongerbar",
    "prolongerbarastes": "prolongerbar",
    "prolongerbarasts": "prolongerbar",
    "prolongerbare": "prolongerbar",
    "prolongerbares": "prolongerbar",
    "prolongerbarheten": "prolongerbarhet",
    "prolongerbarhetens": "prolongerbarhet",
    "prolongerbarhets": "prolongerbarhet",
    "prolongerbars": "prolongerbar",
    "prolongerbart": "prolongerbar",
    "prolongerbarts": "prolongerbar",
    "prolongeringar": "prolongering",
    "prolongeringarna": "prolongering",
    "prolongeringarnas": "prolongering",
    "prolongeringars": "prolongering",
    "prolongeringen": "prolongering",
    "prolongeringens": "prolongering",
    "prolongerings": "prolongering",
    "promemori": "promemoria",
    "promemorian": "promemoria",
    "promemorians": "promemoria",
    "promemorias": "promemoria",
    "promemorie": "promemoria",
    "promemorior": "promemoria",
    "promemoriorna": "promemoria",
    "promemoriornas": "promemoria",
    "promemoriors": "promemoria",
    "promemoris": "promemoria",
    "promenadavståndet": "promenadavstånd",
    "promenadavståndets": "promenadavstånd",
    "promenadavstånds": "promenadavstånd",
    "promenaden": "promenad",
    "promenadens": "promenad",
    "promenader": "promenad",
    "promenaderna": "promenad",
    "promenadernas": "promenad",
    "promenaders": "promenad",
    "promenadgat": "promenadgata",
    "promenadgatan": "promenadgata",
    "promenadgatans": "promenadgata",
    "promenadgatas": "promenadgata",
    "promenadgate": "promenadgata",
    "promenadgator": "promenadgata",
    "promenadgatorna": "promenadgata",
    "promenadgatornas": "promenadgata",
    "promenadgators": "promenadgata",
    "promenadgats": "promenadgata",
    "promenadkonserten": "promenadkonsert",
    "promenadkonsertens": "promenadkonsert",
    "promenadkonserter": "promenadkonsert",
    "promenadkonserterna": "promenadkonsert",
    "promenadkonserternas": "promenadkonsert",
    "promenadkonserters": "promenadkonsert",
    "promenadkonserts": "promenadkonsert",
    "promenadkäppar": "promenadkäpp",
    "promenadkäpparna": "promenadkäpp",
    "promenadkäpparnas": "promenadkäpp",
    "promenadkäppars": "promenadkäpp",
    "promenadkäppen": "promenadkäpp",
    "promenadkäppens": "promenadkäpp",
    "promenadkäpps": "promenadkäpp",
    "promenadkör": "promenadköra",
    "promenadkörande": "promenadköra",
    "promenadköranden": "promenadkörande",
    "promenadkörandena": "promenadkörande",
    "promenadkörandenas": "promenadkörande",
    "promenadkörandens": "promenadkörande",
    "promenadkörandes": "promenadkörande",
    "promenadkörandet": "promenadkörande",
    "promenadkörandets": "promenadkörande",
    "promenadköras": "promenadköra",
    "promenadkörd": "promenadköra",
    "promenadkörda": "promenadköra",
    "promenadkördas": "promenadköra",
    "promenadkörde": "promenadköra",
    "promenadkördes": "promenadköra",
    "promenadkörds": "promenadköra",
    "promenadköres": "promenadköra",
    "promenadkörs": "promenadköra",
    "promenadkört": "promenadköra",
    "promenadkörts": "promenadköra",
    "promenads": "promenad",
    "promenadsegern": "promenadseger",
    "promenadsegerns": "promenadseger",
    "promenadsegers": "promenadseger",
    "promenadsegrar": "promenadseger",
    "promenadsegrarna": "promenadseger",
    "promenadsegrarnas": "promenadseger",
    "promenadsegrars": "promenadseger",
    "promenadstigar": "promenadstig",
    "promenadstigarna": "promenadstig",
    "promenadstigarnas": "promenadstig",
    "promenadstigars": "promenadstig",
    "promenadstigen": "promenadstig",
    "promenadstigens": "promenadstig",
    "promenadstigs": "promenadstig",
    "promenadstråken": "promenadstråk",
    "promenadstråkens": "promenadstråk",
    "promenadstråket": "promenadstråk",
    "promenadstråkets": "promenadstråk",
    "promenadstråks": "promenadstråk",
    "promenadtakten": "promenadtakt",
    "promenadtaktens": "promenadtakt",
    "promenadtakts": "promenadtakt",
    "promenadvägar": "promenadväg",
    "promenadvägarna": "promenadväg",
    "promenadvägarnas": "promenadväg",
    "promenadvägars": "promenadväg",
    "promenadvägen": "promenadväg",
    "promenadvägens": "promenadväg",
    "promenadvägs": "promenadväg",
    "promenerade": "promenera",
    "promenerades": "promenera",
    "promenerande": "promenera",
    "promeneranden": "promenerande",
    "promenerandena": "promenerande",
    "promenerandenas": "promenerande",
    "promenerandens": "promenerande",
    "promenerandes": "promenerande",
    "promenerandet": "promenerande",
    "promenerandets": "promenerande",
    "promenerar": "promenera",
    "promeneras": "promenera",
    "promenerat": "promenera",
    "promenerats": "promenera",
    "promeneringar": "promenering",
    "promeneringarna": "promenering",
    "promeneringarnas": "promenering",
    "promeneringars": "promenering",
    "promeneringen": "promenering",
    "promeneringens": "promenering",
    "promenerings": "promenering",
    "promenoaren": "promenoar",
    "promenoarens": "promenoar",
    "promenoarer": "promenoar",
    "promenoarerna": "promenoar",
    "promenoarernas": "promenoar",
    "promenoarers": "promenoar",
    "promenoars": "promenoar",
    "prometiet": "prometium",
    "prometiets": "prometium",
    "prometiumet": "prometium",
    "prometiumets": "prometium",
    "prometiums": "prometium",
    "promillen": "promille",
    "promillena": "promille",
    "promillenas": "promille",
    "promillens": "promille",
    "promilles": "promille",
    "prominensen": "prominens",
    "prominensens": "prominens",
    "prominenser": "prominens",
    "prominenserna": "prominens",
    "prominensernas": "prominens",
    "prominensers": "prominens",
    "prominenta": "prominent",
    "prominentare": "prominent",
    "prominentares": "prominent",
    "prominentas": "prominent",
    "prominentast": "prominent",
    "prominentaste": "prominent",
    "prominentastes": "prominent",
    "prominentasts": "prominent",
    "prominente": "prominent",
    "prominentes": "prominent",
    "prominents": "prominent",
    "promiskuiteten": "promiskuitet",
    "promiskuitetens": "promiskuitet",
    "promiskuiteter": "promiskuitet",
    "promiskuiteterna": "promiskuitet",
    "promiskuiteternas": "promiskuitet",
    "promiskuiteters": "promiskuitet",
    "promiskuitets": "promiskuitet",
    "promiskuösa": "promiskuös",
    "promiskuösare": "promiskuös",
    "promiskuösares": "promiskuös",
    "promiskuösas": "promiskuös",
    "promiskuösast": "promiskuös",
    "promiskuösaste": "promiskuös",
    "promiskuösastes": "promiskuös",
    "promiskuösasts": "promiskuös",
    "promiskuöse": "promiskuös",
    "promiskuöses": "promiskuös",
    "promiskuöst": "promiskuös",
    "promiskuösts": "promiskuös",
    "promotionen": "promotion",
    "promotionens": "promotion",
    "promotioner": "promotion",
    "promotionerna": "promotion",
    "promotionernas": "promotion",
    "promotioners": "promotion",
    "promotions": "promotion",
    "promotorer": "promotor",
    "promotorerna": "promotor",
    "promotorernas": "promotor",
    "promotorers": "promotor",
    "promotorn": "promotor",
    "promotorns": "promotor",
    "promotors": "promotor",
    "promovenden": "promovend",
    "promovendens": "promovend",
    "promovender": "promovend",
    "promovenderna": "promovend",
    "promovendernas": "promovend",
    "promovenders": "promovend",
    "promovendi": "promovend",
    "promovendina": "promovend",
    "promovendinas": "promovend",
    "promovendis": "promovend",
    "promovends": "promovend",
    "promoverad": "promovera",
    "promoverade": "promovera",
    "promoverades": "promovera",
    "promoverads": "promovera",
    "promoverande": "promovera",
    "promoveranden": "promoverande",
    "promoverandena": "promoverande",
    "promoverandenas": "promoverande",
    "promoverandens": "promoverande",
    "promoverandes": "promoverande",
    "promoverandet": "promoverande",
    "promoverandets": "promoverande",
    "promoverar": "promovera",
    "promoveras": "promovera",
    "promoverat": "promovera",
    "promoverats": "promovera",
    "promoverbara": "promoverbar",
    "promoverbarare": "promoverbar",
    "promoverbarares": "promoverbar",
    "promoverbaras": "promoverbar",
    "promoverbarast": "promoverbar",
    "promoverbaraste": "promoverbar",
    "promoverbarastes": "promoverbar",
    "promoverbarasts": "promoverbar",
    "promoverbare": "promoverbar",
    "promoverbares": "promoverbar",
    "promoverbarheten": "promoverbarhet",
    "promoverbarhetens": "promoverbarhet",
    "promoverbarhets": "promoverbarhet",
    "promoverbars": "promoverbar",
    "promoverbart": "promoverbar",
    "promoverbarts": "promoverbar",
    "promoveringar": "promovering",
    "promoveringarna": "promovering",
    "promoveringarnas": "promovering",
    "promoveringars": "promovering",
    "promoveringen": "promovering",
    "promoveringens": "promovering",
    "promoverings": "promovering",
    "promsen": "proms",
    "promsens": "proms",
    "promulgationen": "promulgation",
    "promulgationens": "promulgation",
    "promulgationer": "promulgation",
    "promulgationerna": "promulgation",
    "promulgationernas": "promulgation",
    "promulgationers": "promulgation",
    "promulgations": "promulgation",
    "promulgerad": "promulgera",
    "promulgerade": "promulgera",
    "promulgerades": "promulgera",
    "promulgerads": "promulgera",
    "promulgerande": "promulgera",
    "promulgeranden": "promulgerande",
    "promulgerandena": "promulgerande",
    "promulgerandenas": "promulgerande",
    "promulgerandens": "promulgerande",
    "promulgerandes": "promulgerande",
    "promulgerandet": "promulgerande",
    "promulgerandets": "promulgerande",
    "promulgerar": "promulgera",
    "promulgeras": "promulgera",
    "promulgerat": "promulgera",
    "promulgerats": "promulgera",
    "promulgerbara": "promulgerbar",
    "promulgerbarare": "promulgerbar",
    "promulgerbarares": "promulgerbar",
    "promulgerbaras": "promulgerbar",
    "promulgerbarast": "promulgerbar",
    "promulgerbaraste": "promulgerbar",
    "promulgerbarastes": "promulgerbar",
    "promulgerbarasts": "promulgerbar",
    "promulgerbare": "promulgerbar",
    "promulgerbares": "promulgerbar",
    "promulgerbarheten": "promulgerbarhet",
    "promulgerbarhetens": "promulgerbarhet",
    "promulgerbarhets": "promulgerbarhet",
    "promulgerbars": "promulgerbar",
    "promulgerbart": "promulgerbar",
    "promulgerbarts": "promulgerbar",
    "promulgeringar": "promulgering",
    "promulgeringarna": "promulgering",
    "promulgeringarnas": "promulgering",
    "promulgeringars": "promulgering",
    "promulgeringen": "promulgering",
    "promulgeringens": "promulgering",
    "promulgerings": "promulgering",
    "pronomenen": "pronomen",
    "pronomenens": "pronomen",
    "pronomenet": "pronomen",
    "pronomenets": "pronomen",
    "pronomens": "pronomen",
    "pronomina": "pronomen",
    "pronominala": "pronominal",
    "pronominalare": "pronominal",
    "pronominalares": "pronominal",
    "pronominalas": "pronominal",
    "pronominalast": "pronominal",
    "pronominalaste": "pronominal",
    "pronominalastes": "pronominal",
    "pronominalasts": "pronominal",
    "pronominale": "pronominal",
    "pronominales": "pronominal",
    "pronominals": "pronominal",
    "pronominalt": "pronominal",
    "pronominalts": "pronominal",
    "pronominas": "pronomen",
    "pronominella": "pronominell",
    "pronominellare": "pronominell",
    "pronominellares": "pronominell",
    "pronominellas": "pronominell",
    "pronominellast": "pronominell",
    "pronominellaste": "pronominell",
    "pronominellastes": "pronominell",
    "pronominellasts": "pronominell",
    "pronominelle": "pronominell",
    "pronominelles": "pronominell",
    "pronominells": "pronominell",
    "pronominellt": "pronominell",
    "pronominellts": "pronominell",
    "prononcerad": "prononcera",
    "prononcerade": "prononcerad",
    "prononcerades": "prononcerad",
    "prononcerads": "prononcerad",
    "prononcerande": "prononcera",
    "prononceranden": "prononcerande",
    "prononcerandena": "prononcerande",
    "prononcerandenas": "prononcerande",
    "prononcerandens": "prononcerande",
    "prononcerandes": "prononcerande",
    "prononcerandet": "prononcerande",
    "prononcerandets": "prononcerande",
    "prononcerar": "prononcera",
    "prononceras": "prononcera",
    "prononcerat": "prononcerad",
    "prononcerats": "prononcerad",
    "prononcerbara": "prononcerbar",
    "prononcerbarare": "prononcerbar",
    "prononcerbarares": "prononcerbar",
    "prononcerbaras": "prononcerbar",
    "prononcerbarast": "prononcerbar",
    "prononcerbaraste": "prononcerbar",
    "prononcerbarastes": "prononcerbar",
    "prononcerbarasts": "prononcerbar",
    "prononcerbare": "prononcerbar",
    "prononcerbares": "prononcerbar",
    "prononcerbarheten": "prononcerbarhet",
    "prononcerbarhetens": "prononcerbarhet",
    "prononcerbarhets": "prononcerbarhet",
    "prononcerbars": "prononcerbar",
    "prononcerbart": "prononcerbar",
    "prononcerbarts": "prononcerbar",
    "prononceringar": "prononcering",
    "prononceringarna": "prononcering",
    "prononceringarnas": "prononcering",
    "prononceringars": "prononcering",
    "prononceringen": "prononcering",
    "prononceringens": "prononcering",
    "prononcerings": "prononcering",
    "prononciationen": "prononciation",
    "prononciationens": "prononciation",
    "prononciationer": "prononciation",
    "prononciationerna": "prononciation",
    "prononciationernas": "prononciation",
    "prononciationers": "prononciation",
    "prononciations": "prononciation",
    "propagandadikten": "propagandadikt",
    "propagandadiktens": "propagandadikt",
    "propagandadikter": "propagandadikt",
    "propagandadikterna": "propagandadikt",
    "propagandadikternas": "propagandadikt",
    "propagandadikters": "propagandadikt",
    "propagandadikts": "propagandadikt",
    "propagandafilmen": "propagandafilm",
    "propagandafilmens": "propagandafilm",
    "propagandafilmer": "propagandafilm",
    "propagandafilmerna": "propagandafilm",
    "propagandafilmernas": "propagandafilm",
    "propagandafilmers": "propagandafilm",
    "propagandafilms": "propagandafilm",
    "propagandaministern": "propagandaminister",
    "propagandaministerns": "propagandaminister",
    "propagandaministers": "propagandaminister",
    "propagandaministrar": "propagandaminister",
    "propagandaministrarna": "propagandaminister",
    "propagandaministrarnas": "propagandaminister",
    "propagandaministrars": "propagandaminister",
    "propagandamässiga": "propagandamässig",
    "propagandamässigare": "propagandamässig",
    "propagandamässigares": "propagandamässig",
    "propagandamässigas": "propagandamässig",
    "propagandamässigast": "propagandamässig",
    "propagandamässigaste": "propagandamässig",
    "propagandamässigastes": "propagandamässig",
    "propagandamässigasts": "propagandamässig",
    "propagandamässige": "propagandamässig",
    "propagandamässiges": "propagandamässig",
    "propagandamässigs": "propagandamässig",
    "propagandamässigt": "propagandamässig",
    "propagandamässigts": "propagandamässig",
    "propagandan": "propaganda",
    "propagandans": "propaganda",
    "propagandas": "propaganda",
    "propagandisten": "propagandist",
    "propagandistens": "propagandist",
    "propagandister": "propagandist",
    "propagandisterna": "propagandist",
    "propagandisternas": "propagandist",
    "propagandisters": "propagandist",
    "propagandistiska": "propagandistisk",
    "propagandistiskare": "propagandistisk",
    "propagandistiskares": "propagandistisk",
    "propagandistiskas": "propagandistisk",
    "propagandistiskast": "propagandistisk",
    "propagandistiskaste": "propagandistisk",
    "propagandistiskastes": "propagandistisk",
    "propagandistiskasts": "propagandistisk",
    "propagandistiske": "propagandistisk",
    "propagandistiskes": "propagandistisk",
    "propagandistisks": "propagandistisk",
    "propagandistiskt": "propagandistisk",
    "propagandistiskts": "propagandistisk",
    "propagandists": "propagandist",
    "propagerade": "propagera",
    "propagerades": "propagera",
    "propagerande": "propagera",
    "propageranden": "propagerande",
    "propagerandena": "propagerande",
    "propagerandenas": "propagerande",
    "propagerandens": "propagerande",
    "propagerandes": "propagerande",
    "propagerandet": "propagerande",
    "propagerandets": "propagerande",
    "propagerar": "propagera",
    "propageras": "propagera",
    "propagerat": "propagera",
    "propagerats": "propagera",
    "propageringar": "propagering",
    "propageringarna": "propagering",
    "propageringarnas": "propagering",
    "propageringars": "propagering",
    "propageringen": "propagering",
    "propageringens": "propagering",
    "propagerings": "propagering",
    "propanen": "propan",
    "propanens": "propan",
    "propanet": "propan",
    "propanets": "propan",
    "propanolen": "propanol",
    "propanolens": "propanol",
    "propanols": "propanol",
    "propans": "propan",
    "propedeutiken": "propedeutik",
    "propedeutikens": "propedeutik",
    "propedeutiks": "propedeutik",
    "propedeutiska": "propedeutisk",
    "propedeutiskare": "propedeutisk",
    "propedeutiskares": "propedeutisk",
    "propedeutiskas": "propedeutisk",
    "propedeutiskast": "propedeutisk",
    "propedeutiskaste": "propedeutisk",
    "propedeutiskastes": "propedeutisk",
    "propedeutiskasts": "propedeutisk",
    "propedeutiske": "propedeutisk",
    "propedeutiskes": "propedeutisk",
    "propedeutisks": "propedeutisk",
    "propedeutiskt": "propedeutisk",
    "propedeutiskts": "propedeutisk",
    "propelleraxeln": "propelleraxel",
    "propelleraxelns": "propelleraxel",
    "propelleraxels": "propelleraxel",
    "propelleraxlar": "propelleraxel",
    "propelleraxlarna": "propelleraxel",
    "propelleraxlarnas": "propelleraxel",
    "propelleraxlars": "propelleraxel",
    "propellern": "propeller",
    "propellerns": "propeller",
    "propellerplanen": "propellerplan",
    "propellerplanens": "propellerplan",
    "propellerplanet": "propellerplan",
    "propellerplanets": "propellerplan",
    "propellerplans": "propellerplan",
    "propellers": "propeller",
    "propellrar": "propeller",
    "propellrarna": "propeller",
    "propellrarnas": "propeller",
    "propellrars": "propeller",
    "propenen": "propen",
    "propenens": "propen",
    "propenet": "propen",
    "propenets": "propen",
    "propenplasten": "propenplast",
    "propenplastens": "propenplast",
    "propenplasts": "propenplast",
    "propens": "propen",
    "propers": "proper",
    "propert": "proper",
    "properts": "proper",
    "proponenten": "proponent",
    "proponentens": "proponent",
    "proponenter": "proponent",
    "proponenterna": "proponent",
    "proponenternas": "proponent",
    "proponenters": "proponent",
    "proponents": "proponent",
    "proponerad": "proponera",
    "proponerade": "proponera",
    "proponerades": "proponera",
    "proponerads": "proponera",
    "proponerande": "proponera",
    "proponeranden": "proponerande",
    "proponerandena": "proponerande",
    "proponerandenas": "proponerande",
    "proponerandens": "proponerande",
    "proponerandes": "proponerande",
    "proponerandet": "proponerande",
    "proponerandets": "proponerande",
    "proponerar": "proponera",
    "proponeras": "proponera",
    "proponerat": "proponera",
    "proponerats": "proponera",
    "proponerbara": "proponerbar",
    "proponerbarare": "proponerbar",
    "proponerbarares": "proponerbar",
    "proponerbaras": "proponerbar",
    "proponerbarast": "proponerbar",
    "proponerbaraste": "proponerbar",
    "proponerbarastes": "proponerbar",
    "proponerbarasts": "proponerbar",
    "proponerbare": "proponerbar",
    "proponerbares": "proponerbar",
    "proponerbarheten": "proponerbarhet",
    "proponerbarhetens": "proponerbarhet",
    "proponerbarhets": "proponerbarhet",
    "proponerbars": "proponerbar",
    "proponerbart": "proponerbar",
    "proponerbarts": "proponerbar",
    "proponeringar": "proponering",
    "proponeringarna": "proponering",
    "proponeringarnas": "proponering",
    "proponeringars": "proponering",
    "proponeringen": "proponering",
    "proponeringens": "proponering",
    "proponerings": "proponering",
    "proportionalen": "proportional",
    "proportionalens": "proportional",
    "proportionaler": "proportional",
    "proportionalerna": "proportional",
    "proportionalernas": "proportional",
    "proportionalers": "proportional",
    "proportionalismen": "proportionalism",
    "proportionalismens": "proportionalism",
    "proportionalismer": "proportionalism",
    "proportionalismerna": "proportionalism",
    "proportionalismernas": "proportionalism",
    "proportionalismers": "proportionalism",
    "proportionalisms": "proportionalism",
    "proportionaliteten": "proportionalitet",
    "proportionalitetens": "proportionalitet",
    "proportionaliteter": "proportionalitet",
    "proportionaliteterna": "proportionalitet",
    "proportionaliteternas": "proportionalitet",
    "proportionaliteters": "proportionalitet",
    "proportionalitets": "proportionalitet",
    "proportionals": "proportional",
    "proportionella": "proportionell",
    "proportionellare": "proportionell",
    "proportionellares": "proportionell",
    "proportionellas": "proportionell",
    "proportionellast": "proportionell",
    "proportionellaste": "proportionell",
    "proportionellastes": "proportionell",
    "proportionellasts": "proportionell",
    "proportionelle": "proportionell",
    "proportionelles": "proportionell",
    "proportionells": "proportionell",
    "proportionellt": "proportionell",
    "proportionellts": "proportionell",
    "proportionen": "proportion",
    "proportionens": "proportion",
    "proportioner": "proportion",
    "proportionerad": "proportionera",
    "proportionerade": "proportionera",
    "proportionerades": "proportionera",
    "proportionerads": "proportionera",
    "proportionerande": "proportionera",
    "proportioneranden": "proportionerande",
    "proportionerandena": "proportionerande",
    "proportionerandenas": "proportionerande",
    "proportionerandens": "proportionerande",
    "proportionerandes": "proportionerande",
    "proportionerandet": "proportionerande",
    "proportionerandets": "proportionerande",
    "proportionerar": "proportionera",
    "proportioneras": "proportionera",
    "proportionerat": "proportionera",
    "proportionerats": "proportionera",
    "proportionerbara": "proportionerbar",
    "proportionerbarare": "proportionerbar",
    "proportionerbarares": "proportionerbar",
    "proportionerbaras": "proportionerbar",
    "proportionerbarast": "proportionerbar",
    "proportionerbaraste": "proportionerbar",
    "proportionerbarastes": "proportionerbar",
    "proportionerbarasts": "proportionerbar",
    "proportionerbare": "proportionerbar",
    "proportionerbares": "proportionerbar",
    "proportionerbarheten": "proportionerbarhet",
    "proportionerbarhetens": "proportionerbarhet",
    "proportionerbarhets": "proportionerbarhet",
    "proportionerbars": "proportionerbar",
    "proportionerbart": "proportionerbar",
    "proportionerbarts": "proportionerbar",
    "proportioneringar": "proportionering",
    "proportioneringarna": "proportionering",
    "proportioneringarnas": "proportionering",
    "proportioneringars": "proportionering",
    "proportioneringen": "proportionering",
    "proportioneringens": "proportionering",
    "proportionerings": "proportionering",
    "proportionerliga": "proportionerlig",
    "proportionerligare": "proportionerlig",
    "proportionerligares": "proportionerlig",
    "proportionerligas": "proportionerlig",
    "proportionerligast": "proportionerlig",
    "proportionerligaste": "proportionerlig",
    "proportionerligastes": "proportionerlig",
    "proportionerligasts": "proportionerlig",
    "proportionerlige": "proportionerlig",
    "proportionerliges": "proportionerlig",
    "proportionerligheten": "proportionerlighet",
    "proportionerlighetens": "proportionerlighet",
    "proportionerlighets": "proportionerlighet",
    "proportionerligs": "proportionerlig",
    "proportionerligt": "proportionerlig",
    "proportionerligts": "proportionerlig",
    "proportionerna": "proportion",
    "proportionernas": "proportion",
    "proportioners": "proportion",
    "proportions": "proportion",
    "propositionen": "proposition",
    "propositionens": "proposition",
    "propositioner": "proposition",
    "propositionerna": "proposition",
    "propositionernas": "proposition",
    "propositioners": "proposition",
    "propositions": "proposition",
    "propp": "proppa",
    "proppad": "proppa",
    "proppade": "proppa",
    "proppades": "proppa",
    "proppads": "proppa",
    "proppande": "proppa",
    "proppanden": "proppande",
    "proppandena": "proppande",
    "proppandenas": "proppande",
    "proppandens": "proppande",
    "proppandes": "proppande",
    "proppandet": "proppande",
    "proppandets": "proppande",
    "proppar": "proppa",
    "propparna": "propp",
    "propparnas": "propp",
    "proppars": "propp",
    "proppas": "proppa",
    "proppat": "proppa",
    "proppats": "proppa",
    "proppen": "propp",
    "proppens": "propp",
    "proppfulla": "proppfull",
    "proppfullare": "proppfull",
    "proppfullares": "proppfull",
    "proppfullas": "proppfull",
    "proppfullast": "proppfull",
    "proppfullaste": "proppfull",
    "proppfullastes": "proppfull",
    "proppfullasts": "proppfull",
    "proppfulle": "proppfull",
    "proppfulles": "proppfull",
    "proppfullheten": "proppfullhet",
    "proppfullhetens": "proppfullhet",
    "proppfullheter": "proppfullhet",
    "proppfullheterna": "proppfullhet",
    "proppfullheternas": "proppfullhet",
    "proppfullheters": "proppfullhet",
    "proppfullhets": "proppfullhet",
    "proppfulls": "proppfull",
    "proppfullt": "proppfull",
    "proppfullts": "proppfull",
    "proppmätta": "proppmätt",
    "proppmättare": "proppmätt",
    "proppmättares": "proppmätt",
    "proppmättas": "proppmätt",
    "proppmättast": "proppmätt",
    "proppmättaste": "proppmätt",
    "proppmättastes": "proppmätt",
    "proppmättasts": "proppmätt",
    "proppmätte": "proppmätt",
    "proppmättes": "proppmätt",
    "proppmättheten": "proppmätthet",
    "proppmätthetens": "proppmätthet",
    "proppmätthets": "proppmätthet",
    "proppmätts": "proppmätt",
    "propps": "propp",
    "proppskåpen": "proppskåp",
    "proppskåpens": "proppskåp",
    "proppskåpet": "proppskåp",
    "proppskåpets": "proppskåp",
    "proppskåps": "proppskåp",
    "proppsäkringar": "proppsäkring",
    "proppsäkringarna": "proppsäkring",
    "proppsäkringarnas": "proppsäkring",
    "proppsäkringars": "proppsäkring",
    "proppsäkringen": "proppsäkring",
    "proppsäkringens": "proppsäkring",
    "proppsäkrings": "proppsäkring",
    "propra": "proper",
    "proprare": "proper",
    "proprares": "proper",
    "propras": "proper",
    "proprast": "proper",
    "propraste": "proper",
    "proprastes": "proper",
    "proprasts": "proper",
    "propre": "proper",
    "propres": "proper",
    "proprieborgens": "proprieborgen",
    "proprietären": "proprietär",
    "proprietärens": "proprietär",
    "proprietärer": "proprietär",
    "proprietärerna": "proprietär",
    "proprietärernas": "proprietär",
    "proprietärers": "proprietär",
    "proprietärs": "proprietär",
    "propsade": "propsa",
    "propsades": "propsa",
    "propsande": "propsa",
    "propsanden": "propsande",
    "propsandena": "propsande",
    "propsandenas": "propsande",
    "propsandens": "propsande",
    "propsandes": "propsande",
    "propsandet": "propsande",
    "propsandets": "propsande",
    "propsar": "propsa",
    "propsas": "propsa",
    "propsat": "propsa",
    "propsats": "propsa",
    "propsen": "props",
    "propsens": "props",
    "propylen": "propyl",
    "propylens": "propyl",
    "propyler": "propyl",
    "propylerna": "propyl",
    "propylernas": "propyl",
    "propylers": "propyl",
    "propyls": "propyl",
    "propyléen": "propylé",
    "propyléens": "propylé",
    "propyléer": "propylé",
    "propyléerna": "propylé",
    "propyléernas": "propylé",
    "propyléers": "propylé",
    "propylén": "propylé",
    "propyléns": "propylé",
    "propylés": "propylé",
    "propåer": "propå",
    "propåerna": "propå",
    "propåernas": "propå",
    "propåers": "propå",
    "propån": "propå",
    "propåns": "propå",
    "propås": "propå",
    "prorektoren": "prorektor",
    "prorektorens": "prorektor",
    "prorektorer": "prorektor",
    "prorektorerna": "prorektor",
    "prorektorernas": "prorektor",
    "prorektorers": "prorektor",
    "prorektorn": "prorektor",
    "prorektorns": "prorektor",
    "prorektors": "prorektor",
    "prorogationen": "prorogation",
    "prorogationens": "prorogation",
    "prorogationer": "prorogation",
    "prorogationerna": "prorogation",
    "prorogationernas": "prorogation",
    "prorogationers": "prorogation",
    "prorogations": "prorogation",
    "prosadikten": "prosadikt",
    "prosadiktens": "prosadikt",
    "prosadikter": "prosadikt",
    "prosadikterna": "prosadikt",
    "prosadikternas": "prosadikt",
    "prosadikters": "prosadikt",
    "prosadikts": "prosadikt",
    "prosaiska": "prosaisk",
    "prosaiskare": "prosaisk",
    "prosaiskares": "prosaisk",
    "prosaiskas": "prosaisk",
    "prosaiskast": "prosaisk",
    "prosaiskaste": "prosaisk",
    "prosaiskastes": "prosaisk",
    "prosaiskasts": "prosaisk",
    "prosaiske": "prosaisk",
    "prosaiskes": "prosaisk",
    "prosaisks": "prosaisk",
    "prosaiskt": "prosaisk",
    "prosaiskts": "prosaisk",
    "prosaisten": "prosaist",
    "prosaistens": "prosaist",
    "prosaister": "prosaist",
    "prosaisterna": "prosaist",
    "prosaisternas": "prosaist",
    "prosaisters": "prosaist",
    "prosaists": "prosaist",
    "prosan": "prosa",
    "prosans": "prosa",
    "prosas": "prosa",
    "proscenie": "proscenium",
    "proscenier": "proscenium",
    "proscenierna": "proscenium",
    "prosceniernas": "proscenium",
    "prosceniers": "proscenium",
    "prosceniet": "proscenium",
    "prosceniets": "proscenium",
    "prosceniums": "proscenium",
    "prosektorer": "prosektor",
    "prosektorerna": "prosektor",
    "prosektorernas": "prosektor",
    "prosektorers": "prosektor",
    "prosektorn": "prosektor",
    "prosektorns": "prosektor",
    "prosektors": "prosektor",
    "proselyten": "proselyt",
    "proselytens": "proselyt",
    "proselyter": "proselyt",
    "proselyterna": "proselyt",
    "proselyternas": "proselyt",
    "proselyters": "proselyt",
    "proselyts": "proselyt",
    "proseminarie": "proseminarium",
    "proseminarier": "proseminarium",
    "proseminarierna": "proseminarium",
    "proseminariernas": "proseminarium",
    "proseminariers": "proseminarium",
    "proseminariet": "proseminarium",
    "proseminariets": "proseminarium",
    "proseminariums": "proseminarium",
    "proskriberad": "proskribera",
    "proskriberade": "proskribera",
    "proskriberades": "proskribera",
    "proskriberads": "proskribera",
    "proskriberande": "proskribera",
    "proskriberanden": "proskriberande",
    "proskriberandena": "proskriberande",
    "proskriberandenas": "proskriberande",
    "proskriberandens": "proskriberande",
    "proskriberandes": "proskriberande",
    "proskriberandet": "proskriberande",
    "proskriberandets": "proskriberande",
    "proskriberar": "proskribera",
    "proskriberas": "proskribera",
    "proskriberat": "proskribera",
    "proskriberats": "proskribera",
    "proskriberbara": "proskriberbar",
    "proskriberbarare": "proskriberbar",
    "proskriberbarares": "proskriberbar",
    "proskriberbaras": "proskriberbar",
    "proskriberbarast": "proskriberbar",
    "proskriberbaraste": "proskriberbar",
    "proskriberbarastes": "proskriberbar",
    "proskriberbarasts": "proskriberbar",
    "proskriberbare": "proskriberbar",
    "proskriberbares": "proskriberbar",
    "proskriberbarheten": "proskriberbarhet",
    "proskriberbarhetens": "proskriberbarhet",
    "proskriberbarhets": "proskriberbarhet",
    "proskriberbars": "proskriberbar",
    "proskriberbart": "proskriberbar",
    "proskriberbarts": "proskriberbar",
    "proskriberingar": "proskribering",
    "proskriberingarna": "proskribering",
    "proskriberingarnas": "proskribering",
    "proskriberingars": "proskribering",
    "proskriberingen": "proskribering",
    "proskriberingens": "proskribering",
    "proskriberings": "proskribering",
    "proskriptionen": "proskription",
    "proskriptionens": "proskription",
    "proskriptioner": "proskription",
    "proskriptionerna": "proskription",
    "proskriptionernas": "proskription",
    "proskriptioners": "proskription",
    "proskriptions": "proskription",
    "prosodien": "prosodi",
    "prosodiens": "prosodi",
    "prosodier": "prosodi",
    "prosodierna": "prosodi",
    "prosodiernas": "prosodi",
    "prosodiers": "prosodi",
    "prosodin": "prosodi",
    "prosodins": "prosodi",
    "prosodis": "prosodi",
    "prosodiska": "prosodisk",
    "prosodiskare": "prosodisk",
    "prosodiskares": "prosodisk",
    "prosodiskas": "prosodisk",
    "prosodiskast": "prosodisk",
    "prosodiskaste": "prosodisk",
    "prosodiskastes": "prosodisk",
    "prosodiskasts": "prosodisk",
    "prosodiske": "prosodisk",
    "prosodiskes": "prosodisk",
    "prosodisks": "prosodisk",
    "prosodiskt": "prosodisk",
    "prosodiskts": "prosodisk",
    "prospekten": "prospekt",
    "prospektens": "prospekt",
    "prospekterad": "prospektera",
    "prospekterade": "prospektera",
    "prospekterades": "prospektera",
    "prospekterads": "prospektera",
    "prospekterande": "prospektera",
    "prospekteranden": "prospekterande",
    "prospekterandena": "prospekterande",
    "prospekterandenas": "prospekterande",
    "prospekterandens": "prospekterande",
    "prospekterandes": "prospekterande",
    "prospekterandet": "prospekterande",
    "prospekterandets": "prospekterande",
    "prospekterar": "prospektera",
    "prospekteras": "prospektera",
    "prospekterat": "prospektera",
    "prospekterats": "prospektera",
    "prospekterbara": "prospekterbar",
    "prospekterbarare": "prospekterbar",
    "prospekterbarares": "prospekterbar",
    "prospekterbaras": "prospekterbar",
    "prospekterbarast": "prospekterbar",
    "prospekterbaraste": "prospekterbar",
    "prospekterbarastes": "prospekterbar",
    "prospekterbarasts": "prospekterbar",
    "prospekterbare": "prospekterbar",
    "prospekterbares": "prospekterbar",
    "prospekterbarheten": "prospekterbarhet",
    "prospekterbarhetens": "prospekterbarhet",
    "prospekterbarhets": "prospekterbarhet",
    "prospekterbars": "prospekterbar",
    "prospekterbart": "prospekterbar",
    "prospekterbarts": "prospekterbar",
    "prospekteringar": "prospektering",
    "prospekteringarna": "prospektering",
    "prospekteringarnas": "prospektering",
    "prospekteringars": "prospektering",
    "prospekteringen": "prospektering",
    "prospekteringens": "prospektering",
    "prospekterings": "prospektering",
    "prospektet": "prospekt",
    "prospektets": "prospekt",
    "prospektiva": "prospektiv",
    "prospektivas": "prospektiv",
    "prospektive": "prospektiv",
    "prospektives": "prospektiv",
    "prospektivs": "prospektiv",
    "prospektivt": "prospektiv",
    "prospektivts": "prospektiv",
    "prospekts": "prospekt",
    "prostar": "prost",
    "prostarna": "prost",
    "prostarnas": "prost",
    "prostars": "prost",
    "prostatacancern": "prostatacancer",
    "prostatacancerns": "prostatacancer",
    "prostatacancers": "prostatacancer",
    "prostatacancertumören": "prostatacancertumör",
    "prostatacancertumörens": "prostatacancertumör",
    "prostatacancertumörer": "prostatacancertumör",
    "prostatacancertumörerna": "prostatacancertumör",
    "prostatacancertumörernas": "prostatacancertumör",
    "prostatacancertumörers": "prostatacancertumör",
    "prostatacancertumörs": "prostatacancertumör",
    "prostatacancrar": "prostatacancer",
    "prostatacancrarna": "prostatacancer",
    "prostatacancrarnas": "prostatacancer",
    "prostatacancrars": "prostatacancer",
    "prostatahypertrofien": "prostatahypertrofi",
    "prostatahypertrofiens": "prostatahypertrofi",
    "prostatahypertrofin": "prostatahypertrofi",
    "prostatahypertrofins": "prostatahypertrofi",
    "prostatahypertrofis": "prostatahypertrofi",
    "prostatan": "prostata",
    "prostatans": "prostata",
    "prostatas": "prostata",
    "prostatiten": "prostatit",
    "prostatitens": "prostatit",
    "prostatiter": "prostatit",
    "prostatiterna": "prostatit",
    "prostatiternas": "prostatit",
    "prostatiters": "prostatit",
    "prostatits": "prostatit",
    "prostator": "prostata",
    "prostatorna": "prostata",
    "prostatornas": "prostata",
    "prostators": "prostata",
    "prosten": "prost",
    "prostens": "prost",
    "prosterier": "prosteri",
    "prosterierna": "prosteri",
    "prosteriernas": "prosteri",
    "prosteriers": "prosteri",
    "prosteriet": "prosteri",
    "prosteriets": "prosteri",
    "prosteris": "prosteri",
    "prosterit": "prosteri",
    "prosterits": "prosteri",
    "prostituerade": "prostituerad",
    "prostituerades": "prostituerad",
    "prostituerads": "prostituerad",
    "prostituerande": "prostituera",
    "prostitueranden": "prostituerande",
    "prostituerandena": "prostituerande",
    "prostituerandenas": "prostituerande",
    "prostituerandens": "prostituerande",
    "prostituerandes": "prostituerande",
    "prostituerandet": "prostituerande",
    "prostituerandets": "prostituerande",
    "prostituerar": "prostituera",
    "prostitueras": "prostituera",
    "prostituerat": "prostituerad",
    "prostituerats": "prostituerad",
    "prostitueringar": "prostituering",
    "prostitueringarna": "prostituering",
    "prostitueringarnas": "prostituering",
    "prostitueringars": "prostituering",
    "prostitueringen": "prostituering",
    "prostitueringens": "prostituering",
    "prostituerings": "prostituering",
    "prostitutionen": "prostitution",
    "prostitutionens": "prostitution",
    "prostitutioner": "prostitution",
    "prostitutionerna": "prostitution",
    "prostitutionernas": "prostitution",
    "prostitutioners": "prostitution",
    "prostitutions": "prostitution",
    "prostitutionshärvan": "prostitutionshärva",
    "prostitutionshärvans": "prostitutionshärva",
    "prostitutionshärvas": "prostitutionshärva",
    "prostitutionshärve": "prostitutionshärva",
    "prostitutionshärvor": "prostitutionshärva",
    "prostitutionshärvorna": "prostitutionshärva",
    "prostitutionshärvornas": "prostitutionshärva",
    "prostitutionshärvors": "prostitutionshärva",
    "prosts": "prost",
    "protagonisten": "protagonist",
    "protagonistens": "protagonist",
    "protagonister": "protagonist",
    "protagonisterna": "protagonist",
    "protagonisternas": "protagonist",
    "protagonisters": "protagonist",
    "protagonists": "protagonist",
    "protaktiniet": "protaktinium",
    "protaktiniets": "protaktinium",
    "protaktiniumet": "protaktinium",
    "protaktiniumets": "protaktinium",
    "protaktiniums": "protaktinium",
    "protegerad": "protegera",
    "protegerade": "protegera",
    "protegerades": "protegera",
    "protegerads": "protegera",
    "protegerande": "protegera",
    "protegeranden": "protegerande",
    "protegerandena": "protegerande",
    "protegerandenas": "protegerande",
    "protegerandens": "protegerande",
    "protegerandes": "protegerande",
    "protegerandet": "protegerande",
    "protegerandets": "protegerande",
    "protegerar": "protegera",
    "protegeras": "protegera",
    "protegerat": "protegera",
    "protegerats": "protegera",
    "protegerbara": "protegerbar",
    "protegerbarare": "protegerbar",
    "protegerbarares": "protegerbar",
    "protegerbaras": "protegerbar",
    "protegerbarast": "protegerbar",
    "protegerbaraste": "protegerbar",
    "protegerbarastes": "protegerbar",
    "protegerbarasts": "protegerbar",
    "protegerbare": "protegerbar",
    "protegerbares": "protegerbar",
    "protegerbarheten": "protegerbarhet",
    "protegerbarhetens": "protegerbarhet",
    "protegerbarhets": "protegerbarhet",
    "protegerbars": "protegerbar",
    "protegerbart": "protegerbar",
    "protegerbarts": "protegerbar",
    "protegeringar": "protegering",
    "protegeringarna": "protegering",
    "protegeringarnas": "protegering",
    "protegeringars": "protegering",
    "protegeringen": "protegering",
    "protegeringens": "protegering",
    "protegerings": "protegering",
    "protegéen": "protegé",
    "protegéens": "protegé",
    "protegéer": "protegé",
    "protegéerna": "protegé",
    "protegéernas": "protegé",
    "protegéers": "protegé",
    "protegén": "protegé",
    "protegéns": "protegé",
    "protegés": "protegé",
    "proteinanalysen": "proteinanalys",
    "proteinanalysens": "proteinanalys",
    "proteinanalyser": "proteinanalys",
    "proteinanalyserna": "proteinanalys",
    "proteinanalysernas": "proteinanalys",
    "proteinanalysers": "proteinanalys",
    "proteinbehoven": "proteinbehov",
    "proteinbehovens": "proteinbehov",
    "proteinbehovet": "proteinbehov",
    "proteinbehovets": "proteinbehov",
    "proteinbehovs": "proteinbehov",
    "proteiner": "protein",
    "proteinerna": "protein",
    "proteinernas": "protein",
    "proteiners": "protein",
    "proteinet": "protein",
    "proteinets": "protein",
    "proteinfabriken": "proteinfabrik",
    "proteinfabrikens": "proteinfabrik",
    "proteinfabriker": "proteinfabrik",
    "proteinfabrikerna": "proteinfabrik",
    "proteinfabrikernas": "proteinfabrik",
    "proteinfabrikers": "proteinfabrik",
    "proteinfabriks": "proteinfabrik",
    "proteinfamiljen": "proteinfamilj",
    "proteinfamiljens": "proteinfamilj",
    "proteinfamiljer": "proteinfamilj",
    "proteinfamiljerna": "proteinfamilj",
    "proteinfamiljernas": "proteinfamilj",
    "proteinfamiljers": "proteinfamilj",
    "proteinfamiljs": "proteinfamilj",
    "proteinforskningar": "proteinforskning",
    "proteinforskningarna": "proteinforskning",
    "proteinforskningarnas": "proteinforskning",
    "proteinforskningars": "proteinforskning",
    "proteinforskningen": "proteinforskning",
    "proteinforskningens": "proteinforskning",
    "proteinforsknings": "proteinforskning",
    "proteinkedjan": "proteinkedja",
    "proteinkedjans": "proteinkedja",
    "proteinkedjas": "proteinkedja",
    "proteinkedje": "proteinkedja",
    "proteinkedjor": "proteinkedja",
    "proteinkedjorna": "proteinkedja",
    "proteinkedjornas": "proteinkedja",
    "proteinkedjors": "proteinkedja",
    "proteinkemisten": "proteinkemist",
    "proteinkemistens": "proteinkemist",
    "proteinkemister": "proteinkemist",
    "proteinkemisterna": "proteinkemist",
    "proteinkemisternas": "proteinkemist",
    "proteinkemisters": "proteinkemist",
    "proteinkemists": "proteinkemist",
    "proteinmolekylen": "proteinmolekyl",
    "proteinmolekylens": "proteinmolekyl",
    "proteinmolekyler": "proteinmolekyl",
    "proteinmolekylerna": "proteinmolekyl",
    "proteinmolekylernas": "proteinmolekyl",
    "proteinmolekylers": "proteinmolekyl",
    "proteinmolekyls": "proteinmolekyl",
    "proteinrika": "proteinrik",
    "proteinrikare": "proteinrik",
    "proteinrikares": "proteinrik",
    "proteinrikas": "proteinrik",
    "proteinrikast": "proteinrik",
    "proteinrikaste": "proteinrik",
    "proteinrikastes": "proteinrik",
    "proteinrikasts": "proteinrik",
    "proteinrike": "proteinrik",
    "proteinrikes": "proteinrik",
    "proteinrikheten": "proteinrikhet",
    "proteinrikhetens": "proteinrikhet",
    "proteinrikhets": "proteinrikhet",
    "proteinriks": "proteinrik",
    "proteinrikt": "proteinrik",
    "proteinrikts": "proteinrik",
    "proteins": "protein",
    "proteinslagen": "proteinslag",
    "proteinslagens": "proteinslag",
    "proteinslaget": "proteinslag",
    "proteinslagets": "proteinslag",
    "proteinslags": "proteinslag",
    "proteiska": "proteisk",
    "proteiskare": "proteisk",
    "proteiskares": "proteisk",
    "proteiskas": "proteisk",
    "proteiskast": "proteisk",
    "proteiskaste": "proteisk",
    "proteiskastes": "proteisk",
    "proteiskasts": "proteisk",
    "proteiske": "proteisk",
    "proteiskes": "proteisk",
    "proteisks": "proteisk",
    "proteiskt": "proteisk",
    "proteiskts": "proteisk",
    "protektionen": "protektion",
    "protektionens": "protektion",
    "protektioner": "protektion",
    "protektionerna": "protektion",
    "protektionernas": "protektion",
    "protektioners": "protektion",
    "protektionismen": "protektionism",
    "protektionismens": "protektionism",
    "protektionismer": "protektionism",
    "protektionismerna": "protektionism",
    "protektionismernas": "protektionism",
    "protektionismers": "protektionism",
    "protektionisms": "protektionism",
    "protektionistiska": "protektionistisk",
    "protektionistiskare": "protektionistisk",
    "protektionistiskares": "protektionistisk",
    "protektionistiskas": "protektionistisk",
    "protektionistiskast": "protektionistisk",
    "protektionistiskaste": "protektionistisk",
    "protektionistiskastes": "protektionistisk",
    "protektionistiskasts": "protektionistisk",
    "protektionistiske": "protektionistisk",
    "protektionistiskes": "protektionistisk",
    "protektionistisks": "protektionistisk",
    "protektionistiskt": "protektionistisk",
    "protektionistiskts": "protektionistisk",
    "protektions": "protektion",
    "protektoraten": "protektorat",
    "protektoratens": "protektorat",
    "protektoratet": "protektorat",
    "protektoratets": "protektorat",
    "protektorats": "protektorat",
    "protektorer": "protektor",
    "protektorerna": "protektor",
    "protektorernas": "protektor",
    "protektorers": "protektor",
    "protektorn": "protektor",
    "protektorns": "protektor",
    "protektors": "protektor",
    "protesen": "protes",
    "protesens": "protes",
    "proteser": "protes",
    "proteserna": "protes",
    "protesernas": "protes",
    "protesers": "protes",
    "protestaktionen": "protestaktion",
    "protestaktionens": "protestaktion",
    "protestaktioner": "protestaktion",
    "protestaktionerna": "protestaktion",
    "protestaktionernas": "protestaktion",
    "protestaktioners": "protestaktion",
    "protestaktions": "protestaktion",
    "protestanten": "protestant",
    "protestantens": "protestant",
    "protestanter": "protestant",
    "protestanterna": "protestant",
    "protestanternas": "protestant",
    "protestanters": "protestant",
    "protestantiska": "protestantisk",
    "protestantiskare": "protestantisk",
    "protestantiskares": "protestantisk",
    "protestantiskas": "protestantisk",
    "protestantiskast": "protestantisk",
    "protestantiskaste": "protestantisk",
    "protestantiskastes": "protestantisk",
    "protestantiskasts": "protestantisk",
    "protestantiske": "protestantisk",
    "protestantiskes": "protestantisk",
    "protestantisks": "protestantisk",
    "protestantiskt": "protestantisk",
    "protestantiskts": "protestantisk",
    "protestantismen": "protestantism",
    "protestantismens": "protestantism",
    "protestantismer": "protestantism",
    "protestantismerna": "protestantism",
    "protestantismernas": "protestantism",
    "protestantismers": "protestantism",
    "protestantisms": "protestantism",
    "protestants": "protestant",
    "protesten": "protest",
    "protestens": "protest",
    "protester": "protest",
    "protesterade": "protestera",
    "protesterades": "protestera",
    "protesterande": "protestera",
    "protesteranden": "protesterande",
    "protesterandena": "protesterande",
    "protesterandenas": "protesterande",
    "protesterandens": "protesterande",
    "protesterandes": "protesterande",
    "protesterandet": "protesterande",
    "protesterandets": "protesterande",
    "protesterar": "protestera",
    "protesteras": "protestera",
    "protesterat": "protestera",
    "protesterats": "protestera",
    "protesteringar": "protestering",
    "protesteringarna": "protestering",
    "protesteringarnas": "protestering",
    "protesteringars": "protestering",
    "protesteringen": "protestering",
    "protesteringens": "protestering",
    "protesterings": "protestering",
    "protesterna": "protest",
    "protesternas": "protest",
    "protesters": "protest",
    "proteströrelsen": "proteströrelse",
    "proteströrelsens": "proteströrelse",
    "proteströrelser": "proteströrelse",
    "proteströrelserna": "proteströrelse",
    "proteströrelsernas": "proteströrelse",
    "proteströrelsers": "proteströrelse",
    "proteströrelses": "proteströrelse",
    "proteströst": "proteströsta",
    "proteströstade": "proteströsta",
    "proteströstades": "proteströsta",
    "proteströstande": "proteströsta",
    "proteströstanden": "proteströstande",
    "proteströstandena": "proteströstande",
    "proteströstandenas": "proteströstande",
    "proteströstandens": "proteströstande",
    "proteströstandes": "proteströstande",
    "proteströstandet": "proteströstande",
    "proteströstandets": "proteströstande",
    "proteströstar": "proteströsta",
    "proteströstas": "proteströsta",
    "proteströstat": "proteströsta",
    "proteströstats": "proteströsta",
    "proteströsten": "proteströst",
    "proteströstens": "proteströst",
    "proteströster": "proteströst",
    "proteströsterna": "proteströst",
    "proteströsternas": "proteströst",
    "proteströsters": "proteströst",
    "proteströsts": "proteströst",
    "protests": "protest",
    "proteststrejken": "proteststrejk",
    "proteststrejkens": "proteststrejk",
    "proteststrejker": "proteststrejk",
    "proteststrejkerna": "proteststrejk",
    "proteststrejkernas": "proteststrejk",
    "proteststrejkers": "proteststrejk",
    "proteststrejks": "proteststrejk",
    "protesttalen": "protesttal",
    "protesttalens": "protesttal",
    "protesttalet": "protesttal",
    "protesttalets": "protesttal",
    "protesttals": "protesttal",
    "protestviljan": "protestvilja",
    "protestviljans": "protestvilja",
    "protestviljas": "protestvilja",
    "protestvilje": "protestvilja",
    "protestviljor": "protestvilja",
    "protestviljorna": "protestvilja",
    "protestviljornas": "protestvilja",
    "protestviljors": "protestvilja",
    "protetiken": "protetik",
    "protetikens": "protetik",
    "protetiks": "protetik",
    "protokollen": "protokoll",
    "protokollens": "protokoll",
    "protokollerad": "protokollera",
    "protokollerade": "protokollera",
    "protokollerades": "protokollera",
    "protokollerads": "protokollera",
    "protokollerande": "protokollera",
    "protokolleranden": "protokollerande",
    "protokollerandena": "protokollerande",
    "protokollerandenas": "protokollerande",
    "protokollerandens": "protokollerande",
    "protokollerandes": "protokollerande",
    "protokollerandet": "protokollerande",
    "protokollerandets": "protokollerande",
    "protokollerar": "protokollera",
    "protokolleras": "protokollera",
    "protokollerat": "protokollera",
    "protokollerats": "protokollera",
    "protokollerbara": "protokollerbar",
    "protokollerbarare": "protokollerbar",
    "protokollerbarares": "protokollerbar",
    "protokollerbaras": "protokollerbar",
    "protokollerbarast": "protokollerbar",
    "protokollerbaraste": "protokollerbar",
    "protokollerbarastes": "protokollerbar",
    "protokollerbarasts": "protokollerbar",
    "protokollerbare": "protokollerbar",
    "protokollerbares": "protokollerbar",
    "protokollerbarheten": "protokollerbarhet",
    "protokollerbarhetens": "protokollerbarhet",
    "protokollerbarhets": "protokollerbarhet",
    "protokollerbars": "protokollerbar",
    "protokollerbart": "protokollerbar",
    "protokollerbarts": "protokollerbar",
    "protokolleringar": "protokollering",
    "protokolleringarna": "protokollering",
    "protokolleringarnas": "protokollering",
    "protokolleringars": "protokollering",
    "protokolleringen": "protokollering",
    "protokolleringens": "protokollering",
    "protokollerings": "protokollering",
    "protokollet": "protokoll",
    "protokollets": "protokoll",
    "protokollmässiga": "protokollmässig",
    "protokollmässigare": "protokollmässig",
    "protokollmässigares": "protokollmässig",
    "protokollmässigas": "protokollmässig",
    "protokollmässigast": "protokollmässig",
    "protokollmässigaste": "protokollmässig",
    "protokollmässigastes": "protokollmässig",
    "protokollmässigasts": "protokollmässig",
    "protokollmässige": "protokollmässig",
    "protokollmässiges": "protokollmässig",
    "protokollmässigs": "protokollmässig",
    "protokollmässigt": "protokollmässig",
    "protokollmässigts": "protokollmässig",
    "protokolls": "protokoll",
    "protokollära": "protokollär",
    "protokollärare": "protokollär",
    "protokollärares": "protokollär",
    "protokolläras": "protokollär",
    "protokollärast": "protokollär",
    "protokolläraste": "protokollär",
    "protokollärastes": "protokollär",
    "protokollärasts": "protokollär",
    "protokolläre": "protokollär",
    "protokolläres": "protokollär",
    "protokollärs": "protokollär",
    "protokollärt": "protokollär",
    "protokollärts": "protokollär",
    "protolysen": "protolys",
    "protolysens": "protolys",
    "protolyser": "protolys",
    "protolyserna": "protolys",
    "protolysernas": "protolys",
    "protolysers": "protolys",
    "protolyten": "protolyt",
    "protolytens": "protolyt",
    "protolyter": "protolyt",
    "protolyterna": "protolyt",
    "protolyternas": "protolyt",
    "protolyters": "protolyt",
    "protolyts": "protolyt",
    "protonen": "proton",
    "protonens": "proton",
    "protoner": "proton",
    "protonerna": "proton",
    "protonernas": "proton",
    "protoners": "proton",
    "protonkarusellen": "protonkarusell",
    "protonkarusellens": "protonkarusell",
    "protonkaruseller": "protonkarusell",
    "protonkarusellerna": "protonkarusell",
    "protonkarusellernas": "protonkarusell",
    "protonkarusellers": "protonkarusell",
    "protonkarusells": "protonkarusell",
    "protonknivar": "protonkniv",
    "protonknivarna": "protonkniv",
    "protonknivarnas": "protonkniv",
    "protonknivars": "protonkniv",
    "protonkniven": "protonkniv",
    "protonknivens": "protonkniv",
    "protonknivs": "protonkniv",
    "protonladdningar": "protonladdning",
    "protonladdningarna": "protonladdning",
    "protonladdningarnas": "protonladdning",
    "protonladdningars": "protonladdning",
    "protonladdningen": "protonladdning",
    "protonladdningens": "protonladdning",
    "protonladdnings": "protonladdning",
    "protons": "proton",
    "protonterapien": "protonterapi",
    "protonterapiens": "protonterapi",
    "protonterapin": "protonterapi",
    "protonterapins": "protonterapi",
    "protonterapis": "protonterapi",
    "protoplasman": "protoplasma",
    "protoplasmans": "protoplasma",
    "protoplasmas": "protoplasma",
    "protoplasmat": "protoplasma",
    "protoplasmats": "protoplasma",
    "prototypen": "prototyp",
    "prototypens": "prototyp",
    "prototyper": "prototyp",
    "prototyperna": "prototyp",
    "prototypernas": "prototyp",
    "prototypers": "prototyp",
    "prototyps": "prototyp",
    "protozoer": "protozo",
    "protozoerna": "protozo",
    "protozoernas": "protozo",
    "protozoers": "protozo",
    "protozon": "protozo",
    "protozons": "protozo",
    "protozos": "protozo",
    "protuberansen": "protuberans",
    "protuberansens": "protuberans",
    "protuberanser": "protuberans",
    "protuberanserna": "protuberans",
    "protuberansernas": "protuberans",
    "protuberansers": "protuberans",
    "prov": "prova",
    "provad": "prova",
    "provade": "prova",
    "provades": "prova",
    "provads": "prova",
    "provanalysen": "provanalys",
    "provanalysens": "provanalys",
    "provanalyser": "provanalys",
    "provanalyserna": "provanalys",
    "provanalysernas": "provanalys",
    "provanalysers": "provanalys",
    "provande": "prova",
    "provanden": "provande",
    "provandena": "provande",
    "provandenas": "provande",
    "provandens": "provande",
    "provandes": "provande",
    "provandet": "provande",
    "provandets": "provande",
    "provanställningar": "provanställning",
    "provanställningarna": "provanställning",
    "provanställningarnas": "provanställning",
    "provanställningars": "provanställning",
    "provanställningen": "provanställning",
    "provanställningens": "provanställning",
    "provanställnings": "provanställning",
    "provar": "provare",
    "provaren": "provare",
    "provarens": "provare",
    "provares": "provare",
    "provarna": "provare",
    "provarnas": "provare",
    "provas": "prova",
    "provat": "prova",
    "provats": "prova",
    "provdock": "provdocka",
    "provdockan": "provdocka",
    "provdockans": "provdocka",
    "provdockas": "provdocka",
    "provdocke": "provdocka",
    "provdockor": "provdocka",
    "provdockorna": "provdocka",
    "provdockornas": "provdocka",
    "provdockors": "provdocka",
    "provdocks": "provdocka",
    "proven": "prov",
    "proveniensen": "proveniens",
    "proveniensens": "proveniens",
    "provenienser": "proveniens",
    "provenienserna": "proveniens",
    "proveniensernas": "proveniens",
    "proveniensers": "proveniens",
    "provens": "prov",
    "provensalen": "provensal",
    "provensalens": "provensal",
    "provensaler": "provensal",
    "provensalerna": "provensal",
    "provensalernas": "provensal",
    "provensalers": "provensal",
    "provensals": "provensal",
    "provensalsk": "provensalska",
    "provensalska": "provensalsk",
    "provensalskan": "provensalska",
    "provensalskans": "provensalska",
    "provensalskare": "provensalsk",
    "provensalskares": "provensalsk",
    "provensalskas": "provensalska",
    "provensalskast": "provensalsk",
    "provensalskaste": "provensalsk",
    "provensalskastes": "provensalsk",
    "provensalskasts": "provensalsk",
    "provensalske": "provensalska",
    "provensalskes": "provensalsk",
    "provensalskor": "provensalska",
    "provensalskorna": "provensalska",
    "provensalskornas": "provensalska",
    "provensalskors": "provensalska",
    "provensalsks": "provensalsk",
    "provensalskt": "provensalsk",
    "provensalskts": "provensalsk",
    "prover": "prov",
    "proverben": "proverb",
    "proverbens": "proverb",
    "proverbet": "proverb",
    "proverbets": "proverb",
    "proverbs": "proverb",
    "proverna": "prov",
    "provernas": "prov",
    "provers": "prov",
    "provet": "prov",
    "provets": "prov",
    "provglasen": "provglas",
    "provglasens": "provglas",
    "provglaset": "provglas",
    "provglasets": "provglas",
    "provianten": "proviant",
    "proviantens": "proviant",
    "provianterade": "proviantera",
    "provianterades": "proviantera",
    "provianterande": "proviantera",
    "provianteranden": "provianterande",
    "provianterandena": "provianterande",
    "provianterandenas": "provianterande",
    "provianterandens": "provianterande",
    "provianterandes": "provianterande",
    "provianterandet": "provianterande",
    "provianterandets": "provianterande",
    "provianterar": "proviantera",
    "provianteras": "proviantera",
    "provianterat": "proviantera",
    "provianterats": "proviantera",
    "provianteringar": "proviantering",
    "provianteringarna": "proviantering",
    "provianteringarnas": "proviantering",
    "provianteringars": "proviantering",
    "provianteringen": "proviantering",
    "provianteringens": "proviantering",
    "provianterings": "proviantering",
    "proviants": "proviant",
    "provien": "provie",
    "proviens": "provie",
    "provies": "provie",
    "proviesarna": "provie",
    "proviesarnas": "provie",
    "proviesen": "provie",
    "proviesens": "provie",
    "provinsen": "provins",
    "provinsens": "provins",
    "provinser": "provins",
    "provinserna": "provins",
    "provinsernas": "provins",
    "provinsers": "provins",
    "provinsialismen": "provinsialism",
    "provinsialismens": "provinsialism",
    "provinsialismer": "provinsialism",
    "provinsialismerna": "provinsialism",
    "provinsialismernas": "provinsialism",
    "provinsialismers": "provinsialism",
    "provinsialisms": "provinsialism",
    "provinsialistiska": "provinsialistisk",
    "provinsialistiskas": "provinsialistisk",
    "provinsialistiske": "provinsialistisk",
    "provinsialistiskes": "provinsialistisk",
    "provinsialistisks": "provinsialistisk",
    "provinsialistiskt": "provinsialistisk",
    "provinsialistiskts": "provinsialistisk",
    "provinsialläkar": "provinsialläkare",
    "provinsialläkaren": "provinsialläkare",
    "provinsialläkarens": "provinsialläkare",
    "provinsialläkares": "provinsialläkare",
    "provinsialläkarna": "provinsialläkare",
    "provinsialläkarnas": "provinsialläkare",
    "provinsiella": "provinsiell",
    "provinsiellare": "provinsiell",
    "provinsiellares": "provinsiell",
    "provinsiellas": "provinsiell",
    "provinsiellast": "provinsiell",
    "provinsiellaste": "provinsiell",
    "provinsiellastes": "provinsiell",
    "provinsiellasts": "provinsiell",
    "provinsielle": "provinsiell",
    "provinsielles": "provinsiell",
    "provinsiells": "provinsiell",
    "provinsiellt": "provinsiell",
    "provinsiellts": "provinsiell",
    "provisionen": "provision",
    "provisionens": "provision",
    "provisioner": "provision",
    "provisionerna": "provision",
    "provisionernas": "provision",
    "provisioners": "provision",
    "provisions": "provision",
    "provisorie": "provisorium",
    "provisorier": "provisorium",
    "provisorierna": "provisorium",
    "provisoriernas": "provisorium",
    "provisoriers": "provisorium",
    "provisoriet": "provisorium",
    "provisoriets": "provisorium",
    "provisoriska": "provisorisk",
    "provisoriskare": "provisorisk",
    "provisoriskares": "provisorisk",
    "provisoriskas": "provisorisk",
    "provisoriskast": "provisorisk",
    "provisoriskaste": "provisorisk",
    "provisoriskastes": "provisorisk",
    "provisoriskasts": "provisorisk",
    "provisoriske": "provisorisk",
    "provisoriskes": "provisorisk",
    "provisorisks": "provisorisk",
    "provisoriskt": "provisorisk",
    "provisoriskts": "provisorisk",
    "provisoriums": "provisorium",
    "provkart": "provkarta",
    "provkartan": "provkarta",
    "provkartans": "provkarta",
    "provkartas": "provkarta",
    "provkarte": "provkarta",
    "provkartor": "provkarta",
    "provkartorna": "provkarta",
    "provkartornas": "provkarta",
    "provkartors": "provkarta",
    "provkarts": "provkarta",
    "provköken": "provkök",
    "provkökens": "provkök",
    "provköket": "provkök",
    "provkökets": "provkök",
    "provköks": "provkök",
    "provkör": "provköra",
    "provkörande": "provköra",
    "provköranden": "provkörande",
    "provkörandena": "provkörande",
    "provkörandenas": "provkörande",
    "provkörandens": "provkörande",
    "provkörandes": "provkörande",
    "provkörandet": "provkörande",
    "provkörandets": "provkörande",
    "provköras": "provköra",
    "provkörd": "provköra",
    "provkörda": "provköra",
    "provkördas": "provköra",
    "provkörde": "provköra",
    "provkördes": "provköra",
    "provkörds": "provköra",
    "provköres": "provköra",
    "provkörs": "provköra",
    "provkört": "provköra",
    "provkörts": "provköra",
    "provningar": "provning",
    "provningarna": "provning",
    "provningarnas": "provning",
    "provningars": "provning",
    "provningen": "provning",
    "provningens": "provning",
    "provnings": "provning",
    "provocerad": "provocera",
    "provocerade": "provocera",
    "provocerades": "provocera",
    "provocerads": "provocera",
    "provocerande": "provocera",
    "provoceranden": "provocerande",
    "provocerandena": "provocerande",
    "provocerandenas": "provocerande",
    "provocerandens": "provocerande",
    "provocerandes": "provocerande",
    "provocerandet": "provocerande",
    "provocerandets": "provocerande",
    "provocerar": "provocera",
    "provoceras": "provocera",
    "provocerat": "provocera",
    "provocerats": "provocera",
    "provocerbara": "provocerbar",
    "provocerbarare": "provocerbar",
    "provocerbarares": "provocerbar",
    "provocerbaras": "provocerbar",
    "provocerbarast": "provocerbar",
    "provocerbaraste": "provocerbar",
    "provocerbarastes": "provocerbar",
    "provocerbarasts": "provocerbar",
    "provocerbare": "provocerbar",
    "provocerbares": "provocerbar",
    "provocerbarheten": "provocerbarhet",
    "provocerbarhetens": "provocerbarhet",
    "provocerbarhets": "provocerbarhet",
    "provocerbars": "provocerbar",
    "provocerbart": "provocerbar",
    "provocerbarts": "provocerbar",
    "provoceringar": "provocering",
    "provoceringarna": "provocering",
    "provoceringarnas": "provocering",
    "provoceringars": "provocering",
    "provoceringen": "provocering",
    "provoceringens": "provocering",
    "provocerings": "provocering",
    "provokationen": "provokation",
    "provokationens": "provokation",
    "provokationer": "provokation",
    "provokationerna": "provokation",
    "provokationernas": "provokation",
    "provokationers": "provokation",
    "provokations": "provokation",
    "provokativa": "provokativ",
    "provokativare": "provokativ",
    "provokativares": "provokativ",
    "provokativas": "provokativ",
    "provokativast": "provokativ",
    "provokativaste": "provokativ",
    "provokativastes": "provokativ",
    "provokativasts": "provokativ",
    "provokative": "provokativ",
    "provokatives": "provokativ",
    "provokativs": "provokativ",
    "provokativt": "provokativ",
    "provokativts": "provokativ",
    "provokatoriska": "provokatorisk",
    "provokatoriskare": "provokatorisk",
    "provokatoriskares": "provokatorisk",
    "provokatoriskas": "provokatorisk",
    "provokatoriskast": "provokatorisk",
    "provokatoriskaste": "provokatorisk",
    "provokatoriskastes": "provokatorisk",
    "provokatoriskasts": "provokatorisk",
    "provokatoriske": "provokatorisk",
    "provokatoriskes": "provokatorisk",
    "provokatorisks": "provokatorisk",
    "provokatoriskt": "provokatorisk",
    "provokatoriskts": "provokatorisk",
    "provokatören": "provokatör",
    "provokatörens": "provokatör",
    "provokatörer": "provokatör",
    "provokatörerna": "provokatör",
    "provokatörernas": "provokatör",
    "provokatörers": "provokatör",
    "provokatörs": "provokatör",
    "provrummen": "provrum",
    "provrummens": "provrum",
    "provrummet": "provrum",
    "provrummets": "provrum",
    "provrums": "provrum",
    "provryttar": "provryttare",
    "provryttaren": "provryttare",
    "provryttarens": "provryttare",
    "provryttares": "provryttare",
    "provryttarna": "provryttare",
    "provryttarnas": "provryttare",
    "provräkningar": "provräkning",
    "provräkningarna": "provräkning",
    "provräkningarnas": "provräkning",
    "provräkningars": "provräkning",
    "provräkningen": "provräkning",
    "provräkningens": "provräkning",
    "provräknings": "provräkning",
    "provrören": "provrör",
    "provrörens": "provrör",
    "provröret": "provrör",
    "provrörets": "provrör",
    "provrörs": "provrör",
    "provrörsbarnen": "provrörsbarn",
    "provrörsbarnens": "provrörsbarn",
    "provrörsbarnet": "provrörsbarn",
    "provrörsbarnets": "provrörsbarn",
    "provrörsbarns": "provrörsbarn",
    "provrörsbefruktningar": "provrörsbefruktning",
    "provrörsbefruktningarna": "provrörsbefruktning",
    "provrörsbefruktningarnas": "provrörsbefruktning",
    "provrörsbefruktningars": "provrörsbefruktning",
    "provrörsbefruktningen": "provrörsbefruktning",
    "provrörsbefruktningens": "provrörsbefruktning",
    "provrörsbefruktnings": "provrörsbefruktning",
    "provs": "prov",
    "provskjut": "provskjuta",
    "provskjutande": "provskjuta",
    "provskjutandes": "provskjuta",
    "provskjutas": "provskjuta",
    "provskjute": "provskjuta",
    "provskjuten": "provskjuta",
    "provskjutens": "provskjuta",
    "provskjuter": "provskjuta",
    "provskjutes": "provskjuta",
    "provskjutet": "provskjuta",
    "provskjutets": "provskjuta",
    "provskjutit": "provskjuta",
    "provskjutits": "provskjuta",
    "provskjutna": "provskjuta",
    "provskjutnas": "provskjuta",
    "provskjutne": "provskjuta",
    "provskjutnes": "provskjuta",
    "provskjutningar": "provskjutning",
    "provskjutningarna": "provskjutning",
    "provskjutningarnas": "provskjutning",
    "provskjutningars": "provskjutning",
    "provskjutningen": "provskjutning",
    "provskjutningens": "provskjutning",
    "provskjutnings": "provskjutning",
    "provskjuts": "provskjuta",
    "provsköt": "provskjuta",
    "provsköte": "provskjuta",
    "provskötes": "provskjuta",
    "provsköts": "provskjuta",
    "provsprängningar": "provsprängning",
    "provsprängningarna": "provsprängning",
    "provsprängningarnas": "provsprängning",
    "provsprängningars": "provsprängning",
    "provsprängningen": "provsprängning",
    "provsprängningens": "provsprängning",
    "provsprängnings": "provsprängning",
    "provstoppen": "provstopp",
    "provstoppens": "provstopp",
    "provstoppet": "provstopp",
    "provstoppets": "provstopp",
    "provstopps": "provstopp",
    "provtagningar": "provtagning",
    "provtagningarna": "provtagning",
    "provtagningarnas": "provtagning",
    "provtagningars": "provtagning",
    "provtagningen": "provtagning",
    "provtagningens": "provtagning",
    "provtagnings": "provtagning",
    "provtjänstgöringar": "provtjänstgöring",
    "provtjänstgöringarna": "provtjänstgöring",
    "provtjänstgöringarnas": "provtjänstgöring",
    "provtjänstgöringars": "provtjänstgöring",
    "provtjänstgöringen": "provtjänstgöring",
    "provtjänstgöringens": "provtjänstgöring",
    "provtjänstgörings": "provtjänstgöring",
    "provturen": "provtur",
    "provturens": "provtur",
    "provturer": "provtur",
    "provturerna": "provtur",
    "provturernas": "provtur",
    "provturers": "provtur",
    "provturs": "provtur",
    "provuppgiften": "provuppgift",
    "provuppgiftens": "provuppgift",
    "provuppgifter": "provuppgift",
    "provuppgifterna": "provuppgift",
    "provuppgifternas": "provuppgift",
    "provuppgifters": "provuppgift",
    "provuppgifts": "provuppgift",
    "provåren": "provår",
    "provårens": "provår",
    "provåret": "provår",
    "provårets": "provår",
    "provårs": "provår",
    "proximala": "proximal",
    "proximalare": "proximal",
    "proximalares": "proximal",
    "proximalas": "proximal",
    "proximalast": "proximal",
    "proximalaste": "proximal",
    "proximalastes": "proximal",
    "proximalasts": "proximal",
    "proximale": "proximal",
    "proximales": "proximal",
    "proximals": "proximal",
    "proximalt": "proximal",
    "proximalts": "proximal",
    "prudentliga": "prudentlig",
    "prudentligare": "prudentlig",
    "prudentligares": "prudentlig",
    "prudentligas": "prudentlig",
    "prudentligast": "prudentlig",
    "prudentligaste": "prudentlig",
    "prudentligastes": "prudentlig",
    "prudentligasts": "prudentlig",
    "prudentlige": "prudentlig",
    "prudentliges": "prudentlig",
    "prudentligheten": "prudentlighet",
    "prudentlighetens": "prudentlighet",
    "prudentligheter": "prudentlighet",
    "prudentligheterna": "prudentlighet",
    "prudentligheternas": "prudentlighet",
    "prudentligheters": "prudentlighet",
    "prudentlighets": "prudentlighet",
    "prudentligs": "prudentlig",
    "prudentligt": "prudentlig",
    "prudentligts": "prudentlig",
    "prunefärgade": "prunefärgad",
    "prunefärgades": "prunefärgad",
    "prunefärgads": "prunefärgad",
    "prunefärgat": "prunefärgad",
    "prunefärgats": "prunefärgad",
    "prunellen": "prunell",
    "prunellens": "prunell",
    "pruneller": "prunell",
    "prunellerna": "prunell",
    "prunellernas": "prunell",
    "prunellers": "prunell",
    "prunells": "prunell",
    "prunkade": "prunka",
    "prunkades": "prunka",
    "prunkande": "prunka",
    "prunkanden": "prunkande",
    "prunkandena": "prunkande",
    "prunkandenas": "prunkande",
    "prunkandens": "prunkande",
    "prunkandes": "prunkande",
    "prunkandet": "prunkande",
    "prunkandets": "prunkande",
    "prunkar": "prunka",
    "prunkas": "prunka",
    "prunkat": "prunka",
    "prunkats": "prunka",
    "prunket": "prunk",
    "prunkets": "prunk",
    "prunks": "prunk",
    "prust": "prusta",
    "prustade": "prusta",
    "prustades": "prusta",
    "prustande": "prusta",
    "prustanden": "prustande",
    "prustandena": "prustande",
    "prustandenas": "prustande",
    "prustandens": "prustande",
    "prustandes": "prustande",
    "prustandet": "prustande",
    "prustandets": "prustande",
    "prustar": "prusta",
    "prustas": "prusta",
    "prustat": "prusta",
    "prustats": "prusta",
    "prustroten": "prustrot",
    "prustrotens": "prustrot",
    "prustrots": "prustrot",
    "prut": "pruta",
    "prutad": "pruta",
    "prutade": "pruta",
    "prutades": "pruta",
    "prutads": "pruta",
    "prutande": "pruta",
    "prutanden": "prutande",
    "prutandena": "prutande",
    "prutandenas": "prutande",
    "prutandens": "prutande",
    "prutandes": "prutande",
    "prutandet": "prutande",
    "prutandets": "prutande",
    "prutar": "pruta",
    "prutas": "pruta",
    "prutat": "pruta",
    "prutats": "pruta",
    "prutgäss": "prutgås",
    "prutgässen": "prutgås",
    "prutgässens": "prutgås",
    "prutgåsen": "prutgås",
    "prutgåsens": "prutgås",
    "prutmånen": "prutmån",
    "prutmånens": "prutmån",
    "prutmåns": "prutmån",
    "pruttade": "prutta",
    "pruttades": "prutta",
    "pruttande": "prutta",
    "pruttanden": "pruttande",
    "pruttandena": "pruttande",
    "pruttandenas": "pruttande",
    "pruttandens": "pruttande",
    "pruttandes": "pruttande",
    "pruttandet": "pruttande",
    "pruttandets": "pruttande",
    "pruttar": "prutta",
    "pruttarna": "prutt",
    "pruttarnas": "prutt",
    "pruttars": "prutt",
    "pruttas": "prutta",
    "pruttat": "prutta",
    "pruttats": "prutta",
    "prutten": "prutt",
    "pruttens": "prutt",
    "pruttiga": "pruttig",
    "pruttigare": "pruttig",
    "pruttigares": "pruttig",
    "pruttigas": "pruttig",
    "pruttigast": "pruttig",
    "pruttigaste": "pruttig",
    "pruttigastes": "pruttig",
    "pruttigasts": "pruttig",
    "pruttige": "pruttig",
    "pruttiges": "pruttig",
    "pruttigheten": "pruttighet",
    "pruttighetens": "pruttighet",
    "pruttighets": "pruttighet",
    "pruttigs": "pruttig",
    "pruttigt": "pruttig",
    "pruttigts": "pruttig",
    "prutts": "prutt",
    "pry": "prya",
    "pryade": "prya",
    "pryades": "prya",
    "pryan": "prya",
    "pryande": "prya",
    "pryanden": "pryande",
    "pryandena": "pryande",
    "pryandenas": "pryande",
    "pryandens": "pryande",
    "pryandes": "pryande",
    "pryandet": "pryande",
    "pryandets": "pryande",
    "pryans": "prya",
    "pryar": "prya",
    "pryas": "prya",
    "pryat": "prya",
    "pryats": "prya",
    "pryd": "pryda",
    "pryda": "pryd",
    "prydande": "pryda",
    "prydanden": "prydande",
    "prydandena": "prydande",
    "prydandenas": "prydande",
    "prydandens": "prydande",
    "prydandes": "prydande",
    "prydandet": "prydande",
    "prydandets": "prydande",
    "prydare": "pryd",
    "prydares": "pryd",
    "prydas": "pryda",
    "prydast": "pryd",
    "prydaste": "pryd",
    "prydastes": "pryd",
    "prydasts": "pryd",
    "prydd": "pryda",
    "prydda": "pryda",
    "pryddas": "pryda",
    "prydde": "pryda",
    "pryddes": "pryda",
    "prydds": "pryda",
    "pryde": "pryd",
    "pryder": "pryda",
    "pryderiet": "pryderi",
    "pryderiets": "pryderi",
    "pryderis": "pryderi",
    "pryderit": "pryderi",
    "pryderits": "pryderi",
    "prydes": "pryda",
    "prydheten": "prydhet",
    "prydhetens": "prydhet",
    "prydheter": "prydhet",
    "prydheterna": "prydhet",
    "prydheternas": "prydhet",
    "prydheters": "prydhet",
    "prydhets": "prydhet",
    "prydliga": "prydlig",
    "prydligare": "prydlig",
    "prydligares": "prydlig",
    "prydligas": "prydlig",
    "prydligast": "prydlig",
    "prydligaste": "prydlig",
    "prydligastes": "prydlig",
    "prydligasts": "prydlig",
    "prydlige": "prydlig",
    "prydliges": "prydlig",
    "prydligheten": "prydlighet",
    "prydlighetens": "prydlighet",
    "prydlighets": "prydlighet",
    "prydligs": "prydlig",
    "prydligt": "prydlig",
    "prydligts": "prydlig",
    "prydnaden": "prydnad",
    "prydnadens": "prydnad",
    "prydnader": "prydnad",
    "prydnaderna": "prydnad",
    "prydnadernas": "prydnad",
    "prydnaders": "prydnad",
    "prydnads": "prydnad",
    "prydnadsartikeln": "prydnadsartikel",
    "prydnadsartikelns": "prydnadsartikel",
    "prydnadsartikels": "prydnadsartikel",
    "prydnadsartiklar": "prydnadsartikel",
    "prydnadsartiklarna": "prydnadsartikel",
    "prydnadsartiklarnas": "prydnadsartikel",
    "prydnadsartiklars": "prydnadsartikel",
    "prydnadsblom": "prydnadsblomma",
    "prydnadsblomman": "prydnadsblomma",
    "prydnadsblommans": "prydnadsblomma",
    "prydnadsblommas": "prydnadsblomma",
    "prydnadsblomme": "prydnadsblomma",
    "prydnadsblommor": "prydnadsblomma",
    "prydnadsblommorna": "prydnadsblomma",
    "prydnadsblommornas": "prydnadsblomma",
    "prydnadsblommors": "prydnadsblomma",
    "prydnadsbloms": "prydnadsblomma",
    "prydnadsbusk": "prydnadsbuske",
    "prydnadsbuskar": "prydnadsbuske",
    "prydnadsbuskarna": "prydnadsbuske",
    "prydnadsbuskarnas": "prydnadsbuske",
    "prydnadsbuskars": "prydnadsbuske",
    "prydnadsbusken": "prydnadsbuske",
    "prydnadsbuskens": "prydnadsbuske",
    "prydnadsbuskes": "prydnadsbuske",
    "prydnadsdetaljen": "prydnadsdetalj",
    "prydnadsdetaljens": "prydnadsdetalj",
    "prydnadsdetaljer": "prydnadsdetalj",
    "prydnadsdetaljerna": "prydnadsdetalj",
    "prydnadsdetaljernas": "prydnadsdetalj",
    "prydnadsdetaljers": "prydnadsdetalj",
    "prydnadsdetaljs": "prydnadsdetalj",
    "prydnadsfiguren": "prydnadsfigur",
    "prydnadsfigurens": "prydnadsfigur",
    "prydnadsfigurer": "prydnadsfigur",
    "prydnadsfigurerna": "prydnadsfigur",
    "prydnadsfigurernas": "prydnadsfigur",
    "prydnadsfigurers": "prydnadsfigur",
    "prydnadsfigurs": "prydnadsfigur",
    "prydnadsfjädern": "prydnadsfjäder",
    "prydnadsfjäderns": "prydnadsfjäder",
    "prydnadsfjäders": "prydnadsfjäder",
    "prydnadsfjädrar": "prydnadsfjäder",
    "prydnadsfjädrarna": "prydnadsfjäder",
    "prydnadsfjädrarnas": "prydnadsfjäder",
    "prydnadsfjädrars": "prydnadsfjäder",
    "prydnadsföremålen": "prydnadsföremål",
    "prydnadsföremålens": "prydnadsföremål",
    "prydnadsföremålet": "prydnadsföremål",
    "prydnadsföremålets": "prydnadsföremål",
    "prydnadsföremåls": "prydnadsföremål",
    "prydnadsgaveln": "prydnadsgavel",
    "prydnadsgavelns": "prydnadsgavel",
    "prydnadsgavels": "prydnadsgavel",
    "prydnadsgavlar": "prydnadsgavel",
    "prydnadsgavlarna": "prydnadsgavel",
    "prydnadsgavlarnas": "prydnadsgavel",
    "prydnadsgavlars": "prydnadsgavel",
    "prydnadshjärt": "prydnadshjärta",
    "prydnadshjärtan": "prydnadshjärta",
    "prydnadshjärtana": "prydnadshjärta",
    "prydnadshjärtanas": "prydnadshjärta",
    "prydnadshjärtans": "prydnadshjärta",
    "prydnadshjärtas": "prydnadshjärta",
    "prydnadshjärtat": "prydnadshjärta",
    "prydnadshjärtats": "prydnadshjärta",
    "prydnadshjärts": "prydnadshjärta",
    "prydnadskransar": "prydnadskrans",
    "prydnadskransarna": "prydnadskrans",
    "prydnadskransarnas": "prydnadskrans",
    "prydnadskransars": "prydnadskrans",
    "prydnadskransen": "prydnadskrans",
    "prydnadskransens": "prydnadskrans",
    "prydnadskuddar": "prydnadskudde",
    "prydnadskuddarna": "prydnadskudde",
    "prydnadskuddarnas": "prydnadskudde",
    "prydnadskuddars": "prydnadskudde",
    "prydnadskudden": "prydnadskudde",
    "prydnadskuddens": "prydnadskudde",
    "prydnadskuddes": "prydnadskudde",
    "prydnadslisten": "prydnadslist",
    "prydnadslistens": "prydnadslist",
    "prydnadslister": "prydnadslist",
    "prydnadslisterna": "prydnadslist",
    "prydnadslisternas": "prydnadslist",
    "prydnadslisters": "prydnadslist",
    "prydnadslists": "prydnadslist",
    "prydnadssnör": "prydnadssnöre",
    "prydnadssnören": "prydnadssnöre",
    "prydnadssnörena": "prydnadssnöre",
    "prydnadssnörenas": "prydnadssnöre",
    "prydnadssnörens": "prydnadssnöre",
    "prydnadssnöres": "prydnadssnöre",
    "prydnadssnöret": "prydnadssnöre",
    "prydnadssnörets": "prydnadssnöre",
    "prydnadssnörs": "prydnadssnöre",
    "prydnadsstjärnan": "prydnadsstjärna",
    "prydnadsstjärnans": "prydnadsstjärna",
    "prydnadsstjärnas": "prydnadsstjärna",
    "prydnadsstjärne": "prydnadsstjärna",
    "prydnadsstjärnor": "prydnadsstjärna",
    "prydnadsstjärnorna": "prydnadsstjärna",
    "prydnadsstjärnornas": "prydnadsstjärna",
    "prydnadsstjärnors": "prydnadsstjärna",
    "prydnadssömmar": "prydnadssöm",
    "prydnadssömmarna": "prydnadssöm",
    "prydnadssömmarnas": "prydnadssöm",
    "prydnadssömmars": "prydnadssöm",
    "prydnadssömmen": "prydnadssöm",
    "prydnadssömmens": "prydnadssöm",
    "prydnadssöms": "prydnadssöm",
    "prydnadsvapens": "prydnadsvapen",
    "prydnadsvapnen": "prydnadsvapen",
    "prydnadsvapnens": "prydnadsvapen",
    "prydnadsvapnet": "prydnadsvapen",
    "prydnadsvapnets": "prydnadsvapen",
    "prydnadsvävar": "prydnadsväv",
    "prydnadsvävarna": "prydnadsväv",
    "prydnadsvävarnas": "prydnadsväv",
    "prydnadsvävars": "prydnadsväv",
    "prydnadsväven": "prydnadsväv",
    "prydnadsvävens": "prydnadsväv",
    "prydnadsvävs": "prydnadsväv",
    "prydnadsväxten": "prydnadsväxt",
    "prydnadsväxtens": "prydnadsväxt",
    "prydnadsväxter": "prydnadsväxt",
    "prydnadsväxterna": "prydnadsväxt",
    "prydnadsväxternas": "prydnadsväxt",
    "prydnadsväxters": "prydnadsväxt",
    "prydnadsväxts": "prydnadsväxt",
    "pryds": "pryda",
    "prye": "prya",
    "prygel": "prygla",
    "prygels": "prygel",
    "pryglad": "prygla",
    "pryglade": "prygla",
    "pryglades": "prygla",
    "pryglads": "prygla",
    "pryglande": "prygla",
    "pryglanden": "pryglande",
    "pryglandena": "pryglande",
    "pryglandenas": "pryglande",
    "pryglandens": "pryglande",
    "pryglandes": "pryglande",
    "pryglandet": "pryglande",
    "pryglandets": "pryglande",
    "pryglar": "prygla",
    "pryglas": "prygla",
    "pryglat": "prygla",
    "pryglats": "prygla",
    "pryglet": "prygel",
    "pryglets": "prygel",
    "prylar": "pryl",
    "prylarna": "pryl",
    "prylarnas": "pryl",
    "prylars": "pryl",
    "prylen": "pryl",
    "prylens": "pryl",
    "pryls": "pryl",
    "pryltokiga": "pryltokig",
    "pryltokigare": "pryltokig",
    "pryltokigares": "pryltokig",
    "pryltokigas": "pryltokig",
    "pryltokigast": "pryltokig",
    "pryltokigaste": "pryltokig",
    "pryltokigastes": "pryltokig",
    "pryltokigasts": "pryltokig",
    "pryltokige": "pryltokig",
    "pryltokiges": "pryltokig",
    "pryltokigheten": "pryltokighet",
    "pryltokighetens": "pryltokighet",
    "pryltokighets": "pryltokighet",
    "pryltokigs": "pryltokig",
    "pryltokigt": "pryltokig",
    "pryltokigts": "pryltokig",
    "pryon": "pryo",
    "pryons": "pryo",
    "pryor": "pryo",
    "pryorna": "pryo",
    "pryornas": "pryo",
    "pryors": "pryo",
    "pryos": "pryo",
    "prys": "prya",
    "prytt": "pryda",
    "prytteln": "pryttel",
    "pryttelns": "pryttel",
    "pryttels": "pryttel",
    "pryttlar": "pryttel",
    "pryttlarna": "pryttel",
    "pryttlarnas": "pryttel",
    "pryttlars": "pryttel",
    "prytts": "pryda",
    "prägeln": "prägel",
    "prägelns": "prägel",
    "prägels": "prägel",
    "prägelvärden": "prägelvärde",
    "prägelvärdena": "prägelvärde",
    "prägelvärdenas": "prägelvärde",
    "prägelvärdens": "prägelvärde",
    "prägelvärdes": "prägelvärde",
    "prägelvärdet": "prägelvärde",
    "prägelvärdets": "prägelvärde",
    "präglad": "prägla",
    "präglade": "prägla",
    "präglades": "prägla",
    "präglads": "prägla",
    "präglande": "prägla",
    "präglanden": "präglande",
    "präglandena": "präglande",
    "präglandenas": "präglande",
    "präglandens": "präglande",
    "präglandes": "präglande",
    "präglandet": "präglande",
    "präglandets": "präglande",
    "präglar": "prägla",
    "präglarna": "prägel",
    "präglarnas": "prägel",
    "präglars": "prägel",
    "präglas": "prägla",
    "präglat": "prägla",
    "präglats": "prägla",
    "präglingar": "prägling",
    "präglingarna": "prägling",
    "präglingarnas": "prägling",
    "präglingars": "prägling",
    "präglingen": "prägling",
    "präglingens": "prägling",
    "präglings": "prägling",
    "präktiga": "präktig",
    "präktigare": "präktig",
    "präktigares": "präktig",
    "präktigas": "präktig",
    "präktigast": "präktig",
    "präktigaste": "präktig",
    "präktigastes": "präktig",
    "präktigasts": "präktig",
    "präktige": "präktig",
    "präktiges": "präktig",
    "präktigheten": "präktighet",
    "präktighetens": "präktighet",
    "präktighets": "präktighet",
    "präktigs": "präktig",
    "präktigt": "präktig",
    "präktigts": "präktig",
    "präll": "prälle",
    "prällar": "prälle",
    "prällarna": "prälle",
    "prällarnas": "prälle",
    "prällars": "prälle",
    "prällen": "prälle",
    "prällens": "prälle",
    "prälles": "prälle",
    "prälls": "prälle",
    "pränt": "pränta",
    "präntad": "pränta",
    "präntade": "pränta",
    "präntades": "pränta",
    "präntads": "pränta",
    "präntande": "pränta",
    "präntanden": "präntande",
    "präntandena": "präntande",
    "präntandenas": "präntande",
    "präntandens": "präntande",
    "präntandes": "präntande",
    "präntandet": "präntande",
    "präntandets": "präntande",
    "präntar": "pränta",
    "präntas": "pränta",
    "präntat": "pränta",
    "präntats": "pränta",
    "pränten": "pränt",
    "präntens": "pränt",
    "präntet": "pränt",
    "präntets": "pränt",
    "pränts": "pränt",
    "präriehundar": "präriehund",
    "präriehundarna": "präriehund",
    "präriehundarnas": "präriehund",
    "präriehundars": "präriehund",
    "präriehunden": "präriehund",
    "präriehundens": "präriehund",
    "präriehunds": "präriehund",
    "prärien": "prärie",
    "präriens": "prärie",
    "prärier": "prärie",
    "prärierna": "prärie",
    "präriernas": "prärie",
    "präriers": "prärie",
    "präries": "prärie",
    "prärievargar": "prärievarg",
    "prärievargarna": "prärievarg",
    "prärievargarnas": "prärievarg",
    "prärievargars": "prärievarg",
    "prärievargen": "prärievarg",
    "prärievargens": "prärievarg",
    "prärievargs": "prärievarg",
    "prästbetygen": "prästbetyg",
    "prästbetygens": "prästbetyg",
    "prästbetyget": "prästbetyg",
    "prästbetygets": "prästbetyg",
    "prästbetygs": "prästbetyg",
    "prästdräkten": "prästdräkt",
    "prästdräktens": "prästdräkt",
    "prästdräkter": "prästdräkt",
    "prästdräkterna": "prästdräkt",
    "prästdräkternas": "prästdräkt",
    "prästdräkters": "prästdräkt",
    "prästdräkts": "prästdräkt",
    "prästen": "präst",
    "prästens": "präst",
    "präster": "präst",
    "prästerliga": "prästerlig",
    "prästerligare": "prästerlig",
    "prästerligares": "prästerlig",
    "prästerligas": "prästerlig",
    "prästerligast": "prästerlig",
    "prästerligaste": "prästerlig",
    "prästerligastes": "prästerlig",
    "prästerligasts": "prästerlig",
    "prästerlige": "prästerlig",
    "prästerliges": "prästerlig",
    "prästerligheten": "prästerlighet",
    "prästerlighetens": "prästerlighet",
    "prästerlighets": "prästerlighet",
    "prästerligs": "prästerlig",
    "prästerligt": "prästerlig",
    "prästerligts": "prästerlig",
    "prästerna": "präst",
    "prästernas": "präst",
    "prästers": "präst",
    "prästerskapet": "prästerskap",
    "prästerskapets": "prästerskap",
    "prästerskaps": "prästerskap",
    "prästeståndet": "prästestånd",
    "prästeståndets": "prästestånd",
    "prästestånds": "prästestånd",
    "prästgällen": "prästgäll",
    "prästgällens": "prästgäll",
    "prästgället": "prästgäll",
    "prästgällets": "prästgäll",
    "prästgälls": "prästgäll",
    "prästgårdar": "prästgård",
    "prästgårdarna": "prästgård",
    "prästgårdarnas": "prästgård",
    "prästgårdars": "prästgård",
    "prästgården": "prästgård",
    "prästgårdens": "prästgård",
    "prästgårds": "prästgård",
    "prästgårdslänstolar": "prästgårdslänstol",
    "prästgårdslänstolarna": "prästgårdslänstol",
    "prästgårdslänstolarnas": "prästgårdslänstol",
    "prästgårdslänstolars": "prästgårdslänstol",
    "prästgårdslänstolen": "prästgårdslänstol",
    "prästgårdslänstolens": "prästgårdslänstol",
    "prästgårdslänstols": "prästgårdslänstol",
    "prästgårdsträdgårdar": "prästgårdsträdgård",
    "prästgårdsträdgårdarna": "prästgårdsträdgård",
    "prästgårdsträdgårdarnas": "prästgårdsträdgård",
    "prästgårdsträdgårdars": "prästgårdsträdgård",
    "prästgårdsträdgården": "prästgårdsträdgård",
    "prästgårdsträdgårdens": "prästgårdsträdgård",
    "prästgårdsträdgårds": "prästgårdsträdgård",
    "prästinnan": "prästinna",
    "prästinnans": "prästinna",
    "prästinnas": "prästinna",
    "prästinne": "prästinna",
    "prästinnor": "prästinna",
    "prästinnorna": "prästinna",
    "prästinnornas": "prästinna",
    "prästinnors": "prästinna",
    "prästkrag": "prästkrage",
    "prästkragar": "prästkrage",
    "prästkragarna": "prästkrage",
    "prästkragarnas": "prästkrage",
    "prästkragars": "prästkrage",
    "prästkragen": "prästkrage",
    "prästkragens": "prästkrage",
    "prästkrages": "prästkrage",
    "prästkrags": "prästkrage",
    "prästmannen": "prästman",
    "prästmannens": "prästman",
    "prästmans": "prästman",
    "prästmän": "prästman",
    "prästmännen": "prästman",
    "prästmännens": "prästman",
    "prästmäns": "prästman",
    "prästostar": "prästost",
    "prästostarna": "prästost",
    "prästostarnas": "prästost",
    "prästostars": "prästost",
    "prästosten": "prästost",
    "prästostens": "prästost",
    "prästosts": "prästost",
    "prästrockar": "prästrock",
    "prästrockarna": "prästrock",
    "prästrockarnas": "prästrock",
    "prästrockars": "prästrock",
    "prästrocken": "prästrock",
    "prästrockens": "prästrock",
    "prästrocks": "prästrock",
    "prästrollen": "prästroll",
    "prästrollens": "prästroll",
    "prästroller": "prästroll",
    "prästrollerna": "prästroll",
    "prästrollernas": "prästroll",
    "prästrollers": "prästroll",
    "prästrolls": "prästroll",
    "prästs": "präst",
    "prästskrudar": "prästskrud",
    "prästskrudarna": "prästskrud",
    "prästskrudarnas": "prästskrud",
    "prästskrudars": "prästskrud",
    "prästskruden": "prästskrud",
    "prästskrudens": "prästskrud",
    "prästskruds": "prästskrud",
    "prästståndet": "präststånd",
    "prästståndets": "präststånd",
    "präststånds": "präststånd",
    "prästtillsättningar": "prästtillsättning",
    "prästtillsättningarna": "prästtillsättning",
    "prästtillsättningarnas": "prästtillsättning",
    "prästtillsättningars": "prästtillsättning",
    "prästtillsättningen": "prästtillsättning",
    "prästtillsättningens": "prästtillsättning",
    "prästtillsättnings": "prästtillsättning",
    "prästtiteln": "prästtitel",
    "prästtitelns": "prästtitel",
    "prästtitels": "prästtitel",
    "prästtitlar": "prästtitel",
    "prästtitlarna": "prästtitel",
    "prästtitlarnas": "prästtitel",
    "prästtitlars": "prästtitel",
    "prästutbildningar": "prästutbildning",
    "prästutbildningarna": "prästutbildning",
    "prästutbildningarnas": "prästutbildning",
    "prästutbildningars": "prästutbildning",
    "prästutbildningen": "prästutbildning",
    "prästutbildningens": "prästutbildning",
    "prästutbildnings": "prästutbildning",
    "prästvig": "prästviga",
    "prästvigande": "prästviga",
    "prästviganden": "prästvigande",
    "prästvigandena": "prästvigande",
    "prästvigandenas": "prästvigande",
    "prästvigandens": "prästvigande",
    "prästvigandes": "prästvigande",
    "prästvigandet": "prästvigande",
    "prästvigandets": "prästvigande",
    "prästvigas": "prästviga",
    "prästvigd": "prästviga",
    "prästvigda": "prästviga",
    "prästvigdas": "prästviga",
    "prästvigde": "prästviga",
    "prästvigdes": "prästviga",
    "prästvigds": "prästviga",
    "prästviger": "prästviga",
    "prästviges": "prästviga",
    "prästvigningar": "prästvigning",
    "prästvigningarna": "prästvigning",
    "prästvigningarnas": "prästvigning",
    "prästvigningars": "prästvigning",
    "prästvigningen": "prästvigning",
    "prästvigningens": "prästvigning",
    "prästvignings": "prästvigning",
    "prästvigs": "prästviga",
    "prästvigt": "prästviga",
    "prästvigts": "prästviga",
    "prästvälden": "prästvälde",
    "prästväldena": "prästvälde",
    "prästväldenas": "prästvälde",
    "prästväldens": "prästvälde",
    "prästväldes": "prästvälde",
    "prästväldet": "prästvälde",
    "prästväldets": "prästvälde",
    "prästämbeten": "prästämbete",
    "prästämbetena": "prästämbete",
    "prästämbetenas": "prästämbete",
    "prästämbetens": "prästämbete",
    "prästämbetes": "prästämbete",
    "prästämbetet": "prästämbete",
    "prästämbetets": "prästämbete",
    "prästänk": "prästänka",
    "prästänkan": "prästänka",
    "prästänkans": "prästänka",
    "prästänkas": "prästänka",
    "prästänke": "prästänka",
    "prästänkor": "prästänka",
    "prästänkorna": "prästänka",
    "prästänkornas": "prästänka",
    "prästänkors": "prästänka",
    "prästänks": "prästänka",
    "prålade": "pråla",
    "prålades": "pråla",
    "prålande": "pråla",
    "prålanden": "prålande",
    "prålandena": "prålande",
    "prålandenas": "prålande",
    "prålandens": "prålande",
    "prålandes": "prålande",
    "prålandet": "prålande",
    "prålandets": "prålande",
    "prålar": "pråla",
    "prålas": "pråla",
    "prålat": "pråla",
    "prålats": "pråla",
    "prålet": "prål",
    "prålets": "prål",
    "pråliga": "prålig",
    "pråligare": "prålig",
    "pråligares": "prålig",
    "pråligas": "prålig",
    "pråligast": "prålig",
    "pråligaste": "prålig",
    "pråligastes": "prålig",
    "pråligasts": "prålig",
    "prålige": "prålig",
    "pråliges": "prålig",
    "pråligheten": "prålighet",
    "prålighetens": "prålighet",
    "pråligheter": "prålighet",
    "pråligheterna": "prålighet",
    "pråligheternas": "prålighet",
    "pråligheters": "prålighet",
    "prålighets": "prålighet",
    "pråligs": "prålig",
    "pråligt": "prålig",
    "pråligts": "prålig",
    "pråls": "prål",
    "pråmad": "pråma",
    "pråmade": "pråma",
    "pråmades": "pråma",
    "pråmads": "pråma",
    "pråmande": "pråma",
    "pråmanden": "pråmande",
    "pråmandena": "pråmande",
    "pråmandenas": "pråmande",
    "pråmandens": "pråmande",
    "pråmandes": "pråmande",
    "pråmandet": "pråmande",
    "pråmandets": "pråmande",
    "pråmar": "pråma",
    "pråmarna": "pråm",
    "pråmarnas": "pråm",
    "pråmars": "pråm",
    "pråmas": "pråma",
    "pråmat": "pråma",
    "pråmats": "pråma",
    "pråmen": "pråm",
    "pråmens": "pråm",
    "pråms": "pråm",
    "prångel": "prångla",
    "prången": "prång",
    "prångens": "prång",
    "prånget": "prång",
    "prångets": "prång",
    "prånglade": "prångla",
    "prånglades": "prångla",
    "prånglande": "prångla",
    "prånglanden": "prånglande",
    "prånglandena": "prånglande",
    "prånglandenas": "prånglande",
    "prånglandens": "prånglande",
    "prånglandes": "prånglande",
    "prånglandet": "prånglande",
    "prånglandets": "prånglande",
    "prånglar": "prångla",
    "prånglas": "prångla",
    "prånglat": "prångla",
    "prånglats": "prångla",
    "prånglerier": "prångleri",
    "prånglerierna": "prångleri",
    "prångleriernas": "prångleri",
    "prångleriers": "prångleri",
    "prångleriet": "prångleri",
    "prångleriets": "prångleri",
    "prångleris": "prångleri",
    "prånglerit": "prångleri",
    "prånglerits": "prångleri",
    "prångs": "prång",
    "pröjs": "pröjsa",
    "pröjsad": "pröjsa",
    "pröjsade": "pröjsa",
    "pröjsades": "pröjsa",
    "pröjsads": "pröjsa",
    "pröjsande": "pröjsa",
    "pröjsanden": "pröjsande",
    "pröjsandena": "pröjsande",
    "pröjsandenas": "pröjsande",
    "pröjsandens": "pröjsande",
    "pröjsandes": "pröjsande",
    "pröjsandet": "pröjsande",
    "pröjsandets": "pröjsande",
    "pröjsar": "pröjsa",
    "pröjsares": "pröjsare",
    "pröjsarna": "pröjsare",
    "pröjsarnas": "pröjsare",
    "pröjsas": "pröjsa",
    "pröjsat": "pröjsa",
    "pröjsats": "pröjsa",
    "pröjset": "pröjs",
    "pröjsets": "pröjs",
    "pröv": "pröva",
    "prövad": "pröva",
    "prövade": "pröva",
    "prövades": "pröva",
    "prövads": "pröva",
    "prövande": "pröva",
    "prövanden": "prövande",
    "prövandena": "prövande",
    "prövandenas": "prövande",
    "prövandens": "prövande",
    "prövandes": "prövande",
    "prövandet": "prövande",
    "prövandets": "prövande",
    "prövar": "pröva",
    "prövas": "pröva",
    "prövat": "pröva",
    "prövats": "pröva",
    "prövningar": "prövning",
    "prövningarna": "prövning",
    "prövningarnas": "prövning",
    "prövningars": "prövning",
    "prövningen": "prövning",
    "prövningens": "prövning",
    "prövnings": "prövning",
    "prövningstillstånden": "prövningstillstånd",
    "prövningstillståndens": "prövningstillstånd",
    "prövningstillståndet": "prövningstillstånd",
    "prövningstillståndets": "prövningstillstånd",
    "prövningstillstånds": "prövningstillstånd",
    "prövo": "pröva",
    "prövostenen": "prövosten",
    "prövostenens": "prövosten",
    "prövostens": "prövosten",
    "prövostunden": "prövostund",
    "prövostundens": "prövostund",
    "prövostunder": "prövostund",
    "prövostunderna": "prövostund",
    "prövostundernas": "prövostund",
    "prövostunders": "prövostund",
    "prövostunds": "prövostund",
    "prövotiden": "prövotid",
    "prövotidens": "prövotid",
    "prövotider": "prövotid",
    "prövotiderna": "prövotid",
    "prövotidernas": "prövotid",
    "prövotiders": "prövotid",
    "prövotids": "prövotid",
    "psalmboken": "psalmbok",
    "psalmbokens": "psalmbok",
    "psalmboks": "psalmbok",
    "psalmböcker": "psalmbok",
    "psalmböckerna": "psalmbok",
    "psalmböckernas": "psalmbok",
    "psalmböckers": "psalmbok",
    "psalmdiktar": "psalmdiktare",
    "psalmdiktaren": "psalmdiktare",
    "psalmdiktarens": "psalmdiktare",
    "psalmdiktares": "psalmdiktare",
    "psalmdiktarna": "psalmdiktare",
    "psalmdiktarnas": "psalmdiktare",
    "psalmen": "psalm",
    "psalmens": "psalm",
    "psalmer": "psalm",
    "psalmerna": "psalm",
    "psalmernas": "psalm",
    "psalmers": "psalm",
    "psalmisten": "psalmist",
    "psalmistens": "psalmist",
    "psalmister": "psalmist",
    "psalmisterna": "psalmist",
    "psalmisternas": "psalmist",
    "psalmisters": "psalmist",
    "psalmists": "psalmist",
    "psalmnummerna": "psalmnummer",
    "psalmnummernas": "psalmnummer",
    "psalmnummers": "psalmnummer",
    "psalmnumren": "psalmnummer",
    "psalmnumrens": "psalmnummer",
    "psalmnumret": "psalmnummer",
    "psalmnumrets": "psalmnummer",
    "psalmodien": "psalmodi",
    "psalmodiens": "psalmodi",
    "psalmodier": "psalmodi",
    "psalmodierna": "psalmodi",
    "psalmodiernas": "psalmodi",
    "psalmodiers": "psalmodi",
    "psalmodikonen": "psalmodikon",
    "psalmodikonens": "psalmodikon",
    "psalmodikonet": "psalmodikon",
    "psalmodikonets": "psalmodikon",
    "psalmodikons": "psalmodikon",
    "psalmodin": "psalmodi",
    "psalmodins": "psalmodi",
    "psalmodis": "psalmodi",
    "psalms": "psalm",
    "psalmversar": "psalmvers",
    "psalmversarna": "psalmvers",
    "psalmversarnas": "psalmvers",
    "psalmversars": "psalmvers",
    "psalmversen": "psalmvers",
    "psalmversens": "psalmvers",
    "psalmverser": "psalmvers",
    "psalmverserna": "psalmvers",
    "psalmversernas": "psalmvers",
    "psalmversers": "psalmvers",
    "psaltar": "psaltare",
    "psaltaren": "psaltare",
    "psaltarens": "psaltare",
    "psaltares": "psaltare",
    "psaltarna": "psaltare",
    "psaltarnas": "psaltare",
    "pseudohändelsen": "pseudohändelse",
    "pseudohändelsens": "pseudohändelse",
    "pseudohändelser": "pseudohändelse",
    "pseudohändelserna": "pseudohändelse",
    "pseudohändelsernas": "pseudohändelse",
    "pseudohändelsers": "pseudohändelse",
    "pseudohändelses": "pseudohändelse",
    "pseudonymen": "pseudonym",
    "pseudonymens": "pseudonym",
    "pseudonymer": "pseudonym",
    "pseudonymerna": "pseudonym",
    "pseudonymernas": "pseudonym",
    "pseudonymers": "pseudonym",
    "pseudonyms": "pseudonym",
    "pseudoproblemen": "pseudoproblem",
    "pseudoproblemens": "pseudoproblem",
    "pseudoproblemet": "pseudoproblem",
    "pseudoproblemets": "pseudoproblem",
    "pseudoproblems": "pseudoproblem",
    "psien": "psi",
    "psiens": "psi",
    "psiet": "psi",
    "psiets": "psi",
    "psin": "psi",
    "psina": "psi",
    "psinas": "psi",
    "psins": "psi",
    "psis": "psi",
    "psit": "psi",
    "psits": "psi",
    "psittakosen": "psittakos",
    "psittakosens": "psittakos",
    "psoriasisen": "psoriasis",
    "psoriasisens": "psoriasis",
    "psoriatikern": "psoriatiker",
    "psoriatikerna": "psoriatiker",
    "psoriatikernas": "psoriatiker",
    "psoriatikerns": "psoriatiker",
    "psoriatikers": "psoriatiker",
    "psyk": "psyka",
    "psykad": "psyka",
    "psykade": "psyka",
    "psykades": "psyka",
    "psykads": "psyka",
    "psykande": "psyka",
    "psykanden": "psykande",
    "psykandena": "psykande",
    "psykandenas": "psykande",
    "psykandens": "psykande",
    "psykandes": "psykande",
    "psykandet": "psykande",
    "psykandets": "psykande",
    "psykar": "psyka",
    "psykas": "psyka",
    "psykat": "psyka",
    "psykats": "psyka",
    "psykbryten": "psykbryt",
    "psykbrytens": "psykbryt",
    "psykbrytet": "psykbryt",
    "psykbrytets": "psykbryt",
    "psykbryts": "psykbryt",
    "psykedeliska": "psykedelisk",
    "psykedeliskare": "psykedelisk",
    "psykedeliskares": "psykedelisk",
    "psykedeliskas": "psykedelisk",
    "psykedeliskast": "psykedelisk",
    "psykedeliskaste": "psykedelisk",
    "psykedeliskastes": "psykedelisk",
    "psykedeliskasts": "psykedelisk",
    "psykedeliske": "psykedelisk",
    "psykedeliskes": "psykedelisk",
    "psykedelisks": "psykedelisk",
    "psykedeliskt": "psykedelisk",
    "psykedeliskts": "psykedelisk",
    "psyken": "psyke",
    "psykena": "psyke",
    "psykenas": "psyke",
    "psykens": "psyke",
    "psykes": "psyke",
    "psyket": "psyke",
    "psykets": "psyke",
    "psykfallen": "psykfall",
    "psykfallens": "psykfall",
    "psykfallet": "psykfall",
    "psykfallets": "psykfall",
    "psykfalls": "psykfall",
    "psykiaterförbunden": "psykiaterförbund",
    "psykiaterförbundens": "psykiaterförbund",
    "psykiaterförbundet": "psykiaterförbund",
    "psykiaterförbundets": "psykiaterförbund",
    "psykiaterförbunds": "psykiaterförbund",
    "psykiatern": "psykiater",
    "psykiaterns": "psykiater",
    "psykiaters": "psykiater",
    "psykiatrer": "psykiater",
    "psykiatrerna": "psykiater",
    "psykiatrernas": "psykiater",
    "psykiatrers": "psykiater",
    "psykiatrien": "psykiatri",
    "psykiatriens": "psykiatri",
    "psykiatrikern": "psykiatriker",
    "psykiatrikerna": "psykiatriker",
    "psykiatrikernas": "psykiatriker",
    "psykiatrikerns": "psykiatriker",
    "psykiatrikers": "psykiatriker",
    "psykiatrin": "psykiatri",
    "psykiatrins": "psykiatri",
    "psykiatris": "psykiatri",
    "psykiatriska": "psykiatrisk",
    "psykiatriskare": "psykiatrisk",
    "psykiatriskares": "psykiatrisk",
    "psykiatriskas": "psykiatrisk",
    "psykiatriskast": "psykiatrisk",
    "psykiatriskaste": "psykiatrisk",
    "psykiatriskastes": "psykiatrisk",
    "psykiatriskasts": "psykiatrisk",
    "psykiatriske": "psykiatrisk",
    "psykiatriskes": "psykiatrisk",
    "psykiatrisks": "psykiatrisk",
    "psykiatriskt": "psykiatrisk",
    "psykiatriskts": "psykiatrisk",
    "psykiska": "psykisk",
    "psykiskare": "psykisk",
    "psykiskares": "psykisk",
    "psykiskas": "psykisk",
    "psykiskast": "psykisk",
    "psykiskaste": "psykisk",
    "psykiskastes": "psykisk",
    "psykiskasts": "psykisk",
    "psykiske": "psykisk",
    "psykiskes": "psykisk",
    "psykisks": "psykisk",
    "psykiskt": "psykisk",
    "psykiskts": "psykisk",
    "psykoanalysen": "psykoanalys",
    "psykoanalysens": "psykoanalys",
    "psykoanalyser": "psykoanalys",
    "psykoanalyserad": "psykoanalysera",
    "psykoanalyserade": "psykoanalysera",
    "psykoanalyserades": "psykoanalysera",
    "psykoanalyserads": "psykoanalysera",
    "psykoanalyserande": "psykoanalysera",
    "psykoanalyseranden": "psykoanalyserande",
    "psykoanalyserandena": "psykoanalyserande",
    "psykoanalyserandenas": "psykoanalyserande",
    "psykoanalyserandens": "psykoanalyserande",
    "psykoanalyserandes": "psykoanalyserande",
    "psykoanalyserandet": "psykoanalyserande",
    "psykoanalyserandets": "psykoanalyserande",
    "psykoanalyserar": "psykoanalysera",
    "psykoanalyseras": "psykoanalysera",
    "psykoanalyserat": "psykoanalysera",
    "psykoanalyserats": "psykoanalysera",
    "psykoanalyserbara": "psykoanalyserbar",
    "psykoanalyserbarare": "psykoanalyserbar",
    "psykoanalyserbarares": "psykoanalyserbar",
    "psykoanalyserbaras": "psykoanalyserbar",
    "psykoanalyserbarast": "psykoanalyserbar",
    "psykoanalyserbaraste": "psykoanalyserbar",
    "psykoanalyserbarastes": "psykoanalyserbar",
    "psykoanalyserbarasts": "psykoanalyserbar",
    "psykoanalyserbare": "psykoanalyserbar",
    "psykoanalyserbares": "psykoanalyserbar",
    "psykoanalyserbarheten": "psykoanalyserbarhet",
    "psykoanalyserbarhetens": "psykoanalyserbarhet",
    "psykoanalyserbarhets": "psykoanalyserbarhet",
    "psykoanalyserbars": "psykoanalyserbar",
    "psykoanalyserbart": "psykoanalyserbar",
    "psykoanalyserbarts": "psykoanalyserbar",
    "psykoanalyseringar": "psykoanalysering",
    "psykoanalyseringarna": "psykoanalysering",
    "psykoanalyseringarnas": "psykoanalysering",
    "psykoanalyseringars": "psykoanalysering",
    "psykoanalyseringen": "psykoanalysering",
    "psykoanalyseringens": "psykoanalysering",
    "psykoanalyserings": "psykoanalysering",
    "psykoanalyserna": "psykoanalys",
    "psykoanalysernas": "psykoanalys",
    "psykoanalysers": "psykoanalys",
    "psykoanalyssoff": "psykoanalyssoffa",
    "psykoanalyssoffan": "psykoanalyssoffa",
    "psykoanalyssoffans": "psykoanalyssoffa",
    "psykoanalyssoffas": "psykoanalyssoffa",
    "psykoanalyssoffe": "psykoanalyssoffa",
    "psykoanalyssoffor": "psykoanalyssoffa",
    "psykoanalyssofforna": "psykoanalyssoffa",
    "psykoanalyssoffornas": "psykoanalyssoffa",
    "psykoanalyssoffors": "psykoanalyssoffa",
    "psykoanalyssoffs": "psykoanalyssoffa",
    "psykoanalytikern": "psykoanalytiker",
    "psykoanalytikerna": "psykoanalytiker",
    "psykoanalytikernas": "psykoanalytiker",
    "psykoanalytikerns": "psykoanalytiker",
    "psykoanalytikers": "psykoanalytiker",
    "psykoanalytiska": "psykoanalytisk",
    "psykoanalytiskare": "psykoanalytisk",
    "psykoanalytiskares": "psykoanalytisk",
    "psykoanalytiskas": "psykoanalytisk",
    "psykoanalytiskast": "psykoanalytisk",
    "psykoanalytiskaste": "psykoanalytisk",
    "psykoanalytiskastes": "psykoanalytisk",
    "psykoanalytiskasts": "psykoanalytisk",
    "psykoanalytiske": "psykoanalytisk",
    "psykoanalytiskes": "psykoanalytisk",
    "psykoanalytisks": "psykoanalytisk",
    "psykoanalytiskt": "psykoanalytisk",
    "psykoanalytiskts": "psykoanalytisk",
    "psykodramas": "psykodrama",
    "psykodramat": "psykodrama",
    "psykodramats": "psykodrama",
    "psykofarmakan": "psykofarmaka",
    "psykofarmakana": "psykofarmaka",
    "psykofarmakanas": "psykofarmaka",
    "psykofarmakans": "psykofarmaka",
    "psykofarmakas": "psykofarmaka",
    "psykofarmakat": "psykofarmaka",
    "psykofarmakats": "psykofarmaka",
    "psykofysiken": "psykofysik",
    "psykofysikens": "psykofysik",
    "psykofysiks": "psykofysik",
    "psykogena": "psykogen",
    "psykogenare": "psykogen",
    "psykogenares": "psykogen",
    "psykogenas": "psykogen",
    "psykogenast": "psykogen",
    "psykogenaste": "psykogen",
    "psykogenastes": "psykogen",
    "psykogenasts": "psykogen",
    "psykogene": "psykogen",
    "psykogenes": "psykogen",
    "psykogens": "psykogen",
    "psykogent": "psykogen",
    "psykogents": "psykogen",
    "psykokirurgien": "psykokirurgi",
    "psykokirurgiens": "psykokirurgi",
    "psykokirurgin": "psykokirurgi",
    "psykokirurgins": "psykokirurgi",
    "psykokirurgis": "psykokirurgi",
    "psykolingvistiken": "psykolingvistik",
    "psykolingvistikens": "psykolingvistik",
    "psykolingvistiks": "psykolingvistik",
    "psykologen": "psykolog",
    "psykologens": "psykolog",
    "psykologer": "psykolog",
    "psykologerna": "psykolog",
    "psykologernas": "psykolog",
    "psykologers": "psykolog",
    "psykologien": "psykologi",
    "psykologiens": "psykologi",
    "psykologin": "psykologi",
    "psykologins": "psykologi",
    "psykologiprofessorer": "psykologiprofessor",
    "psykologiprofessorerna": "psykologiprofessor",
    "psykologiprofessorernas": "psykologiprofessor",
    "psykologiprofessorers": "psykologiprofessor",
    "psykologiprofessorn": "psykologiprofessor",
    "psykologiprofessorns": "psykologiprofessor",
    "psykologiprofessors": "psykologiprofessor",
    "psykologis": "psykologi",
    "psykologiserad": "psykologisera",
    "psykologiserade": "psykologisera",
    "psykologiserades": "psykologisera",
    "psykologiserads": "psykologisera",
    "psykologiserande": "psykologisera",
    "psykologiseranden": "psykologiserande",
    "psykologiserandena": "psykologiserande",
    "psykologiserandenas": "psykologiserande",
    "psykologiserandens": "psykologiserande",
    "psykologiserandes": "psykologiserande",
    "psykologiserandet": "psykologiserande",
    "psykologiserandets": "psykologiserande",
    "psykologiserar": "psykologisera",
    "psykologiseras": "psykologisera",
    "psykologiserat": "psykologisera",
    "psykologiserats": "psykologisera",
    "psykologiserbara": "psykologiserbar",
    "psykologiserbarare": "psykologiserbar",
    "psykologiserbarares": "psykologiserbar",
    "psykologiserbaras": "psykologiserbar",
    "psykologiserbarast": "psykologiserbar",
    "psykologiserbaraste": "psykologiserbar",
    "psykologiserbarastes": "psykologiserbar",
    "psykologiserbarasts": "psykologiserbar",
    "psykologiserbare": "psykologiserbar",
    "psykologiserbares": "psykologiserbar",
    "psykologiserbarheten": "psykologiserbarhet",
    "psykologiserbarhetens": "psykologiserbarhet",
    "psykologiserbarhets": "psykologiserbarhet",
    "psykologiserbars": "psykologiserbar",
    "psykologiserbart": "psykologiserbar",
    "psykologiserbarts": "psykologiserbar",
    "psykologiseringar": "psykologisering",
    "psykologiseringarna": "psykologisering",
    "psykologiseringarnas": "psykologisering",
    "psykologiseringars": "psykologisering",
    "psykologiseringen": "psykologisering",
    "psykologiseringens": "psykologisering",
    "psykologiserings": "psykologisering",
    "psykologiska": "psykologisk",
    "psykologiskare": "psykologisk",
    "psykologiskares": "psykologisk",
    "psykologiskas": "psykologisk",
    "psykologiskast": "psykologisk",
    "psykologiskaste": "psykologisk",
    "psykologiskastes": "psykologisk",
    "psykologiskasts": "psykologisk",
    "psykologiske": "psykologisk",
    "psykologiskes": "psykologisk",
    "psykologisks": "psykologisk",
    "psykologiskt": "psykologisk",
    "psykologiskts": "psykologisk",
    "psykologs": "psykolog",
    "psykometrien": "psykometri",
    "psykometriens": "psykometri",
    "psykometrin": "psykometri",
    "psykometrins": "psykometri",
    "psykometris": "psykometri",
    "psykopaten": "psykopat",
    "psykopatens": "psykopat",
    "psykopater": "psykopat",
    "psykopaterna": "psykopat",
    "psykopaternas": "psykopat",
    "psykopaters": "psykopat",
    "psykopatien": "psykopati",
    "psykopatiens": "psykopati",
    "psykopatier": "psykopati",
    "psykopatierna": "psykopati",
    "psykopatiernas": "psykopati",
    "psykopatiers": "psykopati",
    "psykopatin": "psykopati",
    "psykopatins": "psykopati",
    "psykopatis": "psykopati",
    "psykopatologien": "psykopatologi",
    "psykopatologiens": "psykopatologi",
    "psykopatologin": "psykopatologi",
    "psykopatologins": "psykopatologi",
    "psykopatologis": "psykopatologi",
    "psykopats": "psykopat",
    "psykoprofylaktiska": "psykoprofylaktisk",
    "psykoprofylaktiskare": "psykoprofylaktisk",
    "psykoprofylaktiskares": "psykoprofylaktisk",
    "psykoprofylaktiskas": "psykoprofylaktisk",
    "psykoprofylaktiskast": "psykoprofylaktisk",
    "psykoprofylaktiskaste": "psykoprofylaktisk",
    "psykoprofylaktiskastes": "psykoprofylaktisk",
    "psykoprofylaktiskasts": "psykoprofylaktisk",
    "psykoprofylaktiske": "psykoprofylaktisk",
    "psykoprofylaktiskes": "psykoprofylaktisk",
    "psykoprofylaktisks": "psykoprofylaktisk",
    "psykoprofylaktiskt": "psykoprofylaktisk",
    "psykoprofylaktiskts": "psykoprofylaktisk",
    "psykoprofylaxen": "psykoprofylax",
    "psykoprofylaxens": "psykoprofylax",
    "psykosen": "psykos",
    "psykosens": "psykos",
    "psykoser": "psykos",
    "psykoserna": "psykos",
    "psykosernas": "psykos",
    "psykosers": "psykos",
    "psykosociala": "psykosocial",
    "psykosocialare": "psykosocial",
    "psykosocialares": "psykosocial",
    "psykosocialas": "psykosocial",
    "psykosocialast": "psykosocial",
    "psykosocialaste": "psykosocial",
    "psykosocialastes": "psykosocial",
    "psykosocialasts": "psykosocial",
    "psykosociale": "psykosocial",
    "psykosociales": "psykosocial",
    "psykosocials": "psykosocial",
    "psykosocialt": "psykosocial",
    "psykosocialts": "psykosocial",
    "psykosomatiska": "psykosomatisk",
    "psykosomatiskare": "psykosomatisk",
    "psykosomatiskares": "psykosomatisk",
    "psykosomatiskas": "psykosomatisk",
    "psykosomatiskast": "psykosomatisk",
    "psykosomatiskaste": "psykosomatisk",
    "psykosomatiskastes": "psykosomatisk",
    "psykosomatiskasts": "psykosomatisk",
    "psykosomatiske": "psykosomatisk",
    "psykosomatiskes": "psykosomatisk",
    "psykosomatisks": "psykosomatisk",
    "psykosomatiskt": "psykosomatisk",
    "psykosomatiskts": "psykosomatisk",
    "psykotekniken": "psykoteknik",
    "psykoteknikens": "psykoteknik",
    "psykotekniks": "psykoteknik",
    "psykoterapeuten": "psykoterapeut",
    "psykoterapeutens": "psykoterapeut",
    "psykoterapeuter": "psykoterapeut",
    "psykoterapeuterna": "psykoterapeut",
    "psykoterapeuternas": "psykoterapeut",
    "psykoterapeuters": "psykoterapeut",
    "psykoterapeuts": "psykoterapeut",
    "psykoterapien": "psykoterapi",
    "psykoterapiens": "psykoterapi",
    "psykoterapier": "psykoterapi",
    "psykoterapierna": "psykoterapi",
    "psykoterapiernas": "psykoterapi",
    "psykoterapiers": "psykoterapi",
    "psykoterapin": "psykoterapi",
    "psykoterapins": "psykoterapi",
    "psykoterapis": "psykoterapi",
    "psykotiska": "psykotisk",
    "psykotiskare": "psykotisk",
    "psykotiskares": "psykotisk",
    "psykotiskas": "psykotisk",
    "psykotiskast": "psykotisk",
    "psykotiskaste": "psykotisk",
    "psykotiskastes": "psykotisk",
    "psykotiskasts": "psykotisk",
    "psykotiske": "psykotisk",
    "psykotiskes": "psykotisk",
    "psykotisks": "psykotisk",
    "psykotiskt": "psykotisk",
    "psykotiskts": "psykotisk",
    "psykrometern": "psykrometer",
    "psykrometerns": "psykrometer",
    "psykrometers": "psykrometer",
    "psykrometrar": "psykrometer",
    "psykrometrarna": "psykrometer",
    "psykrometrarnas": "psykrometer",
    "psykrometrars": "psykrometer",
    "psyks": "psyke",
    "pubar": "pub",
    "pubarna": "pub",
    "pubarnas": "pub",
    "pubars": "pub",
    "pubbeungar": "pubbeunge",
    "pubbeungarna": "pubbeunge",
    "pubbeungarnas": "pubbeunge",
    "pubbeungars": "pubbeunge",
    "pubbeungen": "pubbeunge",
    "pubbeungens": "pubbeunge",
    "pubbeunges": "pubbeunge",
    "puben": "pub",
    "pubens": "pub",
    "pubertala": "pubertal",
    "pubertalare": "pubertal",
    "pubertalares": "pubertal",
    "pubertalas": "pubertal",
    "pubertalast": "pubertal",
    "pubertalaste": "pubertal",
    "pubertalastes": "pubertal",
    "pubertalasts": "pubertal",
    "pubertale": "pubertal",
    "pubertales": "pubertal",
    "pubertals": "pubertal",
    "pubertalt": "pubertal",
    "pubertalts": "pubertal",
    "puberteten": "pubertet",
    "pubertetens": "pubertet",
    "puberteter": "pubertet",
    "puberteterna": "pubertet",
    "puberteternas": "pubertet",
    "puberteters": "pubertet",
    "pubertets": "pubertet",
    "pubertetsflick": "pubertetsflicka",
    "pubertetsflickan": "pubertetsflicka",
    "pubertetsflickans": "pubertetsflicka",
    "pubertetsflickas": "pubertetsflicka",
    "pubertetsflicke": "pubertetsflicka",
    "pubertetsflickor": "pubertetsflicka",
    "pubertetsflickorna": "pubertetsflicka",
    "pubertetsflickornas": "pubertetsflicka",
    "pubertetsflickors": "pubertetsflicka",
    "pubertetsflicks": "pubertetsflicka",
    "pubeshåren": "pubeshår",
    "pubeshårens": "pubeshår",
    "pubeshåret": "pubeshår",
    "pubeshårets": "pubeshår",
    "pubeshårs": "pubeshår",
    "pubesringar": "pubesring",
    "pubesringarna": "pubesring",
    "pubesringarnas": "pubesring",
    "pubesringars": "pubesring",
    "pubesringen": "pubesring",
    "pubesringens": "pubesring",
    "pubesrings": "pubesring",
    "pubisringar": "pubisring",
    "pubisringarna": "pubisring",
    "pubisringarnas": "pubisring",
    "pubisringars": "pubisring",
    "pubisringen": "pubisring",
    "pubisringens": "pubisring",
    "pubisrings": "pubisring",
    "publicerad": "publicera",
    "publicerade": "publicera",
    "publicerades": "publicera",
    "publicerads": "publicera",
    "publicerande": "publicera",
    "publiceranden": "publicerande",
    "publicerandena": "publicerande",
    "publicerandenas": "publicerande",
    "publicerandens": "publicerande",
    "publicerandes": "publicerande",
    "publicerandet": "publicerande",
    "publicerandets": "publicerande",
    "publicerar": "publicera",
    "publiceras": "publicera",
    "publicerat": "publicera",
    "publicerats": "publicera",
    "publicerbara": "publicerbar",
    "publicerbarare": "publicerbar",
    "publicerbarares": "publicerbar",
    "publicerbaras": "publicerbar",
    "publicerbarast": "publicerbar",
    "publicerbaraste": "publicerbar",
    "publicerbarastes": "publicerbar",
    "publicerbarasts": "publicerbar",
    "publicerbare": "publicerbar",
    "publicerbares": "publicerbar",
    "publicerbarheten": "publicerbarhet",
    "publicerbarhetens": "publicerbarhet",
    "publicerbarhets": "publicerbarhet",
    "publicerbars": "publicerbar",
    "publicerbart": "publicerbar",
    "publicerbarts": "publicerbar",
    "publiceringar": "publicering",
    "publiceringarna": "publicering",
    "publiceringarnas": "publicering",
    "publiceringars": "publicering",
    "publiceringen": "publicering",
    "publiceringens": "publicering",
    "publicerings": "publicering",
    "publiceringsbesluten": "publiceringsbeslut",
    "publiceringsbeslutens": "publiceringsbeslut",
    "publiceringsbeslutet": "publiceringsbeslut",
    "publiceringsbeslutets": "publiceringsbeslut",
    "publiceringsbesluts": "publiceringsbeslut",
    "publicisten": "publicist",
    "publicistens": "publicist",
    "publicister": "publicist",
    "publicisterna": "publicist",
    "publicisternas": "publicist",
    "publicisters": "publicist",
    "publicistiken": "publicistik",
    "publicistikens": "publicistik",
    "publicistiks": "publicistik",
    "publicistiska": "publicistisk",
    "publicistiskare": "publicistisk",
    "publicistiskares": "publicistisk",
    "publicistiskas": "publicistisk",
    "publicistiskast": "publicistisk",
    "publicistiskaste": "publicistisk",
    "publicistiskastes": "publicistisk",
    "publicistiskasts": "publicistisk",
    "publicistiske": "publicistisk",
    "publicistiskes": "publicistisk",
    "publicistisks": "publicistisk",
    "publicistiskt": "publicistisk",
    "publicistiskts": "publicistisk",
    "publicists": "publicist",
    "publiciteten": "publicitet",
    "publicitetens": "publicitet",
    "publiciteter": "publicitet",
    "publiciteterna": "publicitet",
    "publiciteternas": "publicitet",
    "publiciteters": "publicitet",
    "publicitets": "publicitet",
    "publika": "publik",
    "publikanen": "publikan",
    "publikanens": "publikan",
    "publikaner": "publikan",
    "publikanerna": "publikan",
    "publikanernas": "publikan",
    "publikaners": "publikan",
    "publikans": "publikan",
    "publikare": "publik",
    "publikares": "publik",
    "publikas": "publik",
    "publikast": "publik",
    "publikaste": "publik",
    "publikastes": "publik",
    "publikasts": "publik",
    "publikationen": "publikation",
    "publikationens": "publikation",
    "publikationer": "publikation",
    "publikationerna": "publikation",
    "publikationernas": "publikation",
    "publikationers": "publikation",
    "publikations": "publikation",
    "publike": "publik",
    "publiken": "publik",
    "publikens": "publik",
    "publiker": "publik",
    "publikerna": "publik",
    "publikernas": "publik",
    "publikers": "publik",
    "publikes": "publik",
    "publikmässiga": "publikmässig",
    "publikmässigare": "publikmässig",
    "publikmässigares": "publikmässig",
    "publikmässigas": "publikmässig",
    "publikmässigast": "publikmässig",
    "publikmässigaste": "publikmässig",
    "publikmässigastes": "publikmässig",
    "publikmässigasts": "publikmässig",
    "publikmässige": "publikmässig",
    "publikmässiges": "publikmässig",
    "publikmässigs": "publikmässig",
    "publikmässigt": "publikmässig",
    "publikmässigts": "publikmässig",
    "publiks": "publik",
    "publikt": "publik",
    "publikts": "publik",
    "publikums": "publikum",
    "pubs": "pub",
    "puckade": "puckad",
    "puckades": "puckad",
    "puckadheten": "puckadhet",
    "puckadhetens": "puckadhet",
    "puckadheter": "puckadhet",
    "puckadheterna": "puckadhet",
    "puckadheternas": "puckadhet",
    "puckadheters": "puckadhet",
    "puckadhets": "puckadhet",
    "puckads": "puckad",
    "puckar": "puckare",
    "puckaren": "puckare",
    "puckarens": "puckare",
    "puckares": "puckare",
    "puckarna": "puckare",
    "puckarnas": "puckare",
    "puckars": "puck",
    "puckat": "puckad",
    "puckats": "puckad",
    "puckeln": "puckel",
    "puckelns": "puckel",
    "puckelox": "puckeloxe",
    "puckeloxar": "puckeloxe",
    "puckeloxarna": "puckeloxe",
    "puckeloxarnas": "puckeloxe",
    "puckeloxars": "puckeloxe",
    "puckeloxen": "puckeloxe",
    "puckeloxens": "puckeloxe",
    "puckeloxes": "puckeloxe",
    "puckelpisten": "puckelpist",
    "puckelpistens": "puckelpist",
    "puckelpister": "puckelpist",
    "puckelpisterna": "puckelpist",
    "puckelpisternas": "puckelpist",
    "puckelpisters": "puckelpist",
    "puckelpists": "puckelpist",
    "puckelryggar": "puckelrygg",
    "puckelryggarna": "puckelrygg",
    "puckelryggarnas": "puckelrygg",
    "puckelryggars": "puckelrygg",
    "puckelryggen": "puckelrygg",
    "puckelryggens": "puckelrygg",
    "puckelryggiga": "puckelryggig",
    "puckelryggigare": "puckelryggig",
    "puckelryggigares": "puckelryggig",
    "puckelryggigas": "puckelryggig",
    "puckelryggigast": "puckelryggig",
    "puckelryggigaste": "puckelryggig",
    "puckelryggigastes": "puckelryggig",
    "puckelryggigasts": "puckelryggig",
    "puckelryggige": "puckelryggig",
    "puckelryggiges": "puckelryggig",
    "puckelryggigheten": "puckelryggighet",
    "puckelryggighetens": "puckelryggighet",
    "puckelryggighets": "puckelryggighet",
    "puckelryggigs": "puckelryggig",
    "puckelryggigt": "puckelryggig",
    "puckelryggigts": "puckelryggig",
    "puckelryggs": "puckelrygg",
    "puckels": "puckel",
    "pucken": "puck",
    "puckens": "puck",
    "pucklar": "puckel",
    "pucklarna": "puckel",
    "pucklarnas": "puckel",
    "pucklars": "puckel",
    "pucklet": "puckel",
    "pucklets": "puckel",
    "puckliga": "pucklig",
    "puckligare": "pucklig",
    "puckligares": "pucklig",
    "puckligas": "pucklig",
    "puckligast": "pucklig",
    "puckligaste": "pucklig",
    "puckligastes": "pucklig",
    "puckligasts": "pucklig",
    "pucklige": "pucklig",
    "puckliges": "pucklig",
    "puckligheten": "pucklighet",
    "pucklighetens": "pucklighet",
    "pucklighets": "pucklighet",
    "puckligs": "pucklig",
    "puckligt": "pucklig",
    "puckligts": "pucklig",
    "puckon": "pucko",
    "puckona": "pucko",
    "puckonas": "pucko",
    "puckons": "pucko",
    "puckos": "pucko",
    "puckot": "pucko",
    "puckots": "pucko",
    "pucks": "puck",
    "puddel": "puddla",
    "puddingar": "pudding",
    "puddingarna": "pudding",
    "puddingarnas": "pudding",
    "puddingars": "pudding",
    "puddingen": "pudding",
    "puddingens": "pudding",
    "puddings": "pudding",
    "puddlad": "puddla",
    "puddlade": "puddla",
    "puddlades": "puddla",
    "puddlads": "puddla",
    "puddlande": "puddla",
    "puddlanden": "puddlande",
    "puddlandena": "puddlande",
    "puddlandenas": "puddlande",
    "puddlandens": "puddlande",
    "puddlandes": "puddlande",
    "puddlandet": "puddlande",
    "puddlandets": "puddlande",
    "puddlar": "puddla",
    "puddlas": "puddla",
    "puddlat": "puddla",
    "puddlats": "puddla",
    "pudeln": "pudel",
    "pudelns": "pudel",
    "pudels": "pudel",
    "puderkrämen": "puderkräm",
    "puderkrämens": "puderkräm",
    "puderkrämer": "puderkräm",
    "puderkrämerna": "puderkräm",
    "puderkrämernas": "puderkräm",
    "puderkrämers": "puderkräm",
    "puderkräms": "puderkräm",
    "puders": "puder",
    "pudersnön": "pudersnö",
    "pudersnöns": "pudersnö",
    "pudersnös": "pudersnö",
    "pudersockers": "pudersocker",
    "pudersockret": "pudersocker",
    "pudersockrets": "pudersocker",
    "puderunderlagen": "puderunderlag",
    "puderunderlagens": "puderunderlag",
    "puderunderlaget": "puderunderlag",
    "puderunderlagets": "puderunderlag",
    "puderunderlags": "puderunderlag",
    "pudervipp": "pudervippa",
    "pudervippan": "pudervippa",
    "pudervippans": "pudervippa",
    "pudervippas": "pudervippa",
    "pudervippe": "pudervippa",
    "pudervippor": "pudervippa",
    "pudervipporna": "pudervippa",
    "pudervippornas": "pudervippa",
    "pudervippors": "pudervippa",
    "pudervipps": "pudervippa",
    "pudl": "pudla",
    "pudlade": "pudla",
    "pudlades": "pudla",
    "pudlande": "pudla",
    "pudlanden": "pudlande",
    "pudlandena": "pudlande",
    "pudlandenas": "pudlande",
    "pudlandens": "pudlande",
    "pudlandes": "pudlande",
    "pudlandet": "pudlande",
    "pudlandets": "pudlande",
    "pudlar": "pudla",
    "pudlarna": "pudel",
    "pudlarnas": "pudel",
    "pudlars": "pudel",
    "pudlas": "pudla",
    "pudlat": "pudla",
    "pudlats": "pudla",
    "pudrad": "pudra",
    "pudrade": "pudra",
    "pudrades": "pudra",
    "pudrads": "pudra",
    "pudrande": "pudra",
    "pudranden": "pudrande",
    "pudrandena": "pudrande",
    "pudrandenas": "pudrande",
    "pudrandens": "pudrande",
    "pudrandes": "pudrande",
    "pudrandet": "pudrande",
    "pudrandets": "pudrande",
    "pudrar": "pudra",
    "pudras": "pudra",
    "pudrat": "pudra",
    "pudrats": "pudra",
    "pudret": "puder",
    "pudrets": "puder",
    "pudretten": "pudrett",
    "pudrettens": "pudrett",
    "pudretts": "pudrett",
    "pudriga": "pudrig",
    "pudrigare": "pudrig",
    "pudrigares": "pudrig",
    "pudrigas": "pudrig",
    "pudrigast": "pudrig",
    "pudrigaste": "pudrig",
    "pudrigastes": "pudrig",
    "pudrigasts": "pudrig",
    "pudrige": "pudrig",
    "pudriges": "pudrig",
    "pudrigheten": "pudrighet",
    "pudrighetens": "pudrighet",
    "pudrighets": "pudrighet",
    "pudrigs": "pudrig",
    "pudrigt": "pudrig",
    "pudrigts": "pudrig",
    "puerila": "pueril",
    "puerilare": "pueril",
    "puerilares": "pueril",
    "puerilas": "pueril",
    "puerilast": "pueril",
    "puerilaste": "pueril",
    "puerilastes": "pueril",
    "puerilasts": "pueril",
    "puerile": "pueril",
    "pueriles": "pueril",
    "pueriliteten": "puerilitet",
    "puerilitetens": "puerilitet",
    "pueriliteter": "puerilitet",
    "pueriliteterna": "puerilitet",
    "pueriliteternas": "puerilitet",
    "pueriliteters": "puerilitet",
    "puerilitets": "puerilitet",
    "puerils": "pueril",
    "puerilt": "pueril",
    "puerilts": "pueril",
    "puffad": "puffa",
    "puffade": "puffa",
    "puffades": "puffa",
    "puffads": "puffa",
    "puffande": "puffa",
    "puffanden": "puffande",
    "puffandena": "puffande",
    "puffandenas": "puffande",
    "puffandens": "puffande",
    "puffandes": "puffande",
    "puffandet": "puffande",
    "puffandets": "puffande",
    "puffar": "puffa",
    "puffarna": "puff",
    "puffarnas": "puff",
    "puffars": "puff",
    "puffas": "puffa",
    "puffat": "puffa",
    "puffats": "puffa",
    "puffen": "puff",
    "puffens": "puff",
    "puffertar": "puffert",
    "puffertarna": "puffert",
    "puffertarnas": "puffert",
    "puffertars": "puffert",
    "pufferten": "puffert",
    "puffertens": "puffert",
    "pufferts": "puffert",
    "puffran": "puffra",
    "puffrans": "puffra",
    "puffras": "puffra",
    "puffror": "puffra",
    "puffrorna": "puffra",
    "puffrornas": "puffra",
    "puffrors": "puffra",
    "puffs": "puff",
    "puffärmar": "puffärm",
    "puffärmarna": "puffärm",
    "puffärmarnas": "puffärm",
    "puffärmars": "puffärm",
    "puffärmen": "puffärm",
    "puffärmens": "puffärm",
    "puffärms": "puffärm",
    "pugilismen": "pugilism",
    "pugilismens": "pugilism",
    "pugilismer": "pugilism",
    "pugilismerna": "pugilism",
    "pugilismernas": "pugilism",
    "pugilismers": "pugilism",
    "pugilisms": "pugilism",
    "pugilisten": "pugilist",
    "pugilistens": "pugilist",
    "pugilister": "pugilist",
    "pugilisterna": "pugilist",
    "pugilisternas": "pugilist",
    "pugilisters": "pugilist",
    "pugilistiken": "pugilistik",
    "pugilistikens": "pugilistik",
    "pugilistiks": "pugilistik",
    "pugilistiska": "pugilistisk",
    "pugilistiskas": "pugilistisk",
    "pugilistiske": "pugilistisk",
    "pugilistiskes": "pugilistisk",
    "pugilistisks": "pugilistisk",
    "pugilistiskt": "pugilistisk",
    "pugilistiskts": "pugilistisk",
    "pugilists": "pugilist",
    "puk": "puke",
    "pukan": "puka",
    "pukans": "puka",
    "pukar": "puke",
    "pukarna": "puke",
    "pukarnas": "puke",
    "pukars": "puke",
    "pukas": "puka",
    "puke": "puka",
    "puken": "puke",
    "pukens": "puke",
    "pukes": "puke",
    "pukor": "puka",
    "pukorna": "puka",
    "pukornas": "puka",
    "pukors": "puka",
    "puks": "puke",
    "pukslagen": "pukslag",
    "pukslagens": "pukslag",
    "pukslaget": "pukslag",
    "pukslagets": "pukslag",
    "pukslags": "pukslag",
    "pul": "pula",
    "pulade": "pula",
    "pulades": "pula",
    "pulande": "pula",
    "pulanden": "pulande",
    "pulandena": "pulande",
    "pulandenas": "pulande",
    "pulandens": "pulande",
    "pulandes": "pulande",
    "pulandet": "pulande",
    "pulandets": "pulande",
    "pular": "pula",
    "pulas": "pula",
    "pulat": "pula",
    "pulats": "pula",
    "pulk": "pulka",
    "pulkaback": "pulkabacke",
    "pulkabackar": "pulkabacke",
    "pulkabackarna": "pulkabacke",
    "pulkabackarnas": "pulkabacke",
    "pulkabackars": "pulkabacke",
    "pulkabacken": "pulkabacke",
    "pulkabackens": "pulkabacke",
    "pulkabackes": "pulkabacke",
    "pulkabacks": "pulkabacke",
    "pulkan": "pulka",
    "pulkans": "pulka",
    "pulkas": "pulka",
    "pulke": "pulka",
    "pulkor": "pulka",
    "pulkorna": "pulka",
    "pulkornas": "pulka",
    "pulkors": "pulka",
    "pulks": "pulka",
    "pulkåkningen": "pulkåkning",
    "pulkåkningens": "pulkåkning",
    "pulkåknings": "pulkåkning",
    "pull": "pulla",
    "pullade": "pulla",
    "pullades": "pulla",
    "pullan": "pulla",
    "pullande": "pulla",
    "pullanden": "pullande",
    "pullandena": "pullande",
    "pullandenas": "pullande",
    "pullandens": "pullande",
    "pullandes": "pullande",
    "pullandet": "pullande",
    "pullandets": "pullande",
    "pullans": "pulla",
    "pullar": "pulla",
    "pullas": "pulla",
    "pullat": "pulla",
    "pullats": "pulla",
    "pulle": "pulla",
    "pullmanvagnar": "pullmanvagn",
    "pullmanvagnarna": "pullmanvagn",
    "pullmanvagnarnas": "pullmanvagn",
    "pullmanvagnars": "pullmanvagn",
    "pullmanvagnen": "pullmanvagn",
    "pullmanvagnens": "pullmanvagn",
    "pullmanvagns": "pullmanvagn",
    "pullor": "pulla",
    "pullorna": "pulla",
    "pullornas": "pulla",
    "pullors": "pulla",
    "pullovern": "pullover",
    "pulloverns": "pullover",
    "pullovers": "pullover",
    "pullovrar": "pullover",
    "pullovrarna": "pullover",
    "pullovrarnas": "pullover",
    "pullovrars": "pullover",
    "pulls": "pulla",
    "pulp": "pulpa",
    "pulpan": "pulpa",
    "pulpans": "pulpa",
    "pulpas": "pulpa",
    "pulpe": "pulpa",
    "pulpeten": "pulpet",
    "pulpetens": "pulpet",
    "pulpeter": "pulpet",
    "pulpeterna": "pulpet",
    "pulpeternas": "pulpet",
    "pulpeters": "pulpet",
    "pulpets": "pulpet",
    "pulpettaken": "pulpettak",
    "pulpettakens": "pulpettak",
    "pulpettaket": "pulpettak",
    "pulpettakets": "pulpettak",
    "pulpettaks": "pulpettak",
    "pulpitar": "pulpit",
    "pulpitarna": "pulpit",
    "pulpitarnas": "pulpit",
    "pulpitars": "pulpit",
    "pulpiten": "pulpit",
    "pulpitens": "pulpit",
    "pulpits": "pulpit",
    "pulpor": "pulpa",
    "pulporna": "pulpa",
    "pulpornas": "pulpa",
    "pulpors": "pulpa",
    "pulps": "pulpa",
    "pulsade": "pulsa",
    "pulsades": "pulsa",
    "pulsande": "pulsa",
    "pulsanden": "pulsande",
    "pulsandena": "pulsande",
    "pulsandenas": "pulsande",
    "pulsandens": "pulsande",
    "pulsandes": "pulsande",
    "pulsandet": "pulsande",
    "pulsandets": "pulsande",
    "pulsar": "pulsa",
    "pulsaren": "pulsar",
    "pulsarens": "pulsar",
    "pulsarer": "pulsar",
    "pulsarerna": "pulsar",
    "pulsarernas": "pulsar",
    "pulsarers": "pulsar",
    "pulsarna": "puls",
    "pulsarnas": "puls",
    "pulsars": "pulsar",
    "pulsas": "pulsa",
    "pulsat": "pulsa",
    "pulsats": "pulsa",
    "pulsen": "puls",
    "pulsens": "puls",
    "pulser": "puls",
    "pulserade": "pulsera",
    "pulserades": "pulsera",
    "pulserande": "pulsera",
    "pulseranden": "pulserande",
    "pulserandena": "pulserande",
    "pulserandenas": "pulserande",
    "pulserandens": "pulserande",
    "pulserandes": "pulserande",
    "pulserandet": "pulserande",
    "pulserandets": "pulserande",
    "pulserar": "pulsera",
    "pulseras": "pulsera",
    "pulserat": "pulsera",
    "pulserats": "pulsera",
    "pulseringar": "pulsering",
    "pulseringarna": "pulsering",
    "pulseringarnas": "pulsering",
    "pulseringars": "pulsering",
    "pulseringen": "pulsering",
    "pulseringens": "pulsering",
    "pulserings": "pulsering",
    "pulserna": "puls",
    "pulsernas": "puls",
    "pulsers": "puls",
    "pulsklock": "pulsklocka",
    "pulsklockan": "pulsklocka",
    "pulsklockans": "pulsklocka",
    "pulsklockas": "pulsklocka",
    "pulsklocke": "pulsklocka",
    "pulsklockor": "pulsklocka",
    "pulsklockorna": "pulsklocka",
    "pulsklockornas": "pulsklocka",
    "pulsklockors": "pulsklocka",
    "pulsklocks": "pulsklocka",
    "pulsslagen": "pulsslag",
    "pulsslagens": "pulsslag",
    "pulsslaget": "pulsslag",
    "pulsslagets": "pulsslag",
    "pulsslags": "pulsslag",
    "pulstagningar": "pulstagning",
    "pulstagningarna": "pulstagning",
    "pulstagningarnas": "pulstagning",
    "pulstagningars": "pulstagning",
    "pulstagningen": "pulstagning",
    "pulstagningens": "pulstagning",
    "pulstagnings": "pulstagning",
    "pulstågen": "pulståg",
    "pulstågens": "pulståg",
    "pulståget": "pulståg",
    "pulstågets": "pulståg",
    "pulstågs": "pulståg",
    "pulsvalet": "pulsval",
    "pulsvalets": "pulsval",
    "pulsvals": "pulsval",
    "pulsådern": "pulsåder",
    "pulsåderns": "pulsåder",
    "pulsåders": "pulsåder",
    "pulsådra": "pulsåder",
    "pulsådran": "pulsåder",
    "pulsådrans": "pulsåder",
    "pulsådras": "pulsåder",
    "pulsådre": "pulsåder",
    "pulsådror": "pulsåder",
    "pulsådrorna": "pulsåder",
    "pulsådrornas": "pulsåder",
    "pulsådrors": "pulsåder",
    "pulten": "pult",
    "pultens": "pult",
    "pulter": "pult",
    "pulterna": "pult",
    "pulternas": "pult",
    "pulters": "pult",
    "pultronen": "pultron",
    "pultronens": "pultron",
    "pultroner": "pultron",
    "pultronerna": "pultron",
    "pultronernas": "pultron",
    "pultroners": "pultron",
    "pultrons": "pultron",
    "pults": "pult",
    "pulveriserad": "pulverisera",
    "pulveriserade": "pulverisera",
    "pulveriserades": "pulverisera",
    "pulveriserads": "pulverisera",
    "pulveriserande": "pulverisera",
    "pulveriseranden": "pulveriserande",
    "pulveriserandena": "pulveriserande",
    "pulveriserandenas": "pulveriserande",
    "pulveriserandens": "pulveriserande",
    "pulveriserandes": "pulveriserande",
    "pulveriserandet": "pulveriserande",
    "pulveriserandets": "pulveriserande",
    "pulveriserar": "pulverisera",
    "pulveriseras": "pulverisera",
    "pulveriserat": "pulverisera",
    "pulveriserats": "pulverisera",
    "pulveriserbara": "pulveriserbar",
    "pulveriserbarare": "pulveriserbar",
    "pulveriserbarares": "pulveriserbar",
    "pulveriserbaras": "pulveriserbar",
    "pulveriserbarast": "pulveriserbar",
    "pulveriserbaraste": "pulveriserbar",
    "pulveriserbarastes": "pulveriserbar",
    "pulveriserbarasts": "pulveriserbar",
    "pulveriserbare": "pulveriserbar",
    "pulveriserbares": "pulveriserbar",
    "pulveriserbarheten": "pulveriserbarhet",
    "pulveriserbarhetens": "pulveriserbarhet",
    "pulveriserbarhets": "pulveriserbarhet",
    "pulveriserbars": "pulveriserbar",
    "pulveriserbart": "pulveriserbar",
    "pulveriserbarts": "pulveriserbar",
    "pulveriseringar": "pulverisering",
    "pulveriseringarna": "pulverisering",
    "pulveriseringarnas": "pulverisering",
    "pulveriseringars": "pulverisering",
    "pulveriseringen": "pulverisering",
    "pulveriseringens": "pulverisering",
    "pulveriserings": "pulverisering",
    "pulverkaffes": "pulverkaffe",
    "pulverkaffet": "pulverkaffe",
    "pulverkaffets": "pulverkaffe",
    "pulverlacken": "pulverlack",
    "pulverlackens": "pulverlack",
    "pulverlacker": "pulverlack",
    "pulverlackerad": "pulverlackera",
    "pulverlackerade": "pulverlackera",
    "pulverlackerades": "pulverlackera",
    "pulverlackerads": "pulverlackera",
    "pulverlackerande": "pulverlackera",
    "pulverlackeranden": "pulverlackerande",
    "pulverlackerandena": "pulverlackerande",
    "pulverlackerandenas": "pulverlackerande",
    "pulverlackerandens": "pulverlackerande",
    "pulverlackerandes": "pulverlackerande",
    "pulverlackerandet": "pulverlackerande",
    "pulverlackerandets": "pulverlackerande",
    "pulverlackerar": "pulverlackera",
    "pulverlackeras": "pulverlackera",
    "pulverlackerat": "pulverlackera",
    "pulverlackerats": "pulverlackera",
    "pulverlackerbara": "pulverlackerbar",
    "pulverlackerbarare": "pulverlackerbar",
    "pulverlackerbarares": "pulverlackerbar",
    "pulverlackerbaras": "pulverlackerbar",
    "pulverlackerbarast": "pulverlackerbar",
    "pulverlackerbaraste": "pulverlackerbar",
    "pulverlackerbarastes": "pulverlackerbar",
    "pulverlackerbarasts": "pulverlackerbar",
    "pulverlackerbare": "pulverlackerbar",
    "pulverlackerbares": "pulverlackerbar",
    "pulverlackerbarheten": "pulverlackerbarhet",
    "pulverlackerbarhetens": "pulverlackerbarhet",
    "pulverlackerbarhets": "pulverlackerbarhet",
    "pulverlackerbars": "pulverlackerbar",
    "pulverlackerbart": "pulverlackerbar",
    "pulverlackerbarts": "pulverlackerbar",
    "pulverlackerna": "pulverlack",
    "pulverlackernas": "pulverlack",
    "pulverlackers": "pulverlack",
    "pulverlacket": "pulverlack",
    "pulverlackets": "pulverlack",
    "pulverlacks": "pulverlack",
    "pulvermetallurgien": "pulvermetallurgi",
    "pulvermetallurgiens": "pulvermetallurgi",
    "pulvermetallurgin": "pulvermetallurgi",
    "pulvermetallurgins": "pulvermetallurgi",
    "pulvermetallurgis": "pulvermetallurgi",
    "pulverna": "pulver",
    "pulvernas": "pulver",
    "pulvers": "pulver",
    "pulversläckar": "pulversläckare",
    "pulversläckaren": "pulversläckare",
    "pulversläckarens": "pulversläckare",
    "pulversläckares": "pulversläckare",
    "pulversläckarna": "pulversläckare",
    "pulversläckarnas": "pulversläckare",
    "pulvren": "pulver",
    "pulvrens": "pulver",
    "pulvret": "pulver",
    "pulvrets": "pulver",
    "pulvriserad": "pulvrisera",
    "pulvriserade": "pulvrisera",
    "pulvriserades": "pulvrisera",
    "pulvriserads": "pulvrisera",
    "pulvriserande": "pulvrisera",
    "pulvriseranden": "pulvriserande",
    "pulvriserandena": "pulvriserande",
    "pulvriserandenas": "pulvriserande",
    "pulvriserandens": "pulvriserande",
    "pulvriserandes": "pulvriserande",
    "pulvriserandet": "pulvriserande",
    "pulvriserandets": "pulvriserande",
    "pulvriserar": "pulvrisera",
    "pulvriseras": "pulvrisera",
    "pulvriserat": "pulvrisera",
    "pulvriserats": "pulvrisera",
    "pulvriserbara": "pulvriserbar",
    "pulvriserbarare": "pulvriserbar",
    "pulvriserbarares": "pulvriserbar",
    "pulvriserbaras": "pulvriserbar",
    "pulvriserbarast": "pulvriserbar",
    "pulvriserbaraste": "pulvriserbar",
    "pulvriserbarastes": "pulvriserbar",
    "pulvriserbarasts": "pulvriserbar",
    "pulvriserbare": "pulvriserbar",
    "pulvriserbares": "pulvriserbar",
    "pulvriserbarheten": "pulvriserbarhet",
    "pulvriserbarhetens": "pulvriserbarhet",
    "pulvriserbarhets": "pulvriserbarhet",
    "pulvriserbars": "pulvriserbar",
    "pulvriserbart": "pulvriserbar",
    "pulvriserbarts": "pulvriserbar",
    "pulvriseringar": "pulvrisering",
    "pulvriseringarna": "pulvrisering",
    "pulvriseringarnas": "pulvrisering",
    "pulvriseringars": "pulvrisering",
    "pulvriseringen": "pulvrisering",
    "pulvriseringens": "pulvrisering",
    "pulvriserings": "pulvrisering",
    "puman": "puma",
    "pumans": "puma",
    "pumas": "puma",
    "pumor": "puma",
    "pumorna": "puma",
    "pumornas": "puma",
    "pumors": "puma",
    "pump": "pumpa",
    "pumpad": "pumpa",
    "pumpade": "pumpa",
    "pumpades": "pumpa",
    "pumpads": "pumpa",
    "pumpan": "pumpa",
    "pumpande": "pumpa",
    "pumpanden": "pumpande",
    "pumpandena": "pumpande",
    "pumpandenas": "pumpande",
    "pumpandens": "pumpande",
    "pumpandes": "pumpande",
    "pumpandet": "pumpande",
    "pumpandets": "pumpande",
    "pumpans": "pumpa",
    "pumpar": "pumpa",
    "pumparna": "pump",
    "pumparnas": "pump",
    "pumpars": "pump",
    "pumpas": "pumpa",
    "pumpat": "pumpa",
    "pumpats": "pumpa",
    "pumpe": "pumpa",
    "pumpen": "pump",
    "pumpens": "pump",
    "pumpernickeln": "pumpernickel",
    "pumpernickelns": "pumpernickel",
    "pumpernickels": "pumpernickel",
    "pumpernicklar": "pumpernickel",
    "pumpernicklarna": "pumpernickel",
    "pumpernicklarnas": "pumpernickel",
    "pumpernicklars": "pumpernickel",
    "pumpkolvar": "pumpkolv",
    "pumpkolvarna": "pumpkolv",
    "pumpkolvarnas": "pumpkolv",
    "pumpkolvars": "pumpkolv",
    "pumpkolven": "pumpkolv",
    "pumpkolvens": "pumpkolv",
    "pumpkolvs": "pumpkolv",
    "pumpor": "pumpa",
    "pumporna": "pumpa",
    "pumpornas": "pumpa",
    "pumpors": "pumpa",
    "pumps": "pumpa",
    "pumpsatsen": "pumpsats",
    "pumpsatsens": "pumpsats",
    "pumpsatser": "pumpsats",
    "pumpsatserna": "pumpsats",
    "pumpsatsernas": "pumpsats",
    "pumpsatsers": "pumpsats",
    "pumpsen": "pumps",
    "pumpsens": "pumps",
    "pumpstöveln": "pumpstövel",
    "pumpstövelns": "pumpstövel",
    "pumpstövels": "pumpstövel",
    "pumpstövlar": "pumpstövel",
    "pumpstövlarna": "pumpstövel",
    "pumpstövlarnas": "pumpstövel",
    "pumpstövlars": "pumpstövel",
    "punchar": "punch",
    "puncharna": "punch",
    "puncharnas": "punch",
    "punchars": "punch",
    "punchen": "punch",
    "punchens": "punch",
    "punchs": "punch",
    "pundar": "pundare",
    "pundaren": "pundare",
    "pundarens": "pundare",
    "pundares": "pundare",
    "pundarna": "pundare",
    "pundarnas": "pundare",
    "punden": "pund",
    "pundens": "pund",
    "pundet": "pund",
    "pundets": "pund",
    "pundhuvuden": "pundhuvud",
    "pundhuvudena": "pundhuvud",
    "pundhuvudenas": "pundhuvud",
    "pundhuvudens": "pundhuvud",
    "pundhuvudet": "pundhuvud",
    "pundhuvudets": "pundhuvud",
    "pundhuvuds": "pundhuvud",
    "pundiga": "pundig",
    "pundigare": "pundig",
    "pundigares": "pundig",
    "pundigas": "pundig",
    "pundigast": "pundig",
    "pundigaste": "pundig",
    "pundigastes": "pundig",
    "pundigasts": "pundig",
    "pundige": "pundig",
    "pundiges": "pundig",
    "pundigheten": "pundighet",
    "pundighetens": "pundighet",
    "pundighets": "pundighet",
    "pundigs": "pundig",
    "pundigt": "pundig",
    "pundigts": "pundig",
    "pundkrisen": "pundkris",
    "pundkrisens": "pundkris",
    "pundkriser": "pundkris",
    "pundkriserna": "pundkris",
    "pundkrisernas": "pundkris",
    "pundkrisers": "pundkris",
    "punds": "pund",
    "pungar": "pung",
    "pungarna": "pung",
    "pungarnas": "pung",
    "pungars": "pung",
    "pungbjörnar": "pungbjörn",
    "pungbjörnarna": "pungbjörn",
    "pungbjörnarnas": "pungbjörn",
    "pungbjörnars": "pungbjörn",
    "pungbjörnen": "pungbjörn",
    "pungbjörnens": "pungbjörn",
    "pungbjörns": "pungbjörn",
    "pungdjuren": "pungdjur",
    "pungdjurens": "pungdjur",
    "pungdjuret": "pungdjur",
    "pungdjurets": "pungdjur",
    "pungdjurs": "pungdjur",
    "pungdjävulen": "pungdjävul",
    "pungdjävulens": "pungdjävul",
    "pungdjävuls": "pungdjävul",
    "pungen": "pung",
    "pungens": "pung",
    "punggrävlingar": "punggrävling",
    "punggrävlingarna": "punggrävling",
    "punggrävlingarnas": "punggrävling",
    "punggrävlingars": "punggrävling",
    "punggrävlingen": "punggrävling",
    "punggrävlingens": "punggrävling",
    "punggrävlings": "punggrävling",
    "punghållandes": "punghållande",
    "punghållandet": "punghållande",
    "punghållandets": "punghållande",
    "pungrått": "pungråtta",
    "pungråttan": "pungråtta",
    "pungråttans": "pungråtta",
    "pungråttas": "pungråtta",
    "pungråtte": "pungråtta",
    "pungråttor": "pungråtta",
    "pungråttorna": "pungråtta",
    "pungråttornas": "pungråtta",
    "pungråttors": "pungråtta",
    "pungråtts": "pungråtta",
    "pungs": "pung",
    "pungslagen": "pungslå",
    "pungslagens": "pungslå",
    "pungslaget": "pungslå",
    "pungslagets": "pungslå",
    "pungslagit": "pungslå",
    "pungslagits": "pungslå",
    "pungslagna": "pungslå",
    "pungslagnas": "pungslå",
    "pungslagne": "pungslå",
    "pungslagnes": "pungslå",
    "pungslog": "pungslå",
    "pungsloge": "pungslå",
    "pungsloges": "pungslå",
    "pungslogs": "pungslå",
    "pungslående": "pungslå",
    "pungslåenden": "pungslående",
    "pungslåendena": "pungslående",
    "pungslåendenas": "pungslående",
    "pungslåendens": "pungslående",
    "pungslåendes": "pungslående",
    "pungslåendet": "pungslående",
    "pungslåendets": "pungslående",
    "pungslår": "pungslå",
    "pungslås": "pungslå",
    "pungstenar": "pungsten",
    "pungstenarna": "pungsten",
    "pungstenarnas": "pungsten",
    "pungstenars": "pungsten",
    "pungstenen": "pungsten",
    "pungstenens": "pungsten",
    "pungstens": "pungsten",
    "puniska": "punisk",
    "puniskare": "punisk",
    "puniskares": "punisk",
    "puniskas": "punisk",
    "puniskast": "punisk",
    "puniskaste": "punisk",
    "puniskastes": "punisk",
    "puniskasts": "punisk",
    "puniske": "punisk",
    "puniskes": "punisk",
    "punisks": "punisk",
    "puniskt": "punisk",
    "puniskts": "punisk",
    "punkar": "punkare",
    "punkaren": "punkare",
    "punkarens": "punkare",
    "punkares": "punkare",
    "punkarna": "punkare",
    "punkarnas": "punkare",
    "punkbanden": "punkband",
    "punkbandens": "punkband",
    "punkbandet": "punkband",
    "punkbandets": "punkband",
    "punkbands": "punkband",
    "punken": "punk",
    "punkens": "punk",
    "punkfrisyren": "punkfrisyr",
    "punkfrisyrens": "punkfrisyr",
    "punkfrisyrer": "punkfrisyr",
    "punkfrisyrerna": "punkfrisyr",
    "punkfrisyrernas": "punkfrisyr",
    "punkfrisyrers": "punkfrisyr",
    "punkfrisyrs": "punkfrisyr",
    "punks": "punk",
    "punktad": "punkta",
    "punktade": "punkta",
    "punktades": "punkta",
    "punktads": "punkta",
    "punktalglaset": "punktalglas",
    "punktalglasets": "punktalglas",
    "punktande": "punkta",
    "punktanden": "punktande",
    "punktandena": "punktande",
    "punktandenas": "punktande",
    "punktandens": "punktande",
    "punktandes": "punktande",
    "punktandet": "punktande",
    "punktandets": "punktande",
    "punktar": "punkta",
    "punktas": "punkta",
    "punktat": "punkta",
    "punktats": "punkta",
    "punkten": "punkt",
    "punktens": "punkt",
    "punkter": "punkt",
    "punkterad": "punktera",
    "punkterade": "punktera",
    "punkterades": "punktera",
    "punkterads": "punktera",
    "punkterande": "punktera",
    "punkteranden": "punkterande",
    "punkterandena": "punkterande",
    "punkterandenas": "punkterande",
    "punkterandens": "punkterande",
    "punkterandes": "punkterande",
    "punkterandet": "punkterande",
    "punkterandets": "punkterande",
    "punkterar": "punktera",
    "punkteras": "punktera",
    "punkterat": "punktera",
    "punkterats": "punktera",
    "punkterbara": "punkterbar",
    "punkterbarare": "punkterbar",
    "punkterbarares": "punkterbar",
    "punkterbaras": "punkterbar",
    "punkterbarast": "punkterbar",
    "punkterbaraste": "punkterbar",
    "punkterbarastes": "punkterbar",
    "punkterbarasts": "punkterbar",
    "punkterbare": "punkterbar",
    "punkterbares": "punkterbar",
    "punkterbarheten": "punkterbarhet",
    "punkterbarhetens": "punkterbarhet",
    "punkterbarhets": "punkterbarhet",
    "punkterbars": "punkterbar",
    "punkterbart": "punkterbar",
    "punkterbarts": "punkterbar",
    "punkteringar": "punktering",
    "punkteringarna": "punktering",
    "punkteringarnas": "punktering",
    "punkteringars": "punktering",
    "punkteringen": "punktering",
    "punkteringens": "punktering",
    "punkterings": "punktering",
    "punkteringssprayen": "punkteringsspray",
    "punkteringssprayens": "punkteringsspray",
    "punkteringssprayer": "punkteringsspray",
    "punkteringssprayerna": "punkteringsspray",
    "punkteringssprayernas": "punkteringsspray",
    "punkteringssprayers": "punkteringsspray",
    "punkteringssprays": "punkteringsspray",
    "punkteringssprejen": "punkteringssprej",
    "punkteringssprejens": "punkteringssprej",
    "punkteringssprejer": "punkteringssprej",
    "punkteringssprejerna": "punkteringssprej",
    "punkteringssprejernas": "punkteringssprej",
    "punkteringssprejers": "punkteringssprej",
    "punkteringssprejs": "punkteringssprej",
    "punkterna": "punkt",
    "punkternas": "punkt",
    "punkters": "punkt",
    "punktgravyren": "punktgravyr",
    "punktgravyrens": "punktgravyr",
    "punktgravyrs": "punktgravyr",
    "punkthusen": "punkthus",
    "punkthusens": "punkthus",
    "punkthuset": "punkthus",
    "punkthusets": "punkthus",
    "punktionen": "punktion",
    "punktionens": "punktion",
    "punktioner": "punktion",
    "punktionerna": "punktion",
    "punktionernas": "punktion",
    "punktioners": "punktion",
    "punktions": "punktion",
    "punktliga": "punktlig",
    "punktligare": "punktlig",
    "punktligares": "punktlig",
    "punktligas": "punktlig",
    "punktligast": "punktlig",
    "punktligaste": "punktlig",
    "punktligastes": "punktlig",
    "punktligasts": "punktlig",
    "punktlige": "punktlig",
    "punktliges": "punktlig",
    "punktligheten": "punktlighet",
    "punktlighetens": "punktlighet",
    "punktlighets": "punktlighet",
    "punktligs": "punktlig",
    "punktligt": "punktlig",
    "punktligts": "punktlig",
    "punktmarkerad": "punktmarkera",
    "punktmarkerade": "punktmarkera",
    "punktmarkerades": "punktmarkera",
    "punktmarkerads": "punktmarkera",
    "punktmarkerande": "punktmarkera",
    "punktmarkerandes": "punktmarkera",
    "punktmarkerar": "punktmarkera",
    "punktmarkeras": "punktmarkera",
    "punktmarkerat": "punktmarkera",
    "punktmarkerats": "punktmarkera",
    "punktmusiken": "punktmusik",
    "punktmusikens": "punktmusik",
    "punktmusiks": "punktmusik",
    "punktmängden": "punktmängd",
    "punktmängdens": "punktmängd",
    "punktmängder": "punktmängd",
    "punktmängderna": "punktmängd",
    "punktmängdernas": "punktmängd",
    "punktmängders": "punktmängd",
    "punktmängds": "punktmängd",
    "punkts": "punkt",
    "punktskatten": "punktskatt",
    "punktskattens": "punktskatt",
    "punktskatter": "punktskatt",
    "punktskatterna": "punktskatt",
    "punktskatternas": "punktskatt",
    "punktskatters": "punktskatt",
    "punktskatts": "punktskatt",
    "punktskriften": "punktskrift",
    "punktskriftens": "punktskrift",
    "punktskrifts": "punktskrift",
    "punktsvets": "punktsvetsa",
    "punktsvetsad": "punktsvetsa",
    "punktsvetsade": "punktsvetsa",
    "punktsvetsades": "punktsvetsa",
    "punktsvetsads": "punktsvetsa",
    "punktsvetsande": "punktsvetsa",
    "punktsvetsanden": "punktsvetsande",
    "punktsvetsandena": "punktsvetsande",
    "punktsvetsandenas": "punktsvetsande",
    "punktsvetsandens": "punktsvetsande",
    "punktsvetsandes": "punktsvetsande",
    "punktsvetsandet": "punktsvetsande",
    "punktsvetsandets": "punktsvetsande",
    "punktsvetsar": "punktsvetsa",
    "punktsvetsas": "punktsvetsa",
    "punktsvetsat": "punktsvetsa",
    "punktsvetsats": "punktsvetsa",
    "punktuella": "punktuell",
    "punktuellare": "punktuell",
    "punktuellares": "punktuell",
    "punktuellas": "punktuell",
    "punktuellast": "punktuell",
    "punktuellaste": "punktuell",
    "punktuellastes": "punktuell",
    "punktuellasts": "punktuell",
    "punktuelle": "punktuell",
    "punktuelles": "punktuell",
    "punktuells": "punktuell",
    "punktuellt": "punktuell",
    "punktuellts": "punktuell",
    "punkturen": "punktur",
    "punkturens": "punktur",
    "punkturer": "punktur",
    "punkturerna": "punktur",
    "punkturernas": "punktur",
    "punkturers": "punktur",
    "punkturs": "punktur",
    "punsad": "punsa",
    "punsade": "punsa",
    "punsades": "punsa",
    "punsads": "punsa",
    "punsande": "punsa",
    "punsanden": "punsande",
    "punsandena": "punsande",
    "punsandenas": "punsande",
    "punsandens": "punsande",
    "punsandes": "punsande",
    "punsandet": "punsande",
    "punsandets": "punsande",
    "punsar": "punsa",
    "punsarna": "puns",
    "punsarnas": "puns",
    "punsars": "puns",
    "punsas": "punsa",
    "punsat": "punsa",
    "punsats": "punsa",
    "punschen": "punsch",
    "punschens": "punsch",
    "punschs": "punsch",
    "punsen": "puns",
    "punsens": "puns",
    "pupillen": "pupill",
    "pupillens": "pupill",
    "pupiller": "pupill",
    "pupillerna": "pupill",
    "pupillernas": "pupill",
    "pupillers": "pupill",
    "pupills": "pupill",
    "pupp": "puppa",
    "puppan": "puppa",
    "puppans": "puppa",
    "puppas": "puppa",
    "puppe": "puppa",
    "puppor": "puppa",
    "pupporna": "puppa",
    "puppornas": "puppa",
    "puppors": "puppa",
    "pupps": "puppa",
    "pura": "pur",
    "purare": "pur",
    "purares": "pur",
    "puras": "pur",
    "purast": "pur",
    "puraste": "pur",
    "purastes": "pur",
    "purasts": "pur",
    "pure": "pur",
    "pures": "pur",
    "purgativen": "purgativ",
    "purgativens": "purgativ",
    "purgativet": "purgativ",
    "purgativets": "purgativ",
    "purgativs": "purgativ",
    "purgatoriet": "purgatorium",
    "purgatoriets": "purgatorium",
    "purgatoriums": "purgatorium",
    "purgerad": "purgera",
    "purgerade": "purgera",
    "purgerades": "purgera",
    "purgerads": "purgera",
    "purgerande": "purgera",
    "purgeranden": "purgerande",
    "purgerandena": "purgerande",
    "purgerandenas": "purgerande",
    "purgerandens": "purgerande",
    "purgerandes": "purgerande",
    "purgerandet": "purgerande",
    "purgerandets": "purgerande",
    "purgerar": "purgera",
    "purgeras": "purgera",
    "purgerat": "purgera",
    "purgerats": "purgera",
    "purgerbara": "purgerbar",
    "purgerbarare": "purgerbar",
    "purgerbarares": "purgerbar",
    "purgerbaras": "purgerbar",
    "purgerbarast": "purgerbar",
    "purgerbaraste": "purgerbar",
    "purgerbarastes": "purgerbar",
    "purgerbarasts": "purgerbar",
    "purgerbare": "purgerbar",
    "purgerbares": "purgerbar",
    "purgerbarheten": "purgerbarhet",
    "purgerbarhetens": "purgerbarhet",
    "purgerbarhets": "purgerbarhet",
    "purgerbars": "purgerbar",
    "purgerbart": "purgerbar",
    "purgerbarts": "purgerbar",
    "purgeringar": "purgering",
    "purgeringarna": "purgering",
    "purgeringarnas": "purgering",
    "purgeringars": "purgering",
    "purgeringen": "purgering",
    "purgeringens": "purgering",
    "purgerings": "purgering",
    "purheten": "purhet",
    "purhetens": "purhet",
    "purhets": "purhet",
    "purinen": "purin",
    "purinens": "purin",
    "puriner": "purin",
    "purinerna": "purin",
    "purinernas": "purin",
    "puriners": "purin",
    "purinet": "purin",
    "purinets": "purin",
    "purins": "purin",
    "purismen": "purism",
    "purismens": "purism",
    "purismer": "purism",
    "purismerna": "purism",
    "purismernas": "purism",
    "purismers": "purism",
    "purisms": "purism",
    "puristen": "purist",
    "puristens": "purist",
    "purister": "purist",
    "puristerna": "purist",
    "puristernas": "purist",
    "puristers": "purist",
    "puristiska": "puristisk",
    "puristiskas": "puristisk",
    "puristiske": "puristisk",
    "puristiskes": "puristisk",
    "puristisks": "puristisk",
    "puristiskt": "puristisk",
    "puristiskts": "puristisk",
    "purists": "purist",
    "puritanen": "puritan",
    "puritanens": "puritan",
    "puritaner": "puritan",
    "puritanerna": "puritan",
    "puritanernas": "puritan",
    "puritaners": "puritan",
    "puritanismen": "puritanism",
    "puritanismens": "puritanism",
    "puritanismer": "puritanism",
    "puritanismerna": "puritanism",
    "puritanismernas": "puritanism",
    "puritanismers": "puritanism",
    "puritanisms": "puritanism",
    "puritanistiska": "puritanistisk",
    "puritanistiskas": "puritanistisk",
    "puritanistiske": "puritanistisk",
    "puritanistiskes": "puritanistisk",
    "puritanistisks": "puritanistisk",
    "puritanistiskt": "puritanistisk",
    "puritanistiskts": "puritanistisk",
    "puritans": "puritan",
    "puritanska": "puritansk",
    "puritanskare": "puritansk",
    "puritanskares": "puritansk",
    "puritanskas": "puritansk",
    "puritanskast": "puritansk",
    "puritanskaste": "puritansk",
    "puritanskastes": "puritansk",
    "puritanskasts": "puritansk",
    "puritanske": "puritansk",
    "puritanskes": "puritansk",
    "puritansks": "puritansk",
    "puritanskt": "puritansk",
    "puritanskts": "puritansk",
    "purjolökar": "purjolök",
    "purjolökarna": "purjolök",
    "purjolökarnas": "purjolök",
    "purjolökars": "purjolök",
    "purjolöken": "purjolök",
    "purjolökens": "purjolök",
    "purjolöks": "purjolök",
    "purkens": "purken",
    "purket": "purken",
    "purkets": "purken",
    "purkna": "purken",
    "purknade": "purkna",
    "purknades": "purkna",
    "purknande": "purkna",
    "purknanden": "purknande",
    "purknandena": "purknande",
    "purknandenas": "purknande",
    "purknandens": "purknande",
    "purknandes": "purknande",
    "purknandet": "purknande",
    "purknandets": "purknande",
    "purknar": "purkna",
    "purknare": "purken",
    "purknares": "purken",
    "purknas": "purkna",
    "purknast": "purken",
    "purknaste": "purken",
    "purknastes": "purken",
    "purknasts": "purken",
    "purknat": "purkna",
    "purknats": "purkna",
    "purkne": "purken",
    "purknes": "purken",
    "purprad": "purpra",
    "purprade": "purpra",
    "purprades": "purpra",
    "purprads": "purpra",
    "purprande": "purpra",
    "purpranden": "purprande",
    "purprandena": "purprande",
    "purprandenas": "purprande",
    "purprandens": "purprande",
    "purprandes": "purprande",
    "purprandet": "purprande",
    "purprandets": "purprande",
    "purprar": "purpra",
    "purpras": "purpra",
    "purprat": "purpra",
    "purprats": "purpra",
    "purpurfärg": "purpurfärga",
    "purpurfärgad": "purpurfärga",
    "purpurfärgade": "purpurfärga",
    "purpurfärgades": "purpurfärga",
    "purpurfärgads": "purpurfärga",
    "purpurfärgande": "purpurfärga",
    "purpurfärganden": "purpurfärgande",
    "purpurfärgandena": "purpurfärgande",
    "purpurfärgandenas": "purpurfärgande",
    "purpurfärgandens": "purpurfärgande",
    "purpurfärgandes": "purpurfärgande",
    "purpurfärgandet": "purpurfärgande",
    "purpurfärgandets": "purpurfärgande",
    "purpurfärgar": "purpurfärga",
    "purpurfärgas": "purpurfärga",
    "purpurfärgat": "purpurfärga",
    "purpurfärgats": "purpurfärga",
    "purpurn": "purpur",
    "purpurns": "purpur",
    "purpurröda": "purpurröd",
    "purpurrödare": "purpurröd",
    "purpurrödares": "purpurröd",
    "purpurrödas": "purpurröd",
    "purpurrödast": "purpurröd",
    "purpurrödaste": "purpurröd",
    "purpurrödastes": "purpurröd",
    "purpurrödasts": "purpurröd",
    "purpurröde": "purpurröd",
    "purpurrödes": "purpurröd",
    "purpurröds": "purpurröd",
    "purpurrött": "purpurröd",
    "purpurrötts": "purpurröd",
    "purpurs": "purpur",
    "purpursnäck": "purpursnäcka",
    "purpursnäckan": "purpursnäcka",
    "purpursnäckans": "purpursnäcka",
    "purpursnäckas": "purpursnäcka",
    "purpursnäcke": "purpursnäcka",
    "purpursnäckor": "purpursnäcka",
    "purpursnäckorna": "purpursnäcka",
    "purpursnäckornas": "purpursnäcka",
    "purpursnäckors": "purpursnäcka",
    "purpursnäcks": "purpursnäcka",
    "purr": "purra",
    "purrad": "purra",
    "purrade": "purra",
    "purrades": "purra",
    "purrads": "purra",
    "purrande": "purra",
    "purranden": "purrande",
    "purrandena": "purrande",
    "purrandenas": "purrande",
    "purrandens": "purrande",
    "purrandes": "purrande",
    "purrandet": "purrande",
    "purrandets": "purrande",
    "purrar": "purra",
    "purras": "purra",
    "purrat": "purra",
    "purrats": "purra",
    "purs": "pur",
    "pursern": "purser",
    "purserns": "purser",
    "pursers": "purser",
    "pursersarna": "purser",
    "pursersarnas": "purser",
    "pursersen": "purser",
    "pursersens": "purser",
    "pursrar": "purser",
    "pursrarna": "purser",
    "pursrarnas": "purser",
    "pursrars": "purser",
    "purt": "pur",
    "purts": "pur",
    "puréer": "puré",
    "puréerna": "puré",
    "puréernas": "puré",
    "puréers": "puré",
    "purén": "puré",
    "puréns": "puré",
    "purés": "puré",
    "pushad": "pusha",
    "pushade": "pusha",
    "pushades": "pusha",
    "pushads": "pusha",
    "pushande": "pusha",
    "pushanden": "pushande",
    "pushandena": "pushande",
    "pushandenas": "pushande",
    "pushandens": "pushande",
    "pushandes": "pushande",
    "pushandet": "pushande",
    "pushandets": "pushande",
    "pushar": "pusha",
    "pushas": "pusha",
    "pushat": "pusha",
    "pushats": "pusha",
    "puss": "pussa",
    "pussad": "pussa",
    "pussade": "pussa",
    "pussades": "pussas",
    "pussads": "pussa",
    "pussande": "pussa",
    "pussanden": "pussande",
    "pussandena": "pussande",
    "pussandenas": "pussande",
    "pussandens": "pussande",
    "pussandes": "pussande",
    "pussandet": "pussande",
    "pussandets": "pussande",
    "pussar": "pussa",
    "pussarna": "puss",
    "pussarnas": "puss",
    "pussars": "puss",
    "pussas": "pussa",
    "pussat": "pussa",
    "pussats": "pussas",
    "pusselbitar": "pusselbit",
    "pusselbitarna": "pusselbit",
    "pusselbitarnas": "pusselbit",
    "pusselbitars": "pusselbit",
    "pusselbiten": "pusselbit",
    "pusselbitens": "pusselbit",
    "pusselbits": "pusselbit",
    "pussels": "pussel",
    "pussen": "puss",
    "pussens": "puss",
    "pussiga": "pussig",
    "pussigare": "pussig",
    "pussigares": "pussig",
    "pussigas": "pussig",
    "pussigast": "pussig",
    "pussigaste": "pussig",
    "pussigastes": "pussig",
    "pussigasts": "pussig",
    "pussige": "pussig",
    "pussiges": "pussig",
    "pussigheten": "pussighet",
    "pussighetens": "pussighet",
    "pussighets": "pussighet",
    "pussigs": "pussig",
    "pussigt": "pussig",
    "pussigts": "pussig",
    "pusskalasen": "pusskalas",
    "pusskalasens": "pusskalas",
    "pusskalaset": "pusskalas",
    "pusskalasets": "pusskalas",
    "pusslade": "pussla",
    "pusslades": "pussla",
    "pusslande": "pussla",
    "pusslanden": "pusslande",
    "pusslandena": "pusslande",
    "pusslandenas": "pusslande",
    "pusslandens": "pusslande",
    "pusslandes": "pusslande",
    "pusslandet": "pusslande",
    "pusslandets": "pusslande",
    "pusslar": "pussla",
    "pusslas": "pussla",
    "pusslat": "pussla",
    "pusslats": "pussla",
    "pusslen": "pussel",
    "pusslens": "pussel",
    "pusslet": "pussel",
    "pusslets": "pussel",
    "pustade": "pusta",
    "pustades": "pusta",
    "pustan": "pusta",
    "pustande": "pusta",
    "pustanden": "pustande",
    "pustandena": "pustande",
    "pustandenas": "pustande",
    "pustandens": "pustande",
    "pustandes": "pustande",
    "pustandet": "pustande",
    "pustandets": "pustande",
    "pustans": "pusta",
    "pustar": "pusta",
    "pustarna": "pust",
    "pustarnas": "pust",
    "pustars": "pust",
    "pustas": "pusta",
    "pustat": "pusta",
    "pustats": "pusta",
    "pusteln": "pustel",
    "pustelns": "pustel",
    "pustels": "pustel",
    "pusten": "pust",
    "pustens": "pust",
    "pustler": "pustel",
    "pustlerna": "pustel",
    "pustlernas": "pustel",
    "pustlers": "pustel",
    "pusts": "pust",
    "put": "puta",
    "putade": "puta",
    "putades": "puta",
    "putan": "puta",
    "putande": "puta",
    "putanden": "putande",
    "putandena": "putande",
    "putandenas": "putande",
    "putandens": "putande",
    "putandes": "putande",
    "putandet": "putande",
    "putandets": "putande",
    "putans": "puta",
    "putar": "puta",
    "putas": "puta",
    "putat": "puta",
    "putats": "puta",
    "pute": "puta",
    "putiga": "putig",
    "putigare": "putig",
    "putigares": "putig",
    "putigas": "putig",
    "putigast": "putig",
    "putigaste": "putig",
    "putigastes": "putig",
    "putigasts": "putig",
    "putige": "putig",
    "putiges": "putig",
    "putigs": "putig",
    "putigt": "putig",
    "putigts": "putig",
    "putor": "puta",
    "putorna": "puta",
    "putornas": "puta",
    "putors": "puta",
    "putrida": "putrid",
    "putridare": "putrid",
    "putridares": "putrid",
    "putridas": "putrid",
    "putridast": "putrid",
    "putridaste": "putrid",
    "putridastes": "putrid",
    "putridasts": "putrid",
    "putride": "putrid",
    "putrides": "putrid",
    "putrids": "putrid",
    "puts": "puta",
    "putsad": "putsa",
    "putsade": "putsa",
    "putsades": "putsa",
    "putsads": "putsa",
    "putsande": "putsa",
    "putsanden": "putsande",
    "putsandena": "putsande",
    "putsandenas": "putsande",
    "putsandens": "putsande",
    "putsandes": "putsande",
    "putsandet": "putsande",
    "putsandets": "putsande",
    "putsar": "putsa",
    "putsas": "putsa",
    "putsat": "putsa",
    "putsats": "putsa",
    "putschen": "putsch",
    "putschens": "putsch",
    "putscher": "putsch",
    "putscherna": "putsch",
    "putschernas": "putsch",
    "putschers": "putsch",
    "putschs": "putsch",
    "putsdukar": "putsduk",
    "putsdukarna": "putsduk",
    "putsdukarnas": "putsduk",
    "putsdukars": "putsduk",
    "putsduken": "putsduk",
    "putsdukens": "putsduk",
    "putsduks": "putsduk",
    "putsen": "puts",
    "putsens": "puts",
    "putset": "puts",
    "putsets": "puts",
    "putslustiga": "putslustig",
    "putslustigare": "putslustig",
    "putslustigares": "putslustig",
    "putslustigas": "putslustig",
    "putslustigast": "putslustig",
    "putslustigaste": "putslustig",
    "putslustigastes": "putslustig",
    "putslustigasts": "putslustig",
    "putslustige": "putslustig",
    "putslustiges": "putslustig",
    "putslustigheten": "putslustighet",
    "putslustighetens": "putslustighet",
    "putslustigheter": "putslustighet",
    "putslustigheterna": "putslustighet",
    "putslustigheternas": "putslustighet",
    "putslustigheters": "putslustighet",
    "putslustighets": "putslustighet",
    "putslustigs": "putslustig",
    "putslustigt": "putslustig",
    "putslustigts": "putslustig",
    "putstras": "putstrasa",
    "putstrasan": "putstrasa",
    "putstrasans": "putstrasa",
    "putstrasas": "putstrasa",
    "putstrase": "putstrasa",
    "putstrasor": "putstrasa",
    "putstrasorna": "putstrasa",
    "putstrasornas": "putstrasa",
    "putstrasors": "putstrasa",
    "putt": "putte",
    "putta": "putt",
    "puttad": "putta",
    "puttade": "putta",
    "puttades": "putta",
    "puttads": "putta",
    "puttande": "putta",
    "puttanden": "puttande",
    "puttandena": "puttande",
    "puttandenas": "puttande",
    "puttandens": "puttande",
    "puttandes": "puttande",
    "puttandet": "puttande",
    "puttandets": "puttande",
    "puttar": "putte",
    "puttare": "putt",
    "puttares": "putt",
    "puttarna": "putte",
    "puttarnas": "putte",
    "puttars": "putte",
    "puttas": "putta",
    "puttast": "putt",
    "puttaste": "putt",
    "puttastes": "putt",
    "puttasts": "putt",
    "puttat": "putta",
    "puttats": "putta",
    "putte": "putt",
    "puttefnaskar": "puttefnask",
    "puttefnaskarna": "puttefnask",
    "puttefnaskarnas": "puttefnask",
    "puttefnaskars": "puttefnask",
    "puttefnasken": "puttefnask",
    "puttefnaskens": "puttefnask",
    "puttefnasks": "puttefnask",
    "putten": "putte",
    "puttens": "putte",
    "putter": "puttra",
    "putters": "putter",
    "puttes": "putte",
    "puttheten": "putthet",
    "putthetens": "putthet",
    "putthets": "putthet",
    "putti": "putto",
    "puttina": "putto",
    "puttinas": "putto",
    "puttingar": "putting",
    "puttingarna": "putting",
    "puttingarnas": "putting",
    "puttingars": "putting",
    "puttingen": "putting",
    "puttingens": "putting",
    "puttings": "putting",
    "puttis": "putto",
    "putton": "putto",
    "puttons": "putto",
    "puttos": "putto",
    "puttrade": "puttra",
    "puttrades": "puttra",
    "puttrande": "puttra",
    "puttranden": "puttrande",
    "puttrandena": "puttrande",
    "puttrandenas": "puttrande",
    "puttrandens": "puttrande",
    "puttrandes": "puttrande",
    "puttrandet": "puttrande",
    "puttrandets": "puttrande",
    "puttrar": "puttra",
    "puttras": "puttra",
    "puttrat": "puttra",
    "puttrats": "puttra",
    "puttret": "putter",
    "puttrets": "putter",
    "puttriga": "puttrig",
    "puttrigare": "puttrig",
    "puttrigares": "puttrig",
    "puttrigas": "puttrig",
    "puttrigast": "puttrig",
    "puttrigaste": "puttrig",
    "puttrigastes": "puttrig",
    "puttrigasts": "puttrig",
    "puttrige": "puttrig",
    "puttriges": "puttrig",
    "puttrigheten": "puttrighet",
    "puttrighetens": "puttrighet",
    "puttrighets": "puttrighet",
    "puttrigs": "puttrig",
    "puttrigt": "puttrig",
    "puttrigts": "puttrig",
    "putts": "putte",
    "puzzlen": "puzzle",
    "puzzlens": "puzzle",
    "puzzles": "puzzle",
    "puzzlet": "puzzle",
    "puzzlets": "puzzle",
    "pxen": "pix",
    "pxens": "pix",
    "pxet": "pix",
    "pxets": "pix",
    "pycken": "pycke",
    "pyckena": "pycke",
    "pyckenas": "pycke",
    "pyckens": "pycke",
    "pyckes": "pycke",
    "pycket": "pycke",
    "pyckets": "pycke",
    "pyeliten": "pyelit",
    "pyelitens": "pyelit",
    "pyeliter": "pyelit",
    "pyeliterna": "pyelit",
    "pyeliternas": "pyelit",
    "pyeliters": "pyelit",
    "pyelits": "pyelit",
    "pygméen": "pygmé",
    "pygméens": "pygmé",
    "pygméer": "pygmé",
    "pygméerna": "pygmé",
    "pygméernas": "pygmé",
    "pygméers": "pygmé",
    "pygmén": "pygmé",
    "pygméns": "pygmé",
    "pygmés": "pygmé",
    "pyjamasar": "pyjamas",
    "pyjamasarna": "pyjamas",
    "pyjamasarnas": "pyjamas",
    "pyjamasars": "pyjamas",
    "pyjamasen": "pyjamas",
    "pyjamasens": "pyjamas",
    "pyjamasfick": "pyjamasficka",
    "pyjamasfickan": "pyjamasficka",
    "pyjamasfickans": "pyjamasficka",
    "pyjamasfickas": "pyjamasficka",
    "pyjamasficke": "pyjamasficka",
    "pyjamasfickor": "pyjamasficka",
    "pyjamasfickorna": "pyjamasficka",
    "pyjamasfickornas": "pyjamasficka",
    "pyjamasfickors": "pyjamasficka",
    "pyjamasficks": "pyjamasficka",
    "pyjamaspartyn": "pyjamasparty",
    "pyjamaspartyna": "pyjamasparty",
    "pyjamaspartynas": "pyjamasparty",
    "pyjamaspartyns": "pyjamasparty",
    "pyjamaspartys": "pyjamasparty",
    "pyjamaspartyt": "pyjamasparty",
    "pyjamaspartyts": "pyjamasparty",
    "pyknikern": "pykniker",
    "pyknikerna": "pykniker",
    "pyknikernas": "pykniker",
    "pyknikerns": "pykniker",
    "pyknikers": "pykniker",
    "pykniska": "pyknisk",
    "pykniskare": "pyknisk",
    "pykniskares": "pyknisk",
    "pykniskas": "pyknisk",
    "pykniskast": "pyknisk",
    "pykniskaste": "pyknisk",
    "pykniskastes": "pyknisk",
    "pykniskasts": "pyknisk",
    "pykniske": "pyknisk",
    "pykniskes": "pyknisk",
    "pyknisks": "pyknisk",
    "pykniskt": "pyknisk",
    "pykniskts": "pyknisk",
    "pyknometern": "pyknometer",
    "pyknometerns": "pyknometer",
    "pyknometers": "pyknometer",
    "pyknometrar": "pyknometer",
    "pyknometrarna": "pyknometer",
    "pyknometrarnas": "pyknometer",
    "pyknometrars": "pyknometer",
    "pylonen": "pylon",
    "pylonens": "pylon",
    "pyloner": "pylon",
    "pylonerna": "pylon",
    "pylonernas": "pylon",
    "pyloners": "pylon",
    "pylons": "pylon",
    "pyndar": "pyndare",
    "pyndaren": "pyndare",
    "pyndarens": "pyndare",
    "pyndares": "pyndare",
    "pyndarna": "pyndare",
    "pyndarnas": "pyndare",
    "pyngels": "pyngel",
    "pynglet": "pyngel",
    "pynglets": "pyngel",
    "pynt": "pynta",
    "pyntad": "pynta",
    "pyntade": "pynta",
    "pyntades": "pynta",
    "pyntads": "pynta",
    "pyntande": "pynta",
    "pyntanden": "pyntande",
    "pyntandena": "pyntande",
    "pyntandenas": "pyntande",
    "pyntandens": "pyntande",
    "pyntandes": "pyntande",
    "pyntandet": "pyntande",
    "pyntandets": "pyntande",
    "pyntar": "pynta",
    "pyntarna": "pynt",
    "pyntarnas": "pynt",
    "pyntars": "pynt",
    "pyntas": "pynta",
    "pyntat": "pynta",
    "pyntats": "pynta",
    "pynten": "pynt",
    "pyntens": "pynt",
    "pyntet": "pynt",
    "pyntets": "pynt",
    "pynts": "pynt",
    "pyr": "pyra",
    "pyramidala": "pyramidal",
    "pyramidalare": "pyramidal",
    "pyramidalares": "pyramidal",
    "pyramidalas": "pyramidal",
    "pyramidalast": "pyramidal",
    "pyramidalaste": "pyramidal",
    "pyramidalastes": "pyramidal",
    "pyramidalasts": "pyramidal",
    "pyramidale": "pyramidal",
    "pyramidales": "pyramidal",
    "pyramidals": "pyramidal",
    "pyramidalt": "pyramidal",
    "pyramidalts": "pyramidal",
    "pyramiden": "pyramid",
    "pyramidens": "pyramid",
    "pyramider": "pyramid",
    "pyramiderna": "pyramid",
    "pyramidernas": "pyramid",
    "pyramiders": "pyramid",
    "pyramids": "pyramid",
    "pyrande": "pyra",
    "pyranden": "pyrande",
    "pyrandena": "pyrande",
    "pyrandenas": "pyrande",
    "pyrandens": "pyrande",
    "pyrandes": "pyrande",
    "pyrandet": "pyrande",
    "pyrandets": "pyrande",
    "pyras": "pyra",
    "pyrd": "pyra",
    "pyrda": "pyra",
    "pyrdas": "pyra",
    "pyrde": "pyra",
    "pyrdes": "pyra",
    "pyrds": "pyra",
    "pyren": "pyre",
    "pyrena": "pyre",
    "pyrenas": "pyre",
    "pyreneiska": "pyreneisk",
    "pyreneiskare": "pyreneisk",
    "pyreneiskares": "pyreneisk",
    "pyreneiskas": "pyreneisk",
    "pyreneiskast": "pyreneisk",
    "pyreneiskaste": "pyreneisk",
    "pyreneiskastes": "pyreneisk",
    "pyreneiskasts": "pyreneisk",
    "pyreneiske": "pyreneisk",
    "pyreneiskes": "pyreneisk",
    "pyreneisks": "pyreneisk",
    "pyreneiskt": "pyreneisk",
    "pyreneiskts": "pyreneisk",
    "pyrenen": "pyren",
    "pyrenens": "pyren",
    "pyrens": "pyren",
    "pyres": "pyre",
    "pyret": "pyre",
    "pyrets": "pyre",
    "pyridinen": "pyridin",
    "pyridinens": "pyridin",
    "pyridiner": "pyridin",
    "pyridinerna": "pyridin",
    "pyridinernas": "pyridin",
    "pyridiners": "pyridin",
    "pyridinet": "pyridin",
    "pyridinets": "pyridin",
    "pyridins": "pyridin",
    "pyriten": "pyrit",
    "pyritens": "pyrit",
    "pyriter": "pyrit",
    "pyriterna": "pyrit",
    "pyriternas": "pyrit",
    "pyriters": "pyrit",
    "pyrits": "pyrit",
    "pyrofora": "pyrofor",
    "pyroforas": "pyrofor",
    "pyrofore": "pyrofor",
    "pyrofores": "pyrofor",
    "pyrofors": "pyrofor",
    "pyrofort": "pyrofor",
    "pyroforts": "pyrofor",
    "pyrol": "pyrola",
    "pyrolan": "pyrola",
    "pyrolans": "pyrola",
    "pyrolas": "pyrola",
    "pyrole": "pyrola",
    "pyrolor": "pyrola",
    "pyrolorna": "pyrola",
    "pyrolornas": "pyrola",
    "pyrolors": "pyrola",
    "pyrols": "pyrola",
    "pyromanen": "pyroman",
    "pyromanens": "pyroman",
    "pyromaner": "pyroman",
    "pyromanerna": "pyroman",
    "pyromanernas": "pyroman",
    "pyromaners": "pyroman",
    "pyromanien": "pyromani",
    "pyromaniens": "pyromani",
    "pyromanin": "pyromani",
    "pyromanins": "pyromani",
    "pyromanis": "pyromani",
    "pyromans": "pyroman",
    "pyrometern": "pyrometer",
    "pyrometerns": "pyrometer",
    "pyrometers": "pyrometer",
    "pyrometrar": "pyrometer",
    "pyrometrarna": "pyrometer",
    "pyrometrarnas": "pyrometer",
    "pyrometrars": "pyrometer",
    "pyrotekniken": "pyroteknik",
    "pyroteknikens": "pyroteknik",
    "pyrotekniks": "pyroteknik",
    "pyrotekniska": "pyroteknisk",
    "pyrotekniskare": "pyroteknisk",
    "pyrotekniskares": "pyroteknisk",
    "pyrotekniskas": "pyroteknisk",
    "pyrotekniskast": "pyroteknisk",
    "pyrotekniskaste": "pyroteknisk",
    "pyrotekniskastes": "pyroteknisk",
    "pyrotekniskasts": "pyroteknisk",
    "pyrotekniske": "pyroteknisk",
    "pyrotekniskes": "pyroteknisk",
    "pyroteknisks": "pyroteknisk",
    "pyrotekniskt": "pyroteknisk",
    "pyrotekniskts": "pyroteknisk",
    "pyrrhussegern": "pyrrhusseger",
    "pyrrhussegerns": "pyrrhusseger",
    "pyrrhussegers": "pyrrhusseger",
    "pyrrhussegrar": "pyrrhusseger",
    "pyrrhussegrarna": "pyrrhusseger",
    "pyrrhussegrarnas": "pyrrhusseger",
    "pyrrhussegrars": "pyrrhusseger",
    "pyrrussegern": "pyrrusseger",
    "pyrrussegerns": "pyrrusseger",
    "pyrrussegers": "pyrrusseger",
    "pyrrussegrar": "pyrrusseger",
    "pyrrussegrarna": "pyrrusseger",
    "pyrrussegrarnas": "pyrrusseger",
    "pyrrussegrars": "pyrrusseger",
    "pyrs": "pyre",
    "pyrschjakten": "pyrschjakt",
    "pyrschjaktens": "pyrschjakt",
    "pyrschjakts": "pyrschjakt",
    "pyrt": "pyra",
    "pyrts": "pyra",
    "pys": "pysa",
    "pysande": "pysa",
    "pysanden": "pysande",
    "pysandena": "pysande",
    "pysandenas": "pysande",
    "pysandens": "pysande",
    "pysandes": "pysande",
    "pysandet": "pysande",
    "pysandets": "pysande",
    "pysar": "pys",
    "pysarna": "pys",
    "pysarnas": "pys",
    "pysars": "pys",
    "pysas": "pysa",
    "pysen": "pys",
    "pysens": "pys",
    "pyser": "pysa",
    "pyses": "pysa",
    "pyssel": "pyssla",
    "pyssels": "pyssel",
    "pysslade": "pyssla",
    "pysslades": "pyssla",
    "pysslande": "pyssla",
    "pysslanden": "pysslande",
    "pysslandena": "pysslande",
    "pysslandenas": "pysslande",
    "pysslandens": "pysslande",
    "pysslandes": "pysslande",
    "pysslandet": "pysslande",
    "pysslandets": "pysslande",
    "pysslar": "pyssla",
    "pysslas": "pyssla",
    "pysslat": "pyssla",
    "pysslats": "pyssla",
    "pysslet": "pyssel",
    "pysslets": "pyssel",
    "pyssliga": "pysslig",
    "pyssligare": "pysslig",
    "pyssligares": "pysslig",
    "pyssligas": "pysslig",
    "pyssligast": "pysslig",
    "pyssligaste": "pysslig",
    "pyssligastes": "pysslig",
    "pyssligasts": "pysslig",
    "pysslige": "pysslig",
    "pyssliges": "pysslig",
    "pyssligheten": "pysslighet",
    "pysslighetens": "pysslighet",
    "pysslighets": "pysslighet",
    "pyssligs": "pysslig",
    "pyssligt": "pysslig",
    "pyssligts": "pysslig",
    "pysslingar": "pyssling",
    "pysslingarna": "pyssling",
    "pysslingarnas": "pyssling",
    "pysslingars": "pyssling",
    "pysslingen": "pyssling",
    "pysslingens": "pyssling",
    "pysslings": "pyssling",
    "pyst": "pysa",
    "pyste": "pysa",
    "pystes": "pysa",
    "pysts": "pysa",
    "pytonen": "pyton",
    "pytonens": "pyton",
    "pytonormar": "pytonorm",
    "pytonormarna": "pytonorm",
    "pytonormarnas": "pytonorm",
    "pytonormars": "pytonorm",
    "pytonormen": "pytonorm",
    "pytonormens": "pytonorm",
    "pytonorms": "pytonorm",
    "pytons": "pyton",
    "pyts": "pytsa",
    "pytsad": "pytsa",
    "pytsade": "pytsa",
    "pytsades": "pytsa",
    "pytsads": "pytsa",
    "pytsande": "pytsa",
    "pytsanden": "pytsande",
    "pytsandena": "pytsande",
    "pytsandenas": "pytsande",
    "pytsandens": "pytsande",
    "pytsandes": "pytsande",
    "pytsandet": "pytsande",
    "pytsandets": "pytsande",
    "pytsar": "pytsa",
    "pytsarna": "pyts",
    "pytsarnas": "pyts",
    "pytsars": "pyts",
    "pytsas": "pytsa",
    "pytsat": "pytsa",
    "pytsats": "pytsa",
    "pytsen": "pyts",
    "pytsens": "pyts",
    "pyttelilla": "pytteliten",
    "pyttelillas": "pytteliten",
    "pyttelille": "pytteliten",
    "pyttelilles": "pytteliten",
    "pyttelitens": "pytteliten",
    "pyttelitet": "pytteliten",
    "pyttelitets": "pytteliten",
    "pytten": "pytt",
    "pyttens": "pytt",
    "pyttesmå": "pytteliten",
    "pyttesmås": "pytteliten",
    "pyttipannan": "pyttipanna",
    "pyttipannans": "pyttipanna",
    "pyttipannas": "pyttipanna",
    "pytts": "pytt",
    "päl": "päla",
    "pälad": "päla",
    "pälade": "päla",
    "pälades": "päla",
    "pälads": "päla",
    "pälande": "päla",
    "pälanden": "pälande",
    "pälandena": "pälande",
    "pälandenas": "pälande",
    "pälandens": "pälande",
    "pälandes": "pälande",
    "pälandet": "pälande",
    "pälandets": "pälande",
    "pälar": "päla",
    "pälas": "päla",
    "pälat": "päla",
    "pälats": "päla",
    "pällar": "päll",
    "pällarna": "päll",
    "pällarnas": "päll",
    "pällars": "päll",
    "pällen": "päll",
    "pällens": "päll",
    "pälls": "päll",
    "pälsallergien": "pälsallergi",
    "pälsallergiens": "pälsallergi",
    "pälsallergier": "pälsallergi",
    "pälsallergierna": "pälsallergi",
    "pälsallergiernas": "pälsallergi",
    "pälsallergiers": "pälsallergi",
    "pälsallergin": "pälsallergi",
    "pälsallergins": "pälsallergi",
    "pälsallergis": "pälsallergi",
    "pälsar": "päls",
    "pälsarna": "päls",
    "pälsarnas": "päls",
    "pälsars": "päls",
    "pälsbollar": "pälsboll",
    "pälsbollarna": "pälsboll",
    "pälsbollarnas": "pälsboll",
    "pälsbollars": "pälsboll",
    "pälsbollen": "pälsboll",
    "pälsbollens": "pälsboll",
    "pälsbolls": "pälsboll",
    "pälsdjuren": "pälsdjur",
    "pälsdjurens": "pälsdjur",
    "pälsdjuret": "pälsdjur",
    "pälsdjurets": "pälsdjur",
    "pälsdjurs": "pälsdjur",
    "pälsen": "päls",
    "pälsens": "päls",
    "pälsfarmar": "pälsfarm",
    "pälsfarmarna": "pälsfarm",
    "pälsfarmarnas": "pälsfarm",
    "pälsfarmars": "pälsfarm",
    "pälsfarmen": "pälsfarm",
    "pälsfarmens": "pälsfarm",
    "pälsfarms": "pälsfarm",
    "pälsfladdrar": "pälsfladdrare",
    "pälsfladdraren": "pälsfladdrare",
    "pälsfladdrarens": "pälsfladdrare",
    "pälsfladdrares": "pälsfladdrare",
    "pälsfladdrarna": "pälsfladdrare",
    "pälsfladdrarnas": "pälsfladdrare",
    "pälsjägar": "pälsjägare",
    "pälsjägaren": "pälsjägare",
    "pälsjägarens": "pälsjägare",
    "pälsjägares": "pälsjägare",
    "pälsjägarna": "pälsjägare",
    "pälsjägarnas": "pälsjägare",
    "pälsskinnen": "pälsskinn",
    "pälsskinnens": "pälsskinn",
    "pälsskinnet": "pälsskinn",
    "pälsskinnets": "pälsskinn",
    "pälsskinns": "pälsskinn",
    "pälssälar": "pälssäl",
    "pälssälarna": "pälssäl",
    "pälssälarnas": "pälssäl",
    "pälssälars": "pälssäl",
    "pälssälen": "pälssäl",
    "pälssälens": "pälssäl",
    "pälssäls": "pälssäl",
    "pälsverket": "pälsverk",
    "pälsverkets": "pälsverk",
    "pälsverks": "pälsverk",
    "pälsängern": "pälsänger",
    "pälsängerns": "pälsänger",
    "pälsängers": "pälsänger",
    "pälsängrar": "pälsänger",
    "pälsängrarna": "pälsänger",
    "pälsängrarnas": "pälsänger",
    "pälsängrars": "pälsänger",
    "pären": "pär",
    "pärens": "pär",
    "pärer": "pär",
    "pärerna": "pär",
    "pärernas": "pär",
    "pärers": "pär",
    "pärken": "pärk",
    "pärkens": "pärk",
    "pärks": "pärk",
    "pärl": "pärla",
    "pärlade": "pärla",
    "pärlades": "pärla",
    "pärlan": "pärla",
    "pärlande": "pärla",
    "pärlanden": "pärlande",
    "pärlandena": "pärlande",
    "pärlandenas": "pärlande",
    "pärlandens": "pärlande",
    "pärlandes": "pärlande",
    "pärlandet": "pärlande",
    "pärlandets": "pärlande",
    "pärlans": "pärla",
    "pärlar": "pärla",
    "pärlas": "pärla",
    "pärlat": "pärla",
    "pärlats": "pärla",
    "pärlbanden": "pärlband",
    "pärlbandens": "pärlband",
    "pärlbandet": "pärlband",
    "pärlbandets": "pärlband",
    "pärlbands": "pärlband",
    "pärlbroderier": "pärlbroderi",
    "pärlbroderierna": "pärlbroderi",
    "pärlbroderiernas": "pärlbroderi",
    "pärlbroderiers": "pärlbroderi",
    "pärlbroderiet": "pärlbroderi",
    "pärlbroderiets": "pärlbroderi",
    "pärlbroderis": "pärlbroderi",
    "pärlbroderit": "pärlbroderi",
    "pärlbroderits": "pärlbroderi",
    "pärlbåtar": "pärlbåt",
    "pärlbåtarna": "pärlbåt",
    "pärlbåtarnas": "pärlbåt",
    "pärlbåtars": "pärlbåt",
    "pärlbåten": "pärlbåt",
    "pärlbåtens": "pärlbåt",
    "pärlbåts": "pärlbåt",
    "pärle": "pärla",
    "pärlemon": "pärlemo",
    "pärlemons": "pärlemo",
    "pärlemorfjärilar": "pärlemorfjäril",
    "pärlemorfjärilarna": "pärlemorfjäril",
    "pärlemorfjärilarnas": "pärlemorfjäril",
    "pärlemorfjärilars": "pärlemorfjäril",
    "pärlemorfjärilen": "pärlemorfjäril",
    "pärlemorfjärilens": "pärlemorfjäril",
    "pärlemorfjäriln": "pärlemorfjäril",
    "pärlemorfjärilns": "pärlemorfjäril",
    "pärlemorfjärils": "pärlemorfjäril",
    "pärlemormolnen": "pärlemormoln",
    "pärlemormolnens": "pärlemormoln",
    "pärlemormolnet": "pärlemormoln",
    "pärlemormolnets": "pärlemormoln",
    "pärlemormolns": "pärlemormoln",
    "pärlemorn": "pärlemor",
    "pärlemorns": "pärlemor",
    "pärlemors": "pärlemor",
    "pärlemos": "pärlemo",
    "pärlgarnet": "pärlgarn",
    "pärlgarnets": "pärlgarn",
    "pärlgarns": "pärlgarn",
    "pärlgrynen": "pärlgryn",
    "pärlgrynens": "pärlgryn",
    "pärlgrynet": "pärlgryn",
    "pärlgrynets": "pärlgryn",
    "pärlgryns": "pärlgryn",
    "pärlgråa": "pärlgrå",
    "pärlgråare": "pärlgrå",
    "pärlgråares": "pärlgrå",
    "pärlgråas": "pärlgrå",
    "pärlgråast": "pärlgrå",
    "pärlgråaste": "pärlgrå",
    "pärlgråastes": "pärlgrå",
    "pärlgråasts": "pärlgrå",
    "pärlgråe": "pärlgrå",
    "pärlgråes": "pärlgrå",
    "pärlgrås": "pärlgrå",
    "pärlgrått": "pärlgrå",
    "pärlgråtts": "pärlgrå",
    "pärlhalsbanden": "pärlhalsband",
    "pärlhalsbandens": "pärlhalsband",
    "pärlhalsbandet": "pärlhalsband",
    "pärlhalsbandets": "pärlhalsband",
    "pärlhalsbands": "pärlhalsband",
    "pärlhyacinten": "pärlhyacint",
    "pärlhyacintens": "pärlhyacint",
    "pärlhyacinter": "pärlhyacint",
    "pärlhyacinterna": "pärlhyacint",
    "pärlhyacinternas": "pärlhyacint",
    "pärlhyacinters": "pärlhyacint",
    "pärlhyacints": "pärlhyacint",
    "pärlhön": "pärlhöna",
    "pärlhönan": "pärlhöna",
    "pärlhönans": "pärlhöna",
    "pärlhönas": "pärlhöna",
    "pärlhöne": "pärlhöna",
    "pärlhönor": "pärlhöna",
    "pärlhönorna": "pärlhöna",
    "pärlhönornas": "pärlhöna",
    "pärlhönors": "pärlhöna",
    "pärlhöns": "pärlhöna",
    "pärlmussel": "pärlmussla",
    "pärlmusslan": "pärlmussla",
    "pärlmusslans": "pärlmussla",
    "pärlmusslas": "pärlmussla",
    "pärlmussle": "pärlmussla",
    "pärlmusslor": "pärlmussla",
    "pärlmusslorna": "pärlmussla",
    "pärlmusslornas": "pärlmussla",
    "pärlmusslors": "pärlmussla",
    "pärlor": "pärla",
    "pärlorna": "pärla",
    "pärlornas": "pärla",
    "pärlors": "pärla",
    "pärlplatt": "pärlplatta",
    "pärlplattan": "pärlplatta",
    "pärlplattans": "pärlplatta",
    "pärlplattas": "pärlplatta",
    "pärlplatte": "pärlplatta",
    "pärlplattor": "pärlplatta",
    "pärlplattorna": "pärlplatta",
    "pärlplattornas": "pärlplatta",
    "pärlplattors": "pärlplatta",
    "pärlplatts": "pärlplatta",
    "pärls": "pärla",
    "pärlsockers": "pärlsocker",
    "pärlsockret": "pärlsocker",
    "pärlsockrets": "pärlsocker",
    "pärlspontade": "pärlspontad",
    "pärlspontades": "pärlspontad",
    "pärlspontads": "pärlspontad",
    "pärlspontar": "pärlspont",
    "pärlspontarna": "pärlspont",
    "pärlspontarnas": "pärlspont",
    "pärlspontars": "pärlspont",
    "pärlspontat": "pärlspontad",
    "pärlspontats": "pärlspontad",
    "pärlsponten": "pärlspont",
    "pärlspontens": "pärlspont",
    "pärlsponts": "pärlspont",
    "pärlsponttaken": "pärlsponttak",
    "pärlsponttakens": "pärlsponttak",
    "pärlsponttaket": "pärlsponttak",
    "pärlsponttakets": "pärlsponttak",
    "pärlsponttaks": "pärlsponttak",
    "pärlstavar": "pärlstav",
    "pärlstavarna": "pärlstav",
    "pärlstavarnas": "pärlstav",
    "pärlstavars": "pärlstav",
    "pärlstaven": "pärlstav",
    "pärlstavens": "pärlstav",
    "pärlstavs": "pärlstav",
    "pärlstickningar": "pärlstickning",
    "pärlstickningarna": "pärlstickning",
    "pärlstickningarnas": "pärlstickning",
    "pärlstickningars": "pärlstickning",
    "pärlstickningen": "pärlstickning",
    "pärlstickningens": "pärlstickning",
    "pärlsticknings": "pärlstickning",
    "pärlugglan": "pärluggla",
    "pärlugglans": "pärluggla",
    "pärlugglas": "pärluggla",
    "pärluggle": "pärluggla",
    "pärlugglor": "pärluggla",
    "pärlugglorna": "pärluggla",
    "pärlugglornas": "pärluggla",
    "pärlugglors": "pärluggla",
    "pärmar": "pärm",
    "pärmarna": "pärm",
    "pärmarnas": "pärm",
    "pärmars": "pärm",
    "pärmbreven": "pärmbrev",
    "pärmbrevens": "pärmbrev",
    "pärmbrevet": "pärmbrev",
    "pärmbrevets": "pärmbrev",
    "pärmbrevs": "pärmbrev",
    "pärmebreven": "pärmebrev",
    "pärmebrevens": "pärmebrev",
    "pärmebrevet": "pärmebrev",
    "pärmebrevets": "pärmebrev",
    "pärmebrevs": "pärmebrev",
    "pärmen": "pärm",
    "pärmens": "pärm",
    "pärmkarusellen": "pärmkarusell",
    "pärmkarusellens": "pärmkarusell",
    "pärmkaruseller": "pärmkarusell",
    "pärmkarusellerna": "pärmkarusell",
    "pärmkarusellernas": "pärmkarusell",
    "pärmkarusellers": "pärmkarusell",
    "pärmkarusells": "pärmkarusell",
    "pärms": "pärm",
    "pärmslukar": "pärmslukare",
    "pärmslukaren": "pärmslukare",
    "pärmslukarens": "pärmslukare",
    "pärmslukares": "pärmslukare",
    "pärmslukarna": "pärmslukare",
    "pärmslukarnas": "pärmslukare",
    "päronen": "päron",
    "päronens": "päron",
    "päronet": "päron",
    "päronets": "päron",
    "pärons": "päron",
    "päronskivan": "päronskiva",
    "päronskivans": "päronskiva",
    "päronskivas": "päronskiva",
    "päronskive": "päronskiva",
    "päronskivor": "päronskiva",
    "päronskivorna": "päronskiva",
    "päronskivornas": "päronskiva",
    "päronskivors": "päronskiva",
    "pärsar": "pärs",
    "pärsarna": "pärs",
    "pärsarnas": "pärs",
    "pärsars": "pärs",
    "pärsen": "pärs",
    "pärsens": "pärs",
    "pärser": "pärs",
    "pärserna": "pärs",
    "pärsernas": "pärs",
    "pärsers": "pärs",
    "pärt": "pärta",
    "pärtan": "pärta",
    "pärtans": "pärta",
    "pärtas": "pärta",
    "pärte": "pärta",
    "pärten": "pärt",
    "pärtens": "pärt",
    "pärter": "pärt",
    "pärterna": "pärt",
    "pärternas": "pärt",
    "pärters": "pärt",
    "pärtor": "pärta",
    "pärtorna": "pärta",
    "pärtornas": "pärta",
    "pärtors": "pärta",
    "pärts": "pärta",
    "päskar": "päsk",
    "päskarna": "päsk",
    "päskarnas": "päsk",
    "päskars": "päsk",
    "päsken": "päsk",
    "päskens": "päsk",
    "päsks": "päsk",
    "påad": "påa",
    "påade": "påa",
    "påades": "påa",
    "påads": "påa",
    "påan": "påa",
    "påande": "påa",
    "påanden": "påande",
    "påandena": "påande",
    "påandenas": "påande",
    "påandens": "påande",
    "påandes": "påande",
    "påandet": "påande",
    "påandets": "påande",
    "påannonsen": "påannons",
    "påannonsens": "påannons",
    "påannonser": "påannons",
    "påannonserad": "påannonsera",
    "påannonserade": "påannonsera",
    "påannonserades": "påannonsera",
    "påannonserads": "påannonsera",
    "påannonserande": "påannonsera",
    "påannonseranden": "påannonserande",
    "påannonserandena": "påannonserande",
    "påannonserandenas": "påannonserande",
    "påannonserandens": "påannonserande",
    "påannonserandes": "påannonserande",
    "påannonserandet": "påannonserande",
    "påannonserandets": "påannonserande",
    "påannonserar": "påannonsera",
    "påannonseras": "påannonsera",
    "påannonserat": "påannonsera",
    "påannonserats": "påannonsera",
    "påannonserbara": "påannonserbar",
    "påannonserbarare": "påannonserbar",
    "påannonserbarares": "påannonserbar",
    "påannonserbaras": "påannonserbar",
    "påannonserbarast": "påannonserbar",
    "påannonserbaraste": "påannonserbar",
    "påannonserbarastes": "påannonserbar",
    "påannonserbarasts": "påannonserbar",
    "påannonserbare": "påannonserbar",
    "påannonserbares": "påannonserbar",
    "påannonserbarheten": "påannonserbarhet",
    "påannonserbarhetens": "påannonserbarhet",
    "påannonserbarhets": "påannonserbarhet",
    "påannonserbars": "påannonserbar",
    "påannonserbart": "påannonserbar",
    "påannonserbarts": "påannonserbar",
    "påannonseringar": "påannonsering",
    "påannonseringarna": "påannonsering",
    "påannonseringarnas": "påannonsering",
    "påannonseringars": "påannonsering",
    "påannonseringen": "påannonsering",
    "påannonseringens": "påannonsering",
    "påannonserings": "påannonsering",
    "påannonserna": "påannons",
    "påannonsernas": "påannons",
    "påannonsers": "påannons",
    "påans": "påa",
    "påar": "påa",
    "påas": "påa",
    "påat": "påa",
    "påats": "påa",
    "påbackningar": "påbackning",
    "påbackningarna": "påbackning",
    "påbackningarnas": "påbackning",
    "påbackningars": "påbackning",
    "påbackningen": "påbackning",
    "påbackningens": "påbackning",
    "påbacknings": "påbackning",
    "påbjud": "påbjuda",
    "påbjudande": "påbjuda",
    "påbjudanden": "påbjudande",
    "påbjudandena": "påbjudande",
    "påbjudandenas": "påbjudande",
    "påbjudandens": "påbjudande",
    "påbjudandes": "påbjudande",
    "påbjudandet": "påbjudande",
    "påbjudandets": "påbjudande",
    "påbjudas": "påbjuda",
    "påbjude": "påbjuda",
    "påbjuden": "påbjuda",
    "påbjudens": "påbjuda",
    "påbjuder": "påbjuda",
    "påbjudes": "påbjuda",
    "påbjudet": "påbjuda",
    "påbjudets": "påbjuda",
    "påbjudit": "påbjuda",
    "påbjudits": "påbjuda",
    "påbjudna": "påbjuda",
    "påbjudnas": "påbjuda",
    "påbjudne": "påbjuda",
    "påbjudnes": "påbjuda",
    "påbjuds": "påbjuda",
    "påbjöd": "påbjuda",
    "påbjöde": "påbjuda",
    "påbjödes": "påbjuda",
    "påbjöds": "påbjuda",
    "påbrået": "påbrå",
    "påbråets": "påbrå",
    "påbrås": "påbrå",
    "påbråt": "påbrå",
    "påbråts": "påbrå",
    "påbrödet": "påbröd",
    "påbrödets": "påbröd",
    "påbröds": "påbröd",
    "påbuden": "påbud",
    "påbudens": "påbud",
    "påbudet": "påbud",
    "påbudets": "påbud",
    "påbuds": "påbud",
    "påbyggnaden": "påbyggnad",
    "påbyggnadens": "påbyggnad",
    "påbyggnader": "påbyggnad",
    "påbyggnaderna": "påbyggnad",
    "påbyggnadernas": "påbyggnad",
    "påbyggnaders": "påbyggnad",
    "påbyggnads": "påbyggnad",
    "påbördad": "påbörda",
    "påbördade": "påbörda",
    "påbördades": "påbörda",
    "påbördads": "påbörda",
    "påbördande": "påbörda",
    "påbördanden": "påbördande",
    "påbördandena": "påbördande",
    "påbördandenas": "påbördande",
    "påbördandens": "påbördande",
    "påbördandes": "påbördande",
    "påbördandet": "påbördande",
    "påbördandets": "påbördande",
    "påbördar": "påbörda",
    "påbördas": "påbörda",
    "påbördat": "påbörda",
    "påbördats": "påbörda",
    "påbörjad": "påbörja",
    "påbörjade": "påbörja",
    "påbörjades": "påbörja",
    "påbörjads": "påbörja",
    "påbörjande": "påbörja",
    "påbörjanden": "påbörjande",
    "påbörjandena": "påbörjande",
    "påbörjandenas": "påbörjande",
    "påbörjandens": "påbörjande",
    "påbörjandes": "påbörjande",
    "påbörjandet": "påbörjande",
    "påbörjandets": "påbörjande",
    "påbörjar": "påbörja",
    "påbörjas": "påbörja",
    "påbörjat": "påbörja",
    "påbörjats": "påbörja",
    "pådragen": "pådrag",
    "pådragens": "pådrag",
    "pådraget": "pådrag",
    "pådragets": "pådrag",
    "pådrags": "pådrag",
    "pådrivar": "pådrivare",
    "pådrivaren": "pådrivare",
    "pådrivarens": "pådrivare",
    "pådrivares": "pådrivare",
    "pådrivarna": "pådrivare",
    "pådrivarnas": "pådrivare",
    "pådyvlad": "pådyvla",
    "pådyvlade": "pådyvla",
    "pådyvlades": "pådyvla",
    "pådyvlads": "pådyvla",
    "pådyvlande": "pådyvla",
    "pådyvlanden": "pådyvlande",
    "pådyvlandena": "pådyvlande",
    "pådyvlandenas": "pådyvlande",
    "pådyvlandens": "pådyvlande",
    "pådyvlandes": "pådyvlande",
    "pådyvlandet": "pådyvlande",
    "pådyvlandets": "pådyvlande",
    "pådyvlar": "pådyvla",
    "pådyvlas": "pådyvla",
    "pådyvlat": "pådyvla",
    "pådyvlats": "pådyvla",
    "påfarten": "påfart",
    "påfartens": "påfart",
    "påfarter": "påfart",
    "påfarterna": "påfart",
    "påfarternas": "påfart",
    "påfarters": "påfart",
    "påfarts": "påfart",
    "påflugens": "påflugen",
    "påfluget": "påflugen",
    "påflugets": "påflugen",
    "påflugna": "påflugen",
    "påflugnare": "påflugen",
    "påflugnares": "påflugen",
    "påflugnas": "påflugen",
    "påflugnast": "påflugen",
    "påflugnaste": "påflugen",
    "påflugnastes": "påflugen",
    "påflugnasts": "påflugen",
    "påflugne": "påflugen",
    "påflugnes": "påflugen",
    "påfordrad": "påfordra",
    "påfordrade": "påfordra",
    "påfordrades": "påfordra",
    "påfordrads": "påfordra",
    "påfordrande": "påfordra",
    "påfordranden": "påfordrande",
    "påfordrandena": "påfordrande",
    "påfordrandenas": "påfordrande",
    "påfordrandens": "påfordrande",
    "påfordrandes": "påfordrande",
    "påfordrandet": "påfordrande",
    "påfordrandets": "påfordrande",
    "påfordrar": "påfordra",
    "påfordras": "påfordra",
    "påfordrat": "påfordra",
    "påfordrats": "påfordra",
    "påfrestningar": "påfrestning",
    "påfrestningarna": "påfrestning",
    "påfrestningarnas": "påfrestning",
    "påfrestningars": "påfrestning",
    "påfrestningen": "påfrestning",
    "påfrestningens": "påfrestning",
    "påfrestnings": "påfrestning",
    "påfunden": "påfund",
    "påfundens": "påfund",
    "påfundet": "påfund",
    "påfundets": "påfund",
    "påfunds": "påfund",
    "påfyllnadsförpackningar": "påfyllnadsförpackning",
    "påfyllnadsförpackningarna": "påfyllnadsförpackning",
    "påfyllnadsförpackningarnas": "påfyllnadsförpackning",
    "påfyllnadsförpackningars": "påfyllnadsförpackning",
    "påfyllnadsförpackningen": "påfyllnadsförpackning",
    "påfyllnadsförpackningens": "påfyllnadsförpackning",
    "påfyllnadsförpacknings": "påfyllnadsförpackning",
    "påfyllningar": "påfyllning",
    "påfyllningarna": "påfyllning",
    "påfyllningarnas": "påfyllning",
    "påfyllningars": "påfyllning",
    "påfyllningen": "påfyllning",
    "påfyllningens": "påfyllning",
    "påfyllnings": "påfyllning",
    "påfyllningspipar": "påfyllningspip",
    "påfyllningspiparna": "påfyllningspip",
    "påfyllningspiparnas": "påfyllningspip",
    "påfyllningspipars": "påfyllningspip",
    "påfyllningspipen": "påfyllningspip",
    "påfyllningspipens": "påfyllningspip",
    "påfyllningspips": "påfyllningspip",
    "påfågeln": "påfågel",
    "påfågelns": "påfågel",
    "påfågels": "påfågel",
    "påfågelsögas": "påfågelsöga",
    "påfågelsögat": "påfågelsöga",
    "påfågelsögats": "påfågelsöga",
    "påfågelsögon": "påfågelsöga",
    "påfågelsögonen": "påfågelsöga",
    "påfågelsögonens": "påfågelsöga",
    "påfågelsögons": "påfågelsöga",
    "påfågelögas": "påfågelöga",
    "påfågelögat": "påfågelöga",
    "påfågelögats": "påfågelöga",
    "påfågelögon": "påfågelöga",
    "påfågelögonen": "påfågelöga",
    "påfågelögonens": "påfågelöga",
    "påfågelögons": "påfågelöga",
    "påfåglar": "påfågel",
    "påfåglarna": "påfågel",
    "påfåglarnas": "påfågel",
    "påfåglars": "påfågel",
    "påföljden": "påföljd",
    "påföljdens": "påföljd",
    "påföljder": "påföljd",
    "påföljderna": "påföljd",
    "påföljdernas": "påföljd",
    "påföljders": "påföljd",
    "påföljds": "påföljd",
    "påför": "påföra",
    "påförande": "påföra",
    "påföranden": "påförande",
    "påförandena": "påförande",
    "påförandenas": "påförande",
    "påförandens": "påförande",
    "påförandes": "påförande",
    "påförandet": "påförande",
    "påförandets": "påförande",
    "påföras": "påföra",
    "påförd": "påföra",
    "påförda": "påföra",
    "påfördas": "påföra",
    "påförde": "påföra",
    "påfördes": "påföra",
    "påförds": "påföra",
    "påföres": "påföra",
    "påförs": "påföra",
    "påfört": "påföra",
    "påförts": "påföra",
    "pågar": "påg",
    "pågarna": "påg",
    "pågarnas": "påg",
    "pågars": "påg",
    "pågen": "påg",
    "pågens": "påg",
    "pågick": "pågå",
    "pågicks": "pågå",
    "påginge": "pågå",
    "påginges": "pågå",
    "pågs": "påg",
    "pågående": "pågå",
    "pågåenden": "pågående",
    "pågåendena": "pågående",
    "pågåendenas": "pågående",
    "pågåendens": "pågående",
    "pågåendes": "pågående",
    "pågåendet": "pågående",
    "pågåendets": "pågående",
    "pågår": "pågå",
    "pågås": "pågå",
    "pågått": "pågå",
    "pågåtts": "pågå",
    "påhittade": "påhittad",
    "påhittades": "påhittad",
    "påhittads": "påhittad",
    "påhittat": "påhittad",
    "påhittats": "påhittad",
    "påhitten": "påhitt",
    "påhittens": "påhitt",
    "påhittet": "påhitt",
    "påhittets": "påhitt",
    "påhittiga": "påhittig",
    "påhittigare": "påhittig",
    "påhittigares": "påhittig",
    "påhittigas": "påhittig",
    "påhittigast": "påhittig",
    "påhittigaste": "påhittig",
    "påhittigastes": "påhittig",
    "påhittigasts": "påhittig",
    "påhittige": "påhittig",
    "påhittiges": "påhittig",
    "påhittigheten": "påhittighet",
    "påhittighetens": "påhittighet",
    "påhittigheter": "påhittighet",
    "påhittigheterna": "påhittighet",
    "påhittigheternas": "påhittighet",
    "påhittigheters": "påhittighet",
    "påhittighets": "påhittighet",
    "påhittigs": "påhittig",
    "påhittigt": "påhittig",
    "påhittigts": "påhittig",
    "påhitts": "påhitt",
    "påhoppen": "påhopp",
    "påhoppens": "påhopp",
    "påhoppet": "påhopp",
    "påhoppets": "påhopp",
    "påhopps": "påhopp",
    "påhuggen": "påhugg",
    "påhuggens": "påhugg",
    "påhugget": "påhugg",
    "påhuggets": "påhugg",
    "påhuggs": "påhugg",
    "påhälsningar": "påhälsning",
    "påhälsningarna": "påhälsning",
    "påhälsningarnas": "påhälsning",
    "påhälsningars": "påhälsning",
    "påhälsningen": "påhälsning",
    "påhälsningens": "påhälsning",
    "påhälsnings": "påhälsning",
    "påhänget": "påhäng",
    "påhängets": "påhäng",
    "påhängs": "påhäng",
    "påhängsvagnar": "påhängsvagn",
    "påhängsvagnarna": "påhängsvagn",
    "påhängsvagnarnas": "påhängsvagn",
    "påhängsvagnars": "påhängsvagn",
    "påhängsvagnen": "påhängsvagn",
    "påhängsvagnens": "påhängsvagn",
    "påhängsvagns": "påhängsvagn",
    "påkall": "påkalla",
    "påkallad": "påkalla",
    "påkallade": "påkalla",
    "påkallades": "påkalla",
    "påkallads": "påkalla",
    "påkallande": "påkalla",
    "påkallanden": "påkallande",
    "påkallandena": "påkallande",
    "påkallandenas": "påkallande",
    "påkallandens": "påkallande",
    "påkallandes": "påkallande",
    "påkallandet": "påkallande",
    "påkallandets": "påkallande",
    "påkallar": "påkalla",
    "påkallas": "påkalla",
    "påkallat": "påkalla",
    "påkallats": "påkalla",
    "påkar": "påk",
    "påkarna": "påk",
    "påkarnas": "påk",
    "påkars": "påk",
    "påken": "påk",
    "påkens": "påk",
    "påklädar": "påklädare",
    "påklädaren": "påklädare",
    "påklädarens": "påklädare",
    "påklädares": "påklädare",
    "påklädarna": "påklädare",
    "påklädarnas": "påklädare",
    "påklädda": "påklädd",
    "påkläddare": "påklädd",
    "påkläddares": "påklädd",
    "påkläddas": "påklädd",
    "påkläddast": "påklädd",
    "påkläddaste": "påklädd",
    "påkläddastes": "påklädd",
    "påkläddasts": "påklädd",
    "påklädde": "påklädd",
    "påkläddes": "påklädd",
    "påkläddheten": "påkläddhet",
    "påkläddhetens": "påkläddhet",
    "påkläddhets": "påkläddhet",
    "påklädds": "påklädd",
    "påklädningen": "påklädning",
    "påklädningens": "påklädning",
    "påklädnings": "påklädning",
    "påklädningsrummen": "påklädningsrum",
    "påklädningsrummens": "påklädningsrum",
    "påklädningsrummet": "påklädningsrum",
    "påklädningsrummets": "påklädningsrum",
    "påklädningsrums": "påklädningsrum",
    "påklätt": "påklädd",
    "påklätts": "påklädd",
    "påkommens": "påkommen",
    "påkommet": "påkommen",
    "påkommets": "påkommen",
    "påkomna": "påkommen",
    "påkomnare": "påkommen",
    "påkomnares": "påkommen",
    "påkomnas": "påkommen",
    "påkomnast": "påkommen",
    "påkomnaste": "påkommen",
    "påkomnastes": "påkommen",
    "påkomnasts": "påkommen",
    "påkomne": "påkommen",
    "påkomnes": "påkommen",
    "påkostade": "påkostad",
    "påkostades": "påkostad",
    "påkostads": "påkostad",
    "påkostat": "påkostad",
    "påkostats": "påkostad",
    "påks": "påk",
    "påkänningar": "påkänning",
    "påkänningarna": "påkänning",
    "påkänningarnas": "påkänning",
    "påkänningars": "påkänning",
    "påkänningen": "påkänning",
    "påkänningens": "påkänning",
    "påkännings": "påkänning",
    "påkörningar": "påkörning",
    "påkörningarna": "påkörning",
    "påkörningarnas": "påkörning",
    "påkörningars": "påkörning",
    "påkörningen": "påkörning",
    "påkörningens": "påkörning",
    "påkörnings": "påkörning",
    "pål": "påle",
    "påla": "pålägga",
    "pålad": "påla",
    "pålade": "pålägga",
    "pålades": "pålägga",
    "pålads": "påla",
    "pålag": "pålaga",
    "pålagan": "pålaga",
    "pålagans": "pålaga",
    "pålagas": "pålaga",
    "pålagd": "pålägga",
    "pålagda": "pålägga",
    "pålagdas": "pålägga",
    "pålagde": "pålägga",
    "pålagdes": "pålägga",
    "pålagds": "pålägga",
    "pålage": "pålaga",
    "pålagor": "pålaga",
    "pålagorna": "pålaga",
    "pålagornas": "pålaga",
    "pålagors": "pålaga",
    "pålags": "pålaga",
    "pålagt": "pålägga",
    "pålagts": "pålägga",
    "pålande": "påla",
    "pålanden": "pålande",
    "pålandena": "pålande",
    "pålandenas": "pålande",
    "pålandens": "pålande",
    "pålandes": "pålande",
    "pålandet": "pålande",
    "pålandets": "pålande",
    "pålandsvindar": "pålandsvind",
    "pålandsvindarna": "pålandsvind",
    "pålandsvindarnas": "pålandsvind",
    "pålandsvindars": "pålandsvind",
    "pålandsvinden": "pålandsvind",
    "pålandsvindens": "pålandsvind",
    "pålandsvinds": "pålandsvind",
    "pålar": "påle",
    "pålarna": "påle",
    "pålarnas": "påle",
    "pålars": "påle",
    "pålas": "pålägga",
    "pålat": "påla",
    "pålats": "påla",
    "pålen": "påle",
    "pålens": "påle",
    "påles": "påle",
    "pålitliga": "pålitlig",
    "pålitligare": "pålitlig",
    "pålitligares": "pålitlig",
    "pålitligas": "pålitlig",
    "pålitligast": "pålitlig",
    "pålitligaste": "pålitlig",
    "pålitligastes": "pålitlig",
    "pålitligasts": "pålitlig",
    "pålitlige": "pålitlig",
    "pålitliges": "pålitlig",
    "pålitligheten": "pålitlighet",
    "pålitlighetens": "pålitlighet",
    "pålitlighets": "pålitlighet",
    "pålitligs": "pålitlig",
    "pålitligt": "pålitlig",
    "pålitligts": "pålitlig",
    "pålkranar": "pålkran",
    "pålkranarna": "pålkran",
    "pålkranarnas": "pålkran",
    "pålkranars": "pålkran",
    "pålkranen": "pålkran",
    "pålkranens": "pålkran",
    "pålkrans": "pålkran",
    "pållar": "pålle",
    "pållarna": "pålle",
    "pållarnas": "pålle",
    "pållars": "pålle",
    "pållen": "pålle",
    "pållens": "pålle",
    "pålles": "pålle",
    "pålmasten": "pålmast",
    "pålmastens": "pålmast",
    "pålmaster": "pålmast",
    "pålmasterna": "pålmast",
    "pålmasternas": "pålmast",
    "pålmasters": "pålmast",
    "pålmasts": "pålmast",
    "pålroten": "pålrot",
    "pålrotens": "pålrot",
    "pålrots": "pålrot",
    "pålrötter": "pålrot",
    "pålrötterna": "pålrot",
    "pålrötternas": "pålrot",
    "pålrötters": "pålrot",
    "påls": "påle",
    "pålsteken": "pålstek",
    "pålstekens": "pålstek",
    "pålsteket": "pålstek",
    "pålstekets": "pålstek",
    "pålsteks": "pålstek",
    "pålägg": "pålägga",
    "påläggande": "pålägga",
    "pålägganden": "påläggande",
    "påläggandena": "påläggande",
    "påläggandenas": "påläggande",
    "påläggandens": "påläggande",
    "påläggandes": "påläggande",
    "påläggandet": "påläggande",
    "påläggandets": "påläggande",
    "påläggas": "pålägga",
    "påläggen": "pålägg",
    "påläggens": "pålägg",
    "pålägger": "pålägga",
    "pålägges": "pålägga",
    "pålägget": "pålägg",
    "påläggets": "pålägg",
    "påläggs": "pålägga",
    "påläggskalvar": "påläggskalv",
    "påläggskalvarna": "påläggskalv",
    "påläggskalvarnas": "påläggskalv",
    "påläggskalvars": "påläggskalv",
    "påläggskalven": "påläggskalv",
    "påläggskalvens": "påläggskalv",
    "påläggskalvs": "påläggskalv",
    "pålöd": "pålöda",
    "pålödande": "pålöda",
    "pålödanden": "pålödande",
    "pålödandena": "pålödande",
    "pålödandenas": "pålödande",
    "pålödandens": "pålödande",
    "pålödandes": "pålödande",
    "pålödandet": "pålödande",
    "pålödandets": "pålödande",
    "pålödas": "pålöda",
    "pålödd": "pålöda",
    "pålödda": "pålöda",
    "pålöddas": "pålöda",
    "pålödde": "pålöda",
    "pålöddes": "pålöda",
    "pålödds": "pålöda",
    "pålöder": "pålöda",
    "pålödes": "pålöda",
    "pålöds": "pålöda",
    "pålött": "pålöda",
    "pålötts": "pålöda",
    "påmind": "påminna",
    "påminda": "påminna",
    "påmindas": "påminna",
    "påminde": "påminna",
    "påmindes": "påminna",
    "påminds": "påminna",
    "påminn": "påminna",
    "påminnande": "påminna",
    "påminnanden": "påminnande",
    "påminnandena": "påminnande",
    "påminnandenas": "påminnande",
    "påminnandens": "påminnande",
    "påminnandes": "påminnande",
    "påminnandet": "påminnande",
    "påminnandets": "påminnande",
    "påminnas": "påminna",
    "påminnelsen": "påminnelse",
    "påminnelsens": "påminnelse",
    "påminnelser": "påminnelse",
    "påminnelserna": "påminnelse",
    "påminnelsernas": "påminnelse",
    "påminnelsers": "påminnelse",
    "påminnelses": "påminnelse",
    "påminner": "påminna",
    "påminnes": "påminna",
    "påminns": "påminna",
    "påmint": "påminna",
    "påmints": "påminna",
    "pånyttföd": "pånyttföda",
    "pånyttfödande": "pånyttföda",
    "pånyttfödanden": "pånyttfödande",
    "pånyttfödandena": "pånyttfödande",
    "pånyttfödandenas": "pånyttfödande",
    "pånyttfödandens": "pånyttfödande",
    "pånyttfödandes": "pånyttfödande",
    "pånyttfödandet": "pånyttfödande",
    "pånyttfödandets": "pånyttfödande",
    "pånyttfödas": "pånyttföda",
    "pånyttfödd": "pånyttföda",
    "pånyttfödda": "pånyttföda",
    "pånyttföddas": "pånyttföda",
    "pånyttfödde": "pånyttföda",
    "pånyttföddes": "pånyttföda",
    "pånyttfödds": "pånyttföda",
    "pånyttföder": "pånyttföda",
    "pånyttfödes": "pånyttföda",
    "pånyttföds": "pånyttföda",
    "pånyttfött": "pånyttföda",
    "pånyttfötts": "pånyttföda",
    "påor": "påa",
    "påorna": "påa",
    "påornas": "påa",
    "påors": "påa",
    "påpassade": "påpassad",
    "påpassades": "påpassad",
    "påpassads": "påpassad",
    "påpassat": "påpassad",
    "påpassats": "påpassad",
    "påpassliga": "påpasslig",
    "påpassligare": "påpasslig",
    "påpassligares": "påpasslig",
    "påpassligas": "påpasslig",
    "påpassligast": "påpasslig",
    "påpassligaste": "påpasslig",
    "påpassligastes": "påpasslig",
    "påpassligasts": "påpasslig",
    "påpasslige": "påpasslig",
    "påpassliges": "påpasslig",
    "påpassligheten": "påpasslighet",
    "påpasslighetens": "påpasslighet",
    "påpasslighets": "påpasslighet",
    "påpassligs": "påpasslig",
    "påpassligt": "påpasslig",
    "påpassligts": "påpasslig",
    "påpek": "påpeka",
    "påpekad": "påpeka",
    "påpekade": "påpeka",
    "påpekades": "påpeka",
    "påpekads": "påpeka",
    "påpekande": "påpeka",
    "påpekanden": "påpekande",
    "påpekandena": "påpekande",
    "påpekandenas": "påpekande",
    "påpekandens": "påpekande",
    "påpekandes": "påpekande",
    "påpekandet": "påpekande",
    "påpekandets": "påpekande",
    "påpekar": "påpeka",
    "påpekas": "påpeka",
    "påpekat": "påpeka",
    "påpekats": "påpeka",
    "påpälsade": "påpälsad",
    "påpälsades": "påpälsad",
    "påpälsads": "påpälsad",
    "påpälsat": "påpälsad",
    "påpälsats": "påpälsad",
    "påringningar": "påringning",
    "påringningarna": "påringning",
    "påringningarnas": "påringning",
    "påringningars": "påringning",
    "påringningen": "påringning",
    "påringningens": "påringning",
    "påringnings": "påringning",
    "påropad": "påropa",
    "påropade": "påropa",
    "påropades": "påropa",
    "påropads": "påropa",
    "påropande": "påropa",
    "påropanden": "påropande",
    "påropandena": "påropande",
    "påropandenas": "påropande",
    "påropandens": "påropande",
    "påropandes": "påropande",
    "påropandet": "påropande",
    "påropandets": "påropande",
    "påropar": "påropa",
    "påropas": "påropa",
    "påropat": "påropa",
    "påropats": "påropa",
    "påropen": "pårop",
    "påropens": "pårop",
    "påropet": "pårop",
    "påropets": "pårop",
    "pårops": "pårop",
    "påräkn": "påräkna",
    "påräknad": "påräkna",
    "påräknade": "påräkna",
    "påräknades": "påräkna",
    "påräknads": "påräkna",
    "påräknande": "påräkna",
    "påräknanden": "påräknande",
    "påräknandena": "påräknande",
    "påräknandenas": "påräknande",
    "påräknandens": "påräknande",
    "påräknandes": "påräknande",
    "påräknandet": "påräknande",
    "påräknandets": "påräknande",
    "påräknar": "påräkna",
    "påräknas": "påräkna",
    "påräknat": "påräkna",
    "påräknats": "påräkna",
    "pås": "påse",
    "påsar": "påse",
    "påsarna": "påse",
    "påsarnas": "påse",
    "påsars": "påse",
    "påseendes": "påseende",
    "påseendet": "påseende",
    "påseendets": "påseende",
    "påselade": "påselad",
    "påselades": "påselad",
    "påselads": "påselad",
    "påselat": "påselad",
    "påselats": "påselad",
    "påsen": "påse",
    "påsens": "påse",
    "påses": "påse",
    "påsiga": "påsig",
    "påsigare": "påsig",
    "påsigares": "påsig",
    "påsigas": "påsig",
    "påsigast": "påsig",
    "påsigaste": "påsig",
    "påsigastes": "påsig",
    "påsigasts": "påsig",
    "påsige": "påsig",
    "påsiges": "påsig",
    "påsigs": "påsig",
    "påsigt": "påsig",
    "påsigts": "påsig",
    "påskaftnar": "påskafton",
    "påskaftnarna": "påskafton",
    "påskaftnarnas": "påskafton",
    "påskaftnars": "påskafton",
    "påskaftonen": "påskafton",
    "påskaftonens": "påskafton",
    "påskaftons": "påskafton",
    "påskalammen": "påskalamm",
    "påskalammens": "påskalamm",
    "påskalammet": "påskalamm",
    "påskalammets": "påskalamm",
    "påskalamms": "påskalamm",
    "påskar": "påsk",
    "påskarna": "påsk",
    "påskarnas": "påsk",
    "påskars": "påsk",
    "påskdagar": "påskdag",
    "påskdagarna": "påskdag",
    "påskdagarnas": "påskdag",
    "påskdagars": "påskdag",
    "påskdagen": "påskdag",
    "påskdagens": "påskdag",
    "påskdags": "påskdag",
    "påskeldar": "påskeld",
    "påskeldarna": "påskeld",
    "påskeldarnas": "påskeld",
    "påskeldars": "påskeld",
    "påskelden": "påskeld",
    "påskeldens": "påskeld",
    "påskelds": "påskeld",
    "påsken": "påskina",
    "påskens": "påskina",
    "påskhar": "påskhare",
    "påskharar": "påskhare",
    "påskhararna": "påskhare",
    "påskhararnas": "påskhare",
    "påskharars": "påskhare",
    "påskharen": "påskhare",
    "påskharens": "påskhare",
    "påskhares": "påskhare",
    "påskhars": "påskhare",
    "påskin": "påskina",
    "påskinande": "påskina",
    "påskinanden": "påskinande",
    "påskinandena": "påskinande",
    "påskinandenas": "påskinande",
    "påskinandens": "påskinande",
    "påskinandes": "påskinande",
    "påskinandet": "påskinande",
    "påskinandets": "påskinande",
    "påskinas": "påskina",
    "påskine": "påskina",
    "påskiner": "påskina",
    "påskines": "påskina",
    "påskinit": "påskina",
    "påskinits": "påskina",
    "påskins": "påskina",
    "påskkäringar": "påskkäring",
    "påskkäringarna": "påskkäring",
    "påskkäringarnas": "påskkäring",
    "påskkäringars": "påskkäring",
    "påskkäringen": "påskkäring",
    "påskkäringens": "påskkäring",
    "påskkärings": "påskkäring",
    "påskkärringar": "påskkärring",
    "påskkärringarna": "påskkärring",
    "påskkärringarnas": "påskkärring",
    "påskkärringars": "påskkärring",
    "påskkärringen": "påskkärring",
    "påskkärringens": "påskkärring",
    "påskkärrings": "påskkärring",
    "påsklediga": "påskledig",
    "påskledigare": "påskledig",
    "påskledigares": "påskledig",
    "påskledigas": "påskledig",
    "påskledigast": "påskledig",
    "påskledigaste": "påskledig",
    "påskledigastes": "påskledig",
    "påskledigasts": "påskledig",
    "påskledige": "påskledig",
    "påsklediges": "påskledig",
    "påskledigheten": "påskledighet",
    "påskledighetens": "påskledighet",
    "påskledighets": "påskledighet",
    "påskledigs": "påskledig",
    "påskledigt": "påskledig",
    "påskledigts": "påskledig",
    "påskliljan": "påsklilja",
    "påskliljans": "påsklilja",
    "påskliljas": "påsklilja",
    "påsklilje": "påsklilja",
    "påskliljor": "påsklilja",
    "påskliljorna": "påsklilja",
    "påskliljornas": "påsklilja",
    "påskliljors": "påsklilja",
    "påskriften": "påskrift",
    "påskriftens": "påskrift",
    "påskrifter": "påskrift",
    "påskrifterna": "påskrift",
    "påskrifternas": "påskrift",
    "påskrifters": "påskrift",
    "påskrifts": "påskrift",
    "påskriset": "påskris",
    "påskrisets": "påskris",
    "påsks": "påsk",
    "påsksmällar": "påsksmäll",
    "påsksmällarna": "påsksmäll",
    "påsksmällarnas": "påsksmäll",
    "påsksmällars": "påsksmäll",
    "påsksmällen": "påsksmäll",
    "påsksmällens": "påsksmäll",
    "påsksmälls": "påsksmäll",
    "påskveck": "påskvecka",
    "påskveckan": "påskvecka",
    "påskveckans": "påskvecka",
    "påskveckas": "påskvecka",
    "påskvecke": "påskvecka",
    "påskvecko": "påskvecka",
    "påskveckor": "påskvecka",
    "påskveckorna": "påskvecka",
    "påskveckornas": "påskvecka",
    "påskveckors": "påskvecka",
    "påskvecks": "påskvecka",
    "påskynd": "påskynda",
    "påskyndad": "påskynda",
    "påskyndade": "påskynda",
    "påskyndades": "påskynda",
    "påskyndads": "påskynda",
    "påskyndande": "påskynda",
    "påskyndanden": "påskyndande",
    "påskyndandena": "påskyndande",
    "påskyndandenas": "påskyndande",
    "påskyndandens": "påskyndande",
    "påskyndandes": "påskyndande",
    "påskyndandet": "påskyndande",
    "påskyndandets": "påskyndande",
    "påskyndar": "påskynda",
    "påskyndas": "påskynda",
    "påskyndat": "påskynda",
    "påskyndats": "påskynda",
    "påskäggen": "påskägg",
    "påskäggens": "påskägg",
    "påskägget": "påskägg",
    "påskäggets": "påskägg",
    "påskäggs": "påskägg",
    "påslagen": "påslag",
    "påslagens": "påslag",
    "påslaget": "påslag",
    "påslagets": "påslag",
    "påslags": "påslag",
    "påslakanen": "påslakan",
    "påslakanens": "påslakan",
    "påslakanet": "påslakan",
    "påslakanets": "påslakan",
    "påslakans": "påslakan",
    "påspäd": "påspä",
    "påspäda": "påspä",
    "påspädande": "påspä",
    "påspädanden": "påspädande",
    "påspädandena": "påspädande",
    "påspädandenas": "påspädande",
    "påspädandens": "påspädande",
    "påspädandes": "påspädande",
    "påspädandet": "påspädande",
    "påspädandets": "påspädande",
    "påspädas": "påspä",
    "påspädd": "påspä",
    "påspädda": "påspä",
    "påspäddas": "påspä",
    "påspädde": "påspä",
    "påspäddes": "påspä",
    "påspädds": "påspä",
    "påspäder": "påspä",
    "påspäds": "påspä",
    "påspäende": "påspä",
    "påspäenden": "påspäende",
    "påspäendena": "påspäende",
    "påspäendenas": "påspäende",
    "påspäendens": "påspäende",
    "påspäendes": "påspäende",
    "påspäendet": "påspäende",
    "påspäendets": "påspäende",
    "påspär": "påspä",
    "påspäs": "påspä",
    "påspätt": "påspä",
    "påspätts": "påspä",
    "påssjukan": "påssjuka",
    "påssjukans": "påssjuka",
    "påssjukas": "påssjuka",
    "påssjuke": "påssjuka",
    "påssjuks": "påssjuka",
    "påstod": "påstå",
    "påstode": "påstå",
    "påstodes": "påstå",
    "påstods": "påstå",
    "påstridiga": "påstridig",
    "påstridigare": "påstridig",
    "påstridigares": "påstridig",
    "påstridigas": "påstridig",
    "påstridigast": "påstridig",
    "påstridigaste": "påstridig",
    "påstridigastes": "påstridig",
    "påstridigasts": "påstridig",
    "påstridige": "påstridig",
    "påstridiges": "påstridig",
    "påstridigheten": "påstridighet",
    "påstridighetens": "påstridighet",
    "påstridighets": "påstridighet",
    "påstridigs": "påstridig",
    "påstridigt": "påstridig",
    "påstridigts": "påstridig",
    "påstrukens": "påstruken",
    "påstruket": "påstruken",
    "påstrukets": "påstruken",
    "påstrukna": "påstruken",
    "påstruknare": "påstruken",
    "påstruknares": "påstruken",
    "påstruknas": "påstruken",
    "påstruknast": "påstruken",
    "påstruknaste": "påstruken",
    "påstruknastes": "påstruken",
    "påstruknasts": "påstruken",
    "påstrukne": "påstruken",
    "påstruknes": "påstruken",
    "påstrykningen": "påstrykning",
    "påstrykningens": "påstrykning",
    "påstryknings": "påstrykning",
    "påstådd": "påstå",
    "påstådda": "påstå",
    "påståddas": "påstå",
    "påstådde": "påstå",
    "påståddes": "påstå",
    "påstådds": "påstå",
    "påståeliga": "påståelig",
    "påståeligare": "påståelig",
    "påståeligares": "påståelig",
    "påståeligas": "påståelig",
    "påståeligast": "påståelig",
    "påståeligaste": "påståelig",
    "påståeligastes": "påståelig",
    "påståeligasts": "påståelig",
    "påståelige": "påståelig",
    "påståeliges": "påståelig",
    "påståeligheten": "påståelighet",
    "påståelighetens": "påståelighet",
    "påståelighets": "påståelighet",
    "påståeligs": "påståelig",
    "påståeligt": "påståelig",
    "påståeligts": "påståelig",
    "påstående": "påstå",
    "påståenden": "påstående",
    "påståendena": "påstående",
    "påståendenas": "påstående",
    "påståendens": "påstående",
    "påståendes": "påstående",
    "påståendesatsen": "påståendesats",
    "påståendesatsens": "påståendesats",
    "påståendesatser": "påståendesats",
    "påståendesatserna": "påståendesats",
    "påståendesatsernas": "påståendesats",
    "påståendesatsers": "påståendesats",
    "påståendet": "påstående",
    "påståendets": "påstående",
    "påstår": "påstå",
    "påstås": "påstå",
    "påstått": "påstå",
    "påståtts": "påstå",
    "påstötningar": "påstötning",
    "påstötningarna": "påstötning",
    "påstötningarnas": "påstötning",
    "påstötningars": "påstötning",
    "påstötningen": "påstötning",
    "påstötningens": "påstötning",
    "påstötnings": "påstötning",
    "påsynen": "påsyn",
    "påsynens": "påsyn",
    "påsyns": "påsyn",
    "påtade": "påta",
    "påtades": "påta",
    "påtag": "påta",
    "påtaga": "påta",
    "påtagande": "påta",
    "påtaganden": "påtagande",
    "påtagandena": "påtagande",
    "påtagandenas": "påtagande",
    "påtagandens": "påtagande",
    "påtagandes": "påtagande",
    "påtagandet": "påtagande",
    "påtagandets": "påtagande",
    "påtagas": "påta",
    "påtagbara": "påtagbar",
    "påtagbarare": "påtagbar",
    "påtagbarares": "påtagbar",
    "påtagbaras": "påtagbar",
    "påtagbarast": "påtagbar",
    "påtagbaraste": "påtagbar",
    "påtagbarastes": "påtagbar",
    "påtagbarasts": "påtagbar",
    "påtagbare": "påtagbar",
    "påtagbares": "påtagbar",
    "påtagbarheten": "påtagbarhet",
    "påtagbarhetens": "påtagbarhet",
    "påtagbarhets": "påtagbarhet",
    "påtagbars": "påtagbar",
    "påtagbart": "påtagbar",
    "påtagbarts": "påtagbar",
    "påtage": "påta",
    "påtagen": "påta",
    "påtagens": "påta",
    "påtager": "påta",
    "påtages": "påta",
    "påtaget": "påta",
    "påtagets": "påta",
    "påtagit": "påta",
    "påtagits": "påta",
    "påtagliga": "påtaglig",
    "påtagligare": "påtaglig",
    "påtagligares": "påtaglig",
    "påtagligas": "påtaglig",
    "påtagligast": "påtaglig",
    "påtagligaste": "påtaglig",
    "påtagligastes": "påtaglig",
    "påtagligasts": "påtaglig",
    "påtaglige": "påtaglig",
    "påtagliges": "påtaglig",
    "påtagligheten": "påtaglighet",
    "påtaglighetens": "påtaglighet",
    "påtaglighets": "påtaglighet",
    "påtagligs": "påtaglig",
    "påtagligt": "påtaglig",
    "påtagligts": "påtaglig",
    "påtagna": "påta",
    "påtagnas": "påta",
    "påtagne": "påta",
    "påtagnes": "påta",
    "påtagningar": "påtagning",
    "påtagningarna": "påtagning",
    "påtagningarnas": "påtagning",
    "påtagningars": "påtagning",
    "påtagningen": "påtagning",
    "påtagningens": "påtagning",
    "påtagnings": "påtagning",
    "påtags": "påta",
    "påtal": "påtala",
    "påtalad": "påtala",
    "påtalade": "påtala",
    "påtalades": "påtala",
    "påtalads": "påtala",
    "påtalande": "påtala",
    "påtalanden": "påtalande",
    "påtalandena": "påtalande",
    "påtalandenas": "påtalande",
    "påtalandens": "påtalande",
    "påtalandes": "påtalande",
    "påtalandet": "påtalande",
    "påtalandets": "påtalande",
    "påtalar": "påtala",
    "påtalas": "påtala",
    "påtalat": "påtala",
    "påtalats": "påtala",
    "påtande": "påta",
    "påtanden": "påtande",
    "påtandena": "påtande",
    "påtandenas": "påtande",
    "påtandens": "påtande",
    "påtandes": "påtande",
    "påtandet": "påtande",
    "påtandets": "påtande",
    "påtar": "påta",
    "påtas": "påta",
    "påtat": "påta",
    "påtats": "påta",
    "påtet": "påt",
    "påtets": "påt",
    "påtog": "påta",
    "påtoge": "påta",
    "påtoges": "påta",
    "påtogs": "påta",
    "påtryckar": "påtryckare",
    "påtryckaren": "påtryckare",
    "påtryckarens": "påtryckare",
    "påtryckares": "påtryckare",
    "påtryckarna": "påtryckare",
    "påtryckarnas": "påtryckare",
    "påtryckningar": "påtryckning",
    "påtryckningarna": "påtryckning",
    "påtryckningarnas": "påtryckning",
    "påtryckningars": "påtryckning",
    "påtryckningen": "påtryckning",
    "påtryckningens": "påtryckning",
    "påtrycknings": "påtryckning",
    "påtryckningsmedels": "påtryckningsmedel",
    "påtryckningsmedlen": "påtryckningsmedel",
    "påtryckningsmedlens": "påtryckningsmedel",
    "påtryckningsmedlet": "påtryckningsmedel",
    "påtryckningsmedlets": "påtryckningsmedel",
    "påträff": "påträffa",
    "påträffad": "påträffa",
    "påträffade": "påträffa",
    "påträffades": "påträffa",
    "påträffads": "påträffa",
    "påträffande": "påträffa",
    "påträffanden": "påträffande",
    "påträffandena": "påträffande",
    "påträffandenas": "påträffande",
    "påträffandens": "påträffande",
    "påträffandes": "påträffande",
    "påträffandet": "påträffande",
    "påträffandets": "påträffande",
    "påträffar": "påträffa",
    "påträffas": "påträffa",
    "påträffat": "påträffa",
    "påträffats": "påträffa",
    "påts": "påt",
    "påtvang": "påtvinga",
    "påtvangs": "påtvinga",
    "påtving": "påtvinga",
    "påtvingad": "påtvinga",
    "påtvingade": "påtvinga",
    "påtvingades": "påtvinga",
    "påtvingads": "påtvinga",
    "påtvingande": "påtvinga",
    "påtvinganden": "påtvingande",
    "påtvingandena": "påtvingande",
    "påtvingandenas": "påtvingande",
    "påtvingandens": "påtvingande",
    "påtvingandes": "påtvingande",
    "påtvingandet": "påtvingande",
    "påtvingandets": "påtvingande",
    "påtvingar": "påtvinga",
    "påtvingas": "påtvinga",
    "påtvingat": "påtvinga",
    "påtvingats": "påtvinga",
    "påtvinge": "påtvinga",
    "påtvinges": "påtvinga",
    "påtvunge": "påtvinga",
    "påtvungen": "påtvinga",
    "påtvungens": "påtvinga",
    "påtvunges": "påtvinga",
    "påtvunget": "påtvinga",
    "påtvungets": "påtvinga",
    "påtvungit": "påtvinga",
    "påtvungits": "påtvinga",
    "påtvungna": "påtvinga",
    "påtvungnas": "påtvinga",
    "påtvungne": "påtvinga",
    "påtvungnes": "påtvinga",
    "påtända": "påtänd",
    "påtändare": "påtänd",
    "påtändares": "påtänd",
    "påtändas": "påtänd",
    "påtändast": "påtänd",
    "påtändaste": "påtänd",
    "påtändastes": "påtänd",
    "påtändasts": "påtänd",
    "påtände": "påtänd",
    "påtändes": "påtänd",
    "påtändheten": "påtändhet",
    "påtändhetens": "påtändhet",
    "påtändhets": "påtändhet",
    "påtänds": "påtänd",
    "påtänkta": "påtänkt",
    "påtänktare": "påtänkt",
    "påtänktares": "påtänkt",
    "påtänktas": "påtänkt",
    "påtänktast": "påtänkt",
    "påtänktaste": "påtänkt",
    "påtänktastes": "påtänkt",
    "påtänktasts": "påtänkt",
    "påtänkte": "påtänkt",
    "påtänktes": "påtänkt",
    "påtänkts": "påtänkt",
    "påtänt": "påtänd",
    "påtänts": "påtänd",
    "påtårar": "påtår",
    "påtårarna": "påtår",
    "påtårarnas": "påtår",
    "påtårars": "påtår",
    "påtåren": "påtår",
    "påtårens": "påtår",
    "påtårs": "påtår",
    "påvar": "påve",
    "påvarna": "påve",
    "påvarnas": "påve",
    "påvars": "påve",
    "påvedömen": "påvedöme",
    "påvedömena": "påvedöme",
    "påvedömenas": "påvedöme",
    "påvedömens": "påvedöme",
    "påvedömes": "påvedöme",
    "påvedömet": "påvedöme",
    "påvedömets": "påvedöme",
    "påvekyrkan": "påvekyrka",
    "påvekyrkans": "påvekyrka",
    "påvekyrkas": "påvekyrka",
    "påven": "påve",
    "påvens": "påve",
    "påverk": "påverka",
    "påverkad": "påverka",
    "påverkade": "påverkad",
    "påverkades": "påverkad",
    "påverkads": "påverkad",
    "påverkande": "påverka",
    "påverkanden": "påverkande",
    "påverkandena": "påverkande",
    "påverkandenas": "påverkande",
    "påverkandens": "påverkande",
    "påverkandes": "påverkande",
    "påverkandet": "påverkande",
    "påverkandets": "påverkande",
    "påverkans": "påverkan",
    "påverkar": "påverka",
    "påverkas": "påverka",
    "påverkat": "påverkad",
    "påverkats": "påverkad",
    "påverkbara": "påverkbar",
    "påverkbarare": "påverkbar",
    "påverkbarares": "påverkbar",
    "påverkbaras": "påverkbar",
    "påverkbarast": "påverkbar",
    "påverkbaraste": "påverkbar",
    "påverkbarastes": "påverkbar",
    "påverkbarasts": "påverkbar",
    "påverkbare": "påverkbar",
    "påverkbares": "påverkbar",
    "påverkbarheten": "påverkbarhet",
    "påverkbarhetens": "påverkbarhet",
    "påverkbarhets": "påverkbarhet",
    "påverkbars": "påverkbar",
    "påverkbart": "påverkbar",
    "påverkbarts": "påverkbar",
    "påverkningar": "påverkning",
    "påverkningarna": "påverkning",
    "påverkningarnas": "påverkning",
    "påverkningars": "påverkning",
    "påverkningen": "påverkning",
    "påverkningens": "påverkning",
    "påverknings": "påverkning",
    "påvers": "påver",
    "påvert": "påver",
    "påverts": "påver",
    "påves": "påve",
    "påvestolen": "påvestol",
    "påvestolens": "påvestol",
    "påvestols": "påvestol",
    "påvevärdigheten": "påvevärdighet",
    "påvevärdighetens": "påvevärdighet",
    "påvevärdigheter": "påvevärdighet",
    "påvevärdigheterna": "påvevärdighet",
    "påvevärdigheternas": "påvevärdighet",
    "påvevärdigheters": "påvevärdighet",
    "påvevärdighets": "påvevärdighet",
    "påvilade": "påvila",
    "påvilades": "påvila",
    "påvilande": "påvila",
    "påvilanden": "påvilande",
    "påvilandena": "påvilande",
    "påvilandenas": "påvilande",
    "påvilandens": "påvilande",
    "påvilandes": "påvilande",
    "påvilandet": "påvilande",
    "påvilandets": "påvilande",
    "påvilar": "påvila",
    "påvilas": "påvila",
    "påvilat": "påvila",
    "påvilats": "påvila",
    "påvisad": "påvisa",
    "påvisade": "påvisa",
    "påvisades": "påvisa",
    "påvisads": "påvisa",
    "påvisande": "påvisa",
    "påvisanden": "påvisande",
    "påvisandena": "påvisande",
    "påvisandenas": "påvisande",
    "påvisandens": "påvisande",
    "påvisandes": "påvisande",
    "påvisandet": "påvisande",
    "påvisandets": "påvisande",
    "påvisar": "påvisa",
    "påvisas": "påvisa",
    "påvisat": "påvisa",
    "påvisats": "påvisa",
    "påvisbara": "påvisbar",
    "påvisbarare": "påvisbar",
    "påvisbarares": "påvisbar",
    "påvisbaras": "påvisbar",
    "påvisbarast": "påvisbar",
    "påvisbaraste": "påvisbar",
    "påvisbarastes": "påvisbar",
    "påvisbarasts": "påvisbar",
    "påvisbare": "påvisbar",
    "påvisbares": "påvisbar",
    "påvisbarheten": "påvisbarhet",
    "påvisbarhetens": "påvisbarhet",
    "påvisbarhets": "påvisbarhet",
    "påvisbars": "påvisbar",
    "påvisbart": "påvisbar",
    "påvisbarts": "påvisbar",
    "påviska": "påvisk",
    "påviskare": "påvisk",
    "påviskares": "påvisk",
    "påviskas": "påvisk",
    "påviskast": "påvisk",
    "påviskaste": "påvisk",
    "påviskastes": "påvisk",
    "påviskasts": "påvisk",
    "påviske": "påvisk",
    "påviskes": "påvisk",
    "påvisks": "påvisk",
    "påviskt": "påvisk",
    "påviskts": "påvisk",
    "påvliga": "påvlig",
    "påvligare": "påvlig",
    "påvligares": "påvlig",
    "påvligas": "påvlig",
    "påvligast": "påvlig",
    "påvligaste": "påvlig",
    "påvligastes": "påvlig",
    "påvligasts": "påvlig",
    "påvlige": "påvlig",
    "påvliges": "påvlig",
    "påvligheten": "påvlighet",
    "påvlighetens": "påvlighet",
    "påvlighets": "påvlighet",
    "påvligs": "påvlig",
    "påvligt": "påvlig",
    "påvligts": "påvlig",
    "påvra": "påver",
    "påvrare": "påver",
    "påvrares": "påver",
    "påvras": "påver",
    "påvrast": "påver",
    "påvraste": "påver",
    "påvrastes": "påver",
    "påvrasts": "påver",
    "påvre": "påver",
    "påvres": "påver",
    "påyrk": "påyrka",
    "påyrkad": "påyrka",
    "påyrkade": "påyrka",
    "påyrkades": "påyrka",
    "påyrkads": "påyrka",
    "påyrkande": "påyrka",
    "påyrkanden": "påyrkande",
    "påyrkandena": "påyrkande",
    "påyrkandenas": "påyrkande",
    "påyrkandens": "påyrkande",
    "påyrkandes": "påyrkande",
    "påyrkandet": "påyrkande",
    "påyrkandets": "påyrkande",
    "påyrkar": "påyrka",
    "påyrkas": "påyrka",
    "påyrkat": "påyrka",
    "påyrkats": "påyrka",
    "påökten": "påökt",
    "påöktens": "påökt",
    "påökts": "påökt",
    "pöbelmentaliteten": "pöbelmentalitet",
    "pöbelmentalitetens": "pöbelmentalitet",
    "pöbelmentaliteter": "pöbelmentalitet",
    "pöbelmentaliteterna": "pöbelmentalitet",
    "pöbelmentaliteternas": "pöbelmentalitet",
    "pöbelmentaliteters": "pöbelmentalitet",
    "pöbelmentalitets": "pöbelmentalitet",
    "pöbeln": "pöbel",
    "pöbelns": "pöbel",
    "pöbels": "pöbel",
    "pöl": "pöla",
    "pölade": "pöla",
    "pölades": "pöla",
    "pölande": "pöla",
    "pölanden": "pölande",
    "pölandena": "pölande",
    "pölandenas": "pölande",
    "pölandens": "pölande",
    "pölandes": "pölande",
    "pölandet": "pölande",
    "pölandets": "pölande",
    "pölar": "pöla",
    "pölarna": "pöl",
    "pölarnas": "pöl",
    "pölars": "pöl",
    "pölas": "pöla",
    "pölat": "pöla",
    "pölats": "pöla",
    "pölen": "pöl",
    "pölens": "pöl",
    "pöls": "pölsa",
    "pölsan": "pölsa",
    "pölsans": "pölsa",
    "pölsas": "pölsa",
    "pölse": "pölsa",
    "pölsiga": "pölsig",
    "pölsigare": "pölsig",
    "pölsigares": "pölsig",
    "pölsigas": "pölsig",
    "pölsigast": "pölsig",
    "pölsigaste": "pölsig",
    "pölsigastes": "pölsig",
    "pölsigasts": "pölsig",
    "pölsige": "pölsig",
    "pölsiges": "pölsig",
    "pölsigheten": "pölsighet",
    "pölsighetens": "pölsighet",
    "pölsighets": "pölsighet",
    "pölsigs": "pölsig",
    "pölsigt": "pölsig",
    "pölsigts": "pölsig",
    "pölsor": "pölsa",
    "pölsorna": "pölsa",
    "pölsornas": "pölsa",
    "pölsors": "pölsa",
    "pörten": "pörte",
    "pörtena": "pörte",
    "pörtenas": "pörte",
    "pörtens": "pörte",
    "pörtes": "pörte",
    "pörtet": "pörte",
    "pörtets": "pörte",
    "pörts": "pörte",
    "pös": "pösa",
    "pösande": "pösa",
    "pösanden": "pösande",
    "pösandena": "pösande",
    "pösandenas": "pösande",
    "pösandens": "pösande",
    "pösandes": "pösande",
    "pösandet": "pösande",
    "pösandets": "pösande",
    "pösas": "pösa",
    "pösen": "pös",
    "pösens": "pös",
    "pöser": "pösa",
    "pöses": "pösa",
    "pöset": "pös",
    "pösets": "pös",
    "pösiga": "pösig",
    "pösigare": "pösig",
    "pösigares": "pösig",
    "pösigas": "pösig",
    "pösigast": "pösig",
    "pösigaste": "pösig",
    "pösigastes": "pösig",
    "pösigasts": "pösig",
    "pösige": "pösig",
    "pösiges": "pösig",
    "pösigs": "pösig",
    "pösigt": "pösig",
    "pösigts": "pösig",
    "pösmunkar": "pösmunk",
    "pösmunkarna": "pösmunk",
    "pösmunkarnas": "pösmunk",
    "pösmunkars": "pösmunk",
    "pösmunken": "pösmunk",
    "pösmunkens": "pösmunk",
    "pösmunks": "pösmunk",
    "pöst": "pösa",
    "pöste": "pösa",
    "pöstes": "pösa",
    "pösts": "pösa",
    "q-et": "q",
    "q-ets": "q",
    "q-n": "q",
    "q-na": "q",
    "q-nas": "q",
    "q-ns": "q",
    "q-t": "q",
    "q-ts": "q",
    "q:et": "q",
    "q:ets": "q",
    "q:n": "q",
    "q:na": "q",
    "q:nas": "q",
    "q:ns": "q",
    "q:s": "q",
    "q:t": "q",
    "q:ts": "q",
    "qatariern": "qatarier",
    "qatarierna": "qatarier",
    "qatariernas": "qatarier",
    "qatarierns": "qatarier",
    "qatariers": "qatarier",
    "qatariska": "qatarisk",
    "qatariskan": "qatariska",
    "qatariskans": "qatariska",
    "qatariskare": "qatarisk",
    "qatariskares": "qatarisk",
    "qatariskas": "qatariska",
    "qatariskast": "qatarisk",
    "qatariskaste": "qatarisk",
    "qatariskastes": "qatarisk",
    "qatariskasts": "qatarisk",
    "qatariske": "qatariska",
    "qatariskes": "qatarisk",
    "qatariskor": "qatariska",
    "qatariskorna": "qatariska",
    "qatariskornas": "qatariska",
    "qatariskors": "qatariska",
    "qatarisks": "qatarisk",
    "qatariskt": "qatarisk",
    "qatariskts": "qatarisk",
    "quenellen": "quenell",
    "quenellens": "quenell",
    "queneller": "quenell",
    "quenellerna": "quenell",
    "quenellernas": "quenell",
    "quenellers": "quenell",
    "quenells": "quenell",
    "quilt": "quilta",
    "quiltad": "quilta",
    "quiltade": "quilta",
    "quiltades": "quilta",
    "quiltads": "quilta",
    "quiltande": "quilta",
    "quiltanden": "quiltande",
    "quiltandena": "quiltande",
    "quiltandenas": "quiltande",
    "quiltandens": "quiltande",
    "quiltandes": "quiltande",
    "quiltandet": "quiltande",
    "quiltandets": "quiltande",
    "quiltar": "quilta",
    "quiltas": "quilta",
    "quiltat": "quilta",
    "quiltats": "quilta",
    "quislingar": "quisling",
    "quislingarna": "quisling",
    "quislingarnas": "quisling",
    "quislingars": "quisling",
    "quislingen": "quisling",
    "quislingens": "quisling",
    "quislings": "quisling",
    "quizade": "quiza",
    "quizades": "quiza",
    "quizande": "quiza",
    "quizanden": "quizande",
    "quizandena": "quizande",
    "quizandenas": "quizande",
    "quizandens": "quizande",
    "quizandes": "quizande",
    "quizandet": "quizande",
    "quizandets": "quizande",
    "quizar": "quiza",
    "quizarna": "quiz",
    "quizarnas": "quiz",
    "quizars": "quiz",
    "quizas": "quiza",
    "quizat": "quiza",
    "quizats": "quiza",
    "quizen": "quiz",
    "quizens": "quiz",
    "quizer": "quiz",
    "quizerna": "quiz",
    "quizernas": "quiz",
    "quizers": "quiz",
    "quizzade": "quizza",
    "quizzades": "quizza",
    "quizzande": "quizza",
    "quizzanden": "quizzande",
    "quizzandena": "quizzande",
    "quizzandenas": "quizzande",
    "quizzandens": "quizzande",
    "quizzandes": "quizzande",
    "quizzandet": "quizzande",
    "quizzandets": "quizzande",
    "quizzar": "quizza",
    "quizzarna": "quizz",
    "quizzarnas": "quizz",
    "quizzars": "quizz",
    "quizzas": "quizza",
    "quizzat": "quizza",
    "quizzats": "quizza",
    "quizzen": "quizz",
    "quizzens": "quizz",
    "quizzer": "quizz",
    "quizzerna": "quizz",
    "quizzernas": "quizz",
    "quizzers": "quizz",
    "r-en": "r",
    "r-ens": "r",
    "r-et": "r",
    "r-ets": "r",
    "r-s": "r",
    "r:en": "r",
    "r:ens": "r",
    "r:et": "r",
    "r:ets": "r",
    "r:s": "r",
    "rabalders": "rabalder",
    "rabaldret": "rabalder",
    "rabaldrets": "rabalder",
    "rabarberkak": "rabarberkaka",
    "rabarberkakan": "rabarberkaka",
    "rabarberkakans": "rabarberkaka",
    "rabarberkakas": "rabarberkaka",
    "rabarberkake": "rabarberkaka",
    "rabarberkakor": "rabarberkaka",
    "rabarberkakorna": "rabarberkaka",
    "rabarberkakornas": "rabarberkaka",
    "rabarberkakors": "rabarberkaka",
    "rabarberkaks": "rabarberkaka",
    "rabarbern": "rabarber",
    "rabarberns": "rabarber",
    "rabarbers": "rabarber",
    "rabatten": "rabatt",
    "rabattens": "rabatt",
    "rabatter": "rabatt",
    "rabatterad": "rabattera",
    "rabatterade": "rabattera",
    "rabatterades": "rabattera",
    "rabatterads": "rabattera",
    "rabatterande": "rabattera",
    "rabatteranden": "rabatterande",
    "rabatterandena": "rabatterande",
    "rabatterandenas": "rabatterande",
    "rabatterandens": "rabatterande",
    "rabatterandes": "rabatterande",
    "rabatterandet": "rabatterande",
    "rabatterandets": "rabatterande",
    "rabatterar": "rabattera",
    "rabatteras": "rabattera",
    "rabatterat": "rabattera",
    "rabatterats": "rabattera",
    "rabatterbara": "rabatterbar",
    "rabatterbarare": "rabatterbar",
    "rabatterbarares": "rabatterbar",
    "rabatterbaras": "rabatterbar",
    "rabatterbarast": "rabatterbar",
    "rabatterbaraste": "rabatterbar",
    "rabatterbarastes": "rabatterbar",
    "rabatterbarasts": "rabatterbar",
    "rabatterbare": "rabatterbar",
    "rabatterbares": "rabatterbar",
    "rabatterbarheten": "rabatterbarhet",
    "rabatterbarhetens": "rabatterbarhet",
    "rabatterbarhets": "rabatterbarhet",
    "rabatterbars": "rabatterbar",
    "rabatterbart": "rabatterbar",
    "rabatterbarts": "rabatterbar",
    "rabatteringar": "rabattering",
    "rabatteringarna": "rabattering",
    "rabatteringarnas": "rabattering",
    "rabatteringars": "rabattering",
    "rabatteringen": "rabattering",
    "rabatteringens": "rabattering",
    "rabatterings": "rabattering",
    "rabatterna": "rabatt",
    "rabatternas": "rabatt",
    "rabatters": "rabatt",
    "rabattfrimärken": "rabattfrimärke",
    "rabattfrimärkena": "rabattfrimärke",
    "rabattfrimärkenas": "rabattfrimärke",
    "rabattfrimärkens": "rabattfrimärke",
    "rabattfrimärkes": "rabattfrimärke",
    "rabattfrimärket": "rabattfrimärke",
    "rabattfrimärkets": "rabattfrimärke",
    "rabatthäften": "rabatthäfte",
    "rabatthäftena": "rabatthäfte",
    "rabatthäftenas": "rabatthäfte",
    "rabatthäftens": "rabatthäfte",
    "rabatthäftes": "rabatthäfte",
    "rabatthäftet": "rabatthäfte",
    "rabatthäftets": "rabatthäfte",
    "rabattkorten": "rabattkort",
    "rabattkortens": "rabattkort",
    "rabattkortet": "rabattkort",
    "rabattkortets": "rabattkort",
    "rabattkorts": "rabattkort",
    "rabattkupongen": "rabattkupong",
    "rabattkupongens": "rabattkupong",
    "rabattkuponger": "rabattkupong",
    "rabattkupongerna": "rabattkupong",
    "rabattkupongernas": "rabattkupong",
    "rabattkupongers": "rabattkupong",
    "rabattkupongs": "rabattkupong",
    "rabatts": "rabatt",
    "rabbel": "rabbla",
    "rabbels": "rabbel",
    "rabbier": "rabbi",
    "rabbierna": "rabbi",
    "rabbiernas": "rabbi",
    "rabbiers": "rabbi",
    "rabbin": "rabbi",
    "rabbinen": "rabbin",
    "rabbinens": "rabbin",
    "rabbiner": "rabbin",
    "rabbinerna": "rabbin",
    "rabbinernas": "rabbin",
    "rabbiners": "rabbin",
    "rabbins": "rabbin",
    "rabbis": "rabbi",
    "rabbisar": "rabbis",
    "rabbisarna": "rabbis",
    "rabbisarnas": "rabbis",
    "rabbisars": "rabbis",
    "rabbisen": "rabbis",
    "rabbisens": "rabbis",
    "rabblad": "rabbla",
    "rabblade": "rabbla",
    "rabblades": "rabbla",
    "rabblads": "rabbla",
    "rabblande": "rabbla",
    "rabblandes": "rabblande",
    "rabblandet": "rabblande",
    "rabblandets": "rabblande",
    "rabblar": "rabbla",
    "rabblas": "rabbla",
    "rabblat": "rabbla",
    "rabblats": "rabbla",
    "rabblet": "rabbel",
    "rabblets": "rabbel",
    "rabiata": "rabiat",
    "rabiatare": "rabiat",
    "rabiatares": "rabiat",
    "rabiatas": "rabiat",
    "rabiatast": "rabiat",
    "rabiataste": "rabiat",
    "rabiatastes": "rabiat",
    "rabiatasts": "rabiat",
    "rabiate": "rabiat",
    "rabiates": "rabiat",
    "rabiats": "rabiat",
    "rabiesen": "rabies",
    "rabiesens": "rabies",
    "rabiesskräcken": "rabiesskräck",
    "rabiesskräckens": "rabiesskräck",
    "rabiesskräcks": "rabiesskräck",
    "rabiesutbrotten": "rabiesutbrott",
    "rabiesutbrottens": "rabiesutbrott",
    "rabiesutbrottet": "rabiesutbrott",
    "rabiesutbrottets": "rabiesutbrott",
    "rabiesutbrotts": "rabiesutbrott",
    "rabulismen": "rabulism",
    "rabulismens": "rabulism",
    "rabulismer": "rabulism",
    "rabulismerna": "rabulism",
    "rabulismernas": "rabulism",
    "rabulismers": "rabulism",
    "rabulisms": "rabulism",
    "rabulisten": "rabulist",
    "rabulistens": "rabulist",
    "rabulister": "rabulist",
    "rabulisterna": "rabulist",
    "rabulisternas": "rabulist",
    "rabulisters": "rabulist",
    "rabulistiska": "rabulistisk",
    "rabulistiskare": "rabulistisk",
    "rabulistiskares": "rabulistisk",
    "rabulistiskas": "rabulistisk",
    "rabulistiskast": "rabulistisk",
    "rabulistiskaste": "rabulistisk",
    "rabulistiskastes": "rabulistisk",
    "rabulistiskasts": "rabulistisk",
    "rabulistiske": "rabulistisk",
    "rabulistiskes": "rabulistisk",
    "rabulistisks": "rabulistisk",
    "rabulistiskt": "rabulistisk",
    "rabulistiskts": "rabulistisk",
    "rabulists": "rabulist",
    "racerbilar": "racerbil",
    "racerbilarna": "racerbil",
    "racerbilarnas": "racerbil",
    "racerbilars": "racerbil",
    "racerbilen": "racerbil",
    "racerbilens": "racerbil",
    "racerbils": "racerbil",
    "racerbåtar": "racerbåt",
    "racerbåtarna": "racerbåt",
    "racerbåtarnas": "racerbåt",
    "racerbåtars": "racerbåt",
    "racerbåten": "racerbåt",
    "racerbåtens": "racerbåt",
    "racerbåts": "racerbåt",
    "racercykeln": "racercykel",
    "racercykelns": "racercykel",
    "racercykels": "racercykel",
    "racercyklar": "racercykel",
    "racercyklarna": "racercykel",
    "racercyklarnas": "racercykel",
    "racercyklars": "racercykel",
    "racerförar": "racerförare",
    "racerföraren": "racerförare",
    "racerförarens": "racerförare",
    "racerförares": "racerförare",
    "racerförarna": "racerförare",
    "racerförarnas": "racerförare",
    "racern": "racer",
    "racerna": "racer",
    "racernas": "racer",
    "racerns": "racer",
    "racers": "racer",
    "racingbåtar": "racingbåt",
    "racingbåtarna": "racingbåt",
    "racingbåtarnas": "racingbåt",
    "racingbåtars": "racingbåt",
    "racingbåten": "racingbåt",
    "racingbåtens": "racingbåt",
    "racingbåts": "racingbåt",
    "racingen": "racing",
    "racingens": "racing",
    "racingmässiga": "racingmässig",
    "racingmässigare": "racingmässig",
    "racingmässigares": "racingmässig",
    "racingmässigas": "racingmässig",
    "racingmässigast": "racingmässig",
    "racingmässigaste": "racingmässig",
    "racingmässigastes": "racingmässig",
    "racingmässigasts": "racingmässig",
    "racingmässige": "racingmässig",
    "racingmässiges": "racingmässig",
    "racingmässigs": "racingmässig",
    "racingmässigt": "racingmässig",
    "racingmässigts": "racingmässig",
    "racings": "racing",
    "rackabajsar": "rackabajsare",
    "rackabajsaren": "rackabajsare",
    "rackabajsarens": "rackabajsare",
    "rackabajsares": "rackabajsare",
    "rackabajsarna": "rackabajsare",
    "rackabajsarnas": "rackabajsare",
    "rackad": "racka",
    "rackade": "racka",
    "rackades": "racka",
    "rackads": "racka",
    "rackande": "racka",
    "rackanden": "rackande",
    "rackandena": "rackande",
    "rackandenas": "rackande",
    "rackandens": "rackande",
    "rackandes": "rackande",
    "rackandet": "rackande",
    "rackandets": "rackande",
    "rackar": "rackare",
    "rackaraktiga": "rackaraktig",
    "rackaraktigare": "rackaraktig",
    "rackaraktigares": "rackaraktig",
    "rackaraktigas": "rackaraktig",
    "rackaraktigast": "rackaraktig",
    "rackaraktigaste": "rackaraktig",
    "rackaraktigastes": "rackaraktig",
    "rackaraktigasts": "rackaraktig",
    "rackaraktige": "rackaraktig",
    "rackaraktiges": "rackaraktig",
    "rackaraktigheten": "rackaraktighet",
    "rackaraktighetens": "rackaraktighet",
    "rackaraktighets": "rackaraktighet",
    "rackaraktigs": "rackaraktig",
    "rackaraktigt": "rackaraktig",
    "rackaraktigts": "rackaraktig",
    "rackaren": "rackare",
    "rackarens": "rackare",
    "rackares": "rackare",
    "rackarna": "rackare",
    "rackarnas": "rackare",
    "rackars": "rack",
    "rackarspelet": "rackarspel",
    "rackarspelets": "rackarspel",
    "rackarspels": "rackarspel",
    "rackartygen": "rackartyg",
    "rackartygens": "rackartyg",
    "rackartyget": "rackartyg",
    "rackartygets": "rackartyg",
    "rackartygs": "rackartyg",
    "rackarungar": "rackarunge",
    "rackarungarna": "rackarunge",
    "rackarungarnas": "rackarunge",
    "rackarungars": "rackarunge",
    "rackarungen": "rackarunge",
    "rackarungens": "rackarunge",
    "rackarunges": "rackarunge",
    "rackas": "racka",
    "rackat": "racka",
    "rackats": "racka",
    "rackelhan": "rackelhane",
    "rackelhanar": "rackelhane",
    "rackelhanarna": "rackelhane",
    "rackelhanarnas": "rackelhane",
    "rackelhanars": "rackelhane",
    "rackelhanen": "rackelhane",
    "rackelhanens": "rackelhane",
    "rackelhanes": "rackelhane",
    "rackelhans": "rackelhane",
    "racken": "rack",
    "rackens": "rack",
    "racket": "rack",
    "racketar": "racket",
    "racketarna": "racket",
    "racketarnas": "racket",
    "racketars": "racket",
    "racketen": "racket",
    "racketens": "racket",
    "rackets": "racket",
    "rackliga": "racklig",
    "rackligare": "racklig",
    "rackligares": "racklig",
    "rackligas": "racklig",
    "rackligast": "racklig",
    "rackligaste": "racklig",
    "rackligastes": "racklig",
    "rackligasts": "racklig",
    "racklige": "racklig",
    "rackliges": "racklig",
    "rackligheten": "racklighet",
    "racklighetens": "racklighet",
    "racklighets": "racklighet",
    "rackligs": "racklig",
    "rackligt": "racklig",
    "rackligts": "racklig",
    "racks": "rack",
    "racrar": "racer",
    "racrarna": "racer",
    "racrarnas": "racer",
    "racrars": "racer",
    "radannonsen": "radannons",
    "radannonsens": "radannons",
    "radannonser": "radannons",
    "radannonserna": "radannons",
    "radannonsernas": "radannons",
    "radannonsers": "radannons",
    "radarantennen": "radarantenn",
    "radarantennens": "radarantenn",
    "radarantenner": "radarantenn",
    "radarantennerna": "radarantenn",
    "radarantennernas": "radarantenn",
    "radarantenners": "radarantenn",
    "radarantenns": "radarantenn",
    "radarfyrar": "radarfyr",
    "radarfyrarna": "radarfyr",
    "radarfyrarnas": "radarfyr",
    "radarfyrars": "radarfyr",
    "radarfyren": "radarfyr",
    "radarfyrens": "radarfyr",
    "radarfyrs": "radarfyr",
    "radarkontrollen": "radarkontroll",
    "radarkontrollens": "radarkontroll",
    "radarkontroller": "radarkontroll",
    "radarkontrollerna": "radarkontroll",
    "radarkontrollernas": "radarkontroll",
    "radarkontrollers": "radarkontroll",
    "radarkontrolls": "radarkontroll",
    "radarn": "radar",
    "radarns": "radar",
    "radarparen": "radarpar",
    "radarparens": "radarpar",
    "radarparet": "radarpar",
    "radarparets": "radarpar",
    "radarpars": "radarpar",
    "radarreflektorer": "radarreflektor",
    "radarreflektorerna": "radarreflektor",
    "radarreflektorernas": "radarreflektor",
    "radarreflektorers": "radarreflektor",
    "radarreflektorn": "radarreflektor",
    "radarreflektorns": "radarreflektor",
    "radarreflektors": "radarreflektor",
    "radars": "radar",
    "radarskärmar": "radarskärm",
    "radarskärmarna": "radarskärm",
    "radarskärmarnas": "radarskärm",
    "radarskärmars": "radarskärm",
    "radarskärmen": "radarskärm",
    "radarskärmens": "radarskärm",
    "radarskärms": "radarskärm",
    "radarspelet": "radarspel",
    "radarspelets": "radarspel",
    "radarspels": "radarspel",
    "radarvågen": "radarvåg",
    "radarvågens": "radarvåg",
    "radarvågor": "radarvåg",
    "radarvågorna": "radarvåg",
    "radarvågornas": "radarvåg",
    "radarvågors": "radarvåg",
    "radarvågs": "radarvåg",
    "radavstånden": "radavstånd",
    "radavståndens": "radavstånd",
    "radavståndet": "radavstånd",
    "radavståndets": "radavstånd",
    "radavstånds": "radavstånd",
    "radbanden": "radband",
    "radbandens": "radband",
    "radbandet": "radband",
    "radbandets": "radband",
    "radbands": "radband",
    "radbyten": "radbyte",
    "radbytena": "radbyte",
    "radbytenas": "radbyte",
    "radbytens": "radbyte",
    "radbytes": "radbyte",
    "radbytet": "radbyte",
    "radbytets": "radbyte",
    "radd": "radda",
    "raddan": "radda",
    "raddans": "radda",
    "raddas": "radda",
    "radde": "radda",
    "raddor": "radda",
    "raddorna": "radda",
    "raddornas": "radda",
    "raddors": "radda",
    "radds": "radda",
    "raden": "rad",
    "radens": "rad",
    "rader": "rad",
    "raderad": "radera",
    "raderade": "radera",
    "raderades": "radera",
    "raderads": "radera",
    "raderande": "radera",
    "raderanden": "raderande",
    "raderandena": "raderande",
    "raderandenas": "raderande",
    "raderandens": "raderande",
    "raderandes": "raderande",
    "raderandet": "raderande",
    "raderandets": "raderande",
    "raderar": "radera",
    "raderas": "radera",
    "raderat": "radera",
    "raderats": "radera",
    "raderbara": "raderbar",
    "raderbarare": "raderbar",
    "raderbarares": "raderbar",
    "raderbaras": "raderbar",
    "raderbarast": "raderbar",
    "raderbaraste": "raderbar",
    "raderbarastes": "raderbar",
    "raderbarasts": "raderbar",
    "raderbare": "raderbar",
    "raderbares": "raderbar",
    "raderbarheten": "raderbarhet",
    "raderbarhetens": "raderbarhet",
    "raderbarhets": "raderbarhet",
    "raderbars": "raderbar",
    "raderbart": "raderbar",
    "raderbarts": "raderbar",
    "radergummin": "radergummi",
    "radergummina": "radergummi",
    "radergumminas": "radergummi",
    "radergummins": "radergummi",
    "radergummis": "radergummi",
    "radergummit": "radergummi",
    "radergummits": "radergummi",
    "raderingar": "radering",
    "raderingarna": "radering",
    "raderingarnas": "radering",
    "raderingars": "radering",
    "raderingen": "radering",
    "raderingens": "radering",
    "raderings": "radering",
    "raderknivar": "raderkniv",
    "raderknivarna": "raderkniv",
    "raderknivarnas": "raderkniv",
    "raderknivars": "raderkniv",
    "raderkniven": "raderkniv",
    "raderknivens": "raderkniv",
    "raderknivs": "raderkniv",
    "raderna": "rad",
    "radernas": "rad",
    "raders": "rad",
    "radhusen": "radhus",
    "radhusens": "radhus",
    "radhuset": "radhus",
    "radhusets": "radhus",
    "radhusfamiljen": "radhusfamilj",
    "radhusfamiljens": "radhusfamilj",
    "radhusfamiljer": "radhusfamilj",
    "radhusfamiljerna": "radhusfamilj",
    "radhusfamiljernas": "radhusfamilj",
    "radhusfamiljers": "radhusfamilj",
    "radhusfamiljs": "radhusfamilj",
    "radhusområden": "radhusområde",
    "radhusområdena": "radhusområde",
    "radhusområdenas": "radhusområde",
    "radhusområdens": "radhusområde",
    "radhusområdes": "radhusområde",
    "radhusområdet": "radhusområde",
    "radhusområdets": "radhusområde",
    "radiakbehandlingar": "radiakbehandling",
    "radiakbehandlingarna": "radiakbehandling",
    "radiakbehandlingarnas": "radiakbehandling",
    "radiakbehandlingars": "radiakbehandling",
    "radiakbehandlingen": "radiakbehandling",
    "radiakbehandlingens": "radiakbehandling",
    "radiakbehandlings": "radiakbehandling",
    "radiaken": "radiak",
    "radiakens": "radiak",
    "radiaks": "radiak",
    "radiala": "radial",
    "radialare": "radial",
    "radialares": "radial",
    "radialas": "radial",
    "radialast": "radial",
    "radialaste": "radial",
    "radialastes": "radial",
    "radialasts": "radial",
    "radialdäcken": "radialdäck",
    "radialdäckens": "radialdäck",
    "radialdäcket": "radialdäck",
    "radialdäckets": "radialdäck",
    "radialdäcks": "radialdäck",
    "radiale": "radial",
    "radiales": "radial",
    "radialhastigheten": "radialhastighet",
    "radialhastighetens": "radialhastighet",
    "radialhastigheter": "radialhastighet",
    "radialhastigheterna": "radialhastighet",
    "radialhastigheternas": "radialhastighet",
    "radialhastigheters": "radialhastighet",
    "radialhastighets": "radialhastighet",
    "radiallagerna": "radiallager",
    "radiallagernas": "radiallager",
    "radiallagers": "radiallager",
    "radiallagren": "radiallager",
    "radiallagrens": "radiallager",
    "radiallagret": "radiallager",
    "radiallagrets": "radiallager",
    "radials": "radial",
    "radialt": "radial",
    "radialts": "radial",
    "radianen": "radian",
    "radianens": "radian",
    "radianer": "radian",
    "radianerna": "radian",
    "radianernas": "radian",
    "radianers": "radian",
    "radians": "radian",
    "radiatorer": "radiator",
    "radiatorerna": "radiator",
    "radiatorernas": "radiator",
    "radiatorers": "radiator",
    "radiatorn": "radiator",
    "radiatorns": "radiator",
    "radiators": "radiator",
    "radiella": "radiell",
    "radiellare": "radiell",
    "radiellares": "radiell",
    "radiellas": "radiell",
    "radiellast": "radiell",
    "radiellaste": "radiell",
    "radiellastes": "radiell",
    "radiellasts": "radiell",
    "radielle": "radiell",
    "radielles": "radiell",
    "radiells": "radiell",
    "radiellt": "radiell",
    "radiellts": "radiell",
    "radien": "radie",
    "radiens": "radie",
    "radier": "radie",
    "radierad": "radiera",
    "radierade": "radiera",
    "radierades": "radiera",
    "radierads": "radiera",
    "radierande": "radiera",
    "radieranden": "radierande",
    "radierandena": "radierande",
    "radierandenas": "radierande",
    "radierandens": "radierande",
    "radierandes": "radierande",
    "radierandet": "radierande",
    "radierandets": "radierande",
    "radierar": "radiera",
    "radieras": "radiera",
    "radierat": "radiera",
    "radierats": "radiera",
    "radierbara": "radierbar",
    "radierbarare": "radierbar",
    "radierbarares": "radierbar",
    "radierbaras": "radierbar",
    "radierbarast": "radierbar",
    "radierbaraste": "radierbar",
    "radierbarastes": "radierbar",
    "radierbarasts": "radierbar",
    "radierbare": "radierbar",
    "radierbares": "radierbar",
    "radierbarheten": "radierbarhet",
    "radierbarhetens": "radierbarhet",
    "radierbarhets": "radierbarhet",
    "radierbars": "radierbar",
    "radierbart": "radierbar",
    "radierbarts": "radierbar",
    "radieringar": "radiering",
    "radieringarna": "radiering",
    "radieringarnas": "radiering",
    "radieringars": "radiering",
    "radieringen": "radiering",
    "radieringens": "radiering",
    "radierings": "radiering",
    "radierna": "radie",
    "radiernas": "radie",
    "radiers": "radie",
    "radies": "radie",
    "radiet": "radium",
    "radiets": "radium",
    "radikala": "radikal",
    "radikalare": "radikal",
    "radikalares": "radikal",
    "radikalas": "radikal",
    "radikalast": "radikal",
    "radikalaste": "radikal",
    "radikalastes": "radikal",
    "radikalasts": "radikal",
    "radikale": "radikal",
    "radikalen": "radikal",
    "radikalens": "radikal",
    "radikaler": "radikal",
    "radikalerna": "radikal",
    "radikalernas": "radikal",
    "radikalers": "radikal",
    "radikales": "radikal",
    "radikaliserad": "radikalisera",
    "radikaliserade": "radikalisera",
    "radikaliserades": "radikalisera",
    "radikaliserads": "radikalisera",
    "radikaliserande": "radikalisera",
    "radikaliseranden": "radikaliserande",
    "radikaliserandena": "radikaliserande",
    "radikaliserandenas": "radikaliserande",
    "radikaliserandens": "radikaliserande",
    "radikaliserandes": "radikaliserande",
    "radikaliserandet": "radikaliserande",
    "radikaliserandets": "radikaliserande",
    "radikaliserar": "radikalisera",
    "radikaliseras": "radikalisera",
    "radikaliserat": "radikalisera",
    "radikaliserats": "radikalisera",
    "radikaliserbara": "radikaliserbar",
    "radikaliserbarare": "radikaliserbar",
    "radikaliserbarares": "radikaliserbar",
    "radikaliserbaras": "radikaliserbar",
    "radikaliserbarast": "radikaliserbar",
    "radikaliserbaraste": "radikaliserbar",
    "radikaliserbarastes": "radikaliserbar",
    "radikaliserbarasts": "radikaliserbar",
    "radikaliserbare": "radikaliserbar",
    "radikaliserbares": "radikaliserbar",
    "radikaliserbarheten": "radikaliserbarhet",
    "radikaliserbarhetens": "radikaliserbarhet",
    "radikaliserbarhets": "radikaliserbarhet",
    "radikaliserbars": "radikaliserbar",
    "radikaliserbart": "radikaliserbar",
    "radikaliserbarts": "radikaliserbar",
    "radikaliseringar": "radikalisering",
    "radikaliseringarna": "radikalisering",
    "radikaliseringarnas": "radikalisering",
    "radikaliseringars": "radikalisering",
    "radikaliseringen": "radikalisering",
    "radikaliseringens": "radikalisering",
    "radikaliserings": "radikalisering",
    "radikalismen": "radikalism",
    "radikalismens": "radikalism",
    "radikalismer": "radikalism",
    "radikalismerna": "radikalism",
    "radikalismernas": "radikalism",
    "radikalismers": "radikalism",
    "radikalisms": "radikalism",
    "radikaloperationen": "radikaloperation",
    "radikaloperationens": "radikaloperation",
    "radikaloperationer": "radikaloperation",
    "radikaloperationerna": "radikaloperation",
    "radikaloperationernas": "radikaloperation",
    "radikaloperationers": "radikaloperation",
    "radikaloperations": "radikaloperation",
    "radikals": "radikal",
    "radikalt": "radikal",
    "radikalts": "radikal",
    "radioaktiva": "radioaktiv",
    "radioaktivare": "radioaktiv",
    "radioaktivares": "radioaktiv",
    "radioaktivas": "radioaktiv",
    "radioaktivast": "radioaktiv",
    "radioaktivaste": "radioaktiv",
    "radioaktivastes": "radioaktiv",
    "radioaktivasts": "radioaktiv",
    "radioaktive": "radioaktiv",
    "radioaktives": "radioaktiv",
    "radioaktiviteten": "radioaktivitet",
    "radioaktivitetens": "radioaktivitet",
    "radioaktiviteter": "radioaktivitet",
    "radioaktiviteterna": "radioaktivitet",
    "radioaktiviteternas": "radioaktivitet",
    "radioaktiviteters": "radioaktivitet",
    "radioaktivitets": "radioaktivitet",
    "radioaktivs": "radioaktiv",
    "radioaktivt": "radioaktiv",
    "radioaktivts": "radioaktiv",
    "radioamatören": "radioamatör",
    "radioamatörens": "radioamatör",
    "radioamatörer": "radioamatör",
    "radioamatörerna": "radioamatör",
    "radioamatörernas": "radioamatör",
    "radioamatörers": "radioamatör",
    "radioamatörs": "radioamatör",
    "radioandakten": "radioandakt",
    "radioandaktens": "radioandakt",
    "radioandakter": "radioandakt",
    "radioandakterna": "radioandakt",
    "radioandakternas": "radioandakt",
    "radioandakters": "radioandakt",
    "radioandakts": "radioandakt",
    "radioantennen": "radioantenn",
    "radioantennens": "radioantenn",
    "radioantenner": "radioantenn",
    "radioantennerna": "radioantenn",
    "radioantennernas": "radioantenn",
    "radioantenners": "radioantenn",
    "radioantenns": "radioantenn",
    "radioapparaten": "radioapparat",
    "radioapparatens": "radioapparat",
    "radioapparater": "radioapparat",
    "radioapparaterna": "radioapparat",
    "radioapparaternas": "radioapparat",
    "radioapparaters": "radioapparat",
    "radioapparats": "radioapparat",
    "radioastronomien": "radioastronomi",
    "radioastronomiens": "radioastronomi",
    "radioastronomin": "radioastronomi",
    "radioastronomins": "radioastronomi",
    "radioastronomis": "radioastronomi",
    "radioastronomiska": "radioastronomisk",
    "radioastronomiskare": "radioastronomisk",
    "radioastronomiskares": "radioastronomisk",
    "radioastronomiskas": "radioastronomisk",
    "radioastronomiskast": "radioastronomisk",
    "radioastronomiskaste": "radioastronomisk",
    "radioastronomiskastes": "radioastronomisk",
    "radioastronomiskasts": "radioastronomisk",
    "radioastronomiske": "radioastronomisk",
    "radioastronomiskes": "radioastronomisk",
    "radioastronomisks": "radioastronomisk",
    "radioastronomiskt": "radioastronomisk",
    "radioastronomiskts": "radioastronomisk",
    "radioavlyssningar": "radioavlyssning",
    "radioavlyssningarna": "radioavlyssning",
    "radioavlyssningarnas": "radioavlyssning",
    "radioavlyssningars": "radioavlyssning",
    "radioavlyssningen": "radioavlyssning",
    "radioavlyssningens": "radioavlyssning",
    "radioavlyssnings": "radioavlyssning",
    "radiobilar": "radiobil",
    "radiobilarna": "radiobil",
    "radiobilarnas": "radiobil",
    "radiobilars": "radiobil",
    "radiobilen": "radiobil",
    "radiobilens": "radiobil",
    "radiobils": "radiobil",
    "radiobiologien": "radiobiologi",
    "radiobiologiens": "radiobiologi",
    "radiobiologin": "radiobiologi",
    "radiobiologins": "radiobiologi",
    "radiobiologis": "radiobiologi",
    "radiobruset": "radiobrus",
    "radiobrusets": "radiobrus",
    "radiofrekventa": "radiofrekvent",
    "radiofrekventare": "radiofrekvent",
    "radiofrekventares": "radiofrekvent",
    "radiofrekventas": "radiofrekvent",
    "radiofrekventast": "radiofrekvent",
    "radiofrekventaste": "radiofrekvent",
    "radiofrekventastes": "radiofrekvent",
    "radiofrekventasts": "radiofrekvent",
    "radiofrekvente": "radiofrekvent",
    "radiofrekventes": "radiofrekvent",
    "radiofrekvents": "radiofrekvent",
    "radiofyrar": "radiofyr",
    "radiofyrarna": "radiofyr",
    "radiofyrarnas": "radiofyr",
    "radiofyrars": "radiofyr",
    "radiofyren": "radiofyr",
    "radiofyrens": "radiofyr",
    "radiofyrs": "radiofyr",
    "radiofysiken": "radiofysik",
    "radiofysikens": "radiofysik",
    "radiofysiks": "radiofysik",
    "radiogrammen": "radiogram",
    "radiogrammens": "radiogram",
    "radiogrammet": "radiogram",
    "radiogrammets": "radiogram",
    "radiogrammofonen": "radiogrammofon",
    "radiogrammofonens": "radiogrammofon",
    "radiogrammofoner": "radiogrammofon",
    "radiogrammofonerna": "radiogrammofon",
    "radiogrammofonernas": "radiogrammofon",
    "radiogrammofoners": "radiogrammofon",
    "radiogrammofons": "radiogrammofon",
    "radiograms": "radiogram",
    "radiohusen": "radiohus",
    "radiohusens": "radiohus",
    "radiohuset": "radiohus",
    "radiohusets": "radiohus",
    "radioisotopen": "radioisotop",
    "radioisotopens": "radioisotop",
    "radioisotoper": "radioisotop",
    "radioisotoperna": "radioisotop",
    "radioisotopernas": "radioisotop",
    "radioisotopers": "radioisotop",
    "radioisotops": "radioisotop",
    "radiokanalen": "radiokanal",
    "radiokanalens": "radiokanal",
    "radiokanaler": "radiokanal",
    "radiokanalerna": "radiokanal",
    "radiokanalernas": "radiokanal",
    "radiokanalers": "radiokanal",
    "radiokanals": "radiokanal",
    "radiokolet": "radiokol",
    "radiokolets": "radiokol",
    "radiokols": "radiokol",
    "radiokommunikationen": "radiokommunikation",
    "radiokommunikationens": "radiokommunikation",
    "radiokommunikations": "radiokommunikation",
    "radiokäll": "radiokälla",
    "radiokällan": "radiokälla",
    "radiokällans": "radiokälla",
    "radiokällas": "radiokälla",
    "radiokälle": "radiokälla",
    "radiokällor": "radiokälla",
    "radiokällorna": "radiokälla",
    "radiokällornas": "radiokälla",
    "radiokällors": "radiokälla",
    "radiokälls": "radiokälla",
    "radiolagen": "radiolag",
    "radiolagens": "radiolag",
    "radiolags": "radiolag",
    "radiolarien": "radiolarie",
    "radiolariens": "radiolarie",
    "radiolarier": "radiolarie",
    "radiolarierna": "radiolarie",
    "radiolariernas": "radiolarie",
    "radiolariers": "radiolarie",
    "radiolaries": "radiolarie",
    "radiologen": "radiolog",
    "radiologens": "radiolog",
    "radiologer": "radiolog",
    "radiologerna": "radiolog",
    "radiologernas": "radiolog",
    "radiologers": "radiolog",
    "radiologien": "radiologi",
    "radiologiens": "radiologi",
    "radiologin": "radiologi",
    "radiologins": "radiologi",
    "radiologis": "radiologi",
    "radiologs": "radiolog",
    "radiolänkar": "radiolänk",
    "radiolänkarna": "radiolänk",
    "radiolänkarnas": "radiolänk",
    "radiolänkars": "radiolänk",
    "radiolänken": "radiolänk",
    "radiolänkens": "radiolänk",
    "radiolänks": "radiolänk",
    "radiomannen": "radioman",
    "radiomannens": "radioman",
    "radiomans": "radioman",
    "radiometern": "radiometer",
    "radiometerns": "radiometer",
    "radiometers": "radiometer",
    "radiometrar": "radiometer",
    "radiometrarna": "radiometer",
    "radiometrarnas": "radiometer",
    "radiometrars": "radiometer",
    "radiomottagar": "radiomottagare",
    "radiomottagaren": "radiomottagare",
    "radiomottagarens": "radiomottagare",
    "radiomottagares": "radiomottagare",
    "radiomottagarna": "radiomottagare",
    "radiomottagarnas": "radiomottagare",
    "radiomän": "radioman",
    "radiomännen": "radioman",
    "radiomännens": "radioman",
    "radiomäns": "radioman",
    "radiomässiga": "radiomässig",
    "radiomässigare": "radiomässig",
    "radiomässigares": "radiomässig",
    "radiomässigas": "radiomässig",
    "radiomässigast": "radiomässig",
    "radiomässigaste": "radiomässig",
    "radiomässigastes": "radiomässig",
    "radiomässigasts": "radiomässig",
    "radiomässige": "radiomässig",
    "radiomässiges": "radiomässig",
    "radiomässigs": "radiomässig",
    "radiomässigt": "radiomässig",
    "radiomässigts": "radiomässig",
    "radion": "radio",
    "radionavigerade": "radionavigera",
    "radionavigerades": "radionavigera",
    "radionavigerande": "radionavigera",
    "radionavigeranden": "radionavigerande",
    "radionavigerandena": "radionavigerande",
    "radionavigerandenas": "radionavigerande",
    "radionavigerandens": "radionavigerande",
    "radionavigerandes": "radionavigerande",
    "radionavigerandet": "radionavigerande",
    "radionavigerandets": "radionavigerande",
    "radionavigerar": "radionavigera",
    "radionavigeras": "radionavigera",
    "radionavigerat": "radionavigera",
    "radionavigerats": "radionavigera",
    "radionavigerbara": "radionavigerbar",
    "radionavigerbarare": "radionavigerbar",
    "radionavigerbarares": "radionavigerbar",
    "radionavigerbaras": "radionavigerbar",
    "radionavigerbarast": "radionavigerbar",
    "radionavigerbaraste": "radionavigerbar",
    "radionavigerbarastes": "radionavigerbar",
    "radionavigerbarasts": "radionavigerbar",
    "radionavigerbare": "radionavigerbar",
    "radionavigerbares": "radionavigerbar",
    "radionavigerbarheten": "radionavigerbarhet",
    "radionavigerbarhetens": "radionavigerbarhet",
    "radionavigerbarhets": "radionavigerbarhet",
    "radionavigerbars": "radionavigerbar",
    "radionavigerbart": "radionavigerbar",
    "radionavigerbarts": "radionavigerbar",
    "radionavigeringar": "radionavigering",
    "radionavigeringarna": "radionavigering",
    "radionavigeringarnas": "radionavigering",
    "radionavigeringars": "radionavigering",
    "radionavigeringen": "radionavigering",
    "radionavigeringens": "radionavigering",
    "radionavigerings": "radionavigering",
    "radionavigeringssystemen": "radionavigeringssystem",
    "radionavigeringssystemens": "radionavigeringssystem",
    "radionavigeringssystemet": "radionavigeringssystem",
    "radionavigeringssystemets": "radionavigeringssystem",
    "radionavigeringssystems": "radionavigeringssystem",
    "radions": "radio",
    "radionämnden": "radionämnd",
    "radionämndens": "radionämnd",
    "radionämnds": "radionämnd",
    "radiopejlingar": "radiopejling",
    "radiopejlingarna": "radiopejling",
    "radiopejlingarnas": "radiopejling",
    "radiopejlingars": "radiopejling",
    "radiopejlingen": "radiopejling",
    "radiopejlingens": "radiopejling",
    "radiopejlings": "radiopejling",
    "radiopjäsen": "radiopjäs",
    "radiopjäsens": "radiopjäs",
    "radiopjäser": "radiopjäs",
    "radiopjäserna": "radiopjäs",
    "radiopjäsernas": "radiopjäs",
    "radiopjäsers": "radiopjäs",
    "radioprogrammen": "radioprogram",
    "radioprogrammens": "radioprogram",
    "radioprogrammet": "radioprogram",
    "radioprogrammets": "radioprogram",
    "radioprograms": "radioprogram",
    "radior": "radio",
    "radiorna": "radio",
    "radiornas": "radio",
    "radiors": "radio",
    "radiorören": "radiorör",
    "radiorörens": "radiorör",
    "radioröret": "radiorör",
    "radiorörets": "radiorör",
    "radiorörs": "radiorör",
    "radiorösten": "radioröst",
    "radioröstens": "radioröst",
    "radioröster": "radioröst",
    "radiorösterna": "radioröst",
    "radiorösternas": "radioröst",
    "radiorösters": "radioröst",
    "radiorösts": "radioröst",
    "radios": "radio",
    "radiosignalen": "radiosignal",
    "radiosignalens": "radiosignal",
    "radiosignaler": "radiosignal",
    "radiosignalerna": "radiosignal",
    "radiosignalernas": "radiosignal",
    "radiosignalers": "radiosignal",
    "radiosignals": "radiosignal",
    "radiosonden": "radiosond",
    "radiosondens": "radiosond",
    "radiosonder": "radiosond",
    "radiosonderna": "radiosond",
    "radiosondernas": "radiosond",
    "radiosonders": "radiosond",
    "radiosonds": "radiosond",
    "radiostationen": "radiostation",
    "radiostationens": "radiostation",
    "radiostationer": "radiostation",
    "radiostationerna": "radiostation",
    "radiostationernas": "radiostation",
    "radiostationers": "radiostation",
    "radiostations": "radiostation",
    "radiostrålningar": "radiostrålning",
    "radiostrålningarna": "radiostrålning",
    "radiostrålningarnas": "radiostrålning",
    "radiostrålningars": "radiostrålning",
    "radiostrålningen": "radiostrålning",
    "radiostrålningens": "radiostrålning",
    "radiostrålnings": "radiostrålning",
    "radiostyrde": "radiostyrd",
    "radiostyrdes": "radiostyrd",
    "radiostyrds": "radiostyrd",
    "radiostyrningar": "radiostyrning",
    "radiostyrningarna": "radiostyrning",
    "radiostyrningarnas": "radiostyrning",
    "radiostyrningars": "radiostyrning",
    "radiostyrningen": "radiostyrning",
    "radiostyrningens": "radiostyrning",
    "radiostyrnings": "radiostyrning",
    "radiostyrt": "radiostyrd",
    "radiostyrts": "radiostyrd",
    "radiostörningar": "radiostörning",
    "radiostörningarna": "radiostörning",
    "radiostörningarnas": "radiostörning",
    "radiostörningars": "radiostörning",
    "radiostörningen": "radiostörning",
    "radiostörningens": "radiostörning",
    "radiostörnings": "radiostörning",
    "radiosändar": "radiosändare",
    "radiosändaren": "radiosändare",
    "radiosändarens": "radiosändare",
    "radiosändares": "radiosändare",
    "radiosändarna": "radiosändare",
    "radiosändarnas": "radiosändare",
    "radiosändningar": "radiosändning",
    "radiosändningarna": "radiosändning",
    "radiosändningarnas": "radiosändning",
    "radiosändningars": "radiosändning",
    "radiosändningen": "radiosändning",
    "radiosändningens": "radiosändning",
    "radiosändnings": "radiosändning",
    "radiotaggar": "radiotagg",
    "radiotaggarna": "radiotagg",
    "radiotaggarnas": "radiotagg",
    "radiotaggars": "radiotagg",
    "radiotaggen": "radiotagg",
    "radiotaggens": "radiotagg",
    "radiotaggs": "radiotagg",
    "radiotekniken": "radioteknik",
    "radioteknikens": "radioteknik",
    "radiotekniker": "radioteknik",
    "radioteknikerna": "radioteknik",
    "radioteknikernas": "radioteknik",
    "radioteknikers": "radioteknik",
    "radiotekniks": "radioteknik",
    "radiotelefonen": "radiotelefon",
    "radiotelefonens": "radiotelefon",
    "radiotelefoner": "radiotelefon",
    "radiotelefonerna": "radiotelefon",
    "radiotelefonernas": "radiotelefon",
    "radiotelefoners": "radiotelefon",
    "radiotelefons": "radiotelefon",
    "radiotelegrafien": "radiotelegrafi",
    "radiotelegrafiens": "radiotelegrafi",
    "radiotelegrafin": "radiotelegrafi",
    "radiotelegrafins": "radiotelegrafi",
    "radiotelegrafis": "radiotelegrafi",
    "radiotelegrafisten": "radiotelegrafist",
    "radiotelegrafistens": "radiotelegrafist",
    "radiotelegrafister": "radiotelegrafist",
    "radiotelegrafisterna": "radiotelegrafist",
    "radiotelegrafisternas": "radiotelegrafist",
    "radiotelegrafisters": "radiotelegrafist",
    "radiotelegrafists": "radiotelegrafist",
    "radioteleskopen": "radioteleskop",
    "radioteleskopens": "radioteleskop",
    "radioteleskopet": "radioteleskop",
    "radioteleskopets": "radioteleskop",
    "radioteleskops": "radioteleskop",
    "radioten": "radiot",
    "radiotens": "radiot",
    "radioter": "radiot",
    "radioterapien": "radioterapi",
    "radioterapiens": "radioterapi",
    "radioterapin": "radioterapi",
    "radioterapins": "radioterapi",
    "radioterapis": "radioterapi",
    "radioterna": "radiot",
    "radioternas": "radiot",
    "radioters": "radiot",
    "radiotrafiken": "radiotrafik",
    "radiotrafikens": "radiotrafik",
    "radiotrafiks": "radiotrafik",
    "radiots": "radiot",
    "radiotänger": "radiotång",
    "radiotängerna": "radiotång",
    "radiotängernas": "radiotång",
    "radiotängers": "radiotång",
    "radiotången": "radiotång",
    "radiotångens": "radiotång",
    "radiotångs": "radiotång",
    "radioutsändningar": "radioutsändning",
    "radioutsändningarna": "radioutsändning",
    "radioutsändningarnas": "radioutsändning",
    "radioutsändningars": "radioutsändning",
    "radioutsändningen": "radioutsändning",
    "radioutsändningens": "radioutsändning",
    "radioutsändnings": "radioutsändning",
    "radiovågen": "radiovåg",
    "radiovågens": "radiovåg",
    "radiovågor": "radiovåg",
    "radiovågorna": "radiovåg",
    "radiovågornas": "radiovåg",
    "radiovågors": "radiovåg",
    "radiovågs": "radiovåg",
    "radiumet": "radium",
    "radiumets": "radium",
    "radiums": "radium",
    "radj": "radja",
    "radjan": "radja",
    "radjans": "radja",
    "radjas": "radja",
    "radje": "radja",
    "radjor": "radja",
    "radjorna": "radja",
    "radjornas": "radja",
    "radjors": "radja",
    "radjs": "radja",
    "radondottern": "radondotter",
    "radondotterns": "radondotter",
    "radondotters": "radondotter",
    "radondöttrar": "radondotter",
    "radondöttrarna": "radondotter",
    "radondöttrarnas": "radondotter",
    "radondöttrars": "radondotter",
    "radonen": "radon",
    "radonens": "radon",
    "radonet": "radon",
    "radonets": "radon",
    "radonhusen": "radonhus",
    "radonhusens": "radonhus",
    "radonhuset": "radonhus",
    "radonhusets": "radonhus",
    "radons": "radon",
    "rads": "rad",
    "radskiftar": "radskiftare",
    "radskiftaren": "radskiftare",
    "radskiftarens": "radskiftare",
    "radskiftares": "radskiftare",
    "radskiftarna": "radskiftare",
    "radskiftarnas": "radskiftare",
    "radskrivar": "radskrivare",
    "radskrivaren": "radskrivare",
    "radskrivarens": "radskrivare",
    "radskrivares": "radskrivare",
    "radskrivarna": "radskrivare",
    "radskrivarnas": "radskrivare",
    "radslutssignalen": "radslutssignal",
    "radslutssignalens": "radslutssignal",
    "radslutssignaler": "radslutssignal",
    "radslutssignalerna": "radslutssignal",
    "radslutssignalernas": "radslutssignal",
    "radslutssignalers": "radslutssignal",
    "radslutssignals": "radslutssignal",
    "raffeln": "raffel",
    "raffelns": "raffel",
    "raffels": "raffel",
    "raffiga": "raffig",
    "raffigare": "raffig",
    "raffigares": "raffig",
    "raffigas": "raffig",
    "raffigast": "raffig",
    "raffigaste": "raffig",
    "raffigastes": "raffig",
    "raffigasts": "raffig",
    "raffige": "raffig",
    "raffiges": "raffig",
    "raffigheten": "raffighet",
    "raffighetens": "raffighet",
    "raffighets": "raffighet",
    "raffigs": "raffig",
    "raffigt": "raffig",
    "raffigts": "raffig",
    "raffinaden": "raffinad",
    "raffinadens": "raffinad",
    "raffinader": "raffinad",
    "raffinaderier": "raffinaderi",
    "raffinaderierna": "raffinaderi",
    "raffinaderiernas": "raffinaderi",
    "raffinaderiers": "raffinaderi",
    "raffinaderiet": "raffinaderi",
    "raffinaderiets": "raffinaderi",
    "raffinaderis": "raffinaderi",
    "raffinaderit": "raffinaderi",
    "raffinaderits": "raffinaderi",
    "raffinaderna": "raffinad",
    "raffinadernas": "raffinad",
    "raffinaders": "raffinad",
    "raffinads": "raffinad",
    "raffinemangen": "raffinemang",
    "raffinemangens": "raffinemang",
    "raffinemanget": "raffinemang",
    "raffinemangets": "raffinemang",
    "raffinemangs": "raffinemang",
    "raffinerad": "raffinera",
    "raffinerade": "raffinerad",
    "raffinerades": "raffinerad",
    "raffinerads": "raffinerad",
    "raffinerande": "raffinera",
    "raffineranden": "raffinerande",
    "raffinerandena": "raffinerande",
    "raffinerandenas": "raffinerande",
    "raffinerandens": "raffinerande",
    "raffinerandes": "raffinerande",
    "raffinerandet": "raffinerande",
    "raffinerandets": "raffinerande",
    "raffinerar": "raffinera",
    "raffineras": "raffinera",
    "raffinerat": "raffinerad",
    "raffinerats": "raffinerad",
    "raffinerbara": "raffinerbar",
    "raffinerbarare": "raffinerbar",
    "raffinerbarares": "raffinerbar",
    "raffinerbaras": "raffinerbar",
    "raffinerbarast": "raffinerbar",
    "raffinerbaraste": "raffinerbar",
    "raffinerbarastes": "raffinerbar",
    "raffinerbarasts": "raffinerbar",
    "raffinerbare": "raffinerbar",
    "raffinerbares": "raffinerbar",
    "raffinerbarheten": "raffinerbarhet",
    "raffinerbarhetens": "raffinerbarhet",
    "raffinerbarhets": "raffinerbarhet",
    "raffinerbars": "raffinerbar",
    "raffinerbart": "raffinerbar",
    "raffinerbarts": "raffinerbar",
    "raffineringar": "raffinering",
    "raffineringarna": "raffinering",
    "raffineringarnas": "raffinering",
    "raffineringars": "raffinering",
    "raffineringen": "raffinering",
    "raffineringens": "raffinering",
    "raffinerings": "raffinering",
    "rafflet": "raffel",
    "rafflets": "raffel",
    "raffliga": "rafflig",
    "raffligare": "rafflig",
    "raffligares": "rafflig",
    "raffligas": "rafflig",
    "raffligast": "rafflig",
    "raffligaste": "rafflig",
    "raffligastes": "rafflig",
    "raffligasts": "rafflig",
    "rafflige": "rafflig",
    "raffliges": "rafflig",
    "raffligheten": "rafflighet",
    "rafflighetens": "rafflighet",
    "rafflighets": "rafflighet",
    "raffligs": "rafflig",
    "raffligt": "rafflig",
    "raffligts": "rafflig",
    "rafistulerade": "rafistulera",
    "rafistulerades": "rafistulera",
    "rafistulerande": "rafistulera",
    "rafistuleranden": "rafistulerande",
    "rafistulerandena": "rafistulerande",
    "rafistulerandenas": "rafistulerande",
    "rafistulerandens": "rafistulerande",
    "rafistulerandes": "rafistulerande",
    "rafistulerandet": "rafistulerande",
    "rafistulerandets": "rafistulerande",
    "rafistulerar": "rafistulera",
    "rafistuleras": "rafistulera",
    "rafistulerat": "rafistulera",
    "rafistulerats": "rafistulera",
    "rafistuleringar": "rafistulering",
    "rafistuleringarna": "rafistulering",
    "rafistuleringarnas": "rafistulering",
    "rafistuleringars": "rafistulering",
    "rafistuleringen": "rafistulering",
    "rafistuleringens": "rafistulering",
    "rafistulerings": "rafistulering",
    "rafräschissören": "rafräschissör",
    "rafräschissörens": "rafräschissör",
    "rafräschissörer": "rafräschissör",
    "rafräschissörerna": "rafräschissör",
    "rafräschissörernas": "rafräschissör",
    "rafräschissörers": "rafräschissör",
    "rafräschissörs": "rafräschissör",
    "rafs": "rafsa",
    "rafsade": "rafsa",
    "rafsades": "rafsa",
    "rafsande": "rafsa",
    "rafsandes": "rafsa",
    "rafsar": "rafsa",
    "rafsas": "rafsa",
    "rafsat": "rafsa",
    "rafsats": "rafsa",
    "rag": "raga",
    "ragan": "raga",
    "ragans": "raga",
    "ragas": "raga",
    "ragat": "ragata",
    "ragatan": "ragata",
    "ragatans": "ragata",
    "ragatas": "ragata",
    "ragate": "ragata",
    "ragator": "ragata",
    "ragatorna": "ragata",
    "ragatornas": "ragata",
    "ragators": "ragata",
    "ragats": "ragata",
    "rage": "raga",
    "ragg": "ragga",
    "raggad": "ragga",
    "raggade": "ragga",
    "raggades": "ragga",
    "raggads": "ragga",
    "raggande": "ragga",
    "ragganden": "raggande",
    "raggandena": "raggande",
    "raggandenas": "raggande",
    "raggandens": "raggande",
    "raggandes": "raggande",
    "raggandet": "raggande",
    "raggandets": "raggande",
    "raggar": "raggare",
    "raggarbilar": "raggarbil",
    "raggarbilarna": "raggarbil",
    "raggarbilarnas": "raggarbil",
    "raggarbilars": "raggarbil",
    "raggarbilen": "raggarbil",
    "raggarbilens": "raggarbil",
    "raggarbils": "raggarbil",
    "raggarbrudar": "raggarbrud",
    "raggarbrudarna": "raggarbrud",
    "raggarbrudarnas": "raggarbrud",
    "raggarbrudars": "raggarbrud",
    "raggarbruden": "raggarbrud",
    "raggarbrudens": "raggarbrud",
    "raggarbruds": "raggarbrud",
    "raggaren": "raggare",
    "raggarens": "raggare",
    "raggares": "raggare",
    "raggarna": "raggare",
    "raggarnas": "raggare",
    "raggas": "ragga",
    "raggat": "ragga",
    "raggats": "ragga",
    "raggen": "ragg",
    "raggens": "ragg",
    "ragget": "ragg",
    "raggets": "ragg",
    "raggiga": "raggig",
    "raggigare": "raggig",
    "raggigares": "raggig",
    "raggigas": "raggig",
    "raggigast": "raggig",
    "raggigaste": "raggig",
    "raggigastes": "raggig",
    "raggigasts": "raggig",
    "raggige": "raggig",
    "raggiges": "raggig",
    "raggigheten": "raggighet",
    "raggighetens": "raggighet",
    "raggighets": "raggighet",
    "raggigs": "raggig",
    "raggigt": "raggig",
    "raggigts": "raggig",
    "ragglade": "raggla",
    "ragglades": "raggla",
    "ragglande": "raggla",
    "ragglanden": "ragglande",
    "ragglandena": "ragglande",
    "ragglandenas": "ragglande",
    "ragglandens": "ragglande",
    "ragglandes": "ragglande",
    "ragglandet": "ragglande",
    "ragglandets": "ragglande",
    "ragglar": "raggla",
    "ragglas": "raggla",
    "ragglat": "raggla",
    "ragglats": "raggla",
    "raggmunkar": "raggmunk",
    "raggmunkarna": "raggmunk",
    "raggmunkarnas": "raggmunk",
    "raggmunkars": "raggmunk",
    "raggmunken": "raggmunk",
    "raggmunkens": "raggmunk",
    "raggmunkmixen": "raggmunkmix",
    "raggmunkmixens": "raggmunkmix",
    "raggmunkmixer": "raggmunkmix",
    "raggmunkmixerna": "raggmunkmix",
    "raggmunkmixernas": "raggmunkmix",
    "raggmunkmixers": "raggmunkmix",
    "raggmunks": "raggmunk",
    "raggs": "ragg",
    "raggsock": "raggsocka",
    "raggsockan": "raggsocka",
    "raggsockans": "raggsocka",
    "raggsockas": "raggsocka",
    "raggsocke": "raggsocka",
    "raggsockor": "raggsocka",
    "raggsockorna": "raggsocka",
    "raggsockornas": "raggsocka",
    "raggsockors": "raggsocka",
    "raggsocks": "raggsocka",
    "raglade": "ragla",
    "raglades": "ragla",
    "raglande": "ragla",
    "raglanden": "raglande",
    "raglandena": "raglande",
    "raglandenas": "raglande",
    "raglandens": "raglande",
    "raglandes": "raglande",
    "raglandet": "raglande",
    "raglandets": "raglande",
    "raglans": "raglan",
    "raglanärmar": "raglanärm",
    "raglanärmarna": "raglanärm",
    "raglanärmarnas": "raglanärm",
    "raglanärmars": "raglanärm",
    "raglanärmen": "raglanärm",
    "raglanärmens": "raglanärm",
    "raglanärms": "raglanärm",
    "raglar": "ragla",
    "raglas": "ragla",
    "raglat": "ragla",
    "raglats": "ragla",
    "ragor": "raga",
    "ragorna": "raga",
    "ragornas": "raga",
    "ragors": "raga",
    "rags": "raga",
    "ragtimen": "ragtime",
    "ragtimens": "ragtime",
    "ragtimes": "ragtime",
    "raguer": "ragu",
    "raguerna": "ragu",
    "raguernas": "ragu",
    "raguers": "ragu",
    "ragun": "ragu",
    "raguns": "ragu",
    "ragus": "ragu",
    "raiden": "raid",
    "raidens": "raid",
    "raider": "raid",
    "raiderna": "raid",
    "raidernas": "raid",
    "raiders": "raid",
    "raids": "raid",
    "raj": "raja",
    "rajan": "raja",
    "rajans": "raja",
    "rajas": "raja",
    "rajden": "rajd",
    "rajdens": "rajd",
    "rajder": "rajd",
    "rajderna": "rajd",
    "rajdernas": "rajd",
    "rajders": "rajd",
    "rajds": "rajd",
    "raje": "raja",
    "rajgräset": "rajgräs",
    "rajgräsets": "rajgräs",
    "rajor": "raja",
    "rajorna": "raja",
    "rajornas": "raja",
    "rajors": "raja",
    "rajs": "raja",
    "rak": "raka",
    "raka": "rak",
    "rakad": "raka",
    "rakade": "raka",
    "rakades": "raka",
    "rakads": "raka",
    "rakan": "raka",
    "rakande": "raka",
    "rakanden": "rakande",
    "rakandena": "rakande",
    "rakandenas": "rakande",
    "rakandens": "rakande",
    "rakandes": "rakande",
    "rakandet": "rakande",
    "rakandets": "rakande",
    "rakans": "raka",
    "rakapparaten": "rakapparat",
    "rakapparatens": "rakapparat",
    "rakapparater": "rakapparat",
    "rakapparaterna": "rakapparat",
    "rakapparaternas": "rakapparat",
    "rakapparaters": "rakapparat",
    "rakapparats": "rakapparat",
    "rakar": "raka",
    "rakare": "rak",
    "rakares": "rak",
    "rakas": "raka",
    "rakast": "rak",
    "rakaste": "rak",
    "rakastes": "rak",
    "rakasts": "rak",
    "rakat": "raka",
    "rakats": "raka",
    "rakbladen": "rakblad",
    "rakbladens": "rakblad",
    "rakbladet": "rakblad",
    "rakbladets": "rakblad",
    "rakblads": "rakblad",
    "rakborst": "rakborste",
    "rakborstar": "rakborste",
    "rakborstarna": "rakborste",
    "rakborstarnas": "rakborste",
    "rakborstars": "rakborste",
    "rakborsten": "rakborste",
    "rakborstens": "rakborste",
    "rakborstes": "rakborste",
    "rake": "raka",
    "rakes": "rak",
    "raketbasen": "raketbas",
    "raketbasens": "raketbas",
    "raketbaser": "raketbas",
    "raketbaserna": "raketbas",
    "raketbasernas": "raketbas",
    "raketbasers": "raketbas",
    "raketdriften": "raketdrift",
    "raketdriftens": "raketdrift",
    "raketdrifts": "raketdrift",
    "raketen": "raket",
    "raketens": "raket",
    "raketer": "raket",
    "raketerna": "raket",
    "raketernas": "raket",
    "raketers": "raket",
    "raketfarten": "raketfart",
    "raketfartens": "raketfart",
    "raketfarts": "raketfart",
    "raketfärden": "raketfärd",
    "raketfärdens": "raketfärd",
    "raketfärder": "raketfärd",
    "raketfärderna": "raketfärd",
    "raketfärdernas": "raketfärd",
    "raketfärders": "raketfärd",
    "raketfärds": "raketfärd",
    "raketgevären": "raketgevär",
    "raketgevärens": "raketgevär",
    "raketgeväret": "raketgevär",
    "raketgevärets": "raketgevär",
    "raketgevärs": "raketgevär",
    "raketkonstruktören": "raketkonstruktör",
    "raketkonstruktörens": "raketkonstruktör",
    "raketkonstruktörer": "raketkonstruktör",
    "raketkonstruktörerna": "raketkonstruktör",
    "raketkonstruktörernas": "raketkonstruktör",
    "raketkonstruktörers": "raketkonstruktör",
    "raketkonstruktörs": "raketkonstruktör",
    "raketmotorer": "raketmotor",
    "raketmotorerna": "raketmotor",
    "raketmotorernas": "raketmotor",
    "raketmotorers": "raketmotor",
    "raketmotorn": "raketmotor",
    "raketmotorns": "raketmotor",
    "raketmotors": "raketmotor",
    "rakets": "raket",
    "raketstegen": "raketsteg",
    "raketstegens": "raketsteg",
    "raketsteget": "raketsteg",
    "raketstegets": "raketsteg",
    "raketstegs": "raketsteg",
    "raketvapens": "raketvapen",
    "raketvapnen": "raketvapen",
    "raketvapnens": "raketvapen",
    "raketvapnet": "raketvapen",
    "raketvapnets": "raketvapen",
    "rakheten": "rakhet",
    "rakhetens": "rakhet",
    "rakhets": "rakhet",
    "rakhyveln": "rakhyvel",
    "rakhyvelns": "rakhyvel",
    "rakhyvels": "rakhyvel",
    "rakhyvlar": "rakhyvel",
    "rakhyvlarna": "rakhyvel",
    "rakhyvlarnas": "rakhyvel",
    "rakhyvlars": "rakhyvel",
    "rakitisen": "rakitis",
    "rakitisens": "rakitis",
    "rakitiska": "rakitisk",
    "rakitiskare": "rakitisk",
    "rakitiskares": "rakitisk",
    "rakitiskas": "rakitisk",
    "rakitiskast": "rakitisk",
    "rakitiskaste": "rakitisk",
    "rakitiskastes": "rakitisk",
    "rakitiskasts": "rakitisk",
    "rakitiske": "rakitisk",
    "rakitiskes": "rakitisk",
    "rakitisks": "rakitisk",
    "rakitiskt": "rakitisk",
    "rakitiskts": "rakitisk",
    "rakknivar": "rakkniv",
    "rakknivarna": "rakkniv",
    "rakknivarnas": "rakkniv",
    "rakknivars": "rakkniv",
    "rakkniven": "rakkniv",
    "rakknivens": "rakkniv",
    "rakknivs": "rakkniv",
    "raklinjiga": "raklinjig",
    "raklinjigare": "raklinjig",
    "raklinjigares": "raklinjig",
    "raklinjigas": "raklinjig",
    "raklinjigast": "raklinjig",
    "raklinjigaste": "raklinjig",
    "raklinjigastes": "raklinjig",
    "raklinjigasts": "raklinjig",
    "raklinjige": "raklinjig",
    "raklinjiges": "raklinjig",
    "raklinjigheten": "raklinjighet",
    "raklinjighetens": "raklinjighet",
    "raklinjighets": "raklinjighet",
    "raklinjigs": "raklinjig",
    "raklinjigt": "raklinjig",
    "raklinjigts": "raklinjig",
    "raklånga": "raklång",
    "raklångare": "raklång",
    "raklångares": "raklång",
    "raklångas": "raklång",
    "raklångast": "raklång",
    "raklångaste": "raklång",
    "raklångastes": "raklång",
    "raklångasts": "raklång",
    "raklånge": "raklång",
    "raklånges": "raklång",
    "raklångs": "raklång",
    "raklångt": "raklång",
    "raklångts": "raklång",
    "raklödders": "raklödder",
    "raklöddret": "raklödder",
    "raklöddrets": "raklödder",
    "raknade": "rakna",
    "raknades": "rakna",
    "raknande": "rakna",
    "raknanden": "raknande",
    "raknandena": "raknande",
    "raknandenas": "raknande",
    "raknandens": "raknande",
    "raknandes": "raknande",
    "raknandet": "raknande",
    "raknandets": "raknande",
    "raknar": "rakna",
    "raknas": "rakna",
    "raknat": "rakna",
    "raknats": "rakna",
    "rakningar": "rakning",
    "rakningarna": "rakning",
    "rakningarnas": "rakning",
    "rakningars": "rakning",
    "rakningen": "rakning",
    "rakningens": "rakning",
    "raknings": "rakning",
    "rakor": "raka",
    "rakorna": "raka",
    "rakornas": "raka",
    "rakors": "raka",
    "rakryggade": "rakryggad",
    "rakryggades": "rakryggad",
    "rakryggads": "rakryggad",
    "rakryggat": "rakryggad",
    "rakryggats": "rakryggad",
    "raks": "raka",
    "rakspegeln": "rakspegel",
    "rakspegelns": "rakspegel",
    "rakspegels": "rakspegel",
    "rakspeglar": "rakspegel",
    "rakspeglarna": "rakspegel",
    "rakspeglarnas": "rakspegel",
    "rakspeglars": "rakspegel",
    "rakstrigeln": "rakstrigel",
    "rakstrigelns": "rakstrigel",
    "rakstrigels": "rakstrigel",
    "rakstriglar": "rakstrigel",
    "rakstriglarna": "rakstrigel",
    "rakstriglarnas": "rakstrigel",
    "rakstriglars": "rakstrigel",
    "raksträck": "raksträcka",
    "raksträckan": "raksträcka",
    "raksträckans": "raksträcka",
    "raksträckas": "raksträcka",
    "raksträcke": "raksträcka",
    "raksträckor": "raksträcka",
    "raksträckorna": "raksträcka",
    "raksträckornas": "raksträcka",
    "raksträckors": "raksträcka",
    "raksträcks": "raksträcka",
    "rakt": "rak",
    "rakts": "rak",
    "raktvålar": "raktvål",
    "raktvålarna": "raktvål",
    "raktvålarnas": "raktvål",
    "raktvålars": "raktvål",
    "raktvålen": "raktvål",
    "raktvålens": "raktvål",
    "raktvåls": "raktvål",
    "rakvattens": "rakvatten",
    "rakvattnen": "rakvatten",
    "rakvattnens": "rakvatten",
    "rakvattnet": "rakvatten",
    "rakvattnets": "rakvatten",
    "raljansen": "raljans",
    "raljansens": "raljans",
    "raljanta": "raljant",
    "raljantare": "raljant",
    "raljantares": "raljant",
    "raljantas": "raljant",
    "raljantast": "raljant",
    "raljantaste": "raljant",
    "raljantastes": "raljant",
    "raljantasts": "raljant",
    "raljante": "raljant",
    "raljantes": "raljant",
    "raljants": "raljant",
    "raljerade": "raljera",
    "raljerades": "raljera",
    "raljerande": "raljera",
    "raljeranden": "raljerande",
    "raljerandena": "raljerande",
    "raljerandenas": "raljerande",
    "raljerandens": "raljerande",
    "raljerandes": "raljerande",
    "raljerandet": "raljerande",
    "raljerandets": "raljerande",
    "raljerar": "raljera",
    "raljeras": "raljera",
    "raljerat": "raljera",
    "raljerats": "raljera",
    "raljerier": "raljeri",
    "raljerierna": "raljeri",
    "raljeriernas": "raljeri",
    "raljeriers": "raljeri",
    "raljeriet": "raljeri",
    "raljeriets": "raljeri",
    "raljeringar": "raljering",
    "raljeringarna": "raljering",
    "raljeringarnas": "raljering",
    "raljeringars": "raljering",
    "raljeringen": "raljering",
    "raljeringens": "raljering",
    "raljerings": "raljering",
    "raljeris": "raljeri",
    "raljerit": "raljeri",
    "raljerits": "raljeri",
    "rallar": "rallare",
    "rallarbasar": "rallarbas",
    "rallarbasarna": "rallarbas",
    "rallarbasarnas": "rallarbas",
    "rallarbasars": "rallarbas",
    "rallarbasen": "rallarbas",
    "rallarbasens": "rallarbas",
    "rallaren": "rallare",
    "rallarens": "rallare",
    "rallares": "rallare",
    "rallarna": "rallare",
    "rallarnas": "rallare",
    "rallarrosen": "rallarros",
    "rallarrosens": "rallarros",
    "rallarrosor": "rallarros",
    "rallarrosorna": "rallarros",
    "rallarrosornas": "rallarros",
    "rallarrosors": "rallarros",
    "rallars": "rall",
    "rallarsvingar": "rallarsving",
    "rallarsvingarna": "rallarsving",
    "rallarsvingarnas": "rallarsving",
    "rallarsvingars": "rallarsving",
    "rallarsvingen": "rallarsving",
    "rallarsvingens": "rallarsving",
    "rallarsvings": "rallarsving",
    "rallen": "rall",
    "rallens": "rall",
    "ralls": "rall",
    "rallycrossen": "rallycross",
    "rallycrossens": "rallycross",
    "rallyn": "rally",
    "rallyna": "rally",
    "rallynas": "rally",
    "rallyns": "rally",
    "rallys": "rally",
    "rallyt": "rally",
    "rallyts": "rally",
    "ram": "rama",
    "ramad": "rama",
    "ramadans": "ramadan",
    "ramade": "rama",
    "ramades": "rama",
    "ramads": "rama",
    "ramande": "rama",
    "ramanden": "ramande",
    "ramandena": "ramande",
    "ramandenas": "ramande",
    "ramandens": "ramande",
    "ramandes": "ramande",
    "ramandet": "ramande",
    "ramandets": "ramande",
    "ramar": "rama",
    "ramarna": "ram",
    "ramarnas": "ram",
    "ramars": "ram",
    "ramas": "rama",
    "ramaskrien": "ramaskri",
    "ramaskriens": "ramaskri",
    "ramaskriet": "ramaskri",
    "ramaskriets": "ramaskri",
    "ramaskrin": "ramaskri",
    "ramaskrina": "ramaskri",
    "ramaskrinas": "ramaskri",
    "ramaskrins": "ramaskri",
    "ramaskris": "ramaskri",
    "ramaskrit": "ramaskri",
    "ramaskrits": "ramaskri",
    "ramat": "rama",
    "ramats": "rama",
    "ramavtalen": "ramavtal",
    "ramavtalens": "ramavtal",
    "ramavtalet": "ramavtal",
    "ramavtalets": "ramavtal",
    "ramavtals": "ramavtal",
    "ramberättelsen": "ramberättelse",
    "ramberättelsens": "ramberättelse",
    "ramberättelser": "ramberättelse",
    "ramberättelserna": "ramberättelse",
    "ramberättelsernas": "ramberättelse",
    "ramberättelsers": "ramberättelse",
    "ramberättelses": "ramberättelse",
    "rambudgetar": "rambudget",
    "rambudgetarna": "rambudget",
    "rambudgetarnas": "rambudget",
    "rambudgetars": "rambudget",
    "rambudgeten": "rambudget",
    "rambudgetens": "rambudget",
    "rambudgeter": "rambudget",
    "rambudgeterna": "rambudget",
    "rambudgeternas": "rambudget",
    "rambudgeters": "rambudget",
    "rambudgets": "rambudget",
    "ramen": "ram",
    "ramens": "ram",
    "ramlade": "ramla",
    "ramlades": "ramla",
    "ramlande": "ramla",
    "ramlanden": "ramlande",
    "ramlandena": "ramlande",
    "ramlandenas": "ramlande",
    "ramlandens": "ramlande",
    "ramlandes": "ramlande",
    "ramlandet": "ramlande",
    "ramlandets": "ramlande",
    "ramlar": "ramlare",
    "ramlaren": "ramlare",
    "ramlarens": "ramlare",
    "ramlares": "ramlare",
    "ramlarna": "ramlare",
    "ramlarnas": "ramlare",
    "ramlas": "ramla",
    "ramlat": "ramla",
    "ramlats": "ramla",
    "ramlös": "ramlösa",
    "ramlösan": "ramlösa",
    "ramlösans": "ramlösa",
    "ramlösas": "ramlösa",
    "ramlöse": "ramlösa",
    "ramlösor": "ramlösa",
    "ramlösorna": "ramlösa",
    "ramlösornas": "ramlösa",
    "ramlösors": "ramlösa",
    "rammad": "ramma",
    "rammade": "ramma",
    "rammades": "ramma",
    "rammads": "ramma",
    "rammande": "ramma",
    "rammanden": "rammande",
    "rammandena": "rammande",
    "rammandenas": "rammande",
    "rammandens": "rammande",
    "rammandes": "rammande",
    "rammandet": "rammande",
    "rammandets": "rammande",
    "rammar": "ramma",
    "rammarna": "ramm",
    "rammarnas": "ramm",
    "rammars": "ramm",
    "rammas": "ramma",
    "rammat": "ramma",
    "rammats": "ramma",
    "rammelbuljongen": "rammelbuljong",
    "rammelbuljongens": "rammelbuljong",
    "rammelbuljongs": "rammelbuljong",
    "rammen": "ramm",
    "rammens": "ramm",
    "ramms": "ramm",
    "ramningar": "ramning",
    "ramningarna": "ramning",
    "ramningarnas": "ramning",
    "ramningars": "ramning",
    "ramningen": "ramning",
    "ramningens": "ramning",
    "ramnings": "ramning",
    "rampen": "ramp",
    "rampens": "ramp",
    "ramper": "ramp",
    "ramperna": "ramp",
    "rampernas": "ramp",
    "rampers": "ramp",
    "rampfebern": "rampfeber",
    "rampfeberns": "rampfeber",
    "rampfebers": "rampfeber",
    "rampljuset": "rampljus",
    "rampljusets": "rampljus",
    "ramponerad": "ramponera",
    "ramponerade": "ramponera",
    "ramponerades": "ramponera",
    "ramponerads": "ramponera",
    "ramponerande": "ramponera",
    "ramponeranden": "ramponerande",
    "ramponerandena": "ramponerande",
    "ramponerandenas": "ramponerande",
    "ramponerandens": "ramponerande",
    "ramponerandes": "ramponerande",
    "ramponerandet": "ramponerande",
    "ramponerandets": "ramponerande",
    "ramponerar": "ramponera",
    "ramponeras": "ramponera",
    "ramponerat": "ramponera",
    "ramponerats": "ramponera",
    "ramponerbara": "ramponerbar",
    "ramponerbarare": "ramponerbar",
    "ramponerbarares": "ramponerbar",
    "ramponerbaras": "ramponerbar",
    "ramponerbarast": "ramponerbar",
    "ramponerbaraste": "ramponerbar",
    "ramponerbarastes": "ramponerbar",
    "ramponerbarasts": "ramponerbar",
    "ramponerbare": "ramponerbar",
    "ramponerbares": "ramponerbar",
    "ramponerbarheten": "ramponerbarhet",
    "ramponerbarhetens": "ramponerbarhet",
    "ramponerbarhets": "ramponerbarhet",
    "ramponerbars": "ramponerbar",
    "ramponerbart": "ramponerbar",
    "ramponerbarts": "ramponerbar",
    "ramponeringar": "ramponering",
    "ramponeringarna": "ramponering",
    "ramponeringarnas": "ramponering",
    "ramponeringars": "ramponering",
    "ramponeringen": "ramponering",
    "ramponeringens": "ramponering",
    "ramponerings": "ramponering",
    "ramprisen": "rampris",
    "ramprisens": "rampris",
    "rampriser": "rampris",
    "rampriserna": "rampris",
    "ramprisernas": "rampris",
    "ramprisers": "rampris",
    "rampriset": "rampris",
    "ramprisets": "rampris",
    "ramps": "ramp",
    "rams": "ramsa",
    "ramsad": "ramsa",
    "ramsade": "ramsa",
    "ramsades": "ramsa",
    "ramsads": "ramsa",
    "ramsan": "ramsa",
    "ramsande": "ramsa",
    "ramsanden": "ramsande",
    "ramsandena": "ramsande",
    "ramsandenas": "ramsande",
    "ramsandens": "ramsande",
    "ramsandes": "ramsande",
    "ramsandet": "ramsande",
    "ramsandets": "ramsande",
    "ramsans": "ramsa",
    "ramsar": "ramsa",
    "ramsas": "ramsa",
    "ramsat": "ramsa",
    "ramsats": "ramsa",
    "ramse": "ramsa",
    "ramsen": "rams",
    "ramsens": "rams",
    "ramsor": "ramsa",
    "ramsorna": "ramsa",
    "ramsornas": "ramsa",
    "ramsors": "ramsa",
    "ramstarka": "ramstark",
    "ramstarkare": "ramstark",
    "ramstarkares": "ramstark",
    "ramstarkas": "ramstark",
    "ramstarkast": "ramstark",
    "ramstarkaste": "ramstark",
    "ramstarkastes": "ramstark",
    "ramstarkasts": "ramstark",
    "ramstarke": "ramstark",
    "ramstarkes": "ramstark",
    "ramstarkheten": "ramstarkhet",
    "ramstarkhetens": "ramstarkhet",
    "ramstarkhets": "ramstarkhet",
    "ramstarks": "ramstark",
    "ramstarkt": "ramstark",
    "ramstarkts": "ramstark",
    "ramsvarta": "ramsvart",
    "ramsvartare": "ramsvart",
    "ramsvartares": "ramsvart",
    "ramsvartas": "ramsvart",
    "ramsvartast": "ramsvart",
    "ramsvartaste": "ramsvart",
    "ramsvartastes": "ramsvart",
    "ramsvartasts": "ramsvart",
    "ramsvarte": "ramsvart",
    "ramsvartes": "ramsvart",
    "ramsvarts": "ramsvart",
    "ramverken": "ramverk",
    "ramverkens": "ramverk",
    "ramverket": "ramverk",
    "ramverkets": "ramverk",
    "ramverks": "ramverk",
    "ramverkstaden": "ramverkstad",
    "ramverkstadens": "ramverkstad",
    "ramverkstads": "ramverkstad",
    "ramverkstan": "ramverkstad",
    "ramverkstans": "ramverkstad",
    "ramverkstäder": "ramverkstad",
    "ramverkstäderna": "ramverkstad",
    "ramverkstädernas": "ramverkstad",
    "ramverkstäders": "ramverkstad",
    "ran": "rana",
    "ranan": "rana",
    "ranans": "rana",
    "ranas": "rana",
    "ranchen": "ranch",
    "ranchens": "ranch",
    "rancher": "ranch",
    "rancherna": "ranch",
    "ranchernas": "ranch",
    "ranchers": "ranch",
    "ranchs": "ranch",
    "ranchägar": "ranchägare",
    "ranchägaren": "ranchägare",
    "ranchägarens": "ranchägare",
    "ranchägares": "ranchägare",
    "ranchägarna": "ranchägare",
    "ranchägarnas": "ranchägare",
    "rancunen": "rancune",
    "rancunens": "rancune",
    "rancuner": "rancune",
    "rancunerna": "rancune",
    "rancunernas": "rancune",
    "rancuners": "rancune",
    "rancunes": "rancune",
    "rand": "randa",
    "randad": "randa",
    "randade": "randa",
    "randades": "randas",
    "randads": "randa",
    "randande": "randa",
    "randanden": "randande",
    "randandena": "randande",
    "randandenas": "randande",
    "randandens": "randande",
    "randandes": "randande",
    "randandet": "randande",
    "randandets": "randande",
    "randanmärkningar": "randanmärkning",
    "randanmärkningarna": "randanmärkning",
    "randanmärkningarnas": "randanmärkning",
    "randanmärkningars": "randanmärkning",
    "randanmärkningen": "randanmärkning",
    "randanmärkningens": "randanmärkning",
    "randanmärknings": "randanmärkning",
    "randanteckningar": "randanteckning",
    "randanteckningarna": "randanteckning",
    "randanteckningarnas": "randanteckning",
    "randanteckningars": "randanteckning",
    "randanteckningen": "randanteckning",
    "randanteckningens": "randanteckning",
    "randantecknings": "randanteckning",
    "randar": "randa",
    "randas": "randa",
    "randat": "randa",
    "randats": "randas",
    "randbergen": "randberg",
    "randbergens": "randberg",
    "randberget": "randberg",
    "randbergets": "randberg",
    "randbergs": "randberg",
    "randbildningar": "randbildning",
    "randbildningarna": "randbildning",
    "randbildningarnas": "randbildning",
    "randbildningars": "randbildning",
    "randbildningen": "randbildning",
    "randbildningens": "randbildning",
    "randbildnings": "randbildning",
    "randdeltan": "randdelta",
    "randdeltana": "randdelta",
    "randdeltanas": "randdelta",
    "randdeltans": "randdelta",
    "randdeltas": "randdelta",
    "randdeltat": "randdelta",
    "randdeltats": "randdelta",
    "randen": "rand",
    "randens": "rand",
    "randfenomenen": "randfenomen",
    "randfenomenens": "randfenomen",
    "randfenomenet": "randfenomen",
    "randfenomenets": "randfenomen",
    "randfenomens": "randfenomen",
    "randhaven": "randhav",
    "randhavens": "randhav",
    "randhavet": "randhav",
    "randhavets": "randhav",
    "randhavs": "randhav",
    "randiga": "randig",
    "randigare": "randig",
    "randigares": "randig",
    "randigas": "randig",
    "randigast": "randig",
    "randigaste": "randig",
    "randigastes": "randig",
    "randigasts": "randig",
    "randige": "randig",
    "randiges": "randig",
    "randigheten": "randighet",
    "randighetens": "randighet",
    "randighets": "randighet",
    "randigs": "randig",
    "randigt": "randig",
    "randigts": "randig",
    "randomiserad": "randomisera",
    "randomiserade": "randomisera",
    "randomiserades": "randomisera",
    "randomiserads": "randomisera",
    "randomiserande": "randomisera",
    "randomiserandes": "randomisera",
    "randomiserar": "randomisera",
    "randomiseras": "randomisera",
    "randomiserat": "randomisera",
    "randomiserats": "randomisera",
    "randomiserbara": "randomiserbar",
    "randomiserbarare": "randomiserbar",
    "randomiserbarares": "randomiserbar",
    "randomiserbaras": "randomiserbar",
    "randomiserbarast": "randomiserbar",
    "randomiserbaraste": "randomiserbar",
    "randomiserbarastes": "randomiserbar",
    "randomiserbarasts": "randomiserbar",
    "randomiserbare": "randomiserbar",
    "randomiserbares": "randomiserbar",
    "randomiserbarheten": "randomiserbarhet",
    "randomiserbarhetens": "randomiserbarhet",
    "randomiserbarhets": "randomiserbarhet",
    "randomiserbars": "randomiserbar",
    "randomiserbart": "randomiserbar",
    "randomiserbarts": "randomiserbar",
    "randplatåer": "randplatå",
    "randplatåerna": "randplatå",
    "randplatåernas": "randplatå",
    "randplatåers": "randplatå",
    "randplatån": "randplatå",
    "randplatåns": "randplatå",
    "randplatås": "randplatå",
    "rands": "rand",
    "randsjöar": "randsjö",
    "randsjöarna": "randsjö",
    "randsjöarnas": "randsjö",
    "randsjöars": "randsjö",
    "randsjön": "randsjö",
    "randsjöns": "randsjö",
    "randsjös": "randsjö",
    "randsydda": "randsydd",
    "randsyddare": "randsydd",
    "randsyddares": "randsydd",
    "randsyddas": "randsydd",
    "randsyddast": "randsydd",
    "randsyddaste": "randsydd",
    "randsyddastes": "randsydd",
    "randsyddasts": "randsydd",
    "randsydde": "randsydd",
    "randsyddes": "randsydd",
    "randsydds": "randsydd",
    "randsytt": "randsydd",
    "randsytts": "randsydd",
    "rane": "rana",
    "rangel": "rangla",
    "rangen": "rang",
    "rangens": "rang",
    "rangerad": "rangera",
    "rangerade": "rangerad",
    "rangerades": "rangerad",
    "rangerads": "rangerad",
    "rangerande": "rangera",
    "rangeranden": "rangerande",
    "rangerandena": "rangerande",
    "rangerandenas": "rangerande",
    "rangerandens": "rangerande",
    "rangerandes": "rangerande",
    "rangerandet": "rangerande",
    "rangerandets": "rangerande",
    "rangerar": "rangera",
    "rangeras": "rangera",
    "rangerat": "rangerad",
    "rangerats": "rangerad",
    "rangerbangårdar": "rangerbangård",
    "rangerbangårdarna": "rangerbangård",
    "rangerbangårdarnas": "rangerbangård",
    "rangerbangårdars": "rangerbangård",
    "rangerbangården": "rangerbangård",
    "rangerbangårdens": "rangerbangård",
    "rangerbangårds": "rangerbangård",
    "rangerbara": "rangerbar",
    "rangerbarare": "rangerbar",
    "rangerbarares": "rangerbar",
    "rangerbaras": "rangerbar",
    "rangerbarast": "rangerbar",
    "rangerbaraste": "rangerbar",
    "rangerbarastes": "rangerbar",
    "rangerbarasts": "rangerbar",
    "rangerbare": "rangerbar",
    "rangerbares": "rangerbar",
    "rangerbarheten": "rangerbarhet",
    "rangerbarhetens": "rangerbarhet",
    "rangerbarhets": "rangerbarhet",
    "rangerbars": "rangerbar",
    "rangerbart": "rangerbar",
    "rangerbarts": "rangerbar",
    "rangeringar": "rangering",
    "rangeringarna": "rangering",
    "rangeringarnas": "rangering",
    "rangeringars": "rangering",
    "rangeringen": "rangering",
    "rangeringens": "rangering",
    "rangerings": "rangering",
    "rangern": "ranger",
    "rangerns": "ranger",
    "rangers": "ranger",
    "rangersarna": "ranger",
    "rangersarnas": "ranger",
    "rangersen": "ranger",
    "rangersens": "ranger",
    "ranglade": "rangla",
    "ranglades": "rangla",
    "ranglande": "rangla",
    "ranglanden": "ranglande",
    "ranglandena": "ranglande",
    "ranglandenas": "ranglande",
    "ranglandens": "ranglande",
    "ranglandes": "ranglande",
    "ranglandet": "ranglande",
    "ranglandets": "ranglande",
    "ranglar": "rangla",
    "ranglas": "rangla",
    "ranglat": "rangla",
    "ranglats": "rangla",
    "rangliga": "ranglig",
    "rangligare": "ranglig",
    "rangligares": "ranglig",
    "rangligas": "ranglig",
    "rangligast": "ranglig",
    "rangligaste": "ranglig",
    "rangligastes": "ranglig",
    "rangligasts": "ranglig",
    "ranglige": "ranglig",
    "rangliges": "ranglig",
    "rangligheten": "ranglighet",
    "ranglighetens": "ranglighet",
    "ranglighets": "ranglighet",
    "rangligs": "ranglig",
    "rangligt": "ranglig",
    "rangligts": "ranglig",
    "rangmässiga": "rangmässig",
    "rangmässigare": "rangmässig",
    "rangmässigares": "rangmässig",
    "rangmässigas": "rangmässig",
    "rangmässigast": "rangmässig",
    "rangmässigaste": "rangmässig",
    "rangmässigastes": "rangmässig",
    "rangmässigasts": "rangmässig",
    "rangmässige": "rangmässig",
    "rangmässiges": "rangmässig",
    "rangmässigs": "rangmässig",
    "rangmässigt": "rangmässig",
    "rangmässigts": "rangmässig",
    "rangordnad": "rangordna",
    "rangordnade": "rangordna",
    "rangordnades": "rangordna",
    "rangordnads": "rangordna",
    "rangordnande": "rangordna",
    "rangordnanden": "rangordnande",
    "rangordnandena": "rangordnande",
    "rangordnandenas": "rangordnande",
    "rangordnandens": "rangordnande",
    "rangordnandes": "rangordnande",
    "rangordnandet": "rangordnande",
    "rangordnandets": "rangordnande",
    "rangordnar": "rangordna",
    "rangordnas": "rangordna",
    "rangordnat": "rangordna",
    "rangordnats": "rangordna",
    "rangordningar": "rangordning",
    "rangordningarna": "rangordning",
    "rangordningarnas": "rangordning",
    "rangordningars": "rangordning",
    "rangordningen": "rangordning",
    "rangordningens": "rangordning",
    "rangordnings": "rangordning",
    "rangplatsen": "rangplats",
    "rangplatsens": "rangplats",
    "rangplatser": "rangplats",
    "rangplatserna": "rangplats",
    "rangplatsernas": "rangplats",
    "rangplatsers": "rangplats",
    "rangrull": "rangrulla",
    "rangrullan": "rangrulla",
    "rangrullans": "rangrulla",
    "rangrullas": "rangrulla",
    "rangrulle": "rangrulla",
    "rangrullor": "rangrulla",
    "rangrullorna": "rangrulla",
    "rangrullornas": "rangrulla",
    "rangrullors": "rangrulla",
    "rangrulls": "rangrulla",
    "rangs": "rang",
    "rangskal": "rangskala",
    "rangskalan": "rangskala",
    "rangskalans": "rangskala",
    "rangskalas": "rangskala",
    "rangskale": "rangskala",
    "rangskalor": "rangskala",
    "rangskalorna": "rangskala",
    "rangskalornas": "rangskala",
    "rangskalors": "rangskala",
    "rangskals": "rangskala",
    "rank": "ranka",
    "ranka": "rank",
    "rankad": "ranka",
    "rankade": "ranka",
    "rankades": "ranka",
    "rankads": "ranka",
    "rankan": "ranka",
    "rankande": "ranka",
    "rankanden": "rankande",
    "rankandena": "rankande",
    "rankandenas": "rankande",
    "rankandens": "rankande",
    "rankandes": "rankande",
    "rankandet": "rankande",
    "rankandets": "rankande",
    "rankans": "ranka",
    "rankar": "ranka",
    "rankare": "rank",
    "rankares": "rank",
    "rankas": "ranka",
    "rankast": "rank",
    "rankaste": "rank",
    "rankastes": "rank",
    "rankasts": "rank",
    "rankat": "ranka",
    "rankats": "ranka",
    "ranke": "ranka",
    "rankes": "rank",
    "rankfotingar": "rankfoting",
    "rankfotingarna": "rankfoting",
    "rankfotingarnas": "rankfoting",
    "rankfotingars": "rankfoting",
    "rankfotingen": "rankfoting",
    "rankfotingens": "rankfoting",
    "rankfotings": "rankfoting",
    "rankheten": "rankhet",
    "rankhetens": "rankhet",
    "rankhets": "rankhet",
    "rankiga": "rankig",
    "rankigare": "rankig",
    "rankigares": "rankig",
    "rankigas": "rankig",
    "rankigast": "rankig",
    "rankigaste": "rankig",
    "rankigastes": "rankig",
    "rankigasts": "rankig",
    "rankige": "rankig",
    "rankiges": "rankig",
    "rankigheten": "rankighet",
    "rankighetens": "rankighet",
    "rankighets": "rankighet",
    "rankigs": "rankig",
    "rankigt": "rankig",
    "rankigts": "rankig",
    "rankinglistan": "rankinglista",
    "rankinglistans": "rankinglista",
    "rankinglistas": "rankinglista",
    "rankingliste": "rankinglista",
    "rankinglistor": "rankinglista",
    "rankinglistorna": "rankinglista",
    "rankinglistornas": "rankinglista",
    "rankinglistors": "rankinglista",
    "rankningslistan": "rankningslista",
    "rankningslistans": "rankningslista",
    "rankningslistas": "rankningslista",
    "rankningsliste": "rankningslista",
    "rankningslistor": "rankningslista",
    "rankningslistorna": "rankningslista",
    "rankningslistornas": "rankningslista",
    "rankningslistors": "rankningslista",
    "rankor": "ranka",
    "rankorna": "ranka",
    "rankornas": "ranka",
    "rankors": "ranka",
    "ranks": "ranka",
    "rankt": "rank",
    "rankts": "rank",
    "rann": "rinna",
    "ranns": "rinna",
    "rannsak": "rannsaka",
    "rannsakad": "rannsaka",
    "rannsakade": "rannsaka",
    "rannsakades": "rannsaka",
    "rannsakads": "rannsaka",
    "rannsakande": "rannsaka",
    "rannsakanden": "rannsakande",
    "rannsakandena": "rannsakande",
    "rannsakandenas": "rannsakande",
    "rannsakandens": "rannsakande",
    "rannsakandes": "rannsakande",
    "rannsakandet": "rannsakande",
    "rannsakandets": "rannsakande",
    "rannsakans": "rannsakan",
    "rannsakar": "rannsaka",
    "rannsakas": "rannsaka",
    "rannsakat": "rannsaka",
    "rannsakats": "rannsaka",
    "rannsakningar": "rannsakning",
    "rannsakningarna": "rannsakning",
    "rannsakningarnas": "rannsakning",
    "rannsakningars": "rannsakning",
    "rannsakningen": "rannsakning",
    "rannsakningens": "rannsakning",
    "rannsaknings": "rannsakning",
    "ranor": "rana",
    "ranorna": "rana",
    "ranornas": "rana",
    "ranors": "rana",
    "rans": "rana",
    "ransonen": "ranson",
    "ransonens": "ranson",
    "ransoner": "ranson",
    "ransonerad": "ransonera",
    "ransonerade": "ransonera",
    "ransonerades": "ransonera",
    "ransonerads": "ransonera",
    "ransonerande": "ransonera",
    "ransoneranden": "ransonerande",
    "ransonerandena": "ransonerande",
    "ransonerandenas": "ransonerande",
    "ransonerandens": "ransonerande",
    "ransonerandes": "ransonerande",
    "ransonerandet": "ransonerande",
    "ransonerandets": "ransonerande",
    "ransonerar": "ransonera",
    "ransoneras": "ransonera",
    "ransonerat": "ransonera",
    "ransonerats": "ransonera",
    "ransonerbara": "ransonerbar",
    "ransonerbarare": "ransonerbar",
    "ransonerbarares": "ransonerbar",
    "ransonerbaras": "ransonerbar",
    "ransonerbarast": "ransonerbar",
    "ransonerbaraste": "ransonerbar",
    "ransonerbarastes": "ransonerbar",
    "ransonerbarasts": "ransonerbar",
    "ransonerbare": "ransonerbar",
    "ransonerbares": "ransonerbar",
    "ransonerbarheten": "ransonerbarhet",
    "ransonerbarhetens": "ransonerbarhet",
    "ransonerbarhets": "ransonerbarhet",
    "ransonerbars": "ransonerbar",
    "ransonerbart": "ransonerbar",
    "ransonerbarts": "ransonerbar",
    "ransoneringar": "ransonering",
    "ransoneringarna": "ransonering",
    "ransoneringarnas": "ransonering",
    "ransoneringars": "ransonering",
    "ransoneringen": "ransonering",
    "ransoneringens": "ransonering",
    "ransonerings": "ransonering",
    "ransoneringskorten": "ransoneringskort",
    "ransoneringskortens": "ransoneringskort",
    "ransoneringskortet": "ransoneringskort",
    "ransoneringskortets": "ransoneringskort",
    "ransoneringskorts": "ransoneringskort",
    "ransonerna": "ranson",
    "ransonernas": "ranson",
    "ransoners": "ranson",
    "ransons": "ranson",
    "rant": "ranta",
    "rantade": "ranta",
    "rantades": "ranta",
    "rantande": "ranta",
    "rantanden": "rantande",
    "rantandena": "rantande",
    "rantandenas": "rantande",
    "rantandens": "rantande",
    "rantandes": "rantande",
    "rantandet": "rantande",
    "rantandets": "rantande",
    "rantar": "ranta",
    "rantas": "ranta",
    "rantat": "ranta",
    "rantats": "ranta",
    "ranunkeln": "ranunkel",
    "ranunkelns": "ranunkel",
    "ranunkels": "ranunkel",
    "ranunkelväxten": "ranunkelväxt",
    "ranunkelväxtens": "ranunkelväxt",
    "ranunkelväxter": "ranunkelväxt",
    "ranunkelväxterna": "ranunkelväxt",
    "ranunkelväxternas": "ranunkelväxt",
    "ranunkelväxters": "ranunkelväxt",
    "ranunkelväxts": "ranunkelväxt",
    "ranunklar": "ranunkel",
    "ranunklarna": "ranunkel",
    "ranunklarnas": "ranunkel",
    "ranunklars": "ranunkel",
    "ranunkler": "ranunkel",
    "ranunklerna": "ranunkel",
    "ranunklernas": "ranunkel",
    "ranunklers": "ranunkel",
    "rapade": "rapa",
    "rapades": "rapa",
    "rapande": "rapa",
    "rapanden": "rapande",
    "rapandena": "rapande",
    "rapandenas": "rapande",
    "rapandens": "rapande",
    "rapandes": "rapande",
    "rapandet": "rapande",
    "rapandets": "rapande",
    "rapar": "rapa",
    "rapas": "rapa",
    "rapat": "rapa",
    "rapats": "rapa",
    "rapen": "rap",
    "rapens": "rap",
    "rapet": "rap",
    "rapets": "rap",
    "rapida": "rapid",
    "rapidare": "rapid",
    "rapidares": "rapid",
    "rapidas": "rapid",
    "rapidast": "rapid",
    "rapidaste": "rapid",
    "rapidastes": "rapid",
    "rapidasts": "rapid",
    "rapide": "rapid",
    "rapides": "rapid",
    "rapids": "rapid",
    "rapp": "rappa",
    "rappa": "rapp",
    "rappad": "rappa",
    "rappade": "rappa",
    "rappades": "rappa",
    "rappads": "rappa",
    "rappakaljan": "rappakalja",
    "rappakaljans": "rappakalja",
    "rappakaljas": "rappakalja",
    "rappakaljor": "rappakalja",
    "rappakaljorna": "rappakalja",
    "rappakaljornas": "rappakalja",
    "rappakaljors": "rappakalja",
    "rappande": "rappa",
    "rappanden": "rappande",
    "rappandena": "rappande",
    "rappandenas": "rappande",
    "rappandens": "rappande",
    "rappandes": "rappande",
    "rappandet": "rappande",
    "rappandets": "rappande",
    "rappar": "rappa",
    "rappare": "rapp",
    "rappares": "rapp",
    "rapparna": "rapp",
    "rapparnas": "rapp",
    "rappars": "rapp",
    "rappas": "rappa",
    "rappast": "rapp",
    "rappaste": "rapp",
    "rappastes": "rapp",
    "rappasts": "rapp",
    "rappat": "rappa",
    "rappats": "rappa",
    "rappe": "rapp",
    "rappellen": "rappell",
    "rappellens": "rappell",
    "rappeller": "rappell",
    "rappellerad": "rappellera",
    "rappellerade": "rappellera",
    "rappellerades": "rappellera",
    "rappellerads": "rappellera",
    "rappellerande": "rappellera",
    "rappelleranden": "rappellerande",
    "rappellerandena": "rappellerande",
    "rappellerandenas": "rappellerande",
    "rappellerandens": "rappellerande",
    "rappellerandes": "rappellerande",
    "rappellerandet": "rappellerande",
    "rappellerandets": "rappellerande",
    "rappellerar": "rappellera",
    "rappelleras": "rappellera",
    "rappellerat": "rappellera",
    "rappellerats": "rappellera",
    "rappellerbara": "rappellerbar",
    "rappellerbarare": "rappellerbar",
    "rappellerbarares": "rappellerbar",
    "rappellerbaras": "rappellerbar",
    "rappellerbarast": "rappellerbar",
    "rappellerbaraste": "rappellerbar",
    "rappellerbarastes": "rappellerbar",
    "rappellerbarasts": "rappellerbar",
    "rappellerbare": "rappellerbar",
    "rappellerbares": "rappellerbar",
    "rappellerbarheten": "rappellerbarhet",
    "rappellerbarhetens": "rappellerbarhet",
    "rappellerbarhets": "rappellerbarhet",
    "rappellerbars": "rappellerbar",
    "rappellerbart": "rappellerbar",
    "rappellerbarts": "rappellerbar",
    "rappelleringar": "rappellering",
    "rappelleringarna": "rappellering",
    "rappelleringarnas": "rappellering",
    "rappelleringars": "rappellering",
    "rappelleringen": "rappellering",
    "rappelleringens": "rappellering",
    "rappellerings": "rappellering",
    "rappellerna": "rappell",
    "rappellernas": "rappell",
    "rappellers": "rappell",
    "rappells": "rappell",
    "rappen": "rapp",
    "rappens": "rapp",
    "rappes": "rapp",
    "rappet": "rapp",
    "rappets": "rapp",
    "rappheten": "rapphet",
    "rapphetens": "rapphet",
    "rapphets": "rapphet",
    "rapphönan": "rapphöna",
    "rapphönans": "rapphöna",
    "rapphönas": "rapphöna",
    "rapphöne": "rapphöna",
    "rapphönor": "rapphöna",
    "rapphönorna": "rapphöna",
    "rapphönornas": "rapphöna",
    "rapphönors": "rapphöna",
    "rapphönsen": "rapphöns",
    "rapphönsens": "rapphöns",
    "rapphönset": "rapphöns",
    "rapphönsets": "rapphöns",
    "rappningar": "rappning",
    "rappningarna": "rappning",
    "rappningarnas": "rappning",
    "rappningars": "rappning",
    "rappningen": "rappning",
    "rappningens": "rappning",
    "rappnings": "rappning",
    "rapportboken": "rapportbok",
    "rapportbokens": "rapportbok",
    "rapportboks": "rapportbok",
    "rapportböcker": "rapportbok",
    "rapportböckerna": "rapportbok",
    "rapportböckernas": "rapportbok",
    "rapportböckers": "rapportbok",
    "rapporten": "rapport",
    "rapportens": "rapport",
    "rapporter": "rapport",
    "rapporterad": "rapportera",
    "rapporterade": "rapportera",
    "rapporterades": "rapportera",
    "rapporterads": "rapportera",
    "rapporterande": "rapportera",
    "rapporteranden": "rapporterande",
    "rapporterandena": "rapporterande",
    "rapporterandenas": "rapporterande",
    "rapporterandens": "rapporterande",
    "rapporterandes": "rapporterande",
    "rapporterandet": "rapporterande",
    "rapporterandets": "rapporterande",
    "rapporterar": "rapportera",
    "rapporteras": "rapportera",
    "rapporterat": "rapportera",
    "rapporterats": "rapportera",
    "rapporterbara": "rapporterbar",
    "rapporterbarare": "rapporterbar",
    "rapporterbarares": "rapporterbar",
    "rapporterbaras": "rapporterbar",
    "rapporterbarast": "rapporterbar",
    "rapporterbaraste": "rapporterbar",
    "rapporterbarastes": "rapporterbar",
    "rapporterbarasts": "rapporterbar",
    "rapporterbare": "rapporterbar",
    "rapporterbares": "rapporterbar",
    "rapporterbarheten": "rapporterbarhet",
    "rapporterbarhetens": "rapporterbarhet",
    "rapporterbarhets": "rapporterbarhet",
    "rapporterbars": "rapporterbar",
    "rapporterbart": "rapporterbar",
    "rapporterbarts": "rapporterbar",
    "rapporteringar": "rapportering",
    "rapporteringarna": "rapportering",
    "rapporteringarnas": "rapportering",
    "rapporteringars": "rapportering",
    "rapporteringen": "rapportering",
    "rapporteringens": "rapportering",
    "rapporterings": "rapportering",
    "rapporteringsplikten": "rapporteringsplikt",
    "rapporteringspliktens": "rapporteringsplikt",
    "rapporteringsplikts": "rapporteringsplikt",
    "rapporterna": "rapport",
    "rapporternas": "rapport",
    "rapporters": "rapport",
    "rapportkarlar": "rapportkarl",
    "rapportkarlarna": "rapportkarl",
    "rapportkarlarnas": "rapportkarl",
    "rapportkarlars": "rapportkarl",
    "rapportkarlen": "rapportkarl",
    "rapportkarlens": "rapportkarl",
    "rapportkarls": "rapportkarl",
    "rapports": "rapport",
    "rapportören": "rapportör",
    "rapportörens": "rapportör",
    "rapportörer": "rapportör",
    "rapportörerna": "rapportör",
    "rapportörernas": "rapportör",
    "rapportörers": "rapportör",
    "rapportörs": "rapportör",
    "rapps": "rapp",
    "rappt": "rapp",
    "rappts": "rapp",
    "raps": "rap",
    "rapsbagg": "rapsbagge",
    "rapsbaggar": "rapsbagge",
    "rapsbaggarna": "rapsbagge",
    "rapsbaggarnas": "rapsbagge",
    "rapsbaggars": "rapsbagge",
    "rapsbaggen": "rapsbagge",
    "rapsbaggens": "rapsbagge",
    "rapsbagges": "rapsbagge",
    "rapsbaggs": "rapsbagge",
    "rapsen": "raps",
    "rapsens": "raps",
    "rapsfröen": "rapsfrö",
    "rapsfröens": "rapsfrö",
    "rapsfröer": "rapsfrö",
    "rapsfröerna": "rapsfrö",
    "rapsfröernas": "rapsfrö",
    "rapsfröers": "rapsfrö",
    "rapsfröet": "rapsfrö",
    "rapsfröets": "rapsfrö",
    "rapsfrön": "rapsfrö",
    "rapsfröna": "rapsfrö",
    "rapsfrönas": "rapsfrö",
    "rapsfröns": "rapsfrö",
    "rapsfrös": "rapsfrö",
    "rapsfröt": "rapsfrö",
    "rapsfröts": "rapsfrö",
    "rapsfälten": "rapsfält",
    "rapsfältens": "rapsfält",
    "rapsfältet": "rapsfält",
    "rapsfältets": "rapsfält",
    "rapsfälts": "rapsfält",
    "rapskak": "rapskaka",
    "rapskakan": "rapskaka",
    "rapskakans": "rapskaka",
    "rapskakas": "rapskaka",
    "rapskake": "rapskaka",
    "rapskakor": "rapskaka",
    "rapskakorna": "rapskaka",
    "rapskakornas": "rapskaka",
    "rapskakors": "rapskaka",
    "rapskaks": "rapskaka",
    "rapsoden": "rapsod",
    "rapsodens": "rapsod",
    "rapsoder": "rapsod",
    "rapsoderna": "rapsod",
    "rapsodernas": "rapsod",
    "rapsoders": "rapsod",
    "rapsodien": "rapsodi",
    "rapsodiens": "rapsodi",
    "rapsodier": "rapsodi",
    "rapsodierna": "rapsodi",
    "rapsodiernas": "rapsodi",
    "rapsodiers": "rapsodi",
    "rapsodin": "rapsodi",
    "rapsodins": "rapsodi",
    "rapsodis": "rapsodi",
    "rapsodiska": "rapsodisk",
    "rapsodiskare": "rapsodisk",
    "rapsodiskares": "rapsodisk",
    "rapsodiskas": "rapsodisk",
    "rapsodiskast": "rapsodisk",
    "rapsodiskaste": "rapsodisk",
    "rapsodiskastes": "rapsodisk",
    "rapsodiskasts": "rapsodisk",
    "rapsodiske": "rapsodisk",
    "rapsodiskes": "rapsodisk",
    "rapsodisks": "rapsodisk",
    "rapsodiskt": "rapsodisk",
    "rapsodiskts": "rapsodisk",
    "rapsods": "rapsod",
    "rapsplant": "rapsplanta",
    "rapsplantan": "rapsplanta",
    "rapsplantans": "rapsplanta",
    "rapsplantas": "rapsplanta",
    "rapsplante": "rapsplanta",
    "rapsplantor": "rapsplanta",
    "rapsplantorna": "rapsplanta",
    "rapsplantornas": "rapsplanta",
    "rapsplantors": "rapsplanta",
    "rapsplants": "rapsplanta",
    "rapsåkern": "rapsåker",
    "rapsåkerns": "rapsåker",
    "rapsåkers": "rapsåker",
    "rapsåkrar": "rapsåker",
    "rapsåkrarna": "rapsåker",
    "rapsåkrarnas": "rapsåker",
    "rapsåkrars": "rapsåker",
    "raptusen": "raptus",
    "raptusens": "raptus",
    "raptuset": "raptus",
    "raptusets": "raptus",
    "rara": "rar",
    "rarare": "rar",
    "rarares": "rar",
    "raras": "rar",
    "rarast": "rar",
    "raraste": "rar",
    "rarastes": "rar",
    "rarasts": "rar",
    "rare": "rar",
    "rares": "rar",
    "rarheten": "rarhet",
    "rarhetens": "rarhet",
    "rarhets": "rarhet",
    "raringar": "raring",
    "raringarna": "raring",
    "raringarnas": "raring",
    "raringars": "raring",
    "raringen": "raring",
    "raringens": "raring",
    "rarings": "raring",
    "rariteten": "raritet",
    "raritetens": "raritet",
    "rariteter": "raritet",
    "rariteterna": "raritet",
    "rariteternas": "raritet",
    "rariteters": "raritet",
    "raritets": "raritet",
    "rars": "rar",
    "rart": "rar",
    "rarts": "rar",
    "rasade": "rasa",
    "rasades": "rasa",
    "rasande": "rasa",
    "rasanden": "rasande",
    "rasandena": "rasande",
    "rasandenas": "rasande",
    "rasandens": "rasande",
    "rasandes": "rasande",
    "rasandet": "rasande",
    "rasandets": "rasande",
    "rasar": "rasa",
    "rasas": "rasa",
    "rasat": "rasa",
    "rasats": "rasa",
    "rasbenen": "rasben",
    "rasbenens": "rasben",
    "rasbenet": "rasben",
    "rasbenets": "rasben",
    "rasbens": "rasben",
    "rasbiologien": "rasbiologi",
    "rasbiologiens": "rasbiologi",
    "rasbiologin": "rasbiologi",
    "rasbiologins": "rasbiologi",
    "rasbiologis": "rasbiologi",
    "rasdiskriminerad": "rasdiskriminera",
    "rasdiskriminerade": "rasdiskriminera",
    "rasdiskriminerades": "rasdiskriminera",
    "rasdiskriminerads": "rasdiskriminera",
    "rasdiskriminerande": "rasdiskriminera",
    "rasdiskrimineranden": "rasdiskriminerande",
    "rasdiskriminerandena": "rasdiskriminerande",
    "rasdiskriminerandenas": "rasdiskriminerande",
    "rasdiskriminerandens": "rasdiskriminerande",
    "rasdiskriminerandes": "rasdiskriminerande",
    "rasdiskriminerandet": "rasdiskriminerande",
    "rasdiskriminerandets": "rasdiskriminerande",
    "rasdiskriminerar": "rasdiskriminera",
    "rasdiskrimineras": "rasdiskriminera",
    "rasdiskriminerat": "rasdiskriminera",
    "rasdiskriminerats": "rasdiskriminera",
    "rasdiskriminerbara": "rasdiskriminerbar",
    "rasdiskriminerbarare": "rasdiskriminerbar",
    "rasdiskriminerbarares": "rasdiskriminerbar",
    "rasdiskriminerbaras": "rasdiskriminerbar",
    "rasdiskriminerbarast": "rasdiskriminerbar",
    "rasdiskriminerbaraste": "rasdiskriminerbar",
    "rasdiskriminerbarastes": "rasdiskriminerbar",
    "rasdiskriminerbarasts": "rasdiskriminerbar",
    "rasdiskriminerbare": "rasdiskriminerbar",
    "rasdiskriminerbares": "rasdiskriminerbar",
    "rasdiskriminerbarheten": "rasdiskriminerbarhet",
    "rasdiskriminerbarhetens": "rasdiskriminerbarhet",
    "rasdiskriminerbarhets": "rasdiskriminerbarhet",
    "rasdiskriminerbars": "rasdiskriminerbar",
    "rasdiskriminerbart": "rasdiskriminerbar",
    "rasdiskriminerbarts": "rasdiskriminerbar",
    "rasdiskrimineringar": "rasdiskriminering",
    "rasdiskrimineringarna": "rasdiskriminering",
    "rasdiskrimineringarnas": "rasdiskriminering",
    "rasdiskrimineringars": "rasdiskriminering",
    "rasdiskrimineringen": "rasdiskriminering",
    "rasdiskrimineringens": "rasdiskriminering",
    "rasdiskriminerings": "rasdiskriminering",
    "rasdjuren": "rasdjur",
    "rasdjurens": "rasdjur",
    "rasdjuret": "rasdjur",
    "rasdjurets": "rasdjur",
    "rasdjurs": "rasdjur",
    "rasen": "ras",
    "rasens": "ras",
    "raser": "ras",
    "raserad": "rasera",
    "raserade": "rasera",
    "raserades": "rasera",
    "raserads": "rasera",
    "raserande": "rasera",
    "raseranden": "raserande",
    "raserandena": "raserande",
    "raserandenas": "raserande",
    "raserandens": "raserande",
    "raserandes": "raserande",
    "raserandet": "raserande",
    "raserandets": "raserande",
    "raserar": "rasera",
    "raseras": "rasera",
    "raserat": "rasera",
    "raserats": "rasera",
    "raserbara": "raserbar",
    "raserbarare": "raserbar",
    "raserbarares": "raserbar",
    "raserbaras": "raserbar",
    "raserbarast": "raserbar",
    "raserbaraste": "raserbar",
    "raserbarastes": "raserbar",
    "raserbarasts": "raserbar",
    "raserbare": "raserbar",
    "raserbares": "raserbar",
    "raserbarheten": "raserbarhet",
    "raserbarhetens": "raserbarhet",
    "raserbarhets": "raserbarhet",
    "raserbars": "raserbar",
    "raserbart": "raserbar",
    "raserbarts": "raserbar",
    "raseriet": "raseri",
    "raseriets": "raseri",
    "raseringar": "rasering",
    "raseringarna": "rasering",
    "raseringarnas": "rasering",
    "raseringars": "rasering",
    "raseringen": "rasering",
    "raseringens": "rasering",
    "raserings": "rasering",
    "raseris": "raseri",
    "raserit": "raseri",
    "raserits": "raseri",
    "raseriutbrotten": "raseriutbrott",
    "raseriutbrottens": "raseriutbrott",
    "raseriutbrottet": "raseriutbrott",
    "raseriutbrottets": "raseriutbrott",
    "raseriutbrotts": "raseriutbrott",
    "raserna": "ras",
    "rasernas": "ras",
    "rasers": "ras",
    "raset": "ras",
    "rasets": "ras",
    "rasfrågan": "rasfråga",
    "rasfrågans": "rasfråga",
    "rasfrågas": "rasfråga",
    "rasfråge": "rasfråga",
    "rasfrågor": "rasfråga",
    "rasfrågorna": "rasfråga",
    "rasfrågornas": "rasfråga",
    "rasfrågors": "rasfråga",
    "rasfördomar": "rasfördom",
    "rasfördomarna": "rasfördom",
    "rasfördomarnas": "rasfördom",
    "rasfördomars": "rasfördom",
    "rasfördomen": "rasfördom",
    "rasfördomens": "rasfördom",
    "rasfördoms": "rasfördom",
    "rasförföljelsen": "rasförföljelse",
    "rasförföljelsens": "rasförföljelse",
    "rasförföljelser": "rasförföljelse",
    "rasförföljelserna": "rasförföljelse",
    "rasförföljelsernas": "rasförföljelse",
    "rasförföljelsers": "rasförföljelse",
    "rasförföljelses": "rasförföljelse",
    "rashatet": "rashat",
    "rashatets": "rashat",
    "rashats": "rashat",
    "rashetsar": "rashetsare",
    "rashetsaren": "rashetsare",
    "rashetsarens": "rashetsare",
    "rashetsares": "rashetsare",
    "rashetsarna": "rashetsare",
    "rashetsarnas": "rashetsare",
    "rashetsen": "rashets",
    "rashetsens": "rashets",
    "rashygienen": "rashygien",
    "rashygienens": "rashygien",
    "rashygiens": "rashygien",
    "rasismen": "rasism",
    "rasismens": "rasism",
    "rasismer": "rasism",
    "rasismerna": "rasism",
    "rasismernas": "rasism",
    "rasismers": "rasism",
    "rasisms": "rasism",
    "rasisten": "rasist",
    "rasistens": "rasist",
    "rasister": "rasist",
    "rasisterna": "rasist",
    "rasisternas": "rasist",
    "rasisters": "rasist",
    "rasistiska": "rasistisk",
    "rasistiskare": "rasistisk",
    "rasistiskares": "rasistisk",
    "rasistiskas": "rasistisk",
    "rasistiskast": "rasistisk",
    "rasistiskaste": "rasistisk",
    "rasistiskastes": "rasistisk",
    "rasistiskasts": "rasistisk",
    "rasistiske": "rasistisk",
    "rasistiskes": "rasistisk",
    "rasistisks": "rasistisk",
    "rasistiskt": "rasistisk",
    "rasistiskts": "rasistisk",
    "rasists": "rasist",
    "rasistskandalen": "rasistskandal",
    "rasistskandalens": "rasistskandal",
    "rasistskandaler": "rasistskandal",
    "rasistskandalerna": "rasistskandal",
    "rasistskandalernas": "rasistskandal",
    "rasistskandalers": "rasistskandal",
    "rasistskandals": "rasistskandal",
    "raska": "rask",
    "raskare": "rask",
    "raskares": "rask",
    "raskas": "rask",
    "raskast": "rask",
    "raskaste": "rask",
    "raskastes": "rask",
    "raskasts": "rask",
    "raske": "rask",
    "raskes": "rask",
    "raskheten": "raskhet",
    "raskhetens": "raskhet",
    "raskhets": "raskhet",
    "raskravallerna": "raskravaller",
    "raskravallernas": "raskravaller",
    "raskravallers": "raskravaller",
    "raskravalls": "raskravaller",
    "raskt": "rask",
    "raskts": "rask",
    "rasmassan": "rasmassa",
    "rasmassans": "rasmassa",
    "rasmassas": "rasmassa",
    "rasmasse": "rasmassa",
    "rasmassor": "rasmassa",
    "rasmassorna": "rasmassa",
    "rasmassornas": "rasmassa",
    "rasmassors": "rasmassa",
    "rasmässiga": "rasmässig",
    "rasmässigare": "rasmässig",
    "rasmässigares": "rasmässig",
    "rasmässigas": "rasmässig",
    "rasmässigast": "rasmässig",
    "rasmässigaste": "rasmässig",
    "rasmässigastes": "rasmässig",
    "rasmässigasts": "rasmässig",
    "rasmässige": "rasmässig",
    "rasmässiges": "rasmässig",
    "rasmässigs": "rasmässig",
    "rasmässigt": "rasmässig",
    "rasmässigts": "rasmässig",
    "rasp": "raspa",
    "raspad": "raspa",
    "raspade": "raspa",
    "raspades": "raspa",
    "raspads": "raspa",
    "raspande": "raspa",
    "raspanden": "raspande",
    "raspandena": "raspande",
    "raspandenas": "raspande",
    "raspandens": "raspande",
    "raspandes": "raspande",
    "raspandet": "raspande",
    "raspandets": "raspande",
    "raspar": "raspa",
    "rasparna": "rasp",
    "rasparnas": "rasp",
    "raspars": "rasp",
    "raspas": "raspa",
    "raspat": "raspa",
    "raspats": "raspa",
    "raspen": "rasp",
    "raspens": "rasp",
    "raspet": "rasp",
    "raspets": "rasp",
    "raspiga": "raspig",
    "raspigare": "raspig",
    "raspigares": "raspig",
    "raspigas": "raspig",
    "raspigast": "raspig",
    "raspigaste": "raspig",
    "raspigastes": "raspig",
    "raspigasts": "raspig",
    "raspige": "raspig",
    "raspiges": "raspig",
    "raspigheten": "raspighet",
    "raspighetens": "raspighet",
    "raspighets": "raspighet",
    "raspigs": "raspig",
    "raspigt": "raspig",
    "raspigts": "raspig",
    "rasps": "rasp",
    "rasrena": "rasren",
    "rasrenare": "rasren",
    "rasrenares": "rasren",
    "rasrenas": "rasren",
    "rasrenast": "rasren",
    "rasrenaste": "rasren",
    "rasrenastes": "rasren",
    "rasrenasts": "rasren",
    "rasrene": "rasren",
    "rasrenes": "rasren",
    "rasrens": "rasren",
    "rasrent": "rasren",
    "rasrents": "rasren",
    "rassar": "rasse",
    "rassarna": "rasse",
    "rassarnas": "rasse",
    "rassars": "rasse",
    "rassegregationen": "rassegregation",
    "rassegregationens": "rassegregation",
    "rassegregations": "rassegregation",
    "rassegregerade": "rassegregerad",
    "rassegregerades": "rassegregerad",
    "rassegregerads": "rassegregerad",
    "rassegregerat": "rassegregerad",
    "rassegregerats": "rassegregerad",
    "rassel": "rassla",
    "rassels": "rassel",
    "rassen": "rasse",
    "rassens": "rasse",
    "rasses": "rasse",
    "rasslade": "rassla",
    "rasslades": "rassla",
    "rasslande": "rassla",
    "rasslanden": "rasslande",
    "rasslandena": "rasslande",
    "rasslandenas": "rasslande",
    "rasslandens": "rasslande",
    "rasslandes": "rasslande",
    "rasslandet": "rasslande",
    "rasslandets": "rasslande",
    "rasslar": "rassla",
    "rasslas": "rassla",
    "rasslat": "rassla",
    "rasslats": "rassla",
    "rasslet": "rassel",
    "rasslets": "rassel",
    "rast": "rasta",
    "rastad": "rasta",
    "rastade": "rasta",
    "rastades": "rasta",
    "rastads": "rasta",
    "rastafarin": "rastafari",
    "rastafarins": "rastafari",
    "rastafaris": "rastafari",
    "rastafarisarna": "rastafari",
    "rastafarisarnas": "rastafari",
    "rastafarisekten": "rastafarisekt",
    "rastafarisektens": "rastafarisekt",
    "rastafarisekts": "rastafarisekt",
    "rastafarisen": "rastafari",
    "rastafarisens": "rastafari",
    "rastande": "rasta",
    "rastanden": "rastande",
    "rastandena": "rastande",
    "rastandenas": "rastande",
    "rastandens": "rastande",
    "rastandes": "rastande",
    "rastandet": "rastande",
    "rastandets": "rastande",
    "rastar": "rasta",
    "rastas": "rasta",
    "rastat": "rasta",
    "rastats": "rasta",
    "rasten": "rast",
    "rastens": "rast",
    "raster": "rast",
    "rasterna": "raster",
    "rasternas": "raster",
    "rasters": "raster",
    "rastgårdar": "rastgård",
    "rastgårdarna": "rastgård",
    "rastgårdarnas": "rastgård",
    "rastgårdars": "rastgård",
    "rastgården": "rastgård",
    "rastgårdens": "rastgård",
    "rastgårds": "rastgård",
    "rastlösa": "rastlös",
    "rastlösare": "rastlös",
    "rastlösares": "rastlös",
    "rastlösas": "rastlös",
    "rastlösast": "rastlös",
    "rastlösaste": "rastlös",
    "rastlösastes": "rastlös",
    "rastlösasts": "rastlös",
    "rastlöse": "rastlös",
    "rastlöses": "rastlös",
    "rastlösheten": "rastlöshet",
    "rastlöshetens": "rastlöshet",
    "rastlöshets": "rastlöshet",
    "rastlöst": "rastlös",
    "rastlösts": "rastlös",
    "rastplatsen": "rastplats",
    "rastplatsens": "rastplats",
    "rastplatser": "rastplats",
    "rastplatserna": "rastplats",
    "rastplatsernas": "rastplats",
    "rastplatsers": "rastplats",
    "rastren": "raster",
    "rastrens": "raster",
    "rastret": "raster",
    "rastrets": "raster",
    "rasts": "rast",
    "rat": "rata",
    "ratad": "rata",
    "ratade": "rata",
    "ratades": "rata",
    "ratads": "rata",
    "ratande": "rata",
    "ratanden": "ratande",
    "ratandena": "ratande",
    "ratandenas": "ratande",
    "ratandens": "ratande",
    "ratandes": "ratande",
    "ratandet": "ratande",
    "ratandets": "ratande",
    "ratar": "rata",
    "ratas": "rata",
    "ratat": "rata",
    "ratats": "rata",
    "raten": "rate",
    "ratens": "rate",
    "rater": "rate",
    "raterna": "rate",
    "raternas": "rate",
    "raters": "rate",
    "rates": "rate",
    "ratificerad": "ratificera",
    "ratificerade": "ratificera",
    "ratificerades": "ratificera",
    "ratificerads": "ratificera",
    "ratificerande": "ratificera",
    "ratificeranden": "ratificerande",
    "ratificerandena": "ratificerande",
    "ratificerandenas": "ratificerande",
    "ratificerandens": "ratificerande",
    "ratificerandes": "ratificerande",
    "ratificerandet": "ratificerande",
    "ratificerandets": "ratificerande",
    "ratificerar": "ratificera",
    "ratificeras": "ratificera",
    "ratificerat": "ratificera",
    "ratificerats": "ratificera",
    "ratificerbara": "ratificerbar",
    "ratificerbarare": "ratificerbar",
    "ratificerbarares": "ratificerbar",
    "ratificerbaras": "ratificerbar",
    "ratificerbarast": "ratificerbar",
    "ratificerbaraste": "ratificerbar",
    "ratificerbarastes": "ratificerbar",
    "ratificerbarasts": "ratificerbar",
    "ratificerbare": "ratificerbar",
    "ratificerbares": "ratificerbar",
    "ratificerbarheten": "ratificerbarhet",
    "ratificerbarhetens": "ratificerbarhet",
    "ratificerbarhets": "ratificerbarhet",
    "ratificerbars": "ratificerbar",
    "ratificerbart": "ratificerbar",
    "ratificerbarts": "ratificerbar",
    "ratificeringar": "ratificering",
    "ratificeringarna": "ratificering",
    "ratificeringarnas": "ratificering",
    "ratificeringars": "ratificering",
    "ratificeringen": "ratificering",
    "ratificeringens": "ratificering",
    "ratificerings": "ratificering",
    "ratifikationen": "ratifikation",
    "ratifikationens": "ratifikation",
    "ratifikationer": "ratifikation",
    "ratifikationerna": "ratifikation",
    "ratifikationernas": "ratifikation",
    "ratifikationers": "ratifikation",
    "ratifikations": "ratifikation",
    "ratifikationsinstrumenten": "ratifikationsinstrument",
    "ratifikationsinstrumentens": "ratifikationsinstrument",
    "ratifikationsinstrumentet": "ratifikationsinstrument",
    "ratifikationsinstrumentets": "ratifikationsinstrument",
    "ratifikationsinstruments": "ratifikationsinstrument",
    "rationaliserad": "rationalisera",
    "rationaliserade": "rationalisera",
    "rationaliserades": "rationalisera",
    "rationaliserads": "rationalisera",
    "rationaliserande": "rationalisera",
    "rationaliseranden": "rationaliserande",
    "rationaliserandena": "rationaliserande",
    "rationaliserandenas": "rationaliserande",
    "rationaliserandens": "rationaliserande",
    "rationaliserandes": "rationaliserande",
    "rationaliserandet": "rationaliserande",
    "rationaliserandets": "rationaliserande",
    "rationaliserar": "rationalisera",
    "rationaliseras": "rationalisera",
    "rationaliserat": "rationalisera",
    "rationaliserats": "rationalisera",
    "rationaliserbara": "rationaliserbar",
    "rationaliserbarare": "rationaliserbar",
    "rationaliserbarares": "rationaliserbar",
    "rationaliserbaras": "rationaliserbar",
    "rationaliserbarast": "rationaliserbar",
    "rationaliserbaraste": "rationaliserbar",
    "rationaliserbarastes": "rationaliserbar",
    "rationaliserbarasts": "rationaliserbar",
    "rationaliserbare": "rationaliserbar",
    "rationaliserbares": "rationaliserbar",
    "rationaliserbarheten": "rationaliserbarhet",
    "rationaliserbarhetens": "rationaliserbarhet",
    "rationaliserbarhets": "rationaliserbarhet",
    "rationaliserbars": "rationaliserbar",
    "rationaliserbart": "rationaliserbar",
    "rationaliserbarts": "rationaliserbar",
    "rationaliseringar": "rationalisering",
    "rationaliseringarna": "rationalisering",
    "rationaliseringarnas": "rationalisering",
    "rationaliseringars": "rationalisering",
    "rationaliseringen": "rationalisering",
    "rationaliseringens": "rationalisering",
    "rationaliserings": "rationalisering",
    "rationalismen": "rationalism",
    "rationalismens": "rationalism",
    "rationalismer": "rationalism",
    "rationalismerna": "rationalism",
    "rationalismernas": "rationalism",
    "rationalismers": "rationalism",
    "rationalisms": "rationalism",
    "rationalisten": "rationalist",
    "rationalistens": "rationalist",
    "rationalister": "rationalist",
    "rationalisterna": "rationalist",
    "rationalisternas": "rationalist",
    "rationalisters": "rationalist",
    "rationalistiska": "rationalistisk",
    "rationalistiskas": "rationalistisk",
    "rationalistiske": "rationalistisk",
    "rationalistiskes": "rationalistisk",
    "rationalistisks": "rationalistisk",
    "rationalistiskt": "rationalistisk",
    "rationalistiskts": "rationalistisk",
    "rationalists": "rationalist",
    "rationaliteten": "rationalitet",
    "rationalitetens": "rationalitet",
    "rationaliteter": "rationalitet",
    "rationaliteterna": "rationalitet",
    "rationaliteternas": "rationalitet",
    "rationaliteters": "rationalitet",
    "rationalitets": "rationalitet",
    "rationella": "rationell",
    "rationellare": "rationell",
    "rationellares": "rationell",
    "rationellas": "rationell",
    "rationellast": "rationell",
    "rationellaste": "rationell",
    "rationellastes": "rationell",
    "rationellasts": "rationell",
    "rationelle": "rationell",
    "rationelles": "rationell",
    "rationells": "rationell",
    "rationellt": "rationell",
    "rationellts": "rationell",
    "rationen": "ration",
    "rationens": "ration",
    "rationer": "ration",
    "rationerna": "ration",
    "rationernas": "ration",
    "rationers": "ration",
    "rations": "ration",
    "ratschade": "ratscha",
    "ratschades": "ratscha",
    "ratschande": "ratscha",
    "ratschanden": "ratschande",
    "ratschandena": "ratschande",
    "ratschandenas": "ratschande",
    "ratschandens": "ratschande",
    "ratschandes": "ratschande",
    "ratschandet": "ratschande",
    "ratschandets": "ratschande",
    "ratschar": "ratscha",
    "ratschas": "ratscha",
    "ratschat": "ratscha",
    "ratschats": "ratscha",
    "ratschen": "ratsch",
    "ratschens": "ratsch",
    "ratschet": "ratsch",
    "ratschets": "ratsch",
    "ratschs": "ratsch",
    "ratt": "ratta",
    "rattad": "ratta",
    "rattade": "ratta",
    "rattades": "ratta",
    "rattads": "ratta",
    "rattande": "ratta",
    "rattanden": "rattande",
    "rattandena": "rattande",
    "rattandenas": "rattande",
    "rattandens": "rattande",
    "rattandes": "rattande",
    "rattandet": "rattande",
    "rattandets": "rattande",
    "rattar": "ratta",
    "rattarna": "ratt",
    "rattarnas": "ratt",
    "rattars": "ratt",
    "rattas": "ratta",
    "rattat": "ratta",
    "rattats": "ratta",
    "ratten": "ratt",
    "rattens": "ratt",
    "rattfulla": "rattfull",
    "rattfullas": "rattfull",
    "rattfulle": "rattfull",
    "rattfulles": "rattfull",
    "rattfulls": "rattfull",
    "rattfullt": "rattfull",
    "rattfullts": "rattfull",
    "rattfyllan": "rattfylla",
    "rattfyllans": "rattfylla",
    "rattfyllas": "rattfylla",
    "rattfylleriet": "rattfylleri",
    "rattfylleriets": "rattfylleri",
    "rattfylleris": "rattfylleri",
    "rattfylleristen": "rattfyllerist",
    "rattfylleristens": "rattfyllerist",
    "rattfyllerister": "rattfyllerist",
    "rattfylleristerna": "rattfyllerist",
    "rattfylleristernas": "rattfyllerist",
    "rattfylleristers": "rattfyllerist",
    "rattfyllerists": "rattfyllerist",
    "rattfyllerit": "rattfylleri",
    "rattfyllerits": "rattfylleri",
    "rattkälk": "rattkälke",
    "rattkälkar": "rattkälke",
    "rattkälkarna": "rattkälke",
    "rattkälkarnas": "rattkälke",
    "rattkälkars": "rattkälke",
    "rattkälken": "rattkälke",
    "rattkälkens": "rattkälke",
    "rattkälkes": "rattkälke",
    "rattkälks": "rattkälke",
    "rattlåsen": "rattlås",
    "rattlåsens": "rattlås",
    "rattlåset": "rattlås",
    "rattlåsets": "rattlås",
    "rattonykterheten": "rattonykterhet",
    "rattonykterhetens": "rattonykterhet",
    "rattonykterheter": "rattonykterhet",
    "rattonykterheterna": "rattonykterhet",
    "rattonykterheternas": "rattonykterhet",
    "rattonykterheters": "rattonykterhet",
    "rattonykterhets": "rattonykterhet",
    "ratts": "ratt",
    "rattstänger": "rattstång",
    "rattstängerna": "rattstång",
    "rattstängernas": "rattstång",
    "rattstängers": "rattstång",
    "rattstången": "rattstång",
    "rattstångens": "rattstång",
    "rattstångs": "rattstång",
    "rattväxeln": "rattväxel",
    "rattväxelns": "rattväxel",
    "rattväxels": "rattväxel",
    "rattväxlar": "rattväxel",
    "rattväxlarna": "rattväxel",
    "rattväxlarnas": "rattväxel",
    "rattväxlars": "rattväxel",
    "raukar": "rauk",
    "raukarna": "rauk",
    "raukarnas": "rauk",
    "raukars": "rauk",
    "rauken": "rauk",
    "raukens": "rauk",
    "rauks": "rauk",
    "ravaillacar": "ravaillac",
    "ravaillacarna": "ravaillac",
    "ravaillacarnas": "ravaillac",
    "ravaillacars": "ravaillac",
    "ravaillacen": "ravaillac",
    "ravaillacens": "ravaillac",
    "ravaillacs": "ravaillac",
    "ravefesten": "ravefest",
    "ravefestens": "ravefest",
    "ravefester": "ravefest",
    "ravefesterna": "ravefest",
    "ravefesternas": "ravefest",
    "ravefesters": "ravefest",
    "ravefests": "ravefest",
    "ravelinen": "ravelin",
    "ravelinens": "ravelin",
    "raveliner": "ravelin",
    "ravelinerna": "ravelin",
    "ravelinernas": "ravelin",
    "raveliners": "ravelin",
    "ravelins": "ravelin",
    "raven": "rave",
    "ravens": "rave",
    "raves": "rave",
    "ravinen": "ravin",
    "ravinens": "ravin",
    "raviner": "ravin",
    "ravinerna": "ravin",
    "ravinernas": "ravin",
    "raviners": "ravin",
    "ravins": "ravin",
    "raviolin": "ravioli",
    "raviolins": "ravioli",
    "raviolis": "ravioli",
    "rayonet": "rayon",
    "rayonets": "rayon",
    "rayons": "rayon",
    "rayonsilken": "rayonsilke",
    "rayonsilkena": "rayonsilke",
    "rayonsilkenas": "rayonsilke",
    "rayonsilkens": "rayonsilke",
    "rayonsilkes": "rayonsilke",
    "rayonsilket": "rayonsilke",
    "rayonsilkets": "rayonsilke",
    "rayonsilks": "rayonsilke",
    "rayonullen": "rayonull",
    "rayonullens": "rayonull",
    "rayonulls": "rayonull",
    "razzi": "razzia",
    "razzian": "razzia",
    "razzians": "razzia",
    "razzias": "razzia",
    "razzie": "razzia",
    "razzior": "razzia",
    "razziorna": "razzia",
    "razziornas": "razzia",
    "razziors": "razzia",
    "razzis": "razzia",
    "read": "rea",
    "reade": "rea",
    "reades": "rea",
    "reads": "rea",
    "ready-mades": "ready-made",
    "reagensen": "reagens",
    "reagensens": "reagens",
    "reagenser": "reagens",
    "reagenserna": "reagens",
    "reagensernas": "reagens",
    "reagensers": "reagens",
    "reagenset": "reagens",
    "reagensets": "reagens",
    "reagenspapperen": "reagenspapper",
    "reagenspapperens": "reagenspapper",
    "reagenspapperet": "reagenspapper",
    "reagenspapperets": "reagenspapper",
    "reagenspapperna": "reagenspapper",
    "reagenspappernas": "reagenspapper",
    "reagenspappers": "reagenspapper",
    "reagenspappren": "reagenspapper",
    "reagenspapprens": "reagenspapper",
    "reagenspappret": "reagenspapper",
    "reagenspapprets": "reagenspapper",
    "reagerade": "reagera",
    "reagerades": "reagera",
    "reagerande": "reagera",
    "reageranden": "reagerande",
    "reagerandena": "reagerande",
    "reagerandenas": "reagerande",
    "reagerandens": "reagerande",
    "reagerandes": "reagerande",
    "reagerandet": "reagerande",
    "reagerandets": "reagerande",
    "reagerar": "reagera",
    "reageras": "reagera",
    "reagerat": "reagera",
    "reagerats": "reagera",
    "reageringar": "reagering",
    "reageringarna": "reagering",
    "reageringarnas": "reagering",
    "reageringars": "reagering",
    "reageringen": "reagering",
    "reageringens": "reagering",
    "reagerings": "reagering",
    "reaktionen": "reaktion",
    "reaktionens": "reaktion",
    "reaktioner": "reaktion",
    "reaktionerna": "reaktion",
    "reaktionernas": "reaktion",
    "reaktioners": "reaktion",
    "reaktions": "reaktion",
    "reaktionsbenägens": "reaktionsbenägen",
    "reaktionsbenäget": "reaktionsbenägen",
    "reaktionsbenägets": "reaktionsbenägen",
    "reaktionsbenägna": "reaktionsbenägen",
    "reaktionsbenägnare": "reaktionsbenägen",
    "reaktionsbenägnares": "reaktionsbenägen",
    "reaktionsbenägnas": "reaktionsbenägen",
    "reaktionsbenägnast": "reaktionsbenägen",
    "reaktionsbenägnaste": "reaktionsbenägen",
    "reaktionsbenägnastes": "reaktionsbenägen",
    "reaktionsbenägnasts": "reaktionsbenägen",
    "reaktionsbenägne": "reaktionsbenägen",
    "reaktionsbenägnes": "reaktionsbenägen",
    "reaktionsdriften": "reaktionsdrift",
    "reaktionsdriftens": "reaktionsdrift",
    "reaktionsdrifts": "reaktionsdrift",
    "reaktionsfasen": "reaktionsfas",
    "reaktionsfasens": "reaktionsfas",
    "reaktionsfaser": "reaktionsfas",
    "reaktionsfaserna": "reaktionsfas",
    "reaktionsfasernas": "reaktionsfas",
    "reaktionsfasers": "reaktionsfas",
    "reaktionsförmågan": "reaktionsförmåga",
    "reaktionsförmågans": "reaktionsförmåga",
    "reaktionsförmågas": "reaktionsförmåga",
    "reaktionsförmåge": "reaktionsförmåga",
    "reaktionsmotorer": "reaktionsmotor",
    "reaktionsmotorerna": "reaktionsmotor",
    "reaktionsmotorernas": "reaktionsmotor",
    "reaktionsmotorers": "reaktionsmotor",
    "reaktionsmotorn": "reaktionsmotor",
    "reaktionsmotorns": "reaktionsmotor",
    "reaktionsmotors": "reaktionsmotor",
    "reaktionsprodukten": "reaktionsprodukt",
    "reaktionsproduktens": "reaktionsprodukt",
    "reaktionsprodukter": "reaktionsprodukt",
    "reaktionsprodukterna": "reaktionsprodukt",
    "reaktionsprodukternas": "reaktionsprodukt",
    "reaktionsprodukters": "reaktionsprodukt",
    "reaktionsprodukts": "reaktionsprodukt",
    "reaktionstemperaturen": "reaktionstemperatur",
    "reaktionstemperaturens": "reaktionstemperatur",
    "reaktionstemperaturer": "reaktionstemperatur",
    "reaktionstemperaturerna": "reaktionstemperatur",
    "reaktionstemperaturernas": "reaktionstemperatur",
    "reaktionstemperaturers": "reaktionstemperatur",
    "reaktionstemperaturs": "reaktionstemperatur",
    "reaktionstiden": "reaktionstid",
    "reaktionstidens": "reaktionstid",
    "reaktionstider": "reaktionstid",
    "reaktionstiderna": "reaktionstid",
    "reaktionstidernas": "reaktionstid",
    "reaktionstiders": "reaktionstid",
    "reaktionstids": "reaktionstid",
    "reaktionszonen": "reaktionszon",
    "reaktionszonens": "reaktionszon",
    "reaktionszoner": "reaktionszon",
    "reaktionszonerna": "reaktionszon",
    "reaktionszonernas": "reaktionszon",
    "reaktionszoners": "reaktionszon",
    "reaktionszons": "reaktionszon",
    "reaktionära": "reaktionär",
    "reaktionärare": "reaktionär",
    "reaktionärares": "reaktionär",
    "reaktionäras": "reaktionär",
    "reaktionärast": "reaktionär",
    "reaktionäraste": "reaktionär",
    "reaktionärastes": "reaktionär",
    "reaktionärasts": "reaktionär",
    "reaktionäre": "reaktionär",
    "reaktionären": "reaktionär",
    "reaktionärens": "reaktionär",
    "reaktionärer": "reaktionär",
    "reaktionärerna": "reaktionär",
    "reaktionärernas": "reaktionär",
    "reaktionärers": "reaktionär",
    "reaktionäres": "reaktionär",
    "reaktionärs": "reaktionär",
    "reaktionärt": "reaktionär",
    "reaktionärts": "reaktionär",
    "reaktiva": "reaktiv",
    "reaktivare": "reaktiv",
    "reaktivares": "reaktiv",
    "reaktivas": "reaktiv",
    "reaktivast": "reaktiv",
    "reaktivaste": "reaktiv",
    "reaktivastes": "reaktiv",
    "reaktivasts": "reaktiv",
    "reaktive": "reaktiv",
    "reaktiverad": "reaktivera",
    "reaktiverade": "reaktivera",
    "reaktiverades": "reaktivera",
    "reaktiverads": "reaktivera",
    "reaktiverande": "reaktivera",
    "reaktiveranden": "reaktiverande",
    "reaktiverandena": "reaktiverande",
    "reaktiverandenas": "reaktiverande",
    "reaktiverandens": "reaktiverande",
    "reaktiverandes": "reaktiverande",
    "reaktiverandet": "reaktiverande",
    "reaktiverandets": "reaktiverande",
    "reaktiverar": "reaktivera",
    "reaktiveras": "reaktivera",
    "reaktiverat": "reaktivera",
    "reaktiverats": "reaktivera",
    "reaktiverbara": "reaktiverbar",
    "reaktiverbarare": "reaktiverbar",
    "reaktiverbarares": "reaktiverbar",
    "reaktiverbaras": "reaktiverbar",
    "reaktiverbarast": "reaktiverbar",
    "reaktiverbaraste": "reaktiverbar",
    "reaktiverbarastes": "reaktiverbar",
    "reaktiverbarasts": "reaktiverbar",
    "reaktiverbare": "reaktiverbar",
    "reaktiverbares": "reaktiverbar",
    "reaktiverbarheten": "reaktiverbarhet",
    "reaktiverbarhetens": "reaktiverbarhet",
    "reaktiverbarhets": "reaktiverbarhet",
    "reaktiverbars": "reaktiverbar",
    "reaktiverbart": "reaktiverbar",
    "reaktiverbarts": "reaktiverbar",
    "reaktiveringar": "reaktivering",
    "reaktiveringarna": "reaktivering",
    "reaktiveringarnas": "reaktivering",
    "reaktiveringars": "reaktivering",
    "reaktiveringen": "reaktivering",
    "reaktiveringens": "reaktivering",
    "reaktiverings": "reaktivering",
    "reaktives": "reaktiv",
    "reaktivs": "reaktiv",
    "reaktivt": "reaktiv",
    "reaktivts": "reaktiv",
    "reaktorbyggnaden": "reaktorbyggnad",
    "reaktorbyggnadens": "reaktorbyggnad",
    "reaktorbyggnader": "reaktorbyggnad",
    "reaktorbyggnaderna": "reaktorbyggnad",
    "reaktorbyggnadernas": "reaktorbyggnad",
    "reaktorbyggnaders": "reaktorbyggnad",
    "reaktorbyggnads": "reaktorbyggnad",
    "reaktorer": "reaktor",
    "reaktorerna": "reaktor",
    "reaktorernas": "reaktor",
    "reaktorers": "reaktor",
    "reaktorfysiken": "reaktorfysik",
    "reaktorfysikens": "reaktorfysik",
    "reaktorfysiks": "reaktorfysik",
    "reaktorhärdar": "reaktorhärd",
    "reaktorhärdarna": "reaktorhärd",
    "reaktorhärdarnas": "reaktorhärd",
    "reaktorhärdars": "reaktorhärd",
    "reaktorhärden": "reaktorhärd",
    "reaktorhärdens": "reaktorhärd",
    "reaktorhärds": "reaktorhärd",
    "reaktorkatastrofen": "reaktorkatastrof",
    "reaktorkatastrofens": "reaktorkatastrof",
    "reaktorkatastrofer": "reaktorkatastrof",
    "reaktorkatastroferna": "reaktorkatastrof",
    "reaktorkatastrofernas": "reaktorkatastrof",
    "reaktorkatastrofers": "reaktorkatastrof",
    "reaktorkatastrofs": "reaktorkatastrof",
    "reaktorkramar": "reaktorkramare",
    "reaktorkramaren": "reaktorkramare",
    "reaktorkramarens": "reaktorkramare",
    "reaktorkramares": "reaktorkramare",
    "reaktorkramarna": "reaktorkramare",
    "reaktorkramarnas": "reaktorkramare",
    "reaktorn": "reaktor",
    "reaktorns": "reaktor",
    "reaktors": "reaktor",
    "reaktorsäkerheten": "reaktorsäkerhet",
    "reaktorsäkerhetens": "reaktorsäkerhet",
    "reaktorsäkerheter": "reaktorsäkerhet",
    "reaktorsäkerheterna": "reaktorsäkerhet",
    "reaktorsäkerheternas": "reaktorsäkerhet",
    "reaktorsäkerheters": "reaktorsäkerhet",
    "reaktorsäkerhets": "reaktorsäkerhet",
    "reaktortypen": "reaktortyp",
    "reaktortypens": "reaktortyp",
    "reaktortyper": "reaktortyp",
    "reaktortyperna": "reaktortyp",
    "reaktortypernas": "reaktortyp",
    "reaktortypers": "reaktortyp",
    "reaktortyps": "reaktortyp",
    "reaktorutsläppen": "reaktorutsläpp",
    "reaktorutsläppens": "reaktorutsläpp",
    "reaktorutsläppet": "reaktorutsläpp",
    "reaktorutsläppets": "reaktorutsläpp",
    "reaktorutsläpps": "reaktorutsläpp",
    "reala": "real",
    "realare": "real",
    "realares": "real",
    "realas": "real",
    "realast": "real",
    "realaste": "real",
    "realastes": "real",
    "realasts": "real",
    "reale": "real",
    "realen": "reale",
    "realena": "reale",
    "realenas": "reale",
    "realens": "reale",
    "reales": "reale",
    "realet": "reale",
    "realets": "reale",
    "realexamens": "realexamen",
    "realexamina": "realexamen",
    "realexaminas": "realexamen",
    "realgenuset": "realgenus",
    "realgenusets": "realgenus",
    "realian": "realia",
    "realiana": "realia",
    "realianas": "realia",
    "realians": "realia",
    "realias": "realia",
    "realindexen": "realindex",
    "realindexens": "realindex",
    "realindexet": "realindex",
    "realindexets": "realindex",
    "realisationen": "realisation",
    "realisationens": "realisation",
    "realisationer": "realisation",
    "realisationerna": "realisation",
    "realisationernas": "realisation",
    "realisationers": "realisation",
    "realisations": "realisation",
    "realisationsvinsten": "realisationsvinst",
    "realisationsvinstens": "realisationsvinst",
    "realisationsvinster": "realisationsvinst",
    "realisationsvinsterna": "realisationsvinst",
    "realisationsvinsternas": "realisationsvinst",
    "realisationsvinsters": "realisationsvinst",
    "realisationsvinsts": "realisationsvinst",
    "realiserad": "realisera",
    "realiserade": "realisera",
    "realiserades": "realisera",
    "realiserads": "realisera",
    "realiserande": "realisera",
    "realiseranden": "realiserande",
    "realiserandena": "realiserande",
    "realiserandenas": "realiserande",
    "realiserandens": "realiserande",
    "realiserandes": "realiserande",
    "realiserandet": "realiserande",
    "realiserandets": "realiserande",
    "realiserar": "realisera",
    "realiseras": "realisera",
    "realiserat": "realisera",
    "realiserats": "realisera",
    "realiserbara": "realiserbar",
    "realiserbarare": "realiserbar",
    "realiserbarares": "realiserbar",
    "realiserbaras": "realiserbar",
    "realiserbarast": "realiserbar",
    "realiserbaraste": "realiserbar",
    "realiserbarastes": "realiserbar",
    "realiserbarasts": "realiserbar",
    "realiserbare": "realiserbar",
    "realiserbares": "realiserbar",
    "realiserbarheten": "realiserbarhet",
    "realiserbarhetens": "realiserbarhet",
    "realiserbarhets": "realiserbarhet",
    "realiserbars": "realiserbar",
    "realiserbart": "realiserbar",
    "realiserbarts": "realiserbar",
    "realiseringar": "realisering",
    "realiseringarna": "realisering",
    "realiseringarnas": "realisering",
    "realiseringars": "realisering",
    "realiseringen": "realisering",
    "realiseringens": "realisering",
    "realiserings": "realisering",
    "realismen": "realism",
    "realismens": "realism",
    "realismer": "realism",
    "realismerna": "realism",
    "realismernas": "realism",
    "realismers": "realism",
    "realisms": "realism",
    "realisten": "realist",
    "realistens": "realist",
    "realister": "realist",
    "realisterna": "realist",
    "realisternas": "realist",
    "realisters": "realist",
    "realistiska": "realistisk",
    "realistiskare": "realistisk",
    "realistiskares": "realistisk",
    "realistiskas": "realistisk",
    "realistiskast": "realistisk",
    "realistiskaste": "realistisk",
    "realistiskastes": "realistisk",
    "realistiskasts": "realistisk",
    "realistiske": "realistisk",
    "realistiskes": "realistisk",
    "realistisks": "realistisk",
    "realistiskt": "realistisk",
    "realistiskts": "realistisk",
    "realists": "realist",
    "realiteten": "realitet",
    "realitetens": "realitet",
    "realiteter": "realitet",
    "realiteterna": "realitet",
    "realiteternas": "realitet",
    "realiteters": "realitet",
    "realitets": "realitet",
    "realkapitalen": "realkapital",
    "realkapitalens": "realkapital",
    "realkapitalet": "realkapital",
    "realkapitalets": "realkapital",
    "realkapitals": "realkapital",
    "realkatalogen": "realkatalog",
    "realkatalogens": "realkatalog",
    "realkataloger": "realkatalog",
    "realkatalogerna": "realkatalog",
    "realkatalogernas": "realkatalog",
    "realkatalogers": "realkatalog",
    "realkatalogs": "realkatalog",
    "reallinjen": "reallinje",
    "reallinjens": "reallinje",
    "reallinjer": "reallinje",
    "reallinjerna": "reallinje",
    "reallinjernas": "reallinje",
    "reallinjers": "reallinje",
    "reallinjes": "reallinje",
    "reallönen": "reallön",
    "reallönens": "reallön",
    "reallöner": "reallön",
    "reallönerna": "reallön",
    "reallönernas": "reallön",
    "reallöners": "reallön",
    "reallönesänkningar": "reallönesänkning",
    "reallönesänkningarna": "reallönesänkning",
    "reallönesänkningarnas": "reallönesänkning",
    "reallönesänkningars": "reallönesänkning",
    "reallönesänkningen": "reallönesänkning",
    "reallönesänkningens": "reallönesänkning",
    "reallönesänknings": "reallönesänkning",
    "reallöns": "reallön",
    "realpolitiken": "realpolitik",
    "realpolitikens": "realpolitik",
    "realpolitiks": "realpolitik",
    "realpolitiska": "realpolitisk",
    "realpolitiskas": "realpolitisk",
    "realpolitiske": "realpolitisk",
    "realpolitiskes": "realpolitisk",
    "realpolitisks": "realpolitisk",
    "realpolitiskt": "realpolitisk",
    "realpolitiskts": "realpolitisk",
    "reals": "real",
    "realskolan": "realskola",
    "realskolans": "realskola",
    "realskolas": "realskola",
    "realskole": "realskola",
    "realskolor": "realskola",
    "realskolorna": "realskola",
    "realskolornas": "realskola",
    "realskolors": "realskola",
    "realsäkerheten": "realsäkerhet",
    "realsäkerhetens": "realsäkerhet",
    "realsäkerheter": "realsäkerhet",
    "realsäkerheterna": "realsäkerhet",
    "realsäkerheternas": "realsäkerhet",
    "realsäkerheters": "realsäkerhet",
    "realsäkerhets": "realsäkerhet",
    "realt": "real",
    "realtidsbearbetningar": "realtidsbearbetning",
    "realtidsbearbetningarna": "realtidsbearbetning",
    "realtidsbearbetningarnas": "realtidsbearbetning",
    "realtidsbearbetningars": "realtidsbearbetning",
    "realtidsbearbetningen": "realtidsbearbetning",
    "realtidsbearbetningens": "realtidsbearbetning",
    "realtidsbearbetnings": "realtidsbearbetning",
    "realts": "real",
    "realvärden": "realvärde",
    "realvärdena": "realvärde",
    "realvärdenas": "realvärde",
    "realvärdens": "realvärde",
    "realvärdes": "realvärde",
    "realvärdet": "realvärde",
    "realvärdets": "realvärde",
    "reamotorer": "reamotor",
    "reamotorerna": "reamotor",
    "reamotorernas": "reamotor",
    "reamotorers": "reamotor",
    "reamotorn": "reamotor",
    "reamotorns": "reamotor",
    "reamotors": "reamotor",
    "rean": "rea",
    "reande": "rea",
    "reanden": "reande",
    "reandena": "reande",
    "reandenas": "reande",
    "reandens": "reande",
    "reandes": "reande",
    "reandet": "reande",
    "reandets": "reande",
    "reans": "rea",
    "reaplanen": "reaplan",
    "reaplanens": "reaplan",
    "reaplanet": "reaplan",
    "reaplanets": "reaplan",
    "reaplans": "reaplan",
    "reaprisen": "reapris",
    "reaprisens": "reapris",
    "reapriser": "reapris",
    "reapriserna": "reapris",
    "reaprisernas": "reapris",
    "reaprisers": "reapris",
    "reapriset": "reapris",
    "reaprisets": "reapris",
    "rear": "rea",
    "reas": "rea",
    "reassuransen": "reassurans",
    "reassuransens": "reassurans",
    "reassuranser": "reassurans",
    "reassuranserna": "reassurans",
    "reassuransernas": "reassurans",
    "reassuransers": "reassurans",
    "reassurerad": "reassurera",
    "reassurerade": "reassurera",
    "reassurerades": "reassurera",
    "reassurerads": "reassurera",
    "reassurerande": "reassurera",
    "reassureranden": "reassurerande",
    "reassurerandena": "reassurerande",
    "reassurerandenas": "reassurerande",
    "reassurerandens": "reassurerande",
    "reassurerandes": "reassurerande",
    "reassurerandet": "reassurerande",
    "reassurerandets": "reassurerande",
    "reassurerar": "reassurera",
    "reassureras": "reassurera",
    "reassurerat": "reassurera",
    "reassurerats": "reassurera",
    "reassurerbara": "reassurerbar",
    "reassurerbarare": "reassurerbar",
    "reassurerbarares": "reassurerbar",
    "reassurerbaras": "reassurerbar",
    "reassurerbarast": "reassurerbar",
    "reassurerbaraste": "reassurerbar",
    "reassurerbarastes": "reassurerbar",
    "reassurerbarasts": "reassurerbar",
    "reassurerbare": "reassurerbar",
    "reassurerbares": "reassurerbar",
    "reassurerbarheten": "reassurerbarhet",
    "reassurerbarhetens": "reassurerbarhet",
    "reassurerbarhets": "reassurerbarhet",
    "reassurerbars": "reassurerbar",
    "reassurerbart": "reassurerbar",
    "reassurerbarts": "reassurerbar",
    "reassureringar": "reassurering",
    "reassureringarna": "reassurering",
    "reassureringarnas": "reassurering",
    "reassureringars": "reassurering",
    "reassureringen": "reassurering",
    "reassureringens": "reassurering",
    "reassurerings": "reassurering",
    "reat": "rea",
    "reats": "rea",
    "rebelledar": "rebelledare",
    "rebelledaren": "rebelledare",
    "rebelledarens": "rebelledare",
    "rebelledares": "rebelledare",
    "rebelledarna": "rebelledare",
    "rebelledarnas": "rebelledare",
    "rebellen": "rebell",
    "rebellens": "rebell",
    "rebeller": "rebell",
    "rebellerade": "rebellera",
    "rebellerades": "rebellera",
    "rebellerande": "rebellera",
    "rebelleranden": "rebellerande",
    "rebellerandena": "rebellerande",
    "rebellerandenas": "rebellerande",
    "rebellerandens": "rebellerande",
    "rebellerandes": "rebellerande",
    "rebellerandet": "rebellerande",
    "rebellerandets": "rebellerande",
    "rebellerar": "rebellera",
    "rebelleras": "rebellera",
    "rebellerat": "rebellera",
    "rebellerats": "rebellera",
    "rebelleringar": "rebellering",
    "rebelleringarna": "rebellering",
    "rebelleringarnas": "rebellering",
    "rebelleringars": "rebellering",
    "rebelleringen": "rebellering",
    "rebelleringens": "rebellering",
    "rebellerings": "rebellering",
    "rebellerna": "rebell",
    "rebellernas": "rebell",
    "rebellers": "rebell",
    "rebellfäst": "rebellfäste",
    "rebellfästen": "rebellfäste",
    "rebellfästena": "rebellfäste",
    "rebellfästenas": "rebellfäste",
    "rebellfästens": "rebellfäste",
    "rebellfästes": "rebellfäste",
    "rebellfästet": "rebellfäste",
    "rebellfästets": "rebellfäste",
    "rebelliska": "rebellisk",
    "rebelliskare": "rebellisk",
    "rebelliskares": "rebellisk",
    "rebelliskas": "rebellisk",
    "rebelliskast": "rebellisk",
    "rebelliskaste": "rebellisk",
    "rebelliskastes": "rebellisk",
    "rebelliskasts": "rebellisk",
    "rebelliske": "rebellisk",
    "rebelliskes": "rebellisk",
    "rebellisks": "rebellisk",
    "rebelliskt": "rebellisk",
    "rebelliskts": "rebellisk",
    "rebells": "rebell",
    "rebusar": "rebus",
    "rebusarna": "rebus",
    "rebusarnas": "rebus",
    "rebusars": "rebus",
    "rebusen": "rebus",
    "rebusens": "rebus",
    "receivern": "receiver",
    "receiverns": "receiver",
    "receivers": "receiver",
    "receiversarna": "receiver",
    "receiversarnas": "receiver",
    "receiversen": "receiver",
    "receiversens": "receiver",
    "receivrar": "receiver",
    "receivrarna": "receiver",
    "receivrarnas": "receiver",
    "receivrars": "receiver",
    "recensenten": "recensent",
    "recensentens": "recensent",
    "recensenter": "recensent",
    "recensenterna": "recensent",
    "recensenternas": "recensent",
    "recensenters": "recensent",
    "recensents": "recensent",
    "recenserad": "recensera",
    "recenserade": "recensera",
    "recenserades": "recensera",
    "recenserads": "recensera",
    "recenserande": "recensera",
    "recenseranden": "recenserande",
    "recenserandena": "recenserande",
    "recenserandenas": "recenserande",
    "recenserandens": "recenserande",
    "recenserandes": "recenserande",
    "recenserandet": "recenserande",
    "recenserandets": "recenserande",
    "recenserar": "recensera",
    "recenseras": "recensera",
    "recenserat": "recensera",
    "recenserats": "recensera",
    "recenserbara": "recenserbar",
    "recenserbarare": "recenserbar",
    "recenserbarares": "recenserbar",
    "recenserbaras": "recenserbar",
    "recenserbarast": "recenserbar",
    "recenserbaraste": "recenserbar",
    "recenserbarastes": "recenserbar",
    "recenserbarasts": "recenserbar",
    "recenserbare": "recenserbar",
    "recenserbares": "recenserbar",
    "recenserbarheten": "recenserbarhet",
    "recenserbarhetens": "recenserbarhet",
    "recenserbarhets": "recenserbarhet",
    "recenserbars": "recenserbar",
    "recenserbart": "recenserbar",
    "recenserbarts": "recenserbar",
    "recenseringar": "recensering",
    "recenseringarna": "recensering",
    "recenseringarnas": "recensering",
    "recenseringars": "recensering",
    "recenseringen": "recensering",
    "recenseringens": "recensering",
    "recenserings": "recensering",
    "recensionen": "recension",
    "recensionens": "recension",
    "recensioner": "recension",
    "recensionerna": "recension",
    "recensionernas": "recension",
    "recensioners": "recension",
    "recensions": "recension",
    "recensionsexemplaren": "recensionsexemplar",
    "recensionsexemplarens": "recensionsexemplar",
    "recensionsexemplaret": "recensionsexemplar",
    "recensionsexemplarets": "recensionsexemplar",
    "recensionsexemplars": "recensionsexemplar",
    "recensionsuppdragen": "recensionsuppdrag",
    "recensionsuppdragens": "recensionsuppdrag",
    "recensionsuppdraget": "recensionsuppdrag",
    "recensionsuppdragets": "recensionsuppdrag",
    "recensionsuppdrags": "recensionsuppdrag",
    "recenta": "recent",
    "recentare": "recent",
    "recentares": "recent",
    "recentas": "recent",
    "recentast": "recent",
    "recentaste": "recent",
    "recentastes": "recent",
    "recentasts": "recent",
    "recente": "recent",
    "recentes": "recent",
    "recentiorer": "recentior",
    "recentiorerna": "recentior",
    "recentiorernas": "recentior",
    "recentiorers": "recentior",
    "recentiorn": "recentior",
    "recentiorns": "recentior",
    "recentiors": "recentior",
    "recents": "recent",
    "receptarien": "receptarie",
    "receptariens": "receptarie",
    "receptarier": "receptarie",
    "receptarierna": "receptarie",
    "receptariernas": "receptarie",
    "receptariers": "receptarie",
    "receptaries": "receptarie",
    "receptbelagda": "receptbelagd",
    "receptbelagdare": "receptbelagd",
    "receptbelagdares": "receptbelagd",
    "receptbelagdas": "receptbelagd",
    "receptbelagdast": "receptbelagd",
    "receptbelagdaste": "receptbelagd",
    "receptbelagdastes": "receptbelagd",
    "receptbelagdasts": "receptbelagd",
    "receptbelagde": "receptbelagd",
    "receptbelagdes": "receptbelagd",
    "receptbelagds": "receptbelagd",
    "receptbelagt": "receptbelagd",
    "receptbelagts": "receptbelagd",
    "receptdatabasen": "receptdatabas",
    "receptdatabasens": "receptdatabas",
    "receptdatabaser": "receptdatabas",
    "receptdatabaserna": "receptdatabas",
    "receptdatabasernas": "receptdatabas",
    "receptdatabasers": "receptdatabas",
    "recepten": "recept",
    "receptens": "recept",
    "receptet": "recept",
    "receptets": "recept",
    "receptfria": "receptfri",
    "receptfriare": "receptfri",
    "receptfriares": "receptfri",
    "receptfrias": "receptfri",
    "receptfriast": "receptfri",
    "receptfriaste": "receptfri",
    "receptfriastes": "receptfri",
    "receptfriasts": "receptfri",
    "receptfrie": "receptfri",
    "receptfries": "receptfri",
    "receptfris": "receptfri",
    "receptfritt": "receptfri",
    "receptfritts": "receptfri",
    "receptionen": "reception",
    "receptionens": "reception",
    "receptioner": "reception",
    "receptionerna": "reception",
    "receptionernas": "reception",
    "receptioners": "reception",
    "receptionisten": "receptionist",
    "receptionistens": "receptionist",
    "receptionister": "receptionist",
    "receptionisterna": "receptionist",
    "receptionisternas": "receptionist",
    "receptionisters": "receptionist",
    "receptionists": "receptionist",
    "receptions": "reception",
    "receptiva": "receptiv",
    "receptivare": "receptiv",
    "receptivares": "receptiv",
    "receptivas": "receptiv",
    "receptivast": "receptiv",
    "receptivaste": "receptiv",
    "receptivastes": "receptiv",
    "receptivasts": "receptiv",
    "receptive": "receptiv",
    "receptives": "receptiv",
    "receptiviteten": "receptivitet",
    "receptivitetens": "receptivitet",
    "receptiviteter": "receptivitet",
    "receptiviteterna": "receptivitet",
    "receptiviteternas": "receptivitet",
    "receptiviteters": "receptivitet",
    "receptivitets": "receptivitet",
    "receptivs": "receptiv",
    "receptivt": "receptiv",
    "receptivts": "receptiv",
    "receptorer": "receptor",
    "receptorerna": "receptor",
    "receptorernas": "receptor",
    "receptorers": "receptor",
    "receptorn": "receptor",
    "receptorns": "receptor",
    "receptors": "receptor",
    "recepts": "recept",
    "recepturen": "receptur",
    "recepturens": "receptur",
    "recepturer": "receptur",
    "recepturerna": "receptur",
    "recepturernas": "receptur",
    "recepturers": "receptur",
    "recepturs": "receptur",
    "recessen": "recess",
    "recessens": "recess",
    "recesser": "recess",
    "recesserna": "recess",
    "recessernas": "recess",
    "recessers": "recess",
    "recessionen": "recession",
    "recessionens": "recession",
    "recessioner": "recession",
    "recessionerna": "recession",
    "recessionernas": "recession",
    "recessioners": "recession",
    "recessions": "recession",
    "recessiva": "recessiv",
    "recessivare": "recessiv",
    "recessivares": "recessiv",
    "recessivas": "recessiv",
    "recessivast": "recessiv",
    "recessivaste": "recessiv",
    "recessivastes": "recessiv",
    "recessivasts": "recessiv",
    "recessive": "recessiv",
    "recessives": "recessiv",
    "recessivs": "recessiv",
    "recessivt": "recessiv",
    "recessivts": "recessiv",
    "recetten": "recett",
    "recettens": "recett",
    "recetter": "recett",
    "recetterna": "recett",
    "recetternas": "recett",
    "recetters": "recett",
    "recetts": "recett",
    "recherchen": "recherch",
    "recherchens": "recherch",
    "rechercher": "recherch",
    "rechercherna": "recherch",
    "recherchernas": "recherch",
    "recherchers": "recherch",
    "recherchs": "recherch",
    "recidiven": "recidiv",
    "recidivens": "recidiv",
    "recidiverade": "recidivera",
    "recidiverades": "recidivera",
    "recidiverande": "recidivera",
    "recidiveranden": "recidiverande",
    "recidiverandena": "recidiverande",
    "recidiverandenas": "recidiverande",
    "recidiverandens": "recidiverande",
    "recidiverandes": "recidiverande",
    "recidiverandet": "recidiverande",
    "recidiverandets": "recidiverande",
    "recidiverar": "recidivera",
    "recidiveras": "recidivera",
    "recidiverat": "recidivera",
    "recidiverats": "recidivera",
    "recidiveringar": "recidivering",
    "recidiveringarna": "recidivering",
    "recidiveringarnas": "recidivering",
    "recidiveringars": "recidivering",
    "recidiveringen": "recidivering",
    "recidiveringens": "recidivering",
    "recidiverings": "recidivering",
    "recidivet": "recidiv",
    "recidivets": "recidiv",
    "recidivs": "recidiv",
    "recipienden": "recipiend",
    "recipiendens": "recipiend",
    "recipiender": "recipiend",
    "recipienderna": "recipiend",
    "recipiendernas": "recipiend",
    "recipienders": "recipiend",
    "recipiends": "recipiend",
    "recipienten": "recipient",
    "recipientens": "recipient",
    "recipienter": "recipient",
    "recipienterna": "recipient",
    "recipienternas": "recipient",
    "recipienters": "recipient",
    "recipients": "recipient",
    "recipierad": "recipiera",
    "recipierade": "recipiera",
    "recipierades": "recipiera",
    "recipierads": "recipiera",
    "recipierande": "recipiera",
    "recipieranden": "recipierande",
    "recipierandena": "recipierande",
    "recipierandenas": "recipierande",
    "recipierandens": "recipierande",
    "recipierandes": "recipierande",
    "recipierandet": "recipierande",
    "recipierandets": "recipierande",
    "recipierar": "recipiera",
    "recipieras": "recipiera",
    "recipierat": "recipiera",
    "recipierats": "recipiera",
    "recipierbara": "recipierbar",
    "recipierbarare": "recipierbar",
    "recipierbarares": "recipierbar",
    "recipierbaras": "recipierbar",
    "recipierbarast": "recipierbar",
    "recipierbaraste": "recipierbar",
    "recipierbarastes": "recipierbar",
    "recipierbarasts": "recipierbar",
    "recipierbare": "recipierbar",
    "recipierbares": "recipierbar",
    "recipierbarheten": "recipierbarhet",
    "recipierbarhetens": "recipierbarhet",
    "recipierbarhets": "recipierbarhet",
    "recipierbars": "recipierbar",
    "recipierbart": "recipierbar",
    "recipierbarts": "recipierbar",
    "recipieringar": "recipiering",
    "recipieringarna": "recipiering",
    "recipieringarnas": "recipiering",
    "recipieringars": "recipiering",
    "recipieringen": "recipiering",
    "recipieringens": "recipiering",
    "recipierings": "recipiering",
    "reciprociteten": "reciprocitet",
    "reciprocitetens": "reciprocitet",
    "reciprociteter": "reciprocitet",
    "reciprociteterna": "reciprocitet",
    "reciprociteternas": "reciprocitet",
    "reciprociteters": "reciprocitet",
    "reciprocitets": "reciprocitet",
    "reciproka": "reciprok",
    "reciprokare": "reciprok",
    "reciprokares": "reciprok",
    "reciprokas": "reciprok",
    "reciprokast": "reciprok",
    "reciprokaste": "reciprok",
    "reciprokastes": "reciprok",
    "reciprokasts": "reciprok",
    "reciproke": "reciprok",
    "reciprokes": "reciprok",
    "reciproks": "reciprok",
    "reciprokt": "reciprok",
    "reciprokts": "reciprok",
    "recitationen": "recitation",
    "recitationens": "recitation",
    "recitationer": "recitation",
    "recitationerna": "recitation",
    "recitationernas": "recitation",
    "recitationers": "recitation",
    "recitations": "recitation",
    "recitativen": "recitativ",
    "recitativens": "recitativ",
    "recitativet": "recitativ",
    "recitativets": "recitativ",
    "recitativs": "recitativ",
    "reciten": "recit",
    "recitens": "recit",
    "reciter": "recit",
    "reciterad": "recitera",
    "reciterade": "recitera",
    "reciterades": "recitera",
    "reciterads": "recitera",
    "reciterande": "recitera",
    "reciteranden": "reciterande",
    "reciterandena": "reciterande",
    "reciterandenas": "reciterande",
    "reciterandens": "reciterande",
    "reciterandes": "reciterande",
    "reciterandet": "reciterande",
    "reciterandets": "reciterande",
    "reciterar": "recitera",
    "reciteras": "recitera",
    "reciterat": "recitera",
    "reciterats": "recitera",
    "reciterbara": "reciterbar",
    "reciterbarare": "reciterbar",
    "reciterbarares": "reciterbar",
    "reciterbaras": "reciterbar",
    "reciterbarast": "reciterbar",
    "reciterbaraste": "reciterbar",
    "reciterbarastes": "reciterbar",
    "reciterbarasts": "reciterbar",
    "reciterbare": "reciterbar",
    "reciterbares": "reciterbar",
    "reciterbarheten": "reciterbarhet",
    "reciterbarhetens": "reciterbarhet",
    "reciterbarhets": "reciterbarhet",
    "reciterbars": "reciterbar",
    "reciterbart": "reciterbar",
    "reciterbarts": "reciterbar",
    "reciteringar": "recitering",
    "reciteringarna": "recitering",
    "reciteringarnas": "recitering",
    "reciteringars": "recitering",
    "reciteringen": "recitering",
    "reciteringens": "recitering",
    "reciterings": "recitering",
    "reciterna": "recit",
    "reciternas": "recit",
    "reciters": "recit",
    "recits": "recit",
    "red": "rida",
    "redaktionella": "redaktionell",
    "redaktionellare": "redaktionell",
    "redaktionellares": "redaktionell",
    "redaktionellas": "redaktionell",
    "redaktionellast": "redaktionell",
    "redaktionellaste": "redaktionell",
    "redaktionellastes": "redaktionell",
    "redaktionellasts": "redaktionell",
    "redaktionelle": "redaktionell",
    "redaktionelles": "redaktionell",
    "redaktionells": "redaktionell",
    "redaktionellt": "redaktionell",
    "redaktionellts": "redaktionell",
    "redaktionen": "redaktion",
    "redaktionens": "redaktion",
    "redaktioner": "redaktion",
    "redaktionerna": "redaktion",
    "redaktionernas": "redaktion",
    "redaktioners": "redaktion",
    "redaktions": "redaktion",
    "redaktionssekreterar": "redaktionssekreterare",
    "redaktionssekreteraren": "redaktionssekreterare",
    "redaktionssekreterarens": "redaktionssekreterare",
    "redaktionssekreterares": "redaktionssekreterare",
    "redaktionssekreterarna": "redaktionssekreterare",
    "redaktionssekreterarnas": "redaktionssekreterare",
    "redaktören": "redaktör",
    "redaktörens": "redaktör",
    "redaktörer": "redaktör",
    "redaktörerna": "redaktör",
    "redaktörernas": "redaktör",
    "redaktörers": "redaktör",
    "redaktörn": "redaktör",
    "redaktörns": "redaktör",
    "redaktörs": "redaktör",
    "redan": "reda",
    "redande": "reda",
    "redanden": "redande",
    "redandena": "redande",
    "redandenas": "redande",
    "redandens": "redande",
    "redandes": "redande",
    "redandet": "redande",
    "redandets": "redande",
    "redans": "reda",
    "redar": "redare",
    "redaren": "redare",
    "redarens": "redare",
    "redares": "redare",
    "redarna": "redare",
    "redarnas": "redare",
    "redas": "reda",
    "redbara": "redbar",
    "redbarare": "redbar",
    "redbarares": "redbar",
    "redbaras": "redbar",
    "redbarast": "redbar",
    "redbaraste": "redbar",
    "redbarastes": "redbar",
    "redbarasts": "redbar",
    "redbare": "redbar",
    "redbares": "redbar",
    "redbarheten": "redbarhet",
    "redbarhetens": "redbarhet",
    "redbarhets": "redbarhet",
    "redbars": "redbar",
    "redbart": "redbar",
    "redbarts": "redbar",
    "redd": "reda",
    "redda": "reda",
    "reddas": "reda",
    "redde": "reda",
    "redden": "redd",
    "reddens": "redd",
    "redder": "redd",
    "redderna": "redd",
    "reddernas": "redd",
    "redders": "redd",
    "reddes": "reda",
    "redds": "redd",
    "reden": "rede",
    "redena": "rede",
    "redenas": "rede",
    "redens": "rede",
    "reder": "reda",
    "rederier": "rederi",
    "rederierna": "rederi",
    "rederiernas": "rederi",
    "rederiers": "rederi",
    "rederiet": "rederi",
    "rederiets": "rederi",
    "rederis": "rederi",
    "rederit": "rederi",
    "rederits": "rederi",
    "rederiverksamheten": "rederiverksamhet",
    "rederiverksamhetens": "rederiverksamhet",
    "rederiverksamheter": "rederiverksamhet",
    "rederiverksamheterna": "rederiverksamhet",
    "rederiverksamheternas": "rederiverksamhet",
    "rederiverksamheters": "rederiverksamhet",
    "rederiverksamhets": "rederiverksamhet",
    "redes": "rede",
    "redet": "rede",
    "redets": "rede",
    "rediga": "redig",
    "redigare": "redig",
    "redigares": "redig",
    "redigas": "redig",
    "redigast": "redig",
    "redigaste": "redig",
    "redigastes": "redig",
    "redigasts": "redig",
    "redige": "redig",
    "redigerad": "redigera",
    "redigerade": "redigera",
    "redigerades": "redigera",
    "redigerads": "redigera",
    "redigerande": "redigera",
    "redigeranden": "redigerande",
    "redigerandena": "redigerande",
    "redigerandenas": "redigerande",
    "redigerandens": "redigerande",
    "redigerandes": "redigerande",
    "redigerandet": "redigerande",
    "redigerandets": "redigerande",
    "redigerar": "redigera",
    "redigeras": "redigera",
    "redigerat": "redigera",
    "redigerats": "redigera",
    "redigerbara": "redigerbar",
    "redigerbarare": "redigerbar",
    "redigerbarares": "redigerbar",
    "redigerbaras": "redigerbar",
    "redigerbarast": "redigerbar",
    "redigerbaraste": "redigerbar",
    "redigerbarastes": "redigerbar",
    "redigerbarasts": "redigerbar",
    "redigerbare": "redigerbar",
    "redigerbares": "redigerbar",
    "redigerbarheten": "redigerbarhet",
    "redigerbarhetens": "redigerbarhet",
    "redigerbarhets": "redigerbarhet",
    "redigerbars": "redigerbar",
    "redigerbart": "redigerbar",
    "redigerbarts": "redigerbar",
    "redigeringar": "redigering",
    "redigeringarna": "redigering",
    "redigeringarnas": "redigering",
    "redigeringars": "redigering",
    "redigeringen": "redigering",
    "redigeringens": "redigering",
    "redigerings": "redigering",
    "rediges": "redig",
    "redigs": "redig",
    "redigt": "redig",
    "redigts": "redig",
    "redikylen": "redikyl",
    "redikylens": "redikyl",
    "redikyler": "redikyl",
    "redikylerna": "redikyl",
    "redikylernas": "redikyl",
    "redikylers": "redikyl",
    "redikyls": "redikyl",
    "redingoten": "redingot",
    "redingotens": "redingot",
    "redingoter": "redingot",
    "redingoterna": "redingot",
    "redingoternas": "redingot",
    "redingoters": "redingot",
    "redingots": "redingot",
    "redliga": "redlig",
    "redligare": "redlig",
    "redligares": "redlig",
    "redligas": "redlig",
    "redligast": "redlig",
    "redligaste": "redlig",
    "redligastes": "redlig",
    "redligasts": "redlig",
    "redlige": "redlig",
    "redliges": "redlig",
    "redligheten": "redlighet",
    "redlighetens": "redlighet",
    "redligheter": "redlighet",
    "redligheterna": "redlighet",
    "redligheternas": "redlighet",
    "redligheters": "redlighet",
    "redlighets": "redlighet",
    "redlighetskraven": "redlighetskrav",
    "redlighetskravens": "redlighetskrav",
    "redlighetskravet": "redlighetskrav",
    "redlighetskravets": "redlighetskrav",
    "redlighetskravs": "redlighetskrav",
    "redligs": "redlig",
    "redligt": "redlig",
    "redligts": "redlig",
    "redlösa": "redlös",
    "redlösare": "redlös",
    "redlösares": "redlös",
    "redlösas": "redlös",
    "redlösast": "redlös",
    "redlösaste": "redlös",
    "redlösastes": "redlös",
    "redlösasts": "redlös",
    "redlöse": "redlös",
    "redlöses": "redlös",
    "redlösheten": "redlöshet",
    "redlöshetens": "redlöshet",
    "redlöshets": "redlöshet",
    "redlöst": "redlös",
    "redlösts": "redlös",
    "redningar": "redning",
    "redningarna": "redning",
    "redningarnas": "redning",
    "redningars": "redning",
    "redningen": "redning",
    "redningens": "redning",
    "rednings": "redning",
    "redobogens": "redobogen",
    "redoboget": "redobogen",
    "redobogets": "redobogen",
    "redobogna": "redobogen",
    "redobognare": "redobogen",
    "redobognares": "redobogen",
    "redobognas": "redobogen",
    "redobognast": "redobogen",
    "redobognaste": "redobogen",
    "redobognastes": "redobogen",
    "redobognasts": "redobogen",
    "redobogne": "redobogen",
    "redobognes": "redobogen",
    "redogjord": "redogöra",
    "redogjorda": "redogöra",
    "redogjordas": "redogöra",
    "redogjorde": "redogöra",
    "redogjordes": "redogöra",
    "redogjords": "redogöra",
    "redogjort": "redogöra",
    "redogjorts": "redogöra",
    "redogör": "redogöra",
    "redogörande": "redogöra",
    "redogöranden": "redogörande",
    "redogörandena": "redogörande",
    "redogörandenas": "redogörande",
    "redogörandens": "redogörande",
    "redogörandes": "redogörande",
    "redogörandet": "redogörande",
    "redogörandets": "redogörande",
    "redogöras": "redogöra",
    "redogörelsen": "redogörelse",
    "redogörelsens": "redogörelse",
    "redogörelser": "redogörelse",
    "redogörelserna": "redogörelse",
    "redogörelsernas": "redogörelse",
    "redogörelsers": "redogörelse",
    "redogörelses": "redogörelse",
    "redogöres": "redogöra",
    "redogörs": "redogöra",
    "redovisad": "redovisa",
    "redovisade": "redovisa",
    "redovisades": "redovisa",
    "redovisads": "redovisa",
    "redovisande": "redovisa",
    "redovisanden": "redovisande",
    "redovisandena": "redovisande",
    "redovisandenas": "redovisande",
    "redovisandens": "redovisande",
    "redovisandes": "redovisande",
    "redovisandet": "redovisande",
    "redovisandets": "redovisande",
    "redovisar": "redovisa",
    "redovisas": "redovisa",
    "redovisat": "redovisa",
    "redovisats": "redovisa",
    "redovisningar": "redovisning",
    "redovisningarna": "redovisning",
    "redovisningarnas": "redovisning",
    "redovisningars": "redovisning",
    "redovisningen": "redovisning",
    "redovisningens": "redovisning",
    "redovisnings": "redovisning",
    "redovisningsmässiga": "redovisningsmässig",
    "redovisningsmässigare": "redovisningsmässig",
    "redovisningsmässigares": "redovisningsmässig",
    "redovisningsmässigas": "redovisningsmässig",
    "redovisningsmässigast": "redovisningsmässig",
    "redovisningsmässigaste": "redovisningsmässig",
    "redovisningsmässigastes": "redovisningsmässig",
    "redovisningsmässigasts": "redovisningsmässig",
    "redovisningsmässige": "redovisningsmässig",
    "redovisningsmässiges": "redovisningsmässig",
    "redovisningsmässigs": "redovisningsmässig",
    "redovisningsmässigt": "redovisningsmässig",
    "redovisningsmässigts": "redovisningsmässig",
    "redoxprocessen": "redoxprocess",
    "redoxprocessens": "redoxprocess",
    "redoxprocesser": "redoxprocess",
    "redoxprocesserna": "redoxprocess",
    "redoxprocessernas": "redoxprocess",
    "redoxprocessers": "redoxprocess",
    "reds": "rida",
    "redskapen": "redskap",
    "redskapens": "redskap",
    "redskapet": "redskap",
    "redskapets": "redskap",
    "redskaps": "redskap",
    "redskapsgymnastiken": "redskapsgymnastik",
    "redskapsgymnastikens": "redskapsgymnastik",
    "redskapsgymnastiks": "redskapsgymnastik",
    "redskapsmetallen": "redskapsmetall",
    "redskapsmetallens": "redskapsmetall",
    "redskapsmetaller": "redskapsmetall",
    "redskapsmetallerna": "redskapsmetall",
    "redskapsmetallernas": "redskapsmetall",
    "redskapsmetallers": "redskapsmetall",
    "redskapsmetalls": "redskapsmetall",
    "redubblad": "redubbla",
    "redubblade": "redubbla",
    "redubblades": "redubbla",
    "redubblads": "redubbla",
    "redubblande": "redubbla",
    "redubblanden": "redubblande",
    "redubblandena": "redubblande",
    "redubblandenas": "redubblande",
    "redubblandens": "redubblande",
    "redubblandes": "redubblande",
    "redubblandet": "redubblande",
    "redubblandets": "redubblande",
    "redubblar": "redubbla",
    "redubblas": "redubbla",
    "redubblat": "redubbla",
    "redubblats": "redubbla",
    "reducerad": "reducera",
    "reducerade": "reducera",
    "reducerades": "reducera",
    "reducerads": "reducera",
    "reducerande": "reducera",
    "reduceranden": "reducerande",
    "reducerandena": "reducerande",
    "reducerandenas": "reducerande",
    "reducerandens": "reducerande",
    "reducerandes": "reducerande",
    "reducerandet": "reducerande",
    "reducerandets": "reducerande",
    "reducerar": "reducera",
    "reduceras": "reducera",
    "reducerat": "reducera",
    "reducerats": "reducera",
    "reducerbara": "reducerbar",
    "reducerbarare": "reducerbar",
    "reducerbarares": "reducerbar",
    "reducerbaras": "reducerbar",
    "reducerbarast": "reducerbar",
    "reducerbaraste": "reducerbar",
    "reducerbarastes": "reducerbar",
    "reducerbarasts": "reducerbar",
    "reducerbare": "reducerbar",
    "reducerbares": "reducerbar",
    "reducerbarheten": "reducerbarhet",
    "reducerbarhetens": "reducerbarhet",
    "reducerbarhets": "reducerbarhet",
    "reducerbars": "reducerbar",
    "reducerbart": "reducerbar",
    "reducerbarts": "reducerbar",
    "reduceringar": "reducering",
    "reduceringarna": "reducering",
    "reduceringarnas": "reducering",
    "reduceringars": "reducering",
    "reduceringen": "reducering",
    "reduceringens": "reducering",
    "reducerings": "reducering",
    "reduceringsventilen": "reduceringsventil",
    "reduceringsventilens": "reduceringsventil",
    "reduceringsventiler": "reduceringsventil",
    "reduceringsventilerna": "reduceringsventil",
    "reduceringsventilernas": "reduceringsventil",
    "reduceringsventilers": "reduceringsventil",
    "reduceringsventils": "reduceringsventil",
    "reduktionen": "reduktion",
    "reduktionens": "reduktion",
    "reduktioner": "reduktion",
    "reduktionerna": "reduktion",
    "reduktionernas": "reduktion",
    "reduktioners": "reduktion",
    "reduktions": "reduktion",
    "reduktionsdelningar": "reduktionsdelning",
    "reduktionsdelningarna": "reduktionsdelning",
    "reduktionsdelningarnas": "reduktionsdelning",
    "reduktionsdelningars": "reduktionsdelning",
    "reduktionsdelningen": "reduktionsdelning",
    "reduktionsdelningens": "reduktionsdelning",
    "reduktionsdelnings": "reduktionsdelning",
    "redundansen": "redundans",
    "redundansens": "redundans",
    "redundanta": "redundant",
    "redundantare": "redundant",
    "redundantares": "redundant",
    "redundantas": "redundant",
    "redundantast": "redundant",
    "redundantaste": "redundant",
    "redundantastes": "redundant",
    "redundantasts": "redundant",
    "redundante": "redundant",
    "redundantes": "redundant",
    "redundants": "redundant",
    "reduplikationen": "reduplikation",
    "reduplikationens": "reduplikation",
    "reduplikationer": "reduplikation",
    "reduplikationerna": "reduplikation",
    "reduplikationernas": "reduplikation",
    "reduplikationers": "reduplikation",
    "reduplikations": "reduplikation",
    "redutten": "redutt",
    "reduttens": "redutt",
    "redutter": "redutt",
    "redutterna": "redutt",
    "redutternas": "redutt",
    "redutters": "redutt",
    "redutts": "redutt",
    "reella": "reell",
    "reellare": "reell",
    "reellares": "reell",
    "reellas": "reell",
    "reellast": "reell",
    "reellaste": "reell",
    "reellastes": "reell",
    "reellasts": "reell",
    "reelle": "reell",
    "reelles": "reell",
    "reells": "reell",
    "reellt": "reell",
    "reellts": "reell",
    "reexporten": "reexport",
    "reexportens": "reexport",
    "reexports": "reexport",
    "refektorie": "refektorium",
    "refektorier": "refektorium",
    "refektorierna": "refektorium",
    "refektoriernas": "refektorium",
    "refektoriers": "refektorium",
    "refektoriet": "refektorium",
    "refektoriets": "refektorium",
    "refektoriums": "refektorium",
    "referaten": "referat",
    "referatens": "referat",
    "referatet": "referat",
    "referatets": "referat",
    "referats": "referat",
    "referenda": "referendum",
    "referendana": "referendum",
    "referendanas": "referendum",
    "referendas": "referendum",
    "referendumen": "referendum",
    "referendumens": "referendum",
    "referendumet": "referendum",
    "referendumets": "referendum",
    "referendums": "referendum",
    "referensbiblioteken": "referensbibliotek",
    "referensbibliotekens": "referensbibliotek",
    "referensbiblioteket": "referensbibliotek",
    "referensbibliotekets": "referensbibliotek",
    "referensbiblioteks": "referensbibliotek",
    "referensen": "referens",
    "referensens": "referens",
    "referenser": "referens",
    "referenserna": "referens",
    "referensernas": "referens",
    "referensers": "referens",
    "referensgruppen": "referensgrupp",
    "referensgruppens": "referensgrupp",
    "referensgrupper": "referensgrupp",
    "referensgrupperna": "referensgrupp",
    "referensgruppernas": "referensgrupp",
    "referensgruppers": "referensgrupp",
    "referensgrupps": "referensgrupp",
    "referenslitteraturen": "referenslitteratur",
    "referenslitteraturens": "referenslitteratur",
    "referenslitteraturs": "referenslitteratur",
    "referensmaterialen": "referensmaterial",
    "referensmaterialens": "referensmaterial",
    "referensmaterialet": "referensmaterial",
    "referensmaterialets": "referensmaterial",
    "referensmaterials": "referensmaterial",
    "referenspunkten": "referenspunkt",
    "referenspunktens": "referenspunkt",
    "referenspunkter": "referenspunkt",
    "referenspunkterna": "referenspunkt",
    "referenspunkternas": "referenspunkt",
    "referenspunkters": "referenspunkt",
    "referenspunkts": "referenspunkt",
    "referensramar": "referensram",
    "referensramarna": "referensram",
    "referensramarnas": "referensram",
    "referensramars": "referensram",
    "referensramen": "referensram",
    "referensramens": "referensram",
    "referensrams": "referensram",
    "referenssorten": "referenssort",
    "referenssortens": "referenssort",
    "referenssorter": "referenssort",
    "referenssorterna": "referenssort",
    "referenssorternas": "referenssort",
    "referenssorters": "referenssort",
    "referenssorts": "referenssort",
    "referenssystemen": "referenssystem",
    "referenssystemens": "referenssystem",
    "referenssystemet": "referenssystem",
    "referenssystemets": "referenssystem",
    "referenssystems": "referenssystem",
    "referenten": "referent",
    "referentens": "referent",
    "referenter": "referent",
    "referenterna": "referent",
    "referenternas": "referent",
    "referenters": "referent",
    "referents": "referent",
    "refererad": "referera",
    "refererade": "referera",
    "refererades": "referera",
    "refererads": "referera",
    "refererande": "referera",
    "refereranden": "refererande",
    "refererandena": "refererande",
    "refererandenas": "refererande",
    "refererandens": "refererande",
    "refererandes": "refererande",
    "refererandet": "refererande",
    "refererandets": "refererande",
    "refererar": "referera",
    "refereras": "referera",
    "refererat": "referera",
    "refererats": "referera",
    "refererbara": "refererbar",
    "refererbarare": "refererbar",
    "refererbarares": "refererbar",
    "refererbaras": "refererbar",
    "refererbarast": "refererbar",
    "refererbaraste": "refererbar",
    "refererbarastes": "refererbar",
    "refererbarasts": "refererbar",
    "refererbare": "refererbar",
    "refererbares": "refererbar",
    "refererbarheten": "refererbarhet",
    "refererbarhetens": "refererbarhet",
    "refererbarhets": "refererbarhet",
    "refererbars": "refererbar",
    "refererbart": "refererbar",
    "refererbarts": "refererbar",
    "refereringar": "referering",
    "refereringarna": "referering",
    "refereringarnas": "referering",
    "refereringars": "referering",
    "refereringen": "referering",
    "refereringens": "referering",
    "refererings": "referering",
    "refillen": "refill",
    "refillens": "refill",
    "refiller": "refill",
    "refillerna": "refill",
    "refillernas": "refill",
    "refillers": "refill",
    "refills": "refill",
    "reflekterad": "reflektera",
    "reflekterade": "reflekterad",
    "reflekterades": "reflekterad",
    "reflekterads": "reflekterad",
    "reflekterande": "reflektera",
    "reflekteranden": "reflekterande",
    "reflekterandena": "reflekterande",
    "reflekterandenas": "reflekterande",
    "reflekterandens": "reflekterande",
    "reflekterandes": "reflekterande",
    "reflekterandet": "reflekterande",
    "reflekterandets": "reflekterande",
    "reflekterar": "reflektera",
    "reflekteras": "reflektera",
    "reflekterat": "reflekterad",
    "reflekterats": "reflekterad",
    "reflekterbara": "reflekterbar",
    "reflekterbarare": "reflekterbar",
    "reflekterbarares": "reflekterbar",
    "reflekterbaras": "reflekterbar",
    "reflekterbarast": "reflekterbar",
    "reflekterbaraste": "reflekterbar",
    "reflekterbarastes": "reflekterbar",
    "reflekterbarasts": "reflekterbar",
    "reflekterbare": "reflekterbar",
    "reflekterbares": "reflekterbar",
    "reflekterbarheten": "reflekterbarhet",
    "reflekterbarhetens": "reflekterbarhet",
    "reflekterbarhets": "reflekterbarhet",
    "reflekterbars": "reflekterbar",
    "reflekterbart": "reflekterbar",
    "reflekterbarts": "reflekterbar",
    "reflekteringar": "reflektering",
    "reflekteringarna": "reflektering",
    "reflekteringarnas": "reflektering",
    "reflekteringars": "reflektering",
    "reflekteringen": "reflektering",
    "reflekteringens": "reflektering",
    "reflekterings": "reflektering",
    "reflektionen": "reflektion",
    "reflektionens": "reflektion",
    "reflektioner": "reflektion",
    "reflektionerna": "reflektion",
    "reflektionernas": "reflektion",
    "reflektioners": "reflektion",
    "reflektions": "reflektion",
    "reflektometern": "reflektometer",
    "reflektometerns": "reflektometer",
    "reflektometers": "reflektometer",
    "reflektometrar": "reflektometer",
    "reflektometrarna": "reflektometer",
    "reflektometrarnas": "reflektometer",
    "reflektometrars": "reflektometer",
    "reflektorer": "reflektor",
    "reflektorerna": "reflektor",
    "reflektorernas": "reflektor",
    "reflektorers": "reflektor",
    "reflektorn": "reflektor",
    "reflektorns": "reflektor",
    "reflektors": "reflektor",
    "reflexen": "reflex",
    "reflexens": "reflex",
    "reflexer": "reflex",
    "reflexerna": "reflex",
    "reflexernas": "reflex",
    "reflexers": "reflex",
    "reflexionen": "reflexion",
    "reflexionens": "reflexion",
    "reflexioner": "reflexion",
    "reflexionerna": "reflexion",
    "reflexionernas": "reflexion",
    "reflexioners": "reflexion",
    "reflexions": "reflexion",
    "reflexiva": "reflexiv",
    "reflexivare": "reflexiv",
    "reflexivares": "reflexiv",
    "reflexivas": "reflexiv",
    "reflexivast": "reflexiv",
    "reflexivaste": "reflexiv",
    "reflexivastes": "reflexiv",
    "reflexivasts": "reflexiv",
    "reflexive": "reflexiv",
    "reflexives": "reflexiv",
    "reflexivs": "reflexiv",
    "reflexivt": "reflexiv",
    "reflexivts": "reflexiv",
    "reflexmässiga": "reflexmässig",
    "reflexmässigare": "reflexmässig",
    "reflexmässigares": "reflexmässig",
    "reflexmässigas": "reflexmässig",
    "reflexmässigast": "reflexmässig",
    "reflexmässigaste": "reflexmässig",
    "reflexmässigastes": "reflexmässig",
    "reflexmässigasts": "reflexmässig",
    "reflexmässige": "reflexmässig",
    "reflexmässiges": "reflexmässig",
    "reflexmässigheten": "reflexmässighet",
    "reflexmässighetens": "reflexmässighet",
    "reflexmässighets": "reflexmässighet",
    "reflexmässigs": "reflexmässig",
    "reflexmässigt": "reflexmässig",
    "reflexmässigts": "reflexmässig",
    "reformationen": "reformation",
    "reformationens": "reformation",
    "reformationer": "reformation",
    "reformationerna": "reformation",
    "reformationernas": "reformation",
    "reformationers": "reformation",
    "reformations": "reformation",
    "reformatorer": "reformator",
    "reformatorerna": "reformator",
    "reformatorernas": "reformator",
    "reformatorers": "reformator",
    "reformatorn": "reformator",
    "reformatorns": "reformator",
    "reformators": "reformator",
    "reformbenägens": "reformbenägen",
    "reformbenäget": "reformbenägen",
    "reformbenägets": "reformbenägen",
    "reformbenägna": "reformbenägen",
    "reformbenägnare": "reformbenägen",
    "reformbenägnares": "reformbenägen",
    "reformbenägnas": "reformbenägen",
    "reformbenägnast": "reformbenägen",
    "reformbenägnaste": "reformbenägen",
    "reformbenägnastes": "reformbenägen",
    "reformbenägnasts": "reformbenägen",
    "reformbenägne": "reformbenägen",
    "reformbenägnes": "reformbenägen",
    "reformen": "reform",
    "reformens": "reform",
    "reformer": "reform",
    "reformerad": "reformera",
    "reformerade": "reformera",
    "reformerades": "reformera",
    "reformerads": "reformera",
    "reformerande": "reformera",
    "reformeranden": "reformerande",
    "reformerandena": "reformerande",
    "reformerandenas": "reformerande",
    "reformerandens": "reformerande",
    "reformerandes": "reformerande",
    "reformerandet": "reformerande",
    "reformerandets": "reformerande",
    "reformerar": "reformera",
    "reformeras": "reformera",
    "reformerat": "reformera",
    "reformerats": "reformera",
    "reformerbara": "reformerbar",
    "reformerbarare": "reformerbar",
    "reformerbarares": "reformerbar",
    "reformerbaras": "reformerbar",
    "reformerbarast": "reformerbar",
    "reformerbaraste": "reformerbar",
    "reformerbarastes": "reformerbar",
    "reformerbarasts": "reformerbar",
    "reformerbare": "reformerbar",
    "reformerbares": "reformerbar",
    "reformerbarheten": "reformerbarhet",
    "reformerbarhetens": "reformerbarhet",
    "reformerbarhets": "reformerbarhet",
    "reformerbars": "reformerbar",
    "reformerbart": "reformerbar",
    "reformerbarts": "reformerbar",
    "reformeringar": "reformering",
    "reformeringarna": "reformering",
    "reformeringarnas": "reformering",
    "reformeringars": "reformering",
    "reformeringen": "reformering",
    "reformeringens": "reformering",
    "reformerings": "reformering",
    "reformerna": "reform",
    "reformernas": "reform",
    "reformers": "reform",
    "reformerta": "reformert",
    "reformertare": "reformert",
    "reformertares": "reformert",
    "reformertas": "reformert",
    "reformertast": "reformert",
    "reformertaste": "reformert",
    "reformertastes": "reformert",
    "reformertasts": "reformert",
    "reformerte": "reformert",
    "reformertes": "reformert",
    "reformerts": "reformert",
    "reforminriktade": "reforminriktad",
    "reforminriktades": "reforminriktad",
    "reforminriktads": "reforminriktad",
    "reforminriktat": "reforminriktad",
    "reforminriktats": "reforminriktad",
    "reformismen": "reformism",
    "reformismens": "reformism",
    "reformismer": "reformism",
    "reformismerna": "reformism",
    "reformismernas": "reformism",
    "reformismers": "reformism",
    "reformisms": "reformism",
    "reformisten": "reformist",
    "reformistens": "reformist",
    "reformister": "reformist",
    "reformisterna": "reformist",
    "reformisternas": "reformist",
    "reformisters": "reformist",
    "reformistiska": "reformistisk",
    "reformistiskas": "reformistisk",
    "reformistiske": "reformistisk",
    "reformistiskes": "reformistisk",
    "reformistisks": "reformistisk",
    "reformistiskt": "reformistisk",
    "reformistiskts": "reformistisk",
    "reformists": "reformist",
    "reformkraven": "reformkrav",
    "reformkravens": "reformkrav",
    "reformkravet": "reformkrav",
    "reformkravets": "reformkrav",
    "reformkravs": "reformkrav",
    "reformpolitiken": "reformpolitik",
    "reformpolitikens": "reformpolitik",
    "reformpolitiks": "reformpolitik",
    "reforms": "reform",
    "refraktionen": "refraktion",
    "refraktionens": "refraktion",
    "refraktioner": "refraktion",
    "refraktionerna": "refraktion",
    "refraktionernas": "refraktion",
    "refraktioners": "refraktion",
    "refraktions": "refraktion",
    "refraktorer": "refraktor",
    "refraktorerna": "refraktor",
    "refraktorernas": "refraktor",
    "refraktorers": "refraktor",
    "refraktorn": "refraktor",
    "refraktorns": "refraktor",
    "refraktors": "refraktor",
    "refrängen": "refräng",
    "refrängens": "refräng",
    "refränger": "refräng",
    "refrängerna": "refräng",
    "refrängernas": "refräng",
    "refrängers": "refräng",
    "refrängs": "refräng",
    "refrängsångar": "refrängsångare",
    "refrängsångaren": "refrängsångare",
    "refrängsångarens": "refrängsångare",
    "refrängsångares": "refrängsångare",
    "refrängsångarna": "refrängsångare",
    "refrängsångarnas": "refrängsångare",
    "refugen": "refug",
    "refugens": "refug",
    "refuger": "refug",
    "refugerna": "refug",
    "refugernas": "refug",
    "refugers": "refug",
    "refugs": "refug",
    "refuserad": "refusera",
    "refuserade": "refusera",
    "refuserades": "refusera",
    "refuserads": "refusera",
    "refuserande": "refusera",
    "refuseranden": "refuserande",
    "refuserandena": "refuserande",
    "refuserandenas": "refuserande",
    "refuserandens": "refuserande",
    "refuserandes": "refuserande",
    "refuserandet": "refuserande",
    "refuserandets": "refuserande",
    "refuserar": "refusera",
    "refuseras": "refusera",
    "refuserat": "refusera",
    "refuserats": "refusera",
    "refuserbara": "refuserbar",
    "refuserbarare": "refuserbar",
    "refuserbarares": "refuserbar",
    "refuserbaras": "refuserbar",
    "refuserbarast": "refuserbar",
    "refuserbaraste": "refuserbar",
    "refuserbarastes": "refuserbar",
    "refuserbarasts": "refuserbar",
    "refuserbare": "refuserbar",
    "refuserbares": "refuserbar",
    "refuserbarheten": "refuserbarhet",
    "refuserbarhetens": "refuserbarhet",
    "refuserbarhets": "refuserbarhet",
    "refuserbars": "refuserbar",
    "refuserbart": "refuserbar",
    "refuserbarts": "refuserbar",
    "refuseringar": "refusering",
    "refuseringarna": "refusering",
    "refuseringarnas": "refusering",
    "refuseringars": "refusering",
    "refuseringen": "refusering",
    "refuseringens": "refusering",
    "refuserings": "refusering",
    "regala": "regal",
    "regalare": "regal",
    "regalares": "regal",
    "regalas": "regal",
    "regalast": "regal",
    "regalaste": "regal",
    "regalastes": "regal",
    "regalasts": "regal",
    "regale": "regal",
    "regalen": "regale",
    "regalena": "regale",
    "regalenas": "regale",
    "regalens": "regale",
    "regaler": "regal",
    "regalerad": "regalera",
    "regalerade": "regalera",
    "regalerades": "regalera",
    "regalerads": "regalera",
    "regalerande": "regalera",
    "regaleranden": "regalerande",
    "regalerandena": "regalerande",
    "regalerandenas": "regalerande",
    "regalerandens": "regalerande",
    "regalerandes": "regalerande",
    "regalerandet": "regalerande",
    "regalerandets": "regalerande",
    "regalerar": "regalera",
    "regaleras": "regalera",
    "regalerat": "regalera",
    "regalerats": "regalera",
    "regalerbara": "regalerbar",
    "regalerbarare": "regalerbar",
    "regalerbarares": "regalerbar",
    "regalerbaras": "regalerbar",
    "regalerbarast": "regalerbar",
    "regalerbaraste": "regalerbar",
    "regalerbarastes": "regalerbar",
    "regalerbarasts": "regalerbar",
    "regalerbare": "regalerbar",
    "regalerbares": "regalerbar",
    "regalerbarheten": "regalerbarhet",
    "regalerbarhetens": "regalerbarhet",
    "regalerbarhets": "regalerbarhet",
    "regalerbars": "regalerbar",
    "regalerbart": "regalerbar",
    "regalerbarts": "regalerbar",
    "regaleringar": "regalering",
    "regaleringarna": "regalering",
    "regaleringarnas": "regalering",
    "regaleringars": "regalering",
    "regaleringen": "regalering",
    "regaleringens": "regalering",
    "regalerings": "regalering",
    "regalerna": "regal",
    "regalernas": "regal",
    "regalers": "regal",
    "regales": "regale",
    "regalet": "regale",
    "regalets": "regale",
    "regalie": "regalier",
    "regalierna": "regalier",
    "regaliernas": "regalier",
    "regaliers": "regalier",
    "regals": "regale",
    "regalskeppen": "regalskepp",
    "regalskeppens": "regalskepp",
    "regalskeppet": "regalskepp",
    "regalskeppets": "regalskepp",
    "regalskepps": "regalskepp",
    "regalt": "regal",
    "regalts": "regal",
    "regatt": "regatta",
    "regattan": "regatta",
    "regattans": "regatta",
    "regattas": "regatta",
    "regatte": "regatta",
    "regattor": "regatta",
    "regattorna": "regatta",
    "regattornas": "regatta",
    "regattors": "regatta",
    "regatts": "regatta",
    "regel": "regla",
    "regelbrotten": "regelbrott",
    "regelbrottens": "regelbrott",
    "regelbrottet": "regelbrott",
    "regelbrottets": "regelbrott",
    "regelbrotts": "regelbrott",
    "regelbundenheten": "regelbundenhet",
    "regelbundenhetens": "regelbundenhet",
    "regelbundenheter": "regelbundenhet",
    "regelbundenheterna": "regelbundenhet",
    "regelbundenheternas": "regelbundenhet",
    "regelbundenheters": "regelbundenhet",
    "regelbundenhets": "regelbundenhet",
    "regelbundens": "regelbunden",
    "regelbundet": "regelbunden",
    "regelbundets": "regelbunden",
    "regelbundna": "regelbunden",
    "regelbundnare": "regelbunden",
    "regelbundnares": "regelbunden",
    "regelbundnas": "regelbunden",
    "regelbundnast": "regelbunden",
    "regelbundnaste": "regelbunden",
    "regelbundnastes": "regelbunden",
    "regelbundnasts": "regelbunden",
    "regelbundne": "regelbunden",
    "regelbundnes": "regelbunden",
    "regelbåtar": "regelbåt",
    "regelbåtarna": "regelbåt",
    "regelbåtarnas": "regelbåt",
    "regelbåtars": "regelbåt",
    "regelbåten": "regelbåt",
    "regelbåtens": "regelbåt",
    "regelbåts": "regelbåt",
    "regelkrångels": "regelkrångel",
    "regelkrånglen": "regelkrångel",
    "regelkrånglens": "regelkrångel",
    "regelkrånglet": "regelkrångel",
    "regelkrånglets": "regelkrångel",
    "regellösa": "regellös",
    "regellösare": "regellös",
    "regellösares": "regellös",
    "regellösas": "regellös",
    "regellösast": "regellös",
    "regellösaste": "regellös",
    "regellösastes": "regellös",
    "regellösasts": "regellös",
    "regellöse": "regellös",
    "regellöses": "regellös",
    "regellösheten": "regellöshet",
    "regellöshetens": "regellöshet",
    "regellöshets": "regellöshet",
    "regellöst": "regellös",
    "regellösts": "regellös",
    "regelmässiga": "regelmässig",
    "regelmässigare": "regelmässig",
    "regelmässigares": "regelmässig",
    "regelmässigas": "regelmässig",
    "regelmässigast": "regelmässig",
    "regelmässigaste": "regelmässig",
    "regelmässigastes": "regelmässig",
    "regelmässigasts": "regelmässig",
    "regelmässige": "regelmässig",
    "regelmässiges": "regelmässig",
    "regelmässigheten": "regelmässighet",
    "regelmässighetens": "regelmässighet",
    "regelmässigheter": "regelmässighet",
    "regelmässigheterna": "regelmässighet",
    "regelmässigheternas": "regelmässighet",
    "regelmässigheters": "regelmässighet",
    "regelmässighets": "regelmässighet",
    "regelmässigs": "regelmässig",
    "regelmässigt": "regelmässig",
    "regelmässigts": "regelmässig",
    "regeln": "regel",
    "regelns": "regel",
    "regelrätta": "regelrätt",
    "regelrättare": "regelrätt",
    "regelrättares": "regelrätt",
    "regelrättas": "regelrätt",
    "regelrättast": "regelrätt",
    "regelrättaste": "regelrätt",
    "regelrättastes": "regelrätt",
    "regelrättasts": "regelrätt",
    "regelrätte": "regelrätt",
    "regelrättes": "regelrätt",
    "regelrättheten": "regelrätthet",
    "regelrätthetens": "regelrätthet",
    "regelrätthets": "regelrätthet",
    "regelrätts": "regelrätt",
    "regels": "regel",
    "regelsystemen": "regelsystem",
    "regelsystemens": "regelsystem",
    "regelsystemet": "regelsystem",
    "regelsystemets": "regelsystem",
    "regelsystems": "regelsystem",
    "regelverken": "regelverk",
    "regelverkens": "regelverk",
    "regelverket": "regelverk",
    "regelverkets": "regelverk",
    "regelverks": "regelverk",
    "regelvidriga": "regelvidrig",
    "regelvidrigare": "regelvidrig",
    "regelvidrigares": "regelvidrig",
    "regelvidrigas": "regelvidrig",
    "regelvidrigast": "regelvidrig",
    "regelvidrigaste": "regelvidrig",
    "regelvidrigastes": "regelvidrig",
    "regelvidrigasts": "regelvidrig",
    "regelvidrige": "regelvidrig",
    "regelvidriges": "regelvidrig",
    "regelvidrigheten": "regelvidrighet",
    "regelvidrighetens": "regelvidrighet",
    "regelvidrigheter": "regelvidrighet",
    "regelvidrigheterna": "regelvidrighet",
    "regelvidrigheternas": "regelvidrighet",
    "regelvidrigheters": "regelvidrighet",
    "regelvidrighets": "regelvidrighet",
    "regelvidrigs": "regelvidrig",
    "regelvidrigt": "regelvidrig",
    "regelvidrigts": "regelvidrig",
    "regementen": "regemente",
    "regementena": "regemente",
    "regementenas": "regemente",
    "regementens": "regemente",
    "regementes": "regemente",
    "regementet": "regemente",
    "regementets": "regemente",
    "regements": "regemente",
    "regementschefen": "regementschef",
    "regementschefens": "regementschef",
    "regementschefer": "regementschef",
    "regementscheferna": "regementschef",
    "regementschefernas": "regementschef",
    "regementschefers": "regementschef",
    "regementschefs": "regementschef",
    "regementsofficerare": "regementsofficer",
    "regementsofficerares": "regementsofficer",
    "regementsofficerarna": "regementsofficer",
    "regementsofficerarnas": "regementsofficer",
    "regementsofficeren": "regementsofficer",
    "regementsofficerens": "regementsofficer",
    "regementsofficern": "regementsofficer",
    "regementsofficerns": "regementsofficer",
    "regementsofficers": "regementsofficer",
    "regenerationen": "regeneration",
    "regenerationens": "regeneration",
    "regenerationer": "regeneration",
    "regenerationerna": "regeneration",
    "regenerationernas": "regeneration",
    "regenerationers": "regeneration",
    "regenerations": "regeneration",
    "regeneratorer": "regenerator",
    "regeneratorerna": "regenerator",
    "regeneratorernas": "regenerator",
    "regeneratorers": "regenerator",
    "regeneratorn": "regenerator",
    "regeneratorns": "regenerator",
    "regenerators": "regenerator",
    "regenererad": "regenerera",
    "regenererade": "regenerera",
    "regenererades": "regenerera",
    "regenererads": "regenerera",
    "regenererande": "regenerera",
    "regenereranden": "regenererande",
    "regenererandena": "regenererande",
    "regenererandenas": "regenererande",
    "regenererandens": "regenererande",
    "regenererandes": "regenererande",
    "regenererandet": "regenererande",
    "regenererandets": "regenererande",
    "regenererar": "regenerera",
    "regenereras": "regenerera",
    "regenererat": "regenerera",
    "regenererats": "regenerera",
    "regenererbara": "regenererbar",
    "regenererbarare": "regenererbar",
    "regenererbarares": "regenererbar",
    "regenererbaras": "regenererbar",
    "regenererbarast": "regenererbar",
    "regenererbaraste": "regenererbar",
    "regenererbarastes": "regenererbar",
    "regenererbarasts": "regenererbar",
    "regenererbare": "regenererbar",
    "regenererbares": "regenererbar",
    "regenererbarheten": "regenererbarhet",
    "regenererbarhetens": "regenererbarhet",
    "regenererbarhets": "regenererbarhet",
    "regenererbars": "regenererbar",
    "regenererbart": "regenererbar",
    "regenererbarts": "regenererbar",
    "regenereringar": "regenerering",
    "regenereringarna": "regenerering",
    "regenereringarnas": "regenerering",
    "regenereringars": "regenerering",
    "regenereringen": "regenerering",
    "regenereringens": "regenerering",
    "regenererings": "regenerering",
    "regenten": "regent",
    "regentens": "regent",
    "regenter": "regent",
    "regenterna": "regent",
    "regenternas": "regent",
    "regenters": "regent",
    "regentlängden": "regentlängd",
    "regentlängdens": "regentlängd",
    "regentlängder": "regentlängd",
    "regentlängderna": "regentlängd",
    "regentlängdernas": "regentlängd",
    "regentlängders": "regentlängd",
    "regentlängds": "regentlängd",
    "regents": "regent",
    "regerad": "regera",
    "regerade": "regera",
    "regerades": "regera",
    "regerads": "regera",
    "regerande": "regera",
    "regeranden": "regerande",
    "regerandena": "regerande",
    "regerandenas": "regerande",
    "regerandens": "regerande",
    "regerandes": "regerande",
    "regerandet": "regerande",
    "regerandets": "regerande",
    "regerar": "regera",
    "regeras": "regera",
    "regerat": "regera",
    "regerats": "regera",
    "regerbara": "regerbar",
    "regerbarare": "regerbar",
    "regerbarares": "regerbar",
    "regerbaras": "regerbar",
    "regerbarast": "regerbar",
    "regerbaraste": "regerbar",
    "regerbarastes": "regerbar",
    "regerbarasts": "regerbar",
    "regerbare": "regerbar",
    "regerbares": "regerbar",
    "regerbarheten": "regerbarhet",
    "regerbarhetens": "regerbarhet",
    "regerbarhets": "regerbarhet",
    "regerbars": "regerbar",
    "regerbart": "regerbar",
    "regerbarts": "regerbar",
    "regeringar": "regering",
    "regeringarna": "regering",
    "regeringarnas": "regering",
    "regeringars": "regering",
    "regeringen": "regering",
    "regeringens": "regering",
    "regerings": "regering",
    "regeringsanhängar": "regeringsanhängare",
    "regeringsanhängaren": "regeringsanhängare",
    "regeringsanhängarens": "regeringsanhängare",
    "regeringsanhängares": "regeringsanhängare",
    "regeringsanhängarna": "regeringsanhängare",
    "regeringsanhängarnas": "regeringsanhängare",
    "regeringsbesluten": "regeringsbeslut",
    "regeringsbeslutens": "regeringsbeslut",
    "regeringsbeslutet": "regeringsbeslut",
    "regeringsbeslutets": "regeringsbeslut",
    "regeringsbesluts": "regeringsbeslut",
    "regeringsbyggnaden": "regeringsbyggnad",
    "regeringsbyggnadens": "regeringsbyggnad",
    "regeringsbyggnader": "regeringsbyggnad",
    "regeringsbyggnaderna": "regeringsbyggnad",
    "regeringsbyggnadernas": "regeringsbyggnad",
    "regeringsbyggnaders": "regeringsbyggnad",
    "regeringsbyggnads": "regeringsbyggnad",
    "regeringsbänkar": "regeringsbänk",
    "regeringsbänkarna": "regeringsbänk",
    "regeringsbänkarnas": "regeringsbänk",
    "regeringsbänkars": "regeringsbänk",
    "regeringsbänken": "regeringsbänk",
    "regeringsbänkens": "regeringsbänk",
    "regeringsbänks": "regeringsbänk",
    "regeringschefen": "regeringschef",
    "regeringschefens": "regeringschef",
    "regeringschefer": "regeringschef",
    "regeringscheferna": "regeringschef",
    "regeringschefernas": "regeringschef",
    "regeringschefers": "regeringschef",
    "regeringschefs": "regeringschef",
    "regeringsdeklarationen": "regeringsdeklaration",
    "regeringsdeklarationens": "regeringsdeklaration",
    "regeringsdeklarationer": "regeringsdeklaration",
    "regeringsdeklarationerna": "regeringsdeklaration",
    "regeringsdeklarationernas": "regeringsdeklaration",
    "regeringsdeklarationers": "regeringsdeklaration",
    "regeringsdeklarations": "regeringsdeklaration",
    "regeringsdirektiven": "regeringsdirektiv",
    "regeringsdirektivens": "regeringsdirektiv",
    "regeringsdirektivet": "regeringsdirektiv",
    "regeringsdirektivets": "regeringsdirektiv",
    "regeringsdirektivs": "regeringsdirektiv",
    "regeringsdugliga": "regeringsduglig",
    "regeringsdugligare": "regeringsduglig",
    "regeringsdugligares": "regeringsduglig",
    "regeringsdugligas": "regeringsduglig",
    "regeringsdugligast": "regeringsduglig",
    "regeringsdugligaste": "regeringsduglig",
    "regeringsdugligastes": "regeringsduglig",
    "regeringsdugligasts": "regeringsduglig",
    "regeringsduglige": "regeringsduglig",
    "regeringsdugliges": "regeringsduglig",
    "regeringsdugligheten": "regeringsduglighet",
    "regeringsduglighetens": "regeringsduglighet",
    "regeringsduglighets": "regeringsduglighet",
    "regeringsdugligs": "regeringsduglig",
    "regeringsdugligt": "regeringsduglig",
    "regeringsdugligts": "regeringsduglig",
    "regeringsformen": "regeringsform",
    "regeringsformens": "regeringsform",
    "regeringsformer": "regeringsform",
    "regeringsformerna": "regeringsform",
    "regeringsformernas": "regeringsform",
    "regeringsformers": "regeringsform",
    "regeringsforms": "regeringsform",
    "regeringskanslier": "regeringskansli",
    "regeringskanslierna": "regeringskansli",
    "regeringskansliernas": "regeringskansli",
    "regeringskansliers": "regeringskansli",
    "regeringskansliet": "regeringskansli",
    "regeringskansliets": "regeringskansli",
    "regeringskanslis": "regeringskansli",
    "regeringskanslit": "regeringskansli",
    "regeringskanslits": "regeringskansli",
    "regeringskollegan": "regeringskollega",
    "regeringskollegans": "regeringskollega",
    "regeringskollegas": "regeringskollega",
    "regeringskolleger": "regeringskollega",
    "regeringskollegerna": "regeringskollega",
    "regeringskollegernas": "regeringskollega",
    "regeringskollegers": "regeringskollega",
    "regeringskollegor": "regeringskollega",
    "regeringskollegorna": "regeringskollega",
    "regeringskollegornas": "regeringskollega",
    "regeringskollegors": "regeringskollega",
    "regeringskretsar": "regeringskrets",
    "regeringskretsarna": "regeringskrets",
    "regeringskretsarnas": "regeringskrets",
    "regeringskretsars": "regeringskrets",
    "regeringskretsen": "regeringskrets",
    "regeringskretsens": "regeringskrets",
    "regeringskritiska": "regeringskritisk",
    "regeringskritiskare": "regeringskritisk",
    "regeringskritiskares": "regeringskritisk",
    "regeringskritiskas": "regeringskritisk",
    "regeringskritiskast": "regeringskritisk",
    "regeringskritiskaste": "regeringskritisk",
    "regeringskritiskastes": "regeringskritisk",
    "regeringskritiskasts": "regeringskritisk",
    "regeringskritiske": "regeringskritisk",
    "regeringskritiskes": "regeringskritisk",
    "regeringskritisks": "regeringskritisk",
    "regeringskritiskt": "regeringskritisk",
    "regeringskritiskts": "regeringskritisk",
    "regeringsmakten": "regeringsmakt",
    "regeringsmaktens": "regeringsmakt",
    "regeringsmakter": "regeringsmakt",
    "regeringsmakterna": "regeringsmakt",
    "regeringsmakternas": "regeringsmakt",
    "regeringsmakters": "regeringsmakt",
    "regeringsmakts": "regeringsmakt",
    "regeringsmedlemmar": "regeringsmedlem",
    "regeringsmedlemmarna": "regeringsmedlem",
    "regeringsmedlemmarnas": "regeringsmedlem",
    "regeringsmedlemmars": "regeringsmedlem",
    "regeringsmedlemmen": "regeringsmedlem",
    "regeringsmedlemmens": "regeringsmedlem",
    "regeringsmedlems": "regeringsmedlem",
    "regeringsorganen": "regeringsorgan",
    "regeringsorganens": "regeringsorgan",
    "regeringsorganet": "regeringsorgan",
    "regeringsorganets": "regeringsorgan",
    "regeringsorgans": "regeringsorgan",
    "regeringspartier": "regeringsparti",
    "regeringspartierna": "regeringsparti",
    "regeringspartiernas": "regeringsparti",
    "regeringspartiers": "regeringsparti",
    "regeringspartiet": "regeringsparti",
    "regeringspartiets": "regeringsparti",
    "regeringspartis": "regeringsparti",
    "regeringspartit": "regeringsparti",
    "regeringspartits": "regeringsparti",
    "regeringspropositionen": "regeringsproposition",
    "regeringspropositionens": "regeringsproposition",
    "regeringspropositioner": "regeringsproposition",
    "regeringspropositionerna": "regeringsproposition",
    "regeringspropositionernas": "regeringsproposition",
    "regeringspropositioners": "regeringsproposition",
    "regeringspropositions": "regeringsproposition",
    "regeringspussels": "regeringspussel",
    "regeringspusslen": "regeringspussel",
    "regeringspusslens": "regeringspussel",
    "regeringspusslet": "regeringspussel",
    "regeringspusslets": "regeringspussel",
    "regeringsrätten": "regeringsrätt",
    "regeringsrättens": "regeringsrätt",
    "regeringsrätter": "regeringsrätt",
    "regeringsrätterna": "regeringsrätt",
    "regeringsrätternas": "regeringsrätt",
    "regeringsrätters": "regeringsrätt",
    "regeringsrätts": "regeringsrätt",
    "regeringsråden": "regeringsråd",
    "regeringsrådens": "regeringsråd",
    "regeringsrådet": "regeringsråd",
    "regeringsrådets": "regeringsråd",
    "regeringsråds": "regeringsråd",
    "regeringssammanträden": "regeringssammanträde",
    "regeringssammanträdena": "regeringssammanträde",
    "regeringssammanträdenas": "regeringssammanträde",
    "regeringssammanträdens": "regeringssammanträde",
    "regeringssammanträdes": "regeringssammanträde",
    "regeringssammanträdet": "regeringssammanträde",
    "regeringssammanträdets": "regeringssammanträde",
    "regeringssidan": "regeringssida",
    "regeringssidans": "regeringssida",
    "regeringssidas": "regeringssida",
    "regeringsside": "regeringssida",
    "regeringssides": "regeringssida",
    "regeringssidor": "regeringssida",
    "regeringssidorna": "regeringssida",
    "regeringssidornas": "regeringssida",
    "regeringssidors": "regeringssida",
    "regeringsstyrde": "regeringsstyrd",
    "regeringsstyrdes": "regeringsstyrd",
    "regeringsstyrds": "regeringsstyrd",
    "regeringsstyrt": "regeringsstyrd",
    "regeringsstyrts": "regeringsstyrd",
    "regeringsställningen": "regeringsställning",
    "regeringsställningens": "regeringsställning",
    "regeringsställnings": "regeringsställning",
    "regeringstrogens": "regeringstrogen",
    "regeringstroget": "regeringstrogen",
    "regeringstrogets": "regeringstrogen",
    "regeringstrogna": "regeringstrogen",
    "regeringstrognas": "regeringstrogen",
    "regeringstrogne": "regeringstrogen",
    "regeringstrognes": "regeringstrogen",
    "regerliga": "regerlig",
    "regerligare": "regerlig",
    "regerligares": "regerlig",
    "regerligas": "regerlig",
    "regerligast": "regerlig",
    "regerligaste": "regerlig",
    "regerligastes": "regerlig",
    "regerligasts": "regerlig",
    "regerlige": "regerlig",
    "regerliges": "regerlig",
    "regerligheten": "regerlighet",
    "regerlighetens": "regerlighet",
    "regerlighets": "regerlighet",
    "regerligs": "regerlig",
    "regerligt": "regerlig",
    "regerligts": "regerlig",
    "reggaen": "reggae",
    "reggaens": "reggae",
    "reggaes": "reggae",
    "regien": "regi",
    "regiens": "regi",
    "regimen": "regim",
    "regimens": "regim",
    "regimer": "regim",
    "regimerna": "regim",
    "regimernas": "regim",
    "regimers": "regim",
    "regimkritikern": "regimkritiker",
    "regimkritikerna": "regimkritiker",
    "regimkritikernas": "regimkritiker",
    "regimkritikerns": "regimkritiker",
    "regimkritikers": "regimkritiker",
    "regims": "regim",
    "regimässiga": "regimässig",
    "regimässigare": "regimässig",
    "regimässigares": "regimässig",
    "regimässigas": "regimässig",
    "regimässigast": "regimässig",
    "regimässigaste": "regimässig",
    "regimässigastes": "regimässig",
    "regimässigasts": "regimässig",
    "regimässige": "regimässig",
    "regimässiges": "regimässig",
    "regimässigs": "regimässig",
    "regimässigt": "regimässig",
    "regimässigts": "regimässig",
    "regin": "regi",
    "regins": "regi",
    "regionala": "regional",
    "regionalare": "regional",
    "regionalares": "regional",
    "regionalas": "regional",
    "regionalast": "regional",
    "regionalaste": "regional",
    "regionalastes": "regional",
    "regionalasts": "regional",
    "regionale": "regional",
    "regionales": "regional",
    "regionalismen": "regionalism",
    "regionalismens": "regionalism",
    "regionalismer": "regionalism",
    "regionalismerna": "regionalism",
    "regionalismernas": "regionalism",
    "regionalismers": "regionalism",
    "regionalisms": "regionalism",
    "regionalistiska": "regionalistisk",
    "regionalistiskas": "regionalistisk",
    "regionalistiske": "regionalistisk",
    "regionalistiskes": "regionalistisk",
    "regionalistisks": "regionalistisk",
    "regionalistiskt": "regionalistisk",
    "regionalistiskts": "regionalistisk",
    "regionalpolitiken": "regionalpolitik",
    "regionalpolitikens": "regionalpolitik",
    "regionalpolitiks": "regionalpolitik",
    "regionalpolitiska": "regionalpolitisk",
    "regionalpolitiskas": "regionalpolitisk",
    "regionalpolitiske": "regionalpolitisk",
    "regionalpolitiskes": "regionalpolitisk",
    "regionalpolitisks": "regionalpolitisk",
    "regionalpolitiskt": "regionalpolitisk",
    "regionalpolitiskts": "regionalpolitisk",
    "regionals": "regional",
    "regionalt": "regional",
    "regionalts": "regional",
    "regionen": "region",
    "regionens": "region",
    "regioner": "region",
    "regionerna": "region",
    "regionernas": "region",
    "regioners": "region",
    "regionmusiken": "regionmusik",
    "regionmusikens": "regionmusik",
    "regionmusiks": "regionmusik",
    "regionplane": "regionplan",
    "regionplanen": "regionplan",
    "regionplanens": "regionplan",
    "regionplaner": "regionplan",
    "regionplanerna": "regionplan",
    "regionplanernas": "regionplan",
    "regionplaners": "regionplan",
    "regionplans": "regionplan",
    "regionpolitiken": "regionpolitik",
    "regionpolitikens": "regionpolitik",
    "regionpolitiks": "regionpolitik",
    "regionpolitiska": "regionpolitisk",
    "regionpolitiskas": "regionpolitisk",
    "regionpolitiske": "regionpolitisk",
    "regionpolitiskes": "regionpolitisk",
    "regionpolitisks": "regionpolitisk",
    "regionpolitiskt": "regionpolitisk",
    "regionpolitiskts": "regionpolitisk",
    "regions": "region",
    "regionsjukhusen": "regionsjukhus",
    "regionsjukhusens": "regionsjukhus",
    "regionsjukhuset": "regionsjukhus",
    "regionsjukhusets": "regionsjukhus",
    "regionspolitiken": "regionspolitik",
    "regionspolitikens": "regionspolitik",
    "regionspolitiks": "regionspolitik",
    "regionspolitiska": "regionspolitisk",
    "regionspolitiskas": "regionspolitisk",
    "regionspolitiske": "regionspolitisk",
    "regionspolitiskes": "regionspolitisk",
    "regionspolitisks": "regionspolitisk",
    "regionspolitiskt": "regionspolitisk",
    "regionspolitiskts": "regionspolitisk",
    "regionstyrelsen": "regionstyrelse",
    "regionstyrelsens": "regionstyrelse",
    "regionstyrelser": "regionstyrelse",
    "regionstyrelserna": "regionstyrelse",
    "regionstyrelsernas": "regionstyrelse",
    "regionstyrelsers": "regionstyrelse",
    "regionstyrelses": "regionstyrelse",
    "regis": "regi",
    "regisserad": "regissera",
    "regisserade": "regissera",
    "regisserades": "regissera",
    "regisserads": "regissera",
    "regisserande": "regissera",
    "regisseranden": "regisserande",
    "regisserandena": "regisserande",
    "regisserandenas": "regisserande",
    "regisserandens": "regisserande",
    "regisserandes": "regisserande",
    "regisserandet": "regisserande",
    "regisserandets": "regisserande",
    "regisserar": "regissera",
    "regisseras": "regissera",
    "regisserat": "regissera",
    "regisserats": "regissera",
    "regisserbara": "regisserbar",
    "regisserbarare": "regisserbar",
    "regisserbarares": "regisserbar",
    "regisserbaras": "regisserbar",
    "regisserbarast": "regisserbar",
    "regisserbaraste": "regisserbar",
    "regisserbarastes": "regisserbar",
    "regisserbarasts": "regisserbar",
    "regisserbare": "regisserbar",
    "regisserbares": "regisserbar",
    "regisserbarheten": "regisserbarhet",
    "regisserbarhetens": "regisserbarhet",
    "regisserbarhets": "regisserbarhet",
    "regisserbars": "regisserbar",
    "regisserbart": "regisserbar",
    "regisserbarts": "regisserbar",
    "regisseringar": "regissering",
    "regisseringarna": "regissering",
    "regisseringarnas": "regissering",
    "regisseringars": "regissering",
    "regisseringen": "regissering",
    "regisseringens": "regissering",
    "regisserings": "regissering",
    "regissören": "regissör",
    "regissörens": "regissör",
    "regissörer": "regissör",
    "regissörerna": "regissör",
    "regissörernas": "regissör",
    "regissörers": "regissör",
    "regissörs": "regissör",
    "registerknappar": "registerknapp",
    "registerknapparna": "registerknapp",
    "registerknapparnas": "registerknapp",
    "registerknappars": "registerknapp",
    "registerknappen": "registerknapp",
    "registerknappens": "registerknapp",
    "registerknapps": "registerknapp",
    "registerna": "register",
    "registernas": "register",
    "registers": "register",
    "registertonnen": "registerton",
    "registertonnens": "registerton",
    "registertonnet": "registerton",
    "registertonnets": "registerton",
    "registertons": "registerton",
    "registratorer": "registrator",
    "registratorerna": "registrator",
    "registratorernas": "registrator",
    "registratorers": "registrator",
    "registratorn": "registrator",
    "registratorns": "registrator",
    "registrators": "registrator",
    "registraturen": "registratur",
    "registraturens": "registratur",
    "registraturer": "registratur",
    "registraturerna": "registratur",
    "registraturernas": "registratur",
    "registraturers": "registratur",
    "registraturet": "registratur",
    "registraturets": "registratur",
    "registraturs": "registratur",
    "registren": "register",
    "registrens": "register",
    "registrerad": "registrera",
    "registrerade": "registrera",
    "registrerades": "registrera",
    "registrerads": "registrera",
    "registrerande": "registrera",
    "registreranden": "registrerande",
    "registrerandena": "registrerande",
    "registrerandenas": "registrerande",
    "registrerandens": "registrerande",
    "registrerandes": "registrerande",
    "registrerandet": "registrerande",
    "registrerandets": "registrerande",
    "registrerar": "registrera",
    "registreras": "registrera",
    "registrerat": "registrera",
    "registrerats": "registrera",
    "registrerbara": "registrerbar",
    "registrerbarare": "registrerbar",
    "registrerbarares": "registrerbar",
    "registrerbaras": "registrerbar",
    "registrerbarast": "registrerbar",
    "registrerbaraste": "registrerbar",
    "registrerbarastes": "registrerbar",
    "registrerbarasts": "registrerbar",
    "registrerbare": "registrerbar",
    "registrerbares": "registrerbar",
    "registrerbarheten": "registrerbarhet",
    "registrerbarhetens": "registrerbarhet",
    "registrerbarhets": "registrerbarhet",
    "registrerbars": "registrerbar",
    "registrerbart": "registrerbar",
    "registrerbarts": "registrerbar",
    "registreringar": "registrering",
    "registreringarna": "registrering",
    "registreringarnas": "registrering",
    "registreringars": "registrering",
    "registreringen": "registrering",
    "registreringens": "registrering",
    "registrerings": "registrering",
    "registreringsnummerna": "registreringsnummer",
    "registreringsnummernas": "registreringsnummer",
    "registreringsnummers": "registreringsnummer",
    "registreringsnumren": "registreringsnummer",
    "registreringsnumrens": "registreringsnummer",
    "registreringsnumret": "registreringsnummer",
    "registreringsnumrets": "registreringsnummer",
    "registreringsskyltar": "registreringsskylt",
    "registreringsskyltarna": "registreringsskylt",
    "registreringsskyltarnas": "registreringsskylt",
    "registreringsskyltars": "registreringsskylt",
    "registreringsskylten": "registreringsskylt",
    "registreringsskyltens": "registreringsskylt",
    "registreringsskylts": "registreringsskylt",
    "registret": "register",
    "registrets": "register",
    "reglad": "regla",
    "reglade": "regla",
    "reglades": "regla",
    "reglads": "regla",
    "reglagen": "reglage",
    "reglagens": "reglage",
    "reglages": "reglage",
    "reglaget": "reglage",
    "reglagets": "reglage",
    "reglande": "regla",
    "reglanden": "reglande",
    "reglandena": "reglande",
    "reglandenas": "reglande",
    "reglandens": "reglande",
    "reglandes": "reglande",
    "reglandet": "reglande",
    "reglandets": "reglande",
    "reglar": "regla",
    "reglarna": "regel",
    "reglarnas": "regel",
    "reglars": "regel",
    "reglas": "regla",
    "reglat": "regla",
    "reglats": "regla",
    "reglementariska": "reglementarisk",
    "reglementariskare": "reglementarisk",
    "reglementariskares": "reglementarisk",
    "reglementariskas": "reglementarisk",
    "reglementariskast": "reglementarisk",
    "reglementariskaste": "reglementarisk",
    "reglementariskastes": "reglementarisk",
    "reglementariskasts": "reglementarisk",
    "reglementariske": "reglementarisk",
    "reglementariskes": "reglementarisk",
    "reglementarisks": "reglementarisk",
    "reglementariskt": "reglementarisk",
    "reglementariskts": "reglementarisk",
    "reglementen": "reglemente",
    "reglementena": "reglemente",
    "reglementenas": "reglemente",
    "reglementens": "reglemente",
    "reglementerad": "reglementera",
    "reglementerade": "reglementera",
    "reglementerades": "reglementera",
    "reglementerads": "reglementera",
    "reglementerande": "reglementera",
    "reglementeranden": "reglementerande",
    "reglementerandena": "reglementerande",
    "reglementerandenas": "reglementerande",
    "reglementerandens": "reglementerande",
    "reglementerandes": "reglementerande",
    "reglementerandet": "reglementerande",
    "reglementerandets": "reglementerande",
    "reglementerar": "reglementera",
    "reglementeras": "reglementera",
    "reglementerat": "reglementera",
    "reglementerats": "reglementera",
    "reglementerbara": "reglementerbar",
    "reglementerbarare": "reglementerbar",
    "reglementerbarares": "reglementerbar",
    "reglementerbaras": "reglementerbar",
    "reglementerbarast": "reglementerbar",
    "reglementerbaraste": "reglementerbar",
    "reglementerbarastes": "reglementerbar",
    "reglementerbarasts": "reglementerbar",
    "reglementerbare": "reglementerbar",
    "reglementerbares": "reglementerbar",
    "reglementerbarheten": "reglementerbarhet",
    "reglementerbarhetens": "reglementerbarhet",
    "reglementerbarhets": "reglementerbarhet",
    "reglementerbars": "reglementerbar",
    "reglementerbart": "reglementerbar",
    "reglementerbarts": "reglementerbar",
    "reglementeringar": "reglementering",
    "reglementeringarna": "reglementering",
    "reglementeringarnas": "reglementering",
    "reglementeringars": "reglementering",
    "reglementeringen": "reglementering",
    "reglementeringens": "reglementering",
    "reglementerings": "reglementering",
    "reglementes": "reglemente",
    "reglementet": "reglemente",
    "reglementets": "reglemente",
    "reglements": "reglemente",
    "reglementsenliga": "reglementsenlig",
    "reglementsenligare": "reglementsenlig",
    "reglementsenligares": "reglementsenlig",
    "reglementsenligas": "reglementsenlig",
    "reglementsenligast": "reglementsenlig",
    "reglementsenligaste": "reglementsenlig",
    "reglementsenligastes": "reglementsenlig",
    "reglementsenligasts": "reglementsenlig",
    "reglementsenlige": "reglementsenlig",
    "reglementsenliges": "reglementsenlig",
    "reglementsenligheten": "reglementsenlighet",
    "reglementsenlighetens": "reglementsenlighet",
    "reglementsenlighets": "reglementsenlighet",
    "reglementsenligs": "reglementsenlig",
    "reglementsenligt": "reglementsenlig",
    "reglementsenligts": "reglementsenlig",
    "reglementsvidriga": "reglementsvidrig",
    "reglementsvidrigare": "reglementsvidrig",
    "reglementsvidrigares": "reglementsvidrig",
    "reglementsvidrigas": "reglementsvidrig",
    "reglementsvidrigast": "reglementsvidrig",
    "reglementsvidrigaste": "reglementsvidrig",
    "reglementsvidrigastes": "reglementsvidrig",
    "reglementsvidrigasts": "reglementsvidrig",
    "reglementsvidrige": "reglementsvidrig",
    "reglementsvidriges": "reglementsvidrig",
    "reglementsvidrigheten": "reglementsvidrighet",
    "reglementsvidrighetens": "reglementsvidrighet",
    "reglementsvidrighets": "reglementsvidrighet",
    "reglementsvidrigs": "reglementsvidrig",
    "reglementsvidrigt": "reglementsvidrig",
    "reglementsvidrigts": "reglementsvidrig",
    "regler": "reglera",
    "reglerad": "reglera",
    "reglerade": "reglera",
    "reglerades": "reglera",
    "reglerads": "reglera",
    "reglerande": "reglera",
    "regleranden": "reglerande",
    "reglerandena": "reglerande",
    "reglerandenas": "reglerande",
    "reglerandens": "reglerande",
    "reglerandes": "reglerande",
    "reglerandet": "reglerande",
    "reglerandets": "reglerande",
    "reglerar": "reglera",
    "regleras": "reglera",
    "reglerat": "reglera",
    "reglerats": "reglera",
    "reglerbara": "reglerbar",
    "reglerbarare": "reglerbar",
    "reglerbarares": "reglerbar",
    "reglerbaras": "reglerbar",
    "reglerbarast": "reglerbar",
    "reglerbaraste": "reglerbar",
    "reglerbarastes": "reglerbar",
    "reglerbarasts": "reglerbar",
    "reglerbare": "reglerbar",
    "reglerbares": "reglerbar",
    "reglerbarheten": "reglerbarhet",
    "reglerbarhetens": "reglerbarhet",
    "reglerbarhets": "reglerbarhet",
    "reglerbars": "reglerbar",
    "reglerbart": "reglerbar",
    "reglerbarts": "reglerbar",
    "regleringar": "reglering",
    "regleringarna": "reglering",
    "regleringarnas": "reglering",
    "regleringars": "reglering",
    "regleringen": "reglering",
    "regleringens": "reglering",
    "reglerings": "reglering",
    "reglerna": "regel",
    "reglernas": "regel",
    "reglers": "regel",
    "reglertekniken": "reglerteknik",
    "reglerteknikens": "reglerteknik",
    "reglertekniks": "reglerteknik",
    "regn": "regna",
    "regnade": "regna",
    "regnades": "regna",
    "regnande": "regna",
    "regnanden": "regnande",
    "regnandena": "regnande",
    "regnandenas": "regnande",
    "regnandens": "regnande",
    "regnandes": "regnande",
    "regnandet": "regnande",
    "regnandets": "regnande",
    "regnar": "regna",
    "regnas": "regna",
    "regnat": "regna",
    "regnats": "regna",
    "regnbåg": "regnbåge",
    "regnbågar": "regnbåge",
    "regnbågarna": "regnbåge",
    "regnbågarnas": "regnbåge",
    "regnbågars": "regnbåge",
    "regnbågen": "regnbåge",
    "regnbågens": "regnbåge",
    "regnbåges": "regnbåge",
    "regnbågs": "regnbåge",
    "regnbågshinnan": "regnbågshinna",
    "regnbågshinnans": "regnbågshinna",
    "regnbågshinnas": "regnbågshinna",
    "regnbågshinne": "regnbågshinna",
    "regnbågshinnor": "regnbågshinna",
    "regnbågshinnorna": "regnbågshinna",
    "regnbågshinnornas": "regnbågshinna",
    "regnbågshinnors": "regnbågshinna",
    "regndropp": "regndroppe",
    "regndroppar": "regndroppe",
    "regndropparna": "regndroppe",
    "regndropparnas": "regndroppe",
    "regndroppars": "regndroppe",
    "regndroppen": "regndroppe",
    "regndroppens": "regndroppe",
    "regndroppes": "regndroppe",
    "regndropps": "regndroppe",
    "regnen": "regn",
    "regnens": "regn",
    "regnet": "regn",
    "regnets": "regn",
    "regngråa": "regngrå",
    "regngråare": "regngrå",
    "regngråares": "regngrå",
    "regngråas": "regngrå",
    "regngråast": "regngrå",
    "regngråaste": "regngrå",
    "regngråastes": "regngrå",
    "regngråasts": "regngrå",
    "regngråe": "regngrå",
    "regngråes": "regngrå",
    "regngrås": "regngrå",
    "regngrått": "regngrå",
    "regngråtts": "regngrå",
    "regniga": "regnig",
    "regnigare": "regnig",
    "regnigares": "regnig",
    "regnigas": "regnig",
    "regnigast": "regnig",
    "regnigaste": "regnig",
    "regnigastes": "regnig",
    "regnigasts": "regnig",
    "regnige": "regnig",
    "regniges": "regnig",
    "regnigheten": "regnighet",
    "regnighetens": "regnighet",
    "regnighets": "regnighet",
    "regnigs": "regnig",
    "regnigt": "regnig",
    "regnigts": "regnig",
    "regnkapp": "regnkappa",
    "regnkappan": "regnkappa",
    "regnkappans": "regnkappa",
    "regnkappas": "regnkappa",
    "regnkappe": "regnkappa",
    "regnkappor": "regnkappa",
    "regnkapporna": "regnkappa",
    "regnkappornas": "regnkappa",
    "regnkappors": "regnkappa",
    "regnkapps": "regnkappa",
    "regnkläderna": "regnkläder",
    "regnklädernas": "regnkläder",
    "regnkläders": "regnkläder",
    "regnklädes": "regnkläder",
    "regnkläds": "regnkläder",
    "regnmolnen": "regnmoln",
    "regnmolnens": "regnmoln",
    "regnmolnet": "regnmoln",
    "regnmolnets": "regnmoln",
    "regnmolns": "regnmoln",
    "regnmängden": "regnmängd",
    "regnmängdens": "regnmängd",
    "regnmängder": "regnmängd",
    "regnmängderna": "regnmängd",
    "regnmängdernas": "regnmängd",
    "regnmängders": "regnmängd",
    "regnmängds": "regnmängd",
    "regnmätar": "regnmätare",
    "regnmätaren": "regnmätare",
    "regnmätarens": "regnmätare",
    "regnmätares": "regnmätare",
    "regnmätarna": "regnmätare",
    "regnmätarnas": "regnmätare",
    "regnområden": "regnområde",
    "regnområdena": "regnområde",
    "regnområdenas": "regnområde",
    "regnområdens": "regnområde",
    "regnområdes": "regnområde",
    "regnområdet": "regnområde",
    "regnområdets": "regnområde",
    "regnoverallen": "regnoverall",
    "regnoverallens": "regnoverall",
    "regnoveraller": "regnoverall",
    "regnoverallerna": "regnoverall",
    "regnoverallernas": "regnoverall",
    "regnoverallers": "regnoverall",
    "regnoveralls": "regnoverall",
    "regnperioden": "regnperiod",
    "regnperiodens": "regnperiod",
    "regnperioder": "regnperiod",
    "regnperioderna": "regnperiod",
    "regnperiodernas": "regnperiod",
    "regnperioders": "regnperiod",
    "regnperiods": "regnperiod",
    "regnrockar": "regnrock",
    "regnrockarna": "regnrock",
    "regnrockarnas": "regnrock",
    "regnrockars": "regnrock",
    "regnrocken": "regnrock",
    "regnrockens": "regnrock",
    "regnrocks": "regnrock",
    "regns": "regn",
    "regnskogar": "regnskog",
    "regnskogarna": "regnskog",
    "regnskogarnas": "regnskog",
    "regnskogars": "regnskog",
    "regnskogen": "regnskog",
    "regnskogens": "regnskog",
    "regnskogs": "regnskog",
    "regnskuggan": "regnskugga",
    "regnskuggans": "regnskugga",
    "regnskuggas": "regnskugga",
    "regnskurar": "regnskur",
    "regnskurarna": "regnskur",
    "regnskurarnas": "regnskur",
    "regnskurars": "regnskur",
    "regnskuren": "regnskur",
    "regnskurens": "regnskur",
    "regnskurs": "regnskur",
    "regnskydden": "regnskydd",
    "regnskyddens": "regnskydd",
    "regnskyddet": "regnskydd",
    "regnskyddets": "regnskydd",
    "regnskydds": "regnskydd",
    "regnställen": "regnställ",
    "regnställens": "regnställ",
    "regnstället": "regnställ",
    "regnställets": "regnställ",
    "regnställs": "regnställ",
    "regnstänken": "regnstänk",
    "regnstänkens": "regnstänk",
    "regnstänket": "regnstänk",
    "regnstänkets": "regnstänk",
    "regnstänks": "regnstänk",
    "regntiden": "regntid",
    "regntidens": "regntid",
    "regntider": "regntid",
    "regntiderna": "regntid",
    "regntidernas": "regntid",
    "regntiders": "regntid",
    "regntids": "regntid",
    "regntunga": "regntung",
    "regntungare": "regntung",
    "regntungares": "regntung",
    "regntungas": "regntung",
    "regntungast": "regntung",
    "regntungaste": "regntung",
    "regntungastes": "regntung",
    "regntungasts": "regntung",
    "regntunge": "regntung",
    "regntunges": "regntung",
    "regntungheten": "regntunghet",
    "regntunghetens": "regntunghet",
    "regntunghets": "regntunghet",
    "regntungs": "regntung",
    "regntungt": "regntung",
    "regntungts": "regntung",
    "regntäta": "regntät",
    "regntätare": "regntät",
    "regntätares": "regntät",
    "regntätas": "regntät",
    "regntätast": "regntät",
    "regntätaste": "regntät",
    "regntätastes": "regntät",
    "regntätasts": "regntät",
    "regntäte": "regntät",
    "regntätes": "regntät",
    "regntätheten": "regntäthet",
    "regntäthetens": "regntäthet",
    "regntäthets": "regntäthet",
    "regntäts": "regntät",
    "regntätt": "regntät",
    "regntätts": "regntät",
    "regnvattens": "regnvatten",
    "regnvattnen": "regnvatten",
    "regnvattnens": "regnvatten",
    "regnvattnet": "regnvatten",
    "regnvattnets": "regnvatten",
    "regnvåta": "regnvåt",
    "regnvåtare": "regnvåt",
    "regnvåtares": "regnvåt",
    "regnvåtas": "regnvåt",
    "regnvåtast": "regnvåt",
    "regnvåtaste": "regnvåt",
    "regnvåtastes": "regnvåt",
    "regnvåtasts": "regnvåt",
    "regnvåte": "regnvåt",
    "regnvåtes": "regnvåt",
    "regnvåts": "regnvåt",
    "regnvått": "regnvåt",
    "regnvåtts": "regnvåt",
    "regoliten": "regolit",
    "regolitens": "regolit",
    "regoliter": "regolit",
    "regoliterna": "regolit",
    "regoliternas": "regolit",
    "regoliters": "regolit",
    "regolits": "regolit",
    "regressen": "regress",
    "regressens": "regress",
    "regresser": "regress",
    "regresserna": "regress",
    "regressernas": "regress",
    "regressers": "regress",
    "regressionen": "regression",
    "regressionens": "regression",
    "regressioner": "regression",
    "regressionerna": "regression",
    "regressionernas": "regression",
    "regressioners": "regression",
    "regressions": "regression",
    "regressiva": "regressiv",
    "regressivare": "regressiv",
    "regressivares": "regressiv",
    "regressivas": "regressiv",
    "regressivast": "regressiv",
    "regressivaste": "regressiv",
    "regressivastes": "regressiv",
    "regressivasts": "regressiv",
    "regressive": "regressiv",
    "regressives": "regressiv",
    "regressivs": "regressiv",
    "regressivt": "regressiv",
    "regressivts": "regressiv",
    "reguladetrien": "reguladetri",
    "reguladetriens": "reguladetri",
    "reguladetrin": "reguladetri",
    "reguladetrins": "reguladetri",
    "reguladetris": "reguladetri",
    "regularen": "regular",
    "regularens": "regular",
    "regulariteten": "regularitet",
    "regularitetens": "regularitet",
    "regulariteter": "regularitet",
    "regulariteterna": "regularitet",
    "regulariteternas": "regularitet",
    "regulariteters": "regularitet",
    "regularitets": "regularitet",
    "regulars": "regular",
    "regulatorer": "regulator",
    "regulatorerna": "regulator",
    "regulatorernas": "regulator",
    "regulatorers": "regulator",
    "regulatorn": "regulator",
    "regulatorns": "regulator",
    "regulators": "regulator",
    "reguljära": "reguljär",
    "reguljärare": "reguljär",
    "reguljärares": "reguljär",
    "reguljäras": "reguljär",
    "reguljärast": "reguljär",
    "reguljäraste": "reguljär",
    "reguljärastes": "reguljär",
    "reguljärasts": "reguljär",
    "reguljäre": "reguljär",
    "reguljäres": "reguljär",
    "reguljärs": "reguljär",
    "reguljärt": "reguljär",
    "reguljärts": "reguljär",
    "regummerad": "regummera",
    "regummerade": "regummera",
    "regummerades": "regummera",
    "regummerads": "regummera",
    "regummerande": "regummera",
    "regummeranden": "regummerande",
    "regummerandena": "regummerande",
    "regummerandenas": "regummerande",
    "regummerandens": "regummerande",
    "regummerandes": "regummerande",
    "regummerandet": "regummerande",
    "regummerandets": "regummerande",
    "regummerar": "regummera",
    "regummeras": "regummera",
    "regummerat": "regummera",
    "regummerats": "regummera",
    "regummerbara": "regummerbar",
    "regummerbarare": "regummerbar",
    "regummerbarares": "regummerbar",
    "regummerbaras": "regummerbar",
    "regummerbarast": "regummerbar",
    "regummerbaraste": "regummerbar",
    "regummerbarastes": "regummerbar",
    "regummerbarasts": "regummerbar",
    "regummerbare": "regummerbar",
    "regummerbares": "regummerbar",
    "regummerbarheten": "regummerbarhet",
    "regummerbarhetens": "regummerbarhet",
    "regummerbarhets": "regummerbarhet",
    "regummerbars": "regummerbar",
    "regummerbart": "regummerbar",
    "regummerbarts": "regummerbar",
    "regummeringar": "regummering",
    "regummeringarna": "regummering",
    "regummeringarnas": "regummering",
    "regummeringars": "regummering",
    "regummeringen": "regummering",
    "regummeringens": "regummering",
    "regummerings": "regummering",
    "rehabiliterad": "rehabilitera",
    "rehabiliterade": "rehabilitera",
    "rehabiliterades": "rehabilitera",
    "rehabiliterads": "rehabilitera",
    "rehabiliterande": "rehabilitera",
    "rehabiliteranden": "rehabiliterande",
    "rehabiliterandena": "rehabiliterande",
    "rehabiliterandenas": "rehabiliterande",
    "rehabiliterandens": "rehabiliterande",
    "rehabiliterandes": "rehabiliterande",
    "rehabiliterandet": "rehabiliterande",
    "rehabiliterandets": "rehabiliterande",
    "rehabiliterar": "rehabilitera",
    "rehabiliteras": "rehabilitera",
    "rehabiliterat": "rehabilitera",
    "rehabiliterats": "rehabilitera",
    "rehabiliterbara": "rehabiliterbar",
    "rehabiliterbarare": "rehabiliterbar",
    "rehabiliterbarares": "rehabiliterbar",
    "rehabiliterbaras": "rehabiliterbar",
    "rehabiliterbarast": "rehabiliterbar",
    "rehabiliterbaraste": "rehabiliterbar",
    "rehabiliterbarastes": "rehabiliterbar",
    "rehabiliterbarasts": "rehabiliterbar",
    "rehabiliterbare": "rehabiliterbar",
    "rehabiliterbares": "rehabiliterbar",
    "rehabiliterbarheten": "rehabiliterbarhet",
    "rehabiliterbarhetens": "rehabiliterbarhet",
    "rehabiliterbarhets": "rehabiliterbarhet",
    "rehabiliterbars": "rehabiliterbar",
    "rehabiliterbart": "rehabiliterbar",
    "rehabiliterbarts": "rehabiliterbar",
    "rehabiliteringar": "rehabilitering",
    "rehabiliteringarna": "rehabilitering",
    "rehabiliteringarnas": "rehabilitering",
    "rehabiliteringars": "rehabilitering",
    "rehabiliteringen": "rehabilitering",
    "rehabiliteringens": "rehabilitering",
    "rehabiliterings": "rehabilitering",
    "rehabiliteringshemen": "rehabiliteringshem",
    "rehabiliteringshemens": "rehabiliteringshem",
    "rehabiliteringshemet": "rehabiliteringshem",
    "rehabiliteringshemets": "rehabiliteringshem",
    "rehabiliteringshems": "rehabiliteringshem",
    "rehabiliteringsplanen": "rehabiliteringsplan",
    "rehabiliteringsplanens": "rehabiliteringsplan",
    "rehabiliteringsplaner": "rehabiliteringsplan",
    "rehabiliteringsplanerna": "rehabiliteringsplan",
    "rehabiliteringsplanernas": "rehabiliteringsplan",
    "rehabiliteringsplaners": "rehabiliteringsplan",
    "rehabiliteringsplans": "rehabiliteringsplan",
    "reifikationen": "reifikation",
    "reifikationens": "reifikation",
    "reifikationer": "reifikation",
    "reifikationerna": "reifikation",
    "reifikationernas": "reifikation",
    "reifikationers": "reifikation",
    "reifikations": "reifikation",
    "reinkarnationen": "reinkarnation",
    "reinkarnationens": "reinkarnation",
    "reinkarnationer": "reinkarnation",
    "reinkarnationerna": "reinkarnation",
    "reinkarnationernas": "reinkarnation",
    "reinkarnationers": "reinkarnation",
    "reinkarnations": "reinkarnation",
    "reinkarnerad": "reinkarnera",
    "reinkarnerade": "reinkarnera",
    "reinkarnerades": "reinkarnera",
    "reinkarnerads": "reinkarnera",
    "reinkarnerande": "reinkarnera",
    "reinkarneranden": "reinkarnerande",
    "reinkarnerandena": "reinkarnerande",
    "reinkarnerandenas": "reinkarnerande",
    "reinkarnerandens": "reinkarnerande",
    "reinkarnerandes": "reinkarnerande",
    "reinkarnerandet": "reinkarnerande",
    "reinkarnerandets": "reinkarnerande",
    "reinkarnerar": "reinkarnera",
    "reinkarneras": "reinkarnera",
    "reinkarnerat": "reinkarnera",
    "reinkarnerats": "reinkarnera",
    "reinkarnerbara": "reinkarnerbar",
    "reinkarnerbarare": "reinkarnerbar",
    "reinkarnerbarares": "reinkarnerbar",
    "reinkarnerbaras": "reinkarnerbar",
    "reinkarnerbarast": "reinkarnerbar",
    "reinkarnerbaraste": "reinkarnerbar",
    "reinkarnerbarastes": "reinkarnerbar",
    "reinkarnerbarasts": "reinkarnerbar",
    "reinkarnerbare": "reinkarnerbar",
    "reinkarnerbares": "reinkarnerbar",
    "reinkarnerbarheten": "reinkarnerbarhet",
    "reinkarnerbarhetens": "reinkarnerbarhet",
    "reinkarnerbarhets": "reinkarnerbarhet",
    "reinkarnerbars": "reinkarnerbar",
    "reinkarnerbart": "reinkarnerbar",
    "reinkarnerbarts": "reinkarnerbar",
    "reinkarneringar": "reinkarnering",
    "reinkarneringarna": "reinkarnering",
    "reinkarneringarnas": "reinkarnering",
    "reinkarneringars": "reinkarnering",
    "reinkarneringen": "reinkarnering",
    "reinkarneringens": "reinkarnering",
    "reinkarnerings": "reinkarnering",
    "rejven": "rejv",
    "rejvens": "rejv",
    "rejvfesten": "rejvfest",
    "rejvfestens": "rejvfest",
    "rejvfester": "rejvfest",
    "rejvfesterna": "rejvfest",
    "rejvfesternas": "rejvfest",
    "rejvfesters": "rejvfest",
    "rejvfests": "rejvfest",
    "rejvs": "rejv",
    "rejäla": "rejäl",
    "rejälare": "rejäl",
    "rejälares": "rejäl",
    "rejälas": "rejäl",
    "rejälast": "rejäl",
    "rejälaste": "rejäl",
    "rejälastes": "rejäl",
    "rejälasts": "rejäl",
    "rejäle": "rejäl",
    "rejäles": "rejäl",
    "rejäls": "rejäl",
    "rejält": "rejäl",
    "rejälts": "rejäl",
    "rek": "reka",
    "rekad": "reka",
    "rekade": "reka",
    "rekades": "reka",
    "rekads": "reka",
    "rekande": "reka",
    "rekanden": "rekande",
    "rekandena": "rekande",
    "rekandenas": "rekande",
    "rekandens": "rekande",
    "rekandes": "rekande",
    "rekandet": "rekande",
    "rekandets": "rekande",
    "rekapitulationen": "rekapitulation",
    "rekapitulationens": "rekapitulation",
    "rekapitulationer": "rekapitulation",
    "rekapitulationerna": "rekapitulation",
    "rekapitulationernas": "rekapitulation",
    "rekapitulationers": "rekapitulation",
    "rekapitulations": "rekapitulation",
    "rekapitulerad": "rekapitulera",
    "rekapitulerade": "rekapitulera",
    "rekapitulerades": "rekapitulera",
    "rekapitulerads": "rekapitulera",
    "rekapitulerande": "rekapitulera",
    "rekapituleranden": "rekapitulerande",
    "rekapitulerandena": "rekapitulerande",
    "rekapitulerandenas": "rekapitulerande",
    "rekapitulerandens": "rekapitulerande",
    "rekapitulerandes": "rekapitulerande",
    "rekapitulerandet": "rekapitulerande",
    "rekapitulerandets": "rekapitulerande",
    "rekapitulerar": "rekapitulera",
    "rekapituleras": "rekapitulera",
    "rekapitulerat": "rekapitulera",
    "rekapitulerats": "rekapitulera",
    "rekapitulerbara": "rekapitulerbar",
    "rekapitulerbarare": "rekapitulerbar",
    "rekapitulerbarares": "rekapitulerbar",
    "rekapitulerbaras": "rekapitulerbar",
    "rekapitulerbarast": "rekapitulerbar",
    "rekapitulerbaraste": "rekapitulerbar",
    "rekapitulerbarastes": "rekapitulerbar",
    "rekapitulerbarasts": "rekapitulerbar",
    "rekapitulerbare": "rekapitulerbar",
    "rekapitulerbares": "rekapitulerbar",
    "rekapitulerbarheten": "rekapitulerbarhet",
    "rekapitulerbarhetens": "rekapitulerbarhet",
    "rekapitulerbarhets": "rekapitulerbarhet",
    "rekapitulerbars": "rekapitulerbar",
    "rekapitulerbart": "rekapitulerbar",
    "rekapitulerbarts": "rekapitulerbar",
    "rekapituleringar": "rekapitulering",
    "rekapituleringarna": "rekapitulering",
    "rekapituleringarnas": "rekapitulering",
    "rekapituleringars": "rekapitulering",
    "rekapituleringen": "rekapitulering",
    "rekapituleringens": "rekapitulering",
    "rekapitulerings": "rekapitulering",
    "rekar": "reka",
    "rekas": "reka",
    "rekat": "reka",
    "rekats": "reka",
    "reken": "rek",
    "rekens": "rek",
    "reket": "rek",
    "rekets": "rek",
    "reklamaffischen": "reklamaffisch",
    "reklamaffischens": "reklamaffisch",
    "reklamaffischer": "reklamaffisch",
    "reklamaffischerna": "reklamaffisch",
    "reklamaffischernas": "reklamaffisch",
    "reklamaffischers": "reklamaffisch",
    "reklamaffischs": "reklamaffisch",
    "reklamagenten": "reklamagent",
    "reklamagentens": "reklamagent",
    "reklamagenter": "reklamagent",
    "reklamagenterna": "reklamagent",
    "reklamagenternas": "reklamagent",
    "reklamagenters": "reklamagent",
    "reklamagents": "reklamagent",
    "reklamationen": "reklamation",
    "reklamationens": "reklamation",
    "reklamationer": "reklamation",
    "reklamationerna": "reklamation",
    "reklamationernas": "reklamation",
    "reklamationers": "reklamation",
    "reklamations": "reklamation",
    "reklambroschyren": "reklambroschyr",
    "reklambroschyrens": "reklambroschyr",
    "reklambroschyrer": "reklambroschyr",
    "reklambroschyrerna": "reklambroschyr",
    "reklambroschyrernas": "reklambroschyr",
    "reklambroschyrers": "reklambroschyr",
    "reklambroschyrs": "reklambroschyr",
    "reklamen": "reklam",
    "reklamens": "reklam",
    "reklamer": "reklam",
    "reklamerad": "reklamera",
    "reklamerade": "reklamera",
    "reklamerades": "reklamera",
    "reklamerads": "reklamera",
    "reklamerande": "reklamera",
    "reklameranden": "reklamerande",
    "reklamerandena": "reklamerande",
    "reklamerandenas": "reklamerande",
    "reklamerandens": "reklamerande",
    "reklamerandes": "reklamerande",
    "reklamerandet": "reklamerande",
    "reklamerandets": "reklamerande",
    "reklamerar": "reklamera",
    "reklameras": "reklamera",
    "reklamerat": "reklamera",
    "reklamerats": "reklamera",
    "reklamerbara": "reklamerbar",
    "reklamerbarare": "reklamerbar",
    "reklamerbarares": "reklamerbar",
    "reklamerbaras": "reklamerbar",
    "reklamerbarast": "reklamerbar",
    "reklamerbaraste": "reklamerbar",
    "reklamerbarastes": "reklamerbar",
    "reklamerbarasts": "reklamerbar",
    "reklamerbare": "reklamerbar",
    "reklamerbares": "reklamerbar",
    "reklamerbarheten": "reklamerbarhet",
    "reklamerbarhetens": "reklamerbarhet",
    "reklamerbarhets": "reklamerbarhet",
    "reklamerbars": "reklamerbar",
    "reklamerbart": "reklamerbar",
    "reklamerbarts": "reklamerbar",
    "reklameringar": "reklamering",
    "reklameringarna": "reklamering",
    "reklameringarnas": "reklamering",
    "reklameringars": "reklamering",
    "reklameringen": "reklamering",
    "reklameringens": "reklamering",
    "reklamerings": "reklamering",
    "reklamerna": "reklam",
    "reklamernas": "reklam",
    "reklamers": "reklam",
    "reklaminslagen": "reklaminslag",
    "reklaminslagens": "reklaminslag",
    "reklaminslaget": "reklaminslag",
    "reklaminslagets": "reklaminslag",
    "reklaminslags": "reklaminslag",
    "reklamkuppen": "reklamkupp",
    "reklamkuppens": "reklamkupp",
    "reklamkupper": "reklamkupp",
    "reklamkupperna": "reklamkupp",
    "reklamkuppernas": "reklamkupp",
    "reklamkuppers": "reklamkupp",
    "reklamkupps": "reklamkupp",
    "reklampausen": "reklampaus",
    "reklampausens": "reklampaus",
    "reklampauser": "reklampaus",
    "reklampauserna": "reklampaus",
    "reklampausernas": "reklampaus",
    "reklampausers": "reklampaus",
    "reklampengar": "reklampeng",
    "reklampengarna": "reklampeng",
    "reklampengarnas": "reklampeng",
    "reklampengars": "reklampeng",
    "reklampengen": "reklampeng",
    "reklampengens": "reklampeng",
    "reklampengs": "reklampeng",
    "reklampenn": "reklampenna",
    "reklampennan": "reklampenna",
    "reklampennans": "reklampenna",
    "reklampennas": "reklampenna",
    "reklampenne": "reklampenna",
    "reklampennor": "reklampenna",
    "reklampennorna": "reklampenna",
    "reklampennornas": "reklampenna",
    "reklampennors": "reklampenna",
    "reklampenns": "reklampenna",
    "reklamplakaten": "reklamplakat",
    "reklamplakatens": "reklamplakat",
    "reklamplakatet": "reklamplakat",
    "reklamplakatets": "reklamplakat",
    "reklamplakats": "reklamplakat",
    "reklams": "reklam",
    "reklamsyften": "reklamsyfte",
    "reklamsyftena": "reklamsyfte",
    "reklamsyftenas": "reklamsyfte",
    "reklamsyftens": "reklamsyfte",
    "reklamsyftes": "reklamsyfte",
    "reklamsyftet": "reklamsyfte",
    "reklamsyftets": "reklamsyfte",
    "reklamsyfts": "reklamsyfte",
    "reklamtillvaron": "reklamtillvaro",
    "reklamtillvarons": "reklamtillvaro",
    "reklamtillvaros": "reklamtillvaro",
    "reklamtricken": "reklamtrick",
    "reklamtrickens": "reklamtrick",
    "reklamtricket": "reklamtrick",
    "reklamtrickets": "reklamtrick",
    "reklamtricks": "reklamtrick",
    "rekognoscerad": "rekognoscera",
    "rekognoscerade": "rekognoscera",
    "rekognoscerades": "rekognoscera",
    "rekognoscerads": "rekognoscera",
    "rekognoscerande": "rekognoscera",
    "rekognosceranden": "rekognoscerande",
    "rekognoscerandena": "rekognoscerande",
    "rekognoscerandenas": "rekognoscerande",
    "rekognoscerandens": "rekognoscerande",
    "rekognoscerandes": "rekognoscerande",
    "rekognoscerandet": "rekognoscerande",
    "rekognoscerandets": "rekognoscerande",
    "rekognoscerar": "rekognoscera",
    "rekognosceras": "rekognoscera",
    "rekognoscerat": "rekognoscera",
    "rekognoscerats": "rekognoscera",
    "rekognoscerbara": "rekognoscerbar",
    "rekognoscerbarare": "rekognoscerbar",
    "rekognoscerbarares": "rekognoscerbar",
    "rekognoscerbaras": "rekognoscerbar",
    "rekognoscerbarast": "rekognoscerbar",
    "rekognoscerbaraste": "rekognoscerbar",
    "rekognoscerbarastes": "rekognoscerbar",
    "rekognoscerbarasts": "rekognoscerbar",
    "rekognoscerbare": "rekognoscerbar",
    "rekognoscerbares": "rekognoscerbar",
    "rekognoscerbarheten": "rekognoscerbarhet",
    "rekognoscerbarhetens": "rekognoscerbarhet",
    "rekognoscerbarhets": "rekognoscerbarhet",
    "rekognoscerbars": "rekognoscerbar",
    "rekognoscerbart": "rekognoscerbar",
    "rekognoscerbarts": "rekognoscerbar",
    "rekognosceringar": "rekognoscering",
    "rekognosceringarna": "rekognoscering",
    "rekognosceringarnas": "rekognoscering",
    "rekognosceringars": "rekognoscering",
    "rekognosceringen": "rekognoscering",
    "rekognosceringens": "rekognoscering",
    "rekognoscerings": "rekognoscering",
    "rekognoserad": "rekognosera",
    "rekognoserade": "rekognosera",
    "rekognoserades": "rekognosera",
    "rekognoserads": "rekognosera",
    "rekognoserande": "rekognosera",
    "rekognoseranden": "rekognoserande",
    "rekognoserandena": "rekognoserande",
    "rekognoserandenas": "rekognoserande",
    "rekognoserandens": "rekognoserande",
    "rekognoserandes": "rekognoserande",
    "rekognoserandet": "rekognoserande",
    "rekognoserandets": "rekognoserande",
    "rekognoserar": "rekognosera",
    "rekognoseras": "rekognosera",
    "rekognoserat": "rekognosera",
    "rekognoserats": "rekognosera",
    "rekognoserbara": "rekognoserbar",
    "rekognoserbarare": "rekognoserbar",
    "rekognoserbarares": "rekognoserbar",
    "rekognoserbaras": "rekognoserbar",
    "rekognoserbarast": "rekognoserbar",
    "rekognoserbaraste": "rekognoserbar",
    "rekognoserbarastes": "rekognoserbar",
    "rekognoserbarasts": "rekognoserbar",
    "rekognoserbare": "rekognoserbar",
    "rekognoserbares": "rekognoserbar",
    "rekognoserbarheten": "rekognoserbarhet",
    "rekognoserbarhetens": "rekognoserbarhet",
    "rekognoserbarhets": "rekognoserbarhet",
    "rekognoserbars": "rekognoserbar",
    "rekognoserbart": "rekognoserbar",
    "rekognoserbarts": "rekognoserbar",
    "rekognoseringar": "rekognosering",
    "rekognoseringarna": "rekognosering",
    "rekognoseringarnas": "rekognosering",
    "rekognoseringars": "rekognosering",
    "rekognoseringen": "rekognosering",
    "rekognoseringens": "rekognosering",
    "rekognoserings": "rekognosering",
    "rekommendabels": "rekommendabel",
    "rekommendabelt": "rekommendabel",
    "rekommendabelts": "rekommendabel",
    "rekommendabla": "rekommendabel",
    "rekommendablare": "rekommendabel",
    "rekommendablares": "rekommendabel",
    "rekommendablas": "rekommendabel",
    "rekommendablast": "rekommendabel",
    "rekommendablaste": "rekommendabel",
    "rekommendablastes": "rekommendabel",
    "rekommendablasts": "rekommendabel",
    "rekommendable": "rekommendabel",
    "rekommendables": "rekommendabel",
    "rekommendationen": "rekommendation",
    "rekommendationens": "rekommendation",
    "rekommendationer": "rekommendation",
    "rekommendationerna": "rekommendation",
    "rekommendationernas": "rekommendation",
    "rekommendationers": "rekommendation",
    "rekommendations": "rekommendation",
    "rekommendationsbreven": "rekommendationsbrev",
    "rekommendationsbrevens": "rekommendationsbrev",
    "rekommendationsbrevet": "rekommendationsbrev",
    "rekommendationsbrevets": "rekommendationsbrev",
    "rekommendationsbrevs": "rekommendationsbrev",
    "rekommenderad": "rekommendera",
    "rekommenderade": "rekommendera",
    "rekommenderades": "rekommendera",
    "rekommenderads": "rekommendera",
    "rekommenderande": "rekommendera",
    "rekommenderanden": "rekommenderande",
    "rekommenderandena": "rekommenderande",
    "rekommenderandenas": "rekommenderande",
    "rekommenderandens": "rekommenderande",
    "rekommenderandes": "rekommenderande",
    "rekommenderandet": "rekommenderande",
    "rekommenderandets": "rekommenderande",
    "rekommenderar": "rekommendera",
    "rekommenderas": "rekommendera",
    "rekommenderat": "rekommendera",
    "rekommenderats": "rekommendera",
    "rekommenderbara": "rekommenderbar",
    "rekommenderbarare": "rekommenderbar",
    "rekommenderbarares": "rekommenderbar",
    "rekommenderbaras": "rekommenderbar",
    "rekommenderbarast": "rekommenderbar",
    "rekommenderbaraste": "rekommenderbar",
    "rekommenderbarastes": "rekommenderbar",
    "rekommenderbarasts": "rekommenderbar",
    "rekommenderbare": "rekommenderbar",
    "rekommenderbares": "rekommenderbar",
    "rekommenderbarheten": "rekommenderbarhet",
    "rekommenderbarhetens": "rekommenderbarhet",
    "rekommenderbarhets": "rekommenderbarhet",
    "rekommenderbars": "rekommenderbar",
    "rekommenderbart": "rekommenderbar",
    "rekommenderbarts": "rekommenderbar",
    "rekommenderingar": "rekommendering",
    "rekommenderingarna": "rekommendering",
    "rekommenderingarnas": "rekommendering",
    "rekommenderingars": "rekommendering",
    "rekommenderingen": "rekommendering",
    "rekommenderingens": "rekommendering",
    "rekommenderings": "rekommendering",
    "rekompenserad": "rekompensera",
    "rekompenserade": "rekompensera",
    "rekompenserades": "rekompensera",
    "rekompenserads": "rekompensera",
    "rekompenserande": "rekompensera",
    "rekompenseranden": "rekompenserande",
    "rekompenserandena": "rekompenserande",
    "rekompenserandenas": "rekompenserande",
    "rekompenserandens": "rekompenserande",
    "rekompenserandes": "rekompenserande",
    "rekompenserandet": "rekompenserande",
    "rekompenserandets": "rekompenserande",
    "rekompenserar": "rekompensera",
    "rekompenseras": "rekompensera",
    "rekompenserat": "rekompensera",
    "rekompenserats": "rekompensera",
    "rekompenserbara": "rekompenserbar",
    "rekompenserbarare": "rekompenserbar",
    "rekompenserbarares": "rekompenserbar",
    "rekompenserbaras": "rekompenserbar",
    "rekompenserbarast": "rekompenserbar",
    "rekompenserbaraste": "rekompenserbar",
    "rekompenserbarastes": "rekompenserbar",
    "rekompenserbarasts": "rekompenserbar",
    "rekompenserbare": "rekompenserbar",
    "rekompenserbares": "rekompenserbar",
    "rekompenserbarheten": "rekompenserbarhet",
    "rekompenserbarhetens": "rekompenserbarhet",
    "rekompenserbarhets": "rekompenserbarhet",
    "rekompenserbars": "rekompenserbar",
    "rekompenserbart": "rekompenserbar",
    "rekompenserbarts": "rekompenserbar",
    "rekompenseringar": "rekompensering",
    "rekompenseringarna": "rekompensering",
    "rekompenseringarnas": "rekompensering",
    "rekompenseringars": "rekompensering",
    "rekompenseringen": "rekompensering",
    "rekompenseringens": "rekompensering",
    "rekompenserings": "rekompensering",
    "rekonstruerad": "rekonstruera",
    "rekonstruerade": "rekonstruera",
    "rekonstruerades": "rekonstruera",
    "rekonstruerads": "rekonstruera",
    "rekonstruerande": "rekonstruera",
    "rekonstrueranden": "rekonstruerande",
    "rekonstruerandena": "rekonstruerande",
    "rekonstruerandenas": "rekonstruerande",
    "rekonstruerandens": "rekonstruerande",
    "rekonstruerandes": "rekonstruerande",
    "rekonstruerandet": "rekonstruerande",
    "rekonstruerandets": "rekonstruerande",
    "rekonstruerar": "rekonstruera",
    "rekonstrueras": "rekonstruera",
    "rekonstruerat": "rekonstruera",
    "rekonstruerats": "rekonstruera",
    "rekonstruerbara": "rekonstruerbar",
    "rekonstruerbarare": "rekonstruerbar",
    "rekonstruerbarares": "rekonstruerbar",
    "rekonstruerbaras": "rekonstruerbar",
    "rekonstruerbarast": "rekonstruerbar",
    "rekonstruerbaraste": "rekonstruerbar",
    "rekonstruerbarastes": "rekonstruerbar",
    "rekonstruerbarasts": "rekonstruerbar",
    "rekonstruerbare": "rekonstruerbar",
    "rekonstruerbares": "rekonstruerbar",
    "rekonstruerbarheten": "rekonstruerbarhet",
    "rekonstruerbarhetens": "rekonstruerbarhet",
    "rekonstruerbarhets": "rekonstruerbarhet",
    "rekonstruerbars": "rekonstruerbar",
    "rekonstruerbart": "rekonstruerbar",
    "rekonstruerbarts": "rekonstruerbar",
    "rekonstrueringar": "rekonstruering",
    "rekonstrueringarna": "rekonstruering",
    "rekonstrueringarnas": "rekonstruering",
    "rekonstrueringars": "rekonstruering",
    "rekonstrueringen": "rekonstruering",
    "rekonstrueringens": "rekonstruering",
    "rekonstruerings": "rekonstruering",
    "rekonstruktionen": "rekonstruktion",
    "rekonstruktionens": "rekonstruktion",
    "rekonstruktioner": "rekonstruktion",
    "rekonstruktionerna": "rekonstruktion",
    "rekonstruktionernas": "rekonstruktion",
    "rekonstruktioners": "rekonstruktion",
    "rekonstruktions": "rekonstruktion",
    "rekonvalescensen": "rekonvalescens",
    "rekonvalescensens": "rekonvalescens",
    "rekordartade": "rekordartad",
    "rekordartades": "rekordartad",
    "rekordartads": "rekordartad",
    "rekordartat": "rekordartad",
    "rekordartats": "rekordartad",
    "rekordbonusar": "rekordbonus",
    "rekordbonusarna": "rekordbonus",
    "rekordbonusarnas": "rekordbonus",
    "rekordbonusars": "rekordbonus",
    "rekordbonusen": "rekordbonus",
    "rekordbonusens": "rekordbonus",
    "rekorddjupa": "rekorddjup",
    "rekorddjupare": "rekorddjup",
    "rekorddjupares": "rekorddjup",
    "rekorddjupas": "rekorddjup",
    "rekorddjupast": "rekorddjup",
    "rekorddjupaste": "rekorddjup",
    "rekorddjupastes": "rekorddjup",
    "rekorddjupasts": "rekorddjup",
    "rekorddjupe": "rekorddjup",
    "rekorddjupes": "rekorddjup",
    "rekorddjups": "rekorddjup",
    "rekorddjupt": "rekorddjup",
    "rekorddjupts": "rekorddjup",
    "rekorden": "rekord",
    "rekordens": "rekord",
    "rekorderliga": "rekorderlig",
    "rekorderligare": "rekorderlig",
    "rekorderligares": "rekorderlig",
    "rekorderligas": "rekorderlig",
    "rekorderligast": "rekorderlig",
    "rekorderligaste": "rekorderlig",
    "rekorderligastes": "rekorderlig",
    "rekorderligasts": "rekorderlig",
    "rekorderlige": "rekorderlig",
    "rekorderliges": "rekorderlig",
    "rekorderligheten": "rekorderlighet",
    "rekorderlighetens": "rekorderlighet",
    "rekorderlighets": "rekorderlighet",
    "rekorderligs": "rekorderlig",
    "rekorderligt": "rekorderlig",
    "rekorderligts": "rekorderlig",
    "rekordet": "rekord",
    "rekordets": "rekord",
    "rekordformen": "rekordform",
    "rekordformens": "rekordform",
    "rekordforms": "rekordform",
    "rekordlånga": "rekordlång",
    "rekordlångas": "rekordlång",
    "rekordlånge": "rekordlång",
    "rekordlånges": "rekordlång",
    "rekordlångs": "rekordlång",
    "rekordlångt": "rekordlång",
    "rekordlångts": "rekordlång",
    "rekordmässiga": "rekordmässig",
    "rekordmässigare": "rekordmässig",
    "rekordmässigares": "rekordmässig",
    "rekordmässigas": "rekordmässig",
    "rekordmässigast": "rekordmässig",
    "rekordmässigaste": "rekordmässig",
    "rekordmässigastes": "rekordmässig",
    "rekordmässigasts": "rekordmässig",
    "rekordmässige": "rekordmässig",
    "rekordmässiges": "rekordmässig",
    "rekordmässigs": "rekordmässig",
    "rekordmässigt": "rekordmässig",
    "rekordmässigts": "rekordmässig",
    "rekordnivåer": "rekordnivå",
    "rekordnivåerna": "rekordnivå",
    "rekordnivåernas": "rekordnivå",
    "rekordnivåers": "rekordnivå",
    "rekordnivån": "rekordnivå",
    "rekordnivåns": "rekordnivå",
    "rekordnivås": "rekordnivå",
    "rekords": "rekord",
    "rekordsatsningar": "rekordsatsning",
    "rekordsatsningarna": "rekordsatsning",
    "rekordsatsningarnas": "rekordsatsning",
    "rekordsatsningars": "rekordsatsning",
    "rekordsatsningen": "rekordsatsning",
    "rekordsatsningens": "rekordsatsning",
    "rekordsatsnings": "rekordsatsning",
    "rekordsiffer": "rekordsiffra",
    "rekordsiffran": "rekordsiffra",
    "rekordsiffrans": "rekordsiffra",
    "rekordsiffras": "rekordsiffra",
    "rekordsiffre": "rekordsiffra",
    "rekordsiffror": "rekordsiffra",
    "rekordsiffrorna": "rekordsiffra",
    "rekordsiffrornas": "rekordsiffra",
    "rekordsiffrors": "rekordsiffra",
    "rekordstora": "rekordstor",
    "rekordstoras": "rekordstor",
    "rekordstore": "rekordstor",
    "rekordstores": "rekordstor",
    "rekordstors": "rekordstor",
    "rekordstort": "rekordstor",
    "rekordstorts": "rekordstor",
    "rekreationen": "rekreation",
    "rekreationens": "rekreation",
    "rekreationer": "rekreation",
    "rekreationerna": "rekreation",
    "rekreationernas": "rekreation",
    "rekreationers": "rekreation",
    "rekreations": "rekreation",
    "rekreationsanläggningar": "rekreationsanläggning",
    "rekreationsanläggningarna": "rekreationsanläggning",
    "rekreationsanläggningarnas": "rekreationsanläggning",
    "rekreationsanläggningars": "rekreationsanläggning",
    "rekreationsanläggningen": "rekreationsanläggning",
    "rekreationsanläggningens": "rekreationsanläggning",
    "rekreationsanläggnings": "rekreationsanläggning",
    "rekreationsmässiga": "rekreationsmässig",
    "rekreationsmässigare": "rekreationsmässig",
    "rekreationsmässigares": "rekreationsmässig",
    "rekreationsmässigas": "rekreationsmässig",
    "rekreationsmässigast": "rekreationsmässig",
    "rekreationsmässigaste": "rekreationsmässig",
    "rekreationsmässigastes": "rekreationsmässig",
    "rekreationsmässigasts": "rekreationsmässig",
    "rekreationsmässige": "rekreationsmässig",
    "rekreationsmässiges": "rekreationsmässig",
    "rekreationsmässigs": "rekreationsmässig",
    "rekreationsmässigt": "rekreationsmässig",
    "rekreationsmässigts": "rekreationsmässig",
    "rekreationsområden": "rekreationsområde",
    "rekreationsområdena": "rekreationsområde",
    "rekreationsområdenas": "rekreationsområde",
    "rekreationsområdens": "rekreationsområde",
    "rekreationsområdes": "rekreationsområde",
    "rekreationsområdet": "rekreationsområde",
    "rekreationsområdets": "rekreationsområde",
    "rekreationspolitiken": "rekreationspolitik",
    "rekreationspolitikens": "rekreationspolitik",
    "rekreationspolitiks": "rekreationspolitik",
    "rekreationspolitiska": "rekreationspolitisk",
    "rekreationspolitiskas": "rekreationspolitisk",
    "rekreationspolitiske": "rekreationspolitisk",
    "rekreationspolitiskes": "rekreationspolitisk",
    "rekreationspolitisks": "rekreationspolitisk",
    "rekreationspolitiskt": "rekreationspolitisk",
    "rekreationspolitiskts": "rekreationspolitisk",
    "rekreationsskogar": "rekreationsskog",
    "rekreationsskogarna": "rekreationsskog",
    "rekreationsskogarnas": "rekreationsskog",
    "rekreationsskogars": "rekreationsskog",
    "rekreationsskogen": "rekreationsskog",
    "rekreationsskogens": "rekreationsskog",
    "rekreationsskogs": "rekreationsskog",
    "rekreativa": "rekreativ",
    "rekreativare": "rekreativ",
    "rekreativares": "rekreativ",
    "rekreativas": "rekreativ",
    "rekreativast": "rekreativ",
    "rekreativaste": "rekreativ",
    "rekreativastes": "rekreativ",
    "rekreativasts": "rekreativ",
    "rekreative": "rekreativ",
    "rekreatives": "rekreativ",
    "rekreativs": "rekreativ",
    "rekreativt": "rekreativ",
    "rekreativts": "rekreativ",
    "rekryten": "rekryt",
    "rekrytens": "rekryt",
    "rekryter": "rekryt",
    "rekryterad": "rekrytera",
    "rekryterade": "rekrytera",
    "rekryterades": "rekrytera",
    "rekryterads": "rekrytera",
    "rekryterande": "rekrytera",
    "rekryteranden": "rekryterande",
    "rekryterandena": "rekryterande",
    "rekryterandenas": "rekryterande",
    "rekryterandens": "rekryterande",
    "rekryterandes": "rekryterande",
    "rekryterandet": "rekryterande",
    "rekryterandets": "rekryterande",
    "rekryterar": "rekrytera",
    "rekryteras": "rekrytera",
    "rekryterat": "rekrytera",
    "rekryterats": "rekrytera",
    "rekryterbara": "rekryterbar",
    "rekryterbarare": "rekryterbar",
    "rekryterbarares": "rekryterbar",
    "rekryterbaras": "rekryterbar",
    "rekryterbarast": "rekryterbar",
    "rekryterbaraste": "rekryterbar",
    "rekryterbarastes": "rekryterbar",
    "rekryterbarasts": "rekryterbar",
    "rekryterbare": "rekryterbar",
    "rekryterbares": "rekryterbar",
    "rekryterbarheten": "rekryterbarhet",
    "rekryterbarhetens": "rekryterbarhet",
    "rekryterbarhets": "rekryterbarhet",
    "rekryterbars": "rekryterbar",
    "rekryterbart": "rekryterbar",
    "rekryterbarts": "rekryterbar",
    "rekryteringar": "rekrytering",
    "rekryteringarna": "rekrytering",
    "rekryteringarnas": "rekrytering",
    "rekryteringars": "rekrytering",
    "rekryteringen": "rekrytering",
    "rekryteringens": "rekrytering",
    "rekryterings": "rekrytering",
    "rekryteringsföretagen": "rekryteringsföretag",
    "rekryteringsföretagens": "rekryteringsföretag",
    "rekryteringsföretaget": "rekryteringsföretag",
    "rekryteringsföretagets": "rekryteringsföretag",
    "rekryteringsföretags": "rekryteringsföretag",
    "rekryterna": "rekryt",
    "rekryternas": "rekryt",
    "rekryters": "rekryt",
    "rekryts": "rekryt",
    "reks": "rek",
    "rektangeln": "rektangel",
    "rektangelns": "rektangel",
    "rektangels": "rektangel",
    "rektanglar": "rektangel",
    "rektanglarna": "rektangel",
    "rektanglarnas": "rektangel",
    "rektanglars": "rektangel",
    "rektangulära": "rektangulär",
    "rektangulärare": "rektangulär",
    "rektangulärares": "rektangulär",
    "rektanguläras": "rektangulär",
    "rektangulärast": "rektangulär",
    "rektanguläraste": "rektangulär",
    "rektangulärastes": "rektangulär",
    "rektangulärasts": "rektangulär",
    "rektanguläre": "rektangulär",
    "rektanguläres": "rektangulär",
    "rektangulärs": "rektangulär",
    "rektangulärt": "rektangulär",
    "rektangulärts": "rektangulär",
    "rektascensionen": "rektascension",
    "rektascensionens": "rektascension",
    "rektascensioner": "rektascension",
    "rektascensionerna": "rektascension",
    "rektascensionernas": "rektascension",
    "rektascensioners": "rektascension",
    "rektascensions": "rektascension",
    "rektificerad": "rektificera",
    "rektificerade": "rektificera",
    "rektificerades": "rektificera",
    "rektificerads": "rektificera",
    "rektificerande": "rektificera",
    "rektificeranden": "rektificerande",
    "rektificerandena": "rektificerande",
    "rektificerandenas": "rektificerande",
    "rektificerandens": "rektificerande",
    "rektificerandes": "rektificerande",
    "rektificerandet": "rektificerande",
    "rektificerandets": "rektificerande",
    "rektificerar": "rektificera",
    "rektificeras": "rektificera",
    "rektificerat": "rektificera",
    "rektificerats": "rektificera",
    "rektificerbara": "rektificerbar",
    "rektificerbarare": "rektificerbar",
    "rektificerbarares": "rektificerbar",
    "rektificerbaras": "rektificerbar",
    "rektificerbarast": "rektificerbar",
    "rektificerbaraste": "rektificerbar",
    "rektificerbarastes": "rektificerbar",
    "rektificerbarasts": "rektificerbar",
    "rektificerbare": "rektificerbar",
    "rektificerbares": "rektificerbar",
    "rektificerbarheten": "rektificerbarhet",
    "rektificerbarhetens": "rektificerbarhet",
    "rektificerbarhets": "rektificerbarhet",
    "rektificerbars": "rektificerbar",
    "rektificerbart": "rektificerbar",
    "rektificerbarts": "rektificerbar",
    "rektificeringar": "rektificering",
    "rektificeringarna": "rektificering",
    "rektificeringarnas": "rektificering",
    "rektificeringars": "rektificering",
    "rektificeringen": "rektificering",
    "rektificeringens": "rektificering",
    "rektificerings": "rektificering",
    "rektifierad": "rektifiera",
    "rektifierade": "rektifiera",
    "rektifierades": "rektifiera",
    "rektifierads": "rektifiera",
    "rektifierande": "rektifiera",
    "rektifieranden": "rektifierande",
    "rektifierandena": "rektifierande",
    "rektifierandenas": "rektifierande",
    "rektifierandens": "rektifierande",
    "rektifierandes": "rektifierande",
    "rektifierandet": "rektifierande",
    "rektifierandets": "rektifierande",
    "rektifierar": "rektifiera",
    "rektifieras": "rektifiera",
    "rektifierat": "rektifiera",
    "rektifierats": "rektifiera",
    "rektifierbara": "rektifierbar",
    "rektifierbarare": "rektifierbar",
    "rektifierbarares": "rektifierbar",
    "rektifierbaras": "rektifierbar",
    "rektifierbarast": "rektifierbar",
    "rektifierbaraste": "rektifierbar",
    "rektifierbarastes": "rektifierbar",
    "rektifierbarasts": "rektifierbar",
    "rektifierbare": "rektifierbar",
    "rektifierbares": "rektifierbar",
    "rektifierbarheten": "rektifierbarhet",
    "rektifierbarhetens": "rektifierbarhet",
    "rektifierbarhets": "rektifierbarhet",
    "rektifierbars": "rektifierbar",
    "rektifierbart": "rektifierbar",
    "rektifierbarts": "rektifierbar",
    "rektifieringar": "rektifiering",
    "rektifieringarna": "rektifiering",
    "rektifieringarnas": "rektifiering",
    "rektifieringars": "rektifiering",
    "rektifieringen": "rektifiering",
    "rektifieringens": "rektifiering",
    "rektifierings": "rektifiering",
    "rektifikationen": "rektifikation",
    "rektifikationens": "rektifikation",
    "rektifikationer": "rektifikation",
    "rektifikationerna": "rektifikation",
    "rektifikationernas": "rektifikation",
    "rektifikationers": "rektifikation",
    "rektifikations": "rektifikation",
    "rektionen": "rektion",
    "rektionens": "rektion",
    "rektioner": "rektion",
    "rektionerna": "rektion",
    "rektionernas": "rektion",
    "rektioners": "rektion",
    "rektions": "rektion",
    "rektoraten": "rektorat",
    "rektoratens": "rektorat",
    "rektoratet": "rektorat",
    "rektoratets": "rektorat",
    "rektorats": "rektorat",
    "rektoren": "rektor",
    "rektorens": "rektor",
    "rektorer": "rektor",
    "rektorerna": "rektor",
    "rektorernas": "rektor",
    "rektorers": "rektor",
    "rektorn": "rektor",
    "rektorns": "rektor",
    "rektors": "rektor",
    "rektorsexpeditionen": "rektorsexpedition",
    "rektorsexpeditionens": "rektorsexpedition",
    "rektorsexpeditioner": "rektorsexpedition",
    "rektorsexpeditionerna": "rektorsexpedition",
    "rektorsexpeditionernas": "rektorsexpedition",
    "rektorsexpeditioners": "rektorsexpedition",
    "rektorsexpeditions": "rektorsexpedition",
    "rektorsområden": "rektorsområde",
    "rektorsområdena": "rektorsområde",
    "rektorsområdenas": "rektorsområde",
    "rektorsområdens": "rektorsområde",
    "rektorsområdes": "rektorsområde",
    "rektorsområdet": "rektorsområde",
    "rektorsområdets": "rektorsområde",
    "rekurrensen": "rekurrens",
    "rekurrensens": "rekurrens",
    "rekurrenser": "rekurrens",
    "rekurrenserna": "rekurrens",
    "rekurrensernas": "rekurrens",
    "rekurrensers": "rekurrens",
    "rekurrensrelationen": "rekurrensrelation",
    "rekurrensrelationens": "rekurrensrelation",
    "rekurrensrelationer": "rekurrensrelation",
    "rekurrensrelationerna": "rekurrensrelation",
    "rekurrensrelationernas": "rekurrensrelation",
    "rekurrensrelationers": "rekurrensrelation",
    "rekurrensrelations": "rekurrensrelation",
    "rekviemen": "rekviem",
    "rekviemens": "rekviem",
    "rekviemet": "rekviem",
    "rekviemets": "rekviem",
    "rekviems": "rekviem",
    "rekvier": "rekviem",
    "rekvierna": "rekviem",
    "rekviernas": "rekviem",
    "rekviers": "rekviem",
    "rekviet": "rekviem",
    "rekviets": "rekviem",
    "rekvirerad": "rekvirera",
    "rekvirerade": "rekvirera",
    "rekvirerades": "rekvirera",
    "rekvirerads": "rekvirera",
    "rekvirerande": "rekvirera",
    "rekvireranden": "rekvirerande",
    "rekvirerandena": "rekvirerande",
    "rekvirerandenas": "rekvirerande",
    "rekvirerandens": "rekvirerande",
    "rekvirerandes": "rekvirerande",
    "rekvirerandet": "rekvirerande",
    "rekvirerandets": "rekvirerande",
    "rekvirerar": "rekvirera",
    "rekvireras": "rekvirera",
    "rekvirerat": "rekvirera",
    "rekvirerats": "rekvirera",
    "rekvirerbara": "rekvirerbar",
    "rekvirerbarare": "rekvirerbar",
    "rekvirerbarares": "rekvirerbar",
    "rekvirerbaras": "rekvirerbar",
    "rekvirerbarast": "rekvirerbar",
    "rekvirerbaraste": "rekvirerbar",
    "rekvirerbarastes": "rekvirerbar",
    "rekvirerbarasts": "rekvirerbar",
    "rekvirerbare": "rekvirerbar",
    "rekvirerbares": "rekvirerbar",
    "rekvirerbarheten": "rekvirerbarhet",
    "rekvirerbarhetens": "rekvirerbarhet",
    "rekvirerbarhets": "rekvirerbarhet",
    "rekvirerbars": "rekvirerbar",
    "rekvirerbart": "rekvirerbar",
    "rekvirerbarts": "rekvirerbar",
    "rekvireringar": "rekvirering",
    "rekvireringarna": "rekvirering",
    "rekvireringarnas": "rekvirering",
    "rekvireringars": "rekvirering",
    "rekvireringen": "rekvirering",
    "rekvireringens": "rekvirering",
    "rekvirerings": "rekvirering",
    "rekvisitan": "rekvisita",
    "rekvisitans": "rekvisita",
    "rekvisitas": "rekvisita",
    "rekvisiten": "rekvisit",
    "rekvisitens": "rekvisit",
    "rekvisiter": "rekvisit",
    "rekvisiterna": "rekvisit",
    "rekvisiternas": "rekvisit",
    "rekvisiters": "rekvisit",
    "rekvisitet": "rekvisit",
    "rekvisitets": "rekvisit",
    "rekvisitionen": "rekvisition",
    "rekvisitionens": "rekvisition",
    "rekvisitioner": "rekvisition",
    "rekvisitionerna": "rekvisition",
    "rekvisitionernas": "rekvisition",
    "rekvisitioners": "rekvisition",
    "rekvisitions": "rekvisition",
    "rekvisits": "rekvisit",
    "rekvisitören": "rekvisitör",
    "rekvisitörens": "rekvisitör",
    "rekvisitörer": "rekvisitör",
    "rekvisitörerna": "rekvisitör",
    "rekvisitörernas": "rekvisitör",
    "rekvisitörers": "rekvisitör",
    "rekvisitörs": "rekvisitör",
    "rekylen": "rekyl",
    "rekylens": "rekyl",
    "rekyler": "rekyl",
    "rekylerade": "rekylera",
    "rekylerades": "rekylera",
    "rekylerande": "rekylera",
    "rekyleranden": "rekylerande",
    "rekylerandena": "rekylerande",
    "rekylerandenas": "rekylerande",
    "rekylerandens": "rekylerande",
    "rekylerandes": "rekylerande",
    "rekylerandet": "rekylerande",
    "rekylerandets": "rekylerande",
    "rekylerar": "rekylera",
    "rekyleras": "rekylera",
    "rekylerat": "rekylera",
    "rekylerats": "rekylera",
    "rekyleringar": "rekylering",
    "rekyleringarna": "rekylering",
    "rekyleringarnas": "rekylering",
    "rekyleringars": "rekylering",
    "rekyleringen": "rekylering",
    "rekyleringens": "rekylering",
    "rekylerings": "rekylering",
    "rekylerna": "rekyl",
    "rekylernas": "rekyl",
    "rekylers": "rekyl",
    "rekyls": "rekyl",
    "relaterad": "relatera",
    "relaterade": "relatera",
    "relaterades": "relatera",
    "relaterads": "relatera",
    "relaterande": "relatera",
    "relateranden": "relaterande",
    "relaterandena": "relaterande",
    "relaterandenas": "relaterande",
    "relaterandens": "relaterande",
    "relaterandes": "relaterande",
    "relaterandet": "relaterande",
    "relaterandets": "relaterande",
    "relaterar": "relatera",
    "relateras": "relatera",
    "relaterat": "relatera",
    "relaterats": "relatera",
    "relaterbara": "relaterbar",
    "relaterbarare": "relaterbar",
    "relaterbarares": "relaterbar",
    "relaterbaras": "relaterbar",
    "relaterbarast": "relaterbar",
    "relaterbaraste": "relaterbar",
    "relaterbarastes": "relaterbar",
    "relaterbarasts": "relaterbar",
    "relaterbare": "relaterbar",
    "relaterbares": "relaterbar",
    "relaterbarheten": "relaterbarhet",
    "relaterbarhetens": "relaterbarhet",
    "relaterbarhets": "relaterbarhet",
    "relaterbars": "relaterbar",
    "relaterbart": "relaterbar",
    "relaterbarts": "relaterbar",
    "relateringar": "relatering",
    "relateringarna": "relatering",
    "relateringarnas": "relatering",
    "relateringars": "relatering",
    "relateringen": "relatering",
    "relateringens": "relatering",
    "relaterings": "relatering",
    "relationen": "relation",
    "relationens": "relation",
    "relationer": "relation",
    "relationerna": "relation",
    "relationernas": "relation",
    "relationers": "relation",
    "relations": "relation",
    "relationsmässiga": "relationsmässig",
    "relationsmässigare": "relationsmässig",
    "relationsmässigares": "relationsmässig",
    "relationsmässigas": "relationsmässig",
    "relationsmässigast": "relationsmässig",
    "relationsmässigaste": "relationsmässig",
    "relationsmässigastes": "relationsmässig",
    "relationsmässigasts": "relationsmässig",
    "relationsmässige": "relationsmässig",
    "relationsmässiges": "relationsmässig",
    "relationsmässigs": "relationsmässig",
    "relationsmässigt": "relationsmässig",
    "relationsmässigts": "relationsmässig",
    "relationsråden": "relationsråd",
    "relationsrådens": "relationsråd",
    "relationsrådet": "relationsråd",
    "relationsrådets": "relationsråd",
    "relationsråds": "relationsråd",
    "relationstalen": "relationstal",
    "relationstalens": "relationstal",
    "relationstalet": "relationstal",
    "relationstalets": "relationstal",
    "relationstals": "relationstal",
    "relativa": "relativ",
    "relativare": "relativ",
    "relativares": "relativ",
    "relativas": "relativ",
    "relativast": "relativ",
    "relativaste": "relativ",
    "relativastes": "relativ",
    "relativasts": "relativ",
    "relative": "relativ",
    "relatives": "relativ",
    "relativismen": "relativism",
    "relativismens": "relativism",
    "relativismer": "relativism",
    "relativismerna": "relativism",
    "relativismernas": "relativism",
    "relativismers": "relativism",
    "relativisms": "relativism",
    "relativisten": "relativist",
    "relativistens": "relativist",
    "relativister": "relativist",
    "relativisterna": "relativist",
    "relativisternas": "relativist",
    "relativisters": "relativist",
    "relativistiska": "relativistisk",
    "relativistiskare": "relativistisk",
    "relativistiskares": "relativistisk",
    "relativistiskas": "relativistisk",
    "relativistiskast": "relativistisk",
    "relativistiskaste": "relativistisk",
    "relativistiskastes": "relativistisk",
    "relativistiskasts": "relativistisk",
    "relativistiske": "relativistisk",
    "relativistiskes": "relativistisk",
    "relativistisks": "relativistisk",
    "relativistiskt": "relativistisk",
    "relativistiskts": "relativistisk",
    "relativists": "relativist",
    "relativiteten": "relativitet",
    "relativitetens": "relativitet",
    "relativiteter": "relativitet",
    "relativiteterna": "relativitet",
    "relativiteternas": "relativitet",
    "relativiteters": "relativitet",
    "relativitets": "relativitet",
    "relativitetsteorien": "relativitetsteori",
    "relativitetsteoriens": "relativitetsteori",
    "relativitetsteorin": "relativitetsteori",
    "relativitetsteorins": "relativitetsteori",
    "relativitetsteoris": "relativitetsteori",
    "relativpronomenen": "relativpronomen",
    "relativpronomenens": "relativpronomen",
    "relativpronomenet": "relativpronomen",
    "relativpronomenets": "relativpronomen",
    "relativpronomens": "relativpronomen",
    "relativpronomina": "relativpronomen",
    "relativpronominas": "relativpronomen",
    "relativs": "relativ",
    "relativsatsen": "relativsats",
    "relativsatsens": "relativsats",
    "relativsatser": "relativsats",
    "relativsatserna": "relativsats",
    "relativsatsernas": "relativsats",
    "relativsatsers": "relativsats",
    "relativt": "relativ",
    "relativts": "relativ",
    "relaxade": "relaxa",
    "relaxades": "relaxa",
    "relaxande": "relaxa",
    "relaxanden": "relaxande",
    "relaxandena": "relaxande",
    "relaxandenas": "relaxande",
    "relaxandens": "relaxande",
    "relaxandes": "relaxande",
    "relaxandet": "relaxande",
    "relaxandets": "relaxande",
    "relaxar": "relaxa",
    "relaxas": "relaxa",
    "relaxat": "relaxa",
    "relaxationen": "relaxation",
    "relaxationens": "relaxation",
    "relaxationer": "relaxation",
    "relaxationerna": "relaxation",
    "relaxationernas": "relaxation",
    "relaxationers": "relaxation",
    "relaxations": "relaxation",
    "relaxats": "relaxa",
    "releasen": "release",
    "releasens": "release",
    "releaser": "release",
    "releaserna": "release",
    "releasernas": "release",
    "releasers": "release",
    "releases": "release",
    "relegerad": "relegera",
    "relegerade": "relegera",
    "relegerades": "relegera",
    "relegerads": "relegera",
    "relegerande": "relegera",
    "relegeranden": "relegerande",
    "relegerandena": "relegerande",
    "relegerandenas": "relegerande",
    "relegerandens": "relegerande",
    "relegerandes": "relegerande",
    "relegerandet": "relegerande",
    "relegerandets": "relegerande",
    "relegerar": "relegera",
    "relegeras": "relegera",
    "relegerat": "relegera",
    "relegerats": "relegera",
    "relegerbara": "relegerbar",
    "relegerbarare": "relegerbar",
    "relegerbarares": "relegerbar",
    "relegerbaras": "relegerbar",
    "relegerbarast": "relegerbar",
    "relegerbaraste": "relegerbar",
    "relegerbarastes": "relegerbar",
    "relegerbarasts": "relegerbar",
    "relegerbare": "relegerbar",
    "relegerbares": "relegerbar",
    "relegerbarheten": "relegerbarhet",
    "relegerbarhetens": "relegerbarhet",
    "relegerbarhets": "relegerbarhet",
    "relegerbars": "relegerbar",
    "relegerbart": "relegerbar",
    "relegerbarts": "relegerbar",
    "relegeringar": "relegering",
    "relegeringarna": "relegering",
    "relegeringarnas": "relegering",
    "relegeringars": "relegering",
    "relegeringen": "relegering",
    "relegeringens": "relegering",
    "relegerings": "relegering",
    "relevansen": "relevans",
    "relevansens": "relevans",
    "relevanta": "relevant",
    "relevantare": "relevant",
    "relevantares": "relevant",
    "relevantas": "relevant",
    "relevantast": "relevant",
    "relevantaste": "relevant",
    "relevantastes": "relevant",
    "relevantasts": "relevant",
    "relevante": "relevant",
    "relevantes": "relevant",
    "relevants": "relevant",
    "reliabels": "reliabel",
    "reliabelt": "reliabel",
    "reliabelts": "reliabel",
    "reliabiliteten": "reliabilitet",
    "reliabilitetens": "reliabilitet",
    "reliabiliteter": "reliabilitet",
    "reliabiliteterna": "reliabilitet",
    "reliabiliteternas": "reliabilitet",
    "reliabiliteters": "reliabilitet",
    "reliabilitets": "reliabilitet",
    "reliabla": "reliabel",
    "reliablare": "reliabel",
    "reliablares": "reliabel",
    "reliablas": "reliabel",
    "reliablast": "reliabel",
    "reliablaste": "reliabel",
    "reliablastes": "reliabel",
    "reliablasts": "reliabel",
    "reliable": "reliabel",
    "reliables": "reliabel",
    "reliefartade": "reliefartad",
    "reliefartades": "reliefartad",
    "reliefartads": "reliefartad",
    "reliefartat": "reliefartad",
    "reliefartats": "reliefartad",
    "reliefen": "relief",
    "reliefens": "relief",
    "reliefer": "relief",
    "relieferna": "relief",
    "reliefernas": "relief",
    "reliefers": "relief",
    "reliefs": "relief",
    "religionen": "religion",
    "religionens": "religion",
    "religioner": "religion",
    "religionerna": "religion",
    "religionernas": "religion",
    "religioners": "religion",
    "religions": "religion",
    "religionsfilosofien": "religionsfilosofi",
    "religionsfilosofiens": "religionsfilosofi",
    "religionsfilosofier": "religionsfilosofi",
    "religionsfilosofierna": "religionsfilosofi",
    "religionsfilosofiernas": "religionsfilosofi",
    "religionsfilosofiers": "religionsfilosofi",
    "religionsfilosofin": "religionsfilosofi",
    "religionsfilosofins": "religionsfilosofi",
    "religionsfilosofis": "religionsfilosofi",
    "religionsfriheten": "religionsfrihet",
    "religionsfrihetens": "religionsfrihet",
    "religionsfriheter": "religionsfrihet",
    "religionsfriheterna": "religionsfrihet",
    "religionsfriheternas": "religionsfrihet",
    "religionsfriheters": "religionsfrihet",
    "religionsfrihets": "religionsfrihet",
    "religionsförföljelsen": "religionsförföljelse",
    "religionsförföljelsens": "religionsförföljelse",
    "religionsförföljelser": "religionsförföljelse",
    "religionsförföljelserna": "religionsförföljelse",
    "religionsförföljelsernas": "religionsförföljelse",
    "religionsförföljelsers": "religionsförföljelse",
    "religionsförföljelses": "religionsförföljelse",
    "religionskritikern": "religionskritiker",
    "religionskritikerna": "religionskritiker",
    "religionskritikernas": "religionskritiker",
    "religionskritikerns": "religionskritiker",
    "religionskritikers": "religionskritiker",
    "religionskunskapen": "religionskunskap",
    "religionskunskapens": "religionskunskap",
    "religionskunskaps": "religionskunskap",
    "religionsläran": "religionslära",
    "religionslärans": "religionslära",
    "religionsläras": "religionslära",
    "religionsläre": "religionslära",
    "religionsläro": "religionslära",
    "religionsläror": "religionslära",
    "religionslärorna": "religionslära",
    "religionslärornas": "religionslära",
    "religionslärors": "religionslära",
    "religionsstiftar": "religionsstiftare",
    "religionsstiftaren": "religionsstiftare",
    "religionsstiftarens": "religionsstiftare",
    "religionsstiftares": "religionsstiftare",
    "religionsstiftarna": "religionsstiftare",
    "religionsstiftarnas": "religionsstiftare",
    "religiositeten": "religiositet",
    "religiositetens": "religiositet",
    "religiositeter": "religiositet",
    "religiositeterna": "religiositet",
    "religiositeternas": "religiositet",
    "religiositeters": "religiositet",
    "religiositets": "religiositet",
    "religiösa": "religiös",
    "religiösare": "religiös",
    "religiösares": "religiös",
    "religiösas": "religiös",
    "religiösast": "religiös",
    "religiösaste": "religiös",
    "religiösastes": "religiös",
    "religiösasts": "religiös",
    "religiöse": "religiös",
    "religiöses": "religiös",
    "religiöst": "religiös",
    "religiösts": "religiös",
    "reliken": "relik",
    "relikens": "relik",
    "reliker": "relik",
    "relikerna": "relik",
    "relikernas": "relik",
    "relikers": "relik",
    "reliks": "relik",
    "relikten": "relikt",
    "reliktens": "relikt",
    "relikter": "relikt",
    "relikterna": "relikt",
    "relikternas": "relikt",
    "relikters": "relikt",
    "relikts": "relikt",
    "relingar": "reling",
    "relingarna": "reling",
    "relingarnas": "reling",
    "relingars": "reling",
    "relingen": "reling",
    "relingens": "reling",
    "relings": "reling",
    "relingsmanningar": "relingsmanning",
    "relingsmanningarna": "relingsmanning",
    "relingsmanningarnas": "relingsmanning",
    "relingsmanningars": "relingsmanning",
    "relingsmanningen": "relingsmanning",
    "relingsmanningens": "relingsmanning",
    "relingsmannings": "relingsmanning",
    "relä": "reläa",
    "reläad": "reläa",
    "reläade": "reläa",
    "reläades": "reläa",
    "reläads": "reläa",
    "reläande": "reläa",
    "reläanden": "reläande",
    "reläandena": "reläande",
    "reläandenas": "reläande",
    "reläandens": "reläande",
    "reläandes": "reläande",
    "reläandet": "reläande",
    "reläandets": "reläande",
    "reläar": "reläa",
    "reläas": "reläa",
    "reläat": "reläa",
    "reläats": "reläa",
    "reläer": "relä",
    "reläerna": "relä",
    "reläernas": "relä",
    "reläers": "relä",
    "reläet": "relä",
    "reläets": "relä",
    "reläs": "relä",
    "relästationen": "relästation",
    "relästationens": "relästation",
    "relästationer": "relästation",
    "relästationerna": "relästation",
    "relästationernas": "relästation",
    "relästationers": "relästation",
    "relästations": "relästation",
    "relät": "relä",
    "reläts": "relä",
    "remanensen": "remanens",
    "remanensens": "remanens",
    "remarkabels": "remarkabel",
    "remarkabelt": "remarkabel",
    "remarkabelts": "remarkabel",
    "remarkabla": "remarkabel",
    "remarkablare": "remarkabel",
    "remarkablares": "remarkabel",
    "remarkablas": "remarkabel",
    "remarkablast": "remarkabel",
    "remarkablaste": "remarkabel",
    "remarkablastes": "remarkabel",
    "remarkablasts": "remarkabel",
    "remarkable": "remarkabel",
    "remarkables": "remarkabel",
    "remboursen": "rembours",
    "remboursens": "rembours",
    "rembourser": "rembours",
    "rembourserna": "rembours",
    "remboursernas": "rembours",
    "remboursers": "rembours",
    "rembursen": "remburs",
    "rembursens": "remburs",
    "remburser": "remburs",
    "remburserna": "remburs",
    "rembursernas": "remburs",
    "rembursers": "remburs",
    "remedier": "remedium",
    "remedierna": "remedium",
    "remediernas": "remedium",
    "remediers": "remedium",
    "remediet": "remedium",
    "remediets": "remedium",
    "remediumet": "remedium",
    "remediumets": "remedium",
    "remediums": "remedium",
    "remen": "rem",
    "remens": "rem",
    "remien": "remi",
    "remiens": "remi",
    "remier": "remi",
    "remierna": "remi",
    "remiernas": "remi",
    "remiers": "remi",
    "remin": "remi",
    "reminiscensen": "reminiscens",
    "reminiscensens": "reminiscens",
    "reminiscenser": "reminiscens",
    "reminiscenserna": "reminiscens",
    "reminiscensernas": "reminiscens",
    "reminiscensers": "reminiscens",
    "remins": "remi",
    "remis": "remi",
    "remisen": "remis",
    "remisens": "remis",
    "remiser": "remis",
    "remiserna": "remis",
    "remisernas": "remis",
    "remisers": "remis",
    "remiss": "remissa",
    "remissan": "remissa",
    "remissans": "remissa",
    "remissas": "remissa",
    "remissdebatten": "remissdebatt",
    "remissdebattens": "remissdebatt",
    "remissdebatter": "remissdebatt",
    "remissdebatterna": "remissdebatt",
    "remissdebatternas": "remissdebatt",
    "remissdebatters": "remissdebatt",
    "remissdebatts": "remissdebatt",
    "remisse": "remissa",
    "remissen": "remiss",
    "remissens": "remiss",
    "remisser": "remiss",
    "remisserna": "remiss",
    "remissernas": "remiss",
    "remissers": "remiss",
    "remissinstansen": "remissinstans",
    "remissinstansens": "remissinstans",
    "remissinstanser": "remissinstans",
    "remissinstanserna": "remissinstans",
    "remissinstansernas": "remissinstans",
    "remissinstansers": "remissinstans",
    "remissor": "remissa",
    "remissorna": "remissa",
    "remissornas": "remissa",
    "remissors": "remissa",
    "remissvaren": "remissvar",
    "remissvarens": "remissvar",
    "remissvaret": "remissvar",
    "remissvarets": "remissvar",
    "remissvars": "remissvar",
    "remissyttranden": "remissyttrande",
    "remissyttrandena": "remissyttrande",
    "remissyttrandenas": "remissyttrande",
    "remissyttrandens": "remissyttrande",
    "remissyttrandes": "remissyttrande",
    "remissyttrandet": "remissyttrande",
    "remissyttrandets": "remissyttrande",
    "remittenta": "remittent",
    "remittentare": "remittent",
    "remittentares": "remittent",
    "remittentas": "remittent",
    "remittentast": "remittent",
    "remittentaste": "remittent",
    "remittentastes": "remittent",
    "remittentasts": "remittent",
    "remittente": "remittent",
    "remittenten": "remittent",
    "remittentens": "remittent",
    "remittenter": "remittent",
    "remittenterna": "remittent",
    "remittenternas": "remittent",
    "remittenters": "remittent",
    "remittentes": "remittent",
    "remittents": "remittent",
    "remitterad": "remittera",
    "remitterade": "remittera",
    "remitterades": "remittera",
    "remitterads": "remittera",
    "remitterande": "remittera",
    "remitteranden": "remitterande",
    "remitterandena": "remitterande",
    "remitterandenas": "remitterande",
    "remitterandens": "remitterande",
    "remitterandes": "remitterande",
    "remitterandet": "remitterande",
    "remitterandets": "remitterande",
    "remitterar": "remittera",
    "remitteras": "remittera",
    "remitterat": "remittera",
    "remitterats": "remittera",
    "remitterbara": "remitterbar",
    "remitterbarare": "remitterbar",
    "remitterbarares": "remitterbar",
    "remitterbaras": "remitterbar",
    "remitterbarast": "remitterbar",
    "remitterbaraste": "remitterbar",
    "remitterbarastes": "remitterbar",
    "remitterbarasts": "remitterbar",
    "remitterbare": "remitterbar",
    "remitterbares": "remitterbar",
    "remitterbarheten": "remitterbarhet",
    "remitterbarhetens": "remitterbarhet",
    "remitterbarhets": "remitterbarhet",
    "remitterbars": "remitterbar",
    "remitterbart": "remitterbar",
    "remitterbarts": "remitterbar",
    "remitteringar": "remittering",
    "remitteringarna": "remittering",
    "remitteringarnas": "remittering",
    "remitteringars": "remittering",
    "remitteringen": "remittering",
    "remitteringens": "remittering",
    "remitterings": "remittering",
    "remmad": "remma",
    "remmade": "remma",
    "remmades": "remma",
    "remmads": "remma",
    "remmande": "remma",
    "remmanden": "remmande",
    "remmandena": "remmande",
    "remmandenas": "remmande",
    "remmandens": "remmande",
    "remmandes": "remmande",
    "remmandet": "remmande",
    "remmandets": "remmande",
    "remmar": "remmare",
    "remmaren": "remmare",
    "remmarens": "remmare",
    "remmares": "remmare",
    "remmarna": "remmare",
    "remmarnas": "remmare",
    "remmars": "rem",
    "remmas": "remma",
    "remmat": "remma",
    "remmats": "remma",
    "remmen": "rem",
    "remmens": "rem",
    "remonten": "remont",
    "remontens": "remont",
    "remonter": "remont",
    "remonterade": "remontera",
    "remonterades": "remontera",
    "remonterande": "remontera",
    "remonteranden": "remonterande",
    "remonterandena": "remonterande",
    "remonterandenas": "remonterande",
    "remonterandens": "remonterande",
    "remonterandes": "remonterande",
    "remonterandet": "remonterande",
    "remonterandets": "remonterande",
    "remonterar": "remontera",
    "remonteras": "remontera",
    "remonterat": "remontera",
    "remonterats": "remontera",
    "remonteringar": "remontering",
    "remonteringarna": "remontering",
    "remonteringarnas": "remontering",
    "remonteringars": "remontering",
    "remonteringen": "remontering",
    "remonteringens": "remontering",
    "remonterings": "remontering",
    "remonterna": "remont",
    "remonternas": "remont",
    "remonters": "remont",
    "remonts": "remont",
    "remouladsåsen": "remouladsås",
    "remouladsåsens": "remouladsås",
    "remouladsåser": "remouladsås",
    "remouladsåserna": "remouladsås",
    "remouladsåsernas": "remouladsås",
    "remouladsåsers": "remouladsås",
    "remplacerad": "remplacera",
    "remplacerade": "remplacera",
    "remplacerades": "remplacera",
    "remplacerads": "remplacera",
    "remplacerande": "remplacera",
    "remplaceranden": "remplacerande",
    "remplacerandena": "remplacerande",
    "remplacerandenas": "remplacerande",
    "remplacerandens": "remplacerande",
    "remplacerandes": "remplacerande",
    "remplacerandet": "remplacerande",
    "remplacerandets": "remplacerande",
    "remplacerar": "remplacera",
    "remplaceras": "remplacera",
    "remplacerat": "remplacera",
    "remplacerats": "remplacera",
    "remplacerbara": "remplacerbar",
    "remplacerbarare": "remplacerbar",
    "remplacerbarares": "remplacerbar",
    "remplacerbaras": "remplacerbar",
    "remplacerbarast": "remplacerbar",
    "remplacerbaraste": "remplacerbar",
    "remplacerbarastes": "remplacerbar",
    "remplacerbarasts": "remplacerbar",
    "remplacerbare": "remplacerbar",
    "remplacerbares": "remplacerbar",
    "remplacerbarheten": "remplacerbarhet",
    "remplacerbarhetens": "remplacerbarhet",
    "remplacerbarhets": "remplacerbarhet",
    "remplacerbars": "remplacerbar",
    "remplacerbart": "remplacerbar",
    "remplacerbarts": "remplacerbar",
    "remplaceringar": "remplacering",
    "remplaceringarna": "remplacering",
    "remplaceringarnas": "remplacering",
    "remplaceringars": "remplacering",
    "remplaceringen": "remplacering",
    "remplaceringens": "remplacering",
    "remplacerings": "remplacering",
    "rems": "remsa",
    "remsan": "remsa",
    "remsans": "remsa",
    "remsas": "remsa",
    "remse": "remsa",
    "remsor": "remsa",
    "remsorna": "remsa",
    "remsornas": "remsa",
    "remsors": "remsa",
    "remtygen": "remtyg",
    "remtygens": "remtyg",
    "remtyget": "remtyg",
    "remtygets": "remtyg",
    "remtygs": "remtyg",
    "remuladsåsen": "remuladsås",
    "remuladsåsens": "remuladsås",
    "remuladsåser": "remuladsås",
    "remuladsåserna": "remuladsås",
    "remuladsåsernas": "remuladsås",
    "remuladsåsers": "remuladsås",
    "ren": "rena",
    "rena": "ren",
    "renad": "rena",
    "renade": "rena",
    "renades": "rena",
    "renads": "rena",
    "renande": "rena",
    "renanden": "renande",
    "renandena": "renande",
    "renandenas": "renande",
    "renandens": "renande",
    "renandes": "renande",
    "renandet": "renande",
    "renandets": "renande",
    "renar": "rena",
    "renare": "ren",
    "renares": "ren",
    "renarna": "ren",
    "renarnas": "ren",
    "renars": "ren",
    "renas": "rena",
    "renast": "ren",
    "renaste": "ren",
    "renastes": "ren",
    "renasts": "ren",
    "renat": "rena",
    "renaten": "renat",
    "renatens": "renat",
    "renats": "renat",
    "renbenen": "renben",
    "renbenens": "renben",
    "renbenet": "renben",
    "renbenets": "renben",
    "renbens": "renben",
    "renderad": "rendera",
    "renderade": "rendera",
    "renderades": "rendera",
    "renderads": "rendera",
    "renderande": "rendera",
    "renderanden": "renderande",
    "renderandena": "renderande",
    "renderandenas": "renderande",
    "renderandens": "renderande",
    "renderandes": "renderande",
    "renderandet": "renderande",
    "renderandets": "renderande",
    "renderar": "rendera",
    "renderas": "rendera",
    "renderat": "rendera",
    "renderats": "rendera",
    "renderbara": "renderbar",
    "renderbarare": "renderbar",
    "renderbarares": "renderbar",
    "renderbaras": "renderbar",
    "renderbarast": "renderbar",
    "renderbaraste": "renderbar",
    "renderbarastes": "renderbar",
    "renderbarasts": "renderbar",
    "renderbare": "renderbar",
    "renderbares": "renderbar",
    "renderbarheten": "renderbarhet",
    "renderbarhetens": "renderbarhet",
    "renderbarhets": "renderbarhet",
    "renderbars": "renderbar",
    "renderbart": "renderbar",
    "renderbarts": "renderbar",
    "renderingar": "rendering",
    "renderingarna": "rendering",
    "renderingarnas": "rendering",
    "renderingars": "rendering",
    "renderingen": "rendering",
    "renderingens": "rendering",
    "renderings": "rendering",
    "rendezvouser": "rendezvous",
    "rendezvouserna": "rendezvous",
    "rendezvousernas": "rendezvous",
    "rendezvousers": "rendezvous",
    "rendezvouset": "rendezvous",
    "rendezvousets": "rendezvous",
    "rendriften": "rendrift",
    "rendriftens": "rendrift",
    "rendrifts": "rendrift",
    "rene": "ren",
    "renegaten": "renegat",
    "renegatens": "renegat",
    "renegater": "renegat",
    "renegaterna": "renegat",
    "renegaternas": "renegat",
    "renegaters": "renegat",
    "renegats": "renegat",
    "renen": "ren",
    "renens": "ren",
    "renes": "ren",
    "renfan": "renfana",
    "renfanan": "renfana",
    "renfanans": "renfana",
    "renfanas": "renfana",
    "renfane": "renfana",
    "renfanor": "renfana",
    "renfanorna": "renfana",
    "renfanornas": "renfana",
    "renfanors": "renfana",
    "renfans": "renfana",
    "renfällar": "renfäll",
    "renfällarna": "renfäll",
    "renfällarnas": "renfäll",
    "renfällars": "renfäll",
    "renfällen": "renfäll",
    "renfällens": "renfäll",
    "renfälls": "renfäll",
    "rengjord": "rengöra",
    "rengjorda": "rengöra",
    "rengjordas": "rengöra",
    "rengjorde": "rengöra",
    "rengjordes": "rengöra",
    "rengjords": "rengöra",
    "rengjort": "rengöra",
    "rengjorts": "rengöra",
    "rengör": "rengöra",
    "rengörande": "rengöra",
    "rengöranden": "rengörande",
    "rengörandena": "rengörande",
    "rengörandenas": "rengörande",
    "rengörandens": "rengörande",
    "rengörandes": "rengörande",
    "rengörandet": "rengörande",
    "rengörandets": "rengörande",
    "rengöras": "rengöra",
    "rengöres": "rengöra",
    "rengöringar": "rengöring",
    "rengöringarna": "rengöring",
    "rengöringarnas": "rengöring",
    "rengöringars": "rengöring",
    "rengöringen": "rengöring",
    "rengöringens": "rengöring",
    "rengörings": "rengöring",
    "rengöringsdukar": "rengöringsduk",
    "rengöringsdukarna": "rengöringsduk",
    "rengöringsdukarnas": "rengöringsduk",
    "rengöringsdukars": "rengöringsduk",
    "rengöringsduken": "rengöringsduk",
    "rengöringsdukens": "rengöringsduk",
    "rengöringsduks": "rengöringsduk",
    "rengöringsmedels": "rengöringsmedel",
    "rengöringsmedlen": "rengöringsmedel",
    "rengöringsmedlens": "rengöringsmedel",
    "rengöringsmedlet": "rengöringsmedel",
    "rengöringsmedlets": "rengöringsmedel",
    "rengöringssatsen": "rengöringssats",
    "rengöringssatsens": "rengöringssats",
    "rengöringssatser": "rengöringssats",
    "rengöringssatserna": "rengöringssats",
    "rengöringssatsernas": "rengöringssats",
    "rengöringssatsers": "rengöringssats",
    "rengöringssnör": "rengöringssnöre",
    "rengöringssnören": "rengöringssnöre",
    "rengöringssnörena": "rengöringssnöre",
    "rengöringssnörenas": "rengöringssnöre",
    "rengöringssnörens": "rengöringssnöre",
    "rengöringssnöres": "rengöringssnöre",
    "rengöringssnöret": "rengöringssnöre",
    "rengöringssnörets": "rengöringssnöre",
    "rengöringssnörs": "rengöringssnöre",
    "rengörs": "rengöra",
    "renheten": "renhet",
    "renhetens": "renhet",
    "renheter": "renhet",
    "renheterna": "renhet",
    "renheternas": "renhet",
    "renheters": "renhet",
    "renhets": "renhet",
    "renhetsdrömmar": "renhetsdröm",
    "renhetsdrömmarna": "renhetsdröm",
    "renhetsdrömmarnas": "renhetsdröm",
    "renhetsdrömmars": "renhetsdröm",
    "renhetsdrömmen": "renhetsdröm",
    "renhetsdrömmens": "renhetsdröm",
    "renhetsdröms": "renhetsdröm",
    "renhetslängtans": "renhetslängtan",
    "renhjordar": "renhjord",
    "renhjordarna": "renhjord",
    "renhjordarnas": "renhjord",
    "renhjordars": "renhjord",
    "renhjorden": "renhjord",
    "renhjordens": "renhjord",
    "renhjords": "renhjord",
    "renhjärtade": "renhjärtad",
    "renhjärtades": "renhjärtad",
    "renhjärtads": "renhjärtad",
    "renhjärtat": "renhjärtad",
    "renhjärtats": "renhjärtad",
    "renhornen": "renhorn",
    "renhornens": "renhorn",
    "renhornet": "renhorn",
    "renhornets": "renhorn",
    "renhorns": "renhorn",
    "renhållningar": "renhållning",
    "renhållningarna": "renhållning",
    "renhållningarnas": "renhållning",
    "renhållningars": "renhållning",
    "renhållningen": "renhållning",
    "renhållningens": "renhållning",
    "renhållnings": "renhållning",
    "renhållningsgubb": "renhållningsgubbe",
    "renhållningsgubbar": "renhållningsgubbe",
    "renhållningsgubbarna": "renhållningsgubbe",
    "renhållningsgubbarnas": "renhållningsgubbe",
    "renhållningsgubbars": "renhållningsgubbe",
    "renhållningsgubben": "renhållningsgubbe",
    "renhållningsgubbens": "renhållningsgubbe",
    "renhållningsgubbes": "renhållningsgubbe",
    "renhållningsgubbs": "renhållningsgubbe",
    "renhållningsmyndigheten": "renhållningsmyndighet",
    "renhållningsmyndighetens": "renhållningsmyndighet",
    "renhållningsmyndigheter": "renhållningsmyndighet",
    "renhållningsmyndigheterna": "renhållningsmyndighet",
    "renhållningsmyndigheternas": "renhållningsmyndighet",
    "renhållningsmyndigheters": "renhållningsmyndighet",
    "renhållningsmyndighets": "renhållningsmyndighet",
    "renhåriga": "renhårig",
    "renhårigare": "renhårig",
    "renhårigares": "renhårig",
    "renhårigas": "renhårig",
    "renhårigast": "renhårig",
    "renhårigaste": "renhårig",
    "renhårigastes": "renhårig",
    "renhårigasts": "renhårig",
    "renhårige": "renhårig",
    "renhåriges": "renhårig",
    "renhårigheten": "renhårighet",
    "renhårighetens": "renhårighet",
    "renhårighets": "renhårighet",
    "renhårigs": "renhårig",
    "renhårigt": "renhårig",
    "renhårigts": "renhårig",
    "reningar": "rening",
    "reningarna": "rening",
    "reningarnas": "rening",
    "reningars": "rening",
    "reningen": "rening",
    "reningens": "rening",
    "renings": "rening",
    "reningsverken": "reningsverk",
    "reningsverkens": "reningsverk",
    "reningsverket": "reningsverk",
    "reningsverkets": "reningsverk",
    "reningsverks": "reningsverk",
    "renjakten": "renjakt",
    "renjaktens": "renjakt",
    "renjakter": "renjakt",
    "renjakterna": "renjakt",
    "renjakternas": "renjakt",
    "renjakters": "renjakt",
    "renjakts": "renjakt",
    "renjägar": "renjägare",
    "renjägaren": "renjägare",
    "renjägarens": "renjägare",
    "renjägares": "renjägare",
    "renjägarna": "renjägare",
    "renjägarnas": "renjägare",
    "renkon": "renko",
    "renkons": "renko",
    "renkontern": "renkonter",
    "renkonterns": "renkonter",
    "renkonters": "renkonter",
    "renkonterstriden": "renkonterstrid",
    "renkonterstridens": "renkonterstrid",
    "renkonterstrider": "renkonterstrid",
    "renkonterstriderna": "renkonterstrid",
    "renkonterstridernas": "renkonterstrid",
    "renkonterstriders": "renkonterstrid",
    "renkonterstrids": "renkonterstrid",
    "renkontrer": "renkonter",
    "renkontrerna": "renkonter",
    "renkontrernas": "renkonter",
    "renkontrers": "renkonter",
    "renkor": "renko",
    "renkorna": "renko",
    "renkornas": "renko",
    "renkors": "renko",
    "renkos": "renko",
    "renköttet": "renkött",
    "renköttets": "renkött",
    "renkötts": "renkött",
    "renlavar": "renlav",
    "renlavarna": "renlav",
    "renlavarnas": "renlav",
    "renlavars": "renlav",
    "renlaven": "renlav",
    "renlavens": "renlav",
    "renlavs": "renlav",
    "renlevnaden": "renlevnad",
    "renlevnadens": "renlevnad",
    "renlevnader": "renlevnad",
    "renlevnaderna": "renlevnad",
    "renlevnadernas": "renlevnad",
    "renlevnaders": "renlevnad",
    "renlevnads": "renlevnad",
    "renlevnadsmannen": "renlevnadsman",
    "renlevnadsmannens": "renlevnadsman",
    "renlevnadsmans": "renlevnadsman",
    "renlevnadsmän": "renlevnadsman",
    "renlevnadsmännen": "renlevnadsman",
    "renlevnadsmännens": "renlevnadsman",
    "renlevnadsmäns": "renlevnadsman",
    "renliga": "renlig",
    "renligare": "renlig",
    "renligares": "renlig",
    "renligas": "renlig",
    "renligast": "renlig",
    "renligaste": "renlig",
    "renligastes": "renlig",
    "renligasts": "renlig",
    "renlige": "renlig",
    "renliges": "renlig",
    "renligheten": "renlighet",
    "renlighetens": "renlighet",
    "renligheter": "renlighet",
    "renligheterna": "renlighet",
    "renligheternas": "renlighet",
    "renligheters": "renlighet",
    "renlighets": "renlighet",
    "renligs": "renlig",
    "renligt": "renlig",
    "renligts": "renlig",
    "renläriga": "renlärig",
    "renlärigare": "renlärig",
    "renlärigares": "renlärig",
    "renlärigas": "renlärig",
    "renlärigast": "renlärig",
    "renlärigaste": "renlärig",
    "renlärigastes": "renlärig",
    "renlärigasts": "renlärig",
    "renlärige": "renlärig",
    "renläriges": "renlärig",
    "renlärigheten": "renlärighet",
    "renlärighetens": "renlärighet",
    "renlärigheter": "renlärighet",
    "renlärigheterna": "renlärighet",
    "renlärigheternas": "renlärighet",
    "renlärigheters": "renlärighet",
    "renlärighets": "renlärighet",
    "renlärighetsivern": "renlärighetsiver",
    "renlärighetsiverns": "renlärighetsiver",
    "renlärighetsivers": "renlärighetsiver",
    "renlärigs": "renlärig",
    "renlärigt": "renlärig",
    "renlärigts": "renlärig",
    "renmag": "renmage",
    "renmagar": "renmage",
    "renmagarna": "renmage",
    "renmagarnas": "renmage",
    "renmagars": "renmage",
    "renmagen": "renmage",
    "renmagens": "renmage",
    "renmages": "renmage",
    "renmags": "renmage",
    "renmärken": "renmärke",
    "renmärkena": "renmärke",
    "renmärkenas": "renmärke",
    "renmärkens": "renmärke",
    "renmärkes": "renmärke",
    "renmärket": "renmärke",
    "renmärkets": "renmärke",
    "renodlad": "renodla",
    "renodlade": "renodla",
    "renodlades": "renodla",
    "renodlads": "renodla",
    "renodlande": "renodla",
    "renodlanden": "renodlande",
    "renodlandena": "renodlande",
    "renodlandenas": "renodlande",
    "renodlandens": "renodlande",
    "renodlandes": "renodlande",
    "renodlandet": "renodlande",
    "renodlandets": "renodlande",
    "renodlar": "renodla",
    "renodlas": "renodla",
    "renodlat": "renodla",
    "renodlats": "renodla",
    "renommerade": "renommerad",
    "renommerades": "renommerad",
    "renommerads": "renommerad",
    "renommerat": "renommerad",
    "renommerats": "renommerad",
    "renomméet": "renommé",
    "renomméets": "renommé",
    "renommés": "renommé",
    "renommét": "renommé",
    "renomméts": "renommé",
    "renovationen": "renovation",
    "renovationens": "renovation",
    "renovationer": "renovation",
    "renovationerna": "renovation",
    "renovationernas": "renovation",
    "renovationers": "renovation",
    "renovations": "renovation",
    "renoverad": "renovera",
    "renoverade": "renovera",
    "renoverades": "renovera",
    "renoverads": "renovera",
    "renoverande": "renovera",
    "renoveranden": "renoverande",
    "renoverandena": "renoverande",
    "renoverandenas": "renoverande",
    "renoverandens": "renoverande",
    "renoverandes": "renoverande",
    "renoverandet": "renoverande",
    "renoverandets": "renoverande",
    "renoverar": "renovera",
    "renoveras": "renovera",
    "renoverat": "renovera",
    "renoverats": "renovera",
    "renoverbara": "renoverbar",
    "renoverbarare": "renoverbar",
    "renoverbarares": "renoverbar",
    "renoverbaras": "renoverbar",
    "renoverbarast": "renoverbar",
    "renoverbaraste": "renoverbar",
    "renoverbarastes": "renoverbar",
    "renoverbarasts": "renoverbar",
    "renoverbare": "renoverbar",
    "renoverbares": "renoverbar",
    "renoverbarheten": "renoverbarhet",
    "renoverbarhetens": "renoverbarhet",
    "renoverbarhets": "renoverbarhet",
    "renoverbars": "renoverbar",
    "renoverbart": "renoverbar",
    "renoverbarts": "renoverbar",
    "renoveringar": "renovering",
    "renoveringarna": "renovering",
    "renoveringarnas": "renovering",
    "renoveringars": "renovering",
    "renoveringen": "renovering",
    "renoveringens": "renovering",
    "renoverings": "renovering",
    "renox": "renoxe",
    "renoxar": "renoxe",
    "renoxarna": "renoxe",
    "renoxarnas": "renoxe",
    "renoxars": "renoxe",
    "renoxen": "renoxe",
    "renoxens": "renoxe",
    "renoxes": "renoxe",
    "renrak": "renraka",
    "renrakad": "renraka",
    "renrakade": "renraka",
    "renrakades": "renraka",
    "renrakads": "renraka",
    "renrakande": "renraka",
    "renrakanden": "renrakande",
    "renrakandena": "renrakande",
    "renrakandenas": "renrakande",
    "renrakandens": "renrakande",
    "renrakandes": "renrakande",
    "renrakandet": "renrakande",
    "renrakandets": "renrakande",
    "renrakar": "renraka",
    "renrakas": "renraka",
    "renrakat": "renraka",
    "renrakats": "renraka",
    "renrasiga": "renrasig",
    "renrasigare": "renrasig",
    "renrasigares": "renrasig",
    "renrasigas": "renrasig",
    "renrasigast": "renrasig",
    "renrasigaste": "renrasig",
    "renrasigastes": "renrasig",
    "renrasigasts": "renrasig",
    "renrasige": "renrasig",
    "renrasiges": "renrasig",
    "renrasigheten": "renrasighet",
    "renrasighetens": "renrasighet",
    "renrasighets": "renrasighet",
    "renrasigs": "renrasig",
    "renrasigt": "renrasig",
    "renrasigts": "renrasig",
    "rens": "rensa",
    "rensad": "rensa",
    "rensade": "rensa",
    "rensades": "rensa",
    "rensads": "rensa",
    "rensande": "rensa",
    "rensanden": "rensande",
    "rensandena": "rensande",
    "rensandenas": "rensande",
    "rensandens": "rensande",
    "rensandes": "rensande",
    "rensandet": "rensande",
    "rensandets": "rensande",
    "rensar": "rensa",
    "rensas": "rensa",
    "rensat": "rensa",
    "rensats": "rensa",
    "renserier": "renseri",
    "renserierna": "renseri",
    "renseriernas": "renseri",
    "renseriers": "renseri",
    "renseriet": "renseri",
    "renseriets": "renseri",
    "renseris": "renseri",
    "renserit": "renseri",
    "renserits": "renseri",
    "renskaven": "renskav",
    "renskavens": "renskav",
    "renskavet": "renskav",
    "renskavets": "renskav",
    "renskavs": "renskav",
    "renskiljningar": "renskiljning",
    "renskiljningarna": "renskiljning",
    "renskiljningarnas": "renskiljning",
    "renskiljningars": "renskiljning",
    "renskiljningen": "renskiljning",
    "renskiljningens": "renskiljning",
    "renskiljnings": "renskiljning",
    "renskinnen": "renskinn",
    "renskinnens": "renskinn",
    "renskinnet": "renskinn",
    "renskinnets": "renskinn",
    "renskinns": "renskinn",
    "renskinnspälsar": "renskinnspäls",
    "renskinnspälsarna": "renskinnspäls",
    "renskinnspälsarnas": "renskinnspäls",
    "renskinnspälsars": "renskinnspäls",
    "renskinnspälsen": "renskinnspäls",
    "renskinnspälsens": "renskinnspäls",
    "renskrev": "renskriva",
    "renskrevs": "renskriva",
    "renskriv": "renskriva",
    "renskrivande": "renskriva",
    "renskrivanden": "renskrivande",
    "renskrivandena": "renskrivande",
    "renskrivandenas": "renskrivande",
    "renskrivandens": "renskrivande",
    "renskrivandes": "renskrivande",
    "renskrivandet": "renskrivande",
    "renskrivandets": "renskrivande",
    "renskrivas": "renskriva",
    "renskrive": "renskriva",
    "renskriven": "renskriva",
    "renskrivens": "renskriva",
    "renskriver": "renskriva",
    "renskrives": "renskriva",
    "renskrivet": "renskriva",
    "renskrivets": "renskriva",
    "renskrivit": "renskriva",
    "renskrivits": "renskriva",
    "renskrivna": "renskriva",
    "renskrivnas": "renskriva",
    "renskrivne": "renskriva",
    "renskrivnes": "renskriva",
    "renskrivningar": "renskrivning",
    "renskrivningarna": "renskrivning",
    "renskrivningarnas": "renskrivning",
    "renskrivningars": "renskrivning",
    "renskrivningen": "renskrivning",
    "renskrivningens": "renskrivning",
    "renskrivnings": "renskrivning",
    "renskrivs": "renskriva",
    "renskötar": "renskötare",
    "renskötaren": "renskötare",
    "renskötarens": "renskötare",
    "renskötares": "renskötare",
    "renskötarna": "renskötare",
    "renskötarnas": "renskötare",
    "renskötseln": "renskötsel",
    "renskötselns": "renskötsel",
    "renskötsels": "renskötsel",
    "rensningar": "rensning",
    "rensningarna": "rensning",
    "rensningarnas": "rensning",
    "rensningars": "rensning",
    "rensningen": "rensning",
    "rensningens": "rensning",
    "rensnings": "rensning",
    "rensningsnålar": "rensningsnål",
    "rensningsnålarna": "rensningsnål",
    "rensningsnålarnas": "rensningsnål",
    "rensningsnålars": "rensningsnål",
    "rensningsnålen": "rensningsnål",
    "rensningsnålens": "rensningsnål",
    "rensningsnåls": "rensningsnål",
    "rensopade": "rensopad",
    "rensopades": "rensopad",
    "rensopads": "rensopad",
    "rensopat": "rensopad",
    "rensopats": "rensopad",
    "renspolade": "renspolad",
    "renspolades": "renspolad",
    "renspolads": "renspolad",
    "renspolat": "renspolad",
    "renspolats": "renspolad",
    "renstekar": "renstek",
    "renstekarna": "renstek",
    "renstekarnas": "renstek",
    "renstekars": "renstek",
    "rensteken": "renstek",
    "renstekens": "renstek",
    "rensteks": "renstek",
    "renstrattar": "renstratt",
    "renstrattarna": "renstratt",
    "renstrattarnas": "renstratt",
    "renstrattars": "renstratt",
    "renstratten": "renstratt",
    "renstrattens": "renstratt",
    "renstratts": "renstratt",
    "rent": "ren",
    "rentieren": "rentier",
    "rentierens": "rentier",
    "rentierer": "rentier",
    "rentiererna": "rentier",
    "rentierernas": "rentier",
    "rentierers": "rentier",
    "rentiers": "rentier",
    "rentjurar": "rentjur",
    "rentjurarna": "rentjur",
    "rentjurarnas": "rentjur",
    "rentjurars": "rentjur",
    "rentjuren": "rentjur",
    "rentjurens": "rentjur",
    "rentjurs": "rentjur",
    "rentjéer": "rentjé",
    "rentjéerna": "rentjé",
    "rentjéernas": "rentjé",
    "rentjéers": "rentjé",
    "rentjén": "rentjé",
    "rentjéns": "rentjé",
    "rentjés": "rentjé",
    "rentréer": "rentré",
    "rentréerna": "rentré",
    "rentréernas": "rentré",
    "rentréers": "rentré",
    "rentrén": "rentré",
    "rentréns": "rentré",
    "rentrés": "rentré",
    "rents": "ren",
    "rentvådd": "rentvå",
    "rentvådda": "rentvå",
    "rentvåddas": "rentvå",
    "rentvådde": "rentvå",
    "rentvåddes": "rentvå",
    "rentvådds": "rentvå",
    "rentvående": "rentvå",
    "rentvåenden": "rentvående",
    "rentvåendena": "rentvående",
    "rentvåendenas": "rentvående",
    "rentvåendens": "rentvående",
    "rentvåendes": "rentvående",
    "rentvåendet": "rentvående",
    "rentvåendets": "rentvående",
    "rentvår": "rentvå",
    "rentvås": "rentvå",
    "rentvått": "rentvå",
    "rentvåtts": "rentvå",
    "renässansarkitekturen": "renässansarkitektur",
    "renässansarkitekturens": "renässansarkitektur",
    "renässansarkitekturer": "renässansarkitektur",
    "renässansarkitekturerna": "renässansarkitektur",
    "renässansarkitekturernas": "renässansarkitektur",
    "renässansarkitekturers": "renässansarkitektur",
    "renässansarkitekturs": "renässansarkitektur",
    "renässansen": "renässans",
    "renässansens": "renässans",
    "renässanser": "renässans",
    "renässanserna": "renässans",
    "renässansernas": "renässans",
    "renässansers": "renässans",
    "renässanskonsten": "renässanskonst",
    "renässanskonstens": "renässanskonst",
    "renässanskonster": "renässanskonst",
    "renässanskonsterna": "renässanskonst",
    "renässanskonsternas": "renässanskonst",
    "renässanskonsters": "renässanskonst",
    "renässanskonsts": "renässanskonst",
    "renässansmänniskan": "renässansmänniska",
    "renässansmänniskans": "renässansmänniska",
    "renässansmänniskas": "renässansmänniska",
    "renässansmännisko": "renässansmänniska",
    "renässansmänniskor": "renässansmänniska",
    "renässansmänniskorna": "renässansmänniska",
    "renässansmänniskornas": "renässansmänniska",
    "renässansmänniskors": "renässansmänniska",
    "reolen": "reol",
    "reolens": "reol",
    "reoler": "reol",
    "reolerna": "reol",
    "reolernas": "reol",
    "reolers": "reol",
    "reologien": "reologi",
    "reologiens": "reologi",
    "reologin": "reologi",
    "reologins": "reologi",
    "reologis": "reologi",
    "reols": "reol",
    "reor": "rea",
    "reorganiserad": "reorganisera",
    "reorganiserade": "reorganisera",
    "reorganiserades": "reorganisera",
    "reorganiserads": "reorganisera",
    "reorganiserande": "reorganisera",
    "reorganiseranden": "reorganiserande",
    "reorganiserandena": "reorganiserande",
    "reorganiserandenas": "reorganiserande",
    "reorganiserandens": "reorganiserande",
    "reorganiserandes": "reorganiserande",
    "reorganiserandet": "reorganiserande",
    "reorganiserandets": "reorganiserande",
    "reorganiserar": "reorganisera",
    "reorganiseras": "reorganisera",
    "reorganiserat": "reorganisera",
    "reorganiserats": "reorganisera",
    "reorganiserbara": "reorganiserbar",
    "reorganiserbarare": "reorganiserbar",
    "reorganiserbarares": "reorganiserbar",
    "reorganiserbaras": "reorganiserbar",
    "reorganiserbarast": "reorganiserbar",
    "reorganiserbaraste": "reorganiserbar",
    "reorganiserbarastes": "reorganiserbar",
    "reorganiserbarasts": "reorganiserbar",
    "reorganiserbare": "reorganiserbar",
    "reorganiserbares": "reorganiserbar",
    "reorganiserbarheten": "reorganiserbarhet",
    "reorganiserbarhetens": "reorganiserbarhet",
    "reorganiserbarhets": "reorganiserbarhet",
    "reorganiserbars": "reorganiserbar",
    "reorganiserbart": "reorganiserbar",
    "reorganiserbarts": "reorganiserbar",
    "reorganiseringar": "reorganisering",
    "reorganiseringarna": "reorganisering",
    "reorganiseringarnas": "reorganisering",
    "reorganiseringars": "reorganisering",
    "reorganiseringen": "reorganisering",
    "reorganiseringens": "reorganisering",
    "reorganiserings": "reorganisering",
    "reorna": "rea",
    "reornas": "rea",
    "reors": "rea",
    "reostaten": "reostat",
    "reostatens": "reostat",
    "reostater": "reostat",
    "reostaterna": "reostat",
    "reostaternas": "reostat",
    "reostaters": "reostat",
    "reostats": "reostat",
    "rep": "repa",
    "repad": "repa",
    "repade": "repa",
    "repades": "repa",
    "repads": "repa",
    "repan": "repa",
    "repande": "repa",
    "repanden": "repande",
    "repandena": "repande",
    "repandenas": "repande",
    "repandens": "repande",
    "repandes": "repande",
    "repandet": "repande",
    "repandets": "repande",
    "repans": "repa",
    "repar": "repa",
    "reparabels": "reparabel",
    "reparabelt": "reparabel",
    "reparabelts": "reparabel",
    "reparabla": "reparabel",
    "reparablare": "reparabel",
    "reparablares": "reparabel",
    "reparablas": "reparabel",
    "reparablast": "reparabel",
    "reparablaste": "reparabel",
    "reparablastes": "reparabel",
    "reparablasts": "reparabel",
    "reparable": "reparabel",
    "reparables": "reparabel",
    "reparationen": "reparation",
    "reparationens": "reparation",
    "reparationer": "reparation",
    "reparationerna": "reparation",
    "reparationernas": "reparation",
    "reparationers": "reparation",
    "reparations": "reparation",
    "reparatören": "reparatör",
    "reparatörens": "reparatör",
    "reparatörer": "reparatör",
    "reparatörerna": "reparatör",
    "reparatörernas": "reparatör",
    "reparatörers": "reparatör",
    "reparatörs": "reparatör",
    "reparerad": "reparera",
    "reparerade": "reparera",
    "reparerades": "reparera",
    "reparerads": "reparera",
    "reparerande": "reparera",
    "repareranden": "reparerande",
    "reparerandena": "reparerande",
    "reparerandenas": "reparerande",
    "reparerandens": "reparerande",
    "reparerandes": "reparerande",
    "reparerandet": "reparerande",
    "reparerandets": "reparerande",
    "reparerar": "reparera",
    "repareras": "reparera",
    "reparerat": "reparera",
    "reparerats": "reparera",
    "reparerbara": "reparerbar",
    "reparerbarare": "reparerbar",
    "reparerbarares": "reparerbar",
    "reparerbaras": "reparerbar",
    "reparerbarast": "reparerbar",
    "reparerbaraste": "reparerbar",
    "reparerbarastes": "reparerbar",
    "reparerbarasts": "reparerbar",
    "reparerbare": "reparerbar",
    "reparerbares": "reparerbar",
    "reparerbarheten": "reparerbarhet",
    "reparerbarhetens": "reparerbarhet",
    "reparerbarhets": "reparerbarhet",
    "reparerbars": "reparerbar",
    "reparerbart": "reparerbar",
    "reparerbarts": "reparerbar",
    "repareringar": "reparering",
    "repareringarna": "reparering",
    "repareringarnas": "reparering",
    "repareringars": "reparering",
    "repareringen": "reparering",
    "repareringens": "reparering",
    "reparerings": "reparering",
    "repartiserad": "repartisera",
    "repartiserade": "repartisera",
    "repartiserades": "repartisera",
    "repartiserads": "repartisera",
    "repartiserande": "repartisera",
    "repartiseranden": "repartiserande",
    "repartiserandena": "repartiserande",
    "repartiserandenas": "repartiserande",
    "repartiserandens": "repartiserande",
    "repartiserandes": "repartiserande",
    "repartiserandet": "repartiserande",
    "repartiserandets": "repartiserande",
    "repartiserar": "repartisera",
    "repartiseras": "repartisera",
    "repartiserat": "repartisera",
    "repartiserats": "repartisera",
    "repartiserbara": "repartiserbar",
    "repartiserbarare": "repartiserbar",
    "repartiserbarares": "repartiserbar",
    "repartiserbaras": "repartiserbar",
    "repartiserbarast": "repartiserbar",
    "repartiserbaraste": "repartiserbar",
    "repartiserbarastes": "repartiserbar",
    "repartiserbarasts": "repartiserbar",
    "repartiserbare": "repartiserbar",
    "repartiserbares": "repartiserbar",
    "repartiserbarheten": "repartiserbarhet",
    "repartiserbarhetens": "repartiserbarhet",
    "repartiserbarhets": "repartiserbarhet",
    "repartiserbars": "repartiserbar",
    "repartiserbart": "repartiserbar",
    "repartiserbarts": "repartiserbar",
    "repartiseringar": "repartisering",
    "repartiseringarna": "repartisering",
    "repartiseringarnas": "repartisering",
    "repartiseringars": "repartisering",
    "repartiseringen": "repartisering",
    "repartiseringens": "repartisering",
    "repartiserings": "repartisering",
    "repartitionen": "repartition",
    "repartitionens": "repartition",
    "repartitioner": "repartition",
    "repartitionerna": "repartition",
    "repartitionernas": "repartition",
    "repartitioners": "repartition",
    "repartitions": "repartition",
    "repas": "repa",
    "repat": "repa",
    "repatrierad": "repatriera",
    "repatrierade": "repatriera",
    "repatrierades": "repatriera",
    "repatrierads": "repatriera",
    "repatrierande": "repatriera",
    "repatrieranden": "repatrierande",
    "repatrierandena": "repatrierande",
    "repatrierandenas": "repatrierande",
    "repatrierandens": "repatrierande",
    "repatrierandes": "repatrierande",
    "repatrierandet": "repatrierande",
    "repatrierandets": "repatrierande",
    "repatrierar": "repatriera",
    "repatrieras": "repatriera",
    "repatrierat": "repatriera",
    "repatrierats": "repatriera",
    "repatrierbara": "repatrierbar",
    "repatrierbarare": "repatrierbar",
    "repatrierbarares": "repatrierbar",
    "repatrierbaras": "repatrierbar",
    "repatrierbarast": "repatrierbar",
    "repatrierbaraste": "repatrierbar",
    "repatrierbarastes": "repatrierbar",
    "repatrierbarasts": "repatrierbar",
    "repatrierbare": "repatrierbar",
    "repatrierbares": "repatrierbar",
    "repatrierbarheten": "repatrierbarhet",
    "repatrierbarhetens": "repatrierbarhet",
    "repatrierbarhets": "repatrierbarhet",
    "repatrierbars": "repatrierbar",
    "repatrierbart": "repatrierbar",
    "repatrierbarts": "repatrierbar",
    "repatrieringar": "repatriering",
    "repatrieringarna": "repatriering",
    "repatrieringarnas": "repatriering",
    "repatrieringars": "repatriering",
    "repatrieringen": "repatriering",
    "repatrieringens": "repatriering",
    "repatrierings": "repatriering",
    "repats": "repa",
    "repborttagar": "repborttagare",
    "repborttagaren": "repborttagare",
    "repborttagarens": "repborttagare",
    "repborttagares": "repborttagare",
    "repborttagarna": "repborttagare",
    "repborttagarnas": "repborttagare",
    "repe": "repa",
    "repellerad": "repellera",
    "repellerade": "repellera",
    "repellerades": "repellera",
    "repellerads": "repellera",
    "repellerande": "repellera",
    "repelleranden": "repellerande",
    "repellerandena": "repellerande",
    "repellerandenas": "repellerande",
    "repellerandens": "repellerande",
    "repellerandes": "repellerande",
    "repellerandet": "repellerande",
    "repellerandets": "repellerande",
    "repellerar": "repellera",
    "repelleras": "repellera",
    "repellerat": "repellera",
    "repellerats": "repellera",
    "repellerbara": "repellerbar",
    "repellerbarare": "repellerbar",
    "repellerbarares": "repellerbar",
    "repellerbaras": "repellerbar",
    "repellerbarast": "repellerbar",
    "repellerbaraste": "repellerbar",
    "repellerbarastes": "repellerbar",
    "repellerbarasts": "repellerbar",
    "repellerbare": "repellerbar",
    "repellerbares": "repellerbar",
    "repellerbarheten": "repellerbarhet",
    "repellerbarhetens": "repellerbarhet",
    "repellerbarhets": "repellerbarhet",
    "repellerbars": "repellerbar",
    "repellerbart": "repellerbar",
    "repellerbarts": "repellerbar",
    "repelleringar": "repellering",
    "repelleringarna": "repellering",
    "repelleringarnas": "repellering",
    "repelleringars": "repellering",
    "repelleringen": "repellering",
    "repelleringens": "repellering",
    "repellerings": "repellering",
    "repen": "rep",
    "repens": "rep",
    "repertoaren": "repertoar",
    "repertoarens": "repertoar",
    "repertoarer": "repertoar",
    "repertoarerna": "repertoar",
    "repertoarernas": "repertoar",
    "repertoarers": "repertoar",
    "repertoarmässiga": "repertoarmässig",
    "repertoarmässigare": "repertoarmässig",
    "repertoarmässigares": "repertoarmässig",
    "repertoarmässigas": "repertoarmässig",
    "repertoarmässigast": "repertoarmässig",
    "repertoarmässigaste": "repertoarmässig",
    "repertoarmässigastes": "repertoarmässig",
    "repertoarmässigasts": "repertoarmässig",
    "repertoarmässige": "repertoarmässig",
    "repertoarmässiges": "repertoarmässig",
    "repertoarmässigs": "repertoarmässig",
    "repertoarmässigt": "repertoarmässig",
    "repertoarmässigts": "repertoarmässig",
    "repertoars": "repertoar",
    "repes": "repe",
    "repet": "repe",
    "repeterad": "repetera",
    "repeterade": "repetera",
    "repeterades": "repetera",
    "repeterads": "repetera",
    "repeterande": "repetera",
    "repeteranden": "repeterande",
    "repeterandena": "repeterande",
    "repeterandenas": "repeterande",
    "repeterandens": "repeterande",
    "repeterandes": "repeterande",
    "repeterandet": "repeterande",
    "repeterandets": "repeterande",
    "repeterar": "repetera",
    "repeteras": "repetera",
    "repeterat": "repetera",
    "repeterats": "repetera",
    "repeterbara": "repeterbar",
    "repeterbarare": "repeterbar",
    "repeterbarares": "repeterbar",
    "repeterbaras": "repeterbar",
    "repeterbarast": "repeterbar",
    "repeterbaraste": "repeterbar",
    "repeterbarastes": "repeterbar",
    "repeterbarasts": "repeterbar",
    "repeterbare": "repeterbar",
    "repeterbares": "repeterbar",
    "repeterbarheten": "repeterbarhet",
    "repeterbarhetens": "repeterbarhet",
    "repeterbarhets": "repeterbarhet",
    "repeterbars": "repeterbar",
    "repeterbart": "repeterbar",
    "repeterbarts": "repeterbar",
    "repetergevären": "repetergevär",
    "repetergevärens": "repetergevär",
    "repetergeväret": "repetergevär",
    "repetergevärets": "repetergevär",
    "repetergevärs": "repetergevär",
    "repeteringar": "repetering",
    "repeteringarna": "repetering",
    "repeteringarnas": "repetering",
    "repeteringars": "repetering",
    "repeteringen": "repetering",
    "repeteringens": "repetering",
    "repeterings": "repetering",
    "repetitionen": "repetition",
    "repetitionens": "repetition",
    "repetitioner": "repetition",
    "repetitionerna": "repetition",
    "repetitionernas": "repetition",
    "repetitioners": "repetition",
    "repetitions": "repetition",
    "repetitionslokalen": "repetitionslokal",
    "repetitionslokalens": "repetitionslokal",
    "repetitionslokaler": "repetitionslokal",
    "repetitionslokalerna": "repetitionslokal",
    "repetitionslokalernas": "repetitionslokal",
    "repetitionslokalers": "repetitionslokal",
    "repetitionslokals": "repetitionslokal",
    "repetitionsövningar": "repetitionsövning",
    "repetitionsövningarna": "repetitionsövning",
    "repetitionsövningarnas": "repetitionsövning",
    "repetitionsövningars": "repetitionsövning",
    "repetitionsövningen": "repetitionsövning",
    "repetitionsövningens": "repetitionsövning",
    "repetitionsövnings": "repetitionsövning",
    "repetitorie": "repetitorium",
    "repetitorier": "repetitorium",
    "repetitorierna": "repetitorium",
    "repetitoriernas": "repetitorium",
    "repetitoriers": "repetitorium",
    "repetitoriet": "repetitorium",
    "repetitoriets": "repetitorium",
    "repetitoriums": "repetitorium",
    "repetitören": "repetitör",
    "repetitörens": "repetitör",
    "repetitörer": "repetitör",
    "repetitörerna": "repetitör",
    "repetitörernas": "repetitör",
    "repetitörers": "repetitör",
    "repetitörs": "repetitör",
    "repets": "repe",
    "repiga": "repig",
    "repigare": "repig",
    "repigares": "repig",
    "repigas": "repig",
    "repigast": "repig",
    "repigaste": "repig",
    "repigastes": "repig",
    "repigasts": "repig",
    "repige": "repig",
    "repiges": "repig",
    "repigs": "repig",
    "repigt": "repig",
    "repigts": "repig",
    "replierade": "repliera",
    "replierades": "repliera",
    "replierande": "repliera",
    "replieranden": "replierande",
    "replierandena": "replierande",
    "replierandenas": "replierande",
    "replierandens": "replierande",
    "replierandes": "replierande",
    "replierandet": "replierande",
    "replierandets": "replierande",
    "replierar": "repliera",
    "replieras": "repliera",
    "replierat": "repliera",
    "replierats": "repliera",
    "replieringar": "repliering",
    "replieringarna": "repliering",
    "replieringarnas": "repliering",
    "replieringars": "repliering",
    "replieringen": "repliering",
    "replieringens": "repliering",
    "replierings": "repliering",
    "repliken": "replik",
    "replikens": "replik",
    "repliker": "replik",
    "replikerade": "replikera",
    "replikerades": "replikera",
    "replikerande": "replikera",
    "replikeranden": "replikerande",
    "replikerandena": "replikerande",
    "replikerandenas": "replikerande",
    "replikerandens": "replikerande",
    "replikerandes": "replikerande",
    "replikerandet": "replikerande",
    "replikerandets": "replikerande",
    "replikerar": "replikera",
    "replikeras": "replikera",
    "replikerat": "replikera",
    "replikerats": "replikera",
    "replikeringar": "replikering",
    "replikeringarna": "replikering",
    "replikeringarnas": "replikering",
    "replikeringars": "replikering",
    "replikeringen": "replikering",
    "replikeringens": "replikering",
    "replikerings": "replikering",
    "replikerna": "replik",
    "replikernas": "replik",
    "replikers": "replik",
    "repliks": "replik",
    "replipunkten": "replipunkt",
    "replipunktens": "replipunkt",
    "replipunkter": "replipunkt",
    "replipunkterna": "replipunkt",
    "replipunkternas": "replipunkt",
    "replipunkters": "replipunkt",
    "replipunkts": "replipunkt",
    "replokalen": "replokal",
    "replokalens": "replokal",
    "replokaler": "replokal",
    "replokalerna": "replokal",
    "replokalernas": "replokal",
    "replokalers": "replokal",
    "replokals": "replokal",
    "repmånaden": "repmånad",
    "repmånadens": "repmånad",
    "repmånader": "repmånad",
    "repmånaderna": "repmånad",
    "repmånadernas": "repmånad",
    "repmånaders": "repmånad",
    "repmånads": "repmånad",
    "repor": "repa",
    "reporna": "repa",
    "repornas": "repa",
    "repors": "repa",
    "reportageboken": "reportagebok",
    "reportagebokens": "reportagebok",
    "reportageboks": "reportagebok",
    "reportageböcker": "reportagebok",
    "reportageböckerna": "reportagebok",
    "reportageböckernas": "reportagebok",
    "reportageböckers": "reportagebok",
    "reportagemässiga": "reportagemässig",
    "reportagemässigare": "reportagemässig",
    "reportagemässigares": "reportagemässig",
    "reportagemässigas": "reportagemässig",
    "reportagemässigast": "reportagemässig",
    "reportagemässigaste": "reportagemässig",
    "reportagemässigastes": "reportagemässig",
    "reportagemässigasts": "reportagemässig",
    "reportagemässige": "reportagemässig",
    "reportagemässiges": "reportagemässig",
    "reportagemässigs": "reportagemässig",
    "reportagemässigt": "reportagemässig",
    "reportagemässigts": "reportagemässig",
    "reportagen": "reportage",
    "reportagens": "reportage",
    "reportages": "reportage",
    "reportaget": "reportage",
    "reportagets": "reportage",
    "reporterlegenden": "reporterlegend",
    "reporterlegendens": "reporterlegend",
    "reporterlegender": "reporterlegend",
    "reporterlegenderna": "reporterlegend",
    "reporterlegendernas": "reporterlegend",
    "reporterlegenders": "reporterlegend",
    "reporterlegends": "reporterlegend",
    "reportern": "reporter",
    "reporterns": "reporter",
    "reporters": "reporter",
    "reportrar": "reporter",
    "reportrarna": "reporter",
    "reportrarnas": "reporter",
    "reportrars": "reporter",
    "representanten": "representant",
    "representantens": "representant",
    "representanter": "representant",
    "representanterna": "representant",
    "representanternas": "representant",
    "representanters": "representant",
    "representanthuset": "representanthus",
    "representanthusets": "representanthus",
    "representants": "representant",
    "representationen": "representation",
    "representationens": "representation",
    "representationer": "representation",
    "representationerna": "representation",
    "representationernas": "representation",
    "representationers": "representation",
    "representations": "representation",
    "representativa": "representativ",
    "representativare": "representativ",
    "representativares": "representativ",
    "representativas": "representativ",
    "representativast": "representativ",
    "representativaste": "representativ",
    "representativastes": "representativ",
    "representativasts": "representativ",
    "representative": "representativ",
    "representatives": "representativ",
    "representativs": "representativ",
    "representativt": "representativ",
    "representativts": "representativ",
    "representerad": "representera",
    "representerade": "representera",
    "representerades": "representera",
    "representerads": "representera",
    "representerande": "representera",
    "representeranden": "representerande",
    "representerandena": "representerande",
    "representerandenas": "representerande",
    "representerandens": "representerande",
    "representerandes": "representerande",
    "representerandet": "representerande",
    "representerandets": "representerande",
    "representerar": "representera",
    "representeras": "representera",
    "representerat": "representera",
    "representerats": "representera",
    "representerbara": "representerbar",
    "representerbarare": "representerbar",
    "representerbarares": "representerbar",
    "representerbaras": "representerbar",
    "representerbarast": "representerbar",
    "representerbaraste": "representerbar",
    "representerbarastes": "representerbar",
    "representerbarasts": "representerbar",
    "representerbare": "representerbar",
    "representerbares": "representerbar",
    "representerbarheten": "representerbarhet",
    "representerbarhetens": "representerbarhet",
    "representerbarhets": "representerbarhet",
    "representerbars": "representerbar",
    "representerbart": "representerbar",
    "representerbarts": "representerbar",
    "representeringar": "representering",
    "representeringarna": "representering",
    "representeringarnas": "representering",
    "representeringars": "representering",
    "representeringen": "representering",
    "representeringens": "representering",
    "representerings": "representering",
    "repressalien": "repressalie",
    "repressaliens": "repressalie",
    "repressalier": "repressalie",
    "repressalierna": "repressalie",
    "repressaliernas": "repressalie",
    "repressaliers": "repressalie",
    "repressalies": "repressalie",
    "repressionen": "repression",
    "repressionens": "repression",
    "repressioner": "repression",
    "repressionerna": "repression",
    "repressionernas": "repression",
    "repressioners": "repression",
    "repressions": "repression",
    "repressiva": "repressiv",
    "repressivare": "repressiv",
    "repressivares": "repressiv",
    "repressivas": "repressiv",
    "repressivast": "repressiv",
    "repressivaste": "repressiv",
    "repressivastes": "repressiv",
    "repressivasts": "repressiv",
    "repressive": "repressiv",
    "repressives": "repressiv",
    "repressivs": "repressiv",
    "repressivt": "repressiv",
    "repressivts": "repressiv",
    "reprimanden": "reprimand",
    "reprimandens": "reprimand",
    "reprimander": "reprimand",
    "reprimanderna": "reprimand",
    "reprimandernas": "reprimand",
    "reprimanders": "reprimand",
    "reprimands": "reprimand",
    "reprisen": "repris",
    "reprisens": "repris",
    "repriser": "repris",
    "repriserad": "reprisera",
    "repriserade": "reprisera",
    "repriserades": "reprisera",
    "repriserads": "reprisera",
    "repriserande": "reprisera",
    "repriseranden": "repriserande",
    "repriserandena": "repriserande",
    "repriserandenas": "repriserande",
    "repriserandens": "repriserande",
    "repriserandes": "repriserande",
    "repriserandet": "repriserande",
    "repriserandets": "repriserande",
    "repriserar": "reprisera",
    "repriseras": "reprisera",
    "repriserat": "reprisera",
    "repriserats": "reprisera",
    "repriserbara": "repriserbar",
    "repriserbarare": "repriserbar",
    "repriserbarares": "repriserbar",
    "repriserbaras": "repriserbar",
    "repriserbarast": "repriserbar",
    "repriserbaraste": "repriserbar",
    "repriserbarastes": "repriserbar",
    "repriserbarasts": "repriserbar",
    "repriserbare": "repriserbar",
    "repriserbares": "repriserbar",
    "repriserbarheten": "repriserbarhet",
    "repriserbarhetens": "repriserbarhet",
    "repriserbarhets": "repriserbarhet",
    "repriserbars": "repriserbar",
    "repriserbart": "repriserbar",
    "repriserbarts": "repriserbar",
    "repriseringar": "reprisering",
    "repriseringarna": "reprisering",
    "repriseringarnas": "reprisering",
    "repriseringars": "reprisering",
    "repriseringen": "reprisering",
    "repriseringens": "reprisering",
    "repriserings": "reprisering",
    "repriserna": "repris",
    "reprisernas": "repris",
    "reprisers": "repris",
    "repristeckens": "repristecken",
    "repristecknen": "repristecken",
    "repristecknens": "repristecken",
    "repristecknet": "repristecken",
    "repristecknets": "repristecken",
    "reproducerad": "reproducera",
    "reproducerade": "reproducera",
    "reproducerades": "reproducera",
    "reproducerads": "reproducera",
    "reproducerande": "reproducera",
    "reproduceranden": "reproducerande",
    "reproducerandena": "reproducerande",
    "reproducerandenas": "reproducerande",
    "reproducerandens": "reproducerande",
    "reproducerandes": "reproducerande",
    "reproducerandet": "reproducerande",
    "reproducerandets": "reproducerande",
    "reproducerar": "reproducera",
    "reproduceras": "reproducera",
    "reproducerat": "reproducera",
    "reproducerats": "reproducera",
    "reproducerbara": "reproducerbar",
    "reproducerbarare": "reproducerbar",
    "reproducerbarares": "reproducerbar",
    "reproducerbaras": "reproducerbar",
    "reproducerbarast": "reproducerbar",
    "reproducerbaraste": "reproducerbar",
    "reproducerbarastes": "reproducerbar",
    "reproducerbarasts": "reproducerbar",
    "reproducerbare": "reproducerbar",
    "reproducerbares": "reproducerbar",
    "reproducerbarheten": "reproducerbarhet",
    "reproducerbarhetens": "reproducerbarhet",
    "reproducerbarhets": "reproducerbarhet",
    "reproducerbars": "reproducerbar",
    "reproducerbart": "reproducerbar",
    "reproducerbarts": "reproducerbar",
    "reproduceringar": "reproducering",
    "reproduceringarna": "reproducering",
    "reproduceringarnas": "reproducering",
    "reproduceringars": "reproducering",
    "reproduceringen": "reproducering",
    "reproduceringens": "reproducering",
    "reproducerings": "reproducering",
    "reproduktionen": "reproduktion",
    "reproduktionens": "reproduktion",
    "reproduktioner": "reproduktion",
    "reproduktionerna": "reproduktion",
    "reproduktionernas": "reproduktion",
    "reproduktioners": "reproduktion",
    "reproduktions": "reproduktion",
    "reprografien": "reprografi",
    "reprografiens": "reprografi",
    "reprografin": "reprografi",
    "reprografins": "reprografi",
    "reprografis": "reprografi",
    "reps": "repa",
    "repslagar": "repslagare",
    "repslagaren": "repslagare",
    "repslagarens": "repslagare",
    "repslagares": "repslagare",
    "repslagarna": "repslagare",
    "repslagarnas": "repslagare",
    "repsteg": "repstege",
    "repstegar": "repstege",
    "repstegarna": "repstege",
    "repstegarnas": "repstege",
    "repstegars": "repstege",
    "repstegen": "repstege",
    "repstegens": "repstege",
    "repsteges": "repstege",
    "repstegs": "repstege",
    "reptilen": "reptil",
    "reptilens": "reptil",
    "reptiler": "reptil",
    "reptilerna": "reptil",
    "reptilernas": "reptil",
    "reptilers": "reptil",
    "reptilhjärn": "reptilhjärna",
    "reptilhjärnan": "reptilhjärna",
    "reptilhjärnans": "reptilhjärna",
    "reptilhjärnas": "reptilhjärna",
    "reptilhjärne": "reptilhjärna",
    "reptilhjärnor": "reptilhjärna",
    "reptilhjärnorna": "reptilhjärna",
    "reptilhjärnornas": "reptilhjärna",
    "reptilhjärnors": "reptilhjärna",
    "reptilhjärns": "reptilhjärna",
    "reptils": "reptil",
    "reptricket": "reptrick",
    "reptrickets": "reptrick",
    "reptricks": "reptrick",
    "republikanen": "republikan",
    "republikanens": "republikan",
    "republikaner": "republikan",
    "republikanerna": "republikan",
    "republikanernas": "republikan",
    "republikaners": "republikan",
    "republikans": "republikan",
    "republikanska": "republikansk",
    "republikanskare": "republikansk",
    "republikanskares": "republikansk",
    "republikanskas": "republikansk",
    "republikanskast": "republikansk",
    "republikanskaste": "republikansk",
    "republikanskastes": "republikansk",
    "republikanskasts": "republikansk",
    "republikanske": "republikansk",
    "republikanskes": "republikansk",
    "republikansks": "republikansk",
    "republikanskt": "republikansk",
    "republikanskts": "republikansk",
    "republiken": "republik",
    "republikens": "republik",
    "republiker": "republik",
    "republikerna": "republik",
    "republikernas": "republik",
    "republikers": "republik",
    "republiks": "republik",
    "repulsionen": "repulsion",
    "repulsionens": "repulsion",
    "repulsioner": "repulsion",
    "repulsionerna": "repulsion",
    "repulsionernas": "repulsion",
    "repulsioners": "repulsion",
    "repulsions": "repulsion",
    "repulsiva": "repulsiv",
    "repulsivare": "repulsiv",
    "repulsivares": "repulsiv",
    "repulsivas": "repulsiv",
    "repulsivast": "repulsiv",
    "repulsivaste": "repulsiv",
    "repulsivastes": "repulsiv",
    "repulsivasts": "repulsiv",
    "repulsive": "repulsiv",
    "repulsives": "repulsiv",
    "repulsivs": "repulsiv",
    "repulsivt": "repulsiv",
    "repulsivts": "repulsiv",
    "reputationen": "reputation",
    "reputationens": "reputation",
    "reputationer": "reputation",
    "reputationerna": "reputation",
    "reputationernas": "reputation",
    "reputationers": "reputation",
    "reputations": "reputation",
    "reputerliga": "reputerlig",
    "reputerligare": "reputerlig",
    "reputerligares": "reputerlig",
    "reputerligas": "reputerlig",
    "reputerligast": "reputerlig",
    "reputerligaste": "reputerlig",
    "reputerligastes": "reputerlig",
    "reputerligasts": "reputerlig",
    "reputerlige": "reputerlig",
    "reputerliges": "reputerlig",
    "reputerligheten": "reputerlighet",
    "reputerlighetens": "reputerlighet",
    "reputerlighets": "reputerlighet",
    "reputerligs": "reputerlig",
    "reputerligt": "reputerlig",
    "reputerligts": "reputerlig",
    "repänd": "repända",
    "repändan": "repända",
    "repändans": "repända",
    "repändar": "repände",
    "repändarna": "repände",
    "repändarnas": "repände",
    "repändars": "repände",
    "repändas": "repända",
    "repände": "repända",
    "repänden": "repände",
    "repändens": "repände",
    "repändes": "repände",
    "repändor": "repända",
    "repändorna": "repända",
    "repändornas": "repända",
    "repändors": "repända",
    "repänds": "repända",
    "repövningar": "repövning",
    "repövningarna": "repövning",
    "repövningarnas": "repövning",
    "repövningars": "repövning",
    "repövningen": "repövning",
    "repövningens": "repövning",
    "repövnings": "repövning",
    "res": "rese",
    "resan": "resa",
    "resande": "resa",
    "resandeboken": "resandebok",
    "resandebokens": "resandebok",
    "resandeboks": "resandebok",
    "resandeböcker": "resandebok",
    "resandeböckerna": "resandebok",
    "resandeböckernas": "resandebok",
    "resandeböckers": "resandebok",
    "resanden": "resande",
    "resandena": "resande",
    "resandenas": "resande",
    "resandens": "resande",
    "resandes": "resande",
    "resandet": "resande",
    "resandets": "resande",
    "resans": "resa",
    "resar": "rese",
    "resarna": "rese",
    "resarnas": "rese",
    "resars": "rese",
    "resas": "resa",
    "rese": "resa",
    "researchen": "research",
    "researchens": "research",
    "researcher": "research",
    "researchern": "researcher",
    "researcherna": "researcher",
    "researchernas": "researcher",
    "researcherns": "researcher",
    "researchers": "researcher",
    "researchersarna": "researcher",
    "researchersarnas": "researcher",
    "researchersen": "researcher",
    "researchersens": "researcher",
    "researchs": "research",
    "resebadkaren": "resebadkar",
    "resebadkarens": "resebadkar",
    "resebadkaret": "resebadkar",
    "resebadkarets": "resebadkar",
    "resebadkars": "resebadkar",
    "resebiljetten": "resebiljett",
    "resebiljettens": "resebiljett",
    "resebiljetter": "resebiljett",
    "resebiljetterna": "resebiljett",
    "resebiljetternas": "resebiljett",
    "resebiljetters": "resebiljett",
    "resebiljetts": "resebiljett",
    "resebyråer": "resebyrå",
    "resebyråerna": "resebyrå",
    "resebyråernas": "resebyrå",
    "resebyråers": "resebyrå",
    "resebyrån": "resebyrå",
    "resebyråns": "resebyrå",
    "resebyrås": "resebyrå",
    "resecheckar": "resecheck",
    "resecheckarna": "resecheck",
    "resecheckarnas": "resecheck",
    "resecheckars": "resecheck",
    "resechecken": "resecheck",
    "resecheckens": "resecheck",
    "resechecker": "resecheck",
    "resecheckerna": "resecheck",
    "resecheckernas": "resecheck",
    "resecheckers": "resecheck",
    "resechecks": "resecheck",
    "resed": "reseda",
    "resedan": "reseda",
    "resedans": "reseda",
    "resedas": "reseda",
    "resede": "reseda",
    "resedor": "reseda",
    "resedorna": "reseda",
    "resedornas": "reseda",
    "resedors": "reseda",
    "reseds": "reseda",
    "reseffekt": "reseffekter",
    "reseffekterna": "reseffekter",
    "reseffekternas": "reseffekter",
    "reseffekters": "reseffekter",
    "reseffekts": "reseffekter",
    "reseförbuden": "reseförbud",
    "reseförbudens": "reseförbud",
    "reseförbudet": "reseförbud",
    "reseförbudets": "reseförbud",
    "reseförbuds": "reseförbud",
    "resegarderoben": "resegarderob",
    "resegarderobens": "resegarderob",
    "resegarderober": "resegarderob",
    "resegarderoberna": "resegarderob",
    "resegarderobernas": "resegarderob",
    "resegarderobers": "resegarderob",
    "resegarderobs": "resegarderob",
    "resegrammofonen": "resegrammofon",
    "resegrammofonens": "resegrammofon",
    "resegrammofoner": "resegrammofon",
    "resegrammofonerna": "resegrammofon",
    "resegrammofonernas": "resegrammofon",
    "resegrammofoners": "resegrammofon",
    "resegrammofons": "resegrammofon",
    "reseguiden": "reseguide",
    "reseguidens": "reseguide",
    "reseguider": "reseguide",
    "reseguiderna": "reseguide",
    "reseguidernas": "reseguide",
    "reseguiders": "reseguide",
    "reseguides": "reseguide",
    "resehandboken": "resehandbok",
    "resehandbokens": "resehandbok",
    "resehandboks": "resehandbok",
    "resehandböcker": "resehandbok",
    "resehandböckerna": "resehandbok",
    "resehandböckernas": "resehandbok",
    "resehandböckers": "resehandbok",
    "resekreditiven": "resekreditiv",
    "resekreditivens": "resekreditiv",
    "resekreditivet": "resekreditiv",
    "resekreditivets": "resekreditiv",
    "resekreditivs": "resekreditiv",
    "resektionen": "resektion",
    "resektionens": "resektion",
    "resektioner": "resektion",
    "resektionerna": "resektion",
    "resektionernas": "resektion",
    "resektioners": "resektion",
    "resektions": "resektion",
    "reseledar": "reseledare",
    "reseledaren": "reseledare",
    "reseledarens": "reseledare",
    "reseledares": "reseledare",
    "reseledarna": "reseledare",
    "reseledarnas": "reseledare",
    "resemuggar": "resemugg",
    "resemuggarna": "resemugg",
    "resemuggarnas": "resemugg",
    "resemuggars": "resemugg",
    "resemuggen": "resemugg",
    "resemuggens": "resemugg",
    "resemuggs": "resemugg",
    "resen": "rese",
    "resens": "rese",
    "resenären": "resenär",
    "resenärens": "resenär",
    "resenärer": "resenär",
    "resenärerna": "resenär",
    "resenärernas": "resenär",
    "resenärers": "resenär",
    "resenärs": "resenär",
    "reser": "resa",
    "resereportagen": "resereportage",
    "resereportagens": "resereportage",
    "resereportages": "resereportage",
    "resereportaget": "resereportage",
    "resereportagets": "resereportage",
    "reservanten": "reservant",
    "reservantens": "reservant",
    "reservanter": "reservant",
    "reservanterna": "reservant",
    "reservanternas": "reservant",
    "reservanters": "reservant",
    "reservants": "reservant",
    "reservar": "reservare",
    "reservaren": "reservare",
    "reservarens": "reservare",
    "reservares": "reservare",
    "reservarna": "reservare",
    "reservarnas": "reservare",
    "reservaten": "reservat",
    "reservatens": "reservat",
    "reservatet": "reservat",
    "reservatets": "reservat",
    "reservationen": "reservation",
    "reservationens": "reservation",
    "reservationer": "reservation",
    "reservationerna": "reservation",
    "reservationernas": "reservation",
    "reservationers": "reservation",
    "reservations": "reservation",
    "reservats": "reservat",
    "reservdelar": "reservdel",
    "reservdelarna": "reservdel",
    "reservdelarnas": "reservdel",
    "reservdelars": "reservdel",
    "reservdelen": "reservdel",
    "reservdelens": "reservdel",
    "reservdels": "reservdel",
    "reserven": "reserv",
    "reservens": "reserv",
    "reserver": "reserv",
    "reserverad": "reservera",
    "reserverade": "reserverad",
    "reserverades": "reserverad",
    "reserverads": "reserverad",
    "reserverande": "reservera",
    "reserveranden": "reserverande",
    "reserverandena": "reserverande",
    "reserverandenas": "reserverande",
    "reserverandens": "reserverande",
    "reserverandes": "reserverande",
    "reserverandet": "reserverande",
    "reserverandets": "reserverande",
    "reserverar": "reservera",
    "reserveras": "reservera",
    "reserverat": "reserverad",
    "reserverats": "reserverad",
    "reserverbara": "reserverbar",
    "reserverbarare": "reserverbar",
    "reserverbarares": "reserverbar",
    "reserverbaras": "reserverbar",
    "reserverbarast": "reserverbar",
    "reserverbaraste": "reserverbar",
    "reserverbarastes": "reserverbar",
    "reserverbarasts": "reserverbar",
    "reserverbare": "reserverbar",
    "reserverbares": "reserverbar",
    "reserverbarheten": "reserverbarhet",
    "reserverbarhetens": "reserverbarhet",
    "reserverbarhets": "reserverbarhet",
    "reserverbars": "reserverbar",
    "reserverbart": "reserverbar",
    "reserverbarts": "reserverbar",
    "reserveringar": "reservering",
    "reserveringarna": "reservering",
    "reserveringarnas": "reservering",
    "reserveringars": "reservering",
    "reserveringen": "reservering",
    "reserveringens": "reservering",
    "reserverings": "reservering",
    "reserverna": "reserv",
    "reservernas": "reserv",
    "reservers": "reserv",
    "reservlagerna": "reservlager",
    "reservlagernas": "reservlager",
    "reservlagers": "reservlager",
    "reservlagren": "reservlager",
    "reservlagrens": "reservlager",
    "reservlagret": "reservlager",
    "reservlagrets": "reservlager",
    "reservnäringar": "reservnäring",
    "reservnäringarna": "reservnäring",
    "reservnäringarnas": "reservnäring",
    "reservnäringars": "reservnäring",
    "reservnäringen": "reservnäring",
    "reservnäringens": "reservnäring",
    "reservnärings": "reservnäring",
    "reservoaren": "reservoar",
    "reservoarens": "reservoar",
    "reservoarer": "reservoar",
    "reservoarerna": "reservoar",
    "reservoarernas": "reservoar",
    "reservoarers": "reservoar",
    "reservoarpenn": "reservoarpenna",
    "reservoarpennan": "reservoarpenna",
    "reservoarpennans": "reservoarpenna",
    "reservoarpennas": "reservoarpenna",
    "reservoarpenne": "reservoarpenna",
    "reservoarpennor": "reservoarpenna",
    "reservoarpennorna": "reservoarpenna",
    "reservoarpennornas": "reservoarpenna",
    "reservoarpennors": "reservoarpenna",
    "reservoarpenns": "reservoarpenna",
    "reservoars": "reservoar",
    "reservofficerare": "reservofficer",
    "reservofficerares": "reservofficer",
    "reservofficerarna": "reservofficer",
    "reservofficerarnas": "reservofficer",
    "reservofficeren": "reservofficer",
    "reservofficerens": "reservofficer",
    "reservofficern": "reservofficer",
    "reservofficerns": "reservofficer",
    "reservofficers": "reservofficer",
    "reservpappan": "reservpappa",
    "reservpappans": "reservpappa",
    "reservpappas": "reservpappa",
    "reservpappor": "reservpappa",
    "reservpapporna": "reservpappa",
    "reservpappornas": "reservpappa",
    "reservpappors": "reservpappa",
    "reservs": "reserv",
    "reservspelar": "reservspelare",
    "reservspelaren": "reservspelare",
    "reservspelarens": "reservspelare",
    "reservspelares": "reservspelare",
    "reservspelarna": "reservspelare",
    "reservspelarnas": "reservspelare",
    "reseräkningar": "reseräkning",
    "reseräkningarna": "reseräkning",
    "reseräkningarnas": "reseräkning",
    "reseräkningars": "reseräkning",
    "reseräkningen": "reseräkning",
    "reseräkningens": "reseräkning",
    "reseräknings": "reseräkning",
    "reses": "rese",
    "reseskildringar": "reseskildring",
    "reseskildringarna": "reseskildring",
    "reseskildringarnas": "reseskildring",
    "reseskildringars": "reseskildring",
    "reseskildringen": "reseskildring",
    "reseskildringens": "reseskildring",
    "reseskildrings": "reseskildring",
    "reseskrivmaskinen": "reseskrivmaskin",
    "reseskrivmaskinens": "reseskrivmaskin",
    "reseskrivmaskiner": "reseskrivmaskin",
    "reseskrivmaskinerna": "reseskrivmaskin",
    "reseskrivmaskinernas": "reseskrivmaskin",
    "reseskrivmaskiners": "reseskrivmaskin",
    "reseskrivmaskins": "reseskrivmaskin",
    "resetillbehören": "resetillbehör",
    "resetillbehörens": "resetillbehör",
    "resetillbehöret": "resetillbehör",
    "resetillbehörets": "resetillbehör",
    "resetillbehörs": "resetillbehör",
    "resfebern": "resfeber",
    "resfeberns": "resfeber",
    "resfebers": "resfeber",
    "resgodset": "resgods",
    "resgodsets": "resgods",
    "resguiden": "resguide",
    "resguidens": "resguide",
    "resguider": "resguide",
    "resguiderna": "resguide",
    "resguidernas": "resguide",
    "resguiders": "resguide",
    "resguides": "resguide",
    "residensen": "residens",
    "residensens": "residens",
    "residenset": "residens",
    "residensets": "residens",
    "residensstaden": "residensstad",
    "residensstadens": "residensstad",
    "residensstads": "residensstad",
    "residensstan": "residensstad",
    "residensstans": "residensstad",
    "residensstäder": "residensstad",
    "residensstäderna": "residensstad",
    "residensstädernas": "residensstad",
    "residensstäders": "residensstad",
    "residerade": "residera",
    "residerades": "residera",
    "residerande": "residera",
    "resideranden": "residerande",
    "residerandena": "residerande",
    "residerandenas": "residerande",
    "residerandens": "residerande",
    "residerandes": "residerande",
    "residerandet": "residerande",
    "residerandets": "residerande",
    "residerar": "residera",
    "resideras": "residera",
    "residerat": "residera",
    "residerats": "residera",
    "residua": "residuum",
    "residuana": "residuum",
    "residuanas": "residuum",
    "residuas": "residuum",
    "residue": "residuum",
    "residuer": "residuum",
    "residuerna": "residuum",
    "residuernas": "residuum",
    "residuers": "residuum",
    "residuet": "residuum",
    "residuets": "residuum",
    "residuums": "residuum",
    "resignationen": "resignation",
    "resignationens": "resignation",
    "resignationer": "resignation",
    "resignationerna": "resignation",
    "resignationernas": "resignation",
    "resignationers": "resignation",
    "resignations": "resignation",
    "resignerade": "resignerad",
    "resignerades": "resignerad",
    "resignerads": "resignerad",
    "resignerande": "resignera",
    "resigneranden": "resignerande",
    "resignerandena": "resignerande",
    "resignerandenas": "resignerande",
    "resignerandens": "resignerande",
    "resignerandes": "resignerande",
    "resignerandet": "resignerande",
    "resignerandets": "resignerande",
    "resignerar": "resignera",
    "resigneras": "resignera",
    "resignerat": "resignerad",
    "resignerats": "resignerad",
    "resigneringar": "resignering",
    "resigneringarna": "resignering",
    "resigneringarnas": "resignering",
    "resigneringars": "resignering",
    "resigneringen": "resignering",
    "resigneringens": "resignering",
    "resignerings": "resignering",
    "resistansen": "resistans",
    "resistansens": "resistans",
    "resistensen": "resistens",
    "resistensens": "resistens",
    "resistensområden": "resistensområde",
    "resistensområdena": "resistensområde",
    "resistensområdenas": "resistensområde",
    "resistensområdens": "resistensområde",
    "resistensområdes": "resistensområde",
    "resistensområdet": "resistensområde",
    "resistensområdets": "resistensområde",
    "resistenta": "resistent",
    "resistentare": "resistent",
    "resistentares": "resistent",
    "resistentas": "resistent",
    "resistentast": "resistent",
    "resistentaste": "resistent",
    "resistentastes": "resistent",
    "resistentasts": "resistent",
    "resistente": "resistent",
    "resistentes": "resistent",
    "resistentheten": "resistenthet",
    "resistenthetens": "resistenthet",
    "resistenthets": "resistenthet",
    "resistents": "resistent",
    "resistiviteten": "resistivitet",
    "resistivitetens": "resistivitet",
    "resistiviteter": "resistivitet",
    "resistiviteterna": "resistivitet",
    "resistiviteternas": "resistivitet",
    "resistiviteters": "resistivitet",
    "resistivitets": "resistivitet",
    "resistorer": "resistor",
    "resistorerna": "resistor",
    "resistorernas": "resistor",
    "resistorers": "resistor",
    "resistorn": "resistor",
    "resistorns": "resistor",
    "resistors": "resistor",
    "reskaosen": "reskaos",
    "reskaosens": "reskaos",
    "reskaoset": "reskaos",
    "reskaosets": "reskaos",
    "resklassen": "resklass",
    "resklassens": "resklass",
    "resklasser": "resklass",
    "resklasserna": "resklass",
    "resklassernas": "resklass",
    "resklassers": "resklass",
    "reskontr": "reskontra",
    "reskontran": "reskontra",
    "reskontrans": "reskontra",
    "reskontras": "reskontra",
    "reskontre": "reskontra",
    "reskontror": "reskontra",
    "reskontrorna": "reskontra",
    "reskontrornas": "reskontra",
    "reskontrors": "reskontra",
    "reskontrs": "reskontra",
    "reskripten": "reskript",
    "reskriptens": "reskript",
    "reskriptet": "reskript",
    "reskriptets": "reskript",
    "reskripts": "reskript",
    "resliga": "reslig",
    "resligare": "reslig",
    "resligares": "reslig",
    "resligas": "reslig",
    "resligast": "reslig",
    "resligaste": "reslig",
    "resligastes": "reslig",
    "resligasts": "reslig",
    "reslige": "reslig",
    "resliges": "reslig",
    "resligheten": "reslighet",
    "reslighetens": "reslighet",
    "reslighets": "reslighet",
    "resligs": "reslig",
    "resligt": "reslig",
    "resligts": "reslig",
    "resmålen": "resmål",
    "resmålens": "resmål",
    "resmålet": "resmål",
    "resmålets": "resmål",
    "resmåls": "resmål",
    "resningar": "resning",
    "resningarna": "resning",
    "resningarnas": "resning",
    "resningars": "resning",
    "resningen": "resning",
    "resningens": "resning",
    "resnings": "resning",
    "resningsbesluten": "resningsbeslut",
    "resningsbeslutens": "resningsbeslut",
    "resningsbeslutet": "resningsbeslut",
    "resningsbeslutets": "resningsbeslut",
    "resningsbesluts": "resningsbeslut",
    "resoluta": "resolut",
    "resolutare": "resolut",
    "resolutares": "resolut",
    "resolutas": "resolut",
    "resolutast": "resolut",
    "resolutaste": "resolut",
    "resolutastes": "resolut",
    "resolutasts": "resolut",
    "resolute": "resolut",
    "resolutes": "resolut",
    "resolutheten": "resoluthet",
    "resoluthetens": "resoluthet",
    "resoluthets": "resoluthet",
    "resolutionen": "resolution",
    "resolutionens": "resolution",
    "resolutioner": "resolution",
    "resolutionerna": "resolution",
    "resolutionernas": "resolution",
    "resolutioners": "resolution",
    "resolutions": "resolution",
    "resoluts": "resolut",
    "resolverad": "resolvera",
    "resolverade": "resolvera",
    "resolverades": "resolvera",
    "resolverads": "resolvera",
    "resolverande": "resolvera",
    "resolveranden": "resolverande",
    "resolverandena": "resolverande",
    "resolverandenas": "resolverande",
    "resolverandens": "resolverande",
    "resolverandes": "resolverande",
    "resolverandet": "resolverande",
    "resolverandets": "resolverande",
    "resolverar": "resolvera",
    "resolveras": "resolvera",
    "resolverat": "resolvera",
    "resolverats": "resolvera",
    "resolverbara": "resolverbar",
    "resolverbarare": "resolverbar",
    "resolverbarares": "resolverbar",
    "resolverbaras": "resolverbar",
    "resolverbarast": "resolverbar",
    "resolverbaraste": "resolverbar",
    "resolverbarastes": "resolverbar",
    "resolverbarasts": "resolverbar",
    "resolverbare": "resolverbar",
    "resolverbares": "resolverbar",
    "resolverbarheten": "resolverbarhet",
    "resolverbarhetens": "resolverbarhet",
    "resolverbarhets": "resolverbarhet",
    "resolverbars": "resolverbar",
    "resolverbart": "resolverbar",
    "resolverbarts": "resolverbar",
    "resolveringar": "resolvering",
    "resolveringarna": "resolvering",
    "resolveringarnas": "resolvering",
    "resolveringars": "resolvering",
    "resolveringen": "resolvering",
    "resolveringens": "resolvering",
    "resolverings": "resolvering",
    "resonabels": "resonabel",
    "resonabelt": "resonabel",
    "resonabelts": "resonabel",
    "resonabla": "resonabel",
    "resonablare": "resonabel",
    "resonablares": "resonabel",
    "resonablas": "resonabel",
    "resonablast": "resonabel",
    "resonablaste": "resonabel",
    "resonablastes": "resonabel",
    "resonablasts": "resonabel",
    "resonable": "resonabel",
    "resonables": "resonabel",
    "resonansbottens": "resonansbotten",
    "resonansbottnar": "resonansbotten",
    "resonansbottnarna": "resonansbotten",
    "resonansbottnarnas": "resonansbotten",
    "resonansbottnars": "resonansbotten",
    "resonansbottnen": "resonansbotten",
    "resonansbottnens": "resonansbotten",
    "resonansen": "resonans",
    "resonansens": "resonans",
    "resonanslåd": "resonanslåda",
    "resonanslådan": "resonanslåda",
    "resonanslådans": "resonanslåda",
    "resonanslådas": "resonanslåda",
    "resonanslåde": "resonanslåda",
    "resonanslådor": "resonanslåda",
    "resonanslådorna": "resonanslåda",
    "resonanslådornas": "resonanslåda",
    "resonanslådors": "resonanslåda",
    "resonanslåds": "resonanslåda",
    "resonemangen": "resonemang",
    "resonemangens": "resonemang",
    "resonemanget": "resonemang",
    "resonemangets": "resonemang",
    "resonemangs": "resonemang",
    "resonemangskarusellen": "resonemangskarusell",
    "resonemangskarusellens": "resonemangskarusell",
    "resonemangskaruseller": "resonemangskarusell",
    "resonemangskarusellerna": "resonemangskarusell",
    "resonemangskarusellernas": "resonemangskarusell",
    "resonemangskarusellers": "resonemangskarusell",
    "resonemangskarusells": "resonemangskarusell",
    "resonemangspartier": "resonemangsparti",
    "resonemangspartierna": "resonemangsparti",
    "resonemangspartiernas": "resonemangsparti",
    "resonemangspartiers": "resonemangsparti",
    "resonemangspartiet": "resonemangsparti",
    "resonemangspartiets": "resonemangsparti",
    "resonemangspartis": "resonemangsparti",
    "resonemangspartit": "resonemangsparti",
    "resonemangspartits": "resonemangsparti",
    "resonemangsäktenskapen": "resonemangsäktenskap",
    "resonemangsäktenskapens": "resonemangsäktenskap",
    "resonemangsäktenskapet": "resonemangsäktenskap",
    "resonemangsäktenskapets": "resonemangsäktenskap",
    "resonemangsäktenskaps": "resonemangsäktenskap",
    "resonen": "reson",
    "resonens": "reson",
    "resonerade": "resonera",
    "resonerades": "resonera",
    "resonerande": "resonera",
    "resoneranden": "resonerande",
    "resonerandena": "resonerande",
    "resonerandenas": "resonerande",
    "resonerandens": "resonerande",
    "resonerandes": "resonerande",
    "resonerandet": "resonerande",
    "resonerandets": "resonerande",
    "resonerar": "resonera",
    "resoneras": "resonera",
    "resonerat": "resonera",
    "resonerats": "resonera",
    "resoneringar": "resonering",
    "resoneringarna": "resonering",
    "resoneringarnas": "resonering",
    "resoneringars": "resonering",
    "resoneringen": "resonering",
    "resoneringens": "resonering",
    "resonerings": "resonering",
    "resonliga": "resonlig",
    "resonligare": "resonlig",
    "resonligares": "resonlig",
    "resonligas": "resonlig",
    "resonligast": "resonlig",
    "resonligaste": "resonlig",
    "resonligastes": "resonlig",
    "resonligasts": "resonlig",
    "resonlige": "resonlig",
    "resonliges": "resonlig",
    "resonligheten": "resonlighet",
    "resonlighetens": "resonlighet",
    "resonlighets": "resonlighet",
    "resonligs": "resonlig",
    "resonligt": "resonlig",
    "resonligts": "resonlig",
    "resons": "reson",
    "resonören": "resonör",
    "resonörens": "resonör",
    "resonörer": "resonör",
    "resonörerna": "resonör",
    "resonörernas": "resonör",
    "resonörers": "resonör",
    "resonörs": "resonör",
    "resor": "resa",
    "resorberad": "resorbera",
    "resorberade": "resorbera",
    "resorberades": "resorbera",
    "resorberads": "resorbera",
    "resorberande": "resorbera",
    "resorberanden": "resorberande",
    "resorberandena": "resorberande",
    "resorberandenas": "resorberande",
    "resorberandens": "resorberande",
    "resorberandes": "resorberande",
    "resorberandet": "resorberande",
    "resorberandets": "resorberande",
    "resorberar": "resorbera",
    "resorberas": "resorbera",
    "resorberat": "resorbera",
    "resorberats": "resorbera",
    "resorberbara": "resorberbar",
    "resorberbarare": "resorberbar",
    "resorberbarares": "resorberbar",
    "resorberbaras": "resorberbar",
    "resorberbarast": "resorberbar",
    "resorberbaraste": "resorberbar",
    "resorberbarastes": "resorberbar",
    "resorberbarasts": "resorberbar",
    "resorberbare": "resorberbar",
    "resorberbares": "resorberbar",
    "resorberbarheten": "resorberbarhet",
    "resorberbarhetens": "resorberbarhet",
    "resorberbarhets": "resorberbarhet",
    "resorberbars": "resorberbar",
    "resorberbart": "resorberbar",
    "resorberbarts": "resorberbar",
    "resorberingar": "resorbering",
    "resorberingarna": "resorbering",
    "resorberingarnas": "resorbering",
    "resorberingars": "resorbering",
    "resorberingen": "resorbering",
    "resorberingens": "resorbering",
    "resorberings": "resorbering",
    "resorna": "resa",
    "resornas": "resa",
    "resorptionen": "resorption",
    "resorptionens": "resorption",
    "resorptioner": "resorption",
    "resorptionerna": "resorption",
    "resorptionernas": "resorption",
    "resorptioners": "resorption",
    "resorptions": "resorption",
    "resors": "resa",
    "respassen": "respass",
    "respassens": "respass",
    "respasset": "respass",
    "respassets": "respass",
    "respektabels": "respektabel",
    "respektabelt": "respektabel",
    "respektabelts": "respektabel",
    "respektabla": "respektabel",
    "respektablare": "respektabel",
    "respektablares": "respektabel",
    "respektablas": "respektabel",
    "respektablast": "respektabel",
    "respektablaste": "respektabel",
    "respektablastes": "respektabel",
    "respektablasts": "respektabel",
    "respektable": "respektabel",
    "respektables": "respektabel",
    "respekten": "respekt",
    "respektens": "respekt",
    "respekterad": "respektera",
    "respekterade": "respektera",
    "respekterades": "respektera",
    "respekterads": "respektera",
    "respekterande": "respektera",
    "respekteranden": "respekterande",
    "respekterandena": "respekterande",
    "respekterandenas": "respekterande",
    "respekterandens": "respekterande",
    "respekterandes": "respekterande",
    "respekterandet": "respekterande",
    "respekterandets": "respekterande",
    "respekterar": "respektera",
    "respekteras": "respektera",
    "respekterat": "respektera",
    "respekterats": "respektera",
    "respekterbara": "respekterbar",
    "respekterbarare": "respekterbar",
    "respekterbarares": "respekterbar",
    "respekterbaras": "respekterbar",
    "respekterbarast": "respekterbar",
    "respekterbaraste": "respekterbar",
    "respekterbarastes": "respekterbar",
    "respekterbarasts": "respekterbar",
    "respekterbare": "respekterbar",
    "respekterbares": "respekterbar",
    "respekterbarheten": "respekterbarhet",
    "respekterbarhetens": "respekterbarhet",
    "respekterbarhets": "respekterbarhet",
    "respekterbars": "respekterbar",
    "respekterbart": "respekterbar",
    "respekterbarts": "respekterbar",
    "respekteringar": "respektering",
    "respekteringarna": "respektering",
    "respekteringarnas": "respektering",
    "respekteringars": "respektering",
    "respekteringen": "respektering",
    "respekteringens": "respektering",
    "respekterings": "respektering",
    "respektfulla": "respektfull",
    "respektfullare": "respektfull",
    "respektfullares": "respektfull",
    "respektfullas": "respektfull",
    "respektfullast": "respektfull",
    "respektfullaste": "respektfull",
    "respektfullastes": "respektfull",
    "respektfullasts": "respektfull",
    "respektfulle": "respektfull",
    "respektfulles": "respektfull",
    "respektfullheten": "respektfullhet",
    "respektfullhetens": "respektfullhet",
    "respektfullheter": "respektfullhet",
    "respektfullheterna": "respektfullhet",
    "respektfullheternas": "respektfullhet",
    "respektfullheters": "respektfullhet",
    "respektfullhets": "respektfullhet",
    "respektfulls": "respektfull",
    "respektfullt": "respektfull",
    "respektfullts": "respektfull",
    "respektlösa": "respektlös",
    "respektlösare": "respektlös",
    "respektlösares": "respektlös",
    "respektlösas": "respektlös",
    "respektlösast": "respektlös",
    "respektlösaste": "respektlös",
    "respektlösastes": "respektlös",
    "respektlösasts": "respektlös",
    "respektlöse": "respektlös",
    "respektlöses": "respektlös",
    "respektlösheten": "respektlöshet",
    "respektlöshetens": "respektlöshet",
    "respektlösheter": "respektlöshet",
    "respektlösheterna": "respektlöshet",
    "respektlösheternas": "respektlöshet",
    "respektlösheters": "respektlöshet",
    "respektlöshets": "respektlöshet",
    "respektlöst": "respektlös",
    "respektlösts": "respektlös",
    "respekts": "respekt",
    "respirationen": "respiration",
    "respirationens": "respiration",
    "respirationer": "respiration",
    "respirationerna": "respiration",
    "respirationernas": "respiration",
    "respirationers": "respiration",
    "respirations": "respiration",
    "respiratorer": "respirator",
    "respiratorerna": "respirator",
    "respiratorernas": "respirator",
    "respiratorers": "respirator",
    "respiratoriska": "respiratorisk",
    "respiratoriskare": "respiratorisk",
    "respiratoriskares": "respiratorisk",
    "respiratoriskas": "respiratorisk",
    "respiratoriskast": "respiratorisk",
    "respiratoriskaste": "respiratorisk",
    "respiratoriskastes": "respiratorisk",
    "respiratoriskasts": "respiratorisk",
    "respiratoriske": "respiratorisk",
    "respiratoriskes": "respiratorisk",
    "respiratorisks": "respiratorisk",
    "respiratoriskt": "respiratorisk",
    "respiratoriskts": "respiratorisk",
    "respiratorn": "respirator",
    "respiratorns": "respirator",
    "respirators": "respirator",
    "respirerad": "respirera",
    "respirerade": "respirera",
    "respirerades": "respirera",
    "respirerads": "respirera",
    "respirerande": "respirera",
    "respireranden": "respirerande",
    "respirerandena": "respirerande",
    "respirerandenas": "respirerande",
    "respirerandens": "respirerande",
    "respirerandes": "respirerande",
    "respirerandet": "respirerande",
    "respirerandets": "respirerande",
    "respirerar": "respirera",
    "respireras": "respirera",
    "respirerat": "respirera",
    "respirerats": "respirera",
    "respirerbara": "respirerbar",
    "respirerbarare": "respirerbar",
    "respirerbarares": "respirerbar",
    "respirerbaras": "respirerbar",
    "respirerbarast": "respirerbar",
    "respirerbaraste": "respirerbar",
    "respirerbarastes": "respirerbar",
    "respirerbarasts": "respirerbar",
    "respirerbare": "respirerbar",
    "respirerbares": "respirerbar",
    "respirerbarheten": "respirerbarhet",
    "respirerbarhetens": "respirerbarhet",
    "respirerbarhets": "respirerbarhet",
    "respirerbars": "respirerbar",
    "respirerbart": "respirerbar",
    "respirerbarts": "respirerbar",
    "respireringar": "respirering",
    "respireringarna": "respirering",
    "respireringarnas": "respirering",
    "respireringars": "respirering",
    "respireringen": "respirering",
    "respireringens": "respirering",
    "respirerings": "respirering",
    "respiten": "respit",
    "respitens": "respit",
    "respiter": "respit",
    "respiterna": "respit",
    "respiternas": "respit",
    "respiters": "respit",
    "respits": "respit",
    "respondenten": "respondent",
    "respondentens": "respondent",
    "respondenter": "respondent",
    "respondenterna": "respondent",
    "respondenternas": "respondent",
    "respondenters": "respondent",
    "respondents": "respondent",
    "responsen": "respons",
    "responsens": "respons",
    "ressentimenten": "ressentiment",
    "ressentimentens": "ressentiment",
    "ressentimentet": "ressentiment",
    "ressentimentets": "ressentiment",
    "ressentiments": "ressentiment",
    "ressugens": "ressugen",
    "ressuget": "ressugen",
    "ressugets": "ressugen",
    "ressugna": "ressugen",
    "ressugnare": "ressugen",
    "ressugnares": "ressugen",
    "ressugnas": "ressugen",
    "ressugnast": "ressugen",
    "ressugnaste": "ressugen",
    "ressugnastes": "ressugen",
    "ressugnasts": "ressugen",
    "ressugne": "ressugen",
    "ressugnes": "ressugen",
    "rest": "resa",
    "resta": "resa",
    "restantie": "restantier",
    "restantierna": "restantier",
    "restantiernas": "restantier",
    "restantiers": "restantier",
    "restas": "resa",
    "restaurangbesöken": "restaurangbesök",
    "restaurangbesökens": "restaurangbesök",
    "restaurangbesöket": "restaurangbesök",
    "restaurangbesökets": "restaurangbesök",
    "restaurangbesöks": "restaurangbesök",
    "restaurangborden": "restaurangbord",
    "restaurangbordens": "restaurangbord",
    "restaurangbordet": "restaurangbord",
    "restaurangbordets": "restaurangbord",
    "restaurangbords": "restaurangbord",
    "restaurangbranschen": "restaurangbransch",
    "restaurangbranschens": "restaurangbransch",
    "restaurangbranschs": "restaurangbransch",
    "restaurangbåtar": "restaurangbåt",
    "restaurangbåtarna": "restaurangbåt",
    "restaurangbåtarnas": "restaurangbåt",
    "restaurangbåtars": "restaurangbåt",
    "restaurangbåten": "restaurangbåt",
    "restaurangbåtens": "restaurangbåt",
    "restaurangbåts": "restaurangbåt",
    "restaurangen": "restaurang",
    "restaurangens": "restaurang",
    "restauranger": "restaurang",
    "restaurangerna": "restaurang",
    "restaurangernas": "restaurang",
    "restaurangers": "restaurang",
    "restauranggästen": "restauranggäst",
    "restauranggästens": "restauranggäst",
    "restauranggäster": "restauranggäst",
    "restauranggästerna": "restauranggäst",
    "restauranggästernas": "restauranggäst",
    "restauranggästers": "restauranggäst",
    "restauranggästs": "restauranggäst",
    "restauranghypotesen": "restauranghypotes",
    "restauranghypotesens": "restauranghypotes",
    "restaurangköken": "restaurangkök",
    "restaurangkökens": "restaurangkök",
    "restaurangköket": "restaurangkök",
    "restaurangkökets": "restaurangkök",
    "restaurangköks": "restaurangkök",
    "restaurangmiddagar": "restaurangmiddag",
    "restaurangmiddagarna": "restaurangmiddag",
    "restaurangmiddagarnas": "restaurangmiddag",
    "restaurangmiddagars": "restaurangmiddag",
    "restaurangmiddagen": "restaurangmiddag",
    "restaurangmiddagens": "restaurangmiddag",
    "restaurangmiddags": "restaurangmiddag",
    "restaurangs": "restaurang",
    "restaurangvagnar": "restaurangvagn",
    "restaurangvagnarna": "restaurangvagn",
    "restaurangvagnarnas": "restaurangvagn",
    "restaurangvagnars": "restaurangvagn",
    "restaurangvagnen": "restaurangvagn",
    "restaurangvagnens": "restaurangvagn",
    "restaurangvagns": "restaurangvagn",
    "restaurationen": "restauration",
    "restaurationens": "restauration",
    "restaurationer": "restauration",
    "restaurationerna": "restauration",
    "restaurationernas": "restauration",
    "restaurationers": "restauration",
    "restaurations": "restauration",
    "restauratorer": "restaurator",
    "restauratorerna": "restaurator",
    "restauratorernas": "restaurator",
    "restauratorers": "restaurator",
    "restauratorn": "restaurator",
    "restauratorns": "restaurator",
    "restaurators": "restaurator",
    "restauratrisen": "restauratris",
    "restauratrisens": "restauratris",
    "restauratriser": "restauratris",
    "restauratriserna": "restauratris",
    "restauratrisernas": "restauratris",
    "restauratrisers": "restauratris",
    "restauratören": "restauratör",
    "restauratörens": "restauratör",
    "restauratörer": "restauratör",
    "restauratörerna": "restauratör",
    "restauratörernas": "restauratör",
    "restauratörers": "restauratör",
    "restauratörs": "restauratör",
    "restaurerad": "restaurera",
    "restaurerade": "restaurera",
    "restaurerades": "restaurera",
    "restaurerads": "restaurera",
    "restaurerande": "restaurera",
    "restaureranden": "restaurerande",
    "restaurerandena": "restaurerande",
    "restaurerandenas": "restaurerande",
    "restaurerandens": "restaurerande",
    "restaurerandes": "restaurerande",
    "restaurerandet": "restaurerande",
    "restaurerandets": "restaurerande",
    "restaurerar": "restaurera",
    "restaureras": "restaurera",
    "restaurerat": "restaurera",
    "restaurerats": "restaurera",
    "restaurerbara": "restaurerbar",
    "restaurerbarare": "restaurerbar",
    "restaurerbarares": "restaurerbar",
    "restaurerbaras": "restaurerbar",
    "restaurerbarast": "restaurerbar",
    "restaurerbaraste": "restaurerbar",
    "restaurerbarastes": "restaurerbar",
    "restaurerbarasts": "restaurerbar",
    "restaurerbare": "restaurerbar",
    "restaurerbares": "restaurerbar",
    "restaurerbarheten": "restaurerbarhet",
    "restaurerbarhetens": "restaurerbarhet",
    "restaurerbarhets": "restaurerbarhet",
    "restaurerbars": "restaurerbar",
    "restaurerbart": "restaurerbar",
    "restaurerbarts": "restaurerbar",
    "restaureringar": "restaurering",
    "restaureringarna": "restaurering",
    "restaureringarnas": "restaurering",
    "restaureringars": "restaurering",
    "restaureringen": "restaurering",
    "restaureringens": "restaurering",
    "restaurerings": "restaurering",
    "reste": "resa",
    "resten": "rest",
    "restens": "rest",
    "rester": "rest",
    "resterade": "restera",
    "resterades": "restera",
    "resterande": "restera",
    "resteranden": "resterande",
    "resterandena": "resterande",
    "resterandenas": "resterande",
    "resterandens": "resterande",
    "resterandes": "resterande",
    "resterandet": "resterande",
    "resterandets": "resterande",
    "resterar": "restera",
    "resteras": "restera",
    "resterat": "restera",
    "resterats": "restera",
    "resterna": "rest",
    "resternas": "rest",
    "resters": "rest",
    "restes": "resa",
    "restiden": "restid",
    "restidens": "restid",
    "restider": "restid",
    "restiderna": "restid",
    "restidernas": "restid",
    "restiders": "restid",
    "restids": "restid",
    "restidsgarantien": "restidsgaranti",
    "restidsgarantiens": "restidsgaranti",
    "restidsgarantier": "restidsgaranti",
    "restidsgarantierna": "restidsgaranti",
    "restidsgarantiernas": "restidsgaranti",
    "restidsgarantiers": "restidsgaranti",
    "restidsgarantin": "restidsgaranti",
    "restidsgarantins": "restidsgaranti",
    "restidsgarantis": "restidsgaranti",
    "restituerad": "restituera",
    "restituerade": "restituera",
    "restituerades": "restituera",
    "restituerads": "restituera",
    "restituerande": "restituera",
    "restitueranden": "restituerande",
    "restituerandena": "restituerande",
    "restituerandenas": "restituerande",
    "restituerandens": "restituerande",
    "restituerandes": "restituerande",
    "restituerandet": "restituerande",
    "restituerandets": "restituerande",
    "restituerar": "restituera",
    "restitueras": "restituera",
    "restituerat": "restituera",
    "restituerats": "restituera",
    "restituerbara": "restituerbar",
    "restituerbarare": "restituerbar",
    "restituerbarares": "restituerbar",
    "restituerbaras": "restituerbar",
    "restituerbarast": "restituerbar",
    "restituerbaraste": "restituerbar",
    "restituerbarastes": "restituerbar",
    "restituerbarasts": "restituerbar",
    "restituerbare": "restituerbar",
    "restituerbares": "restituerbar",
    "restituerbarheten": "restituerbarhet",
    "restituerbarhetens": "restituerbarhet",
    "restituerbarhets": "restituerbarhet",
    "restituerbars": "restituerbar",
    "restituerbart": "restituerbar",
    "restituerbarts": "restituerbar",
    "restitueringar": "restituering",
    "restitueringarna": "restituering",
    "restitueringarnas": "restituering",
    "restitueringars": "restituering",
    "restitueringen": "restituering",
    "restitueringens": "restituering",
    "restituerings": "restituering",
    "restitutionen": "restitution",
    "restitutionens": "restitution",
    "restitutioner": "restitution",
    "restitutionerna": "restitution",
    "restitutionernas": "restitution",
    "restitutioners": "restitution",
    "restitutions": "restitution",
    "restlagerna": "restlager",
    "restlagernas": "restlager",
    "restlagers": "restlager",
    "restlagren": "restlager",
    "restlagrens": "restlager",
    "restlagret": "restlager",
    "restlagrets": "restlager",
    "restlängden": "restlängd",
    "restlängdens": "restlängd",
    "restlängder": "restlängd",
    "restlängderna": "restlängd",
    "restlängdernas": "restlängd",
    "restlängders": "restlängd",
    "restlängds": "restlängd",
    "restlösa": "restlös",
    "restlösare": "restlös",
    "restlösares": "restlös",
    "restlösas": "restlös",
    "restlösast": "restlös",
    "restlösaste": "restlös",
    "restlösastes": "restlös",
    "restlösasts": "restlös",
    "restlöse": "restlös",
    "restlöses": "restlös",
    "restlösheten": "restlöshet",
    "restlöshetens": "restlöshet",
    "restlöshets": "restlöshet",
    "restlöst": "restlös",
    "restlösts": "restlös",
    "restprodukten": "restprodukt",
    "restproduktens": "restprodukt",
    "restprodukter": "restprodukt",
    "restprodukterna": "restprodukt",
    "restprodukternas": "restprodukt",
    "restprodukters": "restprodukt",
    "restprodukts": "restprodukt",
    "restriktionen": "restriktion",
    "restriktionens": "restriktion",
    "restriktioner": "restriktion",
    "restriktionerna": "restriktion",
    "restriktionernas": "restriktion",
    "restriktioners": "restriktion",
    "restriktions": "restriktion",
    "restriktiva": "restriktiv",
    "restriktivare": "restriktiv",
    "restriktivares": "restriktiv",
    "restriktivas": "restriktiv",
    "restriktivast": "restriktiv",
    "restriktivaste": "restriktiv",
    "restriktivastes": "restriktiv",
    "restriktivasts": "restriktiv",
    "restriktive": "restriktiv",
    "restriktives": "restriktiv",
    "restriktivs": "restriktiv",
    "restriktivt": "restriktiv",
    "restriktivts": "restriktiv",
    "rests": "rest",
    "restskatten": "restskatt",
    "restskattens": "restskatt",
    "restskatter": "restskatt",
    "restskatterna": "restskatt",
    "restskatternas": "restskatt",
    "restskatters": "restskatt",
    "restskatts": "restskatt",
    "resultanten": "resultant",
    "resultantens": "resultant",
    "resultanter": "resultant",
    "resultanterna": "resultant",
    "resultanternas": "resultant",
    "resultanters": "resultant",
    "resultants": "resultant",
    "resultatbeskeden": "resultatbesked",
    "resultatbeskedens": "resultatbesked",
    "resultatbeskedet": "resultatbesked",
    "resultatbeskedets": "resultatbesked",
    "resultatbeskeds": "resultatbesked",
    "resultaten": "resultat",
    "resultatens": "resultat",
    "resultatet": "resultat",
    "resultatets": "resultat",
    "resultatförbättringar": "resultatförbättring",
    "resultatförbättringarna": "resultatförbättring",
    "resultatförbättringarnas": "resultatförbättring",
    "resultatförbättringars": "resultatförbättring",
    "resultatförbättringen": "resultatförbättring",
    "resultatförbättringens": "resultatförbättring",
    "resultatförbättrings": "resultatförbättring",
    "resultatinriktade": "resultatinriktad",
    "resultatinriktades": "resultatinriktad",
    "resultatinriktads": "resultatinriktad",
    "resultatinriktat": "resultatinriktad",
    "resultatinriktats": "resultatinriktad",
    "resultativa": "resultativ",
    "resultativare": "resultativ",
    "resultativares": "resultativ",
    "resultativas": "resultativ",
    "resultativast": "resultativ",
    "resultativaste": "resultativ",
    "resultativastes": "resultativ",
    "resultativasts": "resultativ",
    "resultative": "resultativ",
    "resultatives": "resultativ",
    "resultativs": "resultativ",
    "resultativt": "resultativ",
    "resultativts": "resultativ",
    "resultatlistan": "resultatlista",
    "resultatlistans": "resultatlista",
    "resultatlistas": "resultatlista",
    "resultatliste": "resultatlista",
    "resultatlistor": "resultatlista",
    "resultatlistorna": "resultatlista",
    "resultatlistornas": "resultatlista",
    "resultatlistors": "resultatlista",
    "resultatlösa": "resultatlös",
    "resultatlösare": "resultatlös",
    "resultatlösares": "resultatlös",
    "resultatlösas": "resultatlös",
    "resultatlösast": "resultatlös",
    "resultatlösaste": "resultatlös",
    "resultatlösastes": "resultatlös",
    "resultatlösasts": "resultatlös",
    "resultatlöse": "resultatlös",
    "resultatlöses": "resultatlös",
    "resultatlösheten": "resultatlöshet",
    "resultatlöshetens": "resultatlöshet",
    "resultatlöshets": "resultatlöshet",
    "resultatlöst": "resultatlös",
    "resultatlösts": "resultatlös",
    "resultatmässiga": "resultatmässig",
    "resultatmässigare": "resultatmässig",
    "resultatmässigares": "resultatmässig",
    "resultatmässigas": "resultatmässig",
    "resultatmässigast": "resultatmässig",
    "resultatmässigaste": "resultatmässig",
    "resultatmässigastes": "resultatmässig",
    "resultatmässigasts": "resultatmässig",
    "resultatmässige": "resultatmässig",
    "resultatmässiges": "resultatmässig",
    "resultatmässigs": "resultatmässig",
    "resultatmässigt": "resultatmässig",
    "resultatmässigts": "resultatmässig",
    "resultatredovisningar": "resultatredovisning",
    "resultatredovisningarna": "resultatredovisning",
    "resultatredovisningarnas": "resultatredovisning",
    "resultatredovisningars": "resultatredovisning",
    "resultatredovisningen": "resultatredovisning",
    "resultatredovisningens": "resultatredovisning",
    "resultatredovisnings": "resultatredovisning",
    "resultaträkningar": "resultaträkning",
    "resultaträkningarna": "resultaträkning",
    "resultaträkningarnas": "resultaträkning",
    "resultaträkningars": "resultaträkning",
    "resultaträkningen": "resultaträkning",
    "resultaträkningens": "resultaträkning",
    "resultaträknings": "resultaträkning",
    "resultats": "resultat",
    "resulterade": "resultera",
    "resulterades": "resultera",
    "resulterande": "resultera",
    "resulteranden": "resulterande",
    "resulterandena": "resulterande",
    "resulterandenas": "resulterande",
    "resulterandens": "resulterande",
    "resulterandes": "resulterande",
    "resulterandet": "resulterande",
    "resulterandets": "resulterande",
    "resulterar": "resultera",
    "resulteras": "resultera",
    "resulterat": "resultera",
    "resulterats": "resultera",
    "resulteringar": "resultering",
    "resulteringarna": "resultering",
    "resulteringarnas": "resultering",
    "resulteringars": "resultering",
    "resulteringen": "resultering",
    "resulteringens": "resultering",
    "resulterings": "resultering",
    "resumerad": "resumera",
    "resumerade": "resumera",
    "resumerades": "resumera",
    "resumerads": "resumera",
    "resumerande": "resumera",
    "resumeranden": "resumerande",
    "resumerandena": "resumerande",
    "resumerandenas": "resumerande",
    "resumerandens": "resumerande",
    "resumerandes": "resumerande",
    "resumerandet": "resumerande",
    "resumerandets": "resumerande",
    "resumerar": "resumera",
    "resumeras": "resumera",
    "resumerat": "resumera",
    "resumerats": "resumera",
    "resumerbara": "resumerbar",
    "resumerbarare": "resumerbar",
    "resumerbarares": "resumerbar",
    "resumerbaras": "resumerbar",
    "resumerbarast": "resumerbar",
    "resumerbaraste": "resumerbar",
    "resumerbarastes": "resumerbar",
    "resumerbarasts": "resumerbar",
    "resumerbare": "resumerbar",
    "resumerbares": "resumerbar",
    "resumerbarheten": "resumerbarhet",
    "resumerbarhetens": "resumerbarhet",
    "resumerbarhets": "resumerbarhet",
    "resumerbars": "resumerbar",
    "resumerbart": "resumerbar",
    "resumerbarts": "resumerbar",
    "resumeringar": "resumering",
    "resumeringarna": "resumering",
    "resumeringarnas": "resumering",
    "resumeringars": "resumering",
    "resumeringen": "resumering",
    "resumeringens": "resumering",
    "resumerings": "resumering",
    "resuméer": "resumé",
    "resuméerna": "resumé",
    "resuméernas": "resumé",
    "resuméers": "resumé",
    "resumén": "resumé",
    "resuméns": "resumé",
    "resumés": "resumé",
    "resursbasen": "resursbas",
    "resursbasens": "resursbas",
    "resursbaser": "resursbas",
    "resursbaserna": "resursbas",
    "resursbasernas": "resursbas",
    "resursbasers": "resursbas",
    "resursbristen": "resursbrist",
    "resursbristens": "resursbrist",
    "resursbrists": "resursbrist",
    "resursen": "resurs",
    "resursens": "resurs",
    "resurser": "resurs",
    "resurserna": "resurs",
    "resursernas": "resurs",
    "resursers": "resurs",
    "resurskrisen": "resurskris",
    "resurskrisens": "resurskris",
    "resurskriser": "resurskris",
    "resurskriserna": "resurskris",
    "resurskrisernas": "resurskris",
    "resurskrisers": "resurskris",
    "resursmässiga": "resursmässig",
    "resursmässigare": "resursmässig",
    "resursmässigares": "resursmässig",
    "resursmässigas": "resursmässig",
    "resursmässigast": "resursmässig",
    "resursmässigaste": "resursmässig",
    "resursmässigastes": "resursmässig",
    "resursmässigasts": "resursmässig",
    "resursmässige": "resursmässig",
    "resursmässiges": "resursmässig",
    "resursmässigs": "resursmässig",
    "resursmässigt": "resursmässig",
    "resursmässigts": "resursmässig",
    "resursorienterade": "resursorienterad",
    "resursorienterades": "resursorienterad",
    "resursorienterads": "resursorienterad",
    "resursorienterat": "resursorienterad",
    "resursorienterats": "resursorienterad",
    "resursöverföringar": "resursöverföring",
    "resursöverföringarna": "resursöverföring",
    "resursöverföringarnas": "resursöverföring",
    "resursöverföringars": "resursöverföring",
    "resursöverföringen": "resursöverföring",
    "resursöverföringens": "resursöverföring",
    "resursöverförings": "resursöverföring",
    "resvana": "resvan",
    "resvanan": "resvana",
    "resvanans": "resvana",
    "resvanare": "resvan",
    "resvanares": "resvan",
    "resvanas": "resvana",
    "resvanast": "resvan",
    "resvanaste": "resvan",
    "resvanastes": "resvan",
    "resvanasts": "resvan",
    "resvane": "resvana",
    "resvanes": "resvan",
    "resvanor": "resvana",
    "resvanorna": "resvana",
    "resvanornas": "resvana",
    "resvanors": "resvana",
    "resvans": "resvan",
    "resvant": "resvan",
    "resvants": "resvan",
    "resvägar": "resväg",
    "resvägarna": "resväg",
    "resvägarnas": "resväg",
    "resvägars": "resväg",
    "resvägen": "resväg",
    "resvägens": "resväg",
    "resvägs": "resväg",
    "resväsk": "resväska",
    "resväskan": "resväska",
    "resväskans": "resväska",
    "resväskas": "resväska",
    "resväske": "resväska",
    "resväskor": "resväska",
    "resväskorna": "resväska",
    "resväskornas": "resväska",
    "resväskors": "resväska",
    "resårbanden": "resårband",
    "resårbandens": "resårband",
    "resårbandet": "resårband",
    "resårbandets": "resårband",
    "resårbands": "resårband",
    "resåren": "resår",
    "resårens": "resår",
    "resårer": "resår",
    "resårerna": "resår",
    "resårernas": "resår",
    "resårers": "resår",
    "resårmadrassen": "resårmadrass",
    "resårmadrassens": "resårmadrass",
    "resårmadrasser": "resårmadrass",
    "resårmadrasserna": "resårmadrass",
    "resårmadrassernas": "resårmadrass",
    "resårmadrassers": "resårmadrass",
    "resårs": "resår",
    "resårstickningar": "resårstickning",
    "resårstickningarna": "resårstickning",
    "resårstickningarnas": "resårstickning",
    "resårstickningars": "resårstickning",
    "resårstickningen": "resårstickning",
    "resårstickningens": "resårstickning",
    "resårsticknings": "resårstickning",
    "ret": "reta",
    "retablerad": "retablera",
    "retablerade": "retablera",
    "retablerades": "retablera",
    "retablerads": "retablera",
    "retablerande": "retablera",
    "retableranden": "retablerande",
    "retablerandena": "retablerande",
    "retablerandenas": "retablerande",
    "retablerandens": "retablerande",
    "retablerandes": "retablerande",
    "retablerandet": "retablerande",
    "retablerandets": "retablerande",
    "retablerar": "retablera",
    "retableras": "retablera",
    "retablerat": "retablera",
    "retablerats": "retablera",
    "retablerbara": "retablerbar",
    "retablerbarare": "retablerbar",
    "retablerbarares": "retablerbar",
    "retablerbaras": "retablerbar",
    "retablerbarast": "retablerbar",
    "retablerbaraste": "retablerbar",
    "retablerbarastes": "retablerbar",
    "retablerbarasts": "retablerbar",
    "retablerbare": "retablerbar",
    "retablerbares": "retablerbar",
    "retablerbarheten": "retablerbarhet",
    "retablerbarhetens": "retablerbarhet",
    "retablerbarhets": "retablerbarhet",
    "retablerbars": "retablerbar",
    "retablerbart": "retablerbar",
    "retablerbarts": "retablerbar",
    "retableringar": "retablering",
    "retableringarna": "retablering",
    "retableringarnas": "retablering",
    "retableringars": "retablering",
    "retableringen": "retablering",
    "retableringens": "retablering",
    "retablerings": "retablering",
    "retad": "reta",
    "retade": "reta",
    "retades": "retas",
    "retads": "reta",
    "retande": "reta",
    "retanden": "retande",
    "retandena": "retande",
    "retandenas": "retande",
    "retandens": "retande",
    "retandes": "retande",
    "retandet": "retande",
    "retandets": "retande",
    "retar": "reta",
    "retardationen": "retardation",
    "retardationens": "retardation",
    "retardationer": "retardation",
    "retardationerna": "retardation",
    "retardationernas": "retardation",
    "retardationers": "retardation",
    "retardations": "retardation",
    "retarderad": "retardera",
    "retarderade": "retarderad",
    "retarderades": "retarderad",
    "retarderads": "retarderad",
    "retarderande": "retardera",
    "retarderanden": "retarderande",
    "retarderandena": "retarderande",
    "retarderandenas": "retarderande",
    "retarderandens": "retarderande",
    "retarderandes": "retarderande",
    "retarderandet": "retarderande",
    "retarderandets": "retarderande",
    "retarderar": "retardera",
    "retarderas": "retardera",
    "retarderat": "retarderad",
    "retarderats": "retarderad",
    "retarderbara": "retarderbar",
    "retarderbarare": "retarderbar",
    "retarderbarares": "retarderbar",
    "retarderbaras": "retarderbar",
    "retarderbarast": "retarderbar",
    "retarderbaraste": "retarderbar",
    "retarderbarastes": "retarderbar",
    "retarderbarasts": "retarderbar",
    "retarderbare": "retarderbar",
    "retarderbares": "retarderbar",
    "retarderbarheten": "retarderbarhet",
    "retarderbarhetens": "retarderbarhet",
    "retarderbarhets": "retarderbarhet",
    "retarderbars": "retarderbar",
    "retarderbart": "retarderbar",
    "retarderbarts": "retarderbar",
    "retarderingar": "retardering",
    "retarderingarna": "retardering",
    "retarderingarnas": "retardering",
    "retarderingars": "retardering",
    "retarderingen": "retardering",
    "retarderingens": "retardering",
    "retarderings": "retardering",
    "retas": "reta",
    "retat": "reta",
    "retats": "retas",
    "retbarheten": "retbarhet",
    "retbarhetens": "retbarhet",
    "retbarheter": "retbarhet",
    "retbarheterna": "retbarhet",
    "retbarheternas": "retbarhet",
    "retbarheters": "retbarhet",
    "retbarhets": "retbarhet",
    "retentionen": "retention",
    "retentionens": "retention",
    "retentioner": "retention",
    "retentionerna": "retention",
    "retentionernas": "retention",
    "retentioners": "retention",
    "retentions": "retention",
    "retentionsrätten": "retentionsrätt",
    "retentionsrättens": "retentionsrätt",
    "retentionsrätts": "retentionsrätt",
    "retfulla": "retfull",
    "retfullare": "retfull",
    "retfullares": "retfull",
    "retfullas": "retfull",
    "retfullast": "retfull",
    "retfullaste": "retfull",
    "retfullastes": "retfull",
    "retfullasts": "retfull",
    "retfulle": "retfull",
    "retfulles": "retfull",
    "retfullheten": "retfullhet",
    "retfullhetens": "retfullhet",
    "retfullhets": "retfullhet",
    "retfulls": "retfull",
    "retfullt": "retfull",
    "retfullts": "retfull",
    "rethost": "rethosta",
    "rethostan": "rethosta",
    "rethostans": "rethosta",
    "rethostas": "rethosta",
    "rethoste": "rethosta",
    "retinan": "retina",
    "retinans": "retina",
    "retinas": "retina",
    "retirerade": "retirera",
    "retirerades": "retirera",
    "retirerande": "retirera",
    "retireranden": "retirerande",
    "retirerandena": "retirerande",
    "retirerandenas": "retirerande",
    "retirerandens": "retirerande",
    "retirerandes": "retirerande",
    "retirerandet": "retirerande",
    "retirerandets": "retirerande",
    "retirerar": "retirera",
    "retireras": "retirera",
    "retirerat": "retirera",
    "retirerats": "retirera",
    "retireringar": "retirering",
    "retireringarna": "retirering",
    "retireringarnas": "retirering",
    "retireringars": "retirering",
    "retireringen": "retirering",
    "retireringens": "retirering",
    "retirerings": "retirering",
    "retliga": "retlig",
    "retligare": "retlig",
    "retligares": "retlig",
    "retligas": "retlig",
    "retligast": "retlig",
    "retligaste": "retlig",
    "retligastes": "retlig",
    "retligasts": "retlig",
    "retlige": "retlig",
    "retliges": "retlig",
    "retligheten": "retlighet",
    "retlighetens": "retlighet",
    "retlighets": "retlighet",
    "retligs": "retlig",
    "retligt": "retlig",
    "retligts": "retlig",
    "retningar": "retning",
    "retningarna": "retning",
    "retningarnas": "retning",
    "retningars": "retning",
    "retningen": "retning",
    "retningens": "retning",
    "retnings": "retning",
    "retorer": "retor",
    "retorerna": "retor",
    "retorernas": "retor",
    "retorers": "retor",
    "retoriken": "retorik",
    "retorikens": "retorik",
    "retorikern": "retoriker",
    "retorikerna": "retoriker",
    "retorikernas": "retoriker",
    "retorikerns": "retoriker",
    "retorikers": "retoriker",
    "retorikexperten": "retorikexpert",
    "retorikexpertens": "retorikexpert",
    "retorikexperter": "retorikexpert",
    "retorikexperterna": "retorikexpert",
    "retorikexperternas": "retorikexpert",
    "retorikexperters": "retorikexpert",
    "retorikexperts": "retorikexpert",
    "retoriks": "retorik",
    "retoriska": "retorisk",
    "retoriskare": "retorisk",
    "retoriskares": "retorisk",
    "retoriskas": "retorisk",
    "retoriskast": "retorisk",
    "retoriskaste": "retorisk",
    "retoriskastes": "retorisk",
    "retoriskasts": "retorisk",
    "retoriske": "retorisk",
    "retoriskes": "retorisk",
    "retorisks": "retorisk",
    "retoriskt": "retorisk",
    "retoriskts": "retorisk",
    "retorn": "retor",
    "retorns": "retor",
    "retors": "retor",
    "retorten": "retort",
    "retortens": "retort",
    "retorter": "retort",
    "retorterna": "retort",
    "retorternas": "retort",
    "retorters": "retort",
    "retorts": "retort",
    "retrievern": "retriever",
    "retrieverns": "retriever",
    "retrievers": "retriever",
    "retrievrar": "retriever",
    "retrievrarna": "retriever",
    "retrievrarnas": "retriever",
    "retrievrars": "retriever",
    "retroaktiva": "retroaktiv",
    "retroaktivare": "retroaktiv",
    "retroaktivares": "retroaktiv",
    "retroaktivas": "retroaktiv",
    "retroaktivast": "retroaktiv",
    "retroaktivaste": "retroaktiv",
    "retroaktivastes": "retroaktiv",
    "retroaktivasts": "retroaktiv",
    "retroaktive": "retroaktiv",
    "retroaktives": "retroaktiv",
    "retroaktivs": "retroaktiv",
    "retroaktivt": "retroaktiv",
    "retroaktivts": "retroaktiv",
    "retrograda": "retrograd",
    "retrogradare": "retrograd",
    "retrogradares": "retrograd",
    "retrogradas": "retrograd",
    "retrogradast": "retrograd",
    "retrogradaste": "retrograd",
    "retrogradastes": "retrograd",
    "retrogradasts": "retrograd",
    "retrogradavledningar": "retrogradavledning",
    "retrogradavledningarna": "retrogradavledning",
    "retrogradavledningarnas": "retrogradavledning",
    "retrogradavledningars": "retrogradavledning",
    "retrogradavledningen": "retrogradavledning",
    "retrogradavledningens": "retrogradavledning",
    "retrogradavlednings": "retrogradavledning",
    "retrograde": "retrograd",
    "retrogrades": "retrograd",
    "retrograds": "retrograd",
    "retronymen": "retronym",
    "retronymens": "retronym",
    "retronymer": "retronym",
    "retronymerna": "retronym",
    "retronymernas": "retronym",
    "retronymers": "retronym",
    "retronyms": "retronym",
    "retrospektiva": "retrospektiv",
    "retrospektivare": "retrospektiv",
    "retrospektivares": "retrospektiv",
    "retrospektivas": "retrospektiv",
    "retrospektivast": "retrospektiv",
    "retrospektivaste": "retrospektiv",
    "retrospektivastes": "retrospektiv",
    "retrospektivasts": "retrospektiv",
    "retrospektive": "retrospektiv",
    "retrospektives": "retrospektiv",
    "retrospektivs": "retrospektiv",
    "retrospektivt": "retrospektiv",
    "retrospektivts": "retrospektiv",
    "reträtten": "reträtt",
    "reträttens": "reträtt",
    "reträtter": "reträtt",
    "reträtterna": "reträtt",
    "reträtternas": "reträtt",
    "reträtters": "reträtt",
    "reträttplatsen": "reträttplats",
    "reträttplatsens": "reträttplats",
    "reträttplatser": "reträttplats",
    "reträttplatserna": "reträttplats",
    "reträttplatsernas": "reträttplats",
    "reträttplatsers": "reträttplats",
    "reträtts": "reträtt",
    "rets": "r",
    "retsamheten": "retsamhet",
    "retsamhetens": "retsamhet",
    "retsamheter": "retsamhet",
    "retsamheterna": "retsamhet",
    "retsamheternas": "retsamhet",
    "retsamheters": "retsamhet",
    "retsamhets": "retsamhet",
    "retsamma": "retsam",
    "retsammare": "retsam",
    "retsammares": "retsam",
    "retsammas": "retsam",
    "retsammast": "retsam",
    "retsammaste": "retsam",
    "retsammastes": "retsam",
    "retsammasts": "retsam",
    "retsamme": "retsam",
    "retsammes": "retsam",
    "retsams": "retsam",
    "retsamt": "retsam",
    "retsamts": "retsam",
    "retsinan": "retsina",
    "retsinans": "retsina",
    "retsinas": "retsina",
    "retstick": "retsticka",
    "retstickan": "retsticka",
    "retstickans": "retsticka",
    "retstickas": "retsticka",
    "retsticke": "retsticka",
    "retstickor": "retsticka",
    "retstickorna": "retsticka",
    "retstickornas": "retsticka",
    "retstickors": "retsticka",
    "retsticks": "retsticka",
    "rett": "reda",
    "retts": "reda",
    "returen": "retur",
    "returens": "retur",
    "returer": "retur",
    "returerna": "retur",
    "returernas": "retur",
    "returers": "retur",
    "returfärden": "returfärd",
    "returfärdens": "returfärd",
    "returfärder": "returfärd",
    "returfärderna": "returfärd",
    "returfärdernas": "returfärd",
    "returfärders": "returfärd",
    "returfärds": "returfärd",
    "returglasen": "returglas",
    "returglasens": "returglas",
    "returglaset": "returglas",
    "returglasets": "returglas",
    "returkapseln": "returkapsel",
    "returkapselns": "returkapsel",
    "returkapsels": "returkapsel",
    "returkapslar": "returkapsel",
    "returkapslarna": "returkapsel",
    "returkapslarnas": "returkapsel",
    "returkapslars": "returkapsel",
    "returmatchen": "returmatch",
    "returmatchens": "returmatch",
    "returmatcher": "returmatch",
    "returmatcherna": "returmatch",
    "returmatchernas": "returmatch",
    "returmatchers": "returmatch",
    "returmatchs": "returmatch",
    "returnerad": "returnera",
    "returnerade": "returnera",
    "returnerades": "returnera",
    "returnerads": "returnera",
    "returnerande": "returnera",
    "returneranden": "returnerande",
    "returnerandena": "returnerande",
    "returnerandenas": "returnerande",
    "returnerandens": "returnerande",
    "returnerandes": "returnerande",
    "returnerandet": "returnerande",
    "returnerandets": "returnerande",
    "returnerar": "returnera",
    "returneras": "returnera",
    "returnerat": "returnera",
    "returnerats": "returnera",
    "returnerbara": "returnerbar",
    "returnerbarare": "returnerbar",
    "returnerbarares": "returnerbar",
    "returnerbaras": "returnerbar",
    "returnerbarast": "returnerbar",
    "returnerbaraste": "returnerbar",
    "returnerbarastes": "returnerbar",
    "returnerbarasts": "returnerbar",
    "returnerbare": "returnerbar",
    "returnerbares": "returnerbar",
    "returnerbarheten": "returnerbarhet",
    "returnerbarhetens": "returnerbarhet",
    "returnerbarhets": "returnerbarhet",
    "returnerbars": "returnerbar",
    "returnerbart": "returnerbar",
    "returnerbarts": "returnerbar",
    "returneringar": "returnering",
    "returneringarna": "returnering",
    "returneringarnas": "returnering",
    "returneringars": "returnering",
    "returneringen": "returnering",
    "returneringens": "returnering",
    "returnerings": "returnering",
    "returporton": "returporto",
    "returportona": "returporto",
    "returportonas": "returporto",
    "returportons": "returporto",
    "returportos": "returporto",
    "returportot": "returporto",
    "returportots": "returporto",
    "returresan": "returresa",
    "returresans": "returresa",
    "returresas": "returresa",
    "returrese": "returresa",
    "returresor": "returresa",
    "returresorna": "returresa",
    "returresornas": "returresa",
    "returresors": "returresa",
    "returs": "retur",
    "retuschen": "retusch",
    "retuschens": "retusch",
    "retuscher": "retusch",
    "retuscherad": "retuschera",
    "retuscherade": "retuschera",
    "retuscherades": "retuschera",
    "retuscherads": "retuschera",
    "retuscherande": "retuschera",
    "retuscheranden": "retuscherande",
    "retuscherandena": "retuscherande",
    "retuscherandenas": "retuscherande",
    "retuscherandens": "retuscherande",
    "retuscherandes": "retuscherande",
    "retuscherandet": "retuscherande",
    "retuscherandets": "retuscherande",
    "retuscherar": "retuschera",
    "retuscheras": "retuschera",
    "retuscherat": "retuschera",
    "retuscherats": "retuschera",
    "retuscherbara": "retuscherbar",
    "retuscherbarare": "retuscherbar",
    "retuscherbarares": "retuscherbar",
    "retuscherbaras": "retuscherbar",
    "retuscherbarast": "retuscherbar",
    "retuscherbaraste": "retuscherbar",
    "retuscherbarastes": "retuscherbar",
    "retuscherbarasts": "retuscherbar",
    "retuscherbare": "retuscherbar",
    "retuscherbares": "retuscherbar",
    "retuscherbarheten": "retuscherbarhet",
    "retuscherbarhetens": "retuscherbarhet",
    "retuscherbarhets": "retuscherbarhet",
    "retuscherbars": "retuscherbar",
    "retuscherbart": "retuscherbar",
    "retuscherbarts": "retuscherbar",
    "retuscheringar": "retuschering",
    "retuscheringarna": "retuschering",
    "retuscheringarnas": "retuschering",
    "retuscheringars": "retuschering",
    "retuscheringen": "retuschering",
    "retuscheringens": "retuschering",
    "retuscherings": "retuschering",
    "retuscherna": "retusch",
    "retuschernas": "retusch",
    "retuschers": "retusch",
    "retuschs": "retusch",
    "reumatikern": "reumatiker",
    "reumatikerna": "reumatiker",
    "reumatikernas": "reumatiker",
    "reumatikerns": "reumatiker",
    "reumatikers": "reumatiker",
    "reumatiska": "reumatisk",
    "reumatiskare": "reumatisk",
    "reumatiskares": "reumatisk",
    "reumatiskas": "reumatisk",
    "reumatiskast": "reumatisk",
    "reumatiskaste": "reumatisk",
    "reumatiskastes": "reumatisk",
    "reumatiskasts": "reumatisk",
    "reumatiske": "reumatisk",
    "reumatiskes": "reumatisk",
    "reumatisks": "reumatisk",
    "reumatiskt": "reumatisk",
    "reumatiskts": "reumatisk",
    "reumatismen": "reumatism",
    "reumatismens": "reumatism",
    "reumatismer": "reumatism",
    "reumatismerna": "reumatism",
    "reumatismernas": "reumatism",
    "reumatismers": "reumatism",
    "reumatisms": "reumatism",
    "reumatologen": "reumatolog",
    "reumatologens": "reumatolog",
    "reumatologer": "reumatolog",
    "reumatologerna": "reumatolog",
    "reumatologernas": "reumatolog",
    "reumatologers": "reumatolog",
    "reumatologien": "reumatologi",
    "reumatologiens": "reumatologi",
    "reumatologin": "reumatologi",
    "reumatologins": "reumatologi",
    "reumatologis": "reumatologi",
    "reumatologs": "reumatolog",
    "rev": "riva",
    "revad": "reva",
    "revade": "reva",
    "revades": "reva",
    "revads": "reva",
    "revalverad": "revalvera",
    "revalverade": "revalvera",
    "revalverades": "revalvera",
    "revalverads": "revalvera",
    "revalverande": "revalvera",
    "revalveranden": "revalverande",
    "revalverandena": "revalverande",
    "revalverandenas": "revalverande",
    "revalverandens": "revalverande",
    "revalverandes": "revalverande",
    "revalverandet": "revalverande",
    "revalverandets": "revalverande",
    "revalverar": "revalvera",
    "revalveras": "revalvera",
    "revalverat": "revalvera",
    "revalverats": "revalvera",
    "revalverbara": "revalverbar",
    "revalverbarare": "revalverbar",
    "revalverbarares": "revalverbar",
    "revalverbaras": "revalverbar",
    "revalverbarast": "revalverbar",
    "revalverbaraste": "revalverbar",
    "revalverbarastes": "revalverbar",
    "revalverbarasts": "revalverbar",
    "revalverbare": "revalverbar",
    "revalverbares": "revalverbar",
    "revalverbarheten": "revalverbarhet",
    "revalverbarhetens": "revalverbarhet",
    "revalverbarhets": "revalverbarhet",
    "revalverbars": "revalverbar",
    "revalverbart": "revalverbar",
    "revalverbarts": "revalverbar",
    "revalveringar": "revalvering",
    "revalveringarna": "revalvering",
    "revalveringarnas": "revalvering",
    "revalveringars": "revalvering",
    "revalveringen": "revalvering",
    "revalveringens": "revalvering",
    "revalverings": "revalvering",
    "revan": "reva",
    "revande": "reva",
    "revanden": "revande",
    "revandena": "revande",
    "revandenas": "revande",
    "revandens": "revande",
    "revandes": "revande",
    "revandet": "revande",
    "revandets": "revande",
    "revans": "reva",
    "revanschen": "revansch",
    "revanschens": "revansch",
    "revanscher": "revansch",
    "revanscherna": "revansch",
    "revanschernas": "revansch",
    "revanschers": "revansch",
    "revanschismen": "revanschism",
    "revanschismens": "revanschism",
    "revanschismer": "revanschism",
    "revanschismerna": "revanschism",
    "revanschismernas": "revanschism",
    "revanschismers": "revanschism",
    "revanschisms": "revanschism",
    "revanschistiska": "revanschistisk",
    "revanschistiskas": "revanschistisk",
    "revanschistiske": "revanschistisk",
    "revanschistiskes": "revanschistisk",
    "revanschistisks": "revanschistisk",
    "revanschistiskt": "revanschistisk",
    "revanschistiskts": "revanschistisk",
    "revanschs": "revansch",
    "revar": "reva",
    "revarna": "rev",
    "revarnas": "rev",
    "revars": "rev",
    "revas": "reva",
    "revat": "reva",
    "revats": "reva",
    "revbenen": "revben",
    "revbenens": "revben",
    "revbenet": "revben",
    "revbenets": "revben",
    "revbens": "revben",
    "revbensspjällen": "revbensspjäll",
    "revbensspjällens": "revbensspjäll",
    "revbensspjället": "revbensspjäll",
    "revbensspjällets": "revbensspjäll",
    "revbensspjälls": "revbensspjäll",
    "reve": "reva",
    "revelationen": "revelation",
    "revelationens": "revelation",
    "revelationer": "revelation",
    "revelationerna": "revelation",
    "revelationernas": "revelation",
    "revelationers": "revelation",
    "revelations": "revelation",
    "reveljen": "revelj",
    "reveljens": "revelj",
    "reveljer": "revelj",
    "reveljerna": "revelj",
    "reveljernas": "revelj",
    "reveljers": "revelj",
    "reveljs": "revelj",
    "reveln": "revel",
    "revelns": "revel",
    "revels": "revel",
    "reven": "rev",
    "revens": "rev",
    "revenyer": "reveny",
    "revenyerna": "reveny",
    "revenyernas": "reveny",
    "revenyers": "reveny",
    "revenyn": "reveny",
    "revenyns": "reveny",
    "revenys": "reveny",
    "reverensen": "reverens",
    "reverensens": "reverens",
    "reverenser": "reverens",
    "reverenserna": "reverens",
    "reverensernas": "reverens",
    "reverensers": "reverens",
    "reversalen": "reversal",
    "reversalens": "reversal",
    "reversalet": "reversal",
    "reversalets": "reversal",
    "reversals": "reversal",
    "reversen": "revers",
    "reversens": "revers",
    "reverser": "revers",
    "reverserna": "revers",
    "reversernas": "revers",
    "reversers": "revers",
    "reversibels": "reversibel",
    "reversibelt": "reversibel",
    "reversibelts": "reversibel",
    "reversibla": "reversibel",
    "reversiblare": "reversibel",
    "reversiblares": "reversibel",
    "reversiblas": "reversibel",
    "reversiblast": "reversibel",
    "reversiblaste": "reversibel",
    "reversiblastes": "reversibel",
    "reversiblasts": "reversibel",
    "reversible": "reversibel",
    "reversibles": "reversibel",
    "revet": "rev",
    "reveterad": "revetera",
    "reveterade": "revetera",
    "reveterades": "revetera",
    "reveterads": "revetera",
    "reveterande": "revetera",
    "reveteranden": "reveterande",
    "reveterandena": "reveterande",
    "reveterandenas": "reveterande",
    "reveterandens": "reveterande",
    "reveterandes": "reveterande",
    "reveterandet": "reveterande",
    "reveterandets": "reveterande",
    "reveterar": "revetera",
    "reveteras": "revetera",
    "reveterat": "revetera",
    "reveterats": "revetera",
    "reveterbara": "reveterbar",
    "reveterbarare": "reveterbar",
    "reveterbarares": "reveterbar",
    "reveterbaras": "reveterbar",
    "reveterbarast": "reveterbar",
    "reveterbaraste": "reveterbar",
    "reveterbarastes": "reveterbar",
    "reveterbarasts": "reveterbar",
    "reveterbare": "reveterbar",
    "reveterbares": "reveterbar",
    "reveterbarheten": "reveterbarhet",
    "reveterbarhetens": "reveterbarhet",
    "reveterbarhets": "reveterbarhet",
    "reveterbars": "reveterbar",
    "reveterbart": "reveterbar",
    "reveterbarts": "reveterbar",
    "reveteringar": "revetering",
    "reveteringarna": "revetering",
    "reveteringarnas": "revetering",
    "reveteringars": "revetering",
    "reveteringen": "revetering",
    "reveteringens": "revetering",
    "reveterings": "revetering",
    "revets": "rev",
    "reviderad": "revidera",
    "reviderade": "revidera",
    "reviderades": "revidera",
    "reviderads": "revidera",
    "reviderande": "revidera",
    "revideranden": "reviderande",
    "reviderandena": "reviderande",
    "reviderandenas": "reviderande",
    "reviderandens": "reviderande",
    "reviderandes": "reviderande",
    "reviderandet": "reviderande",
    "reviderandets": "reviderande",
    "reviderar": "revidera",
    "revideras": "revidera",
    "reviderat": "revidera",
    "reviderats": "revidera",
    "reviderbara": "reviderbar",
    "reviderbarare": "reviderbar",
    "reviderbarares": "reviderbar",
    "reviderbaras": "reviderbar",
    "reviderbarast": "reviderbar",
    "reviderbaraste": "reviderbar",
    "reviderbarastes": "reviderbar",
    "reviderbarasts": "reviderbar",
    "reviderbare": "reviderbar",
    "reviderbares": "reviderbar",
    "reviderbarheten": "reviderbarhet",
    "reviderbarhetens": "reviderbarhet",
    "reviderbarhets": "reviderbarhet",
    "reviderbars": "reviderbar",
    "reviderbart": "reviderbar",
    "reviderbarts": "reviderbar",
    "revideren": "revider",
    "reviderens": "revider",
    "revideret": "revider",
    "reviderets": "revider",
    "revideringar": "revidering",
    "revideringarna": "revidering",
    "revideringarnas": "revidering",
    "revideringars": "revidering",
    "revideringen": "revidering",
    "revideringens": "revidering",
    "reviderings": "revidering",
    "reviders": "revider",
    "reviren": "revir",
    "revirens": "revir",
    "reviret": "revir",
    "revirets": "revir",
    "revirs": "revir",
    "revisionen": "revision",
    "revisionens": "revision",
    "revisioner": "revision",
    "revisionerna": "revision",
    "revisionernas": "revision",
    "revisioners": "revision",
    "revisionismen": "revisionism",
    "revisionismens": "revisionism",
    "revisionismer": "revisionism",
    "revisionismerna": "revisionism",
    "revisionismernas": "revisionism",
    "revisionismers": "revisionism",
    "revisionisms": "revisionism",
    "revisionisten": "revisionist",
    "revisionistens": "revisionist",
    "revisionister": "revisionist",
    "revisionisterna": "revisionist",
    "revisionisternas": "revisionist",
    "revisionisters": "revisionist",
    "revisionistiska": "revisionistisk",
    "revisionistiskas": "revisionistisk",
    "revisionistiske": "revisionistisk",
    "revisionistiskes": "revisionistisk",
    "revisionistisks": "revisionistisk",
    "revisionistiskt": "revisionistisk",
    "revisionistiskts": "revisionistisk",
    "revisionists": "revisionist",
    "revisions": "revision",
    "revisionsberättelsen": "revisionsberättelse",
    "revisionsberättelsens": "revisionsberättelse",
    "revisionsberättelser": "revisionsberättelse",
    "revisionsberättelserna": "revisionsberättelse",
    "revisionsberättelsernas": "revisionsberättelse",
    "revisionsberättelsers": "revisionsberättelse",
    "revisionsberättelses": "revisionsberättelse",
    "revisionssekreterar": "revisionssekreterare",
    "revisionssekreteraren": "revisionssekreterare",
    "revisionssekreterarens": "revisionssekreterare",
    "revisionssekreterares": "revisionssekreterare",
    "revisionssekreterarna": "revisionssekreterare",
    "revisionssekreterarnas": "revisionssekreterare",
    "revisorer": "revisor",
    "revisorerna": "revisor",
    "revisorernas": "revisor",
    "revisorers": "revisor",
    "revisorn": "revisor",
    "revisorns": "revisor",
    "revisors": "revisor",
    "revlar": "revel",
    "revlarna": "revel",
    "revlarnas": "revel",
    "revlars": "revel",
    "revningar": "revning",
    "revningarna": "revning",
    "revningarnas": "revning",
    "revningars": "revning",
    "revningen": "revning",
    "revningens": "revning",
    "revnings": "revning",
    "revoken": "revoke",
    "revokens": "revoke",
    "revoker": "revoke",
    "revokerna": "revoke",
    "revokernas": "revoke",
    "revokers": "revoke",
    "revokes": "revoke",
    "revoltandan": "revoltanda",
    "revoltandans": "revoltanda",
    "revoltandas": "revoltanda",
    "revolten": "revolt",
    "revoltens": "revolt",
    "revolter": "revolt",
    "revolterade": "revoltera",
    "revolterades": "revoltera",
    "revolterande": "revoltera",
    "revolteranden": "revolterande",
    "revolterandena": "revolterande",
    "revolterandenas": "revolterande",
    "revolterandens": "revolterande",
    "revolterandes": "revolterande",
    "revolterandet": "revolterande",
    "revolterandets": "revolterande",
    "revolterar": "revoltera",
    "revolteras": "revoltera",
    "revolterat": "revoltera",
    "revolterats": "revoltera",
    "revolteringar": "revoltering",
    "revolteringarna": "revoltering",
    "revolteringarnas": "revoltering",
    "revolteringars": "revoltering",
    "revolteringen": "revoltering",
    "revolteringens": "revoltering",
    "revolterings": "revoltering",
    "revolterna": "revolt",
    "revolternas": "revolt",
    "revolters": "revolt",
    "revolts": "revolt",
    "revoltören": "revoltör",
    "revoltörens": "revoltör",
    "revoltörer": "revoltör",
    "revoltörerna": "revoltör",
    "revoltörernas": "revoltör",
    "revoltörers": "revoltör",
    "revoltörs": "revoltör",
    "revolutionen": "revolution",
    "revolutionens": "revolution",
    "revolutioner": "revolution",
    "revolutionerad": "revolutionera",
    "revolutionerade": "revolutionera",
    "revolutionerades": "revolutionera",
    "revolutionerads": "revolutionera",
    "revolutionerande": "revolutionera",
    "revolutioneranden": "revolutionerande",
    "revolutionerandena": "revolutionerande",
    "revolutionerandenas": "revolutionerande",
    "revolutionerandens": "revolutionerande",
    "revolutionerandes": "revolutionerande",
    "revolutionerandet": "revolutionerande",
    "revolutionerandets": "revolutionerande",
    "revolutionerar": "revolutionera",
    "revolutioneras": "revolutionera",
    "revolutionerat": "revolutionera",
    "revolutionerats": "revolutionera",
    "revolutionerbara": "revolutionerbar",
    "revolutionerbarare": "revolutionerbar",
    "revolutionerbarares": "revolutionerbar",
    "revolutionerbaras": "revolutionerbar",
    "revolutionerbarast": "revolutionerbar",
    "revolutionerbaraste": "revolutionerbar",
    "revolutionerbarastes": "revolutionerbar",
    "revolutionerbarasts": "revolutionerbar",
    "revolutionerbare": "revolutionerbar",
    "revolutionerbares": "revolutionerbar",
    "revolutionerbarheten": "revolutionerbarhet",
    "revolutionerbarhetens": "revolutionerbarhet",
    "revolutionerbarhets": "revolutionerbarhet",
    "revolutionerbars": "revolutionerbar",
    "revolutionerbart": "revolutionerbar",
    "revolutionerbarts": "revolutionerbar",
    "revolutioneringar": "revolutionering",
    "revolutioneringarna": "revolutionering",
    "revolutioneringarnas": "revolutionering",
    "revolutioneringars": "revolutionering",
    "revolutioneringen": "revolutionering",
    "revolutioneringens": "revolutionering",
    "revolutionerings": "revolutionering",
    "revolutionerna": "revolution",
    "revolutionernas": "revolution",
    "revolutioners": "revolution",
    "revolutions": "revolution",
    "revolutionsledar": "revolutionsledare",
    "revolutionsledaren": "revolutionsledare",
    "revolutionsledarens": "revolutionsledare",
    "revolutionsledares": "revolutionsledare",
    "revolutionsledarna": "revolutionsledare",
    "revolutionsledarnas": "revolutionsledare",
    "revolutionära": "revolutionär",
    "revolutionärare": "revolutionär",
    "revolutionärares": "revolutionär",
    "revolutionäras": "revolutionär",
    "revolutionärast": "revolutionär",
    "revolutionäraste": "revolutionär",
    "revolutionärastes": "revolutionär",
    "revolutionärasts": "revolutionär",
    "revolutionäre": "revolutionär",
    "revolutionären": "revolutionär",
    "revolutionärens": "revolutionär",
    "revolutionärer": "revolutionär",
    "revolutionärerna": "revolutionär",
    "revolutionärernas": "revolutionär",
    "revolutionärers": "revolutionär",
    "revolutionäres": "revolutionär",
    "revolutionärs": "revolutionär",
    "revolutionärt": "revolutionär",
    "revolutionärts": "revolutionär",
    "revolvern": "revolver",
    "revolverns": "revolver",
    "revolvers": "revolver",
    "revolvrar": "revolver",
    "revolvrarna": "revolver",
    "revolvrarnas": "revolver",
    "revolvrars": "revolver",
    "revor": "reva",
    "revormar": "revorm",
    "revormarna": "revorm",
    "revormarnas": "revorm",
    "revormars": "revorm",
    "revormen": "revorm",
    "revormens": "revorm",
    "revorms": "revorm",
    "revorna": "reva",
    "revornas": "reva",
    "revors": "reva",
    "revs": "rivas",
    "revyartisten": "revyartist",
    "revyartistens": "revyartist",
    "revyartister": "revyartist",
    "revyartisterna": "revyartist",
    "revyartisternas": "revyartist",
    "revyartisters": "revyartist",
    "revyartists": "revyartist",
    "revyer": "revy",
    "revyerna": "revy",
    "revyernas": "revy",
    "revyers": "revy",
    "revymakar": "revymakare",
    "revymakaren": "revymakare",
    "revymakarens": "revymakare",
    "revymakares": "revymakare",
    "revymakarna": "revymakare",
    "revymakarnas": "revymakare",
    "revyn": "revy",
    "revyns": "revy",
    "revys": "revy",
    "revären": "revär",
    "revärens": "revär",
    "revärer": "revär",
    "revärerna": "revär",
    "revärernas": "revär",
    "revärers": "revär",
    "revärs": "revär",
    "rf-id-n": "rf-id",
    "rf-id-na": "rf-id",
    "rf-id-nas": "rf-id",
    "rf-id-ns": "rf-id",
    "rf-id-ts": "rf-id",
    "rfid-na": "rfid",
    "rfid-nas": "rfid",
    "rfid-ns": "rfid",
    "rfid-s": "rfid",
    "rfid-t": "rfid",
    "rfid:n": "rfid",
    "rfid:na": "rfid",
    "rfid:nas": "rfid",
    "rfid:ns": "rfid",
    "rfid:s": "rfid",
    "rfid:t": "rfid",
    "rfid:ts": "rfid",
    "rfidn": "rfid",
    "rfidna": "rfid",
    "rh-faktorer": "rh-faktor",
    "rh-faktorerna": "rh-faktor",
    "rh-faktorernas": "rh-faktor",
    "rh-faktorers": "rh-faktor",
    "rh-faktorn": "rh-faktor",
    "rh-faktorns": "rh-faktor",
    "rh-faktors": "rh-faktor",
    "rh-negativa": "rh-negativ",
    "rh-negativare": "rh-negativ",
    "rh-negativares": "rh-negativ",
    "rh-negativas": "rh-negativ",
    "rh-negativast": "rh-negativ",
    "rh-negativaste": "rh-negativ",
    "rh-negativastes": "rh-negativ",
    "rh-negativasts": "rh-negativ",
    "rh-negative": "rh-negativ",
    "rh-negatives": "rh-negativ",
    "rh-negativs": "rh-negativ",
    "rh-negativt": "rh-negativ",
    "rh-negativts": "rh-negativ",
    "rh-positiva": "rh-positiv",
    "rh-positivare": "rh-positiv",
    "rh-positivares": "rh-positiv",
    "rh-positivas": "rh-positiv",
    "rh-positivast": "rh-positiv",
    "rh-positivaste": "rh-positiv",
    "rh-positivastes": "rh-positiv",
    "rh-positivasts": "rh-positiv",
    "rh-positive": "rh-positiv",
    "rh-positives": "rh-positiv",
    "rh-positivs": "rh-positiv",
    "rh-positivt": "rh-positiv",
    "rh-positivts": "rh-positiv",
    "rheniet": "rhenium",
    "rheniets": "rhenium",
    "rheniumet": "rhenium",
    "rheniumets": "rhenium",
    "rheniums": "rhenium",
    "rhenska": "rhensk",
    "rhenskare": "rhensk",
    "rhenskares": "rhensk",
    "rhenskas": "rhensk",
    "rhenskast": "rhensk",
    "rhenskaste": "rhensk",
    "rhenskastes": "rhensk",
    "rhenskasts": "rhensk",
    "rhenske": "rhensk",
    "rhenskes": "rhensk",
    "rhenskheten": "rhenskhet",
    "rhenskhetens": "rhenskhet",
    "rhenskhets": "rhenskhet",
    "rhensks": "rhensk",
    "rhenskt": "rhensk",
    "rhenskts": "rhensk",
    "rhenviner": "rhenvin",
    "rhenvinerna": "rhenvin",
    "rhenvinernas": "rhenvin",
    "rhenviners": "rhenvin",
    "rhenvinet": "rhenvin",
    "rhenvinets": "rhenvin",
    "rhenvins": "rhenvin",
    "rhinologien": "rhinologi",
    "rhinologiens": "rhinologi",
    "rhinologin": "rhinologi",
    "rhinologins": "rhinologi",
    "rhinologis": "rhinologi",
    "rhizomen": "rhizom",
    "rhizomens": "rhizom",
    "rhizomer": "rhizom",
    "rhizomerna": "rhizom",
    "rhizomernas": "rhizom",
    "rhizomers": "rhizom",
    "rhizoms": "rhizom",
    "rhodesiern": "rhodesier",
    "rhodesierna": "rhodesier",
    "rhodesiernas": "rhodesier",
    "rhodesierns": "rhodesier",
    "rhodesiers": "rhodesier",
    "rhodesiska": "rhodesisk",
    "rhodesiskare": "rhodesisk",
    "rhodesiskares": "rhodesisk",
    "rhodesiskas": "rhodesisk",
    "rhodesiskast": "rhodesisk",
    "rhodesiskaste": "rhodesisk",
    "rhodesiskastes": "rhodesisk",
    "rhodesiskasts": "rhodesisk",
    "rhodesiske": "rhodesisk",
    "rhodesiskes": "rhodesisk",
    "rhodesisks": "rhodesisk",
    "rhodesiskt": "rhodesisk",
    "rhodesiskts": "rhodesisk",
    "rhododendrer": "rhododendron",
    "rhododendrerna": "rhododendron",
    "rhododendrernas": "rhododendron",
    "rhododendrers": "rhododendron",
    "rhododendronen": "rhododendron",
    "rhododendronens": "rhododendron",
    "rhododendrons": "rhododendron",
    "rhoen": "rho",
    "rhoens": "rho",
    "rhoet": "rho",
    "rhoets": "rho",
    "rhon": "rho",
    "rhona": "rho",
    "rhonas": "rho",
    "rhons": "rho",
    "rhos": "rho",
    "rhot": "rho",
    "rhots": "rho",
    "rhythm-and-bluesen": "rhythm-and-blues",
    "rhythm-and-bluesens": "rhythm-and-blues",
    "ri": "ria",
    "riad": "ria",
    "riade": "ria",
    "riades": "ria",
    "riads": "ria",
    "rian": "ria",
    "riande": "ria",
    "rianden": "riande",
    "riandena": "riande",
    "riandenas": "riande",
    "riandens": "riande",
    "riandes": "riande",
    "riandet": "riande",
    "riandets": "riande",
    "rians": "ria",
    "riar": "ria",
    "rias": "ria",
    "riat": "ria",
    "riats": "ria",
    "ribb": "ribba",
    "ribbade": "ribbad",
    "ribbades": "ribbad",
    "ribbads": "ribbad",
    "ribban": "ribba",
    "ribbans": "ribba",
    "ribbas": "ribba",
    "ribbat": "ribbad",
    "ribbats": "ribbad",
    "ribbe": "ribba",
    "ribben": "ribb",
    "ribbens": "ribb",
    "ribbor": "ribba",
    "ribborna": "ribba",
    "ribbornas": "ribba",
    "ribbors": "ribba",
    "ribbs": "ribba",
    "ribbstickade": "ribbstickad",
    "ribbstickades": "ribbstickad",
    "ribbstickads": "ribbstickad",
    "ribbstickat": "ribbstickad",
    "ribbstickats": "ribbstickad",
    "ribbstolar": "ribbstol",
    "ribbstolarna": "ribbstol",
    "ribbstolarnas": "ribbstol",
    "ribbstolars": "ribbstol",
    "ribbstolen": "ribbstol",
    "ribbstolens": "ribbstol",
    "ribbstols": "ribbstol",
    "ribbvalven": "ribbvalv",
    "ribbvalvens": "ribbvalv",
    "ribbvalvet": "ribbvalv",
    "ribbvalvets": "ribbvalv",
    "ribbvalvs": "ribbvalv",
    "riboflavinen": "riboflavin",
    "riboflavinens": "riboflavin",
    "riboflaviner": "riboflavin",
    "riboflavinerna": "riboflavin",
    "riboflavinernas": "riboflavin",
    "riboflaviners": "riboflavin",
    "riboflavins": "riboflavin",
    "ribosen": "ribos",
    "ribosens": "ribos",
    "ribosomen": "ribosom",
    "ribosomens": "ribosom",
    "ribosomer": "ribosom",
    "ribosomerna": "ribosom",
    "ribosomernas": "ribosom",
    "ribosomers": "ribosom",
    "ribosoms": "ribosom",
    "ricinbusk": "ricinbuske",
    "ricinbuskar": "ricinbuske",
    "ricinbuskarna": "ricinbuske",
    "ricinbuskarnas": "ricinbuske",
    "ricinbuskars": "ricinbuske",
    "ricinbusken": "ricinbuske",
    "ricinbuskens": "ricinbuske",
    "ricinbuskes": "ricinbuske",
    "ricinoljan": "ricinolja",
    "ricinoljans": "ricinolja",
    "ricinoljas": "ricinolja",
    "ricinolje": "ricinolja",
    "rick": "ricka",
    "rickade": "ricka",
    "rickades": "ricka",
    "rickande": "ricka",
    "rickanden": "rickande",
    "rickandena": "rickande",
    "rickandenas": "rickande",
    "rickandens": "rickande",
    "rickandes": "rickande",
    "rickandet": "rickande",
    "rickandets": "rickande",
    "rickar": "ricka",
    "rickas": "ricka",
    "rickat": "ricka",
    "rickats": "ricka",
    "rickettsien": "rickettsie",
    "rickettsiens": "rickettsie",
    "rickettsier": "rickettsie",
    "rickettsierna": "rickettsie",
    "rickettsiernas": "rickettsie",
    "rickettsiers": "rickettsie",
    "rickettsies": "rickettsie",
    "rickiga": "rickig",
    "rickigare": "rickig",
    "rickigares": "rickig",
    "rickigas": "rickig",
    "rickigast": "rickig",
    "rickigaste": "rickig",
    "rickigastes": "rickig",
    "rickigasts": "rickig",
    "rickige": "rickig",
    "rickiges": "rickig",
    "rickigheten": "rickighet",
    "rickighetens": "rickighet",
    "rickighets": "rickighet",
    "rickigs": "rickig",
    "rickigt": "rickig",
    "rickigts": "rickig",
    "rickshawer": "rickshaw",
    "rickshawerna": "rickshaw",
    "rickshawernas": "rickshaw",
    "rickshawers": "rickshaw",
    "rickshawn": "rickshaw",
    "rickshawns": "rickshaw",
    "rickshaws": "rickshaw",
    "rid": "rida",
    "ridande": "rida",
    "ridanden": "ridande",
    "ridandena": "ridande",
    "ridandenas": "ridande",
    "ridandens": "ridande",
    "ridandes": "ridande",
    "ridandet": "ridande",
    "ridandets": "ridande",
    "ridas": "rida",
    "ridbanan": "ridbana",
    "ridbanans": "ridbana",
    "ridbanas": "ridbana",
    "ridbane": "ridbana",
    "ridbanor": "ridbana",
    "ridbanorna": "ridbana",
    "ridbanornas": "ridbana",
    "ridbanors": "ridbana",
    "ridborgarmärken": "ridborgarmärke",
    "ridborgarmärkena": "ridborgarmärke",
    "ridborgarmärkenas": "ridborgarmärke",
    "ridborgarmärkens": "ridborgarmärke",
    "ridborgarmärkes": "ridborgarmärke",
    "ridborgarmärket": "ridborgarmärke",
    "ridborgarmärkets": "ridborgarmärke",
    "ridbyx": "ridbyxa",
    "ridbyxan": "ridbyxa",
    "ridbyxans": "ridbyxa",
    "ridbyxas": "ridbyxa",
    "ridbyxe": "ridbyxa",
    "ridbyxor": "ridbyxa",
    "ridbyxorna": "ridbyxa",
    "ridbyxornas": "ridbyxa",
    "ridbyxors": "ridbyxa",
    "riddar": "riddare",
    "riddaren": "riddare",
    "riddarens": "riddare",
    "riddares": "riddare",
    "riddarhusen": "riddarhus",
    "riddarhusens": "riddarhus",
    "riddarhuset": "riddarhus",
    "riddarhusets": "riddarhus",
    "riddarna": "riddare",
    "riddarnas": "riddare",
    "riddarordens": "riddarorden",
    "riddarordnar": "riddarorden",
    "riddarordnarna": "riddarorden",
    "riddarordnarnas": "riddarorden",
    "riddarordnars": "riddarorden",
    "riddarordnen": "riddarorden",
    "riddarordnens": "riddarorden",
    "riddarslagen": "riddarslag",
    "riddarslagens": "riddarslag",
    "riddarslaget": "riddarslag",
    "riddarslagets": "riddarslag",
    "riddarslags": "riddarslag",
    "riddarsporr": "riddarsporre",
    "riddarsporrar": "riddarsporre",
    "riddarsporrarna": "riddarsporre",
    "riddarsporrarnas": "riddarsporre",
    "riddarsporrars": "riddarsporre",
    "riddarsporren": "riddarsporre",
    "riddarsporrens": "riddarsporre",
    "riddarsporres": "riddarsporre",
    "riddarsporrs": "riddarsporre",
    "ridderliga": "ridderlig",
    "ridderligare": "ridderlig",
    "ridderligares": "ridderlig",
    "ridderligas": "ridderlig",
    "ridderligast": "ridderlig",
    "ridderligaste": "ridderlig",
    "ridderligastes": "ridderlig",
    "ridderligasts": "ridderlig",
    "ridderlige": "ridderlig",
    "ridderliges": "ridderlig",
    "ridderligheten": "ridderlighet",
    "ridderlighetens": "ridderlighet",
    "ridderlighets": "ridderlighet",
    "ridderligs": "ridderlig",
    "ridderligt": "ridderlig",
    "ridderligts": "ridderlig",
    "ridderskapet": "ridderskap",
    "ridderskapets": "ridderskap",
    "ridderskaps": "ridderskap",
    "riddersmannen": "riddersman",
    "riddersmannens": "riddersman",
    "riddersmans": "riddersman",
    "riddersmän": "riddersman",
    "riddersmännen": "riddersman",
    "riddersmännens": "riddersman",
    "riddersmäns": "riddersman",
    "riddräkten": "riddräkt",
    "riddräktens": "riddräkt",
    "riddräkter": "riddräkt",
    "riddräkterna": "riddräkt",
    "riddräkternas": "riddräkt",
    "riddräkters": "riddräkt",
    "riddräkts": "riddräkt",
    "ride": "rida",
    "riden": "rida",
    "ridens": "rida",
    "rider": "rida",
    "rides": "rida",
    "ridet": "rida",
    "ridets": "rida",
    "ridhusen": "ridhus",
    "ridhusens": "ridhus",
    "ridhuset": "ridhus",
    "ridhusets": "ridhus",
    "ridhästar": "ridhäst",
    "ridhästarna": "ridhäst",
    "ridhästarnas": "ridhäst",
    "ridhästars": "ridhäst",
    "ridhästdressyren": "ridhästdressyr",
    "ridhästdressyrens": "ridhästdressyr",
    "ridhästdressyrer": "ridhästdressyr",
    "ridhästdressyrerna": "ridhästdressyr",
    "ridhästdressyrernas": "ridhästdressyr",
    "ridhästdressyrers": "ridhästdressyr",
    "ridhästdressyrs": "ridhästdressyr",
    "ridhästen": "ridhäst",
    "ridhästens": "ridhäst",
    "ridhästs": "ridhäst",
    "ridikylen": "ridikyl",
    "ridikylens": "ridikyl",
    "ridikyler": "ridikyl",
    "ridikylerna": "ridikyl",
    "ridikylernas": "ridikyl",
    "ridikylers": "ridikyl",
    "ridikyls": "ridikyl",
    "ridinstruktören": "ridinstruktör",
    "ridinstruktörens": "ridinstruktör",
    "ridinstruktörer": "ridinstruktör",
    "ridinstruktörerna": "ridinstruktör",
    "ridinstruktörernas": "ridinstruktör",
    "ridinstruktörers": "ridinstruktör",
    "ridinstruktörn": "ridinstruktör",
    "ridinstruktörns": "ridinstruktör",
    "ridinstruktörs": "ridinstruktör",
    "ridit": "rida",
    "ridits": "rida",
    "ridkunniga": "ridkunnig",
    "ridkunnigare": "ridkunnig",
    "ridkunnigares": "ridkunnig",
    "ridkunnigas": "ridkunnig",
    "ridkunnigast": "ridkunnig",
    "ridkunnigaste": "ridkunnig",
    "ridkunnigastes": "ridkunnig",
    "ridkunnigasts": "ridkunnig",
    "ridkunnige": "ridkunnig",
    "ridkunniges": "ridkunnig",
    "ridkunnigheten": "ridkunnighet",
    "ridkunnighetens": "ridkunnighet",
    "ridkunnigheter": "ridkunnighet",
    "ridkunnigheterna": "ridkunnighet",
    "ridkunnigheternas": "ridkunnighet",
    "ridkunnigheters": "ridkunnighet",
    "ridkunnighets": "ridkunnighet",
    "ridkunnighetsproven": "ridkunnighetsprov",
    "ridkunnighetsprovens": "ridkunnighetsprov",
    "ridkunnighetsprovet": "ridkunnighetsprov",
    "ridkunnighetsprovets": "ridkunnighetsprov",
    "ridkunnighetsprovs": "ridkunnighetsprov",
    "ridkunnigs": "ridkunnig",
    "ridkunnigt": "ridkunnig",
    "ridkunnigts": "ridkunnig",
    "ridna": "rida",
    "ridnas": "rida",
    "ridne": "rida",
    "ridnes": "rida",
    "ridningar": "ridning",
    "ridningarna": "ridning",
    "ridningarnas": "ridning",
    "ridningars": "ridning",
    "ridningen": "ridning",
    "ridningens": "ridning",
    "ridnings": "ridning",
    "ridpisk": "ridpiska",
    "ridpiskan": "ridpiska",
    "ridpiskans": "ridpiska",
    "ridpiskas": "ridpiska",
    "ridpiske": "ridpiska",
    "ridpiskor": "ridpiska",
    "ridpiskorna": "ridpiska",
    "ridpiskornas": "ridpiska",
    "ridpiskors": "ridpiska",
    "rids": "rida",
    "ridskolan": "ridskola",
    "ridskolans": "ridskola",
    "ridskolas": "ridskola",
    "ridskole": "ridskola",
    "ridskolor": "ridskola",
    "ridskolorna": "ridskola",
    "ridskolornas": "ridskola",
    "ridskolors": "ridskola",
    "ridsporten": "ridsport",
    "ridsportens": "ridsport",
    "ridsports": "ridsport",
    "ridspöet": "ridspö",
    "ridspöets": "ridspö",
    "ridspön": "ridspö",
    "ridspöna": "ridspö",
    "ridspönas": "ridspö",
    "ridspöns": "ridspö",
    "ridspös": "ridspö",
    "ridspöt": "ridspö",
    "ridspöts": "ridspö",
    "ridstöveln": "ridstövel",
    "ridstövelns": "ridstövel",
    "ridstövels": "ridstövel",
    "ridstövlar": "ridstövel",
    "ridstövlarna": "ridstövel",
    "ridstövlarnas": "ridstövel",
    "ridstövlars": "ridstövel",
    "ridsåren": "ridsår",
    "ridsårens": "ridsår",
    "ridsåret": "ridsår",
    "ridsårets": "ridsår",
    "ridsårs": "ridsår",
    "ridturen": "ridtur",
    "ridturens": "ridtur",
    "ridturer": "ridtur",
    "ridturerna": "ridtur",
    "ridturernas": "ridtur",
    "ridturers": "ridtur",
    "ridturs": "ridtur",
    "ridtävlingar": "ridtävling",
    "ridtävlingarna": "ridtävling",
    "ridtävlingarnas": "ridtävling",
    "ridtävlingars": "ridtävling",
    "ridtävlingen": "ridtävling",
    "ridtävlingens": "ridtävling",
    "ridtävlings": "ridtävling",
    "ridvägar": "ridväg",
    "ridvägarna": "ridväg",
    "ridvägarnas": "ridväg",
    "ridvägars": "ridväg",
    "ridvägen": "ridväg",
    "ridvägens": "ridväg",
    "ridvägs": "ridväg",
    "ridåer": "ridå",
    "ridåerna": "ridå",
    "ridåernas": "ridå",
    "ridåers": "ridå",
    "ridåfallen": "ridåfall",
    "ridåfallens": "ridåfall",
    "ridåfallet": "ridåfall",
    "ridåfallets": "ridåfall",
    "ridåfalls": "ridåfall",
    "ridån": "ridå",
    "ridåns": "ridå",
    "ridås": "ridå",
    "rie": "ria",
    "rien": "ri",
    "riens": "ri",
    "riesenschnauzern": "riesenschnauzer",
    "riesenschnauzerns": "riesenschnauzer",
    "riesenschnauzers": "riesenschnauzer",
    "riesenschnauzrar": "riesenschnauzer",
    "riesenschnauzrarna": "riesenschnauzer",
    "riesenschnauzrarnas": "riesenschnauzer",
    "riesenschnauzrars": "riesenschnauzer",
    "riet": "ri",
    "riets": "ri",
    "riffen": "riff",
    "riffens": "riff",
    "riffet": "riff",
    "riffets": "riff",
    "riffs": "riff",
    "rififikuppen": "rififikupp",
    "rififikuppens": "rififikupp",
    "rififikupper": "rififikupp",
    "rififikupperna": "rififikupp",
    "rififikuppernas": "rififikupp",
    "rififikuppers": "rififikupp",
    "rififikupps": "rififikupp",
    "rigel": "rigla",
    "rigeln": "rigel",
    "rigelns": "rigel",
    "rigels": "rigel",
    "riggad": "rigga",
    "riggade": "rigga",
    "riggades": "rigga",
    "riggads": "rigga",
    "riggande": "rigga",
    "rigganden": "riggande",
    "riggandena": "riggande",
    "riggandenas": "riggande",
    "riggandens": "riggande",
    "riggandes": "riggande",
    "riggandet": "riggande",
    "riggandets": "riggande",
    "riggar": "rigga",
    "riggarna": "rigg",
    "riggarnas": "rigg",
    "riggars": "rigg",
    "riggas": "rigga",
    "riggat": "rigga",
    "riggats": "rigga",
    "riggen": "rigg",
    "riggens": "rigg",
    "riggs": "rigg",
    "rigida": "rigid",
    "rigidare": "rigid",
    "rigidares": "rigid",
    "rigidas": "rigid",
    "rigidast": "rigid",
    "rigidaste": "rigid",
    "rigidastes": "rigid",
    "rigidasts": "rigid",
    "rigide": "rigid",
    "rigides": "rigid",
    "rigids": "rigid",
    "riglad": "rigla",
    "riglade": "rigla",
    "riglades": "rigla",
    "riglads": "rigla",
    "riglande": "rigla",
    "riglanden": "riglande",
    "riglandena": "riglande",
    "riglandenas": "riglande",
    "riglandens": "riglande",
    "riglandes": "riglande",
    "riglandet": "riglande",
    "riglandets": "riglande",
    "riglar": "rigla",
    "riglarna": "rigel",
    "riglarnas": "rigel",
    "riglars": "rigel",
    "riglas": "rigla",
    "riglat": "rigla",
    "riglats": "rigla",
    "rigorismen": "rigorism",
    "rigorismens": "rigorism",
    "rigorismer": "rigorism",
    "rigorismerna": "rigorism",
    "rigorismernas": "rigorism",
    "rigorismers": "rigorism",
    "rigorisms": "rigorism",
    "rigorösa": "rigorös",
    "rigorösare": "rigorös",
    "rigorösares": "rigorös",
    "rigorösas": "rigorös",
    "rigorösast": "rigorös",
    "rigorösaste": "rigorös",
    "rigorösastes": "rigorös",
    "rigorösasts": "rigorös",
    "rigoröse": "rigorös",
    "rigoröses": "rigorös",
    "rigoröst": "rigorös",
    "rigorösts": "rigorös",
    "rika": "rik",
    "rikare": "rik",
    "rikares": "rik",
    "rikas": "rik",
    "rikast": "rik",
    "rikaste": "rik",
    "rikastes": "rik",
    "rikasts": "rik",
    "rike": "rik",
    "rikedomar": "rikedom",
    "rikedomarna": "rikedom",
    "rikedomarnas": "rikedom",
    "rikedomars": "rikedom",
    "rikedomen": "rikedom",
    "rikedomens": "rikedom",
    "rikedoms": "rikedom",
    "rikemannen": "rikeman",
    "rikemannens": "rikeman",
    "rikemans": "rikeman",
    "rikemansbarnen": "rikemansbarn",
    "rikemansbarnens": "rikemansbarn",
    "rikemansbarnet": "rikemansbarn",
    "rikemansbarnets": "rikemansbarn",
    "rikemansbarns": "rikemansbarn",
    "rikemän": "rikeman",
    "rikemännen": "rikeman",
    "rikemännens": "rikeman",
    "rikemäns": "rikeman",
    "riken": "rike",
    "rikena": "rike",
    "rikenas": "rike",
    "rikens": "rike",
    "rikes": "rike",
    "riket": "rike",
    "rikets": "rike",
    "rikhaltiga": "rikhaltig",
    "rikhaltigare": "rikhaltig",
    "rikhaltigares": "rikhaltig",
    "rikhaltigas": "rikhaltig",
    "rikhaltigast": "rikhaltig",
    "rikhaltigaste": "rikhaltig",
    "rikhaltigastes": "rikhaltig",
    "rikhaltigasts": "rikhaltig",
    "rikhaltige": "rikhaltig",
    "rikhaltiges": "rikhaltig",
    "rikhaltigheten": "rikhaltighet",
    "rikhaltighetens": "rikhaltighet",
    "rikhaltighets": "rikhaltighet",
    "rikhaltigs": "rikhaltig",
    "rikhaltigt": "rikhaltig",
    "rikhaltigts": "rikhaltig",
    "rikheten": "rikhet",
    "rikhetens": "rikhet",
    "rikhets": "rikhet",
    "rikliga": "riklig",
    "rikligare": "riklig",
    "rikligares": "riklig",
    "rikligas": "riklig",
    "rikligast": "riklig",
    "rikligaste": "riklig",
    "rikligastes": "riklig",
    "rikligasts": "riklig",
    "riklige": "riklig",
    "rikliges": "riklig",
    "rikligheten": "riklighet",
    "riklighetens": "riklighet",
    "riklighets": "riklighet",
    "rikligs": "riklig",
    "rikligt": "riklig",
    "rikligts": "riklig",
    "rikoschetten": "rikoschett",
    "rikoschettens": "rikoschett",
    "rikoschetter": "rikoschett",
    "rikoschetterad": "rikoschettera",
    "rikoschetterade": "rikoschettera",
    "rikoschetterades": "rikoschettera",
    "rikoschetterads": "rikoschettera",
    "rikoschetterande": "rikoschettera",
    "rikoschetteranden": "rikoschetterande",
    "rikoschetterandena": "rikoschetterande",
    "rikoschetterandenas": "rikoschetterande",
    "rikoschetterandens": "rikoschetterande",
    "rikoschetterandes": "rikoschetterande",
    "rikoschetterandet": "rikoschetterande",
    "rikoschetterandets": "rikoschetterande",
    "rikoschetterar": "rikoschettera",
    "rikoschetteras": "rikoschettera",
    "rikoschetterat": "rikoschettera",
    "rikoschetterats": "rikoschettera",
    "rikoschetteringar": "rikoschettering",
    "rikoschetteringarna": "rikoschettering",
    "rikoschetteringarnas": "rikoschettering",
    "rikoschetteringars": "rikoschettering",
    "rikoschetteringen": "rikoschettering",
    "rikoschetteringens": "rikoschettering",
    "rikoschetterings": "rikoschettering",
    "rikoschetterna": "rikoschett",
    "rikoschetternas": "rikoschett",
    "rikoschetters": "rikoschett",
    "rikoschetts": "rikoschett",
    "riks": "rike",
    "riksangelägenheten": "riksangelägenhet",
    "riksangelägenhetens": "riksangelägenhet",
    "riksangelägenheter": "riksangelägenhet",
    "riksangelägenheterna": "riksangelägenhet",
    "riksangelägenheternas": "riksangelägenhet",
    "riksangelägenheters": "riksangelägenhet",
    "riksangelägenhets": "riksangelägenhet",
    "riksantikvarien": "riksantikvarie",
    "riksantikvariens": "riksantikvarie",
    "riksantikvarier": "riksantikvarie",
    "riksantikvarierna": "riksantikvarie",
    "riksantikvariernas": "riksantikvarie",
    "riksantikvariers": "riksantikvarie",
    "riksantikvaries": "riksantikvarie",
    "riksarkivarien": "riksarkivarie",
    "riksarkivariens": "riksarkivarie",
    "riksarkivarier": "riksarkivarie",
    "riksarkivarierna": "riksarkivarie",
    "riksarkivariernas": "riksarkivarie",
    "riksarkivariers": "riksarkivarie",
    "riksarkivaries": "riksarkivarie",
    "riksarkiven": "riksarkiv",
    "riksarkivens": "riksarkiv",
    "riksarkivet": "riksarkiv",
    "riksarkivets": "riksarkiv",
    "riksarkivs": "riksarkiv",
    "riksbanken": "riksbank",
    "riksbankens": "riksbank",
    "riksbanker": "riksbank",
    "riksbankerna": "riksbank",
    "riksbankernas": "riksbank",
    "riksbankers": "riksbank",
    "riksbanks": "riksbank",
    "riksbekanta": "riksbekant",
    "riksbekantare": "riksbekant",
    "riksbekantares": "riksbekant",
    "riksbekantas": "riksbekant",
    "riksbekantast": "riksbekant",
    "riksbekantaste": "riksbekant",
    "riksbekantastes": "riksbekant",
    "riksbekantasts": "riksbekant",
    "riksbekante": "riksbekant",
    "riksbekantes": "riksbekant",
    "riksbekants": "riksbekant",
    "riksbibliotekarien": "riksbibliotekarie",
    "riksbibliotekariens": "riksbibliotekarie",
    "riksbibliotekarier": "riksbibliotekarie",
    "riksbibliotekarierna": "riksbibliotekarie",
    "riksbibliotekariernas": "riksbibliotekarie",
    "riksbibliotekariers": "riksbibliotekarie",
    "riksbibliotekaries": "riksbibliotekarie",
    "riksbyggar": "riksbyggare",
    "riksbyggaren": "riksbyggare",
    "riksbyggarens": "riksbyggare",
    "riksbyggares": "riksbyggare",
    "riksbyggarna": "riksbyggare",
    "riksbyggarnas": "riksbyggare",
    "riksdagar": "riksdag",
    "riksdagarna": "riksdag",
    "riksdagarnas": "riksdag",
    "riksdagars": "riksdag",
    "riksdagen": "riksdag",
    "riksdagens": "riksdag",
    "riksdags": "riksdag",
    "riksdagsdebatten": "riksdagsdebatt",
    "riksdagsdebattens": "riksdagsdebatt",
    "riksdagsdebatter": "riksdagsdebatt",
    "riksdagsdebatterna": "riksdagsdebatt",
    "riksdagsdebatternas": "riksdagsdebatt",
    "riksdagsdebatters": "riksdagsdebatt",
    "riksdagsdebatts": "riksdagsdebatt",
    "riksdagsgruppen": "riksdagsgrupp",
    "riksdagsgruppens": "riksdagsgrupp",
    "riksdagsgrupper": "riksdagsgrupp",
    "riksdagsgrupperna": "riksdagsgrupp",
    "riksdagsgruppernas": "riksdagsgrupp",
    "riksdagsgruppers": "riksdagsgrupp",
    "riksdagsgrupps": "riksdagsgrupp",
    "riksdagshusen": "riksdagshus",
    "riksdagshusens": "riksdagshus",
    "riksdagshuset": "riksdagshus",
    "riksdagshusets": "riksdagshus",
    "riksdagskvinnan": "riksdagskvinna",
    "riksdagskvinnans": "riksdagskvinna",
    "riksdagskvinnas": "riksdagskvinna",
    "riksdagskvinne": "riksdagskvinna",
    "riksdagskvinno": "riksdagskvinna",
    "riksdagskvinnor": "riksdagskvinna",
    "riksdagskvinnorna": "riksdagskvinna",
    "riksdagskvinnornas": "riksdagskvinna",
    "riksdagskvinnors": "riksdagskvinna",
    "riksdagsledamoten": "riksdagsledamot",
    "riksdagsledamotens": "riksdagsledamot",
    "riksdagsledamots": "riksdagsledamot",
    "riksdagsledamöter": "riksdagsledamot",
    "riksdagsledamöterna": "riksdagsledamot",
    "riksdagsledamöternas": "riksdagsledamot",
    "riksdagsledamöters": "riksdagsledamot",
    "riksdagsmandaten": "riksdagsmandat",
    "riksdagsmandatens": "riksdagsmandat",
    "riksdagsmandatet": "riksdagsmandat",
    "riksdagsmandatets": "riksdagsmandat",
    "riksdagsmandats": "riksdagsmandat",
    "riksdagsmannen": "riksdagsman",
    "riksdagsmannens": "riksdagsman",
    "riksdagsmans": "riksdagsman",
    "riksdagsmän": "riksdagsman",
    "riksdagsmännen": "riksdagsman",
    "riksdagsmännens": "riksdagsman",
    "riksdagsmäns": "riksdagsman",
    "riksdagsordningar": "riksdagsordning",
    "riksdagsordningarna": "riksdagsordning",
    "riksdagsordningarnas": "riksdagsordning",
    "riksdagsordningars": "riksdagsordning",
    "riksdagsordningen": "riksdagsordning",
    "riksdagsordningens": "riksdagsordning",
    "riksdagsordnings": "riksdagsordning",
    "riksdagspartier": "riksdagsparti",
    "riksdagspartierna": "riksdagsparti",
    "riksdagspartiernas": "riksdagsparti",
    "riksdagspartiers": "riksdagsparti",
    "riksdagspartiet": "riksdagsparti",
    "riksdagspartiets": "riksdagsparti",
    "riksdagspartis": "riksdagsparti",
    "riksdagspartit": "riksdagsparti",
    "riksdagspartits": "riksdagsparti",
    "riksdagsplatsen": "riksdagsplats",
    "riksdagsplatsens": "riksdagsplats",
    "riksdagsplatser": "riksdagsplats",
    "riksdagsplatserna": "riksdagsplats",
    "riksdagsplatsernas": "riksdagsplats",
    "riksdagsplatsers": "riksdagsplats",
    "riksdagsprotokollen": "riksdagsprotokoll",
    "riksdagsprotokollens": "riksdagsprotokoll",
    "riksdagsprotokollet": "riksdagsprotokoll",
    "riksdagsprotokollets": "riksdagsprotokoll",
    "riksdagsprotokolls": "riksdagsprotokoll",
    "riksdagssammanträden": "riksdagssammanträde",
    "riksdagssammanträdena": "riksdagssammanträde",
    "riksdagssammanträdenas": "riksdagssammanträde",
    "riksdagssammanträdens": "riksdagssammanträde",
    "riksdagssammanträdes": "riksdagssammanträde",
    "riksdagssammanträdet": "riksdagssammanträde",
    "riksdagssammanträdets": "riksdagssammanträde",
    "riksdagsspärrar": "riksdagsspärr",
    "riksdagsspärrarna": "riksdagsspärr",
    "riksdagsspärrarnas": "riksdagsspärr",
    "riksdagsspärrars": "riksdagsspärr",
    "riksdagsspärren": "riksdagsspärr",
    "riksdagsspärrens": "riksdagsspärr",
    "riksdagsspärrs": "riksdagsspärr",
    "riksdagsvalen": "riksdagsval",
    "riksdagsvalens": "riksdagsval",
    "riksdagsvalet": "riksdagsval",
    "riksdagsvalets": "riksdagsval",
    "riksdagsvals": "riksdagsval",
    "riksdalern": "riksdaler",
    "riksdalerna": "riksdaler",
    "riksdalernas": "riksdaler",
    "riksdalerns": "riksdaler",
    "riksdalers": "riksdaler",
    "riksen": "riks",
    "riksens": "riks",
    "rikset": "riks",
    "riksets": "riks",
    "riksförbunden": "riksförbund",
    "riksförbundens": "riksförbund",
    "riksförbundet": "riksförbund",
    "riksförbundets": "riksförbund",
    "riksförbunds": "riksförbund",
    "riksföreståndar": "riksföreståndare",
    "riksföreståndaren": "riksföreståndare",
    "riksföreståndarens": "riksföreståndare",
    "riksföreståndares": "riksföreståndare",
    "riksföreståndarna": "riksföreståndare",
    "riksföreståndarnas": "riksföreståndare",
    "riksgenomsnitten": "riksgenomsnitt",
    "riksgenomsnittens": "riksgenomsnitt",
    "riksgenomsnittet": "riksgenomsnitt",
    "riksgenomsnittets": "riksgenomsnitt",
    "riksgenomsnitts": "riksgenomsnitt",
    "riksgränsen": "riksgräns",
    "riksgränsens": "riksgräns",
    "riksgränser": "riksgräns",
    "riksgränserna": "riksgräns",
    "riksgränsernas": "riksgräns",
    "riksgränsers": "riksgräns",
    "riksgälden": "riksgäld",
    "riksgäldens": "riksgäld",
    "riksgälds": "riksgäld",
    "riksh": "riksha",
    "rikshan": "riksha",
    "rikshans": "riksha",
    "rikshas": "riksha",
    "rikshe": "riksha",
    "rikshor": "riksha",
    "rikshorna": "riksha",
    "rikshornas": "riksha",
    "rikshors": "riksha",
    "riksintressen": "riksintresse",
    "riksintressena": "riksintresse",
    "riksintressenas": "riksintresse",
    "riksintressens": "riksintresse",
    "riksintresses": "riksintresse",
    "riksintresset": "riksintresse",
    "riksintressets": "riksintresse",
    "rikskanslerer": "rikskansler",
    "rikskanslererna": "rikskansler",
    "rikskanslerernas": "rikskansler",
    "rikskanslerers": "rikskansler",
    "rikskanslern": "rikskansler",
    "rikskanslerns": "rikskansler",
    "rikskanslers": "rikskansler",
    "rikslikar": "rikslikare",
    "rikslikaren": "rikslikare",
    "rikslikarens": "rikslikare",
    "rikslikares": "rikslikare",
    "rikslikarna": "rikslikare",
    "rikslikarnas": "rikslikare",
    "riksmarskalkar": "riksmarskalk",
    "riksmarskalkarna": "riksmarskalk",
    "riksmarskalkarnas": "riksmarskalk",
    "riksmarskalkars": "riksmarskalk",
    "riksmarskalken": "riksmarskalk",
    "riksmarskalkens": "riksmarskalk",
    "riksmarskalks": "riksmarskalk",
    "riksmålet": "riksmål",
    "riksmålets": "riksmål",
    "riksmåls": "riksmål",
    "riksmöten": "riksmöte",
    "riksmötena": "riksmöte",
    "riksmötenas": "riksmöte",
    "riksmötens": "riksmöte",
    "riksmötes": "riksmöte",
    "riksmötet": "riksmöte",
    "riksmötets": "riksmöte",
    "riksnyckeln": "riksnyckel",
    "riksnyckelns": "riksnyckel",
    "riksnyckels": "riksnyckel",
    "riksnycklar": "riksnyckel",
    "riksnycklarna": "riksnyckel",
    "riksnycklarnas": "riksnyckel",
    "riksnycklars": "riksnyckel",
    "riksnäten": "riksnät",
    "riksnätens": "riksnät",
    "riksnätet": "riksnät",
    "riksnätets": "riksnät",
    "riksnäts": "riksnät",
    "riksolyck": "riksolycka",
    "riksolyckan": "riksolycka",
    "riksolyckans": "riksolycka",
    "riksolyckas": "riksolycka",
    "riksolycke": "riksolycka",
    "riksolyckor": "riksolycka",
    "riksolyckorna": "riksolycka",
    "riksolyckornas": "riksolycka",
    "riksolyckors": "riksolycka",
    "riksolycks": "riksolycka",
    "riksorganisationen": "riksorganisation",
    "riksorganisationens": "riksorganisation",
    "riksorganisationer": "riksorganisation",
    "riksorganisationerna": "riksorganisation",
    "riksorganisationernas": "riksorganisation",
    "riksorganisationers": "riksorganisation",
    "riksorganisations": "riksorganisation",
    "riksplaneringar": "riksplanering",
    "riksplaneringarna": "riksplanering",
    "riksplaneringarnas": "riksplanering",
    "riksplaneringars": "riksplanering",
    "riksplaneringen": "riksplanering",
    "riksplaneringens": "riksplanering",
    "riksplanerings": "riksplanering",
    "riksplanet": "riksplan",
    "riksplanets": "riksplan",
    "riksplans": "riksplan",
    "rikspolitiken": "rikspolitik",
    "rikspolitikens": "rikspolitik",
    "rikspolitiks": "rikspolitik",
    "rikspolitiska": "rikspolitisk",
    "rikspolitiskas": "rikspolitisk",
    "rikspolitiske": "rikspolitisk",
    "rikspolitiskes": "rikspolitisk",
    "rikspolitisks": "rikspolitisk",
    "rikspolitiskt": "rikspolitisk",
    "rikspolitiskts": "rikspolitisk",
    "riksprototypen": "riksprototyp",
    "riksprototypens": "riksprototyp",
    "riksprototyper": "riksprototyp",
    "riksprototyperna": "riksprototyp",
    "riksprototypernas": "riksprototyp",
    "riksprototypers": "riksprototyp",
    "riksprototyps": "riksprototyp",
    "riksregalie": "riksregalier",
    "riksregalierna": "riksregalier",
    "riksregaliernas": "riksregalier",
    "riksregaliers": "riksregalier",
    "riksrätten": "riksrätt",
    "riksrättens": "riksrätt",
    "riksrätter": "riksrätt",
    "riksrätterna": "riksrätt",
    "riksrätternas": "riksrätt",
    "riksrätters": "riksrätt",
    "riksrätts": "riksrätt",
    "riksråden": "riksråd",
    "riksrådens": "riksråd",
    "riksrådet": "riksråd",
    "riksrådets": "riksråd",
    "riksråds": "riksråd",
    "riksrös": "riksröse",
    "riksrösen": "riksröse",
    "riksrösena": "riksröse",
    "riksrösenas": "riksröse",
    "riksrösens": "riksröse",
    "riksröses": "riksröse",
    "riksröset": "riksröse",
    "riksrösets": "riksröse",
    "rikssamtalen": "rikssamtal",
    "rikssamtalens": "rikssamtal",
    "rikssamtalet": "rikssamtal",
    "rikssamtalets": "rikssamtal",
    "rikssamtals": "rikssamtal",
    "riksspråken": "riksspråk",
    "riksspråkens": "riksspråk",
    "riksspråket": "riksspråk",
    "riksspråkets": "riksspråk",
    "riksspråks": "riksspråk",
    "riksstaten": "riksstat",
    "riksstatens": "riksstat",
    "riksstats": "riksstat",
    "riksstämman": "riksstämma",
    "riksstämmans": "riksstämma",
    "riksstämmas": "riksstämma",
    "riksstämme": "riksstämma",
    "riksstämmo": "riksstämma",
    "riksstämmor": "riksstämma",
    "riksstämmorna": "riksstämma",
    "riksstämmornas": "riksstämma",
    "riksstämmors": "riksstämma",
    "rikssvensk": "rikssvenska",
    "rikssvenska": "rikssvensk",
    "rikssvenskan": "rikssvenska",
    "rikssvenskans": "rikssvenska",
    "rikssvenskare": "rikssvensk",
    "rikssvenskares": "rikssvensk",
    "rikssvenskas": "rikssvenska",
    "rikssvenskast": "rikssvensk",
    "rikssvenskaste": "rikssvensk",
    "rikssvenskastes": "rikssvensk",
    "rikssvenskasts": "rikssvensk",
    "rikssvenske": "rikssvensk",
    "rikssvenskes": "rikssvensk",
    "rikssvensks": "rikssvensk",
    "rikssvenskt": "rikssvensk",
    "rikssvenskts": "rikssvensk",
    "rikssvärdet": "rikssvärd",
    "rikssvärdets": "rikssvärd",
    "rikssvärds": "rikssvärd",
    "rikstidningar": "rikstidning",
    "rikstidningarna": "rikstidning",
    "rikstidningarnas": "rikstidning",
    "rikstidningars": "rikstidning",
    "rikstidningen": "rikstidning",
    "rikstidningens": "rikstidning",
    "rikstidnings": "rikstidning",
    "riksuttagen": "riksuttag",
    "riksuttagens": "riksuttag",
    "riksuttaget": "riksuttag",
    "riksuttagets": "riksuttag",
    "riksuttags": "riksuttag",
    "riksvapens": "riksvapen",
    "riksvapnen": "riksvapen",
    "riksvapnens": "riksvapen",
    "riksvapnet": "riksvapen",
    "riksvapnets": "riksvapen",
    "riksviktiga": "riksviktig",
    "riksviktigare": "riksviktig",
    "riksviktigares": "riksviktig",
    "riksviktigas": "riksviktig",
    "riksviktigast": "riksviktig",
    "riksviktigaste": "riksviktig",
    "riksviktigastes": "riksviktig",
    "riksviktigasts": "riksviktig",
    "riksviktige": "riksviktig",
    "riksviktiges": "riksviktig",
    "riksviktigheten": "riksviktighet",
    "riksviktighetens": "riksviktighet",
    "riksviktighets": "riksviktighet",
    "riksviktigs": "riksviktig",
    "riksviktigt": "riksviktig",
    "riksviktigts": "riksviktig",
    "riksvägar": "riksväg",
    "riksvägarna": "riksväg",
    "riksvägarnas": "riksväg",
    "riksvägars": "riksväg",
    "riksvägen": "riksväg",
    "riksvägens": "riksväg",
    "riksvägs": "riksväg",
    "riksäpples": "riksäpple",
    "riksäpplet": "riksäpple",
    "riksäpplets": "riksäpple",
    "riksåklagar": "riksåklagare",
    "riksåklagaren": "riksåklagare",
    "riksåklagarens": "riksåklagare",
    "riksåklagares": "riksåklagare",
    "riksåklagarna": "riksåklagare",
    "riksåklagarnas": "riksåklagare",
    "rikt": "rikta",
    "riktad": "rikta",
    "riktade": "rikta",
    "riktades": "rikta",
    "riktads": "rikta",
    "riktande": "rikta",
    "riktanden": "riktande",
    "riktandena": "riktande",
    "riktandenas": "riktande",
    "riktandens": "riktande",
    "riktandes": "riktande",
    "riktandet": "riktande",
    "riktandets": "riktande",
    "riktar": "rikta",
    "riktas": "rikta",
    "riktat": "rikta",
    "riktats": "rikta",
    "rikthyveln": "rikthyvel",
    "rikthyvelns": "rikthyvel",
    "rikthyvels": "rikthyvel",
    "rikthyvlar": "rikthyvel",
    "rikthyvlarna": "rikthyvel",
    "rikthyvlarnas": "rikthyvel",
    "rikthyvlars": "rikthyvel",
    "riktiga": "riktig",
    "riktigare": "riktig",
    "riktigares": "riktig",
    "riktigas": "riktig",
    "riktigast": "riktig",
    "riktigaste": "riktig",
    "riktigastes": "riktig",
    "riktigasts": "riktig",
    "riktige": "riktig",
    "riktiges": "riktig",
    "riktigheten": "riktighet",
    "riktighetens": "riktighet",
    "riktigheter": "riktighet",
    "riktigheterna": "riktighet",
    "riktigheternas": "riktighet",
    "riktigheters": "riktighet",
    "riktighets": "riktighet",
    "riktigs": "riktig",
    "riktigt": "riktig",
    "riktigts": "riktig",
    "riktinstrumenten": "riktinstrument",
    "riktinstrumentens": "riktinstrument",
    "riktinstrumentet": "riktinstrument",
    "riktinstrumentets": "riktinstrument",
    "riktinstruments": "riktinstrument",
    "riktkarlar": "riktkarl",
    "riktkarlarna": "riktkarl",
    "riktkarlarnas": "riktkarl",
    "riktkarlars": "riktkarl",
    "riktkarlen": "riktkarl",
    "riktkarlens": "riktkarl",
    "riktkarls": "riktkarl",
    "riktlinjen": "riktlinje",
    "riktlinjens": "riktlinje",
    "riktlinjer": "riktlinje",
    "riktlinjerna": "riktlinje",
    "riktlinjernas": "riktlinje",
    "riktlinjers": "riktlinje",
    "riktlinjes": "riktlinje",
    "riktmedels": "riktmedel",
    "riktmedlen": "riktmedel",
    "riktmedlens": "riktmedel",
    "riktmedlet": "riktmedel",
    "riktmedlets": "riktmedel",
    "riktmärken": "riktmärke",
    "riktmärkena": "riktmärke",
    "riktmärkenas": "riktmärke",
    "riktmärkens": "riktmärke",
    "riktmärkes": "riktmärke",
    "riktmärket": "riktmärke",
    "riktmärkets": "riktmärke",
    "riktningar": "riktning",
    "riktningarna": "riktning",
    "riktningarnas": "riktning",
    "riktningars": "riktning",
    "riktningen": "riktning",
    "riktningens": "riktning",
    "riktnings": "riktning",
    "riktningskoefficienten": "riktningskoefficient",
    "riktningskoefficientens": "riktningskoefficient",
    "riktningskoefficienter": "riktningskoefficient",
    "riktningskoefficienterna": "riktningskoefficient",
    "riktningskoefficienternas": "riktningskoefficient",
    "riktningskoefficienters": "riktningskoefficient",
    "riktningskoefficients": "riktningskoefficient",
    "riktnummerna": "riktnummer",
    "riktnummernas": "riktnummer",
    "riktnummers": "riktnummer",
    "riktnumren": "riktnummer",
    "riktnumrens": "riktnummer",
    "riktnumret": "riktnummer",
    "riktnumrets": "riktnummer",
    "riktprisen": "riktpris",
    "riktprisens": "riktpris",
    "riktpriser": "riktpris",
    "riktpriserna": "riktpris",
    "riktprisernas": "riktpris",
    "riktprisers": "riktpris",
    "riktpriset": "riktpris",
    "riktprisets": "riktpris",
    "riktpunkten": "riktpunkt",
    "riktpunktens": "riktpunkt",
    "riktpunkter": "riktpunkt",
    "riktpunkterna": "riktpunkt",
    "riktpunkternas": "riktpunkt",
    "riktpunkters": "riktpunkt",
    "riktpunkts": "riktpunkt",
    "rikts": "rik",
    "rimflätningar": "rimflätning",
    "rimflätningarna": "rimflätning",
    "rimflätningarnas": "rimflätning",
    "rimflätningars": "rimflätning",
    "rimflätningen": "rimflätning",
    "rimflätningens": "rimflätning",
    "rimflätnings": "rimflätning",
    "rimfrosten": "rimfrost",
    "rimfrostens": "rimfrost",
    "rimfrosts": "rimfrost",
    "rimkrönik": "rimkrönika",
    "rimkrönikan": "rimkrönika",
    "rimkrönikans": "rimkrönika",
    "rimkrönikas": "rimkrönika",
    "rimkrönike": "rimkrönika",
    "rimkrönikor": "rimkrönika",
    "rimkrönikorna": "rimkrönika",
    "rimkrönikornas": "rimkrönika",
    "rimkrönikors": "rimkrönika",
    "rimkröniks": "rimkrönika",
    "rimlexika": "rimlexikon",
    "rimlexikas": "rimlexikon",
    "rimlexikonen": "rimlexikon",
    "rimlexikonens": "rimlexikon",
    "rimlexikonet": "rimlexikon",
    "rimlexikonets": "rimlexikon",
    "rimlexikons": "rimlexikon",
    "rimliga": "rimlig",
    "rimligare": "rimlig",
    "rimligares": "rimlig",
    "rimligas": "rimlig",
    "rimligast": "rimlig",
    "rimligaste": "rimlig",
    "rimligastes": "rimlig",
    "rimligasts": "rimlig",
    "rimlige": "rimlig",
    "rimliges": "rimlig",
    "rimligheten": "rimlighet",
    "rimlighetens": "rimlighet",
    "rimligheter": "rimlighet",
    "rimligheterna": "rimlighet",
    "rimligheternas": "rimlighet",
    "rimligheters": "rimlighet",
    "rimlighets": "rimlighet",
    "rimligs": "rimlig",
    "rimligt": "rimlig",
    "rimligts": "rimlig",
    "rimmad": "rimma",
    "rimmade": "rimma",
    "rimmades": "rimma",
    "rimmads": "rimma",
    "rimmande": "rimma",
    "rimmanden": "rimmande",
    "rimmandena": "rimmande",
    "rimmandenas": "rimmande",
    "rimmandens": "rimmande",
    "rimmandes": "rimmande",
    "rimmandet": "rimmande",
    "rimmandets": "rimmande",
    "rimmar": "rimma",
    "rimmas": "rimma",
    "rimmat": "rimma",
    "rimmats": "rimma",
    "rimmen": "rim",
    "rimmens": "rim",
    "rimmet": "rim",
    "rimmets": "rim",
    "rims": "rim",
    "rimsalt": "rimsalta",
    "rimsaltad": "rimsalta",
    "rimsaltade": "rimsalta",
    "rimsaltades": "rimsalta",
    "rimsaltads": "rimsalta",
    "rimsaltande": "rimsalta",
    "rimsaltanden": "rimsaltande",
    "rimsaltandena": "rimsaltande",
    "rimsaltandenas": "rimsaltande",
    "rimsaltandens": "rimsaltande",
    "rimsaltandes": "rimsaltande",
    "rimsaltandet": "rimsaltande",
    "rimsaltandets": "rimsaltande",
    "rimsaltar": "rimsalta",
    "rimsaltas": "rimsalta",
    "rimsaltat": "rimsalta",
    "rimsaltats": "rimsalta",
    "rimsmeden": "rimsmed",
    "rimsmedens": "rimsmed",
    "rimsmeder": "rimsmed",
    "rimsmederna": "rimsmed",
    "rimsmedernas": "rimsmed",
    "rimsmeders": "rimsmed",
    "rimsmeds": "rimsmed",
    "rimtursar": "rimturs",
    "rimtursarna": "rimturs",
    "rimtursarnas": "rimturs",
    "rimtursars": "rimturs",
    "rimtursen": "rimturs",
    "rimtursens": "rimturs",
    "rin": "ri",
    "rina": "ri",
    "rinas": "ri",
    "rindläders": "rindläder",
    "rindlädret": "rindläder",
    "rindlädrets": "rindläder",
    "ring": "ringa",
    "ringad": "ringa",
    "ringade": "ringa",
    "ringades": "ringa",
    "ringads": "ringa",
    "ringakt": "ringakta",
    "ringaktad": "ringakta",
    "ringaktade": "ringakta",
    "ringaktades": "ringakta",
    "ringaktads": "ringakta",
    "ringaktande": "ringakta",
    "ringaktanden": "ringaktande",
    "ringaktandena": "ringaktande",
    "ringaktandenas": "ringaktande",
    "ringaktandens": "ringaktande",
    "ringaktandes": "ringaktande",
    "ringaktandet": "ringaktande",
    "ringaktandets": "ringaktande",
    "ringaktar": "ringakta",
    "ringaktas": "ringakta",
    "ringaktat": "ringakta",
    "ringaktats": "ringakta",
    "ringaktningar": "ringaktning",
    "ringaktningarna": "ringaktning",
    "ringaktningarnas": "ringaktning",
    "ringaktningars": "ringaktning",
    "ringaktningen": "ringaktning",
    "ringaktningens": "ringaktning",
    "ringaktnings": "ringaktning",
    "ringande": "ringa",
    "ringanden": "ringande",
    "ringandena": "ringande",
    "ringandenas": "ringande",
    "ringandens": "ringande",
    "ringandes": "ringande",
    "ringandet": "ringande",
    "ringandets": "ringande",
    "ringar": "ringare",
    "ringaren": "ringare",
    "ringarens": "ringare",
    "ringares": "ringare",
    "ringarna": "ringare",
    "ringarnas": "ringare",
    "ringars": "ring",
    "ringarten": "ringart",
    "ringartens": "ringart",
    "ringarter": "ringart",
    "ringarterna": "ringart",
    "ringarternas": "ringart",
    "ringarters": "ringart",
    "ringarts": "ringart",
    "ringas": "ringa",
    "ringasta": "ringast",
    "ringastas": "ringast",
    "ringaste": "ringast",
    "ringastes": "ringast",
    "ringasts": "ringast",
    "ringat": "ringa",
    "ringats": "ringa",
    "ringbark": "ringbarka",
    "ringbarkad": "ringbarka",
    "ringbarkade": "ringbarka",
    "ringbarkades": "ringbarka",
    "ringbarkads": "ringbarka",
    "ringbarkande": "ringbarka",
    "ringbarkanden": "ringbarkande",
    "ringbarkandena": "ringbarkande",
    "ringbarkandenas": "ringbarkande",
    "ringbarkandens": "ringbarkande",
    "ringbarkandes": "ringbarkande",
    "ringbarkandet": "ringbarkande",
    "ringbarkandets": "ringbarkande",
    "ringbarkar": "ringbarka",
    "ringbarkas": "ringbarka",
    "ringbarkat": "ringbarka",
    "ringbarkats": "ringbarka",
    "ringbergen": "ringberg",
    "ringbergens": "ringberg",
    "ringberget": "ringberg",
    "ringbergets": "ringberg",
    "ringbergs": "ringberg",
    "ringblom": "ringblomma",
    "ringblomman": "ringblomma",
    "ringblommans": "ringblomma",
    "ringblommas": "ringblomma",
    "ringblomme": "ringblomma",
    "ringblommor": "ringblomma",
    "ringblommorna": "ringblomma",
    "ringblommornas": "ringblomma",
    "ringblommors": "ringblomma",
    "ringbloms": "ringblomma",
    "ringbrosken": "ringbrosk",
    "ringbroskens": "ringbrosk",
    "ringbrosket": "ringbrosk",
    "ringbroskets": "ringbrosk",
    "ringbrosks": "ringbrosk",
    "ringbrynjan": "ringbrynja",
    "ringbrynjans": "ringbrynja",
    "ringbrynjas": "ringbrynja",
    "ringbrynje": "ringbrynja",
    "ringbrynjor": "ringbrynja",
    "ringbrynjorna": "ringbrynja",
    "ringbrynjornas": "ringbrynja",
    "ringbrynjors": "ringbrynja",
    "ringd": "ringa",
    "ringda": "ringa",
    "ringdansen": "ringdans",
    "ringdansens": "ringdans",
    "ringdanser": "ringdans",
    "ringdanserna": "ringdans",
    "ringdansernas": "ringdans",
    "ringdansers": "ringdans",
    "ringdas": "ringa",
    "ringde": "ringa",
    "ringdes": "ringa",
    "ringdomar": "ringdomare",
    "ringdomaren": "ringdomare",
    "ringdomarens": "ringdomare",
    "ringdomares": "ringdomare",
    "ringdomarna": "ringdomare",
    "ringdomarnas": "ringdomare",
    "ringds": "ringa",
    "ringduv": "ringduva",
    "ringduvan": "ringduva",
    "ringduvans": "ringduva",
    "ringduvas": "ringduva",
    "ringduve": "ringduva",
    "ringduvor": "ringduva",
    "ringduvorna": "ringduva",
    "ringduvornas": "ringduva",
    "ringduvors": "ringduva",
    "ringduvs": "ringduva",
    "ringel": "ringla",
    "ringen": "ring",
    "ringens": "ring",
    "ringer": "ringa",
    "ringes": "ringa",
    "ringet": "ring",
    "ringets": "ring",
    "ringfingern": "ringfinger",
    "ringfingerns": "ringfinger",
    "ringfingers": "ringfinger",
    "ringfingrar": "ringfinger",
    "ringfingrarna": "ringfinger",
    "ringfingrarnas": "ringfinger",
    "ringfingrars": "ringfinger",
    "ringfingret": "ringfinger",
    "ringfingrets": "ringfinger",
    "ringformade": "ringformad",
    "ringformades": "ringformad",
    "ringformads": "ringformad",
    "ringformat": "ringformad",
    "ringformats": "ringformad",
    "ringformiga": "ringformig",
    "ringformigare": "ringformig",
    "ringformigares": "ringformig",
    "ringformigas": "ringformig",
    "ringformigast": "ringformig",
    "ringformigaste": "ringformig",
    "ringformigastes": "ringformig",
    "ringformigasts": "ringformig",
    "ringformige": "ringformig",
    "ringformiges": "ringformig",
    "ringformigheten": "ringformighet",
    "ringformighetens": "ringformighet",
    "ringformighets": "ringformighet",
    "ringformigs": "ringformig",
    "ringformigt": "ringformig",
    "ringformigts": "ringformig",
    "ringförlovade": "ringförlovad",
    "ringförlovades": "ringförlovad",
    "ringförlovads": "ringförlovad",
    "ringförlovat": "ringförlovad",
    "ringförlovats": "ringförlovad",
    "ringheten": "ringhet",
    "ringhetens": "ringhet",
    "ringheter": "ringhet",
    "ringheterna": "ringhet",
    "ringheternas": "ringhet",
    "ringheters": "ringhet",
    "ringhets": "ringhet",
    "ringhörn": "ringhörna",
    "ringhörnan": "ringhörna",
    "ringhörnans": "ringhörna",
    "ringhörnas": "ringhörna",
    "ringhörne": "ringhörna",
    "ringhörnor": "ringhörna",
    "ringhörnorna": "ringhörna",
    "ringhörnornas": "ringhörna",
    "ringhörnors": "ringhörna",
    "ringhörns": "ringhörna",
    "ringklock": "ringklocka",
    "ringklockan": "ringklocka",
    "ringklockans": "ringklocka",
    "ringklockas": "ringklocka",
    "ringklocke": "ringklocka",
    "ringklockor": "ringklocka",
    "ringklockorna": "ringklocka",
    "ringklockornas": "ringklocka",
    "ringklockors": "ringklocka",
    "ringklocks": "ringklocka",
    "ringlade": "ringla",
    "ringlades": "ringla",
    "ringlande": "ringla",
    "ringlanden": "ringlande",
    "ringlandena": "ringlande",
    "ringlandenas": "ringlande",
    "ringlandens": "ringlande",
    "ringlandes": "ringlande",
    "ringlandet": "ringlande",
    "ringlandets": "ringlande",
    "ringlar": "ringla",
    "ringlas": "ringla",
    "ringlat": "ringla",
    "ringlats": "ringla",
    "ringlekar": "ringlek",
    "ringlekarna": "ringlek",
    "ringlekarnas": "ringlek",
    "ringlekars": "ringlek",
    "ringleken": "ringlek",
    "ringlekens": "ringlek",
    "ringleks": "ringlek",
    "ringmaskar": "ringmask",
    "ringmaskarna": "ringmask",
    "ringmaskarnas": "ringmask",
    "ringmaskars": "ringmask",
    "ringmasken": "ringmask",
    "ringmaskens": "ringmask",
    "ringmasks": "ringmask",
    "ringmurar": "ringmur",
    "ringmurarna": "ringmur",
    "ringmurarnas": "ringmur",
    "ringmurars": "ringmur",
    "ringmuren": "ringmur",
    "ringmurens": "ringmur",
    "ringmurs": "ringmur",
    "ringmuskeln": "ringmuskel",
    "ringmuskelns": "ringmuskel",
    "ringmuskels": "ringmuskel",
    "ringmuskler": "ringmuskel",
    "ringmusklerna": "ringmuskel",
    "ringmusklernas": "ringmuskel",
    "ringmusklers": "ringmuskel",
    "ringmärk": "ringmärka",
    "ringmärkande": "ringmärka",
    "ringmärkanden": "ringmärkande",
    "ringmärkandena": "ringmärkande",
    "ringmärkandenas": "ringmärkande",
    "ringmärkandens": "ringmärkande",
    "ringmärkandes": "ringmärkande",
    "ringmärkandet": "ringmärkande",
    "ringmärkandets": "ringmärkande",
    "ringmärkas": "ringmärka",
    "ringmärker": "ringmärka",
    "ringmärkes": "ringmärka",
    "ringmärks": "ringmärka",
    "ringmärkt": "ringmärka",
    "ringmärkta": "ringmärka",
    "ringmärktas": "ringmärka",
    "ringmärkte": "ringmärka",
    "ringmärktes": "ringmärka",
    "ringmärkts": "ringmärka",
    "ringningar": "ringning",
    "ringningarna": "ringning",
    "ringningarnas": "ringning",
    "ringningars": "ringning",
    "ringningen": "ringning",
    "ringningens": "ringning",
    "ringnings": "ringning",
    "ringormar": "ringorm",
    "ringormarna": "ringorm",
    "ringormarnas": "ringorm",
    "ringormars": "ringorm",
    "ringormen": "ringorm",
    "ringormens": "ringorm",
    "ringorms": "ringorm",
    "ringprydda": "ringprydd",
    "ringpryddare": "ringprydd",
    "ringpryddares": "ringprydd",
    "ringpryddas": "ringprydd",
    "ringpryddast": "ringprydd",
    "ringpryddaste": "ringprydd",
    "ringpryddastes": "ringprydd",
    "ringpryddasts": "ringprydd",
    "ringprydde": "ringprydd",
    "ringpryddes": "ringprydd",
    "ringprydds": "ringprydd",
    "ringprytt": "ringprydd",
    "ringprytts": "ringprydd",
    "ringpärmar": "ringpärm",
    "ringpärmarna": "ringpärm",
    "ringpärmarnas": "ringpärm",
    "ringpärmars": "ringpärm",
    "ringpärmen": "ringpärm",
    "ringpärmens": "ringpärm",
    "ringpärms": "ringpärm",
    "ringreven": "ringrev",
    "ringrevens": "ringrev",
    "ringrevet": "ringrev",
    "ringrevets": "ringrev",
    "ringrevs": "ringrev",
    "ringrostiga": "ringrostig",
    "ringrostigare": "ringrostig",
    "ringrostigares": "ringrostig",
    "ringrostigas": "ringrostig",
    "ringrostigast": "ringrostig",
    "ringrostigaste": "ringrostig",
    "ringrostigastes": "ringrostig",
    "ringrostigasts": "ringrostig",
    "ringrostige": "ringrostig",
    "ringrostiges": "ringrostig",
    "ringrostigheten": "ringrostighet",
    "ringrostighetens": "ringrostighet",
    "ringrostighets": "ringrostighet",
    "ringrostigs": "ringrostig",
    "ringrostigt": "ringrostig",
    "ringrostigts": "ringrostig",
    "ringrävar": "ringräv",
    "ringrävarna": "ringräv",
    "ringrävarnas": "ringräv",
    "ringrävars": "ringräv",
    "ringräven": "ringräv",
    "ringrävens": "ringräv",
    "ringrävs": "ringräv",
    "rings": "ringa",
    "ringsides": "ringside",
    "ringstrukturen": "ringstruktur",
    "ringstrukturens": "ringstruktur",
    "ringstrukturer": "ringstruktur",
    "ringstrukturerna": "ringstruktur",
    "ringstrukturernas": "ringstruktur",
    "ringstrukturers": "ringstruktur",
    "ringstrukturs": "ringstruktur",
    "ringt": "ringa",
    "ringtrycken": "ringtryck",
    "ringtryckens": "ringtryck",
    "ringtrycket": "ringtryck",
    "ringtryckets": "ringtryck",
    "ringtrycks": "ringtryck",
    "ringts": "ringa",
    "ringvraken": "ringvrak",
    "ringvrakens": "ringvrak",
    "ringvraket": "ringvrak",
    "ringvrakets": "ringvrak",
    "ringvraks": "ringvrak",
    "rinkar": "rink",
    "rinkarna": "rink",
    "rinkarnas": "rink",
    "rinkars": "rink",
    "rinken": "rink",
    "rinkens": "rink",
    "rinks": "rink",
    "rinn": "rinna",
    "rinnande": "rinna",
    "rinnanden": "rinnande",
    "rinnandena": "rinnande",
    "rinnandenas": "rinnande",
    "rinnandens": "rinnande",
    "rinnandes": "rinnande",
    "rinnandet": "rinnande",
    "rinnandets": "rinnande",
    "rinnas": "rinna",
    "rinne": "rinna",
    "rinner": "rinna",
    "rinnes": "rinna",
    "rinns": "rinna",
    "rins": "ri",
    "riojaprovningar": "riojaprovning",
    "riojaprovningarna": "riojaprovning",
    "riojaprovningarnas": "riojaprovning",
    "riojaprovningars": "riojaprovning",
    "riojaprovningen": "riojaprovning",
    "riojaprovningens": "riojaprovning",
    "riojaprovnings": "riojaprovning",
    "rior": "ria",
    "riorna": "ria",
    "riornas": "ria",
    "riors": "ria",
    "rip": "ripa",
    "ripan": "ripa",
    "ripans": "ripa",
    "ripas": "ripa",
    "ripe": "ripa",
    "ripor": "ripa",
    "riporna": "ripa",
    "ripornas": "ripa",
    "ripors": "ripa",
    "riposten": "ripost",
    "ripostens": "ripost",
    "riposter": "ripost",
    "riposterade": "ripostera",
    "riposterades": "ripostera",
    "riposterande": "ripostera",
    "riposteranden": "riposterande",
    "riposterandena": "riposterande",
    "riposterandenas": "riposterande",
    "riposterandens": "riposterande",
    "riposterandes": "riposterande",
    "riposterandet": "riposterande",
    "riposterandets": "riposterande",
    "riposterar": "ripostera",
    "riposteras": "ripostera",
    "riposterat": "ripostera",
    "riposterats": "ripostera",
    "riposteringar": "ripostering",
    "riposteringarna": "ripostering",
    "riposteringarnas": "ripostering",
    "riposteringars": "ripostering",
    "riposteringen": "ripostering",
    "riposteringens": "ripostering",
    "riposterings": "ripostering",
    "riposterna": "ripost",
    "riposternas": "ripost",
    "riposters": "ripost",
    "riposts": "ripost",
    "rippeln": "rippel",
    "rippelns": "rippel",
    "rippels": "rippel",
    "ripplar": "rippel",
    "ripplarna": "rippel",
    "ripplarnas": "rippel",
    "ripplars": "rippel",
    "rips": "ripa",
    "ripsen": "rips",
    "ripsens": "rips",
    "ripser": "rips",
    "ripserna": "rips",
    "ripsernas": "rips",
    "ripsers": "rips",
    "ripset": "rips",
    "ripsets": "rips",
    "ris": "risa",
    "risad": "risa",
    "risade": "risa",
    "risades": "risa",
    "risads": "risa",
    "risande": "risa",
    "risanden": "risande",
    "risandena": "risande",
    "risandenas": "risande",
    "risandens": "risande",
    "risandes": "risande",
    "risandet": "risande",
    "risandets": "risande",
    "risar": "risa",
    "risas": "risa",
    "risat": "risa",
    "risats": "risa",
    "risbastun": "risbastu",
    "risbastuns": "risbastu",
    "risbastus": "risbastu",
    "risbrännvinet": "risbrännvin",
    "risbrännvinets": "risbrännvin",
    "risbrännvins": "risbrännvin",
    "risen": "ris",
    "risens": "ris",
    "riset": "ris",
    "risets": "ris",
    "risgrynen": "risgryn",
    "risgrynens": "risgryn",
    "risgrynet": "risgryn",
    "risgrynets": "risgryn",
    "risgryns": "risgryn",
    "risgrynsgröten": "risgrynsgröt",
    "risgrynsgrötens": "risgrynsgröt",
    "risgrynsgröts": "risgrynsgröt",
    "rishögar": "rishög",
    "rishögarna": "rishög",
    "rishögarnas": "rishög",
    "rishögars": "rishög",
    "rishögen": "rishög",
    "rishögens": "rishög",
    "rishögs": "rishög",
    "risiga": "risig",
    "risigare": "risig",
    "risigares": "risig",
    "risigas": "risig",
    "risigast": "risig",
    "risigaste": "risig",
    "risigastes": "risig",
    "risigasts": "risig",
    "risige": "risig",
    "risiges": "risig",
    "risigs": "risig",
    "risigt": "risig",
    "risigts": "risig",
    "risk": "riska",
    "riskabels": "riskabel",
    "riskabelt": "riskabel",
    "riskabelts": "riskabel",
    "riskabla": "riskabel",
    "riskablare": "riskabel",
    "riskablares": "riskabel",
    "riskablas": "riskabel",
    "riskablast": "riskabel",
    "riskablaste": "riskabel",
    "riskablastes": "riskabel",
    "riskablasts": "riskabel",
    "riskable": "riskabel",
    "riskables": "riskabel",
    "riskak": "riskaka",
    "riskakan": "riskaka",
    "riskakans": "riskaka",
    "riskakas": "riskaka",
    "riskake": "riskaka",
    "riskakor": "riskaka",
    "riskakorna": "riskaka",
    "riskakornas": "riskaka",
    "riskakors": "riskaka",
    "riskaks": "riskaka",
    "riskan": "riska",
    "riskanalysen": "riskanalys",
    "riskanalysens": "riskanalys",
    "riskanalyser": "riskanalys",
    "riskanalyserna": "riskanalys",
    "riskanalysernas": "riskanalys",
    "riskanalysers": "riskanalys",
    "riskans": "riska",
    "riskas": "riska",
    "riskbedömningar": "riskbedömning",
    "riskbedömningarna": "riskbedömning",
    "riskbedömningarnas": "riskbedömning",
    "riskbedömningars": "riskbedömning",
    "riskbedömningen": "riskbedömning",
    "riskbedömningens": "riskbedömning",
    "riskbedömnings": "riskbedömning",
    "riske": "riska",
    "risken": "risk",
    "riskens": "risk",
    "risker": "risk",
    "riskerade": "riskera",
    "riskerades": "riskera",
    "riskerande": "riskera",
    "riskeranden": "riskerande",
    "riskerandena": "riskerande",
    "riskerandenas": "riskerande",
    "riskerandens": "riskerande",
    "riskerandes": "riskerande",
    "riskerandet": "riskerande",
    "riskerandets": "riskerande",
    "riskerar": "riskera",
    "riskeras": "riskera",
    "riskerat": "riskera",
    "riskerats": "riskera",
    "riskeringar": "riskering",
    "riskeringarna": "riskering",
    "riskeringarnas": "riskering",
    "riskeringars": "riskering",
    "riskeringen": "riskering",
    "riskeringens": "riskering",
    "riskerings": "riskering",
    "riskerna": "risk",
    "riskernas": "risk",
    "riskers": "risk",
    "riskfaktorer": "riskfaktor",
    "riskfaktorerna": "riskfaktor",
    "riskfaktorernas": "riskfaktor",
    "riskfaktorers": "riskfaktor",
    "riskfaktorn": "riskfaktor",
    "riskfaktorns": "riskfaktor",
    "riskfaktors": "riskfaktor",
    "riskfyllda": "riskfylld",
    "riskfylldare": "riskfylld",
    "riskfylldares": "riskfylld",
    "riskfylldas": "riskfylld",
    "riskfylldast": "riskfylld",
    "riskfylldaste": "riskfylld",
    "riskfylldastes": "riskfylld",
    "riskfylldasts": "riskfylld",
    "riskfyllde": "riskfylld",
    "riskfylldes": "riskfylld",
    "riskfylldheten": "riskfylldhet",
    "riskfylldhetens": "riskfylldhet",
    "riskfylldhets": "riskfylldhet",
    "riskfyllds": "riskfylld",
    "riskfyllt": "riskfylld",
    "riskfyllts": "riskfylld",
    "riskgruppen": "riskgrupp",
    "riskgruppens": "riskgrupp",
    "riskgrupper": "riskgrupp",
    "riskgrupperna": "riskgrupp",
    "riskgruppernas": "riskgrupp",
    "riskgruppers": "riskgrupp",
    "riskgrupps": "riskgrupp",
    "riskkapitalbolagen": "riskkapitalbolag",
    "riskkapitalbolagens": "riskkapitalbolag",
    "riskkapitalbolaget": "riskkapitalbolag",
    "riskkapitalbolagets": "riskkapitalbolag",
    "riskkapitalbolags": "riskkapitalbolag",
    "riskkapitalet": "riskkapital",
    "riskkapitalets": "riskkapital",
    "riskkapitalisten": "riskkapitalist",
    "riskkapitalistens": "riskkapitalist",
    "riskkapitalister": "riskkapitalist",
    "riskkapitalisterna": "riskkapitalist",
    "riskkapitalisternas": "riskkapitalist",
    "riskkapitalisters": "riskkapitalist",
    "riskkapitalists": "riskkapitalist",
    "riskkapitals": "riskkapital",
    "riskmodellen": "riskmodell",
    "riskmodellens": "riskmodell",
    "riskmodeller": "riskmodell",
    "riskmodellerna": "riskmodell",
    "riskmodellernas": "riskmodell",
    "riskmodellers": "riskmodell",
    "riskmodells": "riskmodell",
    "risknivåer": "risknivå",
    "risknivåerna": "risknivå",
    "risknivåernas": "risknivå",
    "risknivåers": "risknivå",
    "risknivån": "risknivå",
    "risknivåns": "risknivå",
    "risknivås": "risknivå",
    "riskområden": "riskområde",
    "riskområdena": "riskområde",
    "riskområdenas": "riskområde",
    "riskområdens": "riskområde",
    "riskområdes": "riskområde",
    "riskområdet": "riskområde",
    "riskområdets": "riskområde",
    "riskor": "riska",
    "riskorna": "riska",
    "riskornas": "riska",
    "riskors": "riska",
    "risks": "risk",
    "riskspridningar": "riskspridning",
    "riskspridningarna": "riskspridning",
    "riskspridningarnas": "riskspridning",
    "riskspridningars": "riskspridning",
    "riskspridningen": "riskspridning",
    "riskspridningens": "riskspridning",
    "riskspridnings": "riskspridning",
    "risktagar": "risktagare",
    "risktagaren": "risktagare",
    "risktagarens": "risktagare",
    "risktagares": "risktagare",
    "risktagarna": "risktagare",
    "risktagarnas": "risktagare",
    "risktalen": "risktal",
    "risktalens": "risktal",
    "risktalet": "risktal",
    "risktalets": "risktal",
    "risktals": "risktal",
    "riskuppfattningar": "riskuppfattning",
    "riskuppfattningarna": "riskuppfattning",
    "riskuppfattningarnas": "riskuppfattning",
    "riskuppfattningars": "riskuppfattning",
    "riskuppfattningen": "riskuppfattning",
    "riskuppfattningens": "riskuppfattning",
    "riskuppfattnings": "riskuppfattning",
    "riskvilliga": "riskvillig",
    "riskvilligare": "riskvillig",
    "riskvilligares": "riskvillig",
    "riskvilligas": "riskvillig",
    "riskvilligast": "riskvillig",
    "riskvilligaste": "riskvillig",
    "riskvilligastes": "riskvillig",
    "riskvilligasts": "riskvillig",
    "riskvillige": "riskvillig",
    "riskvilliges": "riskvillig",
    "riskvilligheten": "riskvillighet",
    "riskvillighetens": "riskvillighet",
    "riskvillighets": "riskvillighet",
    "riskvilligs": "riskvillig",
    "riskvilligt": "riskvillig",
    "riskvilligts": "riskvillig",
    "riskzonen": "riskzon",
    "riskzonens": "riskzon",
    "riskzoner": "riskzon",
    "riskzonerna": "riskzon",
    "riskzonernas": "riskzon",
    "riskzoners": "riskzon",
    "riskzons": "riskzon",
    "risollen": "risoll",
    "risollens": "risoll",
    "risoller": "risoll",
    "risollerna": "risoll",
    "risollernas": "risoll",
    "risollers": "risoll",
    "risolls": "risoll",
    "risotton": "risotto",
    "risottons": "risotto",
    "risottos": "risotto",
    "risp": "rispa",
    "rispad": "rispa",
    "rispade": "rispa",
    "rispades": "rispa",
    "rispads": "rispa",
    "rispan": "rispa",
    "rispande": "rispa",
    "rispanden": "rispande",
    "rispandena": "rispande",
    "rispandenas": "rispande",
    "rispandens": "rispande",
    "rispandes": "rispande",
    "rispandet": "rispande",
    "rispandets": "rispande",
    "rispans": "rispa",
    "rispapperet": "rispapper",
    "rispapperets": "rispapper",
    "rispappers": "rispapper",
    "rispappret": "rispapper",
    "rispapprets": "rispapper",
    "rispar": "rispa",
    "rispas": "rispa",
    "rispat": "rispa",
    "rispats": "rispa",
    "rispe": "rispa",
    "rispor": "rispa",
    "risporna": "rispa",
    "rispornas": "rispa",
    "rispors": "rispa",
    "risrätten": "risrätt",
    "risrättens": "risrätt",
    "risrätter": "risrätt",
    "risrätterna": "risrätt",
    "risrätternas": "risrätt",
    "risrätters": "risrätt",
    "risrätts": "risrätt",
    "rissel": "rissla",
    "rissels": "rissel",
    "rissl": "rissla",
    "risslad": "rissla",
    "risslade": "rissla",
    "risslades": "rissla",
    "risslads": "rissla",
    "risslan": "rissla",
    "risslande": "rissla",
    "risslanden": "risslande",
    "risslandena": "risslande",
    "risslandenas": "risslande",
    "risslandens": "risslande",
    "risslandes": "risslande",
    "risslandet": "risslande",
    "risslandets": "risslande",
    "risslans": "rissla",
    "risslar": "rissla",
    "risslas": "rissla",
    "risslat": "rissla",
    "risslats": "rissla",
    "rissle": "rissla",
    "risslen": "rissel",
    "risslens": "rissel",
    "risslet": "rissel",
    "risslets": "rissel",
    "risslor": "rissla",
    "risslorna": "rissla",
    "risslornas": "rissla",
    "risslors": "rissla",
    "rist": "rista",
    "ristad": "rista",
    "ristade": "rista",
    "ristades": "rista",
    "ristads": "rista",
    "ristande": "rista",
    "ristanden": "ristande",
    "ristandena": "ristande",
    "ristandenas": "ristande",
    "ristandens": "ristande",
    "ristandes": "ristande",
    "ristandet": "ristande",
    "ristandets": "ristande",
    "ristar": "rista",
    "ristarna": "rist",
    "ristarnas": "rist",
    "ristars": "rist",
    "ristas": "rista",
    "ristat": "rista",
    "ristats": "rista",
    "riste": "rista",
    "risten": "rist",
    "ristens": "rist",
    "rister": "rista",
    "risterna": "rist",
    "risternas": "rist",
    "risters": "rist",
    "ristes": "rista",
    "ristningar": "ristning",
    "ristningarna": "ristning",
    "ristningarnas": "ristning",
    "ristningars": "ristning",
    "ristningen": "ristning",
    "ristningens": "ristning",
    "ristnings": "ristning",
    "ristornos": "ristorno",
    "ristornot": "ristorno",
    "ristornots": "ristorno",
    "rists": "rista",
    "risvas": "risvase",
    "risvasar": "risvase",
    "risvasarna": "risvase",
    "risvasarnas": "risvase",
    "risvasars": "risvase",
    "risvasen": "risvase",
    "risvasens": "risvase",
    "risvases": "risvase",
    "rit": "rita",
    "ritad": "rita",
    "ritade": "rita",
    "ritades": "rita",
    "ritads": "rita",
    "ritande": "rita",
    "ritanden": "ritande",
    "ritandena": "ritande",
    "ritandenas": "ritande",
    "ritandens": "ritande",
    "ritandes": "ritande",
    "ritandet": "ritande",
    "ritandets": "ritande",
    "ritapparaten": "ritapparat",
    "ritapparatens": "ritapparat",
    "ritapparater": "ritapparat",
    "ritapparaterna": "ritapparat",
    "ritapparaternas": "ritapparat",
    "ritapparaters": "ritapparat",
    "ritapparats": "ritapparat",
    "ritar": "ritare",
    "ritardandon": "ritardando",
    "ritardandona": "ritardando",
    "ritardandonas": "ritardando",
    "ritardandons": "ritardando",
    "ritardandos": "ritardando",
    "ritardandot": "ritardando",
    "ritardandots": "ritardando",
    "ritaren": "ritare",
    "ritarens": "ritare",
    "ritares": "ritare",
    "ritarna": "ritare",
    "ritarnas": "ritare",
    "ritat": "rita",
    "ritats": "rita",
    "ritbesticken": "ritbestick",
    "ritbestickens": "ritbestick",
    "ritbesticket": "ritbestick",
    "ritbestickets": "ritbestick",
    "ritbesticks": "ritbestick",
    "ritblocken": "ritblock",
    "ritblockens": "ritblock",
    "ritblocket": "ritblock",
    "ritblockets": "ritblock",
    "ritblocks": "ritblock",
    "ritborden": "ritbord",
    "ritbordens": "ritbord",
    "ritbordet": "ritbord",
    "ritbordets": "ritbord",
    "ritbords": "ritbord",
    "riten": "rit",
    "ritens": "rit",
    "riter": "rit",
    "riterna": "rit",
    "riternas": "rit",
    "riters": "rit",
    "ritkolen": "ritkol",
    "ritkolens": "ritkol",
    "ritkolet": "ritkol",
    "ritkolets": "ritkol",
    "ritkols": "ritkol",
    "ritningar": "ritning",
    "ritningarna": "ritning",
    "ritningarnas": "ritning",
    "ritningars": "ritning",
    "ritningen": "ritning",
    "ritningens": "ritning",
    "ritnings": "ritning",
    "rits": "ritsa",
    "ritsad": "ritsa",
    "ritsade": "ritsa",
    "ritsades": "ritsa",
    "ritsads": "ritsa",
    "ritsande": "ritsa",
    "ritsanden": "ritsande",
    "ritsandena": "ritsande",
    "ritsandenas": "ritsande",
    "ritsandens": "ritsande",
    "ritsandes": "ritsande",
    "ritsandet": "ritsande",
    "ritsandets": "ritsande",
    "ritsar": "ritsa",
    "ritsarna": "rits",
    "ritsarnas": "rits",
    "ritsars": "rits",
    "ritsas": "ritsa",
    "ritsat": "ritsa",
    "ritsats": "ritsa",
    "ritschade": "ritscha",
    "ritschades": "ritscha",
    "ritschande": "ritscha",
    "ritschanden": "ritschande",
    "ritschandena": "ritschande",
    "ritschandenas": "ritschande",
    "ritschandens": "ritschande",
    "ritschandes": "ritschande",
    "ritschandet": "ritschande",
    "ritschandets": "ritschande",
    "ritschar": "ritscha",
    "ritschas": "ritscha",
    "ritschat": "ritscha",
    "ritschats": "ritscha",
    "ritschet": "ritsch",
    "ritschets": "ritsch",
    "ritschs": "ritsch",
    "ritsen": "rits",
    "ritsens": "rits",
    "ritser": "rits",
    "ritserna": "rits",
    "ritsernas": "rits",
    "ritsers": "rits",
    "ritten": "ritt",
    "rittens": "ritt",
    "ritter": "ritt",
    "ritterna": "ritt",
    "ritternas": "ritt",
    "ritters": "ritt",
    "ritts": "ritt",
    "ritualen": "ritual",
    "ritualens": "ritual",
    "ritualer": "ritual",
    "ritualerna": "ritual",
    "ritualernas": "ritual",
    "ritualers": "ritual",
    "ritualet": "ritual",
    "ritualets": "ritual",
    "ritualiserad": "ritualisera",
    "ritualiserade": "ritualisera",
    "ritualiserades": "ritualisera",
    "ritualiserads": "ritualisera",
    "ritualiserande": "ritualisera",
    "ritualiseranden": "ritualiserande",
    "ritualiserandena": "ritualiserande",
    "ritualiserandenas": "ritualiserande",
    "ritualiserandens": "ritualiserande",
    "ritualiserandes": "ritualiserande",
    "ritualiserandet": "ritualiserande",
    "ritualiserandets": "ritualiserande",
    "ritualiserar": "ritualisera",
    "ritualiseras": "ritualisera",
    "ritualiserat": "ritualisera",
    "ritualiserats": "ritualisera",
    "ritualiserbara": "ritualiserbar",
    "ritualiserbarare": "ritualiserbar",
    "ritualiserbarares": "ritualiserbar",
    "ritualiserbaras": "ritualiserbar",
    "ritualiserbarast": "ritualiserbar",
    "ritualiserbaraste": "ritualiserbar",
    "ritualiserbarastes": "ritualiserbar",
    "ritualiserbarasts": "ritualiserbar",
    "ritualiserbare": "ritualiserbar",
    "ritualiserbares": "ritualiserbar",
    "ritualiserbarheten": "ritualiserbarhet",
    "ritualiserbarhetens": "ritualiserbarhet",
    "ritualiserbarhets": "ritualiserbarhet",
    "ritualiserbars": "ritualiserbar",
    "ritualiserbart": "ritualiserbar",
    "ritualiserbarts": "ritualiserbar",
    "ritualiseringar": "ritualisering",
    "ritualiseringarna": "ritualisering",
    "ritualiseringarnas": "ritualisering",
    "ritualiseringars": "ritualisering",
    "ritualiseringen": "ritualisering",
    "ritualiseringens": "ritualisering",
    "ritualiserings": "ritualisering",
    "ritualismen": "ritualism",
    "ritualismens": "ritualism",
    "ritualismer": "ritualism",
    "ritualismerna": "ritualism",
    "ritualismernas": "ritualism",
    "ritualismers": "ritualism",
    "ritualisms": "ritualism",
    "ritualistiska": "ritualistisk",
    "ritualistiskas": "ritualistisk",
    "ritualistiske": "ritualistisk",
    "ritualistiskes": "ritualistisk",
    "ritualistisks": "ritualistisk",
    "ritualistiskt": "ritualistisk",
    "ritualistiskts": "ritualistisk",
    "ritualmorden": "ritualmord",
    "ritualmordens": "ritualmord",
    "ritualmordet": "ritualmord",
    "ritualmordets": "ritualmord",
    "ritualmords": "ritualmord",
    "ritualmässiga": "ritualmässig",
    "ritualmässigare": "ritualmässig",
    "ritualmässigares": "ritualmässig",
    "ritualmässigas": "ritualmässig",
    "ritualmässigast": "ritualmässig",
    "ritualmässigaste": "ritualmässig",
    "ritualmässigastes": "ritualmässig",
    "ritualmässigasts": "ritualmässig",
    "ritualmässige": "ritualmässig",
    "ritualmässiges": "ritualmässig",
    "ritualmässigs": "ritualmässig",
    "ritualmässigt": "ritualmässig",
    "ritualmässigts": "ritualmässig",
    "rituals": "ritual",
    "rituella": "rituell",
    "rituellare": "rituell",
    "rituellares": "rituell",
    "rituellas": "rituell",
    "rituellast": "rituell",
    "rituellaste": "rituell",
    "rituellastes": "rituell",
    "rituellasts": "rituell",
    "rituelle": "rituell",
    "rituelles": "rituell",
    "rituells": "rituell",
    "rituellt": "rituell",
    "rituellts": "rituell",
    "riv": "riva",
    "rivalen": "rival",
    "rivalens": "rival",
    "rivaler": "rival",
    "rivalerna": "rival",
    "rivalernas": "rival",
    "rivalers": "rival",
    "rivaliserade": "rivalisera",
    "rivaliserades": "rivalisera",
    "rivaliserande": "rivalisera",
    "rivaliseranden": "rivaliserande",
    "rivaliserandena": "rivaliserande",
    "rivaliserandenas": "rivaliserande",
    "rivaliserandens": "rivaliserande",
    "rivaliserandes": "rivaliserande",
    "rivaliserandet": "rivaliserande",
    "rivaliserandets": "rivaliserande",
    "rivaliserar": "rivalisera",
    "rivaliseras": "rivalisera",
    "rivaliserat": "rivalisera",
    "rivaliserats": "rivalisera",
    "rivaliseringar": "rivalisering",
    "rivaliseringarna": "rivalisering",
    "rivaliseringarnas": "rivalisering",
    "rivaliseringars": "rivalisering",
    "rivaliseringen": "rivalisering",
    "rivaliseringens": "rivalisering",
    "rivaliserings": "rivalisering",
    "rivaliteten": "rivalitet",
    "rivalitetens": "rivalitet",
    "rivaliteter": "rivalitet",
    "rivaliteterna": "rivalitet",
    "rivaliteternas": "rivalitet",
    "rivaliteters": "rivalitet",
    "rivalitets": "rivalitet",
    "rivals": "rival",
    "rivande": "riva",
    "rivanden": "rivande",
    "rivandena": "rivande",
    "rivandenas": "rivande",
    "rivandens": "rivande",
    "rivandes": "rivande",
    "rivandet": "rivande",
    "rivandets": "rivande",
    "rivas": "riva",
    "rive": "riva",
    "rivebrödet": "rivebröd",
    "rivebrödets": "rivebröd",
    "rivebröds": "rivebröd",
    "riven": "riva",
    "rivens": "riva",
    "river": "riva",
    "rives": "riva",
    "rivet": "riva",
    "rivets": "riva",
    "riviga": "rivig",
    "rivigare": "rivig",
    "rivigares": "rivig",
    "rivigas": "rivig",
    "rivigast": "rivig",
    "rivigaste": "rivig",
    "rivigastes": "rivig",
    "rivigasts": "rivig",
    "rivige": "rivig",
    "riviges": "rivig",
    "rivigs": "rivig",
    "rivigt": "rivig",
    "rivigts": "rivig",
    "rivit": "riva",
    "rivits": "rivas",
    "rivjärnen": "rivjärn",
    "rivjärnens": "rivjärn",
    "rivjärnet": "rivjärn",
    "rivjärnets": "rivjärn",
    "rivjärns": "rivjärn",
    "rivna": "riva",
    "rivnas": "riva",
    "rivne": "riva",
    "rivnes": "riva",
    "rivningar": "rivning",
    "rivningarna": "rivning",
    "rivningarnas": "rivning",
    "rivningars": "rivning",
    "rivningen": "rivning",
    "rivningens": "rivning",
    "rivnings": "rivning",
    "rivningshotade": "rivningshotad",
    "rivningshotades": "rivningshotad",
    "rivningshotads": "rivningshotad",
    "rivningshotat": "rivningshotad",
    "rivningshotats": "rivningshotad",
    "rivningshusen": "rivningshus",
    "rivningshusens": "rivningshus",
    "rivningshuset": "rivningshus",
    "rivningshusets": "rivningshus",
    "rivningskontrakten": "rivningskontrakt",
    "rivningskontraktens": "rivningskontrakt",
    "rivningskontraktet": "rivningskontrakt",
    "rivningskontraktets": "rivningskontrakt",
    "rivningskontrakts": "rivningskontrakt",
    "rivningskåkar": "rivningskåk",
    "rivningskåkarna": "rivningskåk",
    "rivningskåkarnas": "rivningskåk",
    "rivningskåkars": "rivningskåk",
    "rivningskåken": "rivningskåk",
    "rivningskåkens": "rivningskåk",
    "rivningskåks": "rivningskåk",
    "rivningslägenheten": "rivningslägenhet",
    "rivningslägenhetens": "rivningslägenhet",
    "rivningslägenheter": "rivningslägenhet",
    "rivningslägenheterna": "rivningslägenhet",
    "rivningslägenheternas": "rivningslägenhet",
    "rivningslägenheters": "rivningslägenhet",
    "rivningslägenhets": "rivningslägenhet",
    "rivningstomten": "rivningstomt",
    "rivningstomtens": "rivningstomt",
    "rivningstomter": "rivningstomt",
    "rivningstomterna": "rivningstomt",
    "rivningstomternas": "rivningstomt",
    "rivningstomters": "rivningstomt",
    "rivningstomts": "rivningstomt",
    "rivs": "rivas",
    "rivstart": "rivstarta",
    "rivstartad": "rivstarta",
    "rivstartade": "rivstarta",
    "rivstartades": "rivstarta",
    "rivstartads": "rivstarta",
    "rivstartande": "rivstarta",
    "rivstartanden": "rivstartande",
    "rivstartandena": "rivstartande",
    "rivstartandenas": "rivstartande",
    "rivstartandens": "rivstartande",
    "rivstartandes": "rivstartande",
    "rivstartandet": "rivstartande",
    "rivstartandets": "rivstartande",
    "rivstartar": "rivstarta",
    "rivstartas": "rivstarta",
    "rivstartat": "rivstarta",
    "rivstartats": "rivstarta",
    "rivstarten": "rivstart",
    "rivstartens": "rivstart",
    "rivstarter": "rivstart",
    "rivstarterna": "rivstart",
    "rivstarternas": "rivstart",
    "rivstarters": "rivstart",
    "rivstarts": "rivstart",
    "ro-ro-fartygen": "ro-ro-fartyg",
    "ro-ro-fartygens": "ro-ro-fartyg",
    "ro-ro-fartyget": "ro-ro-fartyg",
    "ro-ro-fartygets": "ro-ro-fartyg",
    "ro-ro-fartygs": "ro-ro-fartyg",
    "road": "roa",
    "roade": "road",
    "roades": "road",
    "roadien": "roadie",
    "roadiens": "roadie",
    "roadies": "roadie",
    "roadiesarna": "roadie",
    "roadiesarnas": "roadie",
    "roadiesen": "roadie",
    "roadiesens": "roadie",
    "roads": "road",
    "roande": "roa",
    "roanden": "roande",
    "roandena": "roande",
    "roandenas": "roande",
    "roandens": "roande",
    "roandes": "roande",
    "roandet": "roande",
    "roandets": "roande",
    "roar": "roa",
    "roas": "roa",
    "roat": "road",
    "roats": "road",
    "robbertar": "robbert",
    "robbertarna": "robbert",
    "robbertarnas": "robbert",
    "robbertars": "robbert",
    "robberten": "robbert",
    "robbertens": "robbert",
    "robberts": "robbert",
    "roben": "robe",
    "robens": "robe",
    "rober": "robe",
    "roberna": "robe",
    "robernas": "robe",
    "robers": "robe",
    "robes": "robe",
    "robinsonaden": "robinsonad",
    "robinsonadens": "robinsonad",
    "robinsonader": "robinsonad",
    "robinsonaderna": "robinsonad",
    "robinsonadernas": "robinsonad",
    "robinsonaders": "robinsonad",
    "robinsonads": "robinsonad",
    "robotar": "robot",
    "robotarna": "robot",
    "robotarnas": "robot",
    "robotars": "robot",
    "roboten": "robot",
    "robotens": "robot",
    "robotiserad": "robotisera",
    "robotiserade": "robotisera",
    "robotiserades": "robotisera",
    "robotiserads": "robotisera",
    "robotiserande": "robotisera",
    "robotiseranden": "robotiserande",
    "robotiserandena": "robotiserande",
    "robotiserandenas": "robotiserande",
    "robotiserandens": "robotiserande",
    "robotiserandes": "robotiserande",
    "robotiserandet": "robotiserande",
    "robotiserandets": "robotiserande",
    "robotiserar": "robotisera",
    "robotiseras": "robotisera",
    "robotiserat": "robotisera",
    "robotiserats": "robotisera",
    "robotiserbara": "robotiserbar",
    "robotiserbarare": "robotiserbar",
    "robotiserbarares": "robotiserbar",
    "robotiserbaras": "robotiserbar",
    "robotiserbarast": "robotiserbar",
    "robotiserbaraste": "robotiserbar",
    "robotiserbarastes": "robotiserbar",
    "robotiserbarasts": "robotiserbar",
    "robotiserbare": "robotiserbar",
    "robotiserbares": "robotiserbar",
    "robotiserbarheten": "robotiserbarhet",
    "robotiserbarhetens": "robotiserbarhet",
    "robotiserbarhets": "robotiserbarhet",
    "robotiserbars": "robotiserbar",
    "robotiserbart": "robotiserbar",
    "robotiserbarts": "robotiserbar",
    "robotiseringar": "robotisering",
    "robotiseringarna": "robotisering",
    "robotiseringarnas": "robotisering",
    "robotiseringars": "robotisering",
    "robotiseringen": "robotisering",
    "robotiseringens": "robotisering",
    "robotiserings": "robotisering",
    "robotkraschen": "robotkrasch",
    "robotkraschens": "robotkrasch",
    "robotkrascher": "robotkrasch",
    "robotkrascherna": "robotkrasch",
    "robotkraschernas": "robotkrasch",
    "robotkraschers": "robotkrasch",
    "robotkraschs": "robotkrasch",
    "robots": "robot",
    "robotvapens": "robotvapen",
    "robotvapnen": "robotvapen",
    "robotvapnens": "robotvapen",
    "robotvapnet": "robotvapen",
    "robotvapnets": "robotvapen",
    "robs": "rob",
    "robusta": "robust",
    "robustare": "robust",
    "robustares": "robust",
    "robustas": "robust",
    "robustast": "robust",
    "robustaste": "robust",
    "robustastes": "robust",
    "robustasts": "robust",
    "robuste": "robust",
    "robustes": "robust",
    "robustheten": "robusthet",
    "robusthetens": "robusthet",
    "robusthets": "robusthet",
    "robusts": "robust",
    "rock": "rocka",
    "rock'n'rollen": "rock'n'roll",
    "rock'n'rollens": "rock'n'roll",
    "rock'n'rolls": "rock'n'roll",
    "rockade": "rocka",
    "rockaden": "rockad",
    "rockadens": "rockad",
    "rockader": "rockad",
    "rockaderna": "rockad",
    "rockadernas": "rockad",
    "rockaders": "rockad",
    "rockades": "rocka",
    "rockads": "rockad",
    "rockan": "rocka",
    "rockande": "rocka",
    "rockanden": "rockande",
    "rockandena": "rockande",
    "rockandenas": "rockande",
    "rockandens": "rockande",
    "rockandes": "rockande",
    "rockandet": "rockande",
    "rockandets": "rockande",
    "rockans": "rocka",
    "rockar": "rocka",
    "rockarna": "rock",
    "rockarnas": "rock",
    "rockars": "rock",
    "rockas": "rocka",
    "rockat": "rocka",
    "rockats": "rocka",
    "rockbanden": "rockband",
    "rockbandens": "rockband",
    "rockbandet": "rockband",
    "rockbandets": "rockband",
    "rockbands": "rockband",
    "rocke": "rocka",
    "rocken": "rock",
    "rockens": "rock",
    "rockerad": "rockera",
    "rockerade": "rockera",
    "rockerades": "rockera",
    "rockerads": "rockera",
    "rockerande": "rockera",
    "rockeranden": "rockerande",
    "rockerandena": "rockerande",
    "rockerandenas": "rockerande",
    "rockerandens": "rockerande",
    "rockerandes": "rockerande",
    "rockerandet": "rockerande",
    "rockerandets": "rockerande",
    "rockerar": "rockera",
    "rockeras": "rockera",
    "rockerat": "rockera",
    "rockerats": "rockera",
    "rockerbara": "rockerbar",
    "rockerbarare": "rockerbar",
    "rockerbarares": "rockerbar",
    "rockerbaras": "rockerbar",
    "rockerbarast": "rockerbar",
    "rockerbaraste": "rockerbar",
    "rockerbarastes": "rockerbar",
    "rockerbarasts": "rockerbar",
    "rockerbare": "rockerbar",
    "rockerbares": "rockerbar",
    "rockerbarheten": "rockerbarhet",
    "rockerbarhetens": "rockerbarhet",
    "rockerbarhets": "rockerbarhet",
    "rockerbars": "rockerbar",
    "rockerbart": "rockerbar",
    "rockerbarts": "rockerbar",
    "rockeringar": "rockering",
    "rockeringarna": "rockering",
    "rockeringarnas": "rockering",
    "rockeringars": "rockering",
    "rockeringen": "rockering",
    "rockeringens": "rockering",
    "rockerings": "rockering",
    "rockfestivalen": "rockfestival",
    "rockfestivalens": "rockfestival",
    "rockfestivaler": "rockfestival",
    "rockfestivalerna": "rockfestival",
    "rockfestivalernas": "rockfestival",
    "rockfestivalers": "rockfestival",
    "rockfestivals": "rockfestival",
    "rockfick": "rockficka",
    "rockfickan": "rockficka",
    "rockfickans": "rockficka",
    "rockfickas": "rockficka",
    "rockficke": "rockficka",
    "rockfickor": "rockficka",
    "rockfickorna": "rockficka",
    "rockfickornas": "rockficka",
    "rockfickors": "rockficka",
    "rockficks": "rockficka",
    "rockkonserten": "rockkonsert",
    "rockkonsertens": "rockkonsert",
    "rockkonserter": "rockkonsert",
    "rockkonserterna": "rockkonsert",
    "rockkonserternas": "rockkonsert",
    "rockkonserters": "rockkonsert",
    "rockkonserts": "rockkonsert",
    "rockmusiken": "rockmusik",
    "rockmusikens": "rockmusik",
    "rockmusiks": "rockmusik",
    "rockor": "rocka",
    "rockorna": "rocka",
    "rockornas": "rocka",
    "rockors": "rocka",
    "rockringar": "rockring",
    "rockringarna": "rockring",
    "rockringarnas": "rockring",
    "rockringars": "rockring",
    "rockringen": "rockring",
    "rockringens": "rockring",
    "rockrings": "rockring",
    "rocks": "rocka",
    "rocksluskar": "rockslusk",
    "rocksluskarna": "rockslusk",
    "rocksluskarnas": "rockslusk",
    "rocksluskars": "rockslusk",
    "rockslusken": "rockslusk",
    "rocksluskens": "rockslusk",
    "rockslusks": "rockslusk",
    "rockvaktmästar": "rockvaktmästare",
    "rockvaktmästaren": "rockvaktmästare",
    "rockvaktmästarens": "rockvaktmästare",
    "rockvaktmästares": "rockvaktmästare",
    "rockvaktmästarna": "rockvaktmästare",
    "rockvaktmästarnas": "rockvaktmästare",
    "rockärmar": "rockärm",
    "rockärmarna": "rockärm",
    "rockärmarnas": "rockärm",
    "rockärmars": "rockärm",
    "rockärmen": "rockärm",
    "rockärmens": "rockärm",
    "rockärms": "rockärm",
    "rodd": "ro",
    "rodda": "ro",
    "roddar": "roddare",
    "roddarbänkar": "roddarbänk",
    "roddarbänkarna": "roddarbänk",
    "roddarbänkarnas": "roddarbänk",
    "roddarbänkars": "roddarbänk",
    "roddarbänken": "roddarbänk",
    "roddarbänkens": "roddarbänk",
    "roddarbänks": "roddarbänk",
    "roddaren": "roddare",
    "roddarens": "roddare",
    "roddares": "roddare",
    "roddarlagen": "roddarlag",
    "roddarlagens": "roddarlag",
    "roddarlaget": "roddarlag",
    "roddarlagets": "roddarlag",
    "roddarlags": "roddarlag",
    "roddarmadammen": "roddarmadam",
    "roddarmadammens": "roddarmadam",
    "roddarmadammer": "roddarmadam",
    "roddarmadammerna": "roddarmadam",
    "roddarmadammernas": "roddarmadam",
    "roddarmadammers": "roddarmadam",
    "roddarmadams": "roddarmadam",
    "roddarna": "roddare",
    "roddarnas": "roddare",
    "roddarslavar": "roddarslav",
    "roddarslavarna": "roddarslav",
    "roddarslavarnas": "roddarslav",
    "roddarslavars": "roddarslav",
    "roddarslaven": "roddarslav",
    "roddarslavens": "roddarslav",
    "roddarslavs": "roddarslav",
    "roddarsången": "roddarsång",
    "roddarsångens": "roddarsång",
    "roddarsånger": "roddarsång",
    "roddarsångerna": "roddarsång",
    "roddarsångernas": "roddarsång",
    "roddarsångers": "roddarsång",
    "roddarsångs": "roddarsång",
    "roddas": "ro",
    "roddbåtar": "roddbåt",
    "roddbåtarna": "roddbåt",
    "roddbåtarnas": "roddbåt",
    "roddbåtars": "roddbåt",
    "roddbåten": "roddbåt",
    "roddbåtens": "roddbåt",
    "roddbåts": "roddbåt",
    "rodde": "ro",
    "rodden": "rodd",
    "roddens": "rodd",
    "rodder": "rodd",
    "rodderna": "rodd",
    "roddernas": "rodd",
    "rodders": "rodd",
    "roddes": "ro",
    "rodds": "rodd",
    "roddtävlingar": "roddtävling",
    "roddtävlingarna": "roddtävling",
    "roddtävlingarnas": "roddtävling",
    "roddtävlingars": "roddtävling",
    "roddtävlingen": "roddtävling",
    "roddtävlingens": "roddtävling",
    "roddtävlings": "roddtävling",
    "rodeln": "rodel",
    "rodelns": "rodel",
    "rodels": "rodel",
    "rodeon": "rodeo",
    "rodeons": "rodeo",
    "rodeor": "rodeo",
    "rodeorna": "rodeo",
    "rodeornas": "rodeo",
    "rodeors": "rodeo",
    "rodeos": "rodeo",
    "roderfelen": "roderfel",
    "roderfelens": "roderfel",
    "roderfelet": "roderfel",
    "roderfelets": "roderfel",
    "roderfels": "roderfel",
    "roderhaverier": "roderhaveri",
    "roderhaverierna": "roderhaveri",
    "roderhaveriernas": "roderhaveri",
    "roderhaveriers": "roderhaveri",
    "roderhaveriet": "roderhaveri",
    "roderhaveriets": "roderhaveri",
    "roderhaveris": "roderhaveri",
    "roderhaverit": "roderhaveri",
    "roderhaverits": "roderhaveri",
    "roderna": "roder",
    "rodernas": "roder",
    "roders": "roder",
    "rodiet": "rodium",
    "rodiets": "rodium",
    "rodiumet": "rodium",
    "rodiumets": "rodium",
    "rodiums": "rodium",
    "rodlar": "rodel",
    "rodlarna": "rodel",
    "rodlarnas": "rodel",
    "rodlars": "rodel",
    "rodnade": "rodna",
    "rodnaden": "rodnad",
    "rodnadens": "rodnad",
    "rodnader": "rodnad",
    "rodnaderna": "rodnad",
    "rodnadernas": "rodnad",
    "rodnaders": "rodnad",
    "rodnades": "rodna",
    "rodnads": "rodnad",
    "rodnande": "rodna",
    "rodnanden": "rodnande",
    "rodnandena": "rodnande",
    "rodnandenas": "rodnande",
    "rodnandens": "rodnande",
    "rodnandes": "rodnande",
    "rodnandet": "rodnande",
    "rodnandets": "rodnande",
    "rodnar": "rodna",
    "rodnas": "rodna",
    "rodnat": "rodna",
    "rodnats": "rodna",
    "rododendrer": "rododendron",
    "rododendrerna": "rododendron",
    "rododendrernas": "rododendron",
    "rododendrers": "rododendron",
    "rododendronen": "rododendron",
    "rododendronens": "rododendron",
    "rododendrons": "rododendron",
    "rodren": "roder",
    "rodrens": "roder",
    "rodret": "roder",
    "rodrets": "roder",
    "roen": "ro",
    "roende": "ro",
    "roenden": "roende",
    "roendena": "roende",
    "roendenas": "roende",
    "roendens": "roende",
    "roendes": "roende",
    "roendet": "roende",
    "roendets": "roende",
    "roens": "ro",
    "roet": "ro",
    "roets": "ro",
    "roff": "roffa",
    "roffad": "roffa",
    "roffade": "roffa",
    "roffades": "roffa",
    "roffads": "roffa",
    "roffande": "roffa",
    "roffanden": "roffande",
    "roffandena": "roffande",
    "roffandenas": "roffande",
    "roffandens": "roffande",
    "roffandes": "roffande",
    "roffandet": "roffande",
    "roffandets": "roffande",
    "roffar": "roffa",
    "roffas": "roffa",
    "roffat": "roffa",
    "roffats": "roffa",
    "rofyllda": "rofylld",
    "rofylldare": "rofylld",
    "rofylldares": "rofylld",
    "rofylldas": "rofylld",
    "rofylldast": "rofylld",
    "rofylldaste": "rofylld",
    "rofylldastes": "rofylld",
    "rofylldasts": "rofylld",
    "rofyllde": "rofylld",
    "rofylldes": "rofylld",
    "rofylldheten": "rofylldhet",
    "rofylldhetens": "rofylldhet",
    "rofylldhets": "rofylldhet",
    "rofyllds": "rofylld",
    "rofyllt": "rofylld",
    "rofyllts": "rofylld",
    "rojalismen": "rojalism",
    "rojalismens": "rojalism",
    "rojalismer": "rojalism",
    "rojalismerna": "rojalism",
    "rojalismernas": "rojalism",
    "rojalismers": "rojalism",
    "rojalisms": "rojalism",
    "rojalisten": "rojalist",
    "rojalistens": "rojalist",
    "rojalister": "rojalist",
    "rojalisterna": "rojalist",
    "rojalisternas": "rojalist",
    "rojalisters": "rojalist",
    "rojalistiska": "rojalistisk",
    "rojalistiskare": "rojalistisk",
    "rojalistiskares": "rojalistisk",
    "rojalistiskas": "rojalistisk",
    "rojalistiskast": "rojalistisk",
    "rojalistiskaste": "rojalistisk",
    "rojalistiskastes": "rojalistisk",
    "rojalistiskasts": "rojalistisk",
    "rojalistiske": "rojalistisk",
    "rojalistiskes": "rojalistisk",
    "rojalistisks": "rojalistisk",
    "rojalistiskt": "rojalistisk",
    "rojalistiskts": "rojalistisk",
    "rojalists": "rojalist",
    "rokokodamen": "rokokodam",
    "rokokodamens": "rokokodam",
    "rokokodamer": "rokokodam",
    "rokokodamerna": "rokokodam",
    "rokokodamernas": "rokokodam",
    "rokokodamers": "rokokodam",
    "rokokodams": "rokokodam",
    "rokokon": "rokoko",
    "rokokons": "rokoko",
    "rokokopyntade": "rokokopyntad",
    "rokokopyntades": "rokokopyntad",
    "rokokopyntads": "rokokopyntad",
    "rokokopyntat": "rokokopyntad",
    "rokokopyntats": "rokokopyntad",
    "rokokos": "rokoko",
    "roliga": "rolig",
    "roligare": "rolig",
    "roligares": "rolig",
    "roligas": "rolig",
    "roligast": "rolig",
    "roligaste": "rolig",
    "roligastes": "rolig",
    "roligasts": "rolig",
    "rolige": "rolig",
    "roliges": "rolig",
    "roligheten": "rolighet",
    "rolighetens": "rolighet",
    "roligheter": "rolighet",
    "roligheterna": "rolighet",
    "roligheternas": "rolighet",
    "roligheters": "rolighet",
    "rolighets": "rolighet",
    "rolighetsministern": "rolighetsminister",
    "rolighetsministerns": "rolighetsminister",
    "rolighetsministers": "rolighetsminister",
    "rolighetsministrar": "rolighetsminister",
    "rolighetsministrarna": "rolighetsminister",
    "rolighetsministrarnas": "rolighetsminister",
    "rolighetsministrars": "rolighetsminister",
    "roligs": "rolig",
    "roligt": "rolig",
    "roligts": "rolig",
    "roll": "rolla",
    "roll-on-deodoranten": "roll-on-deodorant",
    "roll-on-deodorantens": "roll-on-deodorant",
    "roll-on-deodoranter": "roll-on-deodorant",
    "roll-on-deodoranterna": "roll-on-deodorant",
    "roll-on-deodoranternas": "roll-on-deodorant",
    "roll-on-deodoranters": "roll-on-deodorant",
    "roll-on-deodorants": "roll-on-deodorant",
    "roll-on/roll-off-fartygen": "roll-on/roll-off-fartyg",
    "roll-on/roll-off-fartygens": "roll-on/roll-off-fartyg",
    "roll-on/roll-off-fartyget": "roll-on/roll-off-fartyg",
    "roll-on/roll-off-fartygets": "roll-on/roll-off-fartyg",
    "roll-on/roll-off-fartygs": "roll-on/roll-off-fartyg",
    "rollad": "rolla",
    "rollade": "rolla",
    "rollades": "rolla",
    "rollads": "rolla",
    "rollande": "rolla",
    "rollanden": "rollande",
    "rollandena": "rollande",
    "rollandenas": "rollande",
    "rollandens": "rollande",
    "rollandes": "rollande",
    "rollandet": "rollande",
    "rollandets": "rollande",
    "rollar": "rolla",
    "rollarna": "roll",
    "rollarnas": "roll",
    "rollars": "roll",
    "rollas": "rolla",
    "rollat": "rolla",
    "rollatorer": "rollator",
    "rollatorerna": "rollator",
    "rollatorernas": "rollator",
    "rollatorers": "rollator",
    "rollatorn": "rollator",
    "rollatorns": "rollator",
    "rollators": "rollator",
    "rollats": "rolla",
    "rollbesättningar": "rollbesättning",
    "rollbesättningarna": "rollbesättning",
    "rollbesättningarnas": "rollbesättning",
    "rollbesättningars": "rollbesättning",
    "rollbesättningen": "rollbesättning",
    "rollbesättningens": "rollbesättning",
    "rollbesättnings": "rollbesättning",
    "rollen": "roll",
    "rollens": "roll",
    "roller": "roll",
    "rollerhandtagen": "rollerhandtag",
    "rollerhandtagens": "rollerhandtag",
    "rollerhandtaget": "rollerhandtag",
    "rollerhandtagets": "rollerhandtag",
    "rollerhandtags": "rollerhandtag",
    "rollern": "roller",
    "rollerna": "roller",
    "rollernas": "roller",
    "rollerns": "roller",
    "rollers": "roller",
    "rollfacken": "rollfack",
    "rollfackens": "rollfack",
    "rollfacket": "rollfack",
    "rollfackets": "rollfack",
    "rollfacks": "rollfack",
    "rollfiguren": "rollfigur",
    "rollfigurens": "rollfigur",
    "rollfigurer": "rollfigur",
    "rollfigurerna": "rollfigur",
    "rollfigurernas": "rollfigur",
    "rollfigurers": "rollfigur",
    "rollfigurs": "rollfigur",
    "rollistan": "rollista",
    "rollistans": "rollista",
    "rollistas": "rollista",
    "rolliste": "rollista",
    "rollistor": "rollista",
    "rollistorna": "rollista",
    "rollistornas": "rollista",
    "rollistors": "rollista",
    "rollmopsar": "rollmops",
    "rollmopsarna": "rollmops",
    "rollmopsarnas": "rollmops",
    "rollmopsars": "rollmops",
    "rollmopsen": "rollmops",
    "rollmopsens": "rollmops",
    "rollrar": "roller",
    "rollrarna": "roller",
    "rollrarnas": "roller",
    "rollrars": "roller",
    "rolls": "roll",
    "rollsarna": "rolls",
    "rollsars": "rolls",
    "rollsen": "rolls",
    "rollskiften": "rollskifte",
    "rollskiftena": "rollskifte",
    "rollskiftenas": "rollskifte",
    "rollskiftens": "rollskifte",
    "rollskiftes": "rollskifte",
    "rollskiftet": "rollskifte",
    "rollskiftets": "rollskifte",
    "rollspelen": "rollspel",
    "rollspelens": "rollspel",
    "rollspelet": "rollspel",
    "rollspelets": "rollspel",
    "rollspels": "rollspel",
    "rolösa": "rolös",
    "rolösare": "rolös",
    "rolösares": "rolös",
    "rolösas": "rolös",
    "rolösast": "rolös",
    "rolösaste": "rolös",
    "rolösastes": "rolös",
    "rolösasts": "rolös",
    "rolöse": "rolös",
    "rolöses": "rolös",
    "rolösheten": "rolöshet",
    "rolöshetens": "rolöshet",
    "rolöshets": "rolöshet",
    "rolöst": "rolös",
    "rolösts": "rolös",
    "romanen": "roman",
    "romanens": "roman",
    "romaner": "roman",
    "romanerna": "roman",
    "romanernas": "roman",
    "romaners": "roman",
    "romaneska": "romanesk",
    "romaneskare": "romanesk",
    "romaneskares": "romanesk",
    "romaneskas": "romanesk",
    "romaneskast": "romanesk",
    "romaneskaste": "romanesk",
    "romaneskastes": "romanesk",
    "romaneskasts": "romanesk",
    "romaneske": "romanesk",
    "romaneskes": "romanesk",
    "romanesks": "romanesk",
    "romaneskt": "romanesk",
    "romaneskts": "romanesk",
    "romanförfattar": "romanförfattare",
    "romanförfattaren": "romanförfattare",
    "romanförfattarens": "romanförfattare",
    "romanförfattares": "romanförfattare",
    "romanförfattarna": "romanförfattare",
    "romanförfattarnas": "romanförfattare",
    "romanin": "romani",
    "romanins": "romani",
    "romanis": "romani",
    "romanisten": "romanist",
    "romanistens": "romanist",
    "romanister": "romanist",
    "romanisterna": "romanist",
    "romanisternas": "romanist",
    "romanisters": "romanist",
    "romanistiken": "romanistik",
    "romanistikens": "romanistik",
    "romanistiker": "romanistik",
    "romanistikerna": "romanistik",
    "romanistikernas": "romanistik",
    "romanistikers": "romanistik",
    "romanistiks": "romanistik",
    "romanistiska": "romanistisk",
    "romanistiskare": "romanistisk",
    "romanistiskares": "romanistisk",
    "romanistiskas": "romanistisk",
    "romanistiskast": "romanistisk",
    "romanistiskaste": "romanistisk",
    "romanistiskastes": "romanistisk",
    "romanistiskasts": "romanistisk",
    "romanistiske": "romanistisk",
    "romanistiskes": "romanistisk",
    "romanistisks": "romanistisk",
    "romanistiskt": "romanistisk",
    "romanistiskts": "romanistisk",
    "romanists": "romanist",
    "romans": "roman",
    "romansen": "romans",
    "romansens": "romans",
    "romanser": "romans",
    "romanserna": "romans",
    "romansernas": "romans",
    "romansers": "romans",
    "romanska": "romansk",
    "romanskare": "romansk",
    "romanskares": "romansk",
    "romanskas": "romansk",
    "romanskast": "romansk",
    "romanskaste": "romansk",
    "romanskastes": "romansk",
    "romanskasts": "romansk",
    "romanske": "romansk",
    "romanskes": "romansk",
    "romansks": "romansk",
    "romanskt": "romansk",
    "romanskts": "romansk",
    "romansviten": "romansvit",
    "romansvitens": "romansvit",
    "romansviter": "romansvit",
    "romansviterna": "romansvit",
    "romansviternas": "romansvit",
    "romansviters": "romansvit",
    "romansvits": "romansvit",
    "romantiken": "romantik",
    "romantikens": "romantik",
    "romantikern": "romantiker",
    "romantikerna": "romantiker",
    "romantikernas": "romantiker",
    "romantikerns": "romantiker",
    "romantikers": "romantiker",
    "romantiks": "romantik",
    "romantiserad": "romantisera",
    "romantiserade": "romantisera",
    "romantiserades": "romantisera",
    "romantiserads": "romantisera",
    "romantiserande": "romantisera",
    "romantiseranden": "romantiserande",
    "romantiserandena": "romantiserande",
    "romantiserandenas": "romantiserande",
    "romantiserandens": "romantiserande",
    "romantiserandes": "romantiserande",
    "romantiserandet": "romantiserande",
    "romantiserandets": "romantiserande",
    "romantiserar": "romantisera",
    "romantiseras": "romantisera",
    "romantiserat": "romantisera",
    "romantiserats": "romantisera",
    "romantiserbara": "romantiserbar",
    "romantiserbarare": "romantiserbar",
    "romantiserbarares": "romantiserbar",
    "romantiserbaras": "romantiserbar",
    "romantiserbarast": "romantiserbar",
    "romantiserbaraste": "romantiserbar",
    "romantiserbarastes": "romantiserbar",
    "romantiserbarasts": "romantiserbar",
    "romantiserbare": "romantiserbar",
    "romantiserbares": "romantiserbar",
    "romantiserbarheten": "romantiserbarhet",
    "romantiserbarhetens": "romantiserbarhet",
    "romantiserbarhets": "romantiserbarhet",
    "romantiserbars": "romantiserbar",
    "romantiserbart": "romantiserbar",
    "romantiserbarts": "romantiserbar",
    "romantiseringar": "romantisering",
    "romantiseringarna": "romantisering",
    "romantiseringarnas": "romantisering",
    "romantiseringars": "romantisering",
    "romantiseringen": "romantisering",
    "romantiseringens": "romantisering",
    "romantiserings": "romantisering",
    "romantiska": "romantisk",
    "romantiskare": "romantisk",
    "romantiskares": "romantisk",
    "romantiskas": "romantisk",
    "romantiskast": "romantisk",
    "romantiskaste": "romantisk",
    "romantiskastes": "romantisk",
    "romantiskasts": "romantisk",
    "romantiske": "romantisk",
    "romantiskes": "romantisk",
    "romantisks": "romantisk",
    "romantiskt": "romantisk",
    "romantiskts": "romantisk",
    "romantraditionen": "romantradition",
    "romantraditionens": "romantradition",
    "romantraditioner": "romantradition",
    "romantraditionerna": "romantradition",
    "romantraditionernas": "romantradition",
    "romantraditioners": "romantradition",
    "romantraditions": "romantradition",
    "romar": "romare",
    "romaren": "romare",
    "romarens": "romare",
    "romares": "romare",
    "romarinnan": "romarinna",
    "romarinnans": "romarinna",
    "romarinnas": "romarinna",
    "romarinne": "romarinna",
    "romarinnor": "romarinna",
    "romarinnorna": "romarinna",
    "romarinnornas": "romarinna",
    "romarinnors": "romarinna",
    "romarna": "romare",
    "romarnas": "romare",
    "romarrikes": "romarrike",
    "romarriket": "romarrike",
    "romarrikets": "romarrike",
    "romben": "romb",
    "rombens": "romb",
    "romber": "romb",
    "romberna": "romb",
    "rombernas": "romb",
    "rombers": "romb",
    "rombiska": "rombisk",
    "rombiskare": "rombisk",
    "rombiskares": "rombisk",
    "rombiskas": "rombisk",
    "rombiskast": "rombisk",
    "rombiskaste": "rombisk",
    "rombiskastes": "rombisk",
    "rombiskasts": "rombisk",
    "rombiske": "rombisk",
    "rombiskes": "rombisk",
    "rombisks": "rombisk",
    "rombiskt": "rombisk",
    "rombiskts": "rombisk",
    "romboiden": "romboid",
    "romboidens": "romboid",
    "romboider": "romboid",
    "romboiderna": "romboid",
    "romboidernas": "romboid",
    "romboiders": "romboid",
    "romboids": "romboid",
    "rombs": "romb",
    "romcomen": "romcom",
    "romcomens": "romcom",
    "romcommar": "romcom",
    "romcommarna": "romcom",
    "romcommarnas": "romcom",
    "romcommars": "romcom",
    "romcommen": "romcom",
    "romcommens": "romcom",
    "romcoms": "romcom",
    "romcomsen": "romcom",
    "romcomsens": "romcom",
    "romen": "rom",
    "romens": "rom",
    "romer": "rom",
    "romerna": "rom",
    "romernas": "rom",
    "romers": "rom",
    "romersk-katolska": "romersk-katolsk",
    "romersk-katolskare": "romersk-katolsk",
    "romersk-katolskares": "romersk-katolsk",
    "romersk-katolskas": "romersk-katolsk",
    "romersk-katolskast": "romersk-katolsk",
    "romersk-katolskaste": "romersk-katolsk",
    "romersk-katolskastes": "romersk-katolsk",
    "romersk-katolskasts": "romersk-katolsk",
    "romersk-katolske": "romersk-katolsk",
    "romersk-katolskes": "romersk-katolsk",
    "romersk-katolsks": "romersk-katolsk",
    "romersk-katolskt": "romersk-katolsk",
    "romersk-katolskts": "romersk-katolsk",
    "romerska": "romersk",
    "romerskare": "romersk",
    "romerskares": "romersk",
    "romerskas": "romersk",
    "romerskast": "romersk",
    "romerskaste": "romersk",
    "romerskastes": "romersk",
    "romerskasts": "romersk",
    "romerske": "romersk",
    "romerskes": "romersk",
    "romersks": "romersk",
    "romerskt": "romersk",
    "romerskts": "romersk",
    "romkomen": "romkom",
    "romkomens": "romkom",
    "romkommar": "romkom",
    "romkommarna": "romkom",
    "romkommarnas": "romkom",
    "romkommars": "romkom",
    "romkommen": "romkom",
    "romkommens": "romkom",
    "romkoms": "romkom",
    "romkomsen": "romkom",
    "romkomsens": "romkom",
    "rommanin": "rommani",
    "rommanins": "rommani",
    "rommanis": "rommani",
    "rommen": "rom",
    "rommens": "rom",
    "roms": "rom",
    "ron": "ro",
    "rona": "ro",
    "ronas": "ro",
    "rondellen": "rondell",
    "rondellens": "rondell",
    "rondeller": "rondell",
    "rondellerna": "rondell",
    "rondellernas": "rondell",
    "rondellers": "rondell",
    "rondellhundar": "rondellhund",
    "rondellhundarna": "rondellhund",
    "rondellhundarnas": "rondellhund",
    "rondellhundars": "rondellhund",
    "rondellhunden": "rondellhund",
    "rondellhundens": "rondellhund",
    "rondellhunds": "rondellhund",
    "rondells": "rondell",
    "ronden": "rond",
    "rondens": "rond",
    "ronder": "rond",
    "ronderna": "rond",
    "rondernas": "rond",
    "ronders": "rond",
    "rondon": "rondo",
    "rondona": "rondo",
    "rondonas": "rondo",
    "rondons": "rondo",
    "rondos": "rondo",
    "rondot": "rondo",
    "rondots": "rondo",
    "ronds": "rond",
    "rondören": "rondör",
    "rondörens": "rondör",
    "rondörs": "rondör",
    "rons": "ro",
    "rookien": "rookie",
    "rookiens": "rookie",
    "rookies": "rookie",
    "rookiesarna": "rookie",
    "rookiesarnas": "rookie",
    "rookiesen": "rookie",
    "rookiesens": "rookie",
    "rop": "ropa",
    "ropade": "ropa",
    "ropades": "ropa",
    "ropande": "ropa",
    "ropanden": "ropande",
    "ropandena": "ropande",
    "ropandenas": "ropande",
    "ropandens": "ropande",
    "ropandes": "ropande",
    "ropandet": "ropande",
    "ropandets": "ropande",
    "ropar": "ropa",
    "ropas": "ropa",
    "ropat": "ropa",
    "ropats": "ropa",
    "ropen": "rop",
    "ropens": "rop",
    "ropet": "rop",
    "ropets": "rop",
    "rops": "rop",
    "roqueforten": "roquefort",
    "roquefortens": "roquefort",
    "roquefortostar": "roquefortost",
    "roquefortostarna": "roquefortost",
    "roquefortostarnas": "roquefortost",
    "roquefortostars": "roquefortost",
    "roquefortosten": "roquefortost",
    "roquefortostens": "roquefortost",
    "roquefortosts": "roquefortost",
    "roqueforts": "roquefort",
    "ror": "ro",
    "rorgängar": "rorgängare",
    "rorgängaren": "rorgängare",
    "rorgängarens": "rorgängare",
    "rorgängares": "rorgängare",
    "rorgängarna": "rorgängare",
    "rorgängarnas": "rorgängare",
    "rorkultar": "rorkult",
    "rorkultarna": "rorkult",
    "rorkultarnas": "rorkult",
    "rorkultars": "rorkult",
    "rorkulten": "rorkult",
    "rorkultens": "rorkult",
    "rorkults": "rorkult",
    "rorna": "ro",
    "rornas": "ro",
    "rorpinn": "rorpinne",
    "rorpinnar": "rorpinne",
    "rorpinnarna": "rorpinne",
    "rorpinnarnas": "rorpinne",
    "rorpinnars": "rorpinne",
    "rorpinnen": "rorpinne",
    "rorpinnens": "rorpinne",
    "rorpinnes": "rorpinne",
    "rorpinns": "rorpinne",
    "rors": "ro",
    "rorschachtesten": "rorschachtest",
    "rorschachtestens": "rorschachtest",
    "rorschachtester": "rorschachtest",
    "rorschachtesterna": "rorschachtest",
    "rorschachtesternas": "rorschachtest",
    "rorschachtesters": "rorschachtest",
    "rorschachtestet": "rorschachtest",
    "rorschachtestets": "rorschachtest",
    "rorschachtests": "rorschachtest",
    "rorsmannen": "rorsman",
    "rorsmannens": "rorsman",
    "rorsmans": "rorsman",
    "rorsmän": "rorsman",
    "rorsmännen": "rorsman",
    "rorsmännens": "rorsman",
    "rorsmäns": "rorsman",
    "ros": "rosa",
    "rosad": "rosa",
    "rosade": "rosa",
    "rosades": "rosa",
    "rosads": "rosa",
    "rosafärgade": "rosafärgad",
    "rosafärgades": "rosafärgad",
    "rosafärgads": "rosafärgad",
    "rosafärgat": "rosafärgad",
    "rosafärgats": "rosafärgad",
    "rosande": "rosa",
    "rosanden": "rosande",
    "rosandena": "rosande",
    "rosandenas": "rosande",
    "rosandens": "rosande",
    "rosandes": "rosande",
    "rosandet": "rosande",
    "rosandets": "rosande",
    "rosar": "rosa",
    "rosas": "rosa",
    "rosat": "rosa",
    "rosats": "rosa",
    "rosen": "ros",
    "rosenbröden": "rosenbröd",
    "rosenbrödens": "rosenbröd",
    "rosenbrödet": "rosenbröd",
    "rosenbrödets": "rosenbröd",
    "rosenbröds": "rosenbröd",
    "rosenbusk": "rosenbuske",
    "rosenbuskar": "rosenbuske",
    "rosenbuskarna": "rosenbuske",
    "rosenbuskarnas": "rosenbuske",
    "rosenbuskars": "rosenbuske",
    "rosenbusken": "rosenbuske",
    "rosenbuskens": "rosenbuske",
    "rosenbuskes": "rosenbuske",
    "rosengången": "rosengång",
    "rosengångens": "rosengång",
    "rosengångs": "rosengång",
    "rosengårdar": "rosengård",
    "rosengårdarna": "rosengård",
    "rosengårdarnas": "rosengård",
    "rosengårdars": "rosengård",
    "rosengården": "rosengård",
    "rosengårdens": "rosengård",
    "rosengårds": "rosengård",
    "rosenhyn": "rosenhy",
    "rosenhyns": "rosenhy",
    "rosenhys": "rosenhy",
    "rosenkindade": "rosenkindad",
    "rosenkindades": "rosenkindad",
    "rosenkindads": "rosenkindad",
    "rosenkindat": "rosenkindad",
    "rosenkindats": "rosenkindad",
    "rosenkinden": "rosenkind",
    "rosenkindens": "rosenkind",
    "rosenkinder": "rosenkind",
    "rosenkinderna": "rosenkind",
    "rosenkindernas": "rosenkind",
    "rosenkinders": "rosenkind",
    "rosenkinds": "rosenkind",
    "rosenkransar": "rosenkrans",
    "rosenkransarna": "rosenkrans",
    "rosenkransarnas": "rosenkrans",
    "rosenkransars": "rosenkrans",
    "rosenkransen": "rosenkrans",
    "rosenkransens": "rosenkrans",
    "rosenkålen": "rosenkål",
    "rosenkålens": "rosenkål",
    "rosenkåls": "rosenkål",
    "rosenmolnen": "rosenmoln",
    "rosenmolnens": "rosenmoln",
    "rosenmolnet": "rosenmoln",
    "rosenmolnets": "rosenmoln",
    "rosenmolns": "rosenmoln",
    "rosenmunnar": "rosenmun",
    "rosenmunnarna": "rosenmun",
    "rosenmunnarnas": "rosenmun",
    "rosenmunnars": "rosenmun",
    "rosenmunnen": "rosenmun",
    "rosenmunnens": "rosenmun",
    "rosenmuns": "rosenmun",
    "rosenoljan": "rosenolja",
    "rosenoljans": "rosenolja",
    "rosenoljas": "rosenolja",
    "rosenolje": "rosenolja",
    "rosenröda": "rosenröd",
    "rosenrödare": "rosenröd",
    "rosenrödares": "rosenröd",
    "rosenrödas": "rosenröd",
    "rosenrödast": "rosenröd",
    "rosenrödaste": "rosenröd",
    "rosenrödastes": "rosenröd",
    "rosenrödasts": "rosenröd",
    "rosenröde": "rosenröd",
    "rosenrödes": "rosenröd",
    "rosenröds": "rosenröd",
    "rosenrött": "rosenröd",
    "rosenrötts": "rosenröd",
    "rosens": "ros",
    "rosenstenen": "rosensten",
    "rosenstenens": "rosensten",
    "rosenstens": "rosensten",
    "rosenstockar": "rosenstock",
    "rosenstockarna": "rosenstock",
    "rosenstockarnas": "rosenstock",
    "rosenstockars": "rosenstock",
    "rosenstocken": "rosenstock",
    "rosenstockens": "rosenstock",
    "rosenstocks": "rosenstock",
    "rosenträet": "rosenträ",
    "rosenträets": "rosenträ",
    "rosenträs": "rosenträ",
    "rosenträt": "rosenträ",
    "rosenträts": "rosenträ",
    "rosenvattens": "rosenvatten",
    "rosenvattnet": "rosenvatten",
    "rosenvattnets": "rosenvatten",
    "roset": "ros",
    "rosets": "ros",
    "rosetten": "rosett",
    "rosettens": "rosett",
    "rosetter": "rosett",
    "rosetterna": "rosett",
    "rosetternas": "rosett",
    "rosetters": "rosett",
    "rosettfönsterna": "rosettfönster",
    "rosettfönsternas": "rosettfönster",
    "rosettfönsters": "rosettfönster",
    "rosettfönstren": "rosettfönster",
    "rosettfönstrens": "rosettfönster",
    "rosettfönstret": "rosettfönster",
    "rosettfönstrets": "rosettfönster",
    "rosettmönsterna": "rosettmönster",
    "rosettmönsternas": "rosettmönster",
    "rosettmönsters": "rosettmönster",
    "rosettmönstren": "rosettmönster",
    "rosettmönstrens": "rosettmönster",
    "rosettmönstret": "rosettmönster",
    "rosettmönstrets": "rosettmönster",
    "rosetts": "rosett",
    "rosettställda": "rosettställd",
    "rosettställdare": "rosettställd",
    "rosettställdares": "rosettställd",
    "rosettställdas": "rosettställd",
    "rosettställdast": "rosettställd",
    "rosettställdaste": "rosettställd",
    "rosettställdastes": "rosettställd",
    "rosettställdasts": "rosettställd",
    "rosettställde": "rosettställd",
    "rosettställdes": "rosettställd",
    "rosettställds": "rosettställd",
    "rosettställt": "rosettställd",
    "rosettställts": "rosettställd",
    "rosiga": "rosig",
    "rosigare": "rosig",
    "rosigares": "rosig",
    "rosigas": "rosig",
    "rosigast": "rosig",
    "rosigaste": "rosig",
    "rosigastes": "rosig",
    "rosigasts": "rosig",
    "rosige": "rosig",
    "rosiges": "rosig",
    "rosigs": "rosig",
    "rosigt": "rosig",
    "rosigts": "rosig",
    "roskarlar": "roskarl",
    "roskarlarna": "roskarl",
    "roskarlarnas": "roskarl",
    "roskarlars": "roskarl",
    "roskarlen": "roskarl",
    "roskarlens": "roskarl",
    "roskarls": "roskarl",
    "roslingar": "rosling",
    "roslingarna": "rosling",
    "roslingarnas": "rosling",
    "roslingars": "rosling",
    "roslingen": "rosling",
    "roslingens": "rosling",
    "roslings": "rosling",
    "rosmarinen": "rosmarin",
    "rosmarinens": "rosmarin",
    "rosmariner": "rosmarin",
    "rosmarinerna": "rosmarin",
    "rosmarinernas": "rosmarin",
    "rosmariners": "rosmarin",
    "rosmarins": "rosmarin",
    "rosor": "ros",
    "rosorna": "ros",
    "rosornas": "ros",
    "rosors": "ros",
    "rospiggar": "rospigg",
    "rospiggarna": "rospigg",
    "rospiggarnas": "rospigg",
    "rospiggars": "rospigg",
    "rospiggen": "rospigg",
    "rospiggens": "rospigg",
    "rospiggs": "rospigg",
    "rossel": "rossla",
    "rosslade": "rossla",
    "rosslades": "rossla",
    "rosslande": "rossla",
    "rosslanden": "rosslande",
    "rosslandena": "rosslande",
    "rosslandenas": "rosslande",
    "rosslandens": "rosslande",
    "rosslandes": "rosslande",
    "rosslandet": "rosslande",
    "rosslandets": "rosslande",
    "rosslar": "rossla",
    "rosslas": "rossla",
    "rosslat": "rossla",
    "rosslats": "rossla",
    "rossliga": "rosslig",
    "rossligare": "rosslig",
    "rossligares": "rosslig",
    "rossligas": "rosslig",
    "rossligast": "rosslig",
    "rossligaste": "rosslig",
    "rossligastes": "rosslig",
    "rossligasts": "rosslig",
    "rosslige": "rosslig",
    "rossliges": "rosslig",
    "rossligheten": "rosslighet",
    "rosslighetens": "rosslighet",
    "rosslighets": "rosslighet",
    "rossligs": "rosslig",
    "rossligt": "rosslig",
    "rossligts": "rosslig",
    "rosslingar": "rossling",
    "rosslingarna": "rossling",
    "rosslingarnas": "rossling",
    "rosslingars": "rossling",
    "rosslingen": "rossling",
    "rosslingens": "rossling",
    "rosslings": "rossling",
    "rost": "rosta",
    "rostad": "rosta",
    "rostade": "rosta",
    "rostades": "rosta",
    "rostads": "rosta",
    "rostande": "rosta",
    "rostanden": "rostande",
    "rostandena": "rostande",
    "rostandenas": "rostande",
    "rostandens": "rostande",
    "rostandes": "rostande",
    "rostandet": "rostande",
    "rostandets": "rostande",
    "rostar": "rosta",
    "rostarna": "rost",
    "rostarnas": "rost",
    "rostars": "rost",
    "rostas": "rosta",
    "rostat": "rosta",
    "rostats": "rosta",
    "rostbehandlad": "rostbehandla",
    "rostbehandlade": "rostbehandla",
    "rostbehandlades": "rostbehandla",
    "rostbehandlads": "rostbehandla",
    "rostbehandlande": "rostbehandla",
    "rostbehandlanden": "rostbehandlande",
    "rostbehandlandena": "rostbehandlande",
    "rostbehandlandenas": "rostbehandlande",
    "rostbehandlandens": "rostbehandlande",
    "rostbehandlandes": "rostbehandlande",
    "rostbehandlandet": "rostbehandlande",
    "rostbehandlandets": "rostbehandlande",
    "rostbehandlar": "rostbehandla",
    "rostbehandlas": "rostbehandla",
    "rostbehandlat": "rostbehandla",
    "rostbehandlats": "rostbehandla",
    "rostbiffar": "rostbiff",
    "rostbiffarna": "rostbiff",
    "rostbiffarnas": "rostbiff",
    "rostbiffars": "rostbiff",
    "rostbiffen": "rostbiff",
    "rostbiffens": "rostbiff",
    "rostbiffs": "rostbiff",
    "rosten": "rost",
    "rostens": "rost",
    "rosterier": "rosteri",
    "rosterierna": "rosteri",
    "rosteriernas": "rosteri",
    "rosteriers": "rosteri",
    "rosteriet": "rosteri",
    "rosteriets": "rosteri",
    "rosteris": "rosteri",
    "rosterit": "rosteri",
    "rosterits": "rosteri",
    "rosterna": "roster",
    "rosternas": "roster",
    "rosters": "roster",
    "rostfläckade": "rostfläckad",
    "rostfläckades": "rostfläckad",
    "rostfläckads": "rostfläckad",
    "rostfläckar": "rostfläck",
    "rostfläckarna": "rostfläck",
    "rostfläckarnas": "rostfläck",
    "rostfläckars": "rostfläck",
    "rostfläckat": "rostfläckad",
    "rostfläckats": "rostfläckad",
    "rostfläcken": "rostfläck",
    "rostfläckens": "rostfläck",
    "rostfläcks": "rostfläck",
    "rostfria": "rostfri",
    "rostfriare": "rostfri",
    "rostfriares": "rostfri",
    "rostfrias": "rostfri",
    "rostfriast": "rostfri",
    "rostfriaste": "rostfri",
    "rostfriastes": "rostfri",
    "rostfriasts": "rostfri",
    "rostfrie": "rostfri",
    "rostfries": "rostfri",
    "rostfris": "rostfri",
    "rostfritt": "rostfri",
    "rostfritts": "rostfri",
    "rostiga": "rostig",
    "rostigare": "rostig",
    "rostigares": "rostig",
    "rostigas": "rostig",
    "rostigast": "rostig",
    "rostigaste": "rostig",
    "rostigastes": "rostig",
    "rostigasts": "rostig",
    "rostige": "rostig",
    "rostiges": "rostig",
    "rostigheten": "rostighet",
    "rostighetens": "rostighet",
    "rostighets": "rostighet",
    "rostigs": "rostig",
    "rostigt": "rostig",
    "rostigts": "rostig",
    "rostren": "roster",
    "rostrens": "roster",
    "rostret": "roster",
    "rostrets": "roster",
    "roströda": "roströd",
    "roströdare": "roströd",
    "roströdares": "roströd",
    "roströdas": "roströd",
    "roströdast": "roströd",
    "roströdaste": "roströd",
    "roströdastes": "roströd",
    "roströdasts": "roströd",
    "roströde": "roströd",
    "roströdes": "roströd",
    "roströds": "roströd",
    "rostrött": "roströd",
    "roströtts": "roströd",
    "rosts": "rost",
    "rostskydd": "rostskydda",
    "rostskyddad": "rostskydda",
    "rostskyddade": "rostskydda",
    "rostskyddades": "rostskydda",
    "rostskyddads": "rostskydda",
    "rostskyddande": "rostskydda",
    "rostskyddanden": "rostskyddande",
    "rostskyddandena": "rostskyddande",
    "rostskyddandenas": "rostskyddande",
    "rostskyddandens": "rostskyddande",
    "rostskyddandes": "rostskyddande",
    "rostskyddandet": "rostskyddande",
    "rostskyddandets": "rostskyddande",
    "rostskyddar": "rostskydda",
    "rostskyddas": "rostskydda",
    "rostskyddat": "rostskydda",
    "rostskyddats": "rostskydda",
    "rostskydden": "rostskydd",
    "rostskyddens": "rostskydd",
    "rostskyddet": "rostskydd",
    "rostskyddets": "rostskydd",
    "rostskydds": "rostskydd",
    "rostskyddsbehandlingar": "rostskyddsbehandling",
    "rostskyddsbehandlingarna": "rostskyddsbehandling",
    "rostskyddsbehandlingarnas": "rostskyddsbehandling",
    "rostskyddsbehandlingars": "rostskyddsbehandling",
    "rostskyddsbehandlingen": "rostskyddsbehandling",
    "rostskyddsbehandlingens": "rostskyddsbehandling",
    "rostskyddsbehandlings": "rostskyddsbehandling",
    "rostskyddsfärgade": "rostskyddsfärgad",
    "rostskyddsfärgades": "rostskyddsfärgad",
    "rostskyddsfärgads": "rostskyddsfärgad",
    "rostskyddsfärgat": "rostskyddsfärgad",
    "rostskyddsfärgats": "rostskyddsfärgad",
    "rostskyddsfärgen": "rostskyddsfärg",
    "rostskyddsfärgens": "rostskyddsfärg",
    "rostskyddsfärger": "rostskyddsfärg",
    "rostskyddsfärgerna": "rostskyddsfärg",
    "rostskyddsfärgernas": "rostskyddsfärg",
    "rostskyddsfärgers": "rostskyddsfärg",
    "rostskyddsfärgs": "rostskyddsfärg",
    "rostskyddsmedels": "rostskyddsmedel",
    "rostskyddsmedlen": "rostskyddsmedel",
    "rostskyddsmedlens": "rostskyddsmedel",
    "rostskyddsmedlet": "rostskyddsmedel",
    "rostskyddsmedlets": "rostskyddsmedel",
    "rostskyddspigmenten": "rostskyddspigment",
    "rostskyddspigmentens": "rostskyddspigment",
    "rostskyddspigmentet": "rostskyddspigment",
    "rostskyddspigmentets": "rostskyddspigment",
    "rostskyddspigments": "rostskyddspigment",
    "rostsvampar": "rostsvamp",
    "rostsvamparna": "rostsvamp",
    "rostsvamparnas": "rostsvamp",
    "rostsvampars": "rostsvamp",
    "rostsvampen": "rostsvamp",
    "rostsvampens": "rostsvamp",
    "rostsvamps": "rostsvamp",
    "rosépepparn": "rosépeppar",
    "rosépepparns": "rosépeppar",
    "rosépeppars": "rosépeppar",
    "roséviner": "rosévin",
    "rosévinerna": "rosévin",
    "rosévinernas": "rosévin",
    "roséviners": "rosévin",
    "rosévinet": "rosévin",
    "rosévinets": "rosévin",
    "rosévins": "rosévin",
    "rot": "rota",
    "rotade": "rota",
    "rotades": "rota",
    "rotande": "rota",
    "rotanden": "rotande",
    "rotandena": "rotande",
    "rotandenas": "rotande",
    "rotandens": "rotande",
    "rotandes": "rotande",
    "rotandet": "rotande",
    "rotandets": "rotande",
    "rotar": "rote",
    "rotarna": "rote",
    "rotarnas": "rote",
    "rotars": "rote",
    "rotas": "rota",
    "rotat": "rota",
    "rotationen": "rotation",
    "rotationens": "rotation",
    "rotationer": "rotation",
    "rotationerna": "rotation",
    "rotationernas": "rotation",
    "rotationers": "rotation",
    "rotations": "rotation",
    "rotationsaxeln": "rotationsaxel",
    "rotationsaxelns": "rotationsaxel",
    "rotationsaxels": "rotationsaxel",
    "rotationsaxlar": "rotationsaxel",
    "rotationsaxlarna": "rotationsaxel",
    "rotationsaxlarnas": "rotationsaxel",
    "rotationsaxlars": "rotationsaxel",
    "rotationsenergien": "rotationsenergi",
    "rotationsenergiens": "rotationsenergi",
    "rotationsenergin": "rotationsenergi",
    "rotationsenergins": "rotationsenergi",
    "rotationsenergis": "rotationsenergi",
    "rotationshastigheten": "rotationshastighet",
    "rotationshastighetens": "rotationshastighet",
    "rotationshastigheter": "rotationshastighet",
    "rotationshastigheterna": "rotationshastighet",
    "rotationshastigheternas": "rotationshastighet",
    "rotationshastigheters": "rotationshastighet",
    "rotationshastighets": "rotationshastighet",
    "rotationsmotorer": "rotationsmotor",
    "rotationsmotorerna": "rotationsmotor",
    "rotationsmotorernas": "rotationsmotor",
    "rotationsmotorers": "rotationsmotor",
    "rotationsmotorn": "rotationsmotor",
    "rotationsmotorns": "rotationsmotor",
    "rotationsmotors": "rotationsmotor",
    "rotationspressar": "rotationspress",
    "rotationspressarna": "rotationspress",
    "rotationspressarnas": "rotationspress",
    "rotationspressars": "rotationspress",
    "rotationspressen": "rotationspress",
    "rotationspressens": "rotationspress",
    "rotats": "rota",
    "rotavdragen": "rotavdrag",
    "rotavdragens": "rotavdrag",
    "rotavdraget": "rotavdrag",
    "rotavdragets": "rotavdrag",
    "rotavdrags": "rotavdrag",
    "rotblöt": "rotblöta",
    "rotblötan": "rotblöta",
    "rotblötans": "rotblöta",
    "rotblötas": "rotblöta",
    "rotblöte": "rotblöta",
    "rotblötor": "rotblöta",
    "rotblötorna": "rotblöta",
    "rotblötornas": "rotblöta",
    "rotblötors": "rotblöta",
    "rotblöts": "rotblöta",
    "rotborst": "rotborste",
    "rotborstar": "rotborste",
    "rotborstarna": "rotborste",
    "rotborstarnas": "rotborste",
    "rotborstars": "rotborste",
    "rotborsten": "rotborste",
    "rotborstens": "rotborste",
    "rotborstes": "rotborste",
    "roteln": "rotel",
    "rotelns": "rotel",
    "rotels": "rotel",
    "roten": "rote",
    "rotenonet": "rotenon",
    "rotenonets": "rotenon",
    "rotenons": "rotenon",
    "rotens": "rote",
    "roterad": "rotera",
    "roterade": "rotera",
    "roterades": "rotera",
    "roterads": "rotera",
    "roterande": "rotera",
    "roteranden": "roterande",
    "roterandena": "roterande",
    "roterandenas": "roterande",
    "roterandens": "roterande",
    "roterandes": "roterande",
    "roterandet": "roterande",
    "roterandets": "roterande",
    "roterar": "rotera",
    "roteras": "rotera",
    "roterat": "rotera",
    "roterats": "rotera",
    "roterbara": "roterbar",
    "roterbaras": "roterbar",
    "roterbare": "roterbar",
    "roterbares": "roterbar",
    "roterbars": "roterbar",
    "roterbart": "roterbar",
    "roterbarts": "roterbar",
    "roteringar": "rotering",
    "roteringarna": "rotering",
    "roteringarnas": "rotering",
    "roteringars": "rotering",
    "roteringen": "rotering",
    "roteringens": "rotering",
    "roterings": "rotering",
    "rotes": "rote",
    "rotfasta": "rotfast",
    "rotfastare": "rotfast",
    "rotfastares": "rotfast",
    "rotfastas": "rotfast",
    "rotfastast": "rotfast",
    "rotfastaste": "rotfast",
    "rotfastastes": "rotfast",
    "rotfastasts": "rotfast",
    "rotfaste": "rotfast",
    "rotfastes": "rotfast",
    "rotfastheten": "rotfasthet",
    "rotfasthetens": "rotfasthet",
    "rotfasthets": "rotfasthet",
    "rotfasts": "rotfast",
    "rotfrukten": "rotfrukt",
    "rotfruktens": "rotfrukt",
    "rotfrukter": "rotfrukt",
    "rotfrukterna": "rotfrukt",
    "rotfrukternas": "rotfrukt",
    "rotfrukters": "rotfrukt",
    "rotfrukts": "rotfrukt",
    "rotfyll": "rotfylla",
    "rotfyllande": "rotfylla",
    "rotfyllanden": "rotfyllande",
    "rotfyllandena": "rotfyllande",
    "rotfyllandenas": "rotfyllande",
    "rotfyllandens": "rotfyllande",
    "rotfyllandes": "rotfyllande",
    "rotfyllandet": "rotfyllande",
    "rotfyllandets": "rotfyllande",
    "rotfyllas": "rotfylla",
    "rotfylld": "rotfylla",
    "rotfyllda": "rotfylla",
    "rotfylldas": "rotfylla",
    "rotfyllde": "rotfylla",
    "rotfylldes": "rotfylla",
    "rotfyllds": "rotfylla",
    "rotfyller": "rotfylla",
    "rotfylles": "rotfylla",
    "rotfyllningar": "rotfyllning",
    "rotfyllningarna": "rotfyllning",
    "rotfyllningarnas": "rotfyllning",
    "rotfyllningars": "rotfyllning",
    "rotfyllningen": "rotfyllning",
    "rotfyllningens": "rotfyllning",
    "rotfyllnings": "rotfyllning",
    "rotfylls": "rotfylla",
    "rotfyllt": "rotfylla",
    "rotfyllts": "rotfylla",
    "rotfäst": "rotfäste",
    "rotfästen": "rotfäste",
    "rotfästena": "rotfäste",
    "rotfästenas": "rotfäste",
    "rotfästens": "rotfäste",
    "rotfästes": "rotfäste",
    "rotfästet": "rotfäste",
    "rotfästets": "rotfäste",
    "rotgrönsaken": "rotgrönsak",
    "rotgrönsakens": "rotgrönsak",
    "rotgrönsaker": "rotgrönsak",
    "rotgrönsakerna": "rotgrönsak",
    "rotgrönsakernas": "rotgrönsak",
    "rotgrönsakers": "rotgrönsak",
    "rotgrönsaks": "rotgrönsak",
    "rotisserier": "rotisseri",
    "rotisserierna": "rotisseri",
    "rotisseriernas": "rotisseri",
    "rotisseriers": "rotisseri",
    "rotisseriet": "rotisseri",
    "rotisseriets": "rotisseri",
    "rotisseris": "rotisseri",
    "rotisserit": "rotisseri",
    "rotisserits": "rotisseri",
    "rotkanalen": "rotkanal",
    "rotkanalens": "rotkanal",
    "rotkanaler": "rotkanal",
    "rotkanalerna": "rotkanal",
    "rotkanalernas": "rotkanal",
    "rotkanalers": "rotkanal",
    "rotkanals": "rotkanal",
    "rotknölar": "rotknöl",
    "rotknölarna": "rotknöl",
    "rotknölarnas": "rotknöl",
    "rotknölars": "rotknöl",
    "rotknölen": "rotknöl",
    "rotknölens": "rotknöl",
    "rotknöls": "rotknöl",
    "rotlar": "rotel",
    "rotlarna": "rotel",
    "rotlarnas": "rotel",
    "rotlars": "rotel",
    "rotlösa": "rotlös",
    "rotlösare": "rotlös",
    "rotlösares": "rotlös",
    "rotlösas": "rotlös",
    "rotlösast": "rotlös",
    "rotlösaste": "rotlös",
    "rotlösastes": "rotlös",
    "rotlösasts": "rotlös",
    "rotlöse": "rotlös",
    "rotlöses": "rotlös",
    "rotlösheten": "rotlöshet",
    "rotlöshetens": "rotlöshet",
    "rotlöshets": "rotlöshet",
    "rotlöst": "rotlös",
    "rotlösts": "rotlös",
    "rotmoset": "rotmos",
    "rotmosets": "rotmos",
    "rotmärken": "rotmärke",
    "rotmärkena": "rotmärke",
    "rotmärkenas": "rotmärke",
    "rotmärkens": "rotmärke",
    "rotmärkes": "rotmärke",
    "rotmärket": "rotmärke",
    "rotmärkets": "rotmärke",
    "rotogravyrbilden": "rotogravyrbild",
    "rotogravyrbildens": "rotogravyrbild",
    "rotogravyrbilder": "rotogravyrbild",
    "rotogravyrbilderna": "rotogravyrbild",
    "rotogravyrbildernas": "rotogravyrbild",
    "rotogravyrbilders": "rotogravyrbild",
    "rotogravyrbilds": "rotogravyrbild",
    "rotogravyren": "rotogravyr",
    "rotogravyrens": "rotogravyr",
    "rotogravyrer": "rotogravyr",
    "rotogravyrerna": "rotogravyr",
    "rotogravyrernas": "rotogravyr",
    "rotogravyrers": "rotogravyr",
    "rotogravyrs": "rotogravyr",
    "rotorbladen": "rotorblad",
    "rotorbladens": "rotorblad",
    "rotorbladet": "rotorblad",
    "rotorbladets": "rotorblad",
    "rotorblads": "rotorblad",
    "rotorer": "rotor",
    "rotorerna": "rotor",
    "rotorernas": "rotor",
    "rotorers": "rotor",
    "rotorn": "rotor",
    "rotorns": "rotor",
    "rotors": "rotor",
    "rots": "rot",
    "rotsaken": "rotsak",
    "rotsakens": "rotsak",
    "rotsaker": "rotsak",
    "rotsakerna": "rotsak",
    "rotsakernas": "rotsak",
    "rotsakers": "rotsak",
    "rotsaks": "rotsak",
    "rotsellerin": "rotselleri",
    "rotsellerins": "rotselleri",
    "rotselleris": "rotselleri",
    "rotsen": "rots",
    "rotsens": "rots",
    "rotstockar": "rotstock",
    "rotstockarna": "rotstock",
    "rotstockarnas": "rotstock",
    "rotstockars": "rotstock",
    "rotstocken": "rotstock",
    "rotstockens": "rotstock",
    "rotstocks": "rotstock",
    "rotsystemen": "rotsystem",
    "rotsystemens": "rotsystem",
    "rotsystemet": "rotsystem",
    "rotsystemets": "rotsystem",
    "rotsystems": "rotsystem",
    "rott": "ro",
    "rotteckens": "rottecken",
    "rottecknen": "rottecken",
    "rottecknens": "rottecken",
    "rottecknet": "rottecken",
    "rottecknets": "rottecken",
    "rottingar": "rotting",
    "rottingarna": "rotting",
    "rottingarnas": "rotting",
    "rottingars": "rotting",
    "rottingen": "rotting",
    "rottingens": "rotting",
    "rottingfåtöljen": "rottingfåtölj",
    "rottingfåtöljens": "rottingfåtölj",
    "rottingfåtöljer": "rottingfåtölj",
    "rottingfåtöljerna": "rottingfåtölj",
    "rottingfåtöljernas": "rottingfåtölj",
    "rottingfåtöljers": "rottingfåtölj",
    "rottingfåtöljs": "rottingfåtölj",
    "rottings": "rotting",
    "rottingsoff": "rottingsoffa",
    "rottingsoffan": "rottingsoffa",
    "rottingsoffans": "rottingsoffa",
    "rottingsoffas": "rottingsoffa",
    "rottingsoffe": "rottingsoffa",
    "rottingsoffor": "rottingsoffa",
    "rottingsofforna": "rottingsoffa",
    "rottingsoffornas": "rottingsoffa",
    "rottingsoffors": "rottingsoffa",
    "rottingsoffs": "rottingsoffa",
    "rottrycket": "rottryck",
    "rottryckets": "rottryck",
    "rottrycks": "rottryck",
    "rottrådar": "rottråd",
    "rottrådarna": "rottråd",
    "rottrådarnas": "rottråd",
    "rottrådars": "rottråd",
    "rottråden": "rottråd",
    "rottrådens": "rottråd",
    "rottråds": "rottråd",
    "rotts": "ro",
    "rottweilern": "rottweiler",
    "rottweilerna": "rottweiler",
    "rottweilernas": "rottweiler",
    "rottweilerns": "rottweiler",
    "rottweilers": "rottweiler",
    "rotund": "rotunda",
    "rotundan": "rotunda",
    "rotundans": "rotunda",
    "rotundas": "rotunda",
    "rotunde": "rotunda",
    "rotundor": "rotunda",
    "rotundorna": "rotunda",
    "rotundornas": "rotunda",
    "rotundors": "rotunda",
    "rotunds": "rotunda",
    "rotvälsk": "rotvälska",
    "rotvälskan": "rotvälska",
    "rotvälskans": "rotvälska",
    "rotvälskas": "rotvälska",
    "rotvält": "rotvälta",
    "rotvältan": "rotvälta",
    "rotvältans": "rotvälta",
    "rotvältas": "rotvälta",
    "rotvälte": "rotvälta",
    "rotvältor": "rotvälta",
    "rotvältorna": "rotvälta",
    "rotvältornas": "rotvälta",
    "rotvältors": "rotvälta",
    "rotvälts": "rotvälta",
    "rouges": "rouge",
    "rouget": "rouge",
    "rougets": "rouge",
    "roughar": "rough",
    "rougharna": "rough",
    "rougharnas": "rough",
    "roughars": "rough",
    "roughen": "rough",
    "roughens": "rough",
    "roughs": "rough",
    "rouladen": "roulad",
    "rouladens": "roulad",
    "roulader": "roulad",
    "rouladerna": "roulad",
    "rouladernas": "roulad",
    "rouladers": "roulad",
    "roulads": "roulad",
    "rouletten": "roulett",
    "roulettens": "roulett",
    "rouletter": "roulett",
    "rouletterna": "roulett",
    "rouletternas": "roulett",
    "rouletters": "roulett",
    "rouletts": "roulett",
    "rousseauanen": "rousseauan",
    "rousseauanens": "rousseauan",
    "rousseauaner": "rousseauan",
    "rousseauanerna": "rousseauan",
    "rousseauanernas": "rousseauan",
    "rousseauaners": "rousseauan",
    "rousseauanismen": "rousseauanism",
    "rousseauanismens": "rousseauanism",
    "rousseauanismer": "rousseauanism",
    "rousseauanismerna": "rousseauanism",
    "rousseauanismernas": "rousseauanism",
    "rousseauanismers": "rousseauanism",
    "rousseauanisms": "rousseauanism",
    "rousseauans": "rousseauan",
    "routen": "route",
    "routens": "route",
    "router": "route",
    "routerna": "route",
    "routernas": "route",
    "routers": "route",
    "routes": "route",
    "rouéen": "roué",
    "rouéens": "roué",
    "rouéer": "roué",
    "rouéerna": "roué",
    "rouéernas": "roué",
    "rouéers": "roué",
    "rouén": "roué",
    "rouéns": "roué",
    "roués": "roué",
    "rov": "rova",
    "rovan": "rova",
    "rovans": "rova",
    "rovas": "rova",
    "rovdjuren": "rovdjur",
    "rovdjurens": "rovdjur",
    "rovdjuret": "rovdjur",
    "rovdjurets": "rovdjur",
    "rovdjurs": "rovdjur",
    "rovdriften": "rovdrift",
    "rovdriftens": "rovdrift",
    "rovdrifts": "rovdrift",
    "rove": "rova",
    "roven": "rov",
    "rovens": "rov",
    "rovet": "rov",
    "rovets": "rov",
    "rovfiskar": "rovfisk",
    "rovfiskarna": "rovfisk",
    "rovfiskarnas": "rovfisk",
    "rovfiskars": "rovfisk",
    "rovfisken": "rovfisk",
    "rovfiskens": "rovfisk",
    "rovfiskes": "rovfiske",
    "rovfisket": "rovfiske",
    "rovfiskets": "rovfiske",
    "rovfisks": "rovfisk",
    "rovfågeln": "rovfågel",
    "rovfågelns": "rovfågel",
    "rovfågels": "rovfågel",
    "rovfåglar": "rovfågel",
    "rovfåglarna": "rovfågel",
    "rovfåglarnas": "rovfågel",
    "rovfåglars": "rovfågel",
    "rovgiriga": "rovgirig",
    "rovgirigare": "rovgirig",
    "rovgirigares": "rovgirig",
    "rovgirigas": "rovgirig",
    "rovgirigast": "rovgirig",
    "rovgirigaste": "rovgirig",
    "rovgirigastes": "rovgirig",
    "rovgirigasts": "rovgirig",
    "rovgirige": "rovgirig",
    "rovgiriges": "rovgirig",
    "rovgirigheten": "rovgirighet",
    "rovgirighetens": "rovgirighet",
    "rovgirighets": "rovgirighet",
    "rovgirigs": "rovgirig",
    "rovgirigt": "rovgirig",
    "rovgirigts": "rovgirig",
    "rovlystens": "rovlysten",
    "rovlystet": "rovlysten",
    "rovlystets": "rovlysten",
    "rovlystna": "rovlysten",
    "rovlystnare": "rovlysten",
    "rovlystnares": "rovlysten",
    "rovlystnas": "rovlysten",
    "rovlystnast": "rovlysten",
    "rovlystnaste": "rovlysten",
    "rovlystnastes": "rovlysten",
    "rovlystnasts": "rovlysten",
    "rovlystne": "rovlysten",
    "rovlystnes": "rovlysten",
    "rovor": "rova",
    "rovorna": "rova",
    "rovornas": "rova",
    "rovors": "rova",
    "rovriddar": "rovriddare",
    "rovriddaren": "rovriddare",
    "rovriddarens": "rovriddare",
    "rovriddares": "rovriddare",
    "rovriddarna": "rovriddare",
    "rovriddarnas": "rovriddare",
    "rovs": "rova",
    "royalties": "royalty",
    "royaltiesarna": "royalty",
    "royaltiesarnas": "royalty",
    "royaltyn": "royalty",
    "royaltyns": "royalty",
    "royaltys": "royalty",
    "rs": "r",
    "rubankar": "rubank",
    "rubankarna": "rubank",
    "rubankarnas": "rubank",
    "rubankars": "rubank",
    "rubanken": "rubank",
    "rubankens": "rubank",
    "rubanks": "rubank",
    "rubb": "rubba",
    "rubbad": "rubba",
    "rubbade": "rubbad",
    "rubbades": "rubbad",
    "rubbads": "rubbad",
    "rubbande": "rubba",
    "rubbanden": "rubbande",
    "rubbandena": "rubbande",
    "rubbandenas": "rubbande",
    "rubbandens": "rubbande",
    "rubbandes": "rubbande",
    "rubbandet": "rubbande",
    "rubbandets": "rubbande",
    "rubbar": "rubba",
    "rubbas": "rubba",
    "rubbat": "rubbad",
    "rubbats": "rubbad",
    "rubbets": "rubbet",
    "rubbingen": "rubbing",
    "rubbingens": "rubbing",
    "rubbings": "rubbing",
    "rubbningar": "rubbning",
    "rubbningarna": "rubbning",
    "rubbningarnas": "rubbning",
    "rubbningars": "rubbning",
    "rubbningen": "rubbning",
    "rubbningens": "rubbning",
    "rubbnings": "rubbning",
    "rubeln": "rubel",
    "rubelns": "rubel",
    "rubels": "rubel",
    "rubidiet": "rubidium",
    "rubidiets": "rubidium",
    "rubidiumet": "rubidium",
    "rubidiumets": "rubidium",
    "rubidiums": "rubidium",
    "rubinen": "rubin",
    "rubinens": "rubin",
    "rubiner": "rubin",
    "rubinerna": "rubin",
    "rubinernas": "rubin",
    "rubiners": "rubin",
    "rubinglaset": "rubinglas",
    "rubinglasets": "rubinglas",
    "rubinröda": "rubinröd",
    "rubinrödare": "rubinröd",
    "rubinrödares": "rubinröd",
    "rubinrödas": "rubinröd",
    "rubinrödast": "rubinröd",
    "rubinrödaste": "rubinröd",
    "rubinrödastes": "rubinröd",
    "rubinrödasts": "rubinröd",
    "rubinröde": "rubinröd",
    "rubinrödes": "rubinröd",
    "rubinröds": "rubinröd",
    "rubinrött": "rubinröd",
    "rubinrötts": "rubinröd",
    "rubins": "rubin",
    "rubinsamlingar": "rubinsamling",
    "rubinsamlingarna": "rubinsamling",
    "rubinsamlingarnas": "rubinsamling",
    "rubinsamlingars": "rubinsamling",
    "rubinsamlingen": "rubinsamling",
    "rubinsamlingens": "rubinsamling",
    "rubinsamlings": "rubinsamling",
    "rubler": "rubel",
    "rublerna": "rubel",
    "rublernas": "rubel",
    "rublers": "rubel",
    "rubricerad": "rubricera",
    "rubricerade": "rubricera",
    "rubricerades": "rubricera",
    "rubricerads": "rubricera",
    "rubricerande": "rubricera",
    "rubriceranden": "rubricerande",
    "rubricerandena": "rubricerande",
    "rubricerandenas": "rubricerande",
    "rubricerandens": "rubricerande",
    "rubricerandes": "rubricerande",
    "rubricerandet": "rubricerande",
    "rubricerandets": "rubricerande",
    "rubricerar": "rubricera",
    "rubriceras": "rubricera",
    "rubricerat": "rubricera",
    "rubricerats": "rubricera",
    "rubricerbara": "rubricerbar",
    "rubricerbarare": "rubricerbar",
    "rubricerbarares": "rubricerbar",
    "rubricerbaras": "rubricerbar",
    "rubricerbarast": "rubricerbar",
    "rubricerbaraste": "rubricerbar",
    "rubricerbarastes": "rubricerbar",
    "rubricerbarasts": "rubricerbar",
    "rubricerbare": "rubricerbar",
    "rubricerbares": "rubricerbar",
    "rubricerbarheten": "rubricerbarhet",
    "rubricerbarhetens": "rubricerbarhet",
    "rubricerbarhets": "rubricerbarhet",
    "rubricerbars": "rubricerbar",
    "rubricerbart": "rubricerbar",
    "rubricerbarts": "rubricerbar",
    "rubriceringar": "rubricering",
    "rubriceringarna": "rubricering",
    "rubriceringarnas": "rubricering",
    "rubriceringars": "rubricering",
    "rubriceringen": "rubricering",
    "rubriceringens": "rubricering",
    "rubricerings": "rubricering",
    "rubriken": "rubrik",
    "rubrikens": "rubrik",
    "rubriker": "rubrik",
    "rubrikerna": "rubrik",
    "rubrikernas": "rubrik",
    "rubrikers": "rubrik",
    "rubrikmässiga": "rubrikmässig",
    "rubrikmässigare": "rubrikmässig",
    "rubrikmässigares": "rubrikmässig",
    "rubrikmässigas": "rubrikmässig",
    "rubrikmässigast": "rubrikmässig",
    "rubrikmässigaste": "rubrikmässig",
    "rubrikmässigastes": "rubrikmässig",
    "rubrikmässigasts": "rubrikmässig",
    "rubrikmässige": "rubrikmässig",
    "rubrikmässiges": "rubrikmässig",
    "rubrikmässigs": "rubrikmässig",
    "rubrikmässigt": "rubrikmässig",
    "rubrikmässigts": "rubrikmässig",
    "rubriks": "rubrik",
    "ruck": "rucka",
    "ruckad": "rucka",
    "ruckade": "rucka",
    "ruckades": "rucka",
    "ruckads": "rucka",
    "ruckande": "rucka",
    "ruckanden": "ruckande",
    "ruckandena": "ruckande",
    "ruckandenas": "ruckande",
    "ruckandens": "ruckande",
    "ruckandes": "ruckande",
    "ruckandet": "ruckande",
    "ruckandets": "ruckande",
    "ruckar": "rucka",
    "ruckas": "rucka",
    "ruckat": "rucka",
    "ruckats": "rucka",
    "ruckel": "ruckla",
    "ruckels": "ruckel",
    "rucklade": "ruckla",
    "rucklades": "ruckla",
    "rucklande": "ruckla",
    "rucklanden": "rucklande",
    "rucklandena": "rucklande",
    "rucklandenas": "rucklande",
    "rucklandens": "rucklande",
    "rucklandes": "rucklande",
    "rucklandet": "rucklande",
    "rucklandets": "rucklande",
    "rucklar": "rucklare",
    "rucklaren": "rucklare",
    "rucklarens": "rucklare",
    "rucklares": "rucklare",
    "rucklarna": "rucklare",
    "rucklarnas": "rucklare",
    "rucklas": "ruckla",
    "rucklat": "ruckla",
    "rucklats": "ruckla",
    "rucklen": "ruckel",
    "rucklens": "ruckel",
    "rucklet": "ruckel",
    "rucklets": "ruckel",
    "ruckliga": "rucklig",
    "ruckligare": "rucklig",
    "ruckligares": "rucklig",
    "ruckligas": "rucklig",
    "ruckligast": "rucklig",
    "ruckligaste": "rucklig",
    "ruckligastes": "rucklig",
    "ruckligasts": "rucklig",
    "rucklige": "rucklig",
    "ruckliges": "rucklig",
    "ruckligheten": "rucklighet",
    "rucklighetens": "rucklighet",
    "rucklighets": "rucklighet",
    "ruckligs": "rucklig",
    "ruckligt": "rucklig",
    "ruckligts": "rucklig",
    "rud": "ruda",
    "rudan": "ruda",
    "rudans": "ruda",
    "rudas": "ruda",
    "rude": "ruda",
    "ruderatväxten": "ruderatväxt",
    "ruderatväxtens": "ruderatväxt",
    "ruderatväxter": "ruderatväxt",
    "ruderatväxterna": "ruderatväxt",
    "ruderatväxternas": "ruderatväxt",
    "ruderatväxters": "ruderatväxt",
    "ruderatväxts": "ruderatväxt",
    "rudimenten": "rudiment",
    "rudimentens": "rudiment",
    "rudimentet": "rudiment",
    "rudimentets": "rudiment",
    "rudiments": "rudiment",
    "rudimentära": "rudimentär",
    "rudimentärare": "rudimentär",
    "rudimentärares": "rudimentär",
    "rudimentäras": "rudimentär",
    "rudimentärast": "rudimentär",
    "rudimentäraste": "rudimentär",
    "rudimentärastes": "rudimentär",
    "rudimentärasts": "rudimentär",
    "rudimentäre": "rudimentär",
    "rudimentäres": "rudimentär",
    "rudimentärs": "rudimentär",
    "rudimentärt": "rudimentär",
    "rudimentärts": "rudimentär",
    "rudor": "ruda",
    "rudorna": "ruda",
    "rudornas": "ruda",
    "rudors": "ruda",
    "ruds": "ruda",
    "ruelsen": "ruelse",
    "ruelsens": "ruelse",
    "ruelses": "ruelse",
    "ruffade": "ruffad",
    "ruffades": "ruffad",
    "ruffads": "ruffad",
    "ruffar": "ruff",
    "ruffarna": "ruff",
    "ruffarnas": "ruff",
    "ruffars": "ruff",
    "ruffat": "ruffad",
    "ruffats": "ruffad",
    "ruffel": "ruffla",
    "ruffels": "ruffel",
    "ruffen": "ruff",
    "ruffens": "ruff",
    "ruffet": "ruff",
    "ruffets": "ruff",
    "ruffhäx": "ruffhäxa",
    "ruffhäxan": "ruffhäxa",
    "ruffhäxans": "ruffhäxa",
    "ruffhäxas": "ruffhäxa",
    "ruffhäxe": "ruffhäxa",
    "ruffhäxor": "ruffhäxa",
    "ruffhäxorna": "ruffhäxa",
    "ruffhäxornas": "ruffhäxa",
    "ruffhäxors": "ruffhäxa",
    "ruffiga": "ruffig",
    "ruffigare": "ruffig",
    "ruffigares": "ruffig",
    "ruffigas": "ruffig",
    "ruffigast": "ruffig",
    "ruffigaste": "ruffig",
    "ruffigastes": "ruffig",
    "ruffigasts": "ruffig",
    "ruffige": "ruffig",
    "ruffiges": "ruffig",
    "ruffigheten": "ruffighet",
    "ruffighetens": "ruffighet",
    "ruffighets": "ruffighet",
    "ruffigs": "ruffig",
    "ruffigt": "ruffig",
    "ruffigts": "ruffig",
    "rufflade": "ruffla",
    "rufflades": "ruffla",
    "rufflande": "ruffla",
    "rufflanden": "rufflande",
    "rufflandena": "rufflande",
    "rufflandenas": "rufflande",
    "rufflandens": "rufflande",
    "rufflandes": "rufflande",
    "rufflandet": "rufflande",
    "rufflandets": "rufflande",
    "rufflar": "ruffla",
    "rufflas": "ruffla",
    "rufflat": "ruffla",
    "rufflats": "ruffla",
    "rufflet": "ruffel",
    "rufflets": "ruffel",
    "ruffs": "ruff",
    "rufftaken": "rufftak",
    "rufftakens": "rufftak",
    "rufftaket": "rufftak",
    "rufftakets": "rufftak",
    "rufftaks": "rufftak",
    "rufsade": "rufsa",
    "rufsades": "rufsa",
    "rufsande": "rufsa",
    "rufsanden": "rufsande",
    "rufsandena": "rufsande",
    "rufsandenas": "rufsande",
    "rufsandens": "rufsande",
    "rufsandes": "rufsande",
    "rufsandet": "rufsande",
    "rufsandets": "rufsande",
    "rufsar": "rufsa",
    "rufsas": "rufsa",
    "rufsat": "rufsa",
    "rufsats": "rufsa",
    "rufset": "rufs",
    "rufsets": "rufs",
    "rufsiga": "rufsig",
    "rufsigare": "rufsig",
    "rufsigares": "rufsig",
    "rufsigas": "rufsig",
    "rufsigast": "rufsig",
    "rufsigaste": "rufsig",
    "rufsigastes": "rufsig",
    "rufsigasts": "rufsig",
    "rufsige": "rufsig",
    "rufsiges": "rufsig",
    "rufsigheten": "rufsighet",
    "rufsighetens": "rufsighet",
    "rufsighets": "rufsighet",
    "rufsigs": "rufsig",
    "rufsigt": "rufsig",
    "rufsigts": "rufsig",
    "rugbyn": "rugby",
    "rugbyns": "rugby",
    "rugbys": "rugby",
    "rugg": "rugge",
    "ruggad": "rugga",
    "ruggade": "ruggad",
    "ruggades": "ruggad",
    "ruggads": "ruggad",
    "ruggande": "rugga",
    "rugganden": "ruggande",
    "ruggandena": "ruggande",
    "ruggandenas": "ruggande",
    "ruggandens": "ruggande",
    "ruggandes": "ruggande",
    "ruggandet": "ruggande",
    "ruggandets": "ruggande",
    "ruggar": "rugge",
    "ruggarna": "rugge",
    "ruggarnas": "rugge",
    "ruggars": "rugge",
    "ruggas": "rugga",
    "ruggat": "ruggad",
    "ruggats": "ruggad",
    "ruggen": "rugge",
    "ruggens": "rugge",
    "rugges": "rugge",
    "ruggiga": "ruggig",
    "ruggigare": "ruggig",
    "ruggigares": "ruggig",
    "ruggigas": "ruggig",
    "ruggigast": "ruggig",
    "ruggigaste": "ruggig",
    "ruggigastes": "ruggig",
    "ruggigasts": "ruggig",
    "ruggige": "ruggig",
    "ruggiges": "ruggig",
    "ruggigheten": "ruggighet",
    "ruggighetens": "ruggighet",
    "ruggighets": "ruggighet",
    "ruggigs": "ruggig",
    "ruggigt": "ruggig",
    "ruggigts": "ruggig",
    "ruggs": "rugge",
    "ruinen": "ruin",
    "ruinens": "ruin",
    "ruiner": "ruin",
    "ruinerad": "ruinera",
    "ruinerade": "ruinera",
    "ruinerades": "ruinera",
    "ruinerads": "ruinera",
    "ruinerande": "ruinera",
    "ruineranden": "ruinerande",
    "ruinerandena": "ruinerande",
    "ruinerandenas": "ruinerande",
    "ruinerandens": "ruinerande",
    "ruinerandes": "ruinerande",
    "ruinerandet": "ruinerande",
    "ruinerandets": "ruinerande",
    "ruinerar": "ruinera",
    "ruineras": "ruinera",
    "ruinerat": "ruinera",
    "ruinerats": "ruinera",
    "ruinerbara": "ruinerbar",
    "ruinerbarare": "ruinerbar",
    "ruinerbarares": "ruinerbar",
    "ruinerbaras": "ruinerbar",
    "ruinerbarast": "ruinerbar",
    "ruinerbaraste": "ruinerbar",
    "ruinerbarastes": "ruinerbar",
    "ruinerbarasts": "ruinerbar",
    "ruinerbare": "ruinerbar",
    "ruinerbares": "ruinerbar",
    "ruinerbarheten": "ruinerbarhet",
    "ruinerbarhetens": "ruinerbarhet",
    "ruinerbarhets": "ruinerbarhet",
    "ruinerbars": "ruinerbar",
    "ruinerbart": "ruinerbar",
    "ruinerbarts": "ruinerbar",
    "ruineringar": "ruinering",
    "ruineringarna": "ruinering",
    "ruineringarnas": "ruinering",
    "ruineringars": "ruinering",
    "ruineringen": "ruinering",
    "ruineringens": "ruinering",
    "ruinerings": "ruinering",
    "ruinerna": "ruin",
    "ruinernas": "ruin",
    "ruiners": "ruin",
    "ruinhögar": "ruinhög",
    "ruinhögarna": "ruinhög",
    "ruinhögarnas": "ruinhög",
    "ruinhögars": "ruinhög",
    "ruinhögen": "ruinhög",
    "ruinhögens": "ruinhög",
    "ruinhögs": "ruinhög",
    "ruins": "ruin",
    "ruinstaden": "ruinstad",
    "ruinstadens": "ruinstad",
    "ruinstads": "ruinstad",
    "ruinstan": "ruinstad",
    "ruinstans": "ruinstad",
    "ruinstäder": "ruinstad",
    "ruinstäderna": "ruinstad",
    "ruinstädernas": "ruinstad",
    "ruinstäders": "ruinstad",
    "rukit": "ryka",
    "ruladen": "rulad",
    "ruladens": "rulad",
    "rulader": "rulad",
    "ruladerna": "rulad",
    "ruladernas": "rulad",
    "ruladers": "rulad",
    "rulads": "rulad",
    "ruletten": "rulett",
    "rulettens": "rulett",
    "ruletter": "rulett",
    "ruletterna": "rulett",
    "ruletternas": "rulett",
    "ruletters": "rulett",
    "ruletts": "rulett",
    "ruljangsen": "ruljangs",
    "ruljangsens": "ruljangs",
    "rull": "rulle",
    "rullad": "rulla",
    "rullade": "rulla",
    "rulladen": "rullad",
    "rulladens": "rullad",
    "rullader": "rullad",
    "rulladerna": "rullad",
    "rulladernas": "rullad",
    "rulladers": "rullad",
    "rullades": "rulla",
    "rullads": "rullad",
    "rullagerna": "rullager",
    "rullagernas": "rullager",
    "rullagers": "rullager",
    "rullagren": "rullager",
    "rullagrens": "rullager",
    "rullagret": "rullager",
    "rullagrets": "rullager",
    "rullan": "rulla",
    "rullande": "rulla",
    "rullanden": "rullande",
    "rullandena": "rullande",
    "rullandenas": "rullande",
    "rullandens": "rullande",
    "rullandes": "rullande",
    "rullandet": "rullande",
    "rullandets": "rullande",
    "rullans": "rulla",
    "rullar": "rulle",
    "rullarna": "rulle",
    "rullarnas": "rulle",
    "rullars": "rulle",
    "rullas": "rulla",
    "rullat": "rulla",
    "rullatorer": "rullator",
    "rullatorerna": "rullator",
    "rullatorernas": "rullator",
    "rullatorers": "rullator",
    "rullatorn": "rullator",
    "rullatorns": "rullator",
    "rullators": "rullator",
    "rullats": "rulla",
    "rullbanden": "rullband",
    "rullbandens": "rullband",
    "rullbandet": "rullband",
    "rullbandets": "rullband",
    "rullbands": "rullband",
    "rullbara": "rullbar",
    "rullbarare": "rullbar",
    "rullbarares": "rullbar",
    "rullbaras": "rullbar",
    "rullbarast": "rullbar",
    "rullbaraste": "rullbar",
    "rullbarastes": "rullbar",
    "rullbarasts": "rullbar",
    "rullbare": "rullbar",
    "rullbares": "rullbar",
    "rullbarheten": "rullbarhet",
    "rullbarhetens": "rullbarhet",
    "rullbarhets": "rullbarhet",
    "rullbars": "rullbar",
    "rullbart": "rullbar",
    "rullbarts": "rullbar",
    "rullborden": "rullbord",
    "rullbordens": "rullbord",
    "rullbordet": "rullbord",
    "rullbordets": "rullbord",
    "rullbords": "rullbord",
    "rullbräd": "rullbräda",
    "rullbrädan": "rullbräda",
    "rullbrädans": "rullbräda",
    "rullbrädas": "rullbräda",
    "rullbräde": "rullbräda",
    "rullbräden": "rullbräde",
    "rullbrädena": "rullbräde",
    "rullbrädenas": "rullbräde",
    "rullbrädens": "rullbräde",
    "rullbrädes": "rullbräde",
    "rullbrädet": "rullbräde",
    "rullbrädets": "rullbräde",
    "rullbrädor": "rullbräda",
    "rullbrädorna": "rullbräda",
    "rullbrädornas": "rullbräda",
    "rullbrädors": "rullbräda",
    "rullbräds": "rullbräda",
    "rullbälten": "rullbälte",
    "rullbältena": "rullbälte",
    "rullbältenas": "rullbälte",
    "rullbältens": "rullbälte",
    "rullbältes": "rullbälte",
    "rullbältet": "rullbälte",
    "rullbältets": "rullbälte",
    "rulle": "rulla",
    "rullen": "rulle",
    "rullens": "rulle",
    "rulles": "rulle",
    "rullgardinen": "rullgardin",
    "rullgardinens": "rullgardin",
    "rullgardiner": "rullgardin",
    "rullgardinerna": "rullgardin",
    "rullgardinernas": "rullgardin",
    "rullgardiners": "rullgardin",
    "rullgardins": "rullgardin",
    "rullor": "rulla",
    "rullorna": "rulla",
    "rullornas": "rulla",
    "rullors": "rulla",
    "rullreven": "rullrev",
    "rullrevens": "rullrev",
    "rullrevet": "rullrev",
    "rullrevets": "rullrev",
    "rullrevs": "rullrev",
    "rulls": "rulle",
    "rullskid": "rullskida",
    "rullskidan": "rullskida",
    "rullskidans": "rullskida",
    "rullskidas": "rullskida",
    "rullskide": "rullskida",
    "rullskidor": "rullskida",
    "rullskidorna": "rullskida",
    "rullskidornas": "rullskida",
    "rullskidors": "rullskida",
    "rullskids": "rullskida",
    "rullskridskobanan": "rullskridskobana",
    "rullskridskobanans": "rullskridskobana",
    "rullskridskobanas": "rullskridskobana",
    "rullskridskobane": "rullskridskobana",
    "rullskridskobanor": "rullskridskobana",
    "rullskridskobanorna": "rullskridskobana",
    "rullskridskobanornas": "rullskridskobana",
    "rullskridskobanors": "rullskridskobana",
    "rullskridskon": "rullskridsko",
    "rullskridskons": "rullskridsko",
    "rullskridskor": "rullskridsko",
    "rullskridskorna": "rullskridsko",
    "rullskridskornas": "rullskridsko",
    "rullskridskors": "rullskridsko",
    "rullskridskos": "rullskridsko",
    "rullstenar": "rullsten",
    "rullstenarna": "rullsten",
    "rullstenarnas": "rullsten",
    "rullstenars": "rullsten",
    "rullstenen": "rullsten",
    "rullstenens": "rullsten",
    "rullstens": "rullsten",
    "rullstensåsar": "rullstensås",
    "rullstensåsarna": "rullstensås",
    "rullstensåsarnas": "rullstensås",
    "rullstensåsars": "rullstensås",
    "rullstensåsen": "rullstensås",
    "rullstensåsens": "rullstensås",
    "rullstolar": "rullstol",
    "rullstolarna": "rullstol",
    "rullstolarnas": "rullstol",
    "rullstolars": "rullstol",
    "rullstolen": "rullstol",
    "rullstolens": "rullstol",
    "rullstols": "rullstol",
    "rullstolsbundens": "rullstolsbunden",
    "rullstolsbundet": "rullstolsbunden",
    "rullstolsbundets": "rullstolsbunden",
    "rullstolsbundna": "rullstolsbunden",
    "rullstolsbundnare": "rullstolsbunden",
    "rullstolsbundnares": "rullstolsbunden",
    "rullstolsbundnas": "rullstolsbunden",
    "rullstolsbundnast": "rullstolsbunden",
    "rullstolsbundnaste": "rullstolsbunden",
    "rullstolsbundnastes": "rullstolsbunden",
    "rullstolsbundnasts": "rullstolsbunden",
    "rullstolsbundne": "rullstolsbunden",
    "rullstolsbundnes": "rullstolsbunden",
    "rulltrapp": "rulltrappa",
    "rulltrappan": "rulltrappa",
    "rulltrappans": "rulltrappa",
    "rulltrappas": "rulltrappa",
    "rulltrappe": "rulltrappa",
    "rulltrappor": "rulltrappa",
    "rulltrapporna": "rulltrappa",
    "rulltrappornas": "rulltrappa",
    "rulltrappors": "rulltrappa",
    "rulltrapps": "rulltrappa",
    "rulltrappsräcken": "rulltrappsräcke",
    "rulltrappsräckena": "rulltrappsräcke",
    "rulltrappsräckenas": "rulltrappsräcke",
    "rulltrappsräckens": "rulltrappsräcke",
    "rulltrappsräckes": "rulltrappsräcke",
    "rulltrappsräcket": "rulltrappsräcke",
    "rulltrappsräckets": "rulltrappsräcke",
    "rulltårt": "rulltårta",
    "rulltårtan": "rulltårta",
    "rulltårtans": "rulltårta",
    "rulltårtas": "rulltårta",
    "rulltårte": "rulltårta",
    "rulltårtor": "rulltårta",
    "rulltårtorna": "rulltårta",
    "rulltårtornas": "rulltårta",
    "rulltårtors": "rulltårta",
    "rulltårts": "rulltårta",
    "rullvagnar": "rullvagn",
    "rullvagnarna": "rullvagn",
    "rullvagnarnas": "rullvagn",
    "rullvagnars": "rullvagn",
    "rullvagnen": "rullvagn",
    "rullvagnens": "rullvagn",
    "rullvagns": "rullvagn",
    "rult": "rulta",
    "rultade": "rulta",
    "rultades": "rulta",
    "rultan": "rulta",
    "rultande": "rulta",
    "rultanden": "rultande",
    "rultandena": "rultande",
    "rultandenas": "rultande",
    "rultandens": "rultande",
    "rultandes": "rultande",
    "rultandet": "rultande",
    "rultandets": "rultande",
    "rultans": "rulta",
    "rultar": "rulta",
    "rultas": "rulta",
    "rultat": "rulta",
    "rultats": "rulta",
    "rulte": "rulta",
    "rultiga": "rultig",
    "rultigare": "rultig",
    "rultigares": "rultig",
    "rultigas": "rultig",
    "rultigast": "rultig",
    "rultigaste": "rultig",
    "rultigastes": "rultig",
    "rultigasts": "rultig",
    "rultige": "rultig",
    "rultiges": "rultig",
    "rultigheten": "rultighet",
    "rultighetens": "rultighet",
    "rultighets": "rultighet",
    "rultigs": "rultig",
    "rultigt": "rultig",
    "rultigts": "rultig",
    "rultor": "rulta",
    "rultorna": "rulta",
    "rultornas": "rulta",
    "rultors": "rulta",
    "rults": "rulta",
    "rumb": "rumba",
    "rumban": "rumba",
    "rumbans": "rumba",
    "rumbas": "rumba",
    "rumbe": "rumba",
    "rumbor": "rumba",
    "rumborna": "rumba",
    "rumbornas": "rumba",
    "rumbors": "rumba",
    "rumbs": "rumba",
    "rumheten": "rumhet",
    "rumhetens": "rumhet",
    "rumhets": "rumhet",
    "rumlade": "rumla",
    "rumlades": "rumla",
    "rumlande": "rumla",
    "rumlanden": "rumlande",
    "rumlandena": "rumlande",
    "rumlandenas": "rumlande",
    "rumlandens": "rumlande",
    "rumlandes": "rumlande",
    "rumlandet": "rumlande",
    "rumlandets": "rumlande",
    "rumlar": "rumla",
    "rumlas": "rumla",
    "rumlat": "rumla",
    "rumlats": "rumla",
    "rumma": "rum",
    "rummare": "rum",
    "rummares": "rum",
    "rummas": "rum",
    "rummast": "rum",
    "rummaste": "rum",
    "rummastes": "rum",
    "rummasts": "rum",
    "rumme": "rum",
    "rummel": "rumla",
    "rummen": "rum",
    "rummens": "rum",
    "rummes": "rum",
    "rummet": "rum",
    "rummets": "rum",
    "rump": "rumpa",
    "rumpan": "rumpa",
    "rumpans": "rumpa",
    "rumpas": "rumpa",
    "rumpe": "rumpa",
    "rumphugg": "rumphugga",
    "rumphuggande": "rumphugga",
    "rumphugganden": "rumphuggande",
    "rumphuggandena": "rumphuggande",
    "rumphuggandenas": "rumphuggande",
    "rumphuggandens": "rumphuggande",
    "rumphuggandes": "rumphuggande",
    "rumphuggandet": "rumphuggande",
    "rumphuggandets": "rumphuggande",
    "rumphuggas": "rumphugga",
    "rumphugge": "rumphugga",
    "rumphuggen": "rumphugga",
    "rumphuggens": "rumphugga",
    "rumphugger": "rumphugga",
    "rumphugges": "rumphugga",
    "rumphugget": "rumphugga",
    "rumphuggets": "rumphugga",
    "rumphuggit": "rumphugga",
    "rumphuggits": "rumphugga",
    "rumphuggna": "rumphugga",
    "rumphuggnas": "rumphugga",
    "rumphuggne": "rumphugga",
    "rumphuggnes": "rumphugga",
    "rumphuggs": "rumphugga",
    "rumphögg": "rumphugga",
    "rumphögge": "rumphugga",
    "rumphögges": "rumphugga",
    "rumphöggs": "rumphugga",
    "rumpnissar": "rumpnisse",
    "rumpnissarna": "rumpnisse",
    "rumpnissarnas": "rumpnisse",
    "rumpnissars": "rumpnisse",
    "rumpnissen": "rumpnisse",
    "rumpnissens": "rumpnisse",
    "rumpnisses": "rumpnisse",
    "rumpor": "rumpa",
    "rumporna": "rumpa",
    "rumpornas": "rumpa",
    "rumpors": "rumpa",
    "rumps": "rumpa",
    "rumpsniffar": "rumpsniffare",
    "rumpsniffaren": "rumpsniffare",
    "rumpsniffarens": "rumpsniffare",
    "rumpsniffares": "rumpsniffare",
    "rumpsniffarna": "rumpsniffare",
    "rumpsniffarnas": "rumpsniffare",
    "rumpstekar": "rumpstek",
    "rumpstekarna": "rumpstek",
    "rumpstekarnas": "rumpstek",
    "rumpstekars": "rumpstek",
    "rumpsteken": "rumpstek",
    "rumpstekens": "rumpstek",
    "rumpsteks": "rumpstek",
    "rumptrollen": "rumptroll",
    "rumptrollens": "rumptroll",
    "rumptrollet": "rumptroll",
    "rumptrollets": "rumptroll",
    "rumptrolls": "rumptroll",
    "rums": "rum",
    "rumsadverbialen": "rumsadverbial",
    "rumsadverbialens": "rumsadverbial",
    "rumsadverbialet": "rumsadverbial",
    "rumsadverbialets": "rumsadverbial",
    "rumsadverbials": "rumsadverbial",
    "rumsarresten": "rumsarrest",
    "rumsarrestens": "rumsarrest",
    "rumsarrests": "rumsarrest",
    "rumsbeställningar": "rumsbeställning",
    "rumsbeställningarna": "rumsbeställning",
    "rumsbeställningarnas": "rumsbeställning",
    "rumsbeställningars": "rumsbeställning",
    "rumsbeställningen": "rumsbeställning",
    "rumsbeställningens": "rumsbeställning",
    "rumsbeställnings": "rumsbeställning",
    "rumsbredden": "rumsbredd",
    "rumsbreddens": "rumsbredd",
    "rumsbredder": "rumsbredd",
    "rumsbredderna": "rumsbredd",
    "rumsbreddernas": "rumsbredd",
    "rumsbredders": "rumsbredd",
    "rumsbredds": "rumsbredd",
    "rumsförmedlingar": "rumsförmedling",
    "rumsförmedlingarna": "rumsförmedling",
    "rumsförmedlingarnas": "rumsförmedling",
    "rumsförmedlingars": "rumsförmedling",
    "rumsförmedlingen": "rumsförmedling",
    "rumsförmedlingens": "rumsförmedling",
    "rumsförmedlings": "rumsförmedling",
    "rumsgrann": "rumsgranne",
    "rumsgrannar": "rumsgranne",
    "rumsgrannarna": "rumsgranne",
    "rumsgrannarnas": "rumsgranne",
    "rumsgrannars": "rumsgranne",
    "rumsgrannen": "rumsgranne",
    "rumsgrannens": "rumsgranne",
    "rumsgrannes": "rumsgranne",
    "rumsgranns": "rumsgranne",
    "rumskamraten": "rumskamrat",
    "rumskamratens": "rumskamrat",
    "rumskamrater": "rumskamrat",
    "rumskamraterna": "rumskamrat",
    "rumskamraternas": "rumskamrat",
    "rumskamraters": "rumskamrat",
    "rumskamrats": "rumskamrat",
    "rumskrökningar": "rumskrökning",
    "rumskrökningarna": "rumskrökning",
    "rumskrökningarnas": "rumskrökning",
    "rumskrökningars": "rumskrökning",
    "rumskrökningen": "rumskrökning",
    "rumskrökningens": "rumskrökning",
    "rumskröknings": "rumskrökning",
    "rumslasten": "rumslast",
    "rumslastens": "rumslast",
    "rumslaster": "rumslast",
    "rumslasterna": "rumslast",
    "rumslasternas": "rumslast",
    "rumslasters": "rumslast",
    "rumslasts": "rumslast",
    "rumsliga": "rumslig",
    "rumsligare": "rumslig",
    "rumsligares": "rumslig",
    "rumsligas": "rumslig",
    "rumsligast": "rumslig",
    "rumsligaste": "rumslig",
    "rumsligastes": "rumslig",
    "rumsligasts": "rumslig",
    "rumslige": "rumslig",
    "rumsliges": "rumslig",
    "rumsligheten": "rumslighet",
    "rumslighetens": "rumslighet",
    "rumsligheter": "rumslighet",
    "rumsligheterna": "rumslighet",
    "rumsligheternas": "rumslighet",
    "rumsligheters": "rumslighet",
    "rumslighets": "rumslighet",
    "rumsligs": "rumslig",
    "rumsligt": "rumslig",
    "rumsligts": "rumslig",
    "rumsnummerna": "rumsnummer",
    "rumsnummernas": "rumsnummer",
    "rumsnummers": "rumsnummer",
    "rumsnumren": "rumsnummer",
    "rumsnumrens": "rumsnummer",
    "rumsnumret": "rumsnummer",
    "rumsnumrets": "rumsnummer",
    "rumsrena": "rumsren",
    "rumsrenare": "rumsren",
    "rumsrenares": "rumsren",
    "rumsrenas": "rumsren",
    "rumsrenast": "rumsren",
    "rumsrenaste": "rumsren",
    "rumsrenastes": "rumsren",
    "rumsrenasts": "rumsren",
    "rumsrene": "rumsren",
    "rumsrenes": "rumsren",
    "rumsrens": "rumsren",
    "rumsrent": "rumsren",
    "rumsrents": "rumsren",
    "rumstemperaturen": "rumstemperatur",
    "rumstemperaturens": "rumstemperatur",
    "rumstemperaturer": "rumstemperatur",
    "rumstemperaturerna": "rumstemperatur",
    "rumstemperaturernas": "rumstemperatur",
    "rumstemperaturers": "rumstemperatur",
    "rumstemperaturs": "rumstemperatur",
    "rumsterade": "rumstera",
    "rumsterades": "rumstera",
    "rumsterande": "rumstera",
    "rumsteranden": "rumsterande",
    "rumsterandena": "rumsterande",
    "rumsterandenas": "rumsterande",
    "rumsterandens": "rumsterande",
    "rumsterandes": "rumsterande",
    "rumsterandet": "rumsterande",
    "rumsterandets": "rumsterande",
    "rumsterar": "rumstera",
    "rumsteras": "rumstera",
    "rumsterat": "rumstera",
    "rumsterats": "rumstera",
    "rumsteringar": "rumstering",
    "rumsteringarna": "rumstering",
    "rumsteringarnas": "rumstering",
    "rumsteringars": "rumstering",
    "rumsteringen": "rumstering",
    "rumsteringens": "rumstering",
    "rumsterings": "rumstering",
    "rumstiden": "rumstid",
    "rumstidens": "rumstid",
    "rumstids": "rumstid",
    "rumt": "rum",
    "rumtiden": "rumtid",
    "rumtidens": "rumtid",
    "rumtids": "rumtid",
    "rumts": "rum",
    "rumänen": "rumän",
    "rumänens": "rumän",
    "rumäner": "rumän",
    "rumänerna": "rumän",
    "rumänernas": "rumän",
    "rumäners": "rumän",
    "rumäns": "rumän",
    "rumänsk": "rumänska",
    "rumänsk-franska": "rumänsk-fransk",
    "rumänsk-franskare": "rumänsk-fransk",
    "rumänsk-franskares": "rumänsk-fransk",
    "rumänsk-franskas": "rumänsk-fransk",
    "rumänsk-franskast": "rumänsk-fransk",
    "rumänsk-franskaste": "rumänsk-fransk",
    "rumänsk-franskastes": "rumänsk-fransk",
    "rumänsk-franskasts": "rumänsk-fransk",
    "rumänsk-franske": "rumänsk-fransk",
    "rumänsk-franskes": "rumänsk-fransk",
    "rumänsk-fransks": "rumänsk-fransk",
    "rumänsk-franskt": "rumänsk-fransk",
    "rumänsk-franskts": "rumänsk-fransk",
    "rumänska": "rumänsk",
    "rumänskan": "rumänska",
    "rumänskans": "rumänska",
    "rumänskare": "rumänsk",
    "rumänskares": "rumänsk",
    "rumänskas": "rumänska",
    "rumänskast": "rumänsk",
    "rumänskaste": "rumänsk",
    "rumänskastes": "rumänsk",
    "rumänskasts": "rumänsk",
    "rumänske": "rumänska",
    "rumänskes": "rumänsk",
    "rumänskor": "rumänska",
    "rumänskorna": "rumänska",
    "rumänskornas": "rumänska",
    "rumänskors": "rumänska",
    "rumänsks": "rumänsk",
    "rumänskt": "rumänsk",
    "rumänskts": "rumänsk",
    "run": "runa",
    "runan": "runa",
    "runans": "runa",
    "runas": "runa",
    "rund": "runda",
    "runda": "rund",
    "rundabordskonferensen": "rundabordskonferens",
    "rundabordskonferensens": "rundabordskonferens",
    "rundabordskonferenser": "rundabordskonferens",
    "rundabordskonferenserna": "rundabordskonferens",
    "rundabordskonferensernas": "rundabordskonferens",
    "rundabordskonferensers": "rundabordskonferens",
    "rundabordssamtalen": "rundabordssamtal",
    "rundabordssamtalens": "rundabordssamtal",
    "rundabordssamtalet": "rundabordssamtal",
    "rundabordssamtalets": "rundabordssamtal",
    "rundabordssamtals": "rundabordssamtal",
    "rundad": "runda",
    "rundade": "rundad",
    "rundades": "rundad",
    "rundads": "rundad",
    "rundan": "runda",
    "rundande": "runda",
    "rundanden": "rundande",
    "rundandena": "rundande",
    "rundandenas": "rundande",
    "rundandens": "rundande",
    "rundandes": "rundande",
    "rundandet": "rundande",
    "rundandets": "rundande",
    "rundans": "runda",
    "rundar": "runda",
    "rundare": "rund",
    "rundares": "rund",
    "rundas": "runda",
    "rundast": "rund",
    "rundaste": "rund",
    "rundastes": "rund",
    "rundasts": "rund",
    "rundat": "rundad",
    "rundats": "rundad",
    "rundbottnade": "rundbottnad",
    "rundbottnades": "rundbottnad",
    "rundbottnads": "rundbottnad",
    "rundbottnat": "rundbottnad",
    "rundbottnats": "rundbottnad",
    "rundbreven": "rundbrev",
    "rundbrevens": "rundbrev",
    "rundbrevet": "rundbrev",
    "rundbrevets": "rundbrev",
    "rundbrevs": "rundbrev",
    "rundbåg": "rundbåge",
    "rundbågar": "rundbåge",
    "rundbågarna": "rundbåge",
    "rundbågarnas": "rundbåge",
    "rundbågars": "rundbåge",
    "rundbågen": "rundbåge",
    "rundbågens": "rundbåge",
    "rundbåges": "rundbåge",
    "rundbågs": "rundbåge",
    "runde": "runda",
    "rundeln": "rundel",
    "rundelns": "rundel",
    "rundels": "rundel",
    "rundes": "rund",
    "rundfilar": "rundfil",
    "rundfilarna": "rundfil",
    "rundfilarnas": "rundfil",
    "rundfilars": "rundfil",
    "rundfilen": "rundfil",
    "rundfilens": "rundfil",
    "rundfils": "rundfil",
    "rundflygningar": "rundflygning",
    "rundflygningarna": "rundflygning",
    "rundflygningarnas": "rundflygning",
    "rundflygningars": "rundflygning",
    "rundflygningen": "rundflygning",
    "rundflygningens": "rundflygning",
    "rundflygnings": "rundflygning",
    "rundfrågan": "rundfråga",
    "rundfrågans": "rundfråga",
    "rundfrågas": "rundfråga",
    "rundfråge": "rundfråga",
    "rundfrågor": "rundfråga",
    "rundfrågorna": "rundfråga",
    "rundfrågornas": "rundfråga",
    "rundfrågors": "rundfråga",
    "rundfönsterna": "rundfönster",
    "rundfönsternas": "rundfönster",
    "rundfönsters": "rundfönster",
    "rundfönstren": "rundfönster",
    "rundfönstrens": "rundfönster",
    "rundfönstret": "rundfönster",
    "rundfönstrets": "rundfönster",
    "rundgången": "rundgång",
    "rundgångens": "rundgång",
    "rundgångs": "rundgång",
    "rundheten": "rundhet",
    "rundhetens": "rundhet",
    "rundheter": "rundhet",
    "rundheterna": "rundhet",
    "rundheternas": "rundhet",
    "rundheters": "rundhet",
    "rundhets": "rundhet",
    "rundhorisonten": "rundhorisont",
    "rundhorisontens": "rundhorisont",
    "rundhorisonter": "rundhorisont",
    "rundhorisonterna": "rundhorisont",
    "rundhorisonternas": "rundhorisont",
    "rundhorisonters": "rundhorisont",
    "rundhorisonts": "rundhorisont",
    "rundhultar": "rundhult",
    "rundhultarna": "rundhult",
    "rundhultarnas": "rundhult",
    "rundhultars": "rundhult",
    "rundhulten": "rundhult",
    "rundhultens": "rundhult",
    "rundhulter": "rundhult",
    "rundhulterna": "rundhult",
    "rundhulternas": "rundhult",
    "rundhulters": "rundhult",
    "rundhultet": "rundhult",
    "rundhultets": "rundhult",
    "rundhults": "rundhult",
    "rundhyllta": "rundhyllt",
    "rundhylltare": "rundhyllt",
    "rundhylltares": "rundhyllt",
    "rundhylltas": "rundhyllt",
    "rundhylltast": "rundhyllt",
    "rundhylltaste": "rundhyllt",
    "rundhylltastes": "rundhyllt",
    "rundhylltasts": "rundhyllt",
    "rundhyllte": "rundhyllt",
    "rundhylltes": "rundhyllt",
    "rundhylltheten": "rundhyllthet",
    "rundhyllthetens": "rundhyllthet",
    "rundhyllthets": "rundhyllthet",
    "rundhyllts": "rundhyllt",
    "rundhällar": "rundhäll",
    "rundhällarna": "rundhäll",
    "rundhällarnas": "rundhäll",
    "rundhällars": "rundhäll",
    "rundhällen": "rundhäll",
    "rundhällens": "rundhäll",
    "rundhälls": "rundhäll",
    "rundhänta": "rundhänt",
    "rundhäntare": "rundhänt",
    "rundhäntares": "rundhänt",
    "rundhäntas": "rundhänt",
    "rundhäntast": "rundhänt",
    "rundhäntaste": "rundhänt",
    "rundhäntastes": "rundhänt",
    "rundhäntasts": "rundhänt",
    "rundhänte": "rundhänt",
    "rundhäntes": "rundhänt",
    "rundhäntheten": "rundhänthet",
    "rundhänthetens": "rundhänthet",
    "rundhänthets": "rundhänthet",
    "rundhänts": "rundhänt",
    "rundjärnen": "rundjärn",
    "rundjärnens": "rundjärn",
    "rundjärnet": "rundjärn",
    "rundjärnets": "rundjärn",
    "rundjärns": "rundjärn",
    "rundkul": "rundkula",
    "rundkulan": "rundkula",
    "rundkulans": "rundkula",
    "rundkulas": "rundkula",
    "rundkule": "rundkula",
    "rundkulliga": "rundkullig",
    "rundkulligare": "rundkullig",
    "rundkulligares": "rundkullig",
    "rundkulligas": "rundkullig",
    "rundkulligast": "rundkullig",
    "rundkulligaste": "rundkullig",
    "rundkulligastes": "rundkullig",
    "rundkulligasts": "rundkullig",
    "rundkullige": "rundkullig",
    "rundkulliges": "rundkullig",
    "rundkulligheten": "rundkullighet",
    "rundkullighetens": "rundkullighet",
    "rundkullighets": "rundkullighet",
    "rundkulligs": "rundkullig",
    "rundkulligt": "rundkullig",
    "rundkulligts": "rundkullig",
    "rundkulor": "rundkula",
    "rundkulorna": "rundkula",
    "rundkulornas": "rundkula",
    "rundkulors": "rundkula",
    "rundkuls": "rundkula",
    "rundkyrk": "rundkyrka",
    "rundkyrkan": "rundkyrka",
    "rundkyrkans": "rundkyrka",
    "rundkyrkas": "rundkyrka",
    "rundkyrke": "rundkyrka",
    "rundkyrko": "rundkyrka",
    "rundkyrkor": "rundkyrka",
    "rundkyrkorna": "rundkyrka",
    "rundkyrkornas": "rundkyrka",
    "rundkyrkors": "rundkyrka",
    "rundkyrks": "rundkyrka",
    "rundlagda": "rundlagd",
    "rundlagdare": "rundlagd",
    "rundlagdares": "rundlagd",
    "rundlagdas": "rundlagd",
    "rundlagdast": "rundlagd",
    "rundlagdaste": "rundlagd",
    "rundlagdastes": "rundlagd",
    "rundlagdasts": "rundlagd",
    "rundlagde": "rundlagd",
    "rundlagdes": "rundlagd",
    "rundlagdheten": "rundlagdhet",
    "rundlagdhetens": "rundlagdhet",
    "rundlagdhets": "rundlagdhet",
    "rundlagds": "rundlagd",
    "rundlagt": "rundlagd",
    "rundlagts": "rundlagd",
    "rundlar": "rundel",
    "rundlarna": "rundel",
    "rundlarnas": "rundel",
    "rundlars": "rundel",
    "rundliga": "rundlig",
    "rundligare": "rundlig",
    "rundligares": "rundlig",
    "rundligas": "rundlig",
    "rundligast": "rundlig",
    "rundligaste": "rundlig",
    "rundligastes": "rundlig",
    "rundligasts": "rundlig",
    "rundlige": "rundlig",
    "rundliges": "rundlig",
    "rundligheten": "rundlighet",
    "rundlighetens": "rundlighet",
    "rundlighets": "rundlighet",
    "rundligs": "rundlig",
    "rundligt": "rundlig",
    "rundligts": "rundlig",
    "rundmaskar": "rundmask",
    "rundmaskarna": "rundmask",
    "rundmaskarnas": "rundmask",
    "rundmaskars": "rundmask",
    "rundmasken": "rundmask",
    "rundmaskens": "rundmask",
    "rundmasks": "rundmask",
    "rundmunnar": "rundmun",
    "rundmunnarna": "rundmun",
    "rundmunnarnas": "rundmun",
    "rundmunnars": "rundmun",
    "rundmunnen": "rundmun",
    "rundmunnens": "rundmun",
    "rundmuns": "rundmun",
    "rundmålningar": "rundmålning",
    "rundmålningarna": "rundmålning",
    "rundmålningarnas": "rundmålning",
    "rundmålningars": "rundmålning",
    "rundmålningen": "rundmålning",
    "rundmålningens": "rundmålning",
    "rundmålnings": "rundmålning",
    "rundningar": "rundning",
    "rundningarna": "rundning",
    "rundningarnas": "rundning",
    "rundningars": "rundning",
    "rundningen": "rundning",
    "rundningens": "rundning",
    "rundnings": "rundning",
    "rundningsmärken": "rundningsmärke",
    "rundningsmärkena": "rundningsmärke",
    "rundningsmärkenas": "rundningsmärke",
    "rundningsmärkens": "rundningsmärke",
    "rundningsmärkes": "rundningsmärke",
    "rundningsmärket": "rundningsmärke",
    "rundningsmärkets": "rundningsmärke",
    "rundnätta": "rundnätt",
    "rundnättare": "rundnätt",
    "rundnättares": "rundnätt",
    "rundnättas": "rundnätt",
    "rundnättast": "rundnätt",
    "rundnättaste": "rundnätt",
    "rundnättastes": "rundnätt",
    "rundnättasts": "rundnätt",
    "rundnätte": "rundnätt",
    "rundnättes": "rundnätt",
    "rundnättheten": "rundnätthet",
    "rundnätthetens": "rundnätthet",
    "rundnätthets": "rundnätthet",
    "rundnätts": "rundnätt",
    "rundor": "runda",
    "rundorna": "runda",
    "rundornas": "runda",
    "rundors": "runda",
    "rundradion": "rundradio",
    "rundradions": "rundradio",
    "rundradios": "rundradio",
    "rundresan": "rundresa",
    "rundresans": "rundresa",
    "rundresas": "rundresa",
    "rundrese": "rundresa",
    "rundresor": "rundresa",
    "rundresorna": "rundresa",
    "rundresornas": "rundresa",
    "rundresors": "rundresa",
    "runds": "runda",
    "rundskrivelsen": "rundskrivelse",
    "rundskrivelsens": "rundskrivelse",
    "rundskrivelser": "rundskrivelse",
    "rundskrivelserna": "rundskrivelse",
    "rundskrivelsernas": "rundskrivelse",
    "rundskrivelsers": "rundskrivelse",
    "rundskrivelses": "rundskrivelse",
    "rundslipade": "rundslipad",
    "rundslipades": "rundslipad",
    "rundslipads": "rundslipad",
    "rundslipat": "rundslipad",
    "rundslipats": "rundslipad",
    "rundsmord": "rundsmörja",
    "rundsmorda": "rundsmörja",
    "rundsmordas": "rundsmörja",
    "rundsmorde": "rundsmörja",
    "rundsmordes": "rundsmörja",
    "rundsmords": "rundsmörja",
    "rundsmort": "rundsmörja",
    "rundsmorts": "rundsmörja",
    "rundsmörj": "rundsmörja",
    "rundsmörjande": "rundsmörja",
    "rundsmörjanden": "rundsmörjande",
    "rundsmörjandena": "rundsmörjande",
    "rundsmörjandenas": "rundsmörjande",
    "rundsmörjandens": "rundsmörjande",
    "rundsmörjandes": "rundsmörjande",
    "rundsmörjandet": "rundsmörjande",
    "rundsmörjandets": "rundsmörjande",
    "rundsmörjas": "rundsmörja",
    "rundsmörjer": "rundsmörja",
    "rundsmörjes": "rundsmörja",
    "rundsmörjningar": "rundsmörjning",
    "rundsmörjningarna": "rundsmörjning",
    "rundsmörjningarnas": "rundsmörjning",
    "rundsmörjningars": "rundsmörjning",
    "rundsmörjningen": "rundsmörjning",
    "rundsmörjningens": "rundsmörjning",
    "rundsmörjnings": "rundsmörjning",
    "rundsmörjs": "rundsmörja",
    "rundsnacket": "rundsnack",
    "rundsnackets": "rundsnack",
    "rundsnacks": "rundsnack",
    "rundstick": "rundsticka",
    "rundstickad": "rundsticka",
    "rundstickade": "rundstickad",
    "rundstickades": "rundstickad",
    "rundstickads": "rundstickad",
    "rundstickan": "rundsticka",
    "rundstickande": "rundsticka",
    "rundstickanden": "rundstickande",
    "rundstickandena": "rundstickande",
    "rundstickandenas": "rundstickande",
    "rundstickandens": "rundstickande",
    "rundstickandes": "rundstickande",
    "rundstickandet": "rundstickande",
    "rundstickandets": "rundstickande",
    "rundstickans": "rundsticka",
    "rundstickar": "rundsticka",
    "rundstickas": "rundsticka",
    "rundstickat": "rundstickad",
    "rundstickats": "rundstickad",
    "rundsticke": "rundsticka",
    "rundstickor": "rundsticka",
    "rundstickorna": "rundsticka",
    "rundstickornas": "rundsticka",
    "rundstickors": "rundsticka",
    "rundsticks": "rundsticka",
    "rundstycken": "rundstycke",
    "rundstyckena": "rundstycke",
    "rundstyckenas": "rundstycke",
    "rundstyckens": "rundstycke",
    "rundstyckes": "rundstycke",
    "rundstycket": "rundstycke",
    "rundstyckets": "rundstycke",
    "rundstycks": "rundstycke",
    "rundturen": "rundtur",
    "rundturens": "rundtur",
    "rundturer": "rundtur",
    "rundturerna": "rundtur",
    "rundturernas": "rundtur",
    "rundturers": "rundtur",
    "rundturs": "rundtur",
    "rundtörnar": "rundtörn",
    "rundtörnarna": "rundtörn",
    "rundtörnarnas": "rundtörn",
    "rundtörnars": "rundtörn",
    "rundtörnen": "rundtörn",
    "rundtörnens": "rundtörn",
    "rundtörns": "rundtörn",
    "rundvandringar": "rundvandring",
    "rundvandringarna": "rundvandring",
    "rundvandringarnas": "rundvandring",
    "rundvandringars": "rundvandring",
    "rundvandringen": "rundvandring",
    "rundvandringens": "rundvandring",
    "rundvandrings": "rundvandring",
    "rundvirkes": "rundvirke",
    "rundvirket": "rundvirke",
    "rundvirkets": "rundvirke",
    "rune": "runa",
    "rung": "runga",
    "rungade": "runga",
    "rungades": "runga",
    "rungande": "runga",
    "runganden": "rungande",
    "rungandena": "rungande",
    "rungandenas": "rungande",
    "rungandens": "rungande",
    "rungandes": "rungande",
    "rungandet": "rungande",
    "rungandets": "rungande",
    "rungar": "runga",
    "rungas": "runga",
    "rungat": "runga",
    "rungats": "runga",
    "runk": "runka",
    "runkad": "runka",
    "runkade": "runka",
    "runkades": "runka",
    "runkads": "runka",
    "runkande": "runka",
    "runkanden": "runkande",
    "runkandena": "runkande",
    "runkandenas": "runkande",
    "runkandens": "runkande",
    "runkandes": "runkande",
    "runkandet": "runkande",
    "runkandets": "runkande",
    "runkar": "runka",
    "runkas": "runka",
    "runkat": "runka",
    "runkats": "runka",
    "runken": "runk",
    "runkens": "runk",
    "runket": "runk",
    "runkets": "runk",
    "runks": "runk",
    "runna": "rinna",
    "runnar": "runnare",
    "runnaren": "runnare",
    "runnarens": "runnare",
    "runnares": "runnare",
    "runnarna": "runnare",
    "runnarnas": "runnare",
    "runnas": "rinna",
    "runne": "rinna",
    "runnen": "rinna",
    "runnens": "rinna",
    "runnes": "rinna",
    "runnet": "rinna",
    "runnets": "rinna",
    "runnit": "rinna",
    "runnits": "rinna",
    "runologen": "runolog",
    "runologens": "runolog",
    "runologer": "runolog",
    "runologerna": "runolog",
    "runologernas": "runolog",
    "runologers": "runolog",
    "runologien": "runologi",
    "runologiens": "runologi",
    "runologin": "runologi",
    "runologins": "runologi",
    "runologis": "runologi",
    "runologs": "runolog",
    "runometern": "runometer",
    "runometerns": "runometer",
    "runometers": "runometer",
    "runometrar": "runometer",
    "runometrarna": "runometer",
    "runometrarnas": "runometer",
    "runometrars": "runometer",
    "runor": "runa",
    "runorna": "runa",
    "runornas": "runa",
    "runors": "runa",
    "runosången": "runosång",
    "runosångens": "runosång",
    "runosånger": "runosång",
    "runosångerna": "runosång",
    "runosångernas": "runosång",
    "runosångers": "runosång",
    "runosångs": "runosång",
    "runraden": "runrad",
    "runradens": "runrad",
    "runrader": "runrad",
    "runraderna": "runrad",
    "runradernas": "runrad",
    "runraders": "runrad",
    "runrads": "runrad",
    "runs": "runa",
    "runskriften": "runskrift",
    "runskriftens": "runskrift",
    "runskrifter": "runskrift",
    "runskrifterna": "runskrift",
    "runskrifternas": "runskrift",
    "runskrifters": "runskrift",
    "runskrifts": "runskrift",
    "runstavar": "runstav",
    "runstavarna": "runstav",
    "runstavarnas": "runstav",
    "runstavars": "runstav",
    "runstaven": "runstav",
    "runstavens": "runstav",
    "runstavs": "runstav",
    "runstenar": "runsten",
    "runstenarna": "runsten",
    "runstenarnas": "runsten",
    "runstenars": "runsten",
    "runstenen": "runsten",
    "runstenens": "runsten",
    "runstens": "runsten",
    "runstycken": "runstycke",
    "runstyckena": "runstycke",
    "runstyckenas": "runstycke",
    "runstyckens": "runstycke",
    "runstyckes": "runstycke",
    "runstycket": "runstycke",
    "runstyckets": "runstycke",
    "runstycks": "runstycke",
    "runt": "rund",
    "runts": "rund",
    "rupien": "rupie",
    "rupiens": "rupie",
    "rupier": "rupie",
    "rupierna": "rupie",
    "rupiernas": "rupie",
    "rupiers": "rupie",
    "rupies": "rupie",
    "ruppade": "ruppad",
    "ruppades": "ruppad",
    "ruppads": "ruppad",
    "ruppat": "ruppad",
    "ruppats": "ruppad",
    "rupturen": "ruptur",
    "rupturens": "ruptur",
    "rupturer": "ruptur",
    "rupturerna": "ruptur",
    "rupturernas": "ruptur",
    "rupturers": "ruptur",
    "rupturs": "ruptur",
    "rurala": "rural",
    "ruralare": "rural",
    "ruralares": "rural",
    "ruralas": "rural",
    "ruralast": "rural",
    "ruralaste": "rural",
    "ruralastes": "rural",
    "ruralasts": "rural",
    "rurale": "rural",
    "rurales": "rural",
    "rurals": "rural",
    "ruralt": "rural",
    "ruralts": "rural",
    "rus": "rusa",
    "rusad": "rusa",
    "rusade": "rusa",
    "rusades": "rusa",
    "rusads": "rusa",
    "rusande": "rusa",
    "rusanden": "rusande",
    "rusandena": "rusande",
    "rusandenas": "rusande",
    "rusandens": "rusande",
    "rusandes": "rusande",
    "rusandet": "rusande",
    "rusandets": "rusande",
    "rusar": "rusa",
    "rusas": "rusa",
    "rusat": "rusa",
    "rusats": "rusa",
    "ruschelbanan": "ruschelbana",
    "ruschelbanans": "ruschelbana",
    "ruschelbanas": "ruschelbana",
    "ruschelbane": "ruschelbana",
    "ruschelbanor": "ruschelbana",
    "ruschelbanorna": "ruschelbana",
    "ruschelbanornas": "ruschelbana",
    "ruschelbanors": "ruschelbana",
    "ruschelkanan": "ruschelkana",
    "ruschelkanans": "ruschelkana",
    "ruschelkanas": "ruschelkana",
    "ruschelkane": "ruschelkana",
    "ruschelkanor": "ruschelkana",
    "ruschelkanorna": "ruschelkana",
    "ruschelkanornas": "ruschelkana",
    "ruschelkanors": "ruschelkana",
    "ruschen": "rusch",
    "ruschens": "rusch",
    "ruscher": "rusch",
    "ruscherna": "rusch",
    "ruschernas": "rusch",
    "ruschers": "rusch",
    "ruschiga": "ruschig",
    "ruschigare": "ruschig",
    "ruschigares": "ruschig",
    "ruschigas": "ruschig",
    "ruschigast": "ruschig",
    "ruschigaste": "ruschig",
    "ruschigastes": "ruschig",
    "ruschigasts": "ruschig",
    "ruschige": "ruschig",
    "ruschiges": "ruschig",
    "ruschigheten": "ruschighet",
    "ruschighetens": "ruschighet",
    "ruschighets": "ruschighet",
    "ruschigs": "ruschig",
    "ruschigt": "ruschig",
    "ruschigts": "ruschig",
    "ruschs": "rusch",
    "rusdrycken": "rusdryck",
    "rusdryckens": "rusdryck",
    "rusdrycker": "rusdryck",
    "rusdryckerna": "rusdryck",
    "rusdryckernas": "rusdryck",
    "rusdryckers": "rusdryck",
    "rusdrycks": "rusdryck",
    "rusen": "rus",
    "rusens": "rus",
    "ruset": "rus",
    "rusets": "rus",
    "rushen": "rush",
    "rushens": "rush",
    "rusher": "rush",
    "rusherna": "rush",
    "rushernas": "rush",
    "rushers": "rush",
    "rushs": "rush",
    "rusiga": "rusig",
    "rusigare": "rusig",
    "rusigares": "rusig",
    "rusigas": "rusig",
    "rusigast": "rusig",
    "rusigaste": "rusig",
    "rusigastes": "rusig",
    "rusigasts": "rusig",
    "rusige": "rusig",
    "rusiges": "rusig",
    "rusigs": "rusig",
    "rusigt": "rusig",
    "rusigts": "rusig",
    "rusk": "ruska",
    "ruskad": "ruska",
    "ruskade": "ruska",
    "ruskades": "ruska",
    "ruskads": "ruska",
    "ruskan": "ruska",
    "ruskande": "ruska",
    "ruskanden": "ruskande",
    "ruskandena": "ruskande",
    "ruskandenas": "ruskande",
    "ruskandens": "ruskande",
    "ruskandes": "ruskande",
    "ruskandet": "ruskande",
    "ruskandets": "ruskande",
    "ruskans": "ruska",
    "ruskar": "ruska",
    "ruskas": "ruska",
    "ruskat": "ruska",
    "ruskats": "ruska",
    "ruske": "ruska",
    "rusket": "rusk",
    "ruskets": "rusk",
    "ruskiga": "ruskig",
    "ruskigare": "ruskig",
    "ruskigares": "ruskig",
    "ruskigas": "ruskig",
    "ruskigast": "ruskig",
    "ruskigaste": "ruskig",
    "ruskigastes": "ruskig",
    "ruskigasts": "ruskig",
    "ruskige": "ruskig",
    "ruskiges": "ruskig",
    "ruskigheten": "ruskighet",
    "ruskighetens": "ruskighet",
    "ruskigheter": "ruskighet",
    "ruskigheterna": "ruskighet",
    "ruskigheternas": "ruskighet",
    "ruskigheters": "ruskighet",
    "ruskighets": "ruskighet",
    "ruskigs": "ruskig",
    "ruskigt": "ruskig",
    "ruskigts": "ruskig",
    "ruskor": "ruska",
    "ruskorna": "ruska",
    "ruskornas": "ruska",
    "ruskors": "ruska",
    "ruskprickar": "ruskprick",
    "ruskprickarna": "ruskprick",
    "ruskprickarnas": "ruskprick",
    "ruskprickars": "ruskprick",
    "ruskpricken": "ruskprick",
    "ruskprickens": "ruskprick",
    "ruskpricks": "ruskprick",
    "rusks": "rusk",
    "rusningar": "rusning",
    "rusningarna": "rusning",
    "rusningarnas": "rusning",
    "rusningars": "rusning",
    "rusningen": "rusning",
    "rusningens": "rusning",
    "rusnings": "rusning",
    "rusningstiden": "rusningstid",
    "rusningstidens": "rusningstid",
    "rusningstider": "rusningstid",
    "rusningstiderna": "rusningstid",
    "rusningstidernas": "rusningstid",
    "rusningstiders": "rusningstid",
    "rusningstids": "rusningstid",
    "rusningstrafiken": "rusningstrafik",
    "rusningstrafikens": "rusningstrafik",
    "rusningstrafiks": "rusningstrafik",
    "russen": "russ",
    "russens": "russ",
    "russet": "russ",
    "russets": "russ",
    "russificerad": "russificera",
    "russificerade": "russificera",
    "russificerades": "russificera",
    "russificerads": "russificera",
    "russificerande": "russificera",
    "russificeranden": "russificerande",
    "russificerandena": "russificerande",
    "russificerandenas": "russificerande",
    "russificerandens": "russificerande",
    "russificerandes": "russificerande",
    "russificerandet": "russificerande",
    "russificerandets": "russificerande",
    "russificerar": "russificera",
    "russificeras": "russificera",
    "russificerat": "russificera",
    "russificerats": "russificera",
    "russificerbara": "russificerbar",
    "russificerbarare": "russificerbar",
    "russificerbarares": "russificerbar",
    "russificerbaras": "russificerbar",
    "russificerbarast": "russificerbar",
    "russificerbaraste": "russificerbar",
    "russificerbarastes": "russificerbar",
    "russificerbarasts": "russificerbar",
    "russificerbare": "russificerbar",
    "russificerbares": "russificerbar",
    "russificerbarheten": "russificerbarhet",
    "russificerbarhetens": "russificerbarhet",
    "russificerbarhets": "russificerbarhet",
    "russificerbars": "russificerbar",
    "russificerbart": "russificerbar",
    "russificerbarts": "russificerbar",
    "russificeringar": "russificering",
    "russificeringarna": "russificering",
    "russificeringarnas": "russificering",
    "russificeringars": "russificering",
    "russificeringen": "russificering",
    "russificeringens": "russificering",
    "russificerings": "russificering",
    "russifierad": "russifiera",
    "russifierade": "russifiera",
    "russifierades": "russifiera",
    "russifierads": "russifiera",
    "russifierande": "russifiera",
    "russifieranden": "russifierande",
    "russifierandena": "russifierande",
    "russifierandenas": "russifierande",
    "russifierandens": "russifierande",
    "russifierandes": "russifierande",
    "russifierandet": "russifierande",
    "russifierandets": "russifierande",
    "russifierar": "russifiera",
    "russifieras": "russifiera",
    "russifierat": "russifiera",
    "russifierats": "russifiera",
    "russifierbara": "russifierbar",
    "russifierbarare": "russifierbar",
    "russifierbarares": "russifierbar",
    "russifierbaras": "russifierbar",
    "russifierbarast": "russifierbar",
    "russifierbaraste": "russifierbar",
    "russifierbarastes": "russifierbar",
    "russifierbarasts": "russifierbar",
    "russifierbare": "russifierbar",
    "russifierbares": "russifierbar",
    "russifierbarheten": "russifierbarhet",
    "russifierbarhetens": "russifierbarhet",
    "russifierbarhets": "russifierbarhet",
    "russifierbars": "russifierbar",
    "russifierbart": "russifierbar",
    "russifierbarts": "russifierbar",
    "russifieringar": "russifiering",
    "russifieringarna": "russifiering",
    "russifieringarnas": "russifiering",
    "russifieringars": "russifiering",
    "russifieringen": "russifiering",
    "russifieringens": "russifiering",
    "russifierings": "russifiering",
    "russinen": "russin",
    "russinens": "russin",
    "russinet": "russin",
    "russinets": "russin",
    "russins": "russin",
    "rust": "rusta",
    "rustad": "rusta",
    "rustade": "rustad",
    "rustades": "rustad",
    "rustads": "rustad",
    "rustande": "rusta",
    "rustanden": "rustande",
    "rustandena": "rustande",
    "rustandenas": "rustande",
    "rustandens": "rustande",
    "rustandes": "rustande",
    "rustandet": "rustande",
    "rustandets": "rustande",
    "rustar": "rusta",
    "rustas": "rusta",
    "rustat": "rustad",
    "rustats": "rustad",
    "rusthållar": "rusthållare",
    "rusthållaren": "rusthållare",
    "rusthållarens": "rusthållare",
    "rusthållares": "rusthållare",
    "rusthållarna": "rusthållare",
    "rusthållarnas": "rusthållare",
    "rusthållen": "rusthåll",
    "rusthållens": "rusthåll",
    "rusthållet": "rusthåll",
    "rusthållets": "rusthåll",
    "rusthålls": "rusthåll",
    "rustibussar": "rustibuss",
    "rustibussarna": "rustibuss",
    "rustibussarnas": "rustibuss",
    "rustibussars": "rustibuss",
    "rustibussen": "rustibuss",
    "rustibussens": "rustibuss",
    "rustika": "rustik",
    "rustikare": "rustik",
    "rustikares": "rustik",
    "rustikas": "rustik",
    "rustikast": "rustik",
    "rustikaste": "rustik",
    "rustikastes": "rustik",
    "rustikasts": "rustik",
    "rustike": "rustik",
    "rustikes": "rustik",
    "rustiks": "rustik",
    "rustikt": "rustik",
    "rustikts": "rustik",
    "rustkammar": "rustkammare",
    "rustkammaren": "rustkammare",
    "rustkammarens": "rustkammare",
    "rustkammares": "rustkammare",
    "rustkamrar": "rustkammare",
    "rustkamrarna": "rustkammare",
    "rustkamrarnas": "rustkammare",
    "rustkamrars": "rustkammare",
    "rustmästar": "rustmästare",
    "rustmästaren": "rustmästare",
    "rustmästarens": "rustmästare",
    "rustmästares": "rustmästare",
    "rustmästarna": "rustmästare",
    "rustmästarnas": "rustmästare",
    "rustningar": "rustning",
    "rustningarna": "rustning",
    "rustningarnas": "rustning",
    "rustningars": "rustning",
    "rustningen": "rustning",
    "rustningens": "rustning",
    "rustnings": "rustning",
    "rusttjänsten": "rusttjänst",
    "rusttjänstens": "rusttjänst",
    "rusttjänsts": "rusttjänst",
    "rut": "ruta",
    "rutade": "rutad",
    "rutades": "rutad",
    "rutads": "rutad",
    "rutan": "ruta",
    "rutanden": "rutande",
    "rutandena": "rutande",
    "rutandenas": "rutande",
    "rutandens": "rutande",
    "rutandes": "rutande",
    "rutandet": "rutande",
    "rutandets": "rutande",
    "rutans": "ruta",
    "rutas": "ruta",
    "rutat": "rutad",
    "rutats": "rutad",
    "rutavdragen": "rutavdrag",
    "rutavdragens": "rutavdrag",
    "rutavdraget": "rutavdrag",
    "rutavdragets": "rutavdrag",
    "rutavdrags": "rutavdrag",
    "rutchbanan": "rutchbana",
    "rutchbanans": "rutchbana",
    "rutchbanas": "rutchbana",
    "rutchbane": "rutchbana",
    "rutchbanor": "rutchbana",
    "rutchbanorna": "rutchbana",
    "rutchbanornas": "rutchbana",
    "rutchbanors": "rutchbana",
    "rutchelbanan": "rutchelbana",
    "rutchelbanans": "rutchelbana",
    "rutchelbanas": "rutchelbana",
    "rutchelbane": "rutchelbana",
    "rutchelbanor": "rutchelbana",
    "rutchelbanorna": "rutchelbana",
    "rutchelbanornas": "rutchelbana",
    "rutchelbanors": "rutchelbana",
    "rutchelkanan": "rutchelkana",
    "rutchelkanans": "rutchelkana",
    "rutchelkanas": "rutchelkana",
    "rutchelkane": "rutchelkana",
    "rutchelkanor": "rutchelkana",
    "rutchelkanorna": "rutchelkana",
    "rutchelkanornas": "rutchelkana",
    "rutchelkanors": "rutchelkana",
    "rutchkanan": "rutchkana",
    "rutchkanans": "rutchkana",
    "rutchkanas": "rutchkana",
    "rutchkane": "rutchkana",
    "rutchkanor": "rutchkana",
    "rutchkanorna": "rutchkana",
    "rutchkanornas": "rutchkana",
    "rutchkanors": "rutchkana",
    "rute": "ryta",
    "rutenen": "ruten",
    "rutenens": "ruten",
    "rutener": "ruten",
    "rutenerna": "ruten",
    "rutenernas": "ruten",
    "ruteners": "ruten",
    "ruteniet": "rutenium",
    "ruteniets": "rutenium",
    "ruteniumet": "rutenium",
    "ruteniumets": "rutenium",
    "ruteniums": "rutenium",
    "rutens": "ruten",
    "rutern": "ruter",
    "ruterna": "ruter",
    "ruternas": "ruter",
    "ruterns": "ruter",
    "ruters": "ruter",
    "rutes": "ryta",
    "rutiga": "rutig",
    "rutigare": "rutig",
    "rutigares": "rutig",
    "rutigas": "rutig",
    "rutigast": "rutig",
    "rutigaste": "rutig",
    "rutigastes": "rutig",
    "rutigasts": "rutig",
    "rutige": "rutig",
    "rutiges": "rutig",
    "rutigs": "rutig",
    "rutigt": "rutig",
    "rutigts": "rutig",
    "rutinen": "rutin",
    "rutinens": "rutin",
    "rutiner": "rutin",
    "rutinerade": "rutinerad",
    "rutinerades": "rutinerad",
    "rutinerads": "rutinerad",
    "rutinerat": "rutinerad",
    "rutinerats": "rutinerad",
    "rutinerna": "rutin",
    "rutinernas": "rutin",
    "rutiners": "rutin",
    "rutinmässiga": "rutinmässig",
    "rutinmässigare": "rutinmässig",
    "rutinmässigares": "rutinmässig",
    "rutinmässigas": "rutinmässig",
    "rutinmässigast": "rutinmässig",
    "rutinmässigaste": "rutinmässig",
    "rutinmässigastes": "rutinmässig",
    "rutinmässigasts": "rutinmässig",
    "rutinmässige": "rutinmässig",
    "rutinmässiges": "rutinmässig",
    "rutinmässigs": "rutinmässig",
    "rutinmässigt": "rutinmässig",
    "rutinmässigts": "rutinmässig",
    "rutinoperationen": "rutinoperation",
    "rutinoperationens": "rutinoperation",
    "rutinoperationer": "rutinoperation",
    "rutinoperationerna": "rutinoperation",
    "rutinoperationernas": "rutinoperation",
    "rutinoperationers": "rutinoperation",
    "rutinoperations": "rutinoperation",
    "rutins": "rutin",
    "rutinärenden": "rutinärende",
    "rutinärendena": "rutinärende",
    "rutinärendenas": "rutinärende",
    "rutinärendens": "rutinärende",
    "rutinärendes": "rutinärende",
    "rutinärendet": "rutinärende",
    "rutinärendets": "rutinärende",
    "rutit": "ryta",
    "rutits": "ryta",
    "rutmönsterna": "rutmönster",
    "rutmönsternas": "rutmönster",
    "rutmönsters": "rutmönster",
    "rutmönstren": "rutmönster",
    "rutmönstrens": "rutmönster",
    "rutmönstret": "rutmönster",
    "rutmönstrets": "rutmönster",
    "rutnäten": "rutnät",
    "rutnätens": "rutnät",
    "rutnätet": "rutnät",
    "rutnätets": "rutnät",
    "rutnäts": "rutnät",
    "rutor": "ruta",
    "rutorna": "ruta",
    "rutornas": "ruta",
    "rutors": "ruta",
    "ruts": "ruta",
    "rutsch": "rutscha",
    "rutschade": "rutscha",
    "rutschades": "rutscha",
    "rutschande": "rutscha",
    "rutschanden": "rutschande",
    "rutschandena": "rutschande",
    "rutschandenas": "rutschande",
    "rutschandens": "rutschande",
    "rutschandes": "rutschande",
    "rutschandet": "rutschande",
    "rutschandets": "rutschande",
    "rutschar": "rutscha",
    "rutscharna": "rutsch",
    "rutscharnas": "rutsch",
    "rutschars": "rutsch",
    "rutschas": "rutscha",
    "rutschat": "rutscha",
    "rutschats": "rutscha",
    "rutschbanan": "rutschbana",
    "rutschbanans": "rutschbana",
    "rutschbanas": "rutschbana",
    "rutschbane": "rutschbana",
    "rutschbanor": "rutschbana",
    "rutschbanorna": "rutschbana",
    "rutschbanornas": "rutschbana",
    "rutschbanors": "rutschbana",
    "rutschelbanan": "rutschelbana",
    "rutschelbanans": "rutschelbana",
    "rutschelbanas": "rutschelbana",
    "rutschelbane": "rutschelbana",
    "rutschelbanor": "rutschelbana",
    "rutschelbanorna": "rutschelbana",
    "rutschelbanornas": "rutschelbana",
    "rutschelbanors": "rutschelbana",
    "rutschelkanan": "rutschelkana",
    "rutschelkanans": "rutschelkana",
    "rutschelkanas": "rutschelkana",
    "rutschelkane": "rutschelkana",
    "rutschelkanor": "rutschelkana",
    "rutschelkanorna": "rutschelkana",
    "rutschelkanornas": "rutschelkana",
    "rutschelkanors": "rutschelkana",
    "rutschen": "rutsch",
    "rutschens": "rutsch",
    "rutschkanan": "rutschkana",
    "rutschkanans": "rutschkana",
    "rutschkanas": "rutschkana",
    "rutschkane": "rutschkana",
    "rutschkanor": "rutschkana",
    "rutschkanorna": "rutschkana",
    "rutschkanornas": "rutschkana",
    "rutschkanors": "rutschkana",
    "rutschs": "rutsch",
    "rutten": "rutt",
    "ruttens": "rutten",
    "rutter": "rutt",
    "rutterna": "rutt",
    "rutternas": "rutt",
    "rutters": "rutt",
    "ruttet": "rutten",
    "ruttets": "rutten",
    "ruttna": "rutten",
    "ruttnade": "ruttna",
    "ruttnades": "ruttna",
    "ruttnande": "ruttna",
    "ruttnanden": "ruttnande",
    "ruttnandena": "ruttnande",
    "ruttnandenas": "ruttnande",
    "ruttnandens": "ruttnande",
    "ruttnandes": "ruttnande",
    "ruttnandet": "ruttnande",
    "ruttnandets": "ruttnande",
    "ruttnar": "ruttna",
    "ruttnare": "rutten",
    "ruttnares": "rutten",
    "ruttnas": "ruttna",
    "ruttnast": "rutten",
    "ruttnaste": "rutten",
    "ruttnastes": "rutten",
    "ruttnasts": "rutten",
    "ruttnat": "ruttna",
    "ruttnats": "ruttna",
    "ruttne": "rutten",
    "ruttnes": "rutten",
    "rutts": "rutt",
    "ruv": "ruva",
    "ruvad": "ruva",
    "ruvade": "ruva",
    "ruvades": "ruva",
    "ruvads": "ruva",
    "ruvande": "ruva",
    "ruvanden": "ruvande",
    "ruvandena": "ruvande",
    "ruvandenas": "ruvande",
    "ruvandens": "ruvande",
    "ruvandes": "ruvande",
    "ruvandet": "ruvande",
    "ruvandets": "ruvande",
    "ruvar": "ruva",
    "ruvas": "ruva",
    "ruvat": "ruva",
    "ruvats": "ruva",
    "ruvlåd": "ruvlåda",
    "ruvlådan": "ruvlåda",
    "ruvlådans": "ruvlåda",
    "ruvlådas": "ruvlåda",
    "ruvlåde": "ruvlåda",
    "ruvlådor": "ruvlåda",
    "ruvlådorna": "ruvlåda",
    "ruvlådornas": "ruvlåda",
    "ruvlådors": "ruvlåda",
    "ruvlåds": "ruvlåda",
    "rwandiern": "rwandier",
    "rwandierna": "rwandier",
    "rwandiernas": "rwandier",
    "rwandierns": "rwandier",
    "rwandiers": "rwandier",
    "rwandiska": "rwandisk",
    "rwandiskan": "rwandiska",
    "rwandiskans": "rwandiska",
    "rwandiskare": "rwandisk",
    "rwandiskares": "rwandisk",
    "rwandiskas": "rwandiska",
    "rwandiskast": "rwandisk",
    "rwandiskaste": "rwandisk",
    "rwandiskastes": "rwandisk",
    "rwandiskasts": "rwandisk",
    "rwandiske": "rwandiska",
    "rwandiskes": "rwandisk",
    "rwandiskor": "rwandiska",
    "rwandiskorna": "rwandiska",
    "rwandiskornas": "rwandiska",
    "rwandiskors": "rwandiska",
    "rwandisks": "rwandisk",
    "rwandiskt": "rwandisk",
    "rwandiskts": "rwandisk",
    "ry": "rya",
    "ryade": "rya",
    "ryades": "rya",
    "ryan": "rya",
    "ryande": "rya",
    "ryanden": "ryande",
    "ryandena": "ryande",
    "ryandenas": "ryande",
    "ryandens": "ryande",
    "ryandes": "ryande",
    "ryandet": "ryande",
    "ryandets": "ryande",
    "ryans": "rya",
    "ryar": "rya",
    "ryas": "rya",
    "ryat": "rya",
    "ryats": "rya",
    "rybsen": "rybs",
    "rybsens": "rybs",
    "ryck": "rycka",
    "ryckande": "rycka",
    "ryckanden": "ryckande",
    "ryckandena": "ryckande",
    "ryckandenas": "ryckande",
    "ryckandens": "ryckande",
    "ryckandes": "ryckande",
    "ryckandet": "ryckande",
    "ryckandets": "ryckande",
    "ryckas": "rycka",
    "rycken": "ryck",
    "ryckens": "ryck",
    "rycker": "rycka",
    "ryckes": "rycka",
    "rycket": "ryck",
    "ryckets": "ryck",
    "ryckiga": "ryckig",
    "ryckigare": "ryckig",
    "ryckigares": "ryckig",
    "ryckigas": "ryckig",
    "ryckigast": "ryckig",
    "ryckigaste": "ryckig",
    "ryckigastes": "ryckig",
    "ryckigasts": "ryckig",
    "ryckige": "ryckig",
    "ryckiges": "ryckig",
    "ryckigheten": "ryckighet",
    "ryckighetens": "ryckighet",
    "ryckighets": "ryckighet",
    "ryckigs": "ryckig",
    "ryckigt": "ryckig",
    "ryckigts": "ryckig",
    "ryckningar": "ryckning",
    "ryckningarna": "ryckning",
    "ryckningarnas": "ryckning",
    "ryckningars": "ryckning",
    "ryckningen": "ryckning",
    "ryckningens": "ryckning",
    "rycknings": "ryckning",
    "rycks": "rycka",
    "ryckt": "rycka",
    "ryckte": "rycka",
    "rycktes": "rycka",
    "ryckts": "rycka",
    "rye": "rya",
    "ryggade": "rygga",
    "ryggades": "rygga",
    "ryggan": "rygga",
    "ryggande": "rygga",
    "rygganden": "ryggande",
    "ryggandena": "ryggande",
    "ryggandenas": "ryggande",
    "ryggandens": "ryggande",
    "ryggandes": "ryggande",
    "ryggandet": "ryggande",
    "ryggandets": "ryggande",
    "ryggans": "rygga",
    "ryggar": "rygga",
    "ryggarna": "rygg",
    "ryggarnas": "rygg",
    "ryggars": "rygg",
    "ryggas": "rygga",
    "ryggat": "rygga",
    "ryggats": "rygga",
    "ryggbesvären": "ryggbesvär",
    "ryggbesvärens": "ryggbesvär",
    "ryggbesväret": "ryggbesvär",
    "ryggbesvärets": "ryggbesvär",
    "ryggbesvärs": "ryggbesvär",
    "ryggbiffar": "ryggbiff",
    "ryggbiffarna": "ryggbiff",
    "ryggbiffarnas": "ryggbiff",
    "ryggbiffars": "ryggbiff",
    "ryggbiffen": "ryggbiff",
    "ryggbiffens": "ryggbiff",
    "ryggbiffs": "ryggbiff",
    "ryggen": "rygg",
    "ryggens": "rygg",
    "ryggfen": "ryggfena",
    "ryggfenan": "ryggfena",
    "ryggfenans": "ryggfena",
    "ryggfenas": "ryggfena",
    "ryggfene": "ryggfena",
    "ryggfenor": "ryggfena",
    "ryggfenorna": "ryggfena",
    "ryggfenornas": "ryggfena",
    "ryggfenors": "ryggfena",
    "ryggfens": "ryggfena",
    "ryggkot": "ryggkota",
    "ryggkotan": "ryggkota",
    "ryggkotans": "ryggkota",
    "ryggkotas": "ryggkota",
    "ryggkote": "ryggkota",
    "ryggkotor": "ryggkota",
    "ryggkotorna": "ryggkota",
    "ryggkotornas": "ryggkota",
    "ryggkotors": "ryggkota",
    "ryggkots": "ryggkota",
    "rygglägen": "ryggläge",
    "rygglägena": "ryggläge",
    "rygglägenas": "ryggläge",
    "rygglägens": "ryggläge",
    "ryggläges": "ryggläge",
    "ryggläget": "ryggläge",
    "rygglägets": "ryggläge",
    "ryggmuskeln": "ryggmuskel",
    "ryggmuskelns": "ryggmuskel",
    "ryggmuskels": "ryggmuskel",
    "ryggmuskler": "ryggmuskel",
    "ryggmusklerna": "ryggmuskel",
    "ryggmusklernas": "ryggmuskel",
    "ryggmusklers": "ryggmuskel",
    "ryggmärgen": "ryggmärg",
    "ryggmärgens": "ryggmärg",
    "ryggmärgs": "ryggmärg",
    "ryggmärgsbedövningar": "ryggmärgsbedövning",
    "ryggmärgsbedövningarna": "ryggmärgsbedövning",
    "ryggmärgsbedövningarnas": "ryggmärgsbedövning",
    "ryggmärgsbedövningars": "ryggmärgsbedövning",
    "ryggmärgsbedövningen": "ryggmärgsbedövning",
    "ryggmärgsbedövningens": "ryggmärgsbedövning",
    "ryggmärgsbedövnings": "ryggmärgsbedövning",
    "ryggmärgsmässiga": "ryggmärgsmässig",
    "ryggmärgsmässigare": "ryggmärgsmässig",
    "ryggmärgsmässigares": "ryggmärgsmässig",
    "ryggmärgsmässigas": "ryggmärgsmässig",
    "ryggmärgsmässigast": "ryggmärgsmässig",
    "ryggmärgsmässigaste": "ryggmärgsmässig",
    "ryggmärgsmässigastes": "ryggmärgsmässig",
    "ryggmärgsmässigasts": "ryggmärgsmässig",
    "ryggmärgsmässige": "ryggmärgsmässig",
    "ryggmärgsmässiges": "ryggmärgsmässig",
    "ryggmärgsmässigs": "ryggmärgsmässig",
    "ryggmärgsmässigt": "ryggmärgsmässig",
    "ryggmärgsmässigts": "ryggmärgsmässig",
    "ryggmärgsproven": "ryggmärgsprov",
    "ryggmärgsprovens": "ryggmärgsprov",
    "ryggmärgsprovet": "ryggmärgsprov",
    "ryggmärgsprovets": "ryggmärgsprov",
    "ryggmärgsprovs": "ryggmärgsprov",
    "ryggoperationen": "ryggoperation",
    "ryggoperationens": "ryggoperation",
    "ryggoperationer": "ryggoperation",
    "ryggoperationerna": "ryggoperation",
    "ryggoperationernas": "ryggoperation",
    "ryggoperationers": "ryggoperation",
    "ryggoperations": "ryggoperation",
    "ryggor": "rygga",
    "ryggorna": "rygga",
    "ryggornamenten": "ryggornament",
    "ryggornamentens": "ryggornament",
    "ryggornamentet": "ryggornament",
    "ryggornamentets": "ryggornament",
    "ryggornaments": "ryggornament",
    "ryggornas": "rygga",
    "ryggors": "rygga",
    "ryggpartier": "ryggparti",
    "ryggpartierna": "ryggparti",
    "ryggpartiernas": "ryggparti",
    "ryggpartiers": "ryggparti",
    "ryggpartiet": "ryggparti",
    "ryggpartiets": "ryggparti",
    "ryggpartis": "ryggparti",
    "ryggpartit": "ryggparti",
    "ryggpartits": "ryggparti",
    "ryggraden": "ryggrad",
    "ryggradens": "ryggrad",
    "ryggrader": "ryggrad",
    "ryggraderna": "ryggrad",
    "ryggradernas": "ryggrad",
    "ryggraders": "ryggrad",
    "ryggrads": "ryggrad",
    "ryggradsdjuren": "ryggradsdjur",
    "ryggradsdjurens": "ryggradsdjur",
    "ryggradsdjuret": "ryggradsdjur",
    "ryggradsdjurets": "ryggradsdjur",
    "ryggradsdjurs": "ryggradsdjur",
    "ryggradslösa": "ryggradslös",
    "ryggradslösare": "ryggradslös",
    "ryggradslösares": "ryggradslös",
    "ryggradslösas": "ryggradslös",
    "ryggradslösast": "ryggradslös",
    "ryggradslösaste": "ryggradslös",
    "ryggradslösastes": "ryggradslös",
    "ryggradslösasts": "ryggradslös",
    "ryggradslöse": "ryggradslös",
    "ryggradslöses": "ryggradslös",
    "ryggradslösheten": "ryggradslöshet",
    "ryggradslöshetens": "ryggradslöshet",
    "ryggradslöshets": "ryggradslöshet",
    "ryggradslöst": "ryggradslös",
    "ryggradslösts": "ryggradslös",
    "ryggs": "rygg",
    "ryggsimmet": "ryggsim",
    "ryggsimmets": "ryggsim",
    "ryggsims": "ryggsim",
    "ryggskotten": "ryggskott",
    "ryggskottens": "ryggskott",
    "ryggskottet": "ryggskott",
    "ryggskottets": "ryggskott",
    "ryggskotts": "ryggskott",
    "ryggsluten": "ryggslut",
    "ryggslutens": "ryggslut",
    "ryggslutet": "ryggslut",
    "ryggslutets": "ryggslut",
    "ryggsluts": "ryggslut",
    "ryggstöden": "ryggstöd",
    "ryggstödens": "ryggstöd",
    "ryggstödet": "ryggstöd",
    "ryggstödets": "ryggstöd",
    "ryggstöds": "ryggstöd",
    "ryggsäckar": "ryggsäck",
    "ryggsäckarna": "ryggsäck",
    "ryggsäckarnas": "ryggsäck",
    "ryggsäckars": "ryggsäck",
    "ryggsäcken": "ryggsäck",
    "ryggsäckens": "ryggsäck",
    "ryggsäcks": "ryggsäck",
    "ryggsäcksluff": "ryggsäcksluffa",
    "ryggsäcksluffade": "ryggsäcksluffa",
    "ryggsäcksluffades": "ryggsäcksluffa",
    "ryggsäcksluffande": "ryggsäcksluffa",
    "ryggsäcksluffanden": "ryggsäcksluffande",
    "ryggsäcksluffandena": "ryggsäcksluffande",
    "ryggsäcksluffandenas": "ryggsäcksluffande",
    "ryggsäcksluffandens": "ryggsäcksluffande",
    "ryggsäcksluffandes": "ryggsäcksluffande",
    "ryggsäcksluffandet": "ryggsäcksluffande",
    "ryggsäcksluffandets": "ryggsäcksluffande",
    "ryggsäcksluffar": "ryggsäcksluffa",
    "ryggsäcksluffas": "ryggsäcksluffa",
    "ryggsäcksluffat": "ryggsäcksluffa",
    "ryggsäcksluffats": "ryggsäcksluffa",
    "ryggsäcksturismen": "ryggsäcksturism",
    "ryggsäcksturismens": "ryggsäcksturism",
    "ryggsäcksturisms": "ryggsäcksturism",
    "ryggsäcksturisten": "ryggsäcksturist",
    "ryggsäcksturistens": "ryggsäcksturist",
    "ryggsäcksturister": "ryggsäcksturist",
    "ryggsäcksturisterna": "ryggsäcksturist",
    "ryggsäcksturisternas": "ryggsäcksturist",
    "ryggsäcksturisters": "ryggsäcksturist",
    "ryggsäcksturists": "ryggsäcksturist",
    "ryggtavel": "ryggtavla",
    "ryggtavlan": "ryggtavla",
    "ryggtavlans": "ryggtavla",
    "ryggtavlas": "ryggtavla",
    "ryggtavle": "ryggtavla",
    "ryggtavlor": "ryggtavla",
    "ryggtavlorna": "ryggtavla",
    "ryggtavlornas": "ryggtavla",
    "ryggtavlors": "ryggtavla",
    "ryggtrakten": "ryggtrakt",
    "ryggtraktens": "ryggtrakt",
    "ryggtrakter": "ryggtrakt",
    "ryggtrakterna": "ryggtrakt",
    "ryggtrakternas": "ryggtrakt",
    "ryggtrakters": "ryggtrakt",
    "ryggtrakts": "ryggtrakt",
    "ryggåsstugan": "ryggåsstuga",
    "ryggåsstugans": "ryggåsstuga",
    "ryggåsstugas": "ryggåsstuga",
    "ryggåsstuge": "ryggåsstuga",
    "ryggåsstugor": "ryggåsstuga",
    "ryggåsstugorna": "ryggåsstuga",
    "ryggåsstugornas": "ryggåsstuga",
    "ryggåsstugors": "ryggåsstuga",
    "ryggåsstugu": "ryggåsstuga",
    "ryk": "ryka",
    "rykande": "ryka",
    "rykanden": "rykande",
    "rykandena": "rykande",
    "rykandenas": "rykande",
    "rykandens": "rykande",
    "rykandes": "rykande",
    "rykandet": "rykande",
    "rykandets": "rykande",
    "ryke": "ryka",
    "ryker": "ryka",
    "rykt": "rykta",
    "ryktad": "rykta",
    "ryktade": "rykta",
    "ryktades": "ryktas",
    "ryktads": "rykta",
    "ryktande": "rykta",
    "ryktanden": "ryktande",
    "ryktandena": "ryktande",
    "ryktandenas": "ryktande",
    "ryktandens": "ryktande",
    "ryktandes": "ryktande",
    "ryktandet": "ryktande",
    "ryktandets": "ryktande",
    "ryktar": "rykta",
    "ryktas": "rykta",
    "ryktat": "rykta",
    "ryktats": "ryktas",
    "ryktbara": "ryktbar",
    "ryktbarare": "ryktbar",
    "ryktbarares": "ryktbar",
    "ryktbaras": "ryktbar",
    "ryktbarast": "ryktbar",
    "ryktbaraste": "ryktbar",
    "ryktbarastes": "ryktbar",
    "ryktbarasts": "ryktbar",
    "ryktbare": "ryktbar",
    "ryktbares": "ryktbar",
    "ryktbarheten": "ryktbarhet",
    "ryktbarhetens": "ryktbarhet",
    "ryktbarheter": "ryktbarhet",
    "ryktbarheterna": "ryktbarhet",
    "ryktbarheternas": "ryktbarhet",
    "ryktbarheters": "ryktbarhet",
    "ryktbarhets": "ryktbarhet",
    "ryktbars": "ryktbar",
    "ryktbart": "ryktbar",
    "ryktbarts": "ryktbar",
    "ryktborst": "ryktborste",
    "ryktborstar": "ryktborste",
    "ryktborstarna": "ryktborste",
    "ryktborstarnas": "ryktborste",
    "ryktborstars": "ryktborste",
    "ryktborsten": "ryktborste",
    "ryktborstens": "ryktborste",
    "ryktborstes": "ryktborste",
    "rykte": "ryka",
    "rykten": "rykte",
    "ryktena": "rykte",
    "ryktenas": "rykte",
    "ryktens": "rykte",
    "ryktes": "rykte",
    "rykteskarusellen": "rykteskarusell",
    "rykteskarusellens": "rykteskarusell",
    "rykteskarusells": "rykteskarusell",
    "ryktessmidar": "ryktessmidare",
    "ryktessmidaren": "ryktessmidare",
    "ryktessmidarens": "ryktessmidare",
    "ryktessmidares": "ryktessmidare",
    "ryktessmidarna": "ryktessmidare",
    "ryktessmidarnas": "ryktessmidare",
    "ryktesspridningar": "ryktesspridning",
    "ryktesspridningarna": "ryktesspridning",
    "ryktesspridningarnas": "ryktesspridning",
    "ryktesspridningars": "ryktesspridning",
    "ryktesspridningen": "ryktesspridning",
    "ryktesspridningens": "ryktesspridning",
    "ryktesspridnings": "ryktesspridning",
    "ryktet": "rykte",
    "ryktets": "rykte",
    "rykts": "rykt",
    "ryktskrap": "ryktskrapa",
    "ryktskrapan": "ryktskrapa",
    "ryktskrapans": "ryktskrapa",
    "ryktskrapas": "ryktskrapa",
    "ryktskrape": "ryktskrapa",
    "ryktskrapor": "ryktskrapa",
    "ryktskraporna": "ryktskrapa",
    "ryktskrapornas": "ryktskrapa",
    "ryktskrapors": "ryktskrapa",
    "ryktskraps": "ryktskrapa",
    "rym": "rymma",
    "rymd": "rymma",
    "rymda": "rymma",
    "rymdas": "rymma",
    "rymdbiologien": "rymdbiologi",
    "rymdbiologiens": "rymdbiologi",
    "rymdbiologin": "rymdbiologi",
    "rymdbiologins": "rymdbiologi",
    "rymdbiologis": "rymdbiologi",
    "rymddräkten": "rymddräkt",
    "rymddräktens": "rymddräkt",
    "rymddräkter": "rymddräkt",
    "rymddräkterna": "rymddräkt",
    "rymddräkternas": "rymddräkt",
    "rymddräkters": "rymddräkt",
    "rymddräkts": "rymddräkt",
    "rymde": "rymma",
    "rymden": "rymd",
    "rymdens": "rymd",
    "rymder": "rymd",
    "rymderna": "rymd",
    "rymdernas": "rymd",
    "rymders": "rymd",
    "rymdes": "rymmas",
    "rymdfarar": "rymdfarare",
    "rymdfararen": "rymdfarare",
    "rymdfararens": "rymdfarare",
    "rymdfarares": "rymdfarare",
    "rymdfararna": "rymdfarare",
    "rymdfararnas": "rymdfarare",
    "rymdfarkosten": "rymdfarkost",
    "rymdfarkostens": "rymdfarkost",
    "rymdfarkoster": "rymdfarkost",
    "rymdfarkosterna": "rymdfarkost",
    "rymdfarkosternas": "rymdfarkost",
    "rymdfarkosters": "rymdfarkost",
    "rymdfarkosts": "rymdfarkost",
    "rymdfarten": "rymdfart",
    "rymdfartens": "rymdfart",
    "rymdfarts": "rymdfart",
    "rymdfartsstyrelsen": "rymdfartsstyrelse",
    "rymdfartsstyrelsens": "rymdfartsstyrelse",
    "rymdfartsstyrelser": "rymdfartsstyrelse",
    "rymdfartsstyrelserna": "rymdfartsstyrelse",
    "rymdfartsstyrelsernas": "rymdfartsstyrelse",
    "rymdfartsstyrelsers": "rymdfartsstyrelse",
    "rymdfartsstyrelses": "rymdfartsstyrelse",
    "rymdfärden": "rymdfärd",
    "rymdfärdens": "rymdfärd",
    "rymdfärder": "rymdfärd",
    "rymdfärderna": "rymdfärd",
    "rymdfärdernas": "rymdfärd",
    "rymdfärders": "rymdfärd",
    "rymdfärds": "rymdfärd",
    "rymdfärjan": "rymdfärja",
    "rymdfärjans": "rymdfärja",
    "rymdfärjas": "rymdfärja",
    "rymdfärje": "rymdfärja",
    "rymdfärjor": "rymdfärja",
    "rymdfärjorna": "rymdfärja",
    "rymdfärjornas": "rymdfärja",
    "rymdfärjors": "rymdfärja",
    "rymdgeometrien": "rymdgeometri",
    "rymdgeometriens": "rymdgeometri",
    "rymdgeometrin": "rymdgeometri",
    "rymdgeometrins": "rymdgeometri",
    "rymdgeometris": "rymdgeometri",
    "rymdkapplöpningen": "rymdkapplöpning",
    "rymdkapplöpningens": "rymdkapplöpning",
    "rymdkapplöpnings": "rymdkapplöpning",
    "rymdkapseln": "rymdkapsel",
    "rymdkapselns": "rymdkapsel",
    "rymdkapsels": "rymdkapsel",
    "rymdkapslar": "rymdkapsel",
    "rymdkapslarna": "rymdkapsel",
    "rymdkapslarnas": "rymdkapsel",
    "rymdkapslars": "rymdkapsel",
    "rymdmaterian": "rymdmateria",
    "rymdmaterians": "rymdmateria",
    "rymdmaterias": "rymdmateria",
    "rymdmaterier": "rymdmateria",
    "rymdmaterierna": "rymdmateria",
    "rymdmateriernas": "rymdmateria",
    "rymdmateriers": "rymdmateria",
    "rymdmedicinen": "rymdmedicin",
    "rymdmedicinens": "rymdmedicin",
    "rymdmedicins": "rymdmedicin",
    "rymdmåtten": "rymdmått",
    "rymdmåttens": "rymdmått",
    "rymdmåttet": "rymdmått",
    "rymdmåttets": "rymdmått",
    "rymdmåtts": "rymdmått",
    "rymdpiloten": "rymdpilot",
    "rymdpilotens": "rymdpilot",
    "rymdpiloter": "rymdpilot",
    "rymdpiloterna": "rymdpilot",
    "rymdpiloternas": "rymdpilot",
    "rymdpiloters": "rymdpilot",
    "rymdpilots": "rymdpilot",
    "rymdprogrammen": "rymdprogram",
    "rymdprogrammens": "rymdprogram",
    "rymdprogrammet": "rymdprogram",
    "rymdprogrammets": "rymdprogram",
    "rymdprograms": "rymdprogram",
    "rymdpromenaden": "rymdpromenad",
    "rymdpromenadens": "rymdpromenad",
    "rymdpromenader": "rymdpromenad",
    "rymdpromenaderna": "rymdpromenad",
    "rymdpromenadernas": "rymdpromenad",
    "rymdpromenaders": "rymdpromenad",
    "rymdpromenads": "rymdpromenad",
    "rymdraketen": "rymdraket",
    "rymdraketens": "rymdraket",
    "rymdraketer": "rymdraket",
    "rymdraketerna": "rymdraket",
    "rymdraketernas": "rymdraket",
    "rymdraketers": "rymdraket",
    "rymdrakets": "rymdraket",
    "rymdresan": "rymdresa",
    "rymdresans": "rymdresa",
    "rymdresas": "rymdresa",
    "rymdrese": "rymdresa",
    "rymdresor": "rymdresa",
    "rymdresorna": "rymdresa",
    "rymdresornas": "rymdresa",
    "rymdresors": "rymdresa",
    "rymds": "rymma",
    "rymdsatsningar": "rymdsatsning",
    "rymdsatsningarna": "rymdsatsning",
    "rymdsatsningarnas": "rymdsatsning",
    "rymdsatsningars": "rymdsatsning",
    "rymdsatsningen": "rymdsatsning",
    "rymdsatsningens": "rymdsatsning",
    "rymdsatsnings": "rymdsatsning",
    "rymdskeppen": "rymdskepp",
    "rymdskeppens": "rymdskepp",
    "rymdskeppet": "rymdskepp",
    "rymdskeppets": "rymdskepp",
    "rymdskepps": "rymdskepp",
    "rymdsonden": "rymdsond",
    "rymdsondens": "rymdsond",
    "rymdsonder": "rymdsond",
    "rymdsonderna": "rymdsond",
    "rymdsondernas": "rymdsond",
    "rymdsonders": "rymdsond",
    "rymdsonds": "rymdsond",
    "rymdstationen": "rymdstation",
    "rymdstationens": "rymdstation",
    "rymdstationer": "rymdstation",
    "rymdstationerna": "rymdstation",
    "rymdstationernas": "rymdstation",
    "rymdstationers": "rymdstation",
    "rymdstations": "rymdstation",
    "rymdstyrelsen": "rymdstyrelse",
    "rymdstyrelsens": "rymdstyrelse",
    "rymdstyrelser": "rymdstyrelse",
    "rymdstyrelserna": "rymdstyrelse",
    "rymdstyrelsernas": "rymdstyrelse",
    "rymdstyrelsers": "rymdstyrelse",
    "rymdstyrelses": "rymdstyrelse",
    "rymdtrafiken": "rymdtrafik",
    "rymdtrafikens": "rymdtrafik",
    "rymdtrafiks": "rymdtrafik",
    "rymdvapens": "rymdvapen",
    "rymdvapnen": "rymdvapen",
    "rymdvapnens": "rymdvapen",
    "rymdvapnet": "rymdvapen",
    "rymdvapnets": "rymdvapen",
    "rymdvikten": "rymdvikt",
    "rymdviktens": "rymdvikt",
    "rymdvikts": "rymdvikt",
    "rymdvinkeln": "rymdvinkel",
    "rymdvinkelns": "rymdvinkel",
    "rymdvinkels": "rymdvinkel",
    "rymdvinklar": "rymdvinkel",
    "rymdvinklarna": "rymdvinkel",
    "rymdvinklarnas": "rymdvinkel",
    "rymdvinklars": "rymdvinkel",
    "rymdåldern": "rymdålder",
    "rymdålderns": "rymdålder",
    "rymdålders": "rymdålder",
    "rymliga": "rymlig",
    "rymligare": "rymlig",
    "rymligares": "rymlig",
    "rymligas": "rymlig",
    "rymligast": "rymlig",
    "rymligaste": "rymlig",
    "rymligastes": "rymlig",
    "rymligasts": "rymlig",
    "rymlige": "rymlig",
    "rymliges": "rymlig",
    "rymligheten": "rymlighet",
    "rymlighetens": "rymlighet",
    "rymlighets": "rymlighet",
    "rymligs": "rymlig",
    "rymligt": "rymlig",
    "rymligts": "rymlig",
    "rymlingar": "rymling",
    "rymlingarna": "rymling",
    "rymlingarnas": "rymling",
    "rymlingars": "rymling",
    "rymlingen": "rymling",
    "rymlingens": "rymling",
    "rymlings": "rymling",
    "rymmande": "rymma",
    "rymmanden": "rymmande",
    "rymmandena": "rymmande",
    "rymmandenas": "rymmande",
    "rymmandens": "rymmande",
    "rymmandes": "rymmande",
    "rymmandet": "rymmande",
    "rymmandets": "rymmande",
    "rymmar": "rymmare",
    "rymmaren": "rymmare",
    "rymmarens": "rymmare",
    "rymmares": "rymmare",
    "rymmarna": "rymmare",
    "rymmarnas": "rymmare",
    "rymmas": "rymma",
    "rymmer": "rymma",
    "rymningar": "rymning",
    "rymningarna": "rymning",
    "rymningarnas": "rymning",
    "rymningars": "rymning",
    "rymningen": "rymning",
    "rymningens": "rymning",
    "rymnings": "rymning",
    "rymningssäkerheten": "rymningssäkerhet",
    "rymningssäkerhetens": "rymningssäkerhet",
    "rymningssäkerhets": "rymningssäkerhet",
    "rymningssäkers": "rymningssäker",
    "rymningssäkert": "rymningssäker",
    "rymningssäkerts": "rymningssäker",
    "rymningssäkra": "rymningssäker",
    "rymningssäkrare": "rymningssäker",
    "rymningssäkrares": "rymningssäker",
    "rymningssäkras": "rymningssäker",
    "rymningssäkrast": "rymningssäker",
    "rymningssäkraste": "rymningssäker",
    "rymningssäkrastes": "rymningssäker",
    "rymningssäkrasts": "rymningssäker",
    "rymningssäkre": "rymningssäker",
    "rymningssäkres": "rymningssäker",
    "ryms": "rymmas",
    "rymt": "rymma",
    "rymts": "rymmas",
    "rynk": "rynka",
    "rynkad": "rynka",
    "rynkade": "rynka",
    "rynkades": "rynka",
    "rynkads": "rynka",
    "rynkan": "rynka",
    "rynkande": "rynka",
    "rynkanden": "rynkande",
    "rynkandena": "rynkande",
    "rynkandenas": "rynkande",
    "rynkandens": "rynkande",
    "rynkandes": "rynkande",
    "rynkandet": "rynkande",
    "rynkandets": "rynkande",
    "rynkans": "rynka",
    "rynkar": "rynka",
    "rynkas": "rynka",
    "rynkat": "rynka",
    "rynkats": "rynka",
    "rynke": "rynka",
    "rynkiga": "rynkig",
    "rynkigare": "rynkig",
    "rynkigares": "rynkig",
    "rynkigas": "rynkig",
    "rynkigast": "rynkig",
    "rynkigaste": "rynkig",
    "rynkigastes": "rynkig",
    "rynkigasts": "rynkig",
    "rynkige": "rynkig",
    "rynkiges": "rynkig",
    "rynkigheten": "rynkighet",
    "rynkighetens": "rynkighet",
    "rynkighets": "rynkighet",
    "rynkigs": "rynkig",
    "rynkigt": "rynkig",
    "rynkigts": "rynkig",
    "rynkningar": "rynkning",
    "rynkningarna": "rynkning",
    "rynkningarnas": "rynkning",
    "rynkningars": "rynkning",
    "rynkningen": "rynkning",
    "rynkningens": "rynkning",
    "rynknings": "rynkning",
    "rynkor": "rynka",
    "rynkorna": "rynka",
    "rynkornas": "rynka",
    "rynkors": "rynka",
    "rynks": "rynka",
    "ryor": "rya",
    "ryorna": "rya",
    "ryornas": "rya",
    "ryors": "rya",
    "rypsen": "ryps",
    "rypsens": "ryps",
    "rys": "rysa",
    "rysande": "rysa",
    "rysanden": "rysande",
    "rysandena": "rysande",
    "rysandenas": "rysande",
    "rysandens": "rysande",
    "rysandes": "rysande",
    "rysandet": "rysande",
    "rysandets": "rysande",
    "rysansvärda": "rysansvärd",
    "rysansvärdare": "rysansvärd",
    "rysansvärdares": "rysansvärd",
    "rysansvärdas": "rysansvärd",
    "rysansvärdast": "rysansvärd",
    "rysansvärdaste": "rysansvärd",
    "rysansvärdastes": "rysansvärd",
    "rysansvärdasts": "rysansvärd",
    "rysansvärde": "rysansvärd",
    "rysansvärdes": "rysansvärd",
    "rysansvärdheten": "rysansvärdhet",
    "rysansvärdhetens": "rysansvärdhet",
    "rysansvärdhets": "rysansvärdhet",
    "rysansvärds": "rysansvärd",
    "rysansvärt": "rysansvärd",
    "rysansvärts": "rysansvärd",
    "rysar": "rysare",
    "rysaren": "rysare",
    "rysarens": "rysare",
    "rysares": "rysare",
    "rysarna": "rysare",
    "rysarnas": "rysare",
    "rysas": "rysa",
    "ryschen": "rysch",
    "ryschens": "rysch",
    "ryschet": "rysch",
    "ryschets": "rysch",
    "ryschiga": "ryschig",
    "ryschigare": "ryschig",
    "ryschigares": "ryschig",
    "ryschigas": "ryschig",
    "ryschigast": "ryschig",
    "ryschigaste": "ryschig",
    "ryschigastes": "ryschig",
    "ryschigasts": "ryschig",
    "ryschige": "ryschig",
    "ryschiges": "ryschig",
    "ryschigheten": "ryschighet",
    "ryschighetens": "ryschighet",
    "ryschighets": "ryschighet",
    "ryschigs": "ryschig",
    "ryschigt": "ryschig",
    "ryschigts": "ryschig",
    "ryschs": "rysch",
    "ryse": "rysa",
    "ryser": "rysa",
    "ryses": "rysa",
    "rysk": "ryska",
    "rysk-amerikanska": "rysk-amerikansk",
    "rysk-amerikanskare": "rysk-amerikansk",
    "rysk-amerikanskares": "rysk-amerikansk",
    "rysk-amerikanskas": "rysk-amerikansk",
    "rysk-amerikanskast": "rysk-amerikansk",
    "rysk-amerikanskaste": "rysk-amerikansk",
    "rysk-amerikanskastes": "rysk-amerikansk",
    "rysk-amerikanskasts": "rysk-amerikansk",
    "rysk-amerikanske": "rysk-amerikansk",
    "rysk-amerikanskes": "rysk-amerikansk",
    "rysk-amerikansks": "rysk-amerikansk",
    "rysk-amerikanskt": "rysk-amerikansk",
    "rysk-amerikanskts": "rysk-amerikansk",
    "ryska": "rysk",
    "ryskan": "ryska",
    "ryskans": "ryska",
    "ryskare": "rysk",
    "ryskares": "rysk",
    "ryskas": "ryska",
    "ryskast": "rysk",
    "ryskaste": "rysk",
    "ryskastes": "rysk",
    "ryskasts": "rysk",
    "ryske": "ryska",
    "ryskes": "rysk",
    "ryskheten": "ryskhet",
    "ryskhetens": "ryskhet",
    "ryskhets": "ryskhet",
    "ryskkursen": "ryskkurs",
    "ryskkursens": "ryskkurs",
    "ryskkurser": "ryskkurs",
    "ryskkurserna": "ryskkurs",
    "ryskkursernas": "ryskkurs",
    "ryskkursers": "ryskkurs",
    "rysklektionen": "rysklektion",
    "rysklektionens": "rysklektion",
    "rysklektioner": "rysklektion",
    "rysklektionerna": "rysklektion",
    "rysklektionernas": "rysklektion",
    "rysklektioners": "rysklektion",
    "rysklektions": "rysklektion",
    "rysklärar": "rysklärare",
    "ryskläraren": "rysklärare",
    "rysklärarens": "rysklärare",
    "rysklärares": "rysklärare",
    "rysklärarna": "rysklärare",
    "rysklärarnas": "rysklärare",
    "ryskor": "ryska",
    "ryskorna": "ryska",
    "ryskornas": "ryska",
    "ryskors": "ryska",
    "rysks": "rysk",
    "ryskspråkiga": "ryskspråkig",
    "ryskspråkigas": "ryskspråkig",
    "ryskspråkige": "ryskspråkig",
    "ryskspråkiges": "ryskspråkig",
    "ryskspråkigheten": "ryskspråkighet",
    "ryskspråkighetens": "ryskspråkighet",
    "ryskspråkighets": "ryskspråkighet",
    "ryskspråkigs": "ryskspråkig",
    "ryskspråkigt": "ryskspråkig",
    "ryskspråkigts": "ryskspråkig",
    "ryskt": "rysk",
    "ryskts": "rysk",
    "ryskundervisningen": "ryskundervisning",
    "ryskundervisningens": "ryskundervisning",
    "ryskundervisnings": "ryskundervisning",
    "rysliga": "ryslig",
    "rysligare": "ryslig",
    "rysligares": "ryslig",
    "rysligas": "ryslig",
    "rysligast": "ryslig",
    "rysligaste": "ryslig",
    "rysligastes": "ryslig",
    "rysligasts": "ryslig",
    "ryslige": "ryslig",
    "rysliges": "ryslig",
    "rysligheten": "ryslighet",
    "ryslighetens": "ryslighet",
    "rysligheter": "ryslighet",
    "rysligheterna": "ryslighet",
    "rysligheternas": "ryslighet",
    "rysligheters": "ryslighet",
    "ryslighets": "ryslighet",
    "rysligs": "ryslig",
    "rysligt": "ryslig",
    "rysligts": "ryslig",
    "rysningar": "rysning",
    "rysningarna": "rysning",
    "rysningarnas": "rysning",
    "rysningars": "rysning",
    "rysningen": "rysning",
    "rysningens": "rysning",
    "rysnings": "rysning",
    "ryssar": "ryss",
    "ryssarna": "ryss",
    "ryssarnas": "ryss",
    "ryssars": "ryss",
    "ryssen": "ryss",
    "ryssens": "ryss",
    "ryssfobien": "ryssfobi",
    "ryssfobiens": "ryssfobi",
    "ryssfobier": "ryssfobi",
    "ryssfobierna": "ryssfobi",
    "ryssfobiernas": "ryssfobi",
    "ryssfobiers": "ryssfobi",
    "ryssfobin": "ryssfobi",
    "ryssfobins": "ryssfobi",
    "ryssfobis": "ryssfobi",
    "ryssgubb": "ryssgubbe",
    "ryssgubbar": "ryssgubbe",
    "ryssgubbarna": "ryssgubbe",
    "ryssgubbarnas": "ryssgubbe",
    "ryssgubbars": "ryssgubbe",
    "ryssgubben": "ryssgubbe",
    "ryssgubbens": "ryssgubbe",
    "ryssgubbes": "ryssgubbe",
    "ryssgubbs": "ryssgubbe",
    "rysshatet": "rysshat",
    "rysshatets": "rysshat",
    "rysshats": "rysshat",
    "ryssjan": "ryssja",
    "ryssjans": "ryssja",
    "ryssjas": "ryssja",
    "ryssje": "ryssja",
    "ryssjor": "ryssja",
    "ryssjorna": "ryssja",
    "ryssjornas": "ryssja",
    "ryssjors": "ryssja",
    "ryssläders": "ryssläder",
    "rysslädret": "ryssläder",
    "rysslädrets": "ryssläder",
    "ryssländar": "ryssländare",
    "ryssländaren": "ryssländare",
    "ryssländarens": "ryssländare",
    "ryssländares": "ryssländare",
    "ryssländarna": "ryssländare",
    "ryssländarnas": "ryssländare",
    "ryssländska": "ryssländsk",
    "ryssländskan": "ryssländska",
    "ryssländskans": "ryssländska",
    "ryssländskare": "ryssländsk",
    "ryssländskares": "ryssländsk",
    "ryssländskas": "ryssländska",
    "ryssländskast": "ryssländsk",
    "ryssländskaste": "ryssländsk",
    "ryssländskastes": "ryssländsk",
    "ryssländskasts": "ryssländsk",
    "ryssländske": "ryssländska",
    "ryssländskes": "ryssländsk",
    "ryssländskor": "ryssländska",
    "ryssländskorna": "ryssländska",
    "ryssländskornas": "ryssländska",
    "ryssländskors": "ryssländska",
    "ryssländsks": "ryssländsk",
    "ryssländskt": "ryssländsk",
    "ryssländskts": "ryssländsk",
    "ryst": "rysa",
    "ryste": "rysa",
    "rystes": "rysa",
    "rysts": "rysa",
    "ryt": "ryta",
    "rytande": "ryta",
    "rytanden": "rytande",
    "rytandena": "rytande",
    "rytandenas": "rytande",
    "rytandens": "rytande",
    "rytandes": "rytande",
    "rytandet": "rytande",
    "rytandets": "rytande",
    "rytas": "ryta",
    "ryte": "ryta",
    "ryter": "ryta",
    "rytes": "ryta",
    "rytmen": "rytm",
    "rytmens": "rytm",
    "rytmer": "rytm",
    "rytmerna": "rytm",
    "rytmernas": "rytm",
    "rytmers": "rytm",
    "rytmiciteten": "rytmicitet",
    "rytmicitetens": "rytmicitet",
    "rytmiciteter": "rytmicitet",
    "rytmiciteterna": "rytmicitet",
    "rytmiciteternas": "rytmicitet",
    "rytmiciteters": "rytmicitet",
    "rytmicitets": "rytmicitet",
    "rytmiken": "rytmik",
    "rytmikens": "rytmik",
    "rytmiks": "rytmik",
    "rytmiserad": "rytmisera",
    "rytmiserade": "rytmisera",
    "rytmiserades": "rytmisera",
    "rytmiserads": "rytmisera",
    "rytmiserande": "rytmisera",
    "rytmiseranden": "rytmiserande",
    "rytmiserandena": "rytmiserande",
    "rytmiserandenas": "rytmiserande",
    "rytmiserandens": "rytmiserande",
    "rytmiserandes": "rytmiserande",
    "rytmiserandet": "rytmiserande",
    "rytmiserandets": "rytmiserande",
    "rytmiserar": "rytmisera",
    "rytmiseras": "rytmisera",
    "rytmiserat": "rytmisera",
    "rytmiserats": "rytmisera",
    "rytmiserbara": "rytmiserbar",
    "rytmiserbarare": "rytmiserbar",
    "rytmiserbarares": "rytmiserbar",
    "rytmiserbaras": "rytmiserbar",
    "rytmiserbarast": "rytmiserbar",
    "rytmiserbaraste": "rytmiserbar",
    "rytmiserbarastes": "rytmiserbar",
    "rytmiserbarasts": "rytmiserbar",
    "rytmiserbare": "rytmiserbar",
    "rytmiserbares": "rytmiserbar",
    "rytmiserbarheten": "rytmiserbarhet",
    "rytmiserbarhetens": "rytmiserbarhet",
    "rytmiserbarhets": "rytmiserbarhet",
    "rytmiserbars": "rytmiserbar",
    "rytmiserbart": "rytmiserbar",
    "rytmiserbarts": "rytmiserbar",
    "rytmiseringar": "rytmisering",
    "rytmiseringarna": "rytmisering",
    "rytmiseringarnas": "rytmisering",
    "rytmiseringars": "rytmisering",
    "rytmiseringen": "rytmisering",
    "rytmiseringens": "rytmisering",
    "rytmiserings": "rytmisering",
    "rytmiska": "rytmisk",
    "rytmiskare": "rytmisk",
    "rytmiskares": "rytmisk",
    "rytmiskas": "rytmisk",
    "rytmiskast": "rytmisk",
    "rytmiskaste": "rytmisk",
    "rytmiskastes": "rytmisk",
    "rytmiskasts": "rytmisk",
    "rytmiske": "rytmisk",
    "rytmiskes": "rytmisk",
    "rytmisks": "rytmisk",
    "rytmiskt": "rytmisk",
    "rytmiskts": "rytmisk",
    "rytms": "rytm",
    "rytmsektionen": "rytmsektion",
    "rytmsektionens": "rytmsektion",
    "rytmsektioner": "rytmsektion",
    "rytmsektionerna": "rytmsektion",
    "rytmsektionernas": "rytmsektion",
    "rytmsektioners": "rytmsektion",
    "rytmsektions": "rytmsektion",
    "ryts": "ryta",
    "ryttar": "ryttare",
    "ryttaren": "ryttare",
    "ryttarens": "ryttare",
    "ryttares": "ryttare",
    "ryttarfolken": "ryttarfolk",
    "ryttarfolkens": "ryttarfolk",
    "ryttarfolket": "ryttarfolk",
    "ryttarfolkets": "ryttarfolk",
    "ryttarfolks": "ryttarfolk",
    "ryttargångar": "ryttargång",
    "ryttargångarna": "ryttargång",
    "ryttargångarnas": "ryttargång",
    "ryttargångars": "ryttargång",
    "ryttargången": "ryttargång",
    "ryttargångens": "ryttargång",
    "ryttargångs": "ryttargång",
    "ryttarlekar": "ryttarlek",
    "ryttarlekarna": "ryttarlek",
    "ryttarlekarnas": "ryttarlek",
    "ryttarlekars": "ryttarlek",
    "ryttarleken": "ryttarlek",
    "ryttarlekens": "ryttarlek",
    "ryttarleks": "ryttarlek",
    "ryttarna": "ryttare",
    "ryttarnas": "ryttare",
    "ryttaruppvisningar": "ryttaruppvisning",
    "ryttaruppvisningarna": "ryttaruppvisning",
    "ryttaruppvisningarnas": "ryttaruppvisning",
    "ryttaruppvisningars": "ryttaruppvisning",
    "ryttaruppvisningen": "ryttaruppvisning",
    "ryttaruppvisningens": "ryttaruppvisning",
    "ryttaruppvisnings": "ryttaruppvisning",
    "ryttel": "ryttla",
    "rytteriet": "rytteri",
    "rytteriets": "rytteri",
    "rytteris": "rytteri",
    "rytterit": "rytteri",
    "rytterits": "rytteri",
    "ryttlade": "ryttla",
    "ryttlades": "ryttla",
    "ryttlande": "ryttla",
    "ryttlanden": "ryttlande",
    "ryttlandena": "ryttlande",
    "ryttlandenas": "ryttlande",
    "ryttlandens": "ryttlande",
    "ryttlandes": "ryttlande",
    "ryttlandet": "ryttlande",
    "ryttlandets": "ryttlande",
    "ryttlar": "ryttla",
    "ryttlas": "ryttla",
    "ryttlat": "ryttla",
    "ryttlats": "ryttla",
    "ryttmästar": "ryttmästare",
    "ryttmästaren": "ryttmästare",
    "ryttmästarens": "ryttmästare",
    "ryttmästares": "ryttmästare",
    "ryttmästarna": "ryttmästare",
    "ryttmästarnas": "ryttmästare",
    "räck": "räcka",
    "räckan": "räcka",
    "räckande": "räcka",
    "räckanden": "räckande",
    "räckandena": "räckande",
    "räckandenas": "räckande",
    "räckandens": "räckande",
    "räckandes": "räckande",
    "räckandet": "räckande",
    "räckandets": "räckande",
    "räckans": "räcka",
    "räckas": "räcka",
    "räcke": "räcka",
    "räcken": "räcke",
    "räckena": "räcke",
    "räckenas": "räcke",
    "räckens": "räcke",
    "räcker": "räcka",
    "räckes": "räcke",
    "räcket": "räcke",
    "räckets": "räcke",
    "räckhålls": "räckhåll",
    "räckor": "räcka",
    "räckorna": "räcka",
    "räckornas": "räcka",
    "räckors": "räcka",
    "räcks": "räcka",
    "räckt": "räcka",
    "räckta": "räcka",
    "räcktas": "räcka",
    "räckte": "räcka",
    "räcktes": "räcka",
    "räckts": "räcka",
    "räckverken": "räckverk",
    "räckverkens": "räckverk",
    "räckverket": "räckverk",
    "räckverkets": "räckverk",
    "räckverks": "räckverk",
    "räckvidden": "räckvidd",
    "räckviddens": "räckvidd",
    "räckvidder": "räckvidd",
    "räckvidderna": "räckvidd",
    "räckviddernas": "räckvidd",
    "räckvidders": "räckvidd",
    "räckvidds": "räckvidd",
    "rädd": "rädda",
    "rädda": "rädd",
    "räddad": "rädda",
    "räddade": "rädda",
    "räddades": "rädda",
    "räddads": "rädda",
    "räddande": "rädda",
    "räddanden": "räddande",
    "räddandena": "räddande",
    "räddandenas": "räddande",
    "räddandens": "räddande",
    "räddandes": "räddande",
    "räddandet": "räddande",
    "räddandets": "räddande",
    "räddar": "räddare",
    "räddare": "rädd",
    "räddaren": "räddare",
    "räddarens": "räddare",
    "räddares": "räddare",
    "räddarna": "räddare",
    "räddarnas": "räddare",
    "räddas": "rädda",
    "räddast": "rädd",
    "räddaste": "rädd",
    "räddastes": "rädd",
    "räddasts": "rädd",
    "räddat": "rädda",
    "räddats": "rädda",
    "rädde": "rädd",
    "räddes": "rädd",
    "räddheten": "räddhet",
    "räddhetens": "räddhet",
    "räddhets": "räddhet",
    "räddhågade": "räddhågad",
    "räddhågades": "räddhågad",
    "räddhågads": "räddhågad",
    "räddhågan": "räddhåga",
    "räddhågans": "räddhåga",
    "räddhågas": "räddhåga",
    "räddhågat": "räddhågad",
    "räddhågats": "räddhågad",
    "räddhågsens": "räddhågsen",
    "räddhågset": "räddhågsen",
    "räddhågsets": "räddhågsen",
    "räddhågsna": "räddhågsen",
    "räddhågsnare": "räddhågsen",
    "räddhågsnares": "räddhågsen",
    "räddhågsnas": "räddhågsen",
    "räddhågsnast": "räddhågsen",
    "räddhågsnaste": "räddhågsen",
    "räddhågsnastes": "räddhågsen",
    "räddhågsnasts": "räddhågsen",
    "räddhågsne": "räddhågsen",
    "räddhågsnes": "räddhågsen",
    "räddningar": "räddning",
    "räddningarna": "räddning",
    "räddningarnas": "räddning",
    "räddningars": "räddning",
    "räddningen": "räddning",
    "räddningens": "räddning",
    "räddnings": "räddning",
    "räddningsaktionen": "räddningsaktion",
    "räddningsaktionens": "räddningsaktion",
    "räddningsaktioner": "räddningsaktion",
    "räddningsaktionerna": "räddningsaktion",
    "räddningsaktionernas": "räddningsaktion",
    "räddningsaktioners": "räddningsaktion",
    "räddningsaktions": "räddningsaktion",
    "räddningschefen": "räddningschef",
    "räddningschefens": "räddningschef",
    "räddningschefer": "räddningschef",
    "räddningscheferna": "räddningschef",
    "räddningschefernas": "räddningschef",
    "räddningschefers": "räddningschef",
    "räddningschefs": "räddningschef",
    "räddningsenheten": "räddningsenhet",
    "räddningsenhetens": "räddningsenhet",
    "räddningsenheter": "räddningsenhet",
    "räddningsenheterna": "räddningsenhet",
    "räddningsenheternas": "räddningsenhet",
    "räddningsenheters": "räddningsenhet",
    "räddningsenhets": "räddningsenhet",
    "räddningshelikoptern": "räddningshelikopter",
    "räddningshelikopterns": "räddningshelikopter",
    "räddningshelikopters": "räddningshelikopter",
    "räddningshelikoptrar": "räddningshelikopter",
    "räddningshelikoptrarna": "räddningshelikopter",
    "räddningshelikoptrarnas": "räddningshelikopter",
    "räddningshelikoptrars": "räddningshelikopter",
    "räddningsinsatsen": "räddningsinsats",
    "räddningsinsatsens": "räddningsinsats",
    "räddningsinsatser": "räddningsinsats",
    "räddningsinsatserna": "räddningsinsats",
    "räddningsinsatsernas": "räddningsinsats",
    "räddningsinsatsers": "räddningsinsats",
    "räddningsklock": "räddningsklocka",
    "räddningsklockan": "räddningsklocka",
    "räddningsklockans": "räddningsklocka",
    "räddningsklockas": "räddningsklocka",
    "räddningsklocke": "räddningsklocka",
    "räddningsklockor": "räddningsklocka",
    "räddningsklockorna": "räddningsklocka",
    "räddningsklockornas": "räddningsklocka",
    "räddningsklockors": "räddningsklocka",
    "räddningsklocks": "räddningsklocka",
    "räddningsledar": "räddningsledare",
    "räddningsledaren": "räddningsledare",
    "räddningsledarens": "räddningsledare",
    "räddningsledares": "räddningsledare",
    "räddningsledarna": "räddningsledare",
    "räddningsledarnas": "räddningsledare",
    "räddningslösa": "räddningslös",
    "räddningslösare": "räddningslös",
    "räddningslösares": "räddningslös",
    "räddningslösas": "räddningslös",
    "räddningslösast": "räddningslös",
    "räddningslösaste": "räddningslös",
    "räddningslösastes": "räddningslös",
    "räddningslösasts": "räddningslös",
    "räddningslöse": "räddningslös",
    "räddningslöses": "räddningslös",
    "räddningslösheten": "räddningslöshet",
    "räddningslöshetens": "räddningslöshet",
    "räddningslöshets": "räddningslöshet",
    "räddningslöst": "räddningslös",
    "räddningslösts": "räddningslös",
    "räddningsoperationen": "räddningsoperation",
    "räddningsoperationens": "räddningsoperation",
    "räddningsoperationer": "räddningsoperation",
    "räddningsoperationerna": "räddningsoperation",
    "räddningsoperationernas": "räddningsoperation",
    "räddningsoperationers": "räddningsoperation",
    "räddningsoperations": "räddningsoperation",
    "räddningsplane": "räddningsplan",
    "räddningsplanen": "räddningsplan",
    "räddningsplanens": "räddningsplan",
    "räddningsplaner": "räddningsplan",
    "räddningsplanerna": "räddningsplan",
    "räddningsplanernas": "räddningsplan",
    "räddningsplaners": "räddningsplan",
    "räddningsplank": "räddningsplanka",
    "räddningsplankan": "räddningsplanka",
    "räddningsplankans": "räddningsplanka",
    "räddningsplankas": "räddningsplanka",
    "räddningsplanke": "räddningsplanka",
    "räddningsplankor": "räddningsplanka",
    "räddningsplankorna": "räddningsplanka",
    "räddningsplankornas": "räddningsplanka",
    "räddningsplankors": "räddningsplanka",
    "räddningsplanks": "räddningsplanka",
    "räddningsplans": "räddningsplan",
    "räddningspådragen": "räddningspådrag",
    "räddningspådragens": "räddningspådrag",
    "räddningspådraget": "räddningspådrag",
    "räddningspådragets": "räddningspådrag",
    "räddningspådrags": "räddningspådrag",
    "räddningsstyrkan": "räddningsstyrka",
    "räddningsstyrkans": "räddningsstyrka",
    "räddningsstyrkas": "räddningsstyrka",
    "räddningsstyrke": "räddningsstyrka",
    "räddningsstyrkor": "räddningsstyrka",
    "räddningsstyrkorna": "räddningsstyrka",
    "räddningsstyrkornas": "räddningsstyrka",
    "räddningsstyrkors": "räddningsstyrka",
    "räddningstjänsten": "räddningstjänst",
    "räddningstjänstens": "räddningstjänst",
    "räddningstjänster": "räddningstjänst",
    "räddningstjänsterna": "räddningstjänst",
    "räddningstjänsternas": "räddningstjänst",
    "räddningstjänsters": "räddningstjänst",
    "räddningstjänsts": "räddningstjänst",
    "rädds": "rädd",
    "räden": "räd",
    "rädens": "räd",
    "räder": "räd",
    "räderna": "räd",
    "rädernas": "räd",
    "räders": "räd",
    "rädis": "rädisa",
    "rädisan": "rädisa",
    "rädisans": "rädisa",
    "rädisas": "rädisa",
    "rädise": "rädisa",
    "rädisor": "rädisa",
    "rädisorna": "rädisa",
    "rädisornas": "rädisa",
    "rädisors": "rädisa",
    "räds": "rädas",
    "rädseln": "rädsel",
    "rädselns": "rädsel",
    "rädsels": "rädsel",
    "rädslan": "rädsla",
    "rädslans": "rädsla",
    "rädslas": "rädsla",
    "rädsle": "rädsla",
    "rädslo": "rädsla",
    "räffel": "räffla",
    "räfflad": "räffla",
    "räfflade": "räfflad",
    "räfflades": "räfflad",
    "räfflads": "räfflad",
    "räfflan": "räffla",
    "räfflande": "räffla",
    "räfflanden": "räfflande",
    "räfflandena": "räfflande",
    "räfflandenas": "räfflande",
    "räfflandens": "räfflande",
    "räfflandes": "räfflande",
    "räfflandet": "räfflande",
    "räfflandets": "räfflande",
    "räfflans": "räffla",
    "räfflar": "räffla",
    "räfflas": "räffla",
    "räfflat": "räfflad",
    "räfflats": "räfflad",
    "räffle": "räffla",
    "räfflor": "räffla",
    "räfflorna": "räffla",
    "räfflornas": "räffla",
    "räfflors": "räffla",
    "räfs": "räfsa",
    "räfsad": "räfsa",
    "räfsade": "räfsa",
    "räfsades": "räfsa",
    "räfsads": "räfsa",
    "räfsan": "räfsa",
    "räfsande": "räfsa",
    "räfsanden": "räfsande",
    "räfsandena": "räfsande",
    "räfsandenas": "räfsande",
    "räfsandens": "räfsande",
    "räfsandes": "räfsande",
    "räfsandet": "räfsande",
    "räfsandets": "räfsande",
    "räfsans": "räfsa",
    "räfsar": "räfsa",
    "räfsas": "räfsa",
    "räfsat": "räfsa",
    "räfsats": "räfsa",
    "räfse": "räfsa",
    "räfsor": "räfsa",
    "räfsorna": "räfsa",
    "räfsornas": "räfsa",
    "räfsors": "räfsa",
    "räfsten": "räfst",
    "räfstens": "räfst",
    "räfster": "räfst",
    "räfsterna": "räfst",
    "räfsternas": "räfst",
    "räfsters": "räfst",
    "räfsts": "räfst",
    "räjongen": "räjong",
    "räjongens": "räjong",
    "räjonger": "räjong",
    "räjongerna": "räjong",
    "räjongernas": "räjong",
    "räjongers": "räjong",
    "räjongs": "räjong",
    "räk": "räka",
    "räkan": "räka",
    "räkans": "räka",
    "räkas": "räka",
    "räke": "räka",
    "räkeln": "räkel",
    "räkelns": "räkel",
    "räkels": "räkel",
    "räkenskaperna": "räkenskaper",
    "räkenskapernas": "räkenskaper",
    "räkenskapers": "räkenskaper",
    "räkenskaps": "räkenskaper",
    "räkenskapsåren": "räkenskapsår",
    "räkenskapsårens": "räkenskapsår",
    "räkenskapsåret": "räkenskapsår",
    "räkenskapsårets": "räkenskapsår",
    "räkenskapsårs": "räkenskapsår",
    "räkfrossan": "räkfrossa",
    "räkfrossans": "räkfrossa",
    "räkfrossas": "räkfrossa",
    "räkfrosse": "räkfrossa",
    "räkfrossor": "räkfrossa",
    "räkfrossorna": "räkfrossa",
    "räkfrossornas": "räkfrossa",
    "räkfrossors": "räkfrossa",
    "räkkryssningar": "räkkryssning",
    "räkkryssningarna": "räkkryssning",
    "räkkryssningarnas": "räkkryssning",
    "räkkryssningars": "räkkryssning",
    "räkkryssningen": "räkkryssning",
    "räkkryssningens": "räkkryssning",
    "räkkryssnings": "räkkryssning",
    "räklar": "räkel",
    "räklarna": "räkel",
    "räklarnas": "räkel",
    "räklars": "räkel",
    "räknad": "räkna",
    "räknade": "räkna",
    "räknades": "räkna",
    "räknads": "räkna",
    "räknande": "räkna",
    "räknanden": "räknande",
    "räknandena": "räknande",
    "räknandenas": "räknande",
    "räknandens": "räknande",
    "räknandes": "räknande",
    "räknandet": "räknande",
    "räknandets": "räknande",
    "räknar": "räknare",
    "räknaren": "räknare",
    "räknarens": "räknare",
    "räknares": "räknare",
    "räknarna": "räknare",
    "räknarnas": "räknare",
    "räknas": "räkna",
    "räknat": "räkna",
    "räknats": "räkna",
    "räkne": "räkna",
    "räkneapparaten": "räkneapparat",
    "räkneapparatens": "räkneapparat",
    "räkneapparater": "räkneapparat",
    "räkneapparaterna": "räkneapparat",
    "räkneapparaternas": "räkneapparat",
    "räkneapparaters": "räkneapparat",
    "räkneapparats": "räkneapparat",
    "räknedos": "räknedosa",
    "räknedosan": "räknedosa",
    "räknedosans": "räknedosa",
    "räknedosas": "räknedosa",
    "räknedose": "räknedosa",
    "räknedosor": "räknedosa",
    "räknedosorna": "räknedosa",
    "räknedosornas": "räknedosa",
    "räknedosors": "räknedosa",
    "räkneexempels": "räkneexempel",
    "räkneexemplen": "räkneexempel",
    "räkneexemplens": "räkneexempel",
    "räkneexemplet": "räkneexempel",
    "räkneexemplets": "räkneexempel",
    "räknekapaciteten": "räknekapacitet",
    "räknekapacitetens": "räknekapacitet",
    "räknekapaciteter": "räknekapacitet",
    "räknekapaciteterna": "räknekapacitet",
    "räknekapaciteternas": "räknekapacitet",
    "räknekapaciteters": "räknekapacitet",
    "räknekapacitets": "räknekapacitet",
    "räknemaskinen": "räknemaskin",
    "räknemaskinens": "räknemaskin",
    "räknemaskiner": "räknemaskin",
    "räknemaskinerna": "räknemaskin",
    "räknemaskinernas": "räknemaskin",
    "räknemaskiners": "räknemaskin",
    "räknemaskins": "räknemaskin",
    "räknenissar": "räknenisse",
    "räknenissarna": "räknenisse",
    "räknenissarnas": "räknenisse",
    "räknenissars": "räknenisse",
    "räknenissen": "räknenisse",
    "räknenissens": "räknenisse",
    "räknenisses": "räknenisse",
    "räkneorden": "räkneord",
    "räkneordens": "räkneord",
    "räkneordet": "räkneord",
    "räkneordets": "räkneord",
    "räkneords": "räkneord",
    "räknerams": "räkneramsa",
    "räkneramsan": "räkneramsa",
    "räkneramsans": "räkneramsa",
    "räkneramsas": "räkneramsa",
    "räkneramse": "räkneramsa",
    "räkneramsor": "räkneramsa",
    "räkneramsorna": "räkneramsa",
    "räkneramsornas": "räkneramsa",
    "räkneramsors": "räkneramsa",
    "räknesnabbheten": "räknesnabbhet",
    "räknesnabbhetens": "räknesnabbhet",
    "räknesnabbheter": "räknesnabbhet",
    "räknesnabbheterna": "räknesnabbhet",
    "räknesnabbheternas": "räknesnabbhet",
    "räknesnabbheters": "räknesnabbhet",
    "räknesnabbhets": "räknesnabbhet",
    "räknestick": "räknesticka",
    "räknestickan": "räknesticka",
    "räknestickans": "räknesticka",
    "räknestickas": "räknesticka",
    "räknesticke": "räknesticka",
    "räknestickor": "räknesticka",
    "räknestickorna": "räknesticka",
    "räknestickornas": "räknesticka",
    "räknestickors": "räknesticka",
    "räknesticks": "räknesticka",
    "räknesätten": "räknesätt",
    "räknesättens": "räknesätt",
    "räknesättet": "räknesätt",
    "räknesättets": "räknesätt",
    "räknesätts": "räknesätt",
    "räkneverken": "räkneverk",
    "räkneverkens": "räkneverk",
    "räkneverket": "räkneverk",
    "räkneverkets": "räkneverk",
    "räkneverks": "räkneverk",
    "räkningar": "räkning",
    "räkningarna": "räkning",
    "räkningarnas": "räkning",
    "räkningars": "räkning",
    "räkningen": "räkning",
    "räkningens": "räkning",
    "räknings": "räkning",
    "räkor": "räka",
    "räkorna": "räka",
    "räkornas": "räka",
    "räkors": "räka",
    "räks": "räka",
    "räksmörgåsar": "räksmörgås",
    "räksmörgåsarna": "räksmörgås",
    "räksmörgåsarnas": "räksmörgås",
    "räksmörgåsars": "räksmörgås",
    "räksmörgåsen": "räksmörgås",
    "räksmörgåsens": "räksmörgås",
    "rälen": "räl",
    "rälens": "räl",
    "räler": "räl",
    "rälerna": "räl",
    "rälernas": "räl",
    "rälers": "räl",
    "räliga": "rälig",
    "räligare": "rälig",
    "räligares": "rälig",
    "räligas": "rälig",
    "räligast": "rälig",
    "räligaste": "rälig",
    "räligastes": "rälig",
    "räligasts": "rälig",
    "rälige": "rälig",
    "räliges": "rälig",
    "räligheten": "rälighet",
    "rälighetens": "rälighet",
    "räligheter": "rälighet",
    "räligheterna": "rälighet",
    "räligheternas": "rälighet",
    "räligheters": "rälighet",
    "rälighets": "rälighet",
    "räligs": "rälig",
    "räligt": "rälig",
    "räligts": "rälig",
    "räls": "räl",
    "rälsar": "räls",
    "rälsarna": "räls",
    "rälsarnas": "räls",
    "rälsars": "räls",
    "rälsbrotten": "rälsbrott",
    "rälsbrottens": "rälsbrott",
    "rälsbrottet": "rälsbrott",
    "rälsbrottets": "rälsbrott",
    "rälsbrotts": "rälsbrott",
    "rälsbussar": "rälsbuss",
    "rälsbussarna": "rälsbuss",
    "rälsbussarnas": "rälsbuss",
    "rälsbussars": "rälsbuss",
    "rälsbussen": "rälsbuss",
    "rälsbussens": "rälsbuss",
    "rälsbusstationen": "rälsbusstation",
    "rälsbusstationens": "rälsbusstation",
    "rälsbusstationer": "rälsbusstation",
    "rälsbusstationerna": "rälsbusstation",
    "rälsbusstationernas": "rälsbusstation",
    "rälsbusstationers": "rälsbusstation",
    "rälsbusstations": "rälsbusstation",
    "rälsen": "räls",
    "rälsens": "räls",
    "rälsfelen": "rälsfel",
    "rälsfelens": "rälsfel",
    "rälsfelet": "rälsfel",
    "rälsfelets": "rälsfel",
    "rälsfels": "rälsfel",
    "rämn": "rämna",
    "rämnad": "rämna",
    "rämnade": "rämna",
    "rämnades": "rämna",
    "rämnads": "rämna",
    "rämnande": "rämna",
    "rämnanden": "rämnande",
    "rämnandena": "rämnande",
    "rämnandenas": "rämnande",
    "rämnandens": "rämnande",
    "rämnandes": "rämnande",
    "rämnandet": "rämnande",
    "rämnandets": "rämnande",
    "rämnar": "rämna",
    "rämnas": "rämna",
    "rämnat": "rämna",
    "rämnats": "rämna",
    "ränd": "ränna",
    "rända": "ränna",
    "rändas": "ränna",
    "rände": "ränna",
    "ränder": "rand",
    "ränderna": "rand",
    "rändernas": "rand",
    "ränders": "rand",
    "rändes": "ränna",
    "ränds": "ränna",
    "ränk": "ränker",
    "ränkerna": "ränker",
    "ränkernas": "ränker",
    "ränkers": "ränker",
    "ränks": "ränker",
    "ränksmidar": "ränksmidare",
    "ränksmidaren": "ränksmidare",
    "ränksmidarens": "ränksmidare",
    "ränksmidares": "ränksmidare",
    "ränksmidarna": "ränksmidare",
    "ränksmidarnas": "ränksmidare",
    "ränn": "ränna",
    "rännan": "ränna",
    "rännande": "ränna",
    "rännanden": "rännande",
    "rännandena": "rännande",
    "rännandenas": "rännande",
    "rännandens": "rännande",
    "rännandes": "rännande",
    "rännandet": "rännande",
    "rännandets": "rännande",
    "rännans": "ränna",
    "rännarbanan": "rännarbana",
    "rännarbanans": "rännarbana",
    "rännarbanas": "rännarbana",
    "rännarbane": "rännarbana",
    "rännarbanor": "rännarbana",
    "rännarbanorna": "rännarbana",
    "rännarbanornas": "rännarbana",
    "rännarbanors": "rännarbana",
    "rännas": "ränna",
    "ränne": "ränna",
    "ränner": "ränna",
    "rännes": "ränna",
    "rännilar": "rännil",
    "rännilarna": "rännil",
    "rännilarnas": "rännil",
    "rännilars": "rännil",
    "rännilen": "rännil",
    "rännilens": "rännil",
    "rännils": "rännil",
    "ränningar": "ränning",
    "ränningarna": "ränning",
    "ränningarnas": "ränning",
    "ränningars": "ränning",
    "ränningen": "ränning",
    "ränningens": "ränning",
    "rännings": "ränning",
    "rännor": "ränna",
    "rännorna": "ränna",
    "rännornas": "ränna",
    "rännors": "ränna",
    "ränns": "ränna",
    "rännsnar": "rännsnara",
    "rännsnaran": "rännsnara",
    "rännsnarans": "rännsnara",
    "rännsnaras": "rännsnara",
    "rännsnare": "rännsnara",
    "rännsnaror": "rännsnara",
    "rännsnarorna": "rännsnara",
    "rännsnarornas": "rännsnara",
    "rännsnarors": "rännsnara",
    "rännsnars": "rännsnara",
    "rännstenar": "rännsten",
    "rännstenarna": "rännsten",
    "rännstenarnas": "rännsten",
    "rännstenars": "rännsten",
    "rännstenen": "rännsten",
    "rännstenens": "rännsten",
    "rännstens": "rännsten",
    "rännstensungar": "rännstensunge",
    "rännstensungarna": "rännstensunge",
    "rännstensungarnas": "rännstensunge",
    "rännstensungars": "rännstensunge",
    "rännstensungen": "rännstensunge",
    "rännstensungens": "rännstensunge",
    "rännstensunges": "rännstensunge",
    "ränseln": "ränsel",
    "ränselns": "ränsel",
    "ränsels": "ränsel",
    "ränslar": "ränsel",
    "ränslarna": "ränsel",
    "ränslarnas": "ränsel",
    "ränslars": "ränsel",
    "ränt": "ränna",
    "räntabels": "räntabel",
    "räntabelt": "räntabel",
    "räntabelts": "räntabel",
    "räntabiliteten": "räntabilitet",
    "räntabilitetens": "räntabilitet",
    "räntabiliteter": "räntabilitet",
    "räntabiliteterna": "räntabilitet",
    "räntabiliteternas": "räntabilitet",
    "räntabiliteters": "räntabilitet",
    "räntabilitets": "räntabilitet",
    "räntabla": "räntabel",
    "räntablare": "räntabel",
    "räntablares": "räntabel",
    "räntablas": "räntabel",
    "räntablast": "räntabel",
    "räntablaste": "räntabel",
    "räntablastes": "räntabel",
    "räntablasts": "räntabel",
    "räntable": "räntabel",
    "räntables": "räntabel",
    "räntan": "ränta",
    "räntans": "ränta",
    "räntas": "ränta",
    "ränte": "ränta",
    "ränteavdragen": "ränteavdrag",
    "ränteavdragens": "ränteavdrag",
    "ränteavdraget": "ränteavdrag",
    "ränteavdragets": "ränteavdrag",
    "ränteavdrags": "ränteavdrag",
    "räntebeskeden": "räntebesked",
    "räntebeskedens": "räntebesked",
    "räntebeskedet": "räntebesked",
    "räntebeskedets": "räntebesked",
    "räntebeskeds": "räntebesked",
    "räntefoten": "räntefot",
    "räntefotens": "räntefot",
    "räntefots": "räntefot",
    "räntehöjningar": "räntehöjning",
    "räntehöjningarna": "räntehöjning",
    "räntehöjningarnas": "räntehöjning",
    "räntehöjningars": "räntehöjning",
    "räntehöjningen": "räntehöjning",
    "räntehöjningens": "räntehöjning",
    "räntehöjnings": "räntehöjning",
    "räntemarginalen": "räntemarginal",
    "räntemarginalens": "räntemarginal",
    "räntemarginaler": "räntemarginal",
    "räntemarginalerna": "räntemarginal",
    "räntemarginalernas": "räntemarginal",
    "räntemarginalers": "räntemarginal",
    "räntemarginals": "räntemarginal",
    "räntenivåer": "räntenivå",
    "räntenivåerna": "räntenivå",
    "räntenivåernas": "räntenivå",
    "räntenivåers": "räntenivå",
    "räntenivån": "räntenivå",
    "räntenivåns": "räntenivå",
    "räntenivås": "räntenivå",
    "räntesatsen": "räntesats",
    "räntesatsens": "räntesats",
    "räntesatser": "räntesats",
    "räntesatserna": "räntesats",
    "räntesatsernas": "räntesats",
    "räntesatsers": "räntesats",
    "ränteterminen": "räntetermin",
    "ränteterminens": "räntetermin",
    "ränteterminer": "räntetermin",
    "ränteterminerna": "räntetermin",
    "ränteterminernas": "räntetermin",
    "ränteterminers": "räntetermin",
    "räntetermins": "räntetermin",
    "räntmästar": "räntmästare",
    "räntmästaren": "räntmästare",
    "räntmästarens": "räntmästare",
    "räntmästares": "räntmästare",
    "räntmästarna": "räntmästare",
    "räntmästarnas": "räntmästare",
    "räntor": "ränta",
    "räntorna": "ränta",
    "räntornas": "ränta",
    "räntors": "ränta",
    "ränts": "ränna",
    "rät": "räta",
    "räta": "rät",
    "rätad": "räta",
    "rätade": "räta",
    "rätades": "räta",
    "rätads": "räta",
    "rätan": "räta",
    "rätande": "räta",
    "rätanden": "rätande",
    "rätandena": "rätande",
    "rätandenas": "rätande",
    "rätandens": "rätande",
    "rätandes": "rätande",
    "rätandet": "rätande",
    "rätandets": "rätande",
    "rätans": "räta",
    "rätar": "räta",
    "rätare": "rät",
    "rätares": "rät",
    "rätas": "räta",
    "rätast": "rät",
    "rätaste": "rät",
    "rätastes": "rät",
    "rätasts": "rät",
    "rätat": "räta",
    "rätats": "räta",
    "rätblocken": "rätblock",
    "rätblockens": "rätblock",
    "rätblocket": "rätblock",
    "rätblockets": "rätblock",
    "rätblocks": "rätblock",
    "räte": "rät",
    "rätes": "rät",
    "rätheten": "räthet",
    "räthetens": "räthet",
    "räthets": "räthet",
    "rätlinjiga": "rätlinjig",
    "rätlinjigare": "rätlinjig",
    "rätlinjigares": "rätlinjig",
    "rätlinjigas": "rätlinjig",
    "rätlinjigast": "rätlinjig",
    "rätlinjigaste": "rätlinjig",
    "rätlinjigastes": "rätlinjig",
    "rätlinjigasts": "rätlinjig",
    "rätlinjige": "rätlinjig",
    "rätlinjiges": "rätlinjig",
    "rätlinjigheten": "rätlinjighet",
    "rätlinjighetens": "rätlinjighet",
    "rätlinjighets": "rätlinjighet",
    "rätlinjigs": "rätlinjig",
    "rätlinjigt": "rätlinjig",
    "rätlinjigts": "rätlinjig",
    "rätoromansk": "rätoromanska",
    "rätoromanskan": "rätoromanska",
    "rätoromanskans": "rätoromanska",
    "rätoromanskas": "rätoromanska",
    "räts": "rät",
    "rätsidan": "rätsida",
    "rätsidans": "rätsida",
    "rätsidas": "rätsida",
    "rätside": "rätsida",
    "rätsides": "rätsida",
    "rätsidor": "rätsida",
    "rätsidorna": "rätsida",
    "rätsidornas": "rätsida",
    "rätsidors": "rätsida",
    "rätsteg": "rätstege",
    "rätstegar": "rätstege",
    "rätstegarna": "rätstege",
    "rätstegarnas": "rätstege",
    "rätstegars": "rätstege",
    "rätstegen": "rätstege",
    "rätstegens": "rätstege",
    "rätsteges": "rätstege",
    "rätstegs": "rätstege",
    "rätstickade": "rätstickad",
    "rätstickades": "rätstickad",
    "rätstickads": "rätstickad",
    "rätstickat": "rätstickad",
    "rätstickats": "rätstickad",
    "rätstickningar": "rätstickning",
    "rätstickningarna": "rätstickning",
    "rätstickningarnas": "rätstickning",
    "rätstickningars": "rätstickning",
    "rätstickningen": "rätstickning",
    "rätstickningens": "rätstickning",
    "rätsticknings": "rätstickning",
    "rätta": "rätt",
    "rättad": "rätta",
    "rättade": "rätta",
    "rättades": "rätta",
    "rättads": "rätta",
    "rättande": "rätta",
    "rättanden": "rättande",
    "rättandena": "rättande",
    "rättandenas": "rättande",
    "rättandens": "rättande",
    "rättandes": "rättande",
    "rättandet": "rättande",
    "rättandets": "rättande",
    "rättar": "rättare",
    "rättare": "rätt",
    "rättaren": "rättare",
    "rättarens": "rättare",
    "rättares": "rättare",
    "rättarna": "rättare",
    "rättarnas": "rättare",
    "rättas": "rätta",
    "rättast": "rätt",
    "rättaste": "rätt",
    "rättastes": "rätt",
    "rättasts": "rätt",
    "rättat": "rätta",
    "rättats": "rätta",
    "rätte": "rätta",
    "rättegångar": "rättegång",
    "rättegångarna": "rättegång",
    "rättegångarnas": "rättegång",
    "rättegångars": "rättegång",
    "rättegången": "rättegång",
    "rättegångens": "rättegång",
    "rättegångs": "rättegång",
    "rättegångsbiträden": "rättegångsbiträde",
    "rättegångsbiträdena": "rättegångsbiträde",
    "rättegångsbiträdenas": "rättegångsbiträde",
    "rättegångsbiträdens": "rättegångsbiträde",
    "rättegångsbiträdes": "rättegångsbiträde",
    "rättegångsbiträdet": "rättegångsbiträde",
    "rättegångsbiträdets": "rättegångsbiträde",
    "rättegångsfelen": "rättegångsfel",
    "rättegångsfelens": "rättegångsfel",
    "rättegångsfelet": "rättegångsfel",
    "rättegångsfelets": "rättegångsfel",
    "rättegångsfels": "rättegångsfel",
    "rättelsen": "rättelse",
    "rättelsens": "rättelse",
    "rättelser": "rättelse",
    "rättelserna": "rättelse",
    "rättelsernas": "rättelse",
    "rättelsers": "rättelse",
    "rättelses": "rättelse",
    "rätten": "rätt",
    "rättens": "rätt",
    "rätter": "rätt",
    "rätterna": "rätt",
    "rätternas": "rätt",
    "rätters": "rätt",
    "rättes": "rätt",
    "rättesnör": "rättesnöre",
    "rättesnören": "rättesnöre",
    "rättesnörena": "rättesnöre",
    "rättesnörenas": "rättesnöre",
    "rättesnörens": "rättesnöre",
    "rättesnöres": "rättesnöre",
    "rättesnöret": "rättesnöre",
    "rättesnörets": "rättesnöre",
    "rättesnörs": "rättesnöre",
    "rättframheten": "rättframhet",
    "rättframhetens": "rättframhet",
    "rättframheter": "rättframhet",
    "rättframheterna": "rättframhet",
    "rättframheternas": "rättframhet",
    "rättframheters": "rättframhet",
    "rättframhets": "rättframhet",
    "rättframma": "rättfram",
    "rättframmare": "rättfram",
    "rättframmares": "rättfram",
    "rättframmas": "rättfram",
    "rättframmast": "rättfram",
    "rättframmaste": "rättfram",
    "rättframmastes": "rättfram",
    "rättframmasts": "rättfram",
    "rättframme": "rättfram",
    "rättframmes": "rättfram",
    "rättframs": "rättfram",
    "rättframt": "rättfram",
    "rättframts": "rättfram",
    "rättfärdig": "rättfärdiga",
    "rättfärdiga": "rättfärdig",
    "rättfärdigad": "rättfärdiga",
    "rättfärdigade": "rättfärdiga",
    "rättfärdigades": "rättfärdiga",
    "rättfärdigads": "rättfärdiga",
    "rättfärdigande": "rättfärdiga",
    "rättfärdiganden": "rättfärdigande",
    "rättfärdigandena": "rättfärdigande",
    "rättfärdigandenas": "rättfärdigande",
    "rättfärdigandens": "rättfärdigande",
    "rättfärdigandes": "rättfärdigande",
    "rättfärdigandet": "rättfärdigande",
    "rättfärdigandets": "rättfärdigande",
    "rättfärdigar": "rättfärdiga",
    "rättfärdigare": "rättfärdig",
    "rättfärdigares": "rättfärdig",
    "rättfärdigas": "rättfärdiga",
    "rättfärdigast": "rättfärdig",
    "rättfärdigaste": "rättfärdig",
    "rättfärdigastes": "rättfärdig",
    "rättfärdigasts": "rättfärdig",
    "rättfärdigat": "rättfärdiga",
    "rättfärdigats": "rättfärdiga",
    "rättfärdige": "rättfärdig",
    "rättfärdiges": "rättfärdig",
    "rättfärdiggjord": "rättfärdiggöra",
    "rättfärdiggjorda": "rättfärdiggöra",
    "rättfärdiggjordas": "rättfärdiggöra",
    "rättfärdiggjorde": "rättfärdiggöra",
    "rättfärdiggjordes": "rättfärdiggöra",
    "rättfärdiggjords": "rättfärdiggöra",
    "rättfärdiggjort": "rättfärdiggöra",
    "rättfärdiggjorts": "rättfärdiggöra",
    "rättfärdiggör": "rättfärdiggöra",
    "rättfärdiggörande": "rättfärdiggöra",
    "rättfärdiggöranden": "rättfärdiggörande",
    "rättfärdiggörandena": "rättfärdiggörande",
    "rättfärdiggörandenas": "rättfärdiggörande",
    "rättfärdiggörandens": "rättfärdiggörande",
    "rättfärdiggörandes": "rättfärdiggörande",
    "rättfärdiggörandet": "rättfärdiggörande",
    "rättfärdiggörandets": "rättfärdiggörande",
    "rättfärdiggöras": "rättfärdiggöra",
    "rättfärdiggörelsen": "rättfärdiggörelse",
    "rättfärdiggörelsens": "rättfärdiggörelse",
    "rättfärdiggörelses": "rättfärdiggörelse",
    "rättfärdiggöres": "rättfärdiggöra",
    "rättfärdiggörs": "rättfärdiggöra",
    "rättfärdigheten": "rättfärdighet",
    "rättfärdighetens": "rättfärdighet",
    "rättfärdigheter": "rättfärdighet",
    "rättfärdigheterna": "rättfärdighet",
    "rättfärdigheternas": "rättfärdighet",
    "rättfärdigheters": "rättfärdighet",
    "rättfärdighets": "rättfärdighet",
    "rättfärdigs": "rättfärdig",
    "rättfärdigt": "rättfärdig",
    "rättfärdigts": "rättfärdig",
    "rättigheten": "rättighet",
    "rättighetens": "rättighet",
    "rättigheter": "rättighet",
    "rättigheterna": "rättighet",
    "rättigheternas": "rättighet",
    "rättigheters": "rättighet",
    "rättighets": "rättighet",
    "rättik": "rättika",
    "rättikan": "rättika",
    "rättikans": "rättika",
    "rättikas": "rättika",
    "rättike": "rättika",
    "rättikor": "rättika",
    "rättikorna": "rättika",
    "rättikornas": "rättika",
    "rättikors": "rättika",
    "rättiks": "rättika",
    "rättmätiga": "rättmätig",
    "rättmätigare": "rättmätig",
    "rättmätigares": "rättmätig",
    "rättmätigas": "rättmätig",
    "rättmätigast": "rättmätig",
    "rättmätigaste": "rättmätig",
    "rättmätigastes": "rättmätig",
    "rättmätigasts": "rättmätig",
    "rättmätige": "rättmätig",
    "rättmätiges": "rättmätig",
    "rättmätigheten": "rättmätighet",
    "rättmätighetens": "rättmätighet",
    "rättmätighets": "rättmätighet",
    "rättmätigs": "rättmätig",
    "rättmätigt": "rättmätig",
    "rättmätigts": "rättmätig",
    "rättningar": "rättning",
    "rättningarna": "rättning",
    "rättningarnas": "rättning",
    "rättningars": "rättning",
    "rättningen": "rättning",
    "rättningens": "rättning",
    "rättnings": "rättning",
    "rättrogens": "rättrogen",
    "rättroget": "rättrogen",
    "rättrogets": "rättrogen",
    "rättrogna": "rättrogen",
    "rättrognare": "rättrogen",
    "rättrognares": "rättrogen",
    "rättrognas": "rättrogen",
    "rättrognast": "rättrogen",
    "rättrognaste": "rättrogen",
    "rättrognastes": "rättrogen",
    "rättrognasts": "rättrogen",
    "rättrogne": "rättrogen",
    "rättrognes": "rättrogen",
    "rättrådiga": "rättrådig",
    "rättrådigare": "rättrådig",
    "rättrådigares": "rättrådig",
    "rättrådigas": "rättrådig",
    "rättrådigast": "rättrådig",
    "rättrådigaste": "rättrådig",
    "rättrådigastes": "rättrådig",
    "rättrådigasts": "rättrådig",
    "rättrådige": "rättrådig",
    "rättrådiges": "rättrådig",
    "rättrådigheten": "rättrådighet",
    "rättrådighetens": "rättrådighet",
    "rättrådighets": "rättrådighet",
    "rättrådigs": "rättrådig",
    "rättrådigt": "rättrådig",
    "rättrådigts": "rättrådig",
    "rätts": "rätt",
    "rättschefen": "rättschef",
    "rättschefens": "rättschef",
    "rättschefer": "rättschef",
    "rättscheferna": "rättschef",
    "rättschefernas": "rättschef",
    "rättschefers": "rättschef",
    "rättschefs": "rättschef",
    "rättsenliga": "rättsenlig",
    "rättsenligare": "rättsenlig",
    "rättsenligares": "rättsenlig",
    "rättsenligas": "rättsenlig",
    "rättsenligast": "rättsenlig",
    "rättsenligaste": "rättsenlig",
    "rättsenligastes": "rättsenlig",
    "rättsenligasts": "rättsenlig",
    "rättsenlige": "rättsenlig",
    "rättsenliges": "rättsenlig",
    "rättsenligheten": "rättsenlighet",
    "rättsenlighetens": "rättsenlighet",
    "rättsenlighets": "rättsenlighet",
    "rättsenligs": "rättsenlig",
    "rättsenligt": "rättsenlig",
    "rättsenligts": "rättsenlig",
    "rättsfallen": "rättsfall",
    "rättsfallens": "rättsfall",
    "rättsfallet": "rättsfall",
    "rättsfallets": "rättsfall",
    "rättsfalls": "rättsfall",
    "rättsfilosofien": "rättsfilosofi",
    "rättsfilosofiens": "rättsfilosofi",
    "rättsfilosofin": "rättsfilosofi",
    "rättsfilosofins": "rättsfilosofi",
    "rättsfilosofis": "rättsfilosofi",
    "rättsförmågan": "rättsförmåga",
    "rättsförmågans": "rättsförmåga",
    "rättsförmågas": "rättsförmåga",
    "rättsförmåge": "rättsförmåga",
    "rättshaveriet": "rättshaveri",
    "rättshaveriets": "rättshaveri",
    "rättshaveris": "rättshaveri",
    "rättshaveristen": "rättshaverist",
    "rättshaveristens": "rättshaverist",
    "rättshaverister": "rättshaverist",
    "rättshaveristerna": "rättshaverist",
    "rättshaveristernas": "rättshaverist",
    "rättshaveristers": "rättshaverist",
    "rättshaverists": "rättshaverist",
    "rättshaverit": "rättshaveri",
    "rättshaverits": "rättshaveri",
    "rättshjälpen": "rättshjälp",
    "rättshjälpens": "rättshjälp",
    "rättshjälps": "rättshjälp",
    "rättshjälpskontoren": "rättshjälpskontor",
    "rättshjälpskontorens": "rättshjälpskontor",
    "rättshjälpskontoret": "rättshjälpskontor",
    "rättshjälpskontorets": "rättshjälpskontor",
    "rättshjälpskontors": "rättshjälpskontor",
    "rättsinformationen": "rättsinformation",
    "rättsinformationens": "rättsinformation",
    "rättsinformationer": "rättsinformation",
    "rättsinformationerna": "rättsinformation",
    "rättsinformationernas": "rättsinformation",
    "rättsinformationers": "rättsinformation",
    "rättsinformations": "rättsinformation",
    "rättsinnade": "rättsinnad",
    "rättsinnades": "rättsinnad",
    "rättsinnads": "rättsinnad",
    "rättsinnat": "rättsinnad",
    "rättsinnats": "rättsinnad",
    "rättsinniga": "rättsinnig",
    "rättsinnigare": "rättsinnig",
    "rättsinnigares": "rättsinnig",
    "rättsinnigas": "rättsinnig",
    "rättsinnigast": "rättsinnig",
    "rättsinnigaste": "rättsinnig",
    "rättsinnigastes": "rättsinnig",
    "rättsinnigasts": "rättsinnig",
    "rättsinnige": "rättsinnig",
    "rättsinniges": "rättsinnig",
    "rättsinnigheten": "rättsinnighet",
    "rättsinnighetens": "rättsinnighet",
    "rättsinnighets": "rättsinnighet",
    "rättsinnigs": "rättsinnig",
    "rättsinnigt": "rättsinnig",
    "rättsinnigts": "rättsinnig",
    "rättskapaciteten": "rättskapacitet",
    "rättskapacitetens": "rättskapacitet",
    "rättskapaciteter": "rättskapacitet",
    "rättskapaciteterna": "rättskapacitet",
    "rättskapaciteternas": "rättskapacitet",
    "rättskapaciteters": "rättskapacitet",
    "rättskapacitets": "rättskapacitet",
    "rättskemien": "rättskemi",
    "rättskemiens": "rättskemi",
    "rättskemin": "rättskemi",
    "rättskemins": "rättskemi",
    "rättskemis": "rättskemi",
    "rättskipningar": "rättskipning",
    "rättskipningarna": "rättskipning",
    "rättskipningarnas": "rättskipning",
    "rättskipningars": "rättskipning",
    "rättskipningen": "rättskipning",
    "rättskipningens": "rättskipning",
    "rättskipnings": "rättskipning",
    "rättskrivningar": "rättskrivning",
    "rättskrivningarna": "rättskrivning",
    "rättskrivningarnas": "rättskrivning",
    "rättskrivningars": "rättskrivning",
    "rättskrivningen": "rättskrivning",
    "rättskrivningens": "rättskrivning",
    "rättskrivnings": "rättskrivning",
    "rättskänslan": "rättskänsla",
    "rättskänslans": "rättskänsla",
    "rättskänslas": "rättskänsla",
    "rättskänsle": "rättskänsla",
    "rättskänslo": "rättskänsla",
    "rättsliga": "rättslig",
    "rättsligare": "rättslig",
    "rättsligares": "rättslig",
    "rättsligas": "rättslig",
    "rättsligast": "rättslig",
    "rättsligaste": "rättslig",
    "rättsligastes": "rättslig",
    "rättsligasts": "rättslig",
    "rättslige": "rättslig",
    "rättsliges": "rättslig",
    "rättsligheten": "rättslighet",
    "rättslighetens": "rättslighet",
    "rättslighets": "rättslighet",
    "rättsligs": "rättslig",
    "rättsligt": "rättslig",
    "rättsligts": "rättslig",
    "rättslägen": "rättsläge",
    "rättslägena": "rättsläge",
    "rättslägenas": "rättsläge",
    "rättslägens": "rättsläge",
    "rättsläges": "rättsläge",
    "rättsläget": "rättsläge",
    "rättslägets": "rättsläge",
    "rättsläkar": "rättsläkare",
    "rättsläkaren": "rättsläkare",
    "rättsläkarens": "rättsläkare",
    "rättsläkares": "rättsläkare",
    "rättsläkarna": "rättsläkare",
    "rättsläkarnas": "rättsläkare",
    "rättslösa": "rättslös",
    "rättslösare": "rättslös",
    "rättslösares": "rättslös",
    "rättslösas": "rättslös",
    "rättslösast": "rättslös",
    "rättslösaste": "rättslös",
    "rättslösastes": "rättslös",
    "rättslösasts": "rättslös",
    "rättslöse": "rättslös",
    "rättslöses": "rättslös",
    "rättslösheten": "rättslöshet",
    "rättslöshetens": "rättslöshet",
    "rättslöshets": "rättslöshet",
    "rättslöst": "rättslös",
    "rättslösts": "rättslös",
    "rättsmedicinalverket": "rättsmedicinalverk",
    "rättsmedicinalverkets": "rättsmedicinalverk",
    "rättsmedicinalverks": "rättsmedicinalverk",
    "rättsmedicinen": "rättsmedicin",
    "rättsmedicinens": "rättsmedicin",
    "rättsmedicins": "rättsmedicin",
    "rättsmedicinska": "rättsmedicinsk",
    "rättsmedicinskare": "rättsmedicinsk",
    "rättsmedicinskares": "rättsmedicinsk",
    "rättsmedicinskas": "rättsmedicinsk",
    "rättsmedicinskast": "rättsmedicinsk",
    "rättsmedicinskaste": "rättsmedicinsk",
    "rättsmedicinskastes": "rättsmedicinsk",
    "rättsmedicinskasts": "rättsmedicinsk",
    "rättsmedicinske": "rättsmedicinsk",
    "rättsmedicinskes": "rättsmedicinsk",
    "rättsmedicinsks": "rättsmedicinsk",
    "rättsmedicinskt": "rättsmedicinsk",
    "rättsmedicinskts": "rättsmedicinsk",
    "rättsordningar": "rättsordning",
    "rättsordningarna": "rättsordning",
    "rättsordningarnas": "rättsordning",
    "rättsordningars": "rättsordning",
    "rättsordningen": "rättsordning",
    "rättsordningens": "rättsordning",
    "rättsordnings": "rättsordning",
    "rättspolitiken": "rättspolitik",
    "rättspolitikens": "rättspolitik",
    "rättspolitiks": "rättspolitik",
    "rättspolitiska": "rättspolitisk",
    "rättspolitiskas": "rättspolitisk",
    "rättspolitiske": "rättspolitisk",
    "rättspolitiskes": "rättspolitisk",
    "rättspolitisks": "rättspolitisk",
    "rättspolitiskt": "rättspolitisk",
    "rättspolitiskts": "rättspolitisk",
    "rättsprincipen": "rättsprincip",
    "rättsprincipens": "rättsprincip",
    "rättsprinciper": "rättsprincip",
    "rättsprinciperna": "rättsprincip",
    "rättsprincipernas": "rättsprincip",
    "rättsprincipers": "rättsprincip",
    "rättsprincips": "rättsprincip",
    "rättspsykiatrien": "rättspsykiatri",
    "rättspsykiatriens": "rättspsykiatri",
    "rättspsykiatrikern": "rättspsykiatriker",
    "rättspsykiatrikerna": "rättspsykiatriker",
    "rättspsykiatrikernas": "rättspsykiatriker",
    "rättspsykiatrikerns": "rättspsykiatriker",
    "rättspsykiatrikers": "rättspsykiatriker",
    "rättspsykiatrin": "rättspsykiatri",
    "rättspsykiatrins": "rättspsykiatri",
    "rättspsykiatris": "rättspsykiatri",
    "rättspsykiatriska": "rättspsykiatrisk",
    "rättspsykiatriskare": "rättspsykiatrisk",
    "rättspsykiatriskares": "rättspsykiatrisk",
    "rättspsykiatriskas": "rättspsykiatrisk",
    "rättspsykiatriskast": "rättspsykiatrisk",
    "rättspsykiatriskaste": "rättspsykiatrisk",
    "rättspsykiatriskastes": "rättspsykiatrisk",
    "rättspsykiatriskasts": "rättspsykiatrisk",
    "rättspsykiatriske": "rättspsykiatrisk",
    "rättspsykiatriskes": "rättspsykiatrisk",
    "rättspsykiatrisks": "rättspsykiatrisk",
    "rättspsykiatriskt": "rättspsykiatrisk",
    "rättspsykiatriskts": "rättspsykiatrisk",
    "rättspåföljden": "rättspåföljd",
    "rättspåföljdens": "rättspåföljd",
    "rättspåföljder": "rättspåföljd",
    "rättspåföljderna": "rättspåföljd",
    "rättspåföljdernas": "rättspåföljd",
    "rättspåföljders": "rättspåföljd",
    "rättspåföljds": "rättspåföljd",
    "rättsregeln": "rättsregel",
    "rättsregelns": "rättsregel",
    "rättsregels": "rättsregel",
    "rättsregler": "rättsregel",
    "rättsreglerna": "rättsregel",
    "rättsreglernas": "rättsregel",
    "rättsreglers": "rättsregel",
    "rättsrötan": "rättsröta",
    "rättsrötans": "rättsröta",
    "rättsrötas": "rättsröta",
    "rättsröte": "rättsröta",
    "rättsrötor": "rättsröta",
    "rättsrötorna": "rättsröta",
    "rättsrötornas": "rättsröta",
    "rättsrötors": "rättsröta",
    "rättssaken": "rättssak",
    "rättssakens": "rättssak",
    "rättssaker": "rättssak",
    "rättssakerna": "rättssak",
    "rättssakernas": "rättssak",
    "rättssakers": "rättssak",
    "rättssaks": "rättssak",
    "rättssalar": "rättssal",
    "rättssalarna": "rättssal",
    "rättssalarnas": "rättssal",
    "rättssalars": "rättssal",
    "rättssalen": "rättssal",
    "rättssalens": "rättssal",
    "rättssals": "rättssal",
    "rättssamhällen": "rättssamhälle",
    "rättssamhällena": "rättssamhälle",
    "rättssamhällenas": "rättssamhälle",
    "rättssamhällens": "rättssamhälle",
    "rättssamhälles": "rättssamhälle",
    "rättssamhället": "rättssamhälle",
    "rättssamhällets": "rättssamhälle",
    "rättssamhälls": "rättssamhälle",
    "rättsskipningar": "rättsskipning",
    "rättsskipningarna": "rättsskipning",
    "rättsskipningarnas": "rättsskipning",
    "rättsskipningars": "rättsskipning",
    "rättsskipningen": "rättsskipning",
    "rättsskipningens": "rättsskipning",
    "rättsskipnings": "rättsskipning",
    "rättsstaten": "rättsstat",
    "rättsstatens": "rättsstat",
    "rättsstater": "rättsstat",
    "rättsstaterna": "rättsstat",
    "rättsstaternas": "rättsstat",
    "rättsstaters": "rättsstat",
    "rättsstats": "rättsstat",
    "rättsstridiga": "rättsstridig",
    "rättsstridigare": "rättsstridig",
    "rättsstridigares": "rättsstridig",
    "rättsstridigas": "rättsstridig",
    "rättsstridigast": "rättsstridig",
    "rättsstridigaste": "rättsstridig",
    "rättsstridigastes": "rättsstridig",
    "rättsstridigasts": "rättsstridig",
    "rättsstridige": "rättsstridig",
    "rättsstridiges": "rättsstridig",
    "rättsstridigheten": "rättsstridighet",
    "rättsstridighetens": "rättsstridighet",
    "rättsstridighets": "rättsstridighet",
    "rättsstridigs": "rättsstridig",
    "rättsstridigt": "rättsstridig",
    "rättsstridigts": "rättsstridig",
    "rättssubjekten": "rättssubjekt",
    "rättssubjektens": "rättssubjekt",
    "rättssubjektet": "rättssubjekt",
    "rättssubjektets": "rättssubjekt",
    "rättssubjekts": "rättssubjekt",
    "rättssystemen": "rättssystem",
    "rättssystemens": "rättssystem",
    "rättssystemet": "rättssystem",
    "rättssystemets": "rättssystem",
    "rättssystems": "rättssystem",
    "rättssäkerheten": "rättssäkerhet",
    "rättssäkerhetens": "rättssäkerhet",
    "rättssäkerheter": "rättssäkerhet",
    "rättssäkerheterna": "rättssäkerhet",
    "rättssäkerheternas": "rättssäkerhet",
    "rättssäkerheters": "rättssäkerhet",
    "rättssäkerhets": "rättssäkerhet",
    "rättstavningar": "rättstavning",
    "rättstavningarna": "rättstavning",
    "rättstavningarnas": "rättstavning",
    "rättstavningars": "rättstavning",
    "rättstavningen": "rättstavning",
    "rättstavningens": "rättstavning",
    "rättstavnings": "rättstavning",
    "rättstvisten": "rättstvist",
    "rättstvistens": "rättstvist",
    "rättstvister": "rättstvist",
    "rättstvisterna": "rättstvist",
    "rättstvisternas": "rättstvist",
    "rättstvisters": "rättstvist",
    "rättstvists": "rättstvist",
    "rättsuppfattningar": "rättsuppfattning",
    "rättsuppfattningarna": "rättsuppfattning",
    "rättsuppfattningarnas": "rättsuppfattning",
    "rättsuppfattningars": "rättsuppfattning",
    "rättsuppfattningen": "rättsuppfattning",
    "rättsuppfattningens": "rättsuppfattning",
    "rättsuppfattnings": "rättsuppfattning",
    "rättsvetenskapen": "rättsvetenskap",
    "rättsvetenskapens": "rättsvetenskap",
    "rättsvetenskaps": "rättsvetenskap",
    "rättsvidriga": "rättsvidrig",
    "rättsvidrigare": "rättsvidrig",
    "rättsvidrigares": "rättsvidrig",
    "rättsvidrigas": "rättsvidrig",
    "rättsvidrigast": "rättsvidrig",
    "rättsvidrigaste": "rättsvidrig",
    "rättsvidrigastes": "rättsvidrig",
    "rättsvidrigasts": "rättsvidrig",
    "rättsvidrige": "rättsvidrig",
    "rättsvidriges": "rättsvidrig",
    "rättsvidrigheten": "rättsvidrighet",
    "rättsvidrighetens": "rättsvidrighet",
    "rättsvidrighets": "rättsvidrighet",
    "rättsvidrigs": "rättsvidrig",
    "rättsvidrigt": "rättsvidrig",
    "rättsvidrigts": "rättsvidrig",
    "rättsväsenden": "rättsväsende",
    "rättsväsendena": "rättsväsende",
    "rättsväsendenas": "rättsväsende",
    "rättsväsendens": "rättsväsende",
    "rättsväsendes": "rättsväsende",
    "rättsväsendet": "rättsväsende",
    "rättsväsendets": "rättsväsende",
    "rättsväsenet": "rättsväsen",
    "rättsväsenets": "rättsväsen",
    "rättsväsens": "rättsväsen",
    "rättvisa": "rättvis",
    "rättvisan": "rättvisa",
    "rättvisans": "rättvisa",
    "rättvisare": "rättvis",
    "rättvisares": "rättvis",
    "rättvisas": "rättvisa",
    "rättvisast": "rättvis",
    "rättvisaste": "rättvis",
    "rättvisastes": "rättvis",
    "rättvisasts": "rättvis",
    "rättvise": "rättvisa",
    "rättviseidealen": "rättviseideal",
    "rättviseidealens": "rättviseideal",
    "rättviseidealet": "rättviseideal",
    "rättviseidealets": "rättviseideal",
    "rättviseideals": "rättviseideal",
    "rättvisemässiga": "rättvisemässig",
    "rättvisemässigare": "rättvisemässig",
    "rättvisemässigares": "rättvisemässig",
    "rättvisemässigas": "rättvisemässig",
    "rättvisemässigast": "rättvisemässig",
    "rättvisemässigaste": "rättvisemässig",
    "rättvisemässigastes": "rättvisemässig",
    "rättvisemässigasts": "rättvisemässig",
    "rättvisemässige": "rättvisemässig",
    "rättvisemässiges": "rättvisemässig",
    "rättvisemässigs": "rättvisemässig",
    "rättvisemässigt": "rättvisemässig",
    "rättvisemässigts": "rättvisemässig",
    "rättvisepatoset": "rättvisepatos",
    "rättvisepatosets": "rättvisepatos",
    "rättvises": "rättvis",
    "rättvisor": "rättvisa",
    "rättvisorna": "rättvisa",
    "rättvisornas": "rättvisa",
    "rättvisors": "rättvisa",
    "rättvist": "rättvis",
    "rättvists": "rättvis",
    "rätving": "rätvinge",
    "rätvingar": "rätvinge",
    "rätvingarna": "rätvinge",
    "rätvingarnas": "rätvinge",
    "rätvingars": "rätvinge",
    "rätvingen": "rätvinge",
    "rätvingens": "rätvinge",
    "rätvinges": "rätvinge",
    "rätvings": "rätvinge",
    "rätvinkliga": "rätvinklig",
    "rätvinkligare": "rätvinklig",
    "rätvinkligares": "rätvinklig",
    "rätvinkligas": "rätvinklig",
    "rätvinkligast": "rätvinklig",
    "rätvinkligaste": "rätvinklig",
    "rätvinkligastes": "rätvinklig",
    "rätvinkligasts": "rätvinklig",
    "rätvinklige": "rätvinklig",
    "rätvinkliges": "rätvinklig",
    "rätvinkligheten": "rätvinklighet",
    "rätvinklighetens": "rätvinklighet",
    "rätvinklighets": "rätvinklighet",
    "rätvinkligs": "rätvinklig",
    "rätvinkligt": "rätvinklig",
    "rätvinkligts": "rätvinklig",
    "rävar": "räv",
    "rävarna": "räv",
    "rävarnas": "räv",
    "rävars": "räv",
    "räven": "räv",
    "rävens": "räv",
    "rävfarmar": "rävfarm",
    "rävfarmarna": "rävfarm",
    "rävfarmarnas": "rävfarm",
    "rävfarmars": "rävfarm",
    "rävfarmen": "rävfarm",
    "rävfarmens": "rävfarm",
    "rävfarms": "rävfarm",
    "rävgiftet": "rävgift",
    "rävgiftets": "rävgift",
    "rävgifts": "rävgift",
    "rävhundar": "rävhund",
    "rävhundarna": "rävhund",
    "rävhundarnas": "rävhund",
    "rävhundars": "rävhund",
    "rävhunden": "rävhund",
    "rävhundens": "rävhund",
    "rävhunds": "rävhund",
    "rävjakten": "rävjakt",
    "rävjaktens": "rävjakt",
    "rävjakter": "rävjakt",
    "rävjakterna": "rävjakt",
    "rävjakternas": "rävjakt",
    "rävjakters": "rävjakt",
    "rävjakts": "rävjakt",
    "rävpälsar": "rävpäls",
    "rävpälsarna": "rävpäls",
    "rävpälsarnas": "rävpäls",
    "rävpälsars": "rävpäls",
    "rävpälsen": "rävpäls",
    "rävpälsens": "rävpäls",
    "rävrump": "rävrumpa",
    "rävrumpan": "rävrumpa",
    "rävrumpans": "rävrumpa",
    "rävrumpas": "rävrumpa",
    "rävrumpe": "rävrumpa",
    "rävrumpor": "rävrumpa",
    "rävrumporna": "rävrumpa",
    "rävrumpornas": "rävrumpa",
    "rävrumpors": "rävrumpa",
    "rävrumps": "rävrumpa",
    "rävs": "räv",
    "rävsaxar": "rävsax",
    "rävsaxarna": "rävsax",
    "rävsaxarnas": "rävsax",
    "rävsaxars": "rävsax",
    "rävsaxen": "rävsax",
    "rävsaxens": "rävsax",
    "rävspelen": "rävspel",
    "rävspelens": "rävspel",
    "rävspelet": "rävspel",
    "rävspelets": "rävspel",
    "rävspels": "rävspel",
    "rävsvansar": "rävsvans",
    "rävsvansarna": "rävsvans",
    "rävsvansarnas": "rävsvans",
    "rävsvansars": "rävsvans",
    "rävsvansen": "rävsvans",
    "rävsvansens": "rävsvans",
    "råa": "rå",
    "råare": "rå",
    "råares": "rå",
    "råas": "rå",
    "råast": "rå",
    "råaste": "rå",
    "råastes": "rå",
    "råasts": "rå",
    "råbanden": "råband",
    "råbandens": "råband",
    "råbandet": "råband",
    "råbandets": "råband",
    "råbands": "råband",
    "råbandsknopar": "råbandsknop",
    "råbandsknoparna": "råbandsknop",
    "råbandsknoparnas": "råbandsknop",
    "råbandsknopars": "råbandsknop",
    "råbandsknopen": "råbandsknop",
    "råbandsknopens": "råbandsknop",
    "råbandsknops": "råbandsknop",
    "råbarkade": "råbarkad",
    "råbarkades": "råbarkad",
    "råbarkads": "råbarkad",
    "råbarkat": "råbarkad",
    "råbarkats": "råbarkad",
    "råbiffar": "råbiff",
    "råbiffarna": "råbiff",
    "råbiffarnas": "råbiff",
    "råbiffars": "råbiff",
    "råbiffen": "råbiff",
    "råbiffens": "råbiff",
    "råbiffs": "råbiff",
    "råbockar": "råbock",
    "råbockarna": "råbock",
    "råbockarnas": "råbock",
    "råbockars": "råbock",
    "råbocken": "råbock",
    "råbockens": "råbock",
    "råbocks": "råbock",
    "råd": "råda",
    "råda": "rå",
    "rådande": "råda",
    "rådanden": "rådande",
    "rådandena": "rådande",
    "rådandenas": "rådande",
    "rådandens": "rådande",
    "rådandes": "rådande",
    "rådandet": "rådande",
    "rådandets": "rådande",
    "rådas": "råda",
    "rådbråk": "rådbråka",
    "rådbråkad": "rådbråka",
    "rådbråkade": "rådbråka",
    "rådbråkades": "rådbråka",
    "rådbråkads": "rådbråka",
    "rådbråkande": "rådbråka",
    "rådbråkanden": "rådbråkande",
    "rådbråkandena": "rådbråkande",
    "rådbråkandenas": "rådbråkande",
    "rådbråkandens": "rådbråkande",
    "rådbråkandes": "rådbråkande",
    "rådbråkandet": "rådbråkande",
    "rådbråkandets": "rådbråkande",
    "rådbråkar": "rådbråka",
    "rådbråkas": "rådbråka",
    "rådbråkat": "rådbråka",
    "rådbråkats": "rådbråka",
    "rådd": "råda",
    "rådda": "råda",
    "råddas": "råda",
    "rådde": "råda",
    "råddes": "råda",
    "råddiga": "råddig",
    "råddigare": "råddig",
    "råddigares": "råddig",
    "råddigas": "råddig",
    "råddigast": "råddig",
    "råddigaste": "råddig",
    "råddigastes": "råddig",
    "råddigasts": "råddig",
    "råddige": "råddig",
    "råddiges": "råddig",
    "råddigheten": "råddighet",
    "råddighetens": "råddighet",
    "råddighets": "råddighet",
    "råddigs": "råddig",
    "råddigt": "råddig",
    "råddigts": "råddig",
    "rådds": "råda",
    "råden": "råd",
    "rådens": "råd",
    "råder": "råda",
    "rådes": "råda",
    "rådet": "råd",
    "rådets": "råd",
    "rådfråg": "rådfråga",
    "rådfrågad": "rådfråga",
    "rådfrågade": "rådfråga",
    "rådfrågades": "rådfråga",
    "rådfrågads": "rådfråga",
    "rådfrågande": "rådfråga",
    "rådfråganden": "rådfrågande",
    "rådfrågandena": "rådfrågande",
    "rådfrågandenas": "rådfrågande",
    "rådfrågandens": "rådfrågande",
    "rådfrågandes": "rådfrågande",
    "rådfrågandet": "rådfrågande",
    "rådfrågandets": "rådfrågande",
    "rådfrågar": "rådfråga",
    "rådfrågas": "rådfråga",
    "rådfrågat": "rådfråga",
    "rådfrågats": "rådfråga",
    "rådfrågningar": "rådfrågning",
    "rådfrågningarna": "rådfrågning",
    "rådfrågningarnas": "rådfrågning",
    "rådfrågningars": "rådfrågning",
    "rådfrågningen": "rådfrågning",
    "rådfrågningens": "rådfrågning",
    "rådfrågnings": "rådfrågning",
    "rådför": "rådföra",
    "rådförande": "rådföra",
    "rådföranden": "rådförande",
    "rådförandena": "rådförande",
    "rådförandenas": "rådförande",
    "rådförandens": "rådförande",
    "rådförandes": "rådförande",
    "rådförandet": "rådförande",
    "rådförandets": "rådförande",
    "rådföras": "rådföra",
    "rådförd": "rådföra",
    "rådförda": "rådföra",
    "rådfördas": "rådföra",
    "rådförde": "rådföra",
    "rådfördes": "rådföra",
    "rådförds": "rådföra",
    "rådföres": "rådföra",
    "rådförs": "rådföra",
    "rådfört": "rådföra",
    "rådförts": "rådföra",
    "rådgivar": "rådgivare",
    "rådgivaren": "rådgivare",
    "rådgivarens": "rådgivare",
    "rådgivares": "rådgivare",
    "rådgivarna": "rådgivare",
    "rådgivarnas": "rådgivare",
    "rådgivningar": "rådgivning",
    "rådgivningarna": "rådgivning",
    "rådgivningarnas": "rådgivning",
    "rådgivningars": "rådgivning",
    "rådgivningen": "rådgivning",
    "rådgivningens": "rådgivning",
    "rådgivnings": "rådgivning",
    "rådgjord": "rådgöra",
    "rådgjorda": "rådgöra",
    "rådgjordas": "rådgöra",
    "rådgjorde": "rådgöra",
    "rådgjordes": "rådgöra",
    "rådgjords": "rådgöra",
    "rådgjort": "rådgöra",
    "rådgjorts": "rådgöra",
    "rådgör": "rådgöra",
    "rådgörande": "rådgöra",
    "rådgöranden": "rådgörande",
    "rådgörandena": "rådgörande",
    "rådgörandenas": "rådgörande",
    "rådgörandens": "rådgörande",
    "rådgörandes": "rådgörande",
    "rådgörandet": "rådgörande",
    "rådgörandets": "rådgörande",
    "rådgöras": "rådgöra",
    "rådgöres": "rådgöra",
    "rådgörs": "rådgöra",
    "rådhusen": "rådhus",
    "rådhusens": "rådhus",
    "rådhuset": "rådhus",
    "rådhusets": "rådhus",
    "rådhuskällar": "rådhuskällare",
    "rådhuskällaren": "rådhuskällare",
    "rådhuskällarens": "rådhuskällare",
    "rådhuskällares": "rådhuskällare",
    "rådhuskällarna": "rådhuskällare",
    "rådhuskällarnas": "rådhuskällare",
    "rådhusrätten": "rådhusrätt",
    "rådhusrättens": "rådhusrätt",
    "rådhusrätter": "rådhusrätt",
    "rådhusrätterna": "rådhusrätt",
    "rådhusrätternas": "rådhusrätt",
    "rådhusrätters": "rådhusrätt",
    "rådhusrätts": "rådhusrätt",
    "rådiga": "rådig",
    "rådigare": "rådig",
    "rådigares": "rådig",
    "rådigas": "rådig",
    "rådigast": "rådig",
    "rådigaste": "rådig",
    "rådigastes": "rådig",
    "rådigasts": "rådig",
    "rådige": "rådig",
    "rådiges": "rådig",
    "rådigs": "rådig",
    "rådigt": "rådig",
    "rådigts": "rådig",
    "rådjuren": "rådjur",
    "rådjurens": "rådjur",
    "rådjuret": "rådjur",
    "rådjurets": "rådjur",
    "rådjurs": "rådjur",
    "rådjursjakten": "rådjursjakt",
    "rådjursjaktens": "rådjursjakt",
    "rådjursjakts": "rådjursjakt",
    "rådjurssadeln": "rådjurssadel",
    "rådjurssadelns": "rådjurssadel",
    "rådjurssadels": "rådjurssadel",
    "rådjurssadlar": "rådjurssadel",
    "rådjurssadlarna": "rådjurssadel",
    "rådjurssadlarnas": "rådjurssadel",
    "rådjurssadlars": "rådjurssadel",
    "rådla": "rådlägga",
    "rådlade": "rådlägga",
    "rådlades": "rådlägga",
    "rådlagd": "rådlägga",
    "rådlagda": "rådlägga",
    "rådlagdas": "rådlägga",
    "rådlagde": "rådlägga",
    "rådlagdes": "rådlägga",
    "rådlagds": "rådlägga",
    "rådlagt": "rådlägga",
    "rådlagts": "rådlägga",
    "rådlas": "rådlägga",
    "rådliga": "rådlig",
    "rådligare": "rådlig",
    "rådligares": "rådlig",
    "rådligas": "rådlig",
    "rådligast": "rådlig",
    "rådligaste": "rådlig",
    "rådligastes": "rådlig",
    "rådligasts": "rådlig",
    "rådlige": "rådlig",
    "rådliges": "rådlig",
    "rådligheten": "rådlighet",
    "rådlighetens": "rådlighet",
    "rådlighets": "rådlighet",
    "rådligs": "rådlig",
    "rådligt": "rådlig",
    "rådligts": "rådlig",
    "rådlägg": "rådlägga",
    "rådläggande": "rådlägga",
    "rådlägganden": "rådläggande",
    "rådläggandena": "rådläggande",
    "rådläggandenas": "rådläggande",
    "rådläggandens": "rådläggande",
    "rådläggandes": "rådläggande",
    "rådläggandet": "rådläggande",
    "rådläggandets": "rådläggande",
    "rådläggas": "rådlägga",
    "rådlägger": "rådlägga",
    "rådlägges": "rådlägga",
    "rådläggs": "rådlägga",
    "rådlösa": "rådlös",
    "rådlösare": "rådlös",
    "rådlösares": "rådlös",
    "rådlösas": "rådlös",
    "rådlösast": "rådlös",
    "rådlösaste": "rådlös",
    "rådlösastes": "rådlös",
    "rådlösasts": "rådlös",
    "rådlöse": "rådlös",
    "rådlöses": "rådlös",
    "rådlösheten": "rådlöshet",
    "rådlöshetens": "rådlöshet",
    "rådlöshets": "rådlöshet",
    "rådlöst": "rådlös",
    "rådlösts": "rådlös",
    "rådmannen": "rådman",
    "rådmannens": "rådman",
    "rådmans": "rådman",
    "rådmän": "rådman",
    "rådmännen": "rådman",
    "rådmännens": "rådman",
    "rådmäns": "rådman",
    "rådpläg": "rådpläga",
    "rådplägad": "rådpläga",
    "rådplägade": "rådpläga",
    "rådplägades": "rådpläga",
    "rådplägads": "rådpläga",
    "rådplägande": "rådpläga",
    "rådpläganden": "rådplägande",
    "rådplägandena": "rådplägande",
    "rådplägandenas": "rådplägande",
    "rådplägandens": "rådplägande",
    "rådplägandes": "rådplägande",
    "rådplägandet": "rådplägande",
    "rådplägandets": "rådplägande",
    "rådplägar": "rådpläga",
    "rådplägas": "rådpläga",
    "rådplägat": "rådpläga",
    "rådplägats": "rådpläga",
    "rådplägningar": "rådplägning",
    "rådplägningarna": "rådplägning",
    "rådplägningarnas": "rådplägning",
    "rådplägningars": "rådplägning",
    "rådplägningen": "rådplägning",
    "rådplägningens": "rådplägning",
    "rådplägnings": "rådplägning",
    "rådrummet": "rådrum",
    "rådrummets": "rådrum",
    "rådrums": "rådrum",
    "råds": "råda",
    "rådslagen": "rådslag",
    "rådslagens": "rådslag",
    "rådslaget": "rådslag",
    "rådslagets": "rådslag",
    "rådslagit": "rådslå",
    "rådslagits": "rådslå",
    "rådslags": "rådslag",
    "rådsloe": "rådslå",
    "rådsloes": "rådslå",
    "rådslog": "rådslå",
    "rådslogs": "rådslå",
    "rådslående": "rådslå",
    "rådslåenden": "rådslående",
    "rådslåendena": "rådslående",
    "rådslåendenas": "rådslående",
    "rådslåendens": "rådslående",
    "rådslåendes": "rådslående",
    "rådslåendet": "rådslående",
    "rådslåendets": "rådslående",
    "rådslåge": "rådslå",
    "rådslåges": "rådslå",
    "rådslår": "rådslå",
    "rådslås": "rådslå",
    "rådsnara": "rådsnar",
    "rådsnarare": "rådsnar",
    "rådsnarares": "rådsnar",
    "rådsnaras": "rådsnar",
    "rådsnarast": "rådsnar",
    "rådsnaraste": "rådsnar",
    "rådsnarastes": "rådsnar",
    "rådsnarasts": "rådsnar",
    "rådsnare": "rådsnar",
    "rådsnares": "rådsnar",
    "rådsnars": "rådsnar",
    "rådsnart": "rådsnar",
    "rådsnarts": "rådsnar",
    "rådsrepubliken": "rådsrepublik",
    "rådsrepublikens": "rådsrepublik",
    "rådsrepubliker": "rådsrepublik",
    "rådsrepublikerna": "rådsrepublik",
    "rådsrepublikernas": "rådsrepublik",
    "rådsrepublikers": "rådsrepublik",
    "rådsrepubliks": "rådsrepublik",
    "rådstugan": "rådstuga",
    "rådstugans": "rådstuga",
    "rådstugas": "rådstuga",
    "rådstuge": "rådstuga",
    "rådstugor": "rådstuga",
    "rådstugorna": "rådstuga",
    "rådstugornas": "rådstuga",
    "rådstugors": "rådstuga",
    "rådstugu": "rådstuga",
    "rådstugurätten": "rådstugurätt",
    "rådstugurättens": "rådstugurätt",
    "rådstugurätter": "rådstugurätt",
    "rådstugurätterna": "rådstugurätt",
    "rådstugurätternas": "rådstugurätt",
    "rådstugurätters": "rådstugurätt",
    "rådstugurätts": "rådstugurätt",
    "rådstun": "rådstu",
    "rådstuns": "rådstu",
    "rådsturätten": "rådsturätt",
    "rådsturättens": "rådsturätt",
    "rådsturätter": "rådsturätt",
    "rådsturätterna": "rådsturätt",
    "rådsturätternas": "rådsturätt",
    "rådsturätters": "rådsturätt",
    "rådsturätts": "rådsturätt",
    "rådstus": "rådstu",
    "rådvilla": "rådvill",
    "rådvillare": "rådvill",
    "rådvillares": "rådvill",
    "rådvillas": "rådvill",
    "rådvillast": "rådvill",
    "rådvillaste": "rådvill",
    "rådvillastes": "rådvill",
    "rådvillasts": "rådvill",
    "rådville": "rådvill",
    "rådvilles": "rådvill",
    "rådvillheten": "rådvillhet",
    "rådvillhetens": "rådvillhet",
    "rådvillhets": "rådvillhet",
    "rådvills": "rådvill",
    "rådvillt": "rådvill",
    "rådvillts": "rådvill",
    "råe": "rå",
    "rående": "rå",
    "råenden": "rående",
    "råendena": "rående",
    "råendenas": "rående",
    "råendens": "rående",
    "råendes": "rående",
    "råendet": "rående",
    "råendets": "rående",
    "råes": "rå",
    "rået": "rå",
    "råets": "rå",
    "rågad": "råga",
    "rågade": "råga",
    "rågades": "råga",
    "rågads": "råga",
    "rågande": "råga",
    "råganden": "rågande",
    "rågandena": "rågande",
    "rågandenas": "rågande",
    "rågandens": "rågande",
    "rågandes": "rågande",
    "rågandet": "rågande",
    "rågandets": "rågande",
    "rågar": "råga",
    "rågas": "råga",
    "rågat": "råga",
    "rågats": "råga",
    "rågblonda": "rågblond",
    "rågblondare": "rågblond",
    "rågblondares": "rågblond",
    "rågblondas": "rågblond",
    "rågblondast": "rågblond",
    "rågblondaste": "rågblond",
    "rågblondastes": "rågblond",
    "rågblondasts": "rågblond",
    "rågblonde": "rågblond",
    "rågblondes": "rågblond",
    "rågblondheten": "rågblondhet",
    "rågblondhetens": "rågblondhet",
    "rågblondhets": "rågblondhet",
    "rågblonds": "rågblond",
    "rågblont": "rågblond",
    "rågblonts": "rågblond",
    "rågbröden": "rågbröd",
    "rågbrödens": "rågbröd",
    "rågbrödet": "rågbröd",
    "rågbrödets": "rågbröd",
    "rågbröds": "rågbröd",
    "rågen": "råge",
    "rågens": "råge",
    "råges": "råge",
    "rågeten": "råget",
    "rågetens": "råget",
    "rågets": "råget",
    "rågetter": "råget",
    "rågetterna": "råget",
    "rågetternas": "råget",
    "rågetters": "råget",
    "rågkornen": "rågkorn",
    "rågkornens": "rågkorn",
    "rågkornet": "rågkorn",
    "rågkornets": "rågkorn",
    "rågkorns": "rågkorn",
    "råglaset": "råglas",
    "råglasets": "råglas",
    "råglimp": "råglimpa",
    "råglimpan": "råglimpa",
    "råglimpans": "råglimpa",
    "råglimpas": "råglimpa",
    "råglimpe": "råglimpa",
    "råglimpor": "råglimpa",
    "råglimporna": "råglimpa",
    "råglimpornas": "råglimpa",
    "råglimpors": "råglimpa",
    "råglimps": "råglimpa",
    "rågmjölet": "rågmjöl",
    "rågmjölets": "rågmjöl",
    "rågmjöls": "rågmjöl",
    "rågs": "råg",
    "rågsikten": "rågsikt",
    "rågsiktens": "rågsikt",
    "rågsikts": "rågsikt",
    "rågummis": "rågummi",
    "rågummit": "rågummi",
    "rågummits": "rågummi",
    "rågångar": "rågång",
    "rågångarna": "rågång",
    "rågångarnas": "rågång",
    "rågångars": "rågång",
    "rågången": "rågång",
    "rågångens": "rågång",
    "rågångs": "rågång",
    "råheten": "råhet",
    "råhetens": "råhet",
    "råheter": "råhet",
    "råheterna": "råhet",
    "råheternas": "råhet",
    "råheters": "råhet",
    "råhets": "råhet",
    "råk": "råka",
    "råkad": "råka",
    "råkade": "råka",
    "råkades": "råkas",
    "råkads": "råka",
    "råkalla": "råkall",
    "råkallare": "råkall",
    "råkallares": "råkall",
    "råkallas": "råkall",
    "råkallast": "råkall",
    "råkallaste": "råkall",
    "råkallastes": "råkall",
    "råkallasts": "råkall",
    "råkalle": "råkall",
    "råkalles": "råkall",
    "råkalls": "råkall",
    "råkallt": "råkall",
    "råkallts": "råkall",
    "råkan": "råka",
    "råkande": "råka",
    "råkanden": "råkande",
    "råkandena": "råkande",
    "råkandenas": "råkande",
    "råkandens": "råkande",
    "råkandes": "råkande",
    "råkandet": "råkande",
    "råkandets": "råkande",
    "råkans": "råka",
    "råkar": "råka",
    "råkarna": "råk",
    "råkarnas": "råk",
    "råkars": "råk",
    "råkas": "råka",
    "råkat": "råka",
    "råkats": "råkas",
    "råke": "råka",
    "råken": "råk",
    "råkens": "råk",
    "råket": "råk",
    "råkets": "råk",
    "råkopian": "råkopia",
    "råkopians": "råkopia",
    "råkopias": "råkopia",
    "råkopie": "råkopia",
    "råkopior": "råkopia",
    "råkopiorna": "råkopia",
    "råkopiornas": "råkopia",
    "råkopiors": "råkopia",
    "råkor": "råka",
    "råkorna": "råka",
    "råkornas": "råka",
    "råkors": "råka",
    "råkostaffären": "råkostaffär",
    "råkostaffärens": "råkostaffär",
    "råkostaffärer": "råkostaffär",
    "råkostaffärerna": "råkostaffär",
    "råkostaffärernas": "råkostaffär",
    "råkostaffärers": "råkostaffär",
    "råkostaffärs": "råkostaffär",
    "råkosten": "råkost",
    "råkostens": "råkost",
    "råkosts": "råkost",
    "råks": "råka",
    "råkurren": "råkurr",
    "råkurrens": "råkurr",
    "råkurret": "råkurr",
    "råkurrets": "råkurr",
    "råkurrs": "råkurr",
    "råm": "råma",
    "råmade": "råma",
    "råmades": "råma",
    "råmande": "råma",
    "råmanden": "råmande",
    "råmandena": "råmande",
    "råmandenas": "råmande",
    "råmandens": "råmande",
    "råmandes": "råmande",
    "råmandet": "råmande",
    "råmandets": "råmande",
    "råmar": "råma",
    "råmas": "råma",
    "råmat": "råma",
    "råmats": "råma",
    "råmjölken": "råmjölk",
    "råmjölkens": "råmjölk",
    "råmjölks": "råmjölk",
    "råmärken": "råmärke",
    "råmärkena": "råmärke",
    "råmärkenas": "råmärke",
    "råmärkens": "råmärke",
    "råmärkes": "råmärke",
    "råmärket": "råmärke",
    "råmärkets": "råmärke",
    "rån": "råna",
    "råna": "rå",
    "rånad": "råna",
    "rånade": "råna",
    "rånades": "råna",
    "rånads": "råna",
    "rånande": "råna",
    "rånanden": "rånande",
    "rånandena": "rånande",
    "rånandenas": "rånande",
    "rånandens": "rånande",
    "rånandes": "rånande",
    "rånandet": "rånande",
    "rånandets": "rånande",
    "rånar": "rånare",
    "rånaren": "rånare",
    "rånarens": "rånare",
    "rånares": "rånare",
    "rånarluvan": "rånarluva",
    "rånarluvans": "rånarluva",
    "rånarluvas": "rånarluva",
    "rånarluve": "rånarluva",
    "rånarluvor": "rånarluva",
    "rånarluvorna": "rånarluva",
    "rånarluvornas": "rånarluva",
    "rånarluvors": "rånarluva",
    "rånarna": "rånare",
    "rånarnas": "rånare",
    "rånas": "råna",
    "rånat": "råna",
    "rånats": "råna",
    "rånbyten": "rånbyte",
    "rånbytena": "rånbyte",
    "rånbytenas": "rånbyte",
    "rånbytens": "rånbyte",
    "rånbytes": "rånbyte",
    "rånbytet": "rånbyte",
    "rånbytets": "rånbyte",
    "rånen": "rån",
    "rånens": "rån",
    "rånet": "rån",
    "rånets": "rån",
    "rånförsöken": "rånförsök",
    "rånförsökens": "rånförsök",
    "rånförsöket": "rånförsök",
    "rånförsökets": "rånförsök",
    "rånförsöks": "rånförsök",
    "rånmorden": "rånmord",
    "rånmordens": "rånmord",
    "rånmordet": "rånmord",
    "rånmordets": "rånmord",
    "rånmords": "rånmord",
    "rånockar": "rånock",
    "rånockarna": "rånock",
    "rånockarnas": "rånock",
    "rånockars": "rånock",
    "rånocken": "rånock",
    "rånockens": "rånock",
    "rånocks": "rånock",
    "råns": "rån",
    "rånutvecklingen": "rånutveckling",
    "rånutvecklingens": "rånutveckling",
    "rånutvecklings": "rånutveckling",
    "råoljan": "råolja",
    "råoljans": "råolja",
    "råoljas": "råolja",
    "råolje": "råolja",
    "råoljemotorer": "råoljemotor",
    "råoljemotorerna": "råoljemotor",
    "råoljemotorernas": "råoljemotor",
    "råoljemotorers": "råoljemotor",
    "råoljemotorn": "råoljemotor",
    "råoljemotorns": "råoljemotor",
    "råoljemotors": "råoljemotor",
    "råplugg": "råplugga",
    "råpluggad": "råplugga",
    "råpluggade": "råplugga",
    "råpluggades": "råplugga",
    "råpluggads": "råplugga",
    "råpluggande": "råplugga",
    "råplugganden": "råpluggande",
    "råpluggandena": "råpluggande",
    "råpluggandenas": "råpluggande",
    "råpluggandens": "råpluggande",
    "råpluggandes": "råpluggande",
    "råpluggandet": "råpluggande",
    "råpluggandets": "råpluggande",
    "råpluggar": "råplugga",
    "råpluggas": "råplugga",
    "råpluggat": "råplugga",
    "råpluggats": "råplugga",
    "råplugget": "råplugg",
    "råpluggets": "råplugg",
    "råpluggs": "råplugg",
    "rår": "rå",
    "rårak": "råraka",
    "rårakan": "råraka",
    "rårakans": "råraka",
    "rårakas": "råraka",
    "rårake": "råraka",
    "rårakor": "råraka",
    "rårakorna": "råraka",
    "rårakornas": "råraka",
    "rårakors": "råraka",
    "råraks": "råraka",
    "rårev": "råriva",
    "rårevs": "råriva",
    "råriset": "råris",
    "rårisets": "råris",
    "råriv": "råriva",
    "rårivande": "råriva",
    "rårivanden": "rårivande",
    "rårivandena": "rårivande",
    "rårivandenas": "rårivande",
    "rårivandens": "rårivande",
    "rårivandes": "rårivande",
    "rårivandet": "rårivande",
    "rårivandets": "rårivande",
    "rårivas": "råriva",
    "rårive": "råriva",
    "råriven": "råriva",
    "rårivens": "råriva",
    "råriver": "råriva",
    "rårives": "råriva",
    "rårivet": "råriva",
    "rårivets": "råriva",
    "rårivit": "råriva",
    "rårivits": "råriva",
    "rårivna": "råriva",
    "rårivnas": "råriva",
    "rårivne": "råriva",
    "rårivnes": "råriva",
    "rårivs": "råriva",
    "rårna": "rå",
    "rårnas": "rå",
    "rårs": "rå",
    "rårörda": "rårörd",
    "rårördare": "rårörd",
    "rårördares": "rårörd",
    "rårördas": "rårörd",
    "rårördast": "rårörd",
    "rårördaste": "rårörd",
    "rårördastes": "rårörd",
    "rårördasts": "rårörd",
    "rårörde": "rårörd",
    "rårördes": "rårörd",
    "rårörds": "rårörd",
    "rårört": "rårörd",
    "rårörts": "rårörd",
    "rås": "rå",
    "råsegels": "råsegel",
    "råseglar": "råseglare",
    "råseglaren": "råseglare",
    "råseglarens": "råseglare",
    "råseglares": "råseglare",
    "råseglarna": "råseglare",
    "råseglarnas": "råseglare",
    "råseglen": "råsegel",
    "råseglens": "råsegel",
    "råseglet": "råsegel",
    "råseglets": "råsegel",
    "råsidenet": "råsiden",
    "råsidenets": "råsiden",
    "råsidens": "råsiden",
    "råskal": "råskala",
    "råskalad": "råskala",
    "råskalade": "råskala",
    "råskalades": "råskala",
    "råskalads": "råskala",
    "råskalande": "råskala",
    "råskalanden": "råskalande",
    "råskalandena": "råskalande",
    "råskalandenas": "råskalande",
    "råskalandens": "råskalande",
    "råskalandes": "råskalande",
    "råskalandet": "råskalande",
    "råskalandets": "råskalande",
    "råskalar": "råskala",
    "råskalas": "råskala",
    "råskalat": "råskala",
    "råskalats": "råskala",
    "råskinnen": "råskinn",
    "råskinnens": "råskinn",
    "råskinnet": "råskinn",
    "råskinnets": "råskinn",
    "råskinns": "råskinn",
    "råskäll": "råskälla",
    "råskällande": "råskälla",
    "råskällanden": "råskällande",
    "råskällandena": "råskällande",
    "råskällandenas": "råskällande",
    "råskällandens": "råskällande",
    "råskällandes": "råskällande",
    "råskällandet": "råskällande",
    "råskällandets": "råskällande",
    "råskällas": "råskälla",
    "råskälld": "råskälla",
    "råskällda": "råskälla",
    "råskälldas": "råskälla",
    "råskällde": "råskälla",
    "råskälldes": "råskälla",
    "råskällds": "råskälla",
    "råskäller": "råskälla",
    "råskälles": "råskälla",
    "råskälls": "råskälla",
    "råskällt": "råskälla",
    "råskällts": "råskälla",
    "råsockers": "råsocker",
    "råsockret": "råsocker",
    "råsockrets": "råsocker",
    "råsopar": "råsop",
    "råsoparna": "råsop",
    "råsoparnas": "råsop",
    "råsopars": "råsop",
    "råsopen": "råsop",
    "råsopens": "råsop",
    "råsops": "råsop",
    "råstek": "råsteka",
    "råstekande": "råsteka",
    "råstekanden": "råstekande",
    "råstekandena": "råstekande",
    "råstekandenas": "råstekande",
    "råstekandens": "råstekande",
    "råstekandes": "råstekande",
    "råstekandet": "råstekande",
    "råstekandets": "råstekande",
    "råstekas": "råsteka",
    "råsteker": "råsteka",
    "råstekes": "råsteka",
    "råsteks": "råsteka",
    "råstekt": "råsteka",
    "råstekta": "råsteka",
    "råstektas": "råsteka",
    "råstekte": "råsteka",
    "råstektes": "råsteka",
    "råstekts": "råsteka",
    "råstyrkan": "råstyrka",
    "råstyrkans": "råstyrka",
    "råstyrkas": "råstyrka",
    "råstyrke": "råstyrka",
    "råt": "rå",
    "råtacklade": "råtacklad",
    "råtacklades": "råtacklad",
    "råtacklads": "råtacklad",
    "råtacklat": "råtacklad",
    "råtacklats": "råtacklad",
    "råts": "rå",
    "rått": "råtta",
    "råttan": "råtta",
    "råttans": "råtta",
    "råttas": "råtta",
    "råttdjuren": "råttdjur",
    "råttdjurens": "råttdjur",
    "råttdjuret": "råttdjur",
    "råttdjurets": "råttdjur",
    "råttdjurs": "råttdjur",
    "råtte": "råtta",
    "råttfratet": "råttfrat",
    "råttfratets": "råttfrat",
    "råttfrats": "råttfrat",
    "råttfäll": "råttfälla",
    "råttfällan": "råttfälla",
    "råttfällans": "råttfälla",
    "råttfällas": "råttfälla",
    "råttfälle": "råttfälla",
    "råttfällor": "råttfälla",
    "råttfällorna": "råttfälla",
    "råttfällornas": "råttfälla",
    "råttfällors": "råttfälla",
    "råttfälls": "råttfälla",
    "råttgiftet": "råttgift",
    "råttgiftets": "råttgift",
    "råttgifts": "råttgift",
    "råtthålen": "råtthål",
    "råtthålens": "råtthål",
    "råtthålet": "råtthål",
    "råtthålets": "råtthål",
    "råtthåls": "råtthål",
    "råttor": "råtta",
    "råttorna": "råtta",
    "råttornas": "råtta",
    "råttors": "råtta",
    "råtts": "råtta",
    "råttsvansar": "råttsvans",
    "råttsvansarna": "råttsvans",
    "råttsvansarnas": "råttsvans",
    "råttsvansars": "råttsvans",
    "råttsvansen": "råttsvans",
    "råttsvansens": "råttsvans",
    "råttätens": "råttäten",
    "råttätet": "råttäten",
    "råttätets": "råttäten",
    "råttätna": "råttäten",
    "råttätnare": "råttäten",
    "råttätnares": "råttäten",
    "råttätnas": "råttäten",
    "råttätnast": "råttäten",
    "råttätnaste": "råttäten",
    "råttätnastes": "råttäten",
    "råttätnasts": "råttäten",
    "råttätne": "råttäten",
    "råttätnes": "råttäten",
    "råvar": "råvara",
    "råvaran": "råvara",
    "råvarans": "råvara",
    "råvaras": "råvara",
    "råvaror": "råvara",
    "råvarorna": "råvara",
    "råvarornas": "råvara",
    "råvarors": "råvara",
    "råvaru": "råvara",
    "råvaruekonomien": "råvaruekonomi",
    "råvaruekonomiens": "råvaruekonomi",
    "råvaruekonomier": "råvaruekonomi",
    "råvaruekonomierna": "råvaruekonomi",
    "råvaruekonomiernas": "råvaruekonomi",
    "råvaruekonomiers": "råvaruekonomi",
    "råvaruekonomin": "råvaruekonomi",
    "råvaruekonomins": "råvaruekonomi",
    "råvaruekonomis": "råvaruekonomi",
    "råvarumässiga": "råvarumässig",
    "råvarumässigare": "råvarumässig",
    "råvarumässigares": "råvarumässig",
    "råvarumässigas": "råvarumässig",
    "råvarumässigast": "råvarumässig",
    "råvarumässigaste": "råvarumässig",
    "råvarumässigastes": "råvarumässig",
    "råvarumässigasts": "råvarumässig",
    "råvarumässige": "råvarumässig",
    "råvarumässiges": "råvarumässig",
    "råvarumässigs": "råvarumässig",
    "råvarumässigt": "råvarumässig",
    "råvarumässigts": "råvarumässig",
    "råämnen": "råämne",
    "råämnena": "råämne",
    "råämnenas": "råämne",
    "råämnens": "råämne",
    "råämnes": "råämne",
    "råämnet": "råämne",
    "råämnets": "råämne",
    "röda": "röd",
    "rödaktiga": "rödaktig",
    "rödaktigare": "rödaktig",
    "rödaktigares": "rödaktig",
    "rödaktigas": "rödaktig",
    "rödaktigast": "rödaktig",
    "rödaktigaste": "rödaktig",
    "rödaktigastes": "rödaktig",
    "rödaktigasts": "rödaktig",
    "rödaktige": "rödaktig",
    "rödaktiges": "rödaktig",
    "rödaktigheten": "rödaktighet",
    "rödaktighetens": "rödaktighet",
    "rödaktighets": "rödaktighet",
    "rödaktigs": "rödaktig",
    "rödaktigt": "rödaktig",
    "rödaktigts": "rödaktig",
    "rödare": "röd",
    "rödares": "röd",
    "rödas": "röd",
    "rödast": "röd",
    "rödaste": "röd",
    "rödastes": "röd",
    "rödasts": "röd",
    "rödben": "rödbena",
    "rödbenan": "rödbena",
    "rödbenans": "rödbena",
    "rödbenas": "rödbena",
    "rödbene": "rödbena",
    "rödbenor": "rödbena",
    "rödbenorna": "rödbena",
    "rödbenornas": "rödbena",
    "rödbenors": "rödbena",
    "rödbens": "rödbena",
    "rödbet": "rödbeta",
    "rödbetan": "rödbeta",
    "rödbetans": "rödbeta",
    "rödbetas": "rödbeta",
    "rödbete": "rödbeta",
    "rödbetor": "rödbeta",
    "rödbetorna": "rödbeta",
    "rödbetornas": "rödbeta",
    "rödbetors": "rödbeta",
    "rödbets": "rödbeta",
    "rödbetssalladen": "rödbetssallad",
    "rödbetssalladens": "rödbetssallad",
    "rödbetssallader": "rödbetssallad",
    "rödbetssalladerna": "rödbetssallad",
    "rödbetssalladernas": "rödbetssallad",
    "rödbetssalladers": "rödbetssallad",
    "rödbetssallads": "rödbetssallad",
    "rödblinda": "rödblind",
    "rödblindare": "rödblind",
    "rödblindares": "rödblind",
    "rödblindas": "rödblind",
    "rödblindast": "rödblind",
    "rödblindaste": "rödblind",
    "rödblindastes": "rödblind",
    "rödblindasts": "rödblind",
    "rödblinde": "rödblind",
    "rödblindes": "rödblind",
    "rödblindheten": "rödblindhet",
    "rödblindhetens": "rödblindhet",
    "rödblindhets": "rödblindhet",
    "rödblinds": "rödblind",
    "rödblint": "rödblind",
    "rödblints": "rödblind",
    "rödblommiga": "rödblommig",
    "rödblommigare": "rödblommig",
    "rödblommigares": "rödblommig",
    "rödblommigas": "rödblommig",
    "rödblommigast": "rödblommig",
    "rödblommigaste": "rödblommig",
    "rödblommigastes": "rödblommig",
    "rödblommigasts": "rödblommig",
    "rödblommige": "rödblommig",
    "rödblommiges": "rödblommig",
    "rödblommigs": "rödblommig",
    "rödblommigt": "rödblommig",
    "rödblommigts": "rödblommig",
    "rödblonda": "rödblond",
    "rödblondare": "rödblond",
    "rödblondares": "rödblond",
    "rödblondas": "rödblond",
    "rödblondast": "rödblond",
    "rödblondaste": "rödblond",
    "rödblondastes": "rödblond",
    "rödblondasts": "rödblond",
    "rödblonde": "rödblond",
    "rödblondes": "rödblond",
    "rödblondheten": "rödblondhet",
    "rödblondhetens": "rödblondhet",
    "rödblondhets": "rödblondhet",
    "rödblonds": "rödblond",
    "rödblont": "rödblond",
    "rödblonts": "rödblond",
    "rödblåa": "rödblå",
    "rödblåare": "rödblå",
    "rödblåares": "rödblå",
    "rödblåas": "rödblå",
    "rödblåast": "rödblå",
    "rödblåaste": "rödblå",
    "rödblåastes": "rödblå",
    "rödblåasts": "rödblå",
    "rödblåe": "rödblå",
    "rödblåes": "rödblå",
    "rödblås": "rödblå",
    "rödblått": "rödblå",
    "rödblåtts": "rödblå",
    "rödbokar": "rödbok",
    "rödbokarna": "rödbok",
    "rödbokarnas": "rödbok",
    "rödbokars": "rödbok",
    "rödboken": "rödbok",
    "rödbokens": "rödbok",
    "rödboks": "rödbok",
    "rödbrokiga": "rödbrokig",
    "rödbrokigare": "rödbrokig",
    "rödbrokigares": "rödbrokig",
    "rödbrokigas": "rödbrokig",
    "rödbrokigast": "rödbrokig",
    "rödbrokigaste": "rödbrokig",
    "rödbrokigastes": "rödbrokig",
    "rödbrokigasts": "rödbrokig",
    "rödbrokige": "rödbrokig",
    "rödbrokiges": "rödbrokig",
    "rödbrokigs": "rödbrokig",
    "rödbrokigt": "rödbrokig",
    "rödbrokigts": "rödbrokig",
    "rödbruna": "rödbrun",
    "rödbrunare": "rödbrun",
    "rödbrunares": "rödbrun",
    "rödbrunas": "rödbrun",
    "rödbrunast": "rödbrun",
    "rödbrunaste": "rödbrun",
    "rödbrunastes": "rödbrun",
    "rödbrunasts": "rödbrun",
    "rödbrune": "rödbrun",
    "rödbrunes": "rödbrun",
    "rödbruns": "rödbrun",
    "rödbrunt": "rödbrun",
    "rödbrunts": "rödbrun",
    "rödbrusiga": "rödbrusig",
    "rödbrusigare": "rödbrusig",
    "rödbrusigares": "rödbrusig",
    "rödbrusigas": "rödbrusig",
    "rödbrusigast": "rödbrusig",
    "rödbrusigaste": "rödbrusig",
    "rödbrusigastes": "rödbrusig",
    "rödbrusigasts": "rödbrusig",
    "rödbrusige": "rödbrusig",
    "rödbrusiges": "rödbrusig",
    "rödbrusigheten": "rödbrusighet",
    "rödbrusighetens": "rödbrusighet",
    "rödbrusighets": "rödbrusighet",
    "rödbrusigs": "rödbrusig",
    "rödbrusigt": "rödbrusig",
    "rödbrusigts": "rödbrusig",
    "röde": "röd",
    "rödes": "röd",
    "rödfilterna": "rödfilter",
    "rödfilternas": "rödfilter",
    "rödfilters": "rödfilter",
    "rödfiltren": "rödfilter",
    "rödfiltrens": "rödfilter",
    "rödfiltret": "rödfilter",
    "rödfiltrets": "rödfilter",
    "rödflammiga": "rödflammig",
    "rödflammigare": "rödflammig",
    "rödflammigares": "rödflammig",
    "rödflammigas": "rödflammig",
    "rödflammigast": "rödflammig",
    "rödflammigaste": "rödflammig",
    "rödflammigastes": "rödflammig",
    "rödflammigasts": "rödflammig",
    "rödflammige": "rödflammig",
    "rödflammiges": "rödflammig",
    "rödflammigheten": "rödflammighet",
    "rödflammighetens": "rödflammighet",
    "rödflammighets": "rödflammighet",
    "rödflammigs": "rödflammig",
    "rödflammigt": "rödflammig",
    "rödflammigts": "rödflammig",
    "rödfärgen": "rödfärg",
    "rödfärgens": "rödfärg",
    "rödfärgs": "rödfärg",
    "rödförskjutningen": "rödförskjutning",
    "rödförskjutningens": "rödförskjutning",
    "rödförskjutnings": "rödförskjutning",
    "rödglödg": "rödglödga",
    "rödglödgad": "rödglödga",
    "rödglödgade": "rödglödga",
    "rödglödgades": "rödglödga",
    "rödglödgads": "rödglödga",
    "rödglödgande": "rödglödga",
    "rödglödganden": "rödglödgande",
    "rödglödgandena": "rödglödgande",
    "rödglödgandenas": "rödglödgande",
    "rödglödgandens": "rödglödgande",
    "rödglödgandes": "rödglödgande",
    "rödglödgandet": "rödglödgande",
    "rödglödgandets": "rödglödgande",
    "rödglödgar": "rödglödga",
    "rödglödgas": "rödglödga",
    "rödglödgat": "rödglödga",
    "rödglödgats": "rödglödga",
    "rödgråtens": "rödgråten",
    "rödgråtet": "rödgråten",
    "rödgråtets": "rödgråten",
    "rödgråtna": "rödgråten",
    "rödgråtnare": "rödgråten",
    "rödgråtnares": "rödgråten",
    "rödgråtnas": "rödgråten",
    "rödgråtnast": "rödgråten",
    "rödgråtnaste": "rödgråten",
    "rödgråtnastes": "rödgråten",
    "rödgråtnasts": "rödgråten",
    "rödgråtne": "rödgråten",
    "rödgråtnes": "rödgråten",
    "rödgröna": "rödgrön",
    "rödgrönare": "rödgrön",
    "rödgrönares": "rödgrön",
    "rödgrönas": "rödgrön",
    "rödgrönast": "rödgrön",
    "rödgrönaste": "rödgrön",
    "rödgrönastes": "rödgrön",
    "rödgrönasts": "rödgrön",
    "rödgrönblinda": "rödgrönblind",
    "rödgrönblindare": "rödgrönblind",
    "rödgrönblindares": "rödgrönblind",
    "rödgrönblindas": "rödgrönblind",
    "rödgrönblindast": "rödgrönblind",
    "rödgrönblindaste": "rödgrönblind",
    "rödgrönblindastes": "rödgrönblind",
    "rödgrönblindasts": "rödgrönblind",
    "rödgrönblinde": "rödgrönblind",
    "rödgrönblindes": "rödgrönblind",
    "rödgrönblindheten": "rödgrönblindhet",
    "rödgrönblindhetens": "rödgrönblindhet",
    "rödgrönblindhets": "rödgrönblindhet",
    "rödgrönblinds": "rödgrönblind",
    "rödgrönblint": "rödgrönblind",
    "rödgrönblints": "rödgrönblind",
    "rödgröne": "rödgrön",
    "rödgrönes": "rödgrön",
    "rödgröns": "rödgrön",
    "rödgrönt": "rödgrön",
    "rödgrönts": "rödgrön",
    "rödhakar": "rödhake",
    "rödhakarna": "rödhake",
    "rödhakarnas": "rödhake",
    "rödhakars": "rödhake",
    "rödhaken": "rödhake",
    "rödhakens": "rödhake",
    "rödhakes": "rödhake",
    "rödhakesångar": "rödhakesångare",
    "rödhakesångaren": "rödhakesångare",
    "rödhakesångarens": "rödhakesångare",
    "rödhakesångares": "rödhakesångare",
    "rödhakesångarna": "rödhakesångare",
    "rödhakesångarnas": "rödhakesångare",
    "rödhåriga": "rödhårig",
    "rödhårigare": "rödhårig",
    "rödhårigares": "rödhårig",
    "rödhårigas": "rödhårig",
    "rödhårigast": "rödhårig",
    "rödhårigaste": "rödhårig",
    "rödhårigastes": "rödhårig",
    "rödhårigasts": "rödhårig",
    "rödhårige": "rödhårig",
    "rödhåriges": "rödhårig",
    "rödhårigheten": "rödhårighet",
    "rödhårighetens": "rödhårighet",
    "rödhårighets": "rödhårighet",
    "rödhårigs": "rödhårig",
    "rödhårigt": "rödhårig",
    "rödhårigts": "rödhårig",
    "rödingar": "röding",
    "rödingarna": "röding",
    "rödingarnas": "röding",
    "rödingars": "röding",
    "rödingen": "röding",
    "rödingens": "röding",
    "rödings": "röding",
    "rödkantade": "rödkantad",
    "rödkantades": "rödkantad",
    "rödkantads": "rödkantad",
    "rödkantat": "rödkantad",
    "rödkantats": "rödkantad",
    "rödkindade": "rödkindad",
    "rödkindades": "rödkindad",
    "rödkindads": "rödkindad",
    "rödkindat": "rödkindad",
    "rödkindats": "rödkindad",
    "rödklinten": "rödklint",
    "rödklintens": "rödklint",
    "rödklints": "rödklint",
    "rödklövern": "rödklöver",
    "rödklöverns": "rödklöver",
    "rödklövers": "rödklöver",
    "rödkålen": "rödkål",
    "rödkålens": "rödkål",
    "rödkåls": "rödkål",
    "rödlistad": "rödlista",
    "rödlistade": "rödlista",
    "rödlistades": "rödlista",
    "rödlistads": "rödlista",
    "rödlistan": "rödlista",
    "rödlistande": "rödlista",
    "rödlistanden": "rödlistande",
    "rödlistandena": "rödlistande",
    "rödlistandenas": "rödlistande",
    "rödlistandens": "rödlistande",
    "rödlistandes": "rödlistande",
    "rödlistandet": "rödlistande",
    "rödlistandets": "rödlistande",
    "rödlistans": "rödlista",
    "rödlistar": "rödlista",
    "rödlistas": "rödlista",
    "rödlistat": "rödlista",
    "rödlistats": "rödlista",
    "rödliste": "rödlista",
    "rödlistor": "rödlista",
    "rödlistorna": "rödlista",
    "rödlistornas": "rödlista",
    "rödlistors": "rödlista",
    "rödlätta": "rödlätt",
    "rödlättare": "rödlätt",
    "rödlättares": "rödlätt",
    "rödlättas": "rödlätt",
    "rödlättast": "rödlätt",
    "rödlättaste": "rödlätt",
    "rödlättastes": "rödlätt",
    "rödlättasts": "rödlätt",
    "rödlätte": "rödlätt",
    "rödlättes": "rödlätt",
    "rödlättheten": "rödlätthet",
    "rödlätthetens": "rödlätthet",
    "rödlätthets": "rödlätthet",
    "rödlätts": "rödlätt",
    "rödlöken": "rödlök",
    "rödlökens": "rödlök",
    "rödlöks": "rödlök",
    "rödmosiga": "rödmosig",
    "rödmosigare": "rödmosig",
    "rödmosigares": "rödmosig",
    "rödmosigas": "rödmosig",
    "rödmosigast": "rödmosig",
    "rödmosigaste": "rödmosig",
    "rödmosigastes": "rödmosig",
    "rödmosigasts": "rödmosig",
    "rödmosige": "rödmosig",
    "rödmosiges": "rödmosig",
    "rödmosigheten": "rödmosighet",
    "rödmosighetens": "rödmosighet",
    "rödmosighets": "rödmosighet",
    "rödmosigs": "rödmosig",
    "rödmosigt": "rödmosig",
    "rödmosigts": "rödmosig",
    "rödmyr": "rödmyra",
    "rödmyran": "rödmyra",
    "rödmyrans": "rödmyra",
    "rödmyras": "rödmyra",
    "rödmyre": "rödmyra",
    "rödmyror": "rödmyra",
    "rödmyrorna": "rödmyra",
    "rödmyrornas": "rödmyra",
    "rödmyrors": "rödmyra",
    "rödmyrs": "rödmyra",
    "rödmålade": "rödmålad",
    "rödmålades": "rödmålad",
    "rödmålads": "rödmålad",
    "rödmålat": "rödmålad",
    "rödmålats": "rödmålad",
    "rödnästa": "rödnäst",
    "rödnästare": "rödnäst",
    "rödnästares": "rödnäst",
    "rödnästas": "rödnäst",
    "rödnästast": "rödnäst",
    "rödnästaste": "rödnäst",
    "rödnästastes": "rödnäst",
    "rödnästasts": "rödnäst",
    "rödnäste": "rödnäst",
    "rödnästes": "rödnäst",
    "rödnästheten": "rödnästhet",
    "rödnästhetens": "rödnästhet",
    "rödnästhets": "rödnästhet",
    "rödnästs": "rödnäst",
    "rödpenn": "rödpenna",
    "rödpennan": "rödpenna",
    "rödpennans": "rödpenna",
    "rödpennas": "rödpenna",
    "rödpenne": "rödpenna",
    "rödpennor": "rödpenna",
    "rödpennorna": "rödpenna",
    "rödpennornas": "rödpenna",
    "rödpennors": "rödpenna",
    "rödpenns": "rödpenna",
    "rödpepparn": "rödpeppar",
    "rödpepparns": "rödpeppar",
    "rödpeppars": "rödpeppar",
    "rödpunktsikten": "rödpunktsikte",
    "rödpunktsiktena": "rödpunktsikte",
    "rödpunktsiktenas": "rödpunktsikte",
    "rödpunktsiktens": "rödpunktsikte",
    "rödpunktsiktes": "rödpunktsikte",
    "rödpunktsiktet": "rödpunktsikte",
    "rödpunktsiktets": "rödpunktsikte",
    "rödpunktssikten": "rödpunktssikte",
    "rödpunktssiktena": "rödpunktssikte",
    "rödpunktssiktenas": "rödpunktssikte",
    "rödpunktssiktens": "rödpunktssikte",
    "rödpunktssiktes": "rödpunktssikte",
    "rödpunktssiktet": "rödpunktssikte",
    "rödpunktssiktets": "rödpunktssikte",
    "rödrävar": "rödräv",
    "rödrävarna": "rödräv",
    "rödrävarnas": "rödräv",
    "rödrävars": "rödräv",
    "rödräven": "rödräv",
    "rödrävens": "rödräv",
    "rödrävs": "rödräv",
    "röds": "röd",
    "rödskinnen": "rödskinn",
    "rödskinnens": "rödskinn",
    "rödskinnet": "rödskinn",
    "rödskinnets": "rödskinn",
    "rödskinns": "rödskinn",
    "rödsoten": "rödsot",
    "rödsotens": "rödsot",
    "rödsots": "rödsot",
    "rödspott": "rödspotta",
    "rödspottan": "rödspotta",
    "rödspottans": "rödspotta",
    "rödspottas": "rödspotta",
    "rödspotte": "rödspotta",
    "rödspottor": "rödspotta",
    "rödspottorna": "rödspotta",
    "rödspottornas": "rödspotta",
    "rödspottors": "rödspotta",
    "rödspotts": "rödspotta",
    "rödspriten": "rödsprit",
    "rödspritens": "rödsprit",
    "rödsprits": "rödsprit",
    "rödsprängda": "rödsprängd",
    "rödsprängdare": "rödsprängd",
    "rödsprängdares": "rödsprängd",
    "rödsprängdas": "rödsprängd",
    "rödsprängdast": "rödsprängd",
    "rödsprängdaste": "rödsprängd",
    "rödsprängdastes": "rödsprängd",
    "rödsprängdasts": "rödsprängd",
    "rödsprängde": "rödsprängd",
    "rödsprängdes": "rödsprängd",
    "rödsprängdheten": "rödsprängdhet",
    "rödsprängdhetens": "rödsprängdhet",
    "rödsprängdhets": "rödsprängdhet",
    "rödsprängds": "rödsprängd",
    "rödsprängt": "rödsprängd",
    "rödsprängts": "rödsprängd",
    "rödspätt": "rödspätta",
    "rödspättan": "rödspätta",
    "rödspättans": "rödspätta",
    "rödspättas": "rödspätta",
    "rödspätte": "rödspätta",
    "rödspättor": "rödspätta",
    "rödspättorna": "rödspätta",
    "rödspättornas": "rödspätta",
    "rödspättors": "rödspätta",
    "rödspätts": "rödspätta",
    "rödstjärtar": "rödstjärt",
    "rödstjärtarna": "rödstjärt",
    "rödstjärtarnas": "rödstjärt",
    "rödstjärtars": "rödstjärt",
    "rödstjärten": "rödstjärt",
    "rödstjärtens": "rödstjärt",
    "rödstjärts": "rödstjärt",
    "rödstrump": "rödstrumpa",
    "rödstrumpan": "rödstrumpa",
    "rödstrumpans": "rödstrumpa",
    "rödstrumpas": "rödstrumpa",
    "rödstrumpe": "rödstrumpa",
    "rödstrumpor": "rödstrumpa",
    "rödstrumporna": "rödstrumpa",
    "rödstrumpornas": "rödstrumpa",
    "rödstrumpors": "rödstrumpa",
    "rödstrumps": "rödstrumpa",
    "rödtungan": "rödtunga",
    "rödtungans": "rödtunga",
    "rödtungas": "rödtunga",
    "rödtunge": "rödtunga",
    "rödtungo": "rödtunga",
    "rödtungor": "rödtunga",
    "rödtungorna": "rödtunga",
    "rödtungornas": "rödtunga",
    "rödtungors": "rödtunga",
    "rödviner": "rödvin",
    "rödvinerna": "rödvin",
    "rödvinernas": "rödvin",
    "rödviners": "rödvin",
    "rödvinet": "rödvin",
    "rödvinets": "rödvin",
    "rödvins": "rödvin",
    "rödväpplingar": "rödväppling",
    "rödväpplingarna": "rödväppling",
    "rödväpplingarnas": "rödväppling",
    "rödväpplingars": "rödväppling",
    "rödväpplingen": "rödväppling",
    "rödväpplingens": "rödväppling",
    "rödväpplings": "rödväppling",
    "rödögda": "rödögd",
    "rödögdare": "rödögd",
    "rödögdares": "rödögd",
    "rödögdas": "rödögd",
    "rödögdast": "rödögd",
    "rödögdaste": "rödögd",
    "rödögdastes": "rödögd",
    "rödögdasts": "rödögd",
    "rödögde": "rödögd",
    "rödögdes": "rödögd",
    "rödögdheten": "rödögdhet",
    "rödögdhetens": "rödögdhet",
    "rödögdhets": "rödögdhet",
    "rödögds": "rödögd",
    "rödögt": "rödögd",
    "rödögts": "rödögd",
    "röet": "rö",
    "röets": "rö",
    "röj": "röja",
    "röjande": "röja",
    "röjanden": "röjande",
    "röjandena": "röjande",
    "röjandenas": "röjande",
    "röjandens": "röjande",
    "röjandes": "röjande",
    "röjandet": "röjande",
    "röjandets": "röjande",
    "röjarskivan": "röjarskiva",
    "röjarskivans": "röjarskiva",
    "röjarskivas": "röjarskiva",
    "röjarskive": "röjarskiva",
    "röjarskivor": "röjarskiva",
    "röjarskivorna": "röjarskiva",
    "röjarskivornas": "röjarskiva",
    "röjarskivors": "röjarskiva",
    "röjas": "röja",
    "röjd": "röja",
    "röjda": "röja",
    "röjdas": "röja",
    "röjde": "röja",
    "röjdes": "röja",
    "röjds": "röja",
    "röjdykar": "röjdykare",
    "röjdykaren": "röjdykare",
    "röjdykarens": "röjdykare",
    "röjdykares": "röjdykare",
    "röjdykarna": "röjdykare",
    "röjdykarnas": "röjdykare",
    "röjeln": "röjel",
    "röjelns": "röjel",
    "röjels": "röjel",
    "röjer": "röja",
    "röjes": "röja",
    "röjlar": "röjel",
    "röjlarna": "röjel",
    "röjlarnas": "röjel",
    "röjlars": "röjel",
    "röjningar": "röjning",
    "röjningarna": "röjning",
    "röjningarnas": "röjning",
    "röjningars": "röjning",
    "röjningen": "röjning",
    "röjningens": "röjning",
    "röjnings": "röjning",
    "röjningsarbeten": "röjningsarbete",
    "röjningsarbetena": "röjningsarbete",
    "röjningsarbetenas": "röjningsarbete",
    "röjningsarbetens": "röjningsarbete",
    "röjningsarbetes": "röjningsarbete",
    "röjningsarbetet": "röjningsarbete",
    "röjningsarbetets": "röjningsarbete",
    "röjningsarbets": "röjningsarbete",
    "röjs": "röja",
    "röjsågar": "röjsåg",
    "röjsågarna": "röjsåg",
    "röjsågarnas": "röjsåg",
    "röjsågars": "röjsåg",
    "röjsågen": "röjsåg",
    "röjsågens": "röjsåg",
    "röjsågs": "röjsåg",
    "röjt": "röja",
    "röjts": "röja",
    "rök": "ryka",
    "rökande": "röka",
    "rökanden": "rökande",
    "rökandena": "rökande",
    "rökandenas": "rökande",
    "rökandens": "rökande",
    "rökandes": "rökande",
    "rökandet": "rökande",
    "rökandets": "rökande",
    "rökar": "rökare",
    "rökaren": "rökare",
    "rökarens": "rökare",
    "rökares": "rökare",
    "rökarna": "rökare",
    "rökarnas": "rökare",
    "rökars": "rök",
    "rökas": "röka",
    "rökat": "röka",
    "rökats": "röka",
    "rökavvänjningen": "rökavvänjning",
    "rökavvänjningens": "rökavvänjning",
    "rökavvänjnings": "rökavvänjning",
    "rökblåa": "rökblå",
    "rökblåare": "rökblå",
    "rökblåares": "rökblå",
    "rökblåas": "rökblå",
    "rökblåast": "rökblå",
    "rökblåaste": "rökblå",
    "rökblåastes": "rökblå",
    "rökblåasts": "rökblå",
    "rökblåe": "rökblå",
    "rökblåes": "rökblå",
    "rökblås": "rökblå",
    "rökblått": "rökblå",
    "rökblåtts": "rökblå",
    "rökbomben": "rökbomb",
    "rökbombens": "rökbomb",
    "rökbomber": "rökbomb",
    "rökbomberna": "rökbomb",
    "rökbombernas": "rökbomb",
    "rökbombers": "rökbomb",
    "rökbombs": "rökbomb",
    "rökborden": "rökbord",
    "rökbordens": "rökbord",
    "rökbordet": "rökbord",
    "rökbordets": "rökbord",
    "rökbords": "rökbord",
    "rökdetektorer": "rökdetektor",
    "rökdetektorerna": "rökdetektor",
    "rökdetektorernas": "rökdetektor",
    "rökdetektorers": "rökdetektor",
    "rökdetektorn": "rökdetektor",
    "rökdetektorns": "rökdetektor",
    "rökdetektors": "rökdetektor",
    "rökdykar": "rökdykare",
    "rökdykaren": "rökdykare",
    "rökdykarens": "rökdykare",
    "rökdykares": "rökdykare",
    "rökdykarna": "rökdykare",
    "rökdykarnas": "rökdykare",
    "röke": "ryka",
    "rökelsekaren": "rökelsekar",
    "rökelsekarens": "rökelsekar",
    "rökelsekaret": "rökelsekar",
    "rökelsekarets": "rökelsekar",
    "rökelsekars": "rökelsekar",
    "rökelsen": "rökelse",
    "rökelsens": "rökelse",
    "rökelser": "rökelse",
    "rökelserna": "rökelse",
    "rökelsernas": "rökelse",
    "rökelsers": "rökelse",
    "rökelses": "rökelse",
    "röken": "rök",
    "rökens": "rök",
    "röker": "röka",
    "rökerier": "rökeri",
    "rökerierna": "rökeri",
    "rökeriernas": "rökeri",
    "rökeriers": "rökeri",
    "rökeriet": "rökeri",
    "rökeriets": "rökeri",
    "rökeris": "rökeri",
    "rökerit": "rökeri",
    "rökerits": "rökeri",
    "rökes": "röka",
    "rökfria": "rökfri",
    "rökfriare": "rökfri",
    "rökfriares": "rökfri",
    "rökfrias": "rökfri",
    "rökfriast": "rökfri",
    "rökfriaste": "rökfri",
    "rökfriastes": "rökfri",
    "rökfriasts": "rökfri",
    "rökfrie": "rökfri",
    "rökfries": "rökfri",
    "rökfris": "rökfri",
    "rökfritt": "rökfri",
    "rökfritts": "rökfri",
    "rökfärgade": "rökfärgad",
    "rökfärgades": "rökfärgad",
    "rökfärgads": "rökfärgad",
    "rökfärgat": "rökfärgad",
    "rökfärgats": "rökfärgad",
    "rökfången": "rökfång",
    "rökfångens": "rökfång",
    "rökfånget": "rökfång",
    "rökfångets": "rökfång",
    "rökfångs": "rökfång",
    "rökförbuden": "rökförbud",
    "rökförbudens": "rökförbud",
    "rökförbudet": "rökförbud",
    "rökförbudets": "rökförbud",
    "rökförbuds": "rökförbud",
    "rökgasen": "rökgas",
    "rökgasens": "rökgas",
    "rökgaser": "rökgas",
    "rökgaserna": "rökgas",
    "rökgasernas": "rökgas",
    "rökgasers": "rökgas",
    "rökgranaten": "rökgranat",
    "rökgranatens": "rökgranat",
    "rökgranater": "rökgranat",
    "rökgranaterna": "rökgranat",
    "rökgranaternas": "rökgranat",
    "rökgranaters": "rökgranat",
    "rökgranats": "rökgranat",
    "rökgråa": "rökgrå",
    "rökgråare": "rökgrå",
    "rökgråares": "rökgrå",
    "rökgråas": "rökgrå",
    "rökgråast": "rökgrå",
    "rökgråaste": "rökgrå",
    "rökgråastes": "rökgrå",
    "rökgråasts": "rökgrå",
    "rökgråe": "rökgrå",
    "rökgråes": "rökgrå",
    "rökgrås": "rökgrå",
    "rökgrått": "rökgrå",
    "rökgråtts": "rökgrå",
    "rökgångar": "rökgång",
    "rökgångarna": "rökgång",
    "rökgångarnas": "rökgång",
    "rökgångars": "rökgång",
    "rökgången": "rökgång",
    "rökgångens": "rökgång",
    "rökgångs": "rökgång",
    "rökgårdar": "rökgård",
    "rökgårdarna": "rökgård",
    "rökgårdarnas": "rökgård",
    "rökgårdars": "rökgård",
    "rökgården": "rökgård",
    "rökgårdens": "rökgård",
    "rökgårds": "rökgård",
    "rökhost": "rökhosta",
    "rökhostan": "rökhosta",
    "rökhostans": "rökhosta",
    "rökhostas": "rökhosta",
    "rökhoste": "rökhosta",
    "rökiga": "rökig",
    "rökigare": "rökig",
    "rökigares": "rökig",
    "rökigas": "rökig",
    "rökigast": "rökig",
    "rökigaste": "rökig",
    "rökigastes": "rökig",
    "rökigasts": "rökig",
    "rökige": "rökig",
    "rökiges": "rökig",
    "rökigs": "rökig",
    "rökigt": "rökig",
    "rökigts": "rökig",
    "rökkanalen": "rökkanal",
    "rökkanalens": "rökkanal",
    "rökkanaler": "rökkanal",
    "rökkanalerna": "rökkanal",
    "rökkanalernas": "rökkanal",
    "rökkanalers": "rökkanal",
    "rökkanals": "rökkanal",
    "rökkupéer": "rökkupé",
    "rökkupéerna": "rökkupé",
    "rökkupéernas": "rökkupé",
    "rökkupéers": "rökkupé",
    "rökkupén": "rökkupé",
    "rökkupéns": "rökkupé",
    "rökkupés": "rökkupé",
    "röklukten": "röklukt",
    "rökluktens": "röklukt",
    "röklukts": "röklukt",
    "rökmanien": "rökmani",
    "rökmaniens": "rökmani",
    "rökmanier": "rökmani",
    "rökmanierna": "rökmani",
    "rökmaniernas": "rökmani",
    "rökmaniers": "rökmani",
    "rökmanin": "rökmani",
    "rökmanins": "rökmani",
    "rökmanis": "rökmani",
    "rökmasken": "rökmask",
    "rökmaskens": "rökmask",
    "rökmasker": "rökmask",
    "rökmaskerna": "rökmask",
    "rökmaskernas": "rökmask",
    "rökmaskers": "rökmask",
    "rökmasks": "rökmask",
    "rökmolnen": "rökmoln",
    "rökmolnens": "rökmoln",
    "rökmolnet": "rökmoln",
    "rökmolnets": "rökmoln",
    "rökmolns": "rökmoln",
    "rökningar": "rökning",
    "rökningarna": "rökning",
    "rökningarnas": "rökning",
    "rökningars": "rökning",
    "rökningen": "rökning",
    "rökningens": "rökning",
    "röknings": "rökning",
    "rökpelar": "rökpelare",
    "rökpelaren": "rökpelare",
    "rökpelarens": "rökpelare",
    "rökpelares": "rökpelare",
    "rökpelarna": "rökpelare",
    "rökpelarnas": "rökpelare",
    "rökridåer": "rökridå",
    "rökridåerna": "rökridå",
    "rökridåernas": "rökridå",
    "rökridåers": "rökridå",
    "rökridån": "rökridå",
    "rökridåns": "rökridå",
    "rökridås": "rökridå",
    "rökringar": "rökring",
    "rökringarna": "rökring",
    "rökringarnas": "rökring",
    "rökringars": "rökring",
    "rökringen": "rökring",
    "rökringens": "rökring",
    "rökrings": "rökring",
    "rökrockar": "rökrock",
    "rökrockarna": "rökrock",
    "rökrockarnas": "rökrock",
    "rökrockars": "rökrock",
    "rökrocken": "rökrock",
    "rökrockens": "rökrock",
    "rökrocks": "rökrock",
    "rökrutan": "rökruta",
    "rökrutans": "rökruta",
    "rökrutas": "rökruta",
    "rökrute": "rökruta",
    "rökrutor": "rökruta",
    "rökrutorna": "rökruta",
    "rökrutornas": "rökruta",
    "rökrutors": "rökruta",
    "röks": "röka",
    "rökskadade": "rökskadad",
    "rökskadades": "rökskadad",
    "rökskadads": "rökskadad",
    "rökskadat": "rökskadad",
    "rökskadats": "rökskadad",
    "rökspiralen": "rökspiral",
    "rökspiralens": "rökspiral",
    "rökspiraler": "rökspiral",
    "rökspiralerna": "rökspiral",
    "rökspiralernas": "rökspiral",
    "rökspiralers": "rökspiral",
    "rökspirals": "rökspiral",
    "röksugens": "röksugen",
    "röksuget": "röksugen",
    "röksugets": "röksugen",
    "röksugna": "röksugen",
    "röksugnare": "röksugen",
    "röksugnares": "röksugen",
    "röksugnas": "röksugen",
    "röksugnast": "röksugen",
    "röksugnaste": "röksugen",
    "röksugnastes": "röksugen",
    "röksugnasts": "röksugen",
    "röksugne": "röksugen",
    "röksugnes": "röksugen",
    "röksvaga": "röksvag",
    "röksvagare": "röksvag",
    "röksvagares": "röksvag",
    "röksvagas": "röksvag",
    "röksvagast": "röksvag",
    "röksvagaste": "röksvag",
    "röksvagastes": "röksvag",
    "röksvagasts": "röksvag",
    "röksvage": "röksvag",
    "röksvages": "röksvag",
    "röksvagheten": "röksvaghet",
    "röksvaghetens": "röksvaghet",
    "röksvaghets": "röksvaghet",
    "röksvags": "röksvag",
    "röksvagt": "röksvag",
    "röksvagts": "röksvag",
    "röksvampar": "röksvamp",
    "röksvamparna": "röksvamp",
    "röksvamparnas": "röksvamp",
    "röksvampars": "röksvamp",
    "röksvampen": "röksvamp",
    "röksvampens": "röksvamp",
    "röksvamps": "röksvamp",
    "röksvärtade": "röksvärtad",
    "röksvärtades": "röksvärtad",
    "röksvärtads": "röksvärtad",
    "röksvärtat": "röksvärtad",
    "röksvärtats": "röksvärtad",
    "rökt": "röka",
    "rökta": "rökt",
    "röktare": "rökt",
    "röktares": "rökt",
    "röktas": "rökt",
    "röktast": "rökt",
    "röktaste": "rökt",
    "röktastes": "rökt",
    "röktasts": "rökt",
    "rökte": "rökt",
    "röktes": "rökt",
    "röktheten": "rökthet",
    "rökthetens": "rökthet",
    "rökthets": "rökthet",
    "röktopasen": "röktopas",
    "röktopasens": "röktopas",
    "röktopaser": "röktopas",
    "röktopaserna": "röktopas",
    "röktopasernas": "röktopas",
    "röktopasers": "röktopas",
    "rökts": "rökt",
    "rökverket": "rökverk",
    "rökverkets": "rökverk",
    "rökverks": "rökverk",
    "rölakanet": "rölakan",
    "rölakanets": "rölakan",
    "rölakans": "rölakan",
    "röllakanet": "röllakan",
    "röllakanets": "röllakan",
    "röllakans": "röllakan",
    "röllekan": "rölleka",
    "röllekans": "rölleka",
    "röllekas": "rölleka",
    "röllekor": "rölleka",
    "röllekorna": "rölleka",
    "röllekornas": "rölleka",
    "röllekors": "rölleka",
    "röllikan": "röllika",
    "röllikans": "röllika",
    "röllikas": "röllika",
    "röllikor": "röllika",
    "röllikorna": "röllika",
    "röllikornas": "röllika",
    "röllikors": "röllika",
    "rön": "röna",
    "röna": "rö",
    "rönande": "röna",
    "rönanden": "rönande",
    "rönandena": "rönande",
    "rönandenas": "rönande",
    "rönandens": "rönande",
    "rönandes": "rönande",
    "rönandet": "rönande",
    "rönandets": "rönande",
    "rönas": "röna",
    "rönen": "rön",
    "rönens": "rön",
    "röner": "röna",
    "rönes": "röna",
    "rönet": "rön",
    "rönets": "rön",
    "rönnar": "rönn",
    "rönnarna": "rönn",
    "rönnarnas": "rönn",
    "rönnars": "rönn",
    "rönnbären": "rönnbär",
    "rönnbärens": "rönnbär",
    "rönnbäret": "rönnbär",
    "rönnbärets": "rönnbär",
    "rönnbärs": "rönnbär",
    "rönnbärsfilosofien": "rönnbärsfilosofi",
    "rönnbärsfilosofiens": "rönnbärsfilosofi",
    "rönnbärsfilosofin": "rönnbärsfilosofi",
    "rönnbärsfilosofins": "rönnbärsfilosofi",
    "rönnbärsfilosofis": "rönnbärsfilosofi",
    "rönnen": "rönn",
    "rönnens": "rönn",
    "rönns": "rönn",
    "röns": "röna",
    "rönt": "röna",
    "rönta": "röna",
    "röntas": "röna",
    "rönte": "röna",
    "röntes": "röna",
    "röntg": "röntga",
    "röntgad": "röntga",
    "röntgade": "röntga",
    "röntgades": "röntga",
    "röntgads": "röntga",
    "röntgande": "röntga",
    "röntganden": "röntgande",
    "röntgandena": "röntgande",
    "röntgandenas": "röntgande",
    "röntgandens": "röntgande",
    "röntgandes": "röntgande",
    "röntgandet": "röntgande",
    "röntgandets": "röntgande",
    "röntgar": "röntga",
    "röntgas": "röntga",
    "röntgat": "röntga",
    "röntgats": "röntga",
    "röntgenapparaten": "röntgenapparat",
    "röntgenapparatens": "röntgenapparat",
    "röntgenapparater": "röntgenapparat",
    "röntgenapparaterna": "röntgenapparat",
    "röntgenapparaternas": "röntgenapparat",
    "röntgenapparaters": "röntgenapparat",
    "röntgenapparats": "röntgenapparat",
    "röntgenbehandlingar": "röntgenbehandling",
    "röntgenbehandlingarna": "röntgenbehandling",
    "röntgenbehandlingarnas": "röntgenbehandling",
    "röntgenbehandlingars": "röntgenbehandling",
    "röntgenbehandlingen": "röntgenbehandling",
    "röntgenbehandlingens": "röntgenbehandling",
    "röntgenbehandlings": "röntgenbehandling",
    "röntgenbilden": "röntgenbild",
    "röntgenbildens": "röntgenbild",
    "röntgenbilder": "röntgenbild",
    "röntgenbilderna": "röntgenbild",
    "röntgenbildernas": "röntgenbild",
    "röntgenbilders": "röntgenbild",
    "röntgenbilds": "röntgenbild",
    "röntgenblicken": "röntgenblick",
    "röntgenblickens": "röntgenblick",
    "röntgenblicks": "röntgenblick",
    "röntgendiagnostiken": "röntgendiagnostik",
    "röntgendiagnostikens": "röntgendiagnostik",
    "röntgendiagnostiks": "röntgendiagnostik",
    "röntgenen": "röntgen",
    "röntgenens": "röntgen",
    "röntgenfotograferad": "röntgenfotografera",
    "röntgenfotograferade": "röntgenfotografera",
    "röntgenfotograferades": "röntgenfotografera",
    "röntgenfotograferads": "röntgenfotografera",
    "röntgenfotograferande": "röntgenfotografera",
    "röntgenfotograferanden": "röntgenfotograferande",
    "röntgenfotograferandena": "röntgenfotograferande",
    "röntgenfotograferandenas": "röntgenfotograferande",
    "röntgenfotograferandens": "röntgenfotograferande",
    "röntgenfotograferandes": "röntgenfotograferande",
    "röntgenfotograferandet": "röntgenfotograferande",
    "röntgenfotograferandets": "röntgenfotograferande",
    "röntgenfotograferar": "röntgenfotografera",
    "röntgenfotograferas": "röntgenfotografera",
    "röntgenfotograferat": "röntgenfotografera",
    "röntgenfotograferats": "röntgenfotografera",
    "röntgenfotograferbara": "röntgenfotograferbar",
    "röntgenfotograferbarare": "röntgenfotograferbar",
    "röntgenfotograferbarares": "röntgenfotograferbar",
    "röntgenfotograferbaras": "röntgenfotograferbar",
    "röntgenfotograferbarast": "röntgenfotograferbar",
    "röntgenfotograferbaraste": "röntgenfotograferbar",
    "röntgenfotograferbarastes": "röntgenfotograferbar",
    "röntgenfotograferbarasts": "röntgenfotograferbar",
    "röntgenfotograferbare": "röntgenfotograferbar",
    "röntgenfotograferbares": "röntgenfotograferbar",
    "röntgenfotograferbarheten": "röntgenfotograferbarhet",
    "röntgenfotograferbarhetens": "röntgenfotograferbarhet",
    "röntgenfotograferbarhets": "röntgenfotograferbarhet",
    "röntgenfotograferbars": "röntgenfotograferbar",
    "röntgenfotograferbart": "röntgenfotograferbar",
    "röntgenfotograferbarts": "röntgenfotograferbar",
    "röntgenfotograferingar": "röntgenfotografering",
    "röntgenfotograferingarna": "röntgenfotografering",
    "röntgenfotograferingarnas": "röntgenfotografering",
    "röntgenfotograferingars": "röntgenfotografering",
    "röntgenfotograferingen": "röntgenfotografering",
    "röntgenfotograferingens": "röntgenfotografering",
    "röntgenfotograferings": "röntgenfotografering",
    "röntgenkameran": "röntgenkamera",
    "röntgenkamerans": "röntgenkamera",
    "röntgenkameras": "röntgenkamera",
    "röntgenkameror": "röntgenkamera",
    "röntgenkamerorna": "röntgenkamera",
    "röntgenkamerornas": "röntgenkamera",
    "röntgenkamerors": "röntgenkamera",
    "röntgenmikroskopen": "röntgenmikroskop",
    "röntgenmikroskopens": "röntgenmikroskop",
    "röntgenmikroskopet": "röntgenmikroskop",
    "röntgenmikroskopets": "röntgenmikroskop",
    "röntgenmikroskops": "röntgenmikroskop",
    "röntgenrören": "röntgenrör",
    "röntgenrörens": "röntgenrör",
    "röntgenröret": "röntgenrör",
    "röntgenrörets": "röntgenrör",
    "röntgenrörs": "röntgenrör",
    "röntgenstrålningar": "röntgenstrålning",
    "röntgenstrålningarna": "röntgenstrålning",
    "röntgenstrålningarnas": "röntgenstrålning",
    "röntgenstrålningars": "röntgenstrålning",
    "röntgenstrålningen": "röntgenstrålning",
    "röntgenstrålningens": "röntgenstrålning",
    "röntgenstrålnings": "röntgenstrålning",
    "röntgenundersökningar": "röntgenundersökning",
    "röntgenundersökningarna": "röntgenundersökning",
    "röntgenundersökningarnas": "röntgenundersökning",
    "röntgenundersökningars": "röntgenundersökning",
    "röntgenundersökningen": "röntgenundersökning",
    "röntgenundersökningens": "röntgenundersökning",
    "röntgenundersöknings": "röntgenundersökning",
    "rönts": "röna",
    "rör": "röra",
    "rör-mig-ejen": "rör-mig-ej",
    "rör-mig-ejens": "rör-mig-ej",
    "rör-mig-ejs": "rör-mig-ej",
    "röran": "röra",
    "rörande": "röra",
    "röranden": "rörande",
    "rörandena": "rörande",
    "rörandenas": "rörande",
    "rörandens": "rörande",
    "rörandes": "rörande",
    "rörandet": "rörande",
    "rörandets": "rörande",
    "rörans": "röra",
    "röras": "röra",
    "rörbladen": "rörblad",
    "rörbladens": "rörblad",
    "rörbladet": "rörblad",
    "rörbladets": "rörblad",
    "rörblads": "rörblad",
    "rörd": "röra",
    "rörda": "rörd",
    "rördare": "rörd",
    "rördares": "rörd",
    "rördas": "rörd",
    "rördast": "rörd",
    "rördaste": "rörd",
    "rördastes": "rörd",
    "rördasts": "rörd",
    "rörde": "rörd",
    "rördes": "rörd",
    "rördheten": "rördhet",
    "rördhetens": "rördhet",
    "rördhets": "rördhet",
    "rördrommar": "rördrom",
    "rördrommarna": "rördrom",
    "rördrommarnas": "rördrom",
    "rördrommars": "rördrom",
    "rördrommen": "rördrom",
    "rördrommens": "rördrom",
    "rördroms": "rördrom",
    "rörds": "rörd",
    "rörelsecentra": "rörelsecentrum",
    "rörelsecentrana": "rörelsecentrum",
    "rörelsecentranas": "rörelsecentrum",
    "rörelsecentras": "rörelsecentrum",
    "rörelsecentrer": "rörelsecentrum",
    "rörelsecentrerna": "rörelsecentrum",
    "rörelsecentrernas": "rörelsecentrum",
    "rörelsecentrers": "rörelsecentrum",
    "rörelsecentret": "rörelsecentrum",
    "rörelsecentrets": "rörelsecentrum",
    "rörelsecentrumen": "rörelsecentrum",
    "rörelsecentrumens": "rörelsecentrum",
    "rörelsecentrumet": "rörelsecentrum",
    "rörelsecentrumets": "rörelsecentrum",
    "rörelsecentrums": "rörelsecentrum",
    "rörelsedetektorer": "rörelsedetektor",
    "rörelsedetektorerna": "rörelsedetektor",
    "rörelsedetektorernas": "rörelsedetektor",
    "rörelsedetektorers": "rörelsedetektor",
    "rörelsedetektorn": "rörelsedetektor",
    "rörelsedetektorns": "rörelsedetektor",
    "rörelsedetektors": "rörelsedetektor",
    "rörelseenergien": "rörelseenergi",
    "rörelseenergiens": "rörelseenergi",
    "rörelseenergin": "rörelseenergi",
    "rörelseenergins": "rörelseenergi",
    "rörelseenergis": "rörelseenergi",
    "rörelsefriheten": "rörelsefrihet",
    "rörelsefrihetens": "rörelsefrihet",
    "rörelsefriheter": "rörelsefrihet",
    "rörelsefriheterna": "rörelsefrihet",
    "rörelsefriheternas": "rörelsefrihet",
    "rörelsefriheters": "rörelsefrihet",
    "rörelsefrihets": "rörelsefrihet",
    "rörelsehindrade": "rörelsehindrad",
    "rörelsehindrades": "rörelsehindrad",
    "rörelsehindrads": "rörelsehindrad",
    "rörelsehindrat": "rörelsehindrad",
    "rörelsehindrats": "rörelsehindrad",
    "rörelseinkomsten": "rörelseinkomst",
    "rörelseinkomstens": "rörelseinkomst",
    "rörelseinkomster": "rörelseinkomst",
    "rörelseinkomsterna": "rörelseinkomst",
    "rörelseinkomsternas": "rörelseinkomst",
    "rörelseinkomsters": "rörelseinkomst",
    "rörelseinkomsts": "rörelseinkomst",
    "rörelsekapitalen": "rörelsekapital",
    "rörelsekapitalens": "rörelsekapital",
    "rörelsekapitalet": "rörelsekapital",
    "rörelsekapitalets": "rörelsekapital",
    "rörelsekapitals": "rörelsekapital",
    "rörelsekommandon": "rörelsekommando",
    "rörelsekommandona": "rörelsekommando",
    "rörelsekommandonas": "rörelsekommando",
    "rörelsekommandons": "rörelsekommando",
    "rörelsekommandos": "rörelsekommando",
    "rörelsekommandot": "rörelsekommando",
    "rörelsekommandots": "rörelsekommando",
    "rörelsemängden": "rörelsemängd",
    "rörelsemängdens": "rörelsemängd",
    "rörelsemängder": "rörelsemängd",
    "rörelsemängderna": "rörelsemängd",
    "rörelsemängdernas": "rörelsemängd",
    "rörelsemängders": "rörelsemängd",
    "rörelsemängds": "rörelsemängd",
    "rörelsemängdsmomenten": "rörelsemängdsmoment",
    "rörelsemängdsmomentens": "rörelsemängdsmoment",
    "rörelsemängdsmomentet": "rörelsemängdsmoment",
    "rörelsemängdsmomentets": "rörelsemängdsmoment",
    "rörelsemängdsmoments": "rörelsemängdsmoment",
    "rörelsemässiga": "rörelsemässig",
    "rörelsemässigare": "rörelsemässig",
    "rörelsemässigares": "rörelsemässig",
    "rörelsemässigas": "rörelsemässig",
    "rörelsemässigast": "rörelsemässig",
    "rörelsemässigaste": "rörelsemässig",
    "rörelsemässigastes": "rörelsemässig",
    "rörelsemässigasts": "rörelsemässig",
    "rörelsemässige": "rörelsemässig",
    "rörelsemässiges": "rörelsemässig",
    "rörelsemässigs": "rörelsemässig",
    "rörelsemässigt": "rörelsemässig",
    "rörelsemässigts": "rörelsemässig",
    "rörelsemönsterna": "rörelsemönster",
    "rörelsemönsternas": "rörelsemönster",
    "rörelsemönsters": "rörelsemönster",
    "rörelsemönstren": "rörelsemönster",
    "rörelsemönstrens": "rörelsemönster",
    "rörelsemönstret": "rörelsemönster",
    "rörelsemönstrets": "rörelsemönster",
    "rörelsen": "rörelse",
    "rörelsens": "rörelse",
    "rörelser": "rörelse",
    "rörelseriktningar": "rörelseriktning",
    "rörelseriktningarna": "rörelseriktning",
    "rörelseriktningarnas": "rörelseriktning",
    "rörelseriktningars": "rörelseriktning",
    "rörelseriktningen": "rörelseriktning",
    "rörelseriktningens": "rörelseriktning",
    "rörelseriktnings": "rörelseriktning",
    "rörelserna": "rörelse",
    "rörelsernas": "rörelse",
    "rörelsers": "rörelse",
    "rörelses": "rörelse",
    "rörelsesinnen": "rörelsesinne",
    "rörelsesinnena": "rörelsesinne",
    "rörelsesinnenas": "rörelsesinne",
    "rörelsesinnens": "rörelsesinne",
    "rörelsesinnes": "rörelsesinne",
    "rörelsesinnet": "rörelsesinne",
    "rörelsesinnets": "rörelsesinne",
    "rörelsesinns": "rörelsesinne",
    "rörelsesjukan": "rörelsesjuka",
    "rörelsesjukans": "rörelsesjuka",
    "rörelsesjukas": "rörelsesjuka",
    "rörelsesjuke": "rörelsesjuka",
    "rörelsesjuks": "rörelsesjuka",
    "rörelsestörningar": "rörelsestörning",
    "rörelsestörningarna": "rörelsestörning",
    "rörelsestörningarnas": "rörelsestörning",
    "rörelsestörningars": "rörelsestörning",
    "rörelsestörningen": "rörelsestörning",
    "rörelsestörningens": "rörelsestörning",
    "rörelsestörnings": "rörelsestörning",
    "rörelsesvårigheten": "rörelsesvårighet",
    "rörelsesvårighetens": "rörelsesvårighet",
    "rörelsesvårigheter": "rörelsesvårighet",
    "rörelsesvårigheterna": "rörelsesvårighet",
    "rörelsesvårigheternas": "rörelsesvårighet",
    "rörelsesvårigheters": "rörelsesvårighet",
    "rörelsesvårighets": "rörelsesvårighet",
    "rörelsevinsten": "rörelsevinst",
    "rörelsevinstens": "rörelsevinst",
    "rörelsevinster": "rörelsevinst",
    "rörelsevinsterna": "rörelsevinst",
    "rörelsevinsternas": "rörelsevinst",
    "rörelsevinsters": "rörelsevinst",
    "rörelsevinsts": "rörelsevinst",
    "rören": "rör",
    "rörens": "rör",
    "röres": "röra",
    "röret": "rör",
    "rörets": "rör",
    "röriga": "rörig",
    "rörigare": "rörig",
    "rörigares": "rörig",
    "rörigas": "rörig",
    "rörigast": "rörig",
    "rörigaste": "rörig",
    "rörigastes": "rörig",
    "rörigasts": "rörig",
    "rörige": "rörig",
    "röriges": "rörig",
    "rörigs": "rörig",
    "rörigt": "rörig",
    "rörigts": "rörig",
    "röringar": "röring",
    "röringarna": "röring",
    "röringarnas": "röring",
    "röringars": "röring",
    "röringen": "röring",
    "röringens": "röring",
    "rörings": "röring",
    "rörknipp": "rörknippe",
    "rörknippen": "rörknippe",
    "rörknippena": "rörknippe",
    "rörknippenas": "rörknippe",
    "rörknippens": "rörknippe",
    "rörknippes": "rörknippe",
    "rörknippet": "rörknippe",
    "rörknippets": "rörknippe",
    "rörknipps": "rörknippe",
    "rörledningar": "rörledning",
    "rörledningarna": "rörledning",
    "rörledningarnas": "rörledning",
    "rörledningars": "rörledning",
    "rörledningen": "rörledning",
    "rörledningens": "rörledning",
    "rörlednings": "rörledning",
    "rörliga": "rörlig",
    "rörligare": "rörlig",
    "rörligares": "rörlig",
    "rörligas": "rörlig",
    "rörligast": "rörlig",
    "rörligaste": "rörlig",
    "rörligastes": "rörlig",
    "rörligasts": "rörlig",
    "rörlige": "rörlig",
    "rörliges": "rörlig",
    "rörligheten": "rörlighet",
    "rörlighetens": "rörlighet",
    "rörligheter": "rörlighet",
    "rörligheterna": "rörlighet",
    "rörligheternas": "rörlighet",
    "rörligheters": "rörlighet",
    "rörlighets": "rörlighet",
    "rörligs": "rörlig",
    "rörligt": "rörlig",
    "rörligts": "rörlig",
    "rörläggar": "rörläggare",
    "rörläggaren": "rörläggare",
    "rörläggarens": "rörläggare",
    "rörläggares": "rörläggare",
    "rörläggarna": "rörläggare",
    "rörläggarnas": "rörläggare",
    "rörmigejen": "rörmigej",
    "rörmigejens": "rörmigej",
    "rörmigejs": "rörmigej",
    "rörmokar": "rörmokare",
    "rörmokaren": "rörmokare",
    "rörmokarens": "rörmokare",
    "rörmokares": "rörmokare",
    "rörmokarna": "rörmokare",
    "rörmokarnas": "rörmokare",
    "rörmontören": "rörmontör",
    "rörmontörens": "rörmontör",
    "rörmontörer": "rörmontör",
    "rörmontörerna": "rörmontör",
    "rörmontörernas": "rörmontör",
    "rörmontörers": "rörmontör",
    "rörmontörs": "rörmontör",
    "rörposten": "rörpost",
    "rörpostens": "rörpost",
    "rörposts": "rörpost",
    "rörs": "röra",
    "rörsockers": "rörsocker",
    "rörsockret": "rörsocker",
    "rörsockrets": "rörsocker",
    "rörsoppar": "rörsopp",
    "rörsopparna": "rörsopp",
    "rörsopparnas": "rörsopp",
    "rörsoppars": "rörsopp",
    "rörsoppen": "rörsopp",
    "rörsoppens": "rörsopp",
    "rörsopps": "rörsopp",
    "rörspisar": "rörspis",
    "rörspisarna": "rörspis",
    "rörspisarnas": "rörspis",
    "rörspisars": "rörspis",
    "rörspisen": "rörspis",
    "rörspisens": "rörspis",
    "rörsvampar": "rörsvamp",
    "rörsvamparna": "rörsvamp",
    "rörsvamparnas": "rörsvamp",
    "rörsvampars": "rörsvamp",
    "rörsvampen": "rörsvamp",
    "rörsvampens": "rörsvamp",
    "rörsvamps": "rörsvamp",
    "rörsångar": "rörsångare",
    "rörsångaren": "rörsångare",
    "rörsångarens": "rörsångare",
    "rörsångares": "rörsångare",
    "rörsångarna": "rörsångare",
    "rörsångarnas": "rörsångare",
    "rört": "rörd",
    "rörts": "rörd",
    "rörtänger": "rörtång",
    "rörtängerna": "rörtång",
    "rörtängernas": "rörtång",
    "rörtängers": "rörtång",
    "rörtången": "rörtång",
    "rörtångens": "rörtång",
    "rörtångs": "rörtång",
    "rös": "rysa",
    "rösad": "rösa",
    "rösade": "rösa",
    "rösades": "rösa",
    "rösads": "rösa",
    "rösande": "rösa",
    "rösanden": "rösande",
    "rösandena": "rösande",
    "rösandenas": "rösande",
    "rösandens": "rösande",
    "rösandes": "rösande",
    "rösandet": "rösande",
    "rösandets": "rösande",
    "rösar": "rösa",
    "rösas": "rösa",
    "rösat": "rösa",
    "rösats": "rösa",
    "röse": "rysa",
    "rösen": "röse",
    "rösena": "röse",
    "rösenas": "röse",
    "rösens": "röse",
    "röses": "rysa",
    "röset": "röse",
    "rösets": "röse",
    "röst": "röste",
    "röstade": "rösta",
    "röstades": "rösta",
    "röstande": "rösta",
    "röstanden": "röstande",
    "röstandena": "röstande",
    "röstandenas": "röstande",
    "röstandens": "röstande",
    "röstandes": "röstande",
    "röstandet": "röstande",
    "röstandets": "röstande",
    "röstar": "rösta",
    "röstas": "rösta",
    "röstat": "rösta",
    "röstats": "rösta",
    "röstberättigade": "röstberättigad",
    "röstberättigades": "röstberättigad",
    "röstberättigads": "röstberättigad",
    "röstberättigat": "röstberättigad",
    "röstberättigats": "röstberättigad",
    "röstcoachar": "röstcoach",
    "röstcoacharna": "röstcoach",
    "röstcoacharnas": "röstcoach",
    "röstcoachars": "röstcoach",
    "röstcoachen": "röstcoach",
    "röstcoachens": "röstcoach",
    "röstcoacher": "röstcoach",
    "röstcoacherna": "röstcoach",
    "röstcoachernas": "röstcoach",
    "röstcoachers": "röstcoach",
    "röstcoachs": "röstcoach",
    "rösten": "röste",
    "röstena": "röste",
    "röstenas": "röste",
    "röstens": "röste",
    "röster": "röst",
    "rösterna": "röst",
    "rösternas": "röst",
    "rösters": "röst",
    "röstes": "röste",
    "röstet": "röste",
    "röstetalen": "röstetal",
    "röstetalens": "röstetal",
    "röstetalet": "röstetal",
    "röstetalets": "röstetal",
    "röstetals": "röstetal",
    "röstets": "röste",
    "röstfiskes": "röstfiske",
    "röstfisket": "röstfiske",
    "röstfiskets": "röstfiske",
    "röstjärnen": "röstjärn",
    "röstjärnens": "röstjärn",
    "röstjärnet": "röstjärn",
    "röstjärnets": "röstjärn",
    "röstjärns": "röstjärn",
    "röstkaosen": "röstkaos",
    "röstkaosens": "röstkaos",
    "röstkaoset": "röstkaos",
    "röstkaosets": "röstkaos",
    "röstkorten": "röstkort",
    "röstkortens": "röstkort",
    "röstkortet": "röstkort",
    "röstkortets": "röstkort",
    "röstkorts": "röstkort",
    "röstlägen": "röstläge",
    "röstlägena": "röstläge",
    "röstlägenas": "röstläge",
    "röstlägens": "röstläge",
    "röstläges": "röstläge",
    "röstläget": "röstläge",
    "röstlägets": "röstläge",
    "röstlängden": "röstlängd",
    "röstlängdens": "röstlängd",
    "röstlängder": "röstlängd",
    "röstlängderna": "röstlängd",
    "röstlängdernas": "röstlängd",
    "röstlängders": "röstlängd",
    "röstlängds": "röstlängd",
    "röstmaximerade": "röstmaximera",
    "röstmaximerades": "röstmaximera",
    "röstmaximerande": "röstmaximera",
    "röstmaximeranden": "röstmaximerande",
    "röstmaximerandena": "röstmaximerande",
    "röstmaximerandenas": "röstmaximerande",
    "röstmaximerandens": "röstmaximerande",
    "röstmaximerandes": "röstmaximerande",
    "röstmaximerandet": "röstmaximerande",
    "röstmaximerandets": "röstmaximerande",
    "röstmaximerar": "röstmaximera",
    "röstmaximeras": "röstmaximera",
    "röstmaximerat": "röstmaximera",
    "röstmaximerats": "röstmaximera",
    "röstmässiga": "röstmässig",
    "röstmässigare": "röstmässig",
    "röstmässigares": "röstmässig",
    "röstmässigas": "röstmässig",
    "röstmässigast": "röstmässig",
    "röstmässigaste": "röstmässig",
    "röstmässigastes": "röstmässig",
    "röstmässigasts": "röstmässig",
    "röstmässige": "röstmässig",
    "röstmässiges": "röstmässig",
    "röstmässigs": "röstmässig",
    "röstmässigt": "röstmässig",
    "röstmässigts": "röstmässig",
    "röstningar": "röstning",
    "röstningarna": "röstning",
    "röstningarnas": "röstning",
    "röstningars": "röstning",
    "röstningen": "röstning",
    "röstningens": "röstning",
    "röstnings": "röstning",
    "röstresurs": "röstresurser",
    "röstresurserna": "röstresurser",
    "röstresursernas": "röstresurser",
    "röstresursers": "röstresurser",
    "rösträkningar": "rösträkning",
    "rösträkningarna": "rösträkning",
    "rösträkningarnas": "rösträkning",
    "rösträkningars": "rösträkning",
    "rösträkningen": "rösträkning",
    "rösträkningens": "rösträkning",
    "rösträknings": "rösträkning",
    "rösträkningsmaskinen": "rösträkningsmaskin",
    "rösträkningsmaskinens": "rösträkningsmaskin",
    "rösträkningsmaskiner": "rösträkningsmaskin",
    "rösträkningsmaskinerna": "rösträkningsmaskin",
    "rösträkningsmaskinernas": "rösträkningsmaskin",
    "rösträkningsmaskiners": "rösträkningsmaskin",
    "rösträkningsmaskins": "rösträkningsmaskin",
    "rösträtten": "rösträtt",
    "rösträttens": "rösträtt",
    "rösträtts": "rösträtt",
    "rösträttsfrågan": "rösträttsfråga",
    "rösträttsfrågans": "rösträttsfråga",
    "rösträttsfrågas": "rösträttsfråga",
    "rösträttsfråge": "rösträttsfråga",
    "rösträttsfrågor": "rösträttsfråga",
    "rösträttsfrågorna": "rösträttsfråga",
    "rösträttsfrågornas": "rösträttsfråga",
    "rösträttsfrågors": "rösträttsfråga",
    "rösts": "röst",
    "röstsedeln": "röstsedel",
    "röstsedelns": "röstsedel",
    "röstsedels": "röstsedel",
    "röstsedlar": "röstsedel",
    "röstsedlarna": "röstsedel",
    "röstsedlarnas": "röstsedel",
    "röstsedlars": "röstsedel",
    "röstspring": "röstspringa",
    "röstspringan": "röstspringa",
    "röstspringans": "röstspringa",
    "röstspringas": "röstspringa",
    "röstspringe": "röstspringa",
    "röstspringor": "röstspringa",
    "röstspringorna": "röstspringa",
    "röstspringornas": "röstspringa",
    "röstspringors": "röstspringa",
    "röstsprings": "röstspringa",
    "röststyrkan": "röststyrka",
    "röststyrkans": "röststyrka",
    "röststyrkas": "röststyrka",
    "röststyrke": "röststyrka",
    "röststyrkor": "röststyrka",
    "röststyrkorna": "röststyrka",
    "röststyrkornas": "röststyrka",
    "röststyrkors": "röststyrka",
    "röt": "ryta",
    "rötan": "röta",
    "rötans": "röta",
    "rötas": "röta",
    "rötkammar": "rötkammare",
    "rötkammaren": "rötkammare",
    "rötkammarens": "rötkammare",
    "rötkammares": "rötkammare",
    "rötkamrar": "rötkammare",
    "rötkamrarna": "rötkammare",
    "rötkamrarnas": "rötkammare",
    "rötkamrars": "rötkammare",
    "rötmånaden": "rötmånad",
    "rötmånadens": "rötmånad",
    "rötmånader": "rötmånad",
    "rötmånaderna": "rötmånad",
    "rötmånadernas": "rötmånad",
    "rötmånaders": "rötmånad",
    "rötmånads": "rötmånad",
    "röts": "ryta",
    "rötslammet": "rötslam",
    "rötslammets": "rötslam",
    "rötslams": "rötslam",
    "rött": "röd",
    "rötter": "rot",
    "rötterna": "rötter",
    "rötternas": "rötter",
    "rötters": "rötter",
    "rötts": "röd",
    "rötäggen": "rötägg",
    "rötäggens": "rötägg",
    "rötägget": "rötägg",
    "rötäggets": "rötägg",
    "rötäggs": "rötägg",
    "rövad": "röva",
    "rövade": "röva",
    "rövades": "röva",
    "rövads": "röva",
    "rövande": "röva",
    "rövanden": "rövande",
    "rövandena": "rövande",
    "rövandenas": "rövande",
    "rövandens": "rövande",
    "rövandes": "rövande",
    "rövandet": "rövande",
    "rövandets": "rövande",
    "rövar": "rövare",
    "rövaren": "rövare",
    "rövarens": "rövare",
    "rövares": "rövare",
    "rövarhistorian": "rövarhistoria",
    "rövarhistorians": "rövarhistoria",
    "rövarhistorias": "rövarhistoria",
    "rövarhistorien": "rövarhistoria",
    "rövarhistoriens": "rövarhistoria",
    "rövarhistorier": "rövarhistoria",
    "rövarhistorierna": "rövarhistoria",
    "rövarhistoriernas": "rövarhistoria",
    "rövarhistoriers": "rövarhistoria",
    "rövarlivet": "rövarliv",
    "rövarlivets": "rövarliv",
    "rövarlivs": "rövarliv",
    "rövarna": "rövare",
    "rövarnas": "rövare",
    "rövarprisen": "rövarpris",
    "rövarprisens": "rövarpris",
    "rövarpriser": "rövarpris",
    "rövarpriserna": "rövarpris",
    "rövarprisernas": "rövarpris",
    "rövarprisers": "rövarpris",
    "rövarpriset": "rövarpris",
    "rövarprisets": "rövarpris",
    "rövars": "röv",
    "rövarspråket": "rövarspråk",
    "rövarspråkets": "rövarspråk",
    "rövarspråks": "rövarspråk",
    "rövas": "röva",
    "rövat": "röva",
    "rövats": "röva",
    "röven": "röv",
    "rövens": "röv",
    "röverier": "röveri",
    "röverierna": "röveri",
    "röveriernas": "röveri",
    "röveriers": "röveri",
    "röveriet": "röveri",
    "röveriets": "röveri",
    "röveris": "röveri",
    "röverit": "röveri",
    "röverits": "röveri",
    "rövhålen": "rövhål",
    "rövhålens": "rövhål",
    "rövhålet": "rövhål",
    "rövhålets": "rövhål",
    "rövhåls": "rövhål",
    "rövknull": "rövknulla",
    "rövknullad": "rövknulla",
    "rövknullade": "rövknulla",
    "rövknullades": "rövknulla",
    "rövknullads": "rövknulla",
    "rövknullande": "rövknulla",
    "rövknullanden": "rövknullande",
    "rövknullandena": "rövknullande",
    "rövknullandenas": "rövknullande",
    "rövknullandens": "rövknullande",
    "rövknullandes": "rövknullande",
    "rövknullandet": "rövknullande",
    "rövknullandets": "rövknullande",
    "rövknullar": "rövknulla",
    "rövknullas": "rövknulla",
    "rövknullat": "rövknulla",
    "rövknullats": "rövknulla",
    "rövs": "röv",
    "rövslickar": "rövslickare",
    "rövslickaren": "rövslickare",
    "rövslickarens": "rövslickare",
    "rövslickares": "rövslickare",
    "rövslickarna": "rövslickare",
    "rövslickarnas": "rövslickare",
    "rövtrakten": "rövtrakt",
    "rövtraktens": "rövtrakt",
    "rövtrakter": "rövtrakt",
    "rövtrakterna": "rövtrakt",
    "rövtrakternas": "rövtrakt",
    "rövtrakters": "rövtrakt",
    "rövtrakts": "rövtrakt",
    "s-en": "s",
    "s-ens": "s",
    "s-et": "s",
    "s-ets": "s",
    "s-formade": "s-formad",
    "s-formades": "s-formad",
    "s-formads": "s-formad",
    "s-format": "s-formad",
    "s-formats": "s-formad",
    "s-kurv": "s-kurva",
    "s-kurvan": "s-kurva",
    "s-kurvans": "s-kurva",
    "s-kurvas": "s-kurva",
    "s-kurve": "s-kurva",
    "s-kurvor": "s-kurva",
    "s-kurvorna": "s-kurva",
    "s-kurvornas": "s-kurva",
    "s-kurvors": "s-kurva",
    "s-kurvs": "s-kurva",
    "s-s": "s",
    "s:en": "s",
    "s:ens": "s",
    "s:et": "s",
    "s:ets": "s",
    "s:s": "s",
    "sa": "säga",
    "saabar": "saab",
    "saabarnas": "saab",
    "saaben": "saab",
    "saabs": "saab",
    "sabadillen": "sabadill",
    "sabadillens": "sabadill",
    "sabadiller": "sabadill",
    "sabadillerna": "sabadill",
    "sabadillernas": "sabadill",
    "sabadillers": "sabadill",
    "sabadills": "sabadill",
    "sabadillättikan": "sabadillättika",
    "sabadillättikans": "sabadillättika",
    "sabadillättikas": "sabadillättika",
    "sabbad": "sabba",
    "sabbade": "sabba",
    "sabbades": "sabba",
    "sabbads": "sabba",
    "sabbande": "sabba",
    "sabbanden": "sabbande",
    "sabbandena": "sabbande",
    "sabbandenas": "sabbande",
    "sabbandens": "sabbande",
    "sabbandes": "sabbande",
    "sabbandet": "sabbande",
    "sabbandets": "sabbande",
    "sabbar": "sabba",
    "sabbas": "sabba",
    "sabbat": "sabba",
    "sabbaten": "sabbat",
    "sabbatens": "sabbat",
    "sabbater": "sabbat",
    "sabbaterna": "sabbat",
    "sabbaternas": "sabbat",
    "sabbaters": "sabbat",
    "sabbats": "sabbat",
    "sabbatsbrotten": "sabbatsbrott",
    "sabbatsbrottens": "sabbatsbrott",
    "sabbatsbrottet": "sabbatsbrott",
    "sabbatsbrottets": "sabbatsbrott",
    "sabbatsbrotts": "sabbatsbrott",
    "sabbatsterminen": "sabbatstermin",
    "sabbatsterminens": "sabbatstermin",
    "sabbatsterminer": "sabbatstermin",
    "sabbatsterminerna": "sabbatstermin",
    "sabbatsterminernas": "sabbatstermin",
    "sabbatsterminers": "sabbatstermin",
    "sabbatstermins": "sabbatstermin",
    "sabbatsåren": "sabbatsår",
    "sabbatsårens": "sabbatsår",
    "sabbatsåret": "sabbatsår",
    "sabbatsårets": "sabbatsår",
    "sabbatsårs": "sabbatsår",
    "sabbet": "sabb",
    "sabbets": "sabb",
    "sabbikar": "sabbik",
    "sabbikarna": "sabbik",
    "sabbikarnas": "sabbik",
    "sabbikars": "sabbik",
    "sabbiken": "sabbik",
    "sabbikens": "sabbik",
    "sabbiks": "sabbik",
    "sabbs": "sabb",
    "sabelbajonetten": "sabelbajonett",
    "sabelbajonettens": "sabelbajonett",
    "sabelbajonetter": "sabelbajonett",
    "sabelbajonetterna": "sabelbajonett",
    "sabelbajonetternas": "sabelbajonett",
    "sabelbajonetters": "sabelbajonett",
    "sabelbajonetts": "sabelbajonett",
    "sabelbaljan": "sabelbalja",
    "sabelbaljans": "sabelbalja",
    "sabelbaljas": "sabelbalja",
    "sabelbalje": "sabelbalja",
    "sabelbaljor": "sabelbalja",
    "sabelbaljorna": "sabelbalja",
    "sabelbaljornas": "sabelbalja",
    "sabelbaljors": "sabelbalja",
    "sabelbenta": "sabelbent",
    "sabelbentare": "sabelbent",
    "sabelbentares": "sabelbent",
    "sabelbentas": "sabelbent",
    "sabelbentast": "sabelbent",
    "sabelbentaste": "sabelbent",
    "sabelbentastes": "sabelbent",
    "sabelbentasts": "sabelbent",
    "sabelbente": "sabelbent",
    "sabelbentes": "sabelbent",
    "sabelbentheten": "sabelbenthet",
    "sabelbenthetens": "sabelbenthet",
    "sabelbenthets": "sabelbenthet",
    "sabelbents": "sabelbent",
    "sabelformade": "sabelformad",
    "sabelformades": "sabelformad",
    "sabelformads": "sabelformad",
    "sabelformat": "sabelformad",
    "sabelformats": "sabelformad",
    "sabelfäktningar": "sabelfäktning",
    "sabelfäktningarna": "sabelfäktning",
    "sabelfäktningarnas": "sabelfäktning",
    "sabelfäktningars": "sabelfäktning",
    "sabelfäktningen": "sabelfäktning",
    "sabelfäktningens": "sabelfäktning",
    "sabelfäktnings": "sabelfäktning",
    "sabelkling": "sabelklinga",
    "sabelklingan": "sabelklinga",
    "sabelklingans": "sabelklinga",
    "sabelklingas": "sabelklinga",
    "sabelklinge": "sabelklinga",
    "sabelklingor": "sabelklinga",
    "sabelklingorna": "sabelklinga",
    "sabelklingornas": "sabelklinga",
    "sabelklingors": "sabelklinga",
    "sabelklings": "sabelklinga",
    "sabelliljan": "sabellilja",
    "sabelliljans": "sabellilja",
    "sabelliljas": "sabellilja",
    "sabellilje": "sabellilja",
    "sabelliljor": "sabellilja",
    "sabelliljorna": "sabellilja",
    "sabelliljornas": "sabellilja",
    "sabelliljors": "sabellilja",
    "sabeln": "sabel",
    "sabelns": "sabel",
    "sabels": "sabel",
    "sabelskramlet": "sabelskrammel",
    "sabelskramlets": "sabelskrammel",
    "sabelskrammels": "sabelskrammel",
    "sabeltandade": "sabeltandad",
    "sabeltandades": "sabeltandad",
    "sabeltandads": "sabeltandad",
    "sabeltandat": "sabeltandad",
    "sabeltandats": "sabeltandad",
    "sabinen": "sabin",
    "sabinens": "sabin",
    "sabiner": "sabin",
    "sabinerna": "sabin",
    "sabinernas": "sabin",
    "sabiners": "sabin",
    "sabins": "sabin",
    "sablar": "sabel",
    "sablarna": "sabel",
    "sablarnas": "sabel",
    "sablars": "sabel",
    "sabotagen": "sabotage",
    "sabotagens": "sabotage",
    "sabotages": "sabotage",
    "sabotaget": "sabotage",
    "sabotagets": "sabotage",
    "saboterad": "sabotera",
    "saboterade": "sabotera",
    "saboterades": "sabotera",
    "saboterads": "sabotera",
    "saboterande": "sabotera",
    "saboteranden": "saboterande",
    "saboterandena": "saboterande",
    "saboterandenas": "saboterande",
    "saboterandens": "saboterande",
    "saboterandes": "saboterande",
    "saboterandet": "saboterande",
    "saboterandets": "saboterande",
    "saboterar": "sabotera",
    "saboteras": "sabotera",
    "saboterat": "sabotera",
    "saboterats": "sabotera",
    "saboterbara": "saboterbar",
    "saboterbarare": "saboterbar",
    "saboterbarares": "saboterbar",
    "saboterbaras": "saboterbar",
    "saboterbarast": "saboterbar",
    "saboterbaraste": "saboterbar",
    "saboterbarastes": "saboterbar",
    "saboterbarasts": "saboterbar",
    "saboterbare": "saboterbar",
    "saboterbares": "saboterbar",
    "saboterbarheten": "saboterbarhet",
    "saboterbarhetens": "saboterbarhet",
    "saboterbarhets": "saboterbarhet",
    "saboterbars": "saboterbar",
    "saboterbart": "saboterbar",
    "saboterbarts": "saboterbar",
    "saboteringar": "sabotering",
    "saboteringarna": "sabotering",
    "saboteringarnas": "sabotering",
    "saboteringars": "sabotering",
    "saboteringen": "sabotering",
    "saboteringens": "sabotering",
    "saboterings": "sabotering",
    "sabotören": "sabotör",
    "sabotörens": "sabotör",
    "sabotörer": "sabotör",
    "sabotörerna": "sabotör",
    "sabotörernas": "sabotör",
    "sabotörers": "sabotör",
    "sabotörs": "sabotör",
    "sabrerad": "sabrera",
    "sabrerade": "sabrera",
    "sabrerades": "sabrera",
    "sabrerads": "sabrera",
    "sabrerande": "sabrera",
    "sabreranden": "sabrerande",
    "sabrerandena": "sabrerande",
    "sabrerandenas": "sabrerande",
    "sabrerandens": "sabrerande",
    "sabrerandes": "sabrerande",
    "sabrerandet": "sabrerande",
    "sabrerandets": "sabrerande",
    "sabrerar": "sabrera",
    "sabreras": "sabrera",
    "sabrerat": "sabrera",
    "sabrerats": "sabrera",
    "sabrerbara": "sabrerbar",
    "sabrerbarare": "sabrerbar",
    "sabrerbarares": "sabrerbar",
    "sabrerbaras": "sabrerbar",
    "sabrerbarast": "sabrerbar",
    "sabrerbaraste": "sabrerbar",
    "sabrerbarastes": "sabrerbar",
    "sabrerbarasts": "sabrerbar",
    "sabrerbare": "sabrerbar",
    "sabrerbares": "sabrerbar",
    "sabrerbarheten": "sabrerbarhet",
    "sabrerbarhetens": "sabrerbarhet",
    "sabrerbarhets": "sabrerbarhet",
    "sabrerbars": "sabrerbar",
    "sabrerbart": "sabrerbar",
    "sabrerbarts": "sabrerbar",
    "sabreringar": "sabrering",
    "sabreringarna": "sabrering",
    "sabreringarnas": "sabrering",
    "sabreringars": "sabrering",
    "sabreringen": "sabrering",
    "sabreringens": "sabrering",
    "sabrerings": "sabrering",
    "sachsar": "sachsare",
    "sachsaren": "sachsare",
    "sachsarens": "sachsare",
    "sachsares": "sachsare",
    "sachsarna": "sachsare",
    "sachsarnas": "sachsare",
    "sachsiska": "sachsisk",
    "sachsiskare": "sachsisk",
    "sachsiskares": "sachsisk",
    "sachsiskas": "sachsisk",
    "sachsiskast": "sachsisk",
    "sachsiskaste": "sachsisk",
    "sachsiskastes": "sachsisk",
    "sachsiskasts": "sachsisk",
    "sachsiske": "sachsisk",
    "sachsiskes": "sachsisk",
    "sachsisks": "sachsisk",
    "sachsiskt": "sachsisk",
    "sachsiskts": "sachsisk",
    "sack": "sacka",
    "sackade": "sacka",
    "sackades": "sacka",
    "sackande": "sacka",
    "sackanden": "sackande",
    "sackandena": "sackande",
    "sackandenas": "sackande",
    "sackandens": "sackande",
    "sackandes": "sackande",
    "sackandet": "sackande",
    "sackandets": "sackande",
    "sackar": "sacka",
    "sackarinen": "sackarin",
    "sackarinens": "sackarin",
    "sackariner": "sackarin",
    "sackarinerna": "sackarin",
    "sackarinernas": "sackarin",
    "sackariners": "sackarin",
    "sackarinet": "sackarin",
    "sackarinets": "sackarin",
    "sackarins": "sackarin",
    "sackarosen": "sackaros",
    "sackarosens": "sackaros",
    "sackas": "sacka",
    "sackat": "sacka",
    "sackats": "sacka",
    "sacketten": "sackett",
    "sackettens": "sackett",
    "sacketter": "sackett",
    "sacketterna": "sackett",
    "sacketternas": "sackett",
    "sacketters": "sackett",
    "sacketts": "sackett",
    "sadducéen": "sadducé",
    "sadducéens": "sadducé",
    "sadducéer": "sadducé",
    "sadducéerna": "sadducé",
    "sadducéernas": "sadducé",
    "sadducéers": "sadducé",
    "sadducén": "sadducé",
    "sadducéns": "sadducé",
    "sadducés": "sadducé",
    "sade": "säga",
    "sadel": "sadla",
    "sadelbommar": "sadelbom",
    "sadelbommarna": "sadelbom",
    "sadelbommarnas": "sadelbom",
    "sadelbommars": "sadelbom",
    "sadelbommen": "sadelbom",
    "sadelbommens": "sadelbom",
    "sadelboms": "sadelbom",
    "sadelbrotten": "sadelbrott",
    "sadelbrottens": "sadelbrott",
    "sadelbrottet": "sadelbrott",
    "sadelbrottets": "sadelbrott",
    "sadelbrotts": "sadelbrott",
    "sadelbrutens": "sadelbruten",
    "sadelbrutet": "sadelbruten",
    "sadelbrutets": "sadelbruten",
    "sadelbrutna": "sadelbruten",
    "sadelbrutnare": "sadelbruten",
    "sadelbrutnares": "sadelbruten",
    "sadelbrutnas": "sadelbruten",
    "sadelbrutnast": "sadelbruten",
    "sadelbrutnaste": "sadelbruten",
    "sadelbrutnastes": "sadelbruten",
    "sadelbrutnasts": "sadelbruten",
    "sadelbrutne": "sadelbruten",
    "sadelbrutnes": "sadelbruten",
    "sadeldyn": "sadeldyna",
    "sadeldynan": "sadeldyna",
    "sadeldynans": "sadeldyna",
    "sadeldynas": "sadeldyna",
    "sadeldyne": "sadeldyna",
    "sadeldynor": "sadeldyna",
    "sadeldynorna": "sadeldyna",
    "sadeldynornas": "sadeldyna",
    "sadeldynors": "sadeldyna",
    "sadeldyns": "sadeldyna",
    "sadelfiltar": "sadelfilt",
    "sadelfiltarna": "sadelfilt",
    "sadelfiltarnas": "sadelfilt",
    "sadelfiltars": "sadelfilt",
    "sadelfilten": "sadelfilt",
    "sadelfiltens": "sadelfilt",
    "sadelfilts": "sadelfilt",
    "sadelformade": "sadelformad",
    "sadelformades": "sadelformad",
    "sadelformads": "sadelformad",
    "sadelformat": "sadelformad",
    "sadelformats": "sadelformad",
    "sadelformiga": "sadelformig",
    "sadelformigare": "sadelformig",
    "sadelformigares": "sadelformig",
    "sadelformigas": "sadelformig",
    "sadelformigast": "sadelformig",
    "sadelformigaste": "sadelformig",
    "sadelformigastes": "sadelformig",
    "sadelformigasts": "sadelformig",
    "sadelformige": "sadelformig",
    "sadelformiges": "sadelformig",
    "sadelformigheten": "sadelformighet",
    "sadelformighetens": "sadelformighet",
    "sadelformighets": "sadelformighet",
    "sadelformigs": "sadelformig",
    "sadelformigt": "sadelformig",
    "sadelformigts": "sadelformig",
    "sadelgjordar": "sadelgjord",
    "sadelgjordarna": "sadelgjord",
    "sadelgjordarnas": "sadelgjord",
    "sadelgjordars": "sadelgjord",
    "sadelgjorden": "sadelgjord",
    "sadelgjordens": "sadelgjord",
    "sadelgjords": "sadelgjord",
    "sadelknappar": "sadelknapp",
    "sadelknapparna": "sadelknapp",
    "sadelknapparnas": "sadelknapp",
    "sadelknappars": "sadelknapp",
    "sadelknappen": "sadelknapp",
    "sadelknappens": "sadelknapp",
    "sadelknapps": "sadelknapp",
    "sadellägen": "sadelläge",
    "sadellägena": "sadelläge",
    "sadellägenas": "sadelläge",
    "sadellägens": "sadelläge",
    "sadelläges": "sadelläge",
    "sadelläget": "sadelläge",
    "sadellägets": "sadelläge",
    "sadelmakar": "sadelmakare",
    "sadelmakaren": "sadelmakare",
    "sadelmakarens": "sadelmakare",
    "sadelmakares": "sadelmakare",
    "sadelmakarna": "sadelmakare",
    "sadelmakarnas": "sadelmakare",
    "sadelmakarnålar": "sadelmakarnål",
    "sadelmakarnålarna": "sadelmakarnål",
    "sadelmakarnålarnas": "sadelmakarnål",
    "sadelmakarnålars": "sadelmakarnål",
    "sadelmakarnålen": "sadelmakarnål",
    "sadelmakarnålens": "sadelmakarnål",
    "sadelmakarnåls": "sadelmakarnål",
    "sadelmakarstiften": "sadelmakarstift",
    "sadelmakarstiftens": "sadelmakarstift",
    "sadelmakarstiftet": "sadelmakarstift",
    "sadelmakarstiftets": "sadelmakarstift",
    "sadelmakarstifts": "sadelmakarstift",
    "sadelmakerier": "sadelmakeri",
    "sadelmakerierna": "sadelmakeri",
    "sadelmakeriernas": "sadelmakeri",
    "sadelmakeriers": "sadelmakeri",
    "sadelmakeriet": "sadelmakeri",
    "sadelmakeriets": "sadelmakeri",
    "sadelmakeris": "sadelmakeri",
    "sadelmakerit": "sadelmakeri",
    "sadelmakerits": "sadelmakeri",
    "sadeln": "sadel",
    "sadelns": "sadel",
    "sadelnäs": "sadelnäsa",
    "sadelnäsan": "sadelnäsa",
    "sadelnäsans": "sadelnäsa",
    "sadelnäsas": "sadelnäsa",
    "sadelnäse": "sadelnäsa",
    "sadelnäsor": "sadelnäsa",
    "sadelnäsorna": "sadelnäsa",
    "sadelnäsornas": "sadelnäsa",
    "sadelnäsors": "sadelnäsa",
    "sadelplatsen": "sadelplats",
    "sadelplatsens": "sadelplats",
    "sadelplatser": "sadelplats",
    "sadelplatserna": "sadelplats",
    "sadelplatsernas": "sadelplats",
    "sadelplatsers": "sadelplats",
    "sadelput": "sadelputa",
    "sadelputan": "sadelputa",
    "sadelputans": "sadelputa",
    "sadelputas": "sadelputa",
    "sadelpute": "sadelputa",
    "sadelputor": "sadelputa",
    "sadelputorna": "sadelputa",
    "sadelputornas": "sadelputa",
    "sadelputors": "sadelputa",
    "sadelputs": "sadelputa",
    "sadels": "sadel",
    "sadelskydden": "sadelskydd",
    "sadelskyddens": "sadelskydd",
    "sadelskyddet": "sadelskydd",
    "sadelskyddets": "sadelskydd",
    "sadelskydds": "sadelskydd",
    "sadelstaden": "sadelstad",
    "sadelstadens": "sadelstad",
    "sadelstads": "sadelstad",
    "sadeltaken": "sadeltak",
    "sadeltakens": "sadeltak",
    "sadeltaket": "sadeltak",
    "sadeltakets": "sadeltak",
    "sadeltaks": "sadeltak",
    "sadeltrycket": "sadeltryck",
    "sadeltryckets": "sadeltryck",
    "sadeltrycks": "sadeltryck",
    "sadeltäcken": "sadeltäcke",
    "sadeltäckena": "sadeltäcke",
    "sadeltäckenas": "sadeltäcke",
    "sadeltäckens": "sadeltäcke",
    "sadeltäckes": "sadeltäcke",
    "sadeltäcket": "sadeltäcke",
    "sadeltäckets": "sadeltäcke",
    "sadeltäcks": "sadeltäcke",
    "sades": "säga",
    "sadismen": "sadism",
    "sadismens": "sadism",
    "sadismer": "sadism",
    "sadismerna": "sadism",
    "sadismernas": "sadism",
    "sadismers": "sadism",
    "sadisms": "sadism",
    "sadisten": "sadist",
    "sadistens": "sadist",
    "sadister": "sadist",
    "sadisterna": "sadist",
    "sadisternas": "sadist",
    "sadisters": "sadist",
    "sadistiska": "sadistisk",
    "sadistiskare": "sadistisk",
    "sadistiskares": "sadistisk",
    "sadistiskas": "sadistisk",
    "sadistiskast": "sadistisk",
    "sadistiskaste": "sadistisk",
    "sadistiskastes": "sadistisk",
    "sadistiskasts": "sadistisk",
    "sadistiske": "sadistisk",
    "sadistiskes": "sadistisk",
    "sadistisks": "sadistisk",
    "sadistiskt": "sadistisk",
    "sadistiskts": "sadistisk",
    "sadists": "sadist",
    "sadlad": "sadla",
    "sadlade": "sadla",
    "sadlades": "sadla",
    "sadlads": "sadla",
    "sadlande": "sadla",
    "sadlanden": "sadlande",
    "sadlandena": "sadlande",
    "sadlandenas": "sadlande",
    "sadlandens": "sadlande",
    "sadlandes": "sadlande",
    "sadlandet": "sadlande",
    "sadlandets": "sadlande",
    "sadlar": "sadla",
    "sadlarna": "sadel",
    "sadlarnas": "sadel",
    "sadlars": "sadel",
    "sadlas": "sadla",
    "sadlat": "sadla",
    "sadlats": "sadla",
    "sado-masochismen": "sado-masochism",
    "sado-masochismens": "sado-masochism",
    "sado-masochismer": "sado-masochism",
    "sado-masochismerna": "sado-masochism",
    "sado-masochismernas": "sado-masochism",
    "sado-masochismers": "sado-masochism",
    "sado-masochisms": "sado-masochism",
    "sado-masochistiska": "sado-masochistisk",
    "sado-masochistiskare": "sado-masochistisk",
    "sado-masochistiskares": "sado-masochistisk",
    "sado-masochistiskas": "sado-masochistisk",
    "sado-masochistiskast": "sado-masochistisk",
    "sado-masochistiskaste": "sado-masochistisk",
    "sado-masochistiskastes": "sado-masochistisk",
    "sado-masochistiskasts": "sado-masochistisk",
    "sado-masochistiske": "sado-masochistisk",
    "sado-masochistiskes": "sado-masochistisk",
    "sado-masochistisks": "sado-masochistisk",
    "sado-masochistiskt": "sado-masochistisk",
    "sado-masochistiskts": "sado-masochistisk",
    "safarier": "safari",
    "safarierna": "safari",
    "safariernas": "safari",
    "safariers": "safari",
    "safarin": "safari",
    "safarins": "safari",
    "safaris": "safari",
    "safarisarna": "safari",
    "safarisarnas": "safari",
    "saffianen": "saffian",
    "saffianens": "saffian",
    "saffianet": "saffian",
    "saffianets": "saffian",
    "saffians": "saffian",
    "safflorn": "safflor",
    "safflorns": "safflor",
    "safflors": "safflor",
    "saffranen": "saffran",
    "saffranens": "saffran",
    "saffranet": "saffran",
    "saffranets": "saffran",
    "saffrans": "saffran",
    "saffransbröden": "saffransbröd",
    "saffransbrödens": "saffransbröd",
    "saffransbrödet": "saffransbröd",
    "saffransbrödets": "saffransbröd",
    "saffransbröds": "saffransbröd",
    "saffransbull": "saffransbulle",
    "saffransbullan": "saffransbulla",
    "saffransbullans": "saffransbulla",
    "saffransbullar": "saffransbulle",
    "saffransbullarna": "saffransbulle",
    "saffransbullarnas": "saffransbulle",
    "saffransbullars": "saffransbulle",
    "saffransbullas": "saffransbulla",
    "saffransbulle": "saffransbulla",
    "saffransbullen": "saffransbulle",
    "saffransbullens": "saffransbulle",
    "saffransbulles": "saffransbulle",
    "saffransbullor": "saffransbulla",
    "saffransbullorna": "saffransbulla",
    "saffransbullornas": "saffransbulla",
    "saffransbullors": "saffransbulla",
    "saffransbulls": "saffransbulle",
    "saffransfärgade": "saffransfärgad",
    "saffransfärgades": "saffransfärgad",
    "saffransfärgads": "saffransfärgad",
    "saffransfärgat": "saffransfärgad",
    "saffransfärgats": "saffransfärgad",
    "saffransfärgen": "saffransfärg",
    "saffransfärgens": "saffransfärg",
    "saffransfärgs": "saffransfärg",
    "saffransgula": "saffransgul",
    "saffransgulare": "saffransgul",
    "saffransgulares": "saffransgul",
    "saffransgulas": "saffransgul",
    "saffransgulast": "saffransgul",
    "saffransgulaste": "saffransgul",
    "saffransgulastes": "saffransgul",
    "saffransgulasts": "saffransgul",
    "saffransgule": "saffransgul",
    "saffransgules": "saffransgul",
    "saffransguls": "saffransgul",
    "saffransgult": "saffransgul",
    "saffransgults": "saffransgul",
    "saffranslängden": "saffranslängd",
    "saffranslängdens": "saffranslängd",
    "saffranslängder": "saffranslängd",
    "saffranslängderna": "saffranslängd",
    "saffranslängdernas": "saffranslängd",
    "saffranslängders": "saffranslängd",
    "saffranslängds": "saffranslängd",
    "safiren": "safir",
    "safirens": "safir",
    "safirer": "safir",
    "safirerna": "safir",
    "safirernas": "safir",
    "safirers": "safir",
    "safirnålar": "safirnål",
    "safirnålarna": "safirnål",
    "safirnålarnas": "safirnål",
    "safirnålars": "safirnål",
    "safirnålen": "safirnål",
    "safirnålens": "safirnål",
    "safirnåls": "safirnål",
    "safirs": "safir",
    "saft": "safta",
    "saftad": "safta",
    "saftade": "safta",
    "saftades": "safta",
    "saftads": "safta",
    "saftande": "safta",
    "saftanden": "saftande",
    "saftandena": "saftande",
    "saftandenas": "saftande",
    "saftandens": "saftande",
    "saftandes": "saftande",
    "saftandet": "saftande",
    "saftandets": "saftande",
    "saftar": "safta",
    "saftas": "safta",
    "saftat": "safta",
    "saftats": "safta",
    "saften": "saft",
    "saftens": "saft",
    "safter": "saft",
    "safterna": "saft",
    "safternas": "saft",
    "safters": "saft",
    "saftfoders": "saftfoder",
    "saftfodret": "saftfoder",
    "saftfodrets": "saftfoder",
    "saftglassar": "saftglass",
    "saftglassarna": "saftglass",
    "saftglassarnas": "saftglass",
    "saftglassars": "saftglass",
    "saftglassen": "saftglass",
    "saftglassens": "saftglass",
    "saftiga": "saftig",
    "saftigare": "saftig",
    "saftigares": "saftig",
    "saftigas": "saftig",
    "saftigast": "saftig",
    "saftigaste": "saftig",
    "saftigastes": "saftig",
    "saftigasts": "saftig",
    "saftige": "saftig",
    "saftiges": "saftig",
    "saftigheten": "saftighet",
    "saftighetens": "saftighet",
    "saftighets": "saftighet",
    "saftigs": "saftig",
    "saftigt": "saftig",
    "saftigts": "saftig",
    "saftkalasen": "saftkalas",
    "saftkalasens": "saftkalas",
    "saftkalaset": "saftkalas",
    "saftkalasets": "saftkalas",
    "saftkannan": "saftkanna",
    "saftkannans": "saftkanna",
    "saftkannas": "saftkanna",
    "saftkanne": "saftkanna",
    "saftkannor": "saftkanna",
    "saftkannorna": "saftkanna",
    "saftkannornas": "saftkanna",
    "saftkannors": "saftkanna",
    "saftkrämen": "saftkräm",
    "saftkrämens": "saftkräm",
    "saftkrämer": "saftkräm",
    "saftkrämerna": "saftkräm",
    "saftkrämernas": "saftkräm",
    "saftkrämers": "saftkräm",
    "saftkräms": "saftkräm",
    "saftpressar": "saftpress",
    "saftpressarna": "saftpress",
    "saftpressarnas": "saftpress",
    "saftpressars": "saftpress",
    "saftpressen": "saftpress",
    "saftpressens": "saftpress",
    "safts": "saft",
    "saftsoppan": "saftsoppa",
    "saftsoppans": "saftsoppa",
    "saftsoppas": "saftsoppa",
    "saftspänningar": "saftspänning",
    "saftspänningarna": "saftspänning",
    "saftspänningarnas": "saftspänning",
    "saftspänningars": "saftspänning",
    "saftspänningen": "saftspänning",
    "saftspänningens": "saftspänning",
    "saftspännings": "saftspänning",
    "saftstationen": "saftstation",
    "saftstationens": "saftstation",
    "saftstationer": "saftstation",
    "saftstationerna": "saftstation",
    "saftstationernas": "saftstation",
    "saftstationers": "saftstation",
    "saftstations": "saftstation",
    "saftströmningar": "saftströmning",
    "saftströmningarna": "saftströmning",
    "saftströmningarnas": "saftströmning",
    "saftströmningars": "saftströmning",
    "saftströmningen": "saftströmning",
    "saftströmningens": "saftströmning",
    "saftströmnings": "saftströmning",
    "saftsåsen": "saftsås",
    "saftsåsens": "saftsås",
    "saftsåser": "saftsås",
    "saftsåserna": "saftsås",
    "saftsåsernas": "saftsås",
    "saftsåsers": "saftsås",
    "sag": "saga",
    "sagalitteraturen": "sagalitteratur",
    "sagalitteraturens": "sagalitteratur",
    "sagalitteraturs": "sagalitteratur",
    "sagan": "saga",
    "sagans": "saga",
    "sagas": "saga",
    "sagatiden": "sagatid",
    "sagatidens": "sagatid",
    "sagatids": "sagatid",
    "sagd": "säga",
    "sagda": "säga",
    "sagdas": "säga",
    "sagde": "säga",
    "sagdes": "säga",
    "sagds": "säga",
    "sage": "saga",
    "sagel": "sagla",
    "sagesmannen": "sagesman",
    "sagesmannens": "sagesman",
    "sagesmans": "sagesman",
    "sagesmän": "sagesman",
    "sagesmännen": "sagesman",
    "sagesmännens": "sagesman",
    "sagesmäns": "sagesman",
    "sagg": "sagga",
    "saggade": "sagga",
    "saggades": "sagga",
    "saggande": "sagga",
    "sagganden": "saggande",
    "saggandena": "saggande",
    "saggandenas": "saggande",
    "saggandens": "saggande",
    "saggandes": "saggande",
    "saggandet": "saggande",
    "saggandets": "saggande",
    "saggar": "sagga",
    "saggas": "sagga",
    "saggat": "sagga",
    "saggats": "sagga",
    "sagget": "sagg",
    "saggets": "sagg",
    "saggs": "sagg",
    "saglade": "sagla",
    "saglades": "sagla",
    "saglande": "sagla",
    "saglanden": "saglande",
    "saglandena": "saglande",
    "saglandenas": "saglande",
    "saglandens": "saglande",
    "saglandes": "saglande",
    "saglandet": "saglande",
    "saglandets": "saglande",
    "saglar": "sagla",
    "saglas": "sagla",
    "saglat": "sagla",
    "saglats": "sagla",
    "sago": "saga",
    "sagoberättar": "sagoberättare",
    "sagoberättaren": "sagoberättare",
    "sagoberättarens": "sagoberättare",
    "sagoberättares": "sagoberättare",
    "sagoberättarna": "sagoberättare",
    "sagoberättarnas": "sagoberättare",
    "sagoboken": "sagobok",
    "sagobokens": "sagobok",
    "sagoboks": "sagobok",
    "sagoböcker": "sagobok",
    "sagoböckerna": "sagobok",
    "sagoböckernas": "sagobok",
    "sagoböckers": "sagobok",
    "sagocykeln": "sagocykel",
    "sagocykelns": "sagocykel",
    "sagocykels": "sagocykel",
    "sagocyklar": "sagocykel",
    "sagocyklarna": "sagocykel",
    "sagocyklarnas": "sagocykel",
    "sagocyklars": "sagocykel",
    "sagocykler": "sagocykel",
    "sagocyklerna": "sagocykel",
    "sagocyklernas": "sagocykel",
    "sagocyklers": "sagocykel",
    "sagodjuren": "sagodjur",
    "sagodjurens": "sagodjur",
    "sagodjuret": "sagodjur",
    "sagodjurets": "sagodjur",
    "sagodjurs": "sagodjur",
    "sagofiguren": "sagofigur",
    "sagofigurens": "sagofigur",
    "sagofigurer": "sagofigur",
    "sagofigurerna": "sagofigur",
    "sagofigurernas": "sagofigur",
    "sagofigurers": "sagofigur",
    "sagofigurs": "sagofigur",
    "sagogrynen": "sagogryn",
    "sagogrynens": "sagogryn",
    "sagogrynet": "sagogryn",
    "sagogrynets": "sagogryn",
    "sagogryns": "sagogryn",
    "sagohjältar": "sagohjälte",
    "sagohjältarna": "sagohjälte",
    "sagohjältarnas": "sagohjälte",
    "sagohjältars": "sagohjälte",
    "sagohjälten": "sagohjälte",
    "sagohjältens": "sagohjälte",
    "sagohjältes": "sagohjälte",
    "sagohörn": "sagohörna",
    "sagohörnan": "sagohörna",
    "sagohörnans": "sagohörna",
    "sagohörnas": "sagohörna",
    "sagohörne": "sagohörna",
    "sagohörnor": "sagohörna",
    "sagohörnorna": "sagohörna",
    "sagohörnornas": "sagohörna",
    "sagohörnors": "sagohörna",
    "sagohörns": "sagohörna",
    "sagokretsar": "sagokrets",
    "sagokretsarna": "sagokrets",
    "sagokretsarnas": "sagokrets",
    "sagokretsars": "sagokrets",
    "sagokretsen": "sagokrets",
    "sagokretsens": "sagokrets",
    "sagolandet": "sagoland",
    "sagolandets": "sagoland",
    "sagolands": "sagoland",
    "sagolika": "sagolik",
    "sagolikare": "sagolik",
    "sagolikares": "sagolik",
    "sagolikas": "sagolik",
    "sagolikast": "sagolik",
    "sagolikaste": "sagolik",
    "sagolikastes": "sagolik",
    "sagolikasts": "sagolik",
    "sagolike": "sagolik",
    "sagolikes": "sagolik",
    "sagolikheten": "sagolikhet",
    "sagolikhetens": "sagolikhet",
    "sagolikhets": "sagolikhet",
    "sagoliks": "sagolik",
    "sagolikt": "sagolik",
    "sagolikts": "sagolik",
    "sagoländer": "sagoland",
    "sagoländerna": "sagoland",
    "sagoländernas": "sagoland",
    "sagoländers": "sagoland",
    "sagomjölet": "sagomjöl",
    "sagomjölets": "sagomjöl",
    "sagomjöls": "sagomjöl",
    "sagomässiga": "sagomässig",
    "sagomässigare": "sagomässig",
    "sagomässigares": "sagomässig",
    "sagomässigas": "sagomässig",
    "sagomässigast": "sagomässig",
    "sagomässigaste": "sagomässig",
    "sagomässigastes": "sagomässig",
    "sagomässigasts": "sagomässig",
    "sagomässige": "sagomässig",
    "sagomässiges": "sagomässig",
    "sagomässigs": "sagomässig",
    "sagomässigt": "sagomässig",
    "sagomässigts": "sagomässig",
    "sagon": "sago",
    "sagons": "sago",
    "sagoomspunna": "sagoomspunnen",
    "sagoomspunnare": "sagoomspunnen",
    "sagoomspunnares": "sagoomspunnen",
    "sagoomspunnas": "sagoomspunnen",
    "sagoomspunnast": "sagoomspunnen",
    "sagoomspunnaste": "sagoomspunnen",
    "sagoomspunnastes": "sagoomspunnen",
    "sagoomspunnasts": "sagoomspunnen",
    "sagoomspunne": "sagoomspunnen",
    "sagoomspunnens": "sagoomspunnen",
    "sagoomspunnes": "sagoomspunnen",
    "sagoomspunnet": "sagoomspunnen",
    "sagoomspunnets": "sagoomspunnen",
    "sagopalmen": "sagopalm",
    "sagopalmens": "sagopalm",
    "sagopalmer": "sagopalm",
    "sagopalmerna": "sagopalm",
    "sagopalmernas": "sagopalm",
    "sagopalmers": "sagopalm",
    "sagopalms": "sagopalm",
    "sagoprinsar": "sagoprins",
    "sagoprinsarna": "sagoprins",
    "sagoprinsarnas": "sagoprins",
    "sagoprinsars": "sagoprins",
    "sagoprinsen": "sagoprins",
    "sagoprinsens": "sagoprins",
    "sagoprinsess": "sagoprinsessa",
    "sagoprinsessan": "sagoprinsessa",
    "sagoprinsessans": "sagoprinsessa",
    "sagoprinsessas": "sagoprinsessa",
    "sagoprinsesse": "sagoprinsessa",
    "sagoprinsessor": "sagoprinsessa",
    "sagoprinsessorna": "sagoprinsessa",
    "sagoprinsessornas": "sagoprinsessa",
    "sagoprinsessors": "sagoprinsessa",
    "sagor": "saga",
    "sagorna": "saga",
    "sagornas": "saga",
    "sagors": "saga",
    "sagos": "sago",
    "sagosamlingar": "sagosamling",
    "sagosamlingarna": "sagosamling",
    "sagosamlingarnas": "sagosamling",
    "sagosamlingars": "sagosamling",
    "sagosamlingen": "sagosamling",
    "sagosamlingens": "sagosamling",
    "sagosamlings": "sagosamling",
    "sagoskimmers": "sagoskimmer",
    "sagoskimret": "sagoskimmer",
    "sagoskimrets": "sagoskimmer",
    "sagoslotten": "sagoslott",
    "sagoslottens": "sagoslott",
    "sagoslottet": "sagoslott",
    "sagoslottets": "sagoslott",
    "sagoslotts": "sagoslott",
    "sagosoppan": "sagosoppa",
    "sagosoppans": "sagosoppa",
    "sagosoppas": "sagosoppa",
    "sagostunden": "sagostund",
    "sagostundens": "sagostund",
    "sagostunder": "sagostund",
    "sagostunderna": "sagostund",
    "sagostundernas": "sagostund",
    "sagostunders": "sagostund",
    "sagostunds": "sagostund",
    "sagot": "sago",
    "sagots": "sago",
    "sagovärldar": "sagovärld",
    "sagovärldarna": "sagovärld",
    "sagovärldarnas": "sagovärld",
    "sagovärldars": "sagovärld",
    "sagovärlden": "sagovärld",
    "sagovärldens": "sagovärld",
    "sagovärlds": "sagovärld",
    "sagoväsena": "sagoväsen",
    "sagoväsenas": "sagoväsen",
    "sagoväsendet": "sagoväsen",
    "sagoväsendets": "sagoväsen",
    "sagoväsens": "sagoväsen",
    "sags": "saga",
    "sagt": "säga",
    "sagts": "säga",
    "sahiben": "sahib",
    "sahibens": "sahib",
    "sahiber": "sahib",
    "sahiberna": "sahib",
    "sahibernas": "sahib",
    "sahibers": "sahib",
    "sahibs": "sahib",
    "saig": "saiga",
    "saigan": "saiga",
    "saigans": "saiga",
    "saigas": "saiga",
    "saige": "saiga",
    "saigor": "saiga",
    "saigorna": "saiga",
    "saigornas": "saiga",
    "saigors": "saiga",
    "saigs": "saiga",
    "saintpaulian": "saintpaulia",
    "saintpaulians": "saintpaulia",
    "saintpaulias": "saintpaulia",
    "saintpaulior": "saintpaulia",
    "saintpauliorna": "saintpaulia",
    "saintpauliornas": "saintpaulia",
    "saintpauliors": "saintpaulia",
    "saints": "saint",
    "sajten": "sajt",
    "sajtens": "sajt",
    "sajter": "sajt",
    "sajterna": "sajt",
    "sajternas": "sajt",
    "sajters": "sajt",
    "sajts": "sajt",
    "sak": "saka",
    "sakad": "saka",
    "sakade": "saka",
    "sakades": "saka",
    "sakads": "saka",
    "sakande": "saka",
    "sakanden": "sakande",
    "sakandena": "sakande",
    "sakandenas": "sakande",
    "sakandens": "sakande",
    "sakandes": "sakande",
    "sakandet": "sakande",
    "sakandets": "sakande",
    "sakar": "saka",
    "sakas": "saka",
    "sakat": "saka",
    "sakats": "saka",
    "sakdebatten": "sakdebatt",
    "sakdebattens": "sakdebatt",
    "sakdebatter": "sakdebatt",
    "sakdebatterna": "sakdebatt",
    "sakdebatternas": "sakdebatt",
    "sakdebatters": "sakdebatt",
    "sakdebatts": "sakdebatt",
    "sakdiskussionen": "sakdiskussion",
    "sakdiskussionens": "sakdiskussion",
    "sakdiskussioner": "sakdiskussion",
    "sakdiskussionerna": "sakdiskussion",
    "sakdiskussionernas": "sakdiskussion",
    "sakdiskussioners": "sakdiskussion",
    "sakdiskussions": "sakdiskussion",
    "saken": "sak",
    "sakens": "sak",
    "saker": "sak",
    "sakerförklarad": "sakerförklara",
    "sakerförklarade": "sakerförklara",
    "sakerförklarades": "sakerförklara",
    "sakerförklarads": "sakerförklara",
    "sakerförklarande": "sakerförklara",
    "sakerförklaranden": "sakerförklarande",
    "sakerförklarandena": "sakerförklarande",
    "sakerförklarandenas": "sakerförklarande",
    "sakerförklarandens": "sakerförklarande",
    "sakerförklarandes": "sakerförklarande",
    "sakerförklarandet": "sakerförklarande",
    "sakerförklarandets": "sakerförklarande",
    "sakerförklarar": "sakerförklara",
    "sakerförklaras": "sakerförklara",
    "sakerförklarat": "sakerförklara",
    "sakerförklarats": "sakerförklara",
    "sakerna": "sak",
    "sakernas": "sak",
    "sakers": "sak",
    "sakfelen": "sakfel",
    "sakfelens": "sakfel",
    "sakfelet": "sakfel",
    "sakfelets": "sakfel",
    "sakfels": "sakfel",
    "sakframställningar": "sakframställning",
    "sakframställningarna": "sakframställning",
    "sakframställningarnas": "sakframställning",
    "sakframställningars": "sakframställning",
    "sakframställningen": "sakframställning",
    "sakframställningens": "sakframställning",
    "sakframställnings": "sakframställning",
    "sakfrågan": "sakfråga",
    "sakfrågans": "sakfråga",
    "sakfrågas": "sakfråga",
    "sakfråge": "sakfråga",
    "sakfrågor": "sakfråga",
    "sakfrågorna": "sakfråga",
    "sakfrågornas": "sakfråga",
    "sakfrågors": "sakfråga",
    "sakfäll": "sakfälla",
    "sakfällande": "sakfälla",
    "sakfällanden": "sakfällande",
    "sakfällandena": "sakfällande",
    "sakfällandenas": "sakfällande",
    "sakfällandens": "sakfällande",
    "sakfällandes": "sakfällande",
    "sakfällandet": "sakfällande",
    "sakfällandets": "sakfällande",
    "sakfällas": "sakfälla",
    "sakfälld": "sakfälla",
    "sakfällda": "sakfälla",
    "sakfälldas": "sakfälla",
    "sakfällde": "sakfälla",
    "sakfälldes": "sakfälla",
    "sakfällds": "sakfälla",
    "sakfäller": "sakfälla",
    "sakfälles": "sakfälla",
    "sakfälls": "sakfälla",
    "sakfällt": "sakfälla",
    "sakfällts": "sakfälla",
    "sakförar": "sakförare",
    "sakföraren": "sakförare",
    "sakförarens": "sakförare",
    "sakförares": "sakförare",
    "sakförarna": "sakförare",
    "sakförarnas": "sakförare",
    "sakförhållanden": "sakförhållande",
    "sakförhållandena": "sakförhållande",
    "sakförhållandenas": "sakförhållande",
    "sakförhållandens": "sakförhållande",
    "sakförhållandes": "sakförhållande",
    "sakförhållandet": "sakförhållande",
    "sakförhållandets": "sakförhållande",
    "sakförklaringar": "sakförklaring",
    "sakförklaringarna": "sakförklaring",
    "sakförklaringarnas": "sakförklaring",
    "sakförklaringars": "sakförklaring",
    "sakförklaringen": "sakförklaring",
    "sakförklaringens": "sakförklaring",
    "sakförklarings": "sakförklaring",
    "sakförståndet": "sakförstånd",
    "sakförståndets": "sakförstånd",
    "sakförståndiga": "sakförståndig",
    "sakförståndigare": "sakförståndig",
    "sakförståndigares": "sakförståndig",
    "sakförståndigas": "sakförståndig",
    "sakförståndigast": "sakförståndig",
    "sakförståndigaste": "sakförståndig",
    "sakförståndigastes": "sakförståndig",
    "sakförståndigasts": "sakförståndig",
    "sakförståndige": "sakförståndig",
    "sakförståndiges": "sakförståndig",
    "sakförståndigheten": "sakförståndighet",
    "sakförståndighetens": "sakförståndighet",
    "sakförståndighets": "sakförståndighet",
    "sakförståndigs": "sakförståndig",
    "sakförståndigt": "sakförståndig",
    "sakförståndigts": "sakförståndig",
    "sakförstånds": "sakförstånd",
    "sakförsäkringar": "sakförsäkring",
    "sakförsäkringarna": "sakförsäkring",
    "sakförsäkringarnas": "sakförsäkring",
    "sakförsäkringars": "sakförsäkring",
    "sakförsäkringen": "sakförsäkring",
    "sakförsäkringens": "sakförsäkring",
    "sakförsäkrings": "sakförsäkring",
    "sakkunniga": "sakkunnig",
    "sakkunnigare": "sakkunnig",
    "sakkunnigares": "sakkunnig",
    "sakkunnigas": "sakkunnig",
    "sakkunnigast": "sakkunnig",
    "sakkunnigaste": "sakkunnig",
    "sakkunnigastes": "sakkunnig",
    "sakkunnigasts": "sakkunnig",
    "sakkunnigberedningar": "sakkunnigberedning",
    "sakkunnigberedningarna": "sakkunnigberedning",
    "sakkunnigberedningarnas": "sakkunnigberedning",
    "sakkunnigberedningars": "sakkunnigberedning",
    "sakkunnigberedningen": "sakkunnigberedning",
    "sakkunnigberedningens": "sakkunnigberedning",
    "sakkunnigberednings": "sakkunnigberedning",
    "sakkunnigbetänkanden": "sakkunnigbetänkande",
    "sakkunnigbetänkandena": "sakkunnigbetänkande",
    "sakkunnigbetänkandenas": "sakkunnigbetänkande",
    "sakkunnigbetänkandens": "sakkunnigbetänkande",
    "sakkunnigbetänkandes": "sakkunnigbetänkande",
    "sakkunnigbetänkandet": "sakkunnigbetänkande",
    "sakkunnigbetänkandets": "sakkunnigbetänkande",
    "sakkunnige": "sakkunnig",
    "sakkunniges": "sakkunnig",
    "sakkunnigheten": "sakkunnighet",
    "sakkunnighetens": "sakkunnighet",
    "sakkunnighets": "sakkunnighet",
    "sakkunnigprövningar": "sakkunnigprövning",
    "sakkunnigprövningarna": "sakkunnigprövning",
    "sakkunnigprövningarnas": "sakkunnigprövning",
    "sakkunnigprövningars": "sakkunnigprövning",
    "sakkunnigprövningen": "sakkunnigprövning",
    "sakkunnigprövningens": "sakkunnigprövning",
    "sakkunnigprövnings": "sakkunnigprövning",
    "sakkunnigs": "sakkunnig",
    "sakkunnigt": "sakkunnig",
    "sakkunnigts": "sakkunnig",
    "sakkunniguppdragen": "sakkunniguppdrag",
    "sakkunniguppdragens": "sakkunniguppdrag",
    "sakkunniguppdraget": "sakkunniguppdrag",
    "sakkunniguppdragets": "sakkunniguppdrag",
    "sakkunniguppdrags": "sakkunniguppdrag",
    "sakkunnigutlåtanden": "sakkunnigutlåtande",
    "sakkunnigutlåtandena": "sakkunnigutlåtande",
    "sakkunnigutlåtandenas": "sakkunnigutlåtande",
    "sakkunnigutlåtandens": "sakkunnigutlåtande",
    "sakkunnigutlåtandes": "sakkunnigutlåtande",
    "sakkunnigutlåtandet": "sakkunnigutlåtande",
    "sakkunnigutlåtandets": "sakkunnigutlåtande",
    "sakkunskapen": "sakkunskap",
    "sakkunskapens": "sakkunskap",
    "sakkunskaps": "sakkunskap",
    "sakkännedomar": "sakkännedom",
    "sakkännedomarna": "sakkännedom",
    "sakkännedomarnas": "sakkännedom",
    "sakkännedomars": "sakkännedom",
    "sakkännedomen": "sakkännedom",
    "sakkännedomens": "sakkännedom",
    "sakkännedoms": "sakkännedom",
    "sakliga": "saklig",
    "sakligare": "saklig",
    "sakligares": "saklig",
    "sakligas": "saklig",
    "sakligast": "saklig",
    "sakligaste": "saklig",
    "sakligastes": "saklig",
    "sakligasts": "saklig",
    "saklige": "saklig",
    "sakliges": "saklig",
    "sakligheten": "saklighet",
    "saklighetens": "saklighet",
    "sakligheter": "saklighet",
    "sakligheterna": "saklighet",
    "sakligheternas": "saklighet",
    "sakligheters": "saklighet",
    "saklighets": "saklighet",
    "sakligs": "saklig",
    "sakligt": "saklig",
    "sakligts": "saklig",
    "sakläges": "sakläge",
    "sakläget": "sakläge",
    "saklägets": "sakläge",
    "saklösa": "saklös",
    "saklösare": "saklös",
    "saklösares": "saklös",
    "saklösas": "saklös",
    "saklösast": "saklös",
    "saklösaste": "saklös",
    "saklösastes": "saklös",
    "saklösasts": "saklös",
    "saklöse": "saklös",
    "saklöses": "saklös",
    "saklösheten": "saklöshet",
    "saklöshetens": "saklöshet",
    "saklöshets": "saklöshet",
    "saklöst": "saklös",
    "saklösts": "saklös",
    "saknad": "sakna",
    "saknade": "sakna",
    "saknaden": "saknad",
    "saknadens": "saknad",
    "saknader": "saknad",
    "saknaderna": "saknad",
    "saknadernas": "saknad",
    "saknaders": "saknad",
    "saknades": "saknas",
    "saknads": "saknad",
    "saknande": "sakna",
    "saknanden": "saknande",
    "saknandena": "saknande",
    "saknandenas": "saknande",
    "saknandens": "saknande",
    "saknandes": "saknande",
    "saknandet": "saknande",
    "saknandets": "saknande",
    "saknar": "sakna",
    "saknas": "sakna",
    "saknat": "sakna",
    "saknats": "saknas",
    "sakobjekten": "sakobjekt",
    "sakobjektens": "sakobjekt",
    "sakobjektet": "sakobjekt",
    "sakobjektets": "sakobjekt",
    "sakobjekts": "sakobjekt",
    "sakockers": "sakocker",
    "sakockret": "sakocker",
    "sakockrets": "sakocker",
    "sakorden": "sakord",
    "sakordens": "sakord",
    "sakordet": "sakord",
    "sakordets": "sakord",
    "sakords": "sakord",
    "sakpolitiken": "sakpolitik",
    "sakpolitikens": "sakpolitik",
    "sakpolitiks": "sakpolitik",
    "sakpolitiska": "sakpolitisk",
    "sakpolitiskare": "sakpolitisk",
    "sakpolitiskares": "sakpolitisk",
    "sakpolitiskas": "sakpolitisk",
    "sakpolitiskast": "sakpolitisk",
    "sakpolitiskaste": "sakpolitisk",
    "sakpolitiskastes": "sakpolitisk",
    "sakpolitiskasts": "sakpolitisk",
    "sakpolitiske": "sakpolitisk",
    "sakpolitiskes": "sakpolitisk",
    "sakpolitisks": "sakpolitisk",
    "sakpolitiskt": "sakpolitisk",
    "sakpolitiskts": "sakpolitisk",
    "sakprosan": "sakprosa",
    "sakprosans": "sakprosa",
    "sakprosas": "sakprosa",
    "sakprövningar": "sakprövning",
    "sakprövningarna": "sakprövning",
    "sakprövningarnas": "sakprövning",
    "sakprövningars": "sakprövning",
    "sakprövningen": "sakprövning",
    "sakprövningens": "sakprövning",
    "sakprövnings": "sakprövning",
    "sakrala": "sakral",
    "sakralare": "sakral",
    "sakralares": "sakral",
    "sakralas": "sakral",
    "sakralast": "sakral",
    "sakralaste": "sakral",
    "sakralastes": "sakral",
    "sakralasts": "sakral",
    "sakrale": "sakral",
    "sakrales": "sakral",
    "sakrals": "sakral",
    "sakralt": "sakral",
    "sakralts": "sakral",
    "sakramentala": "sakramental",
    "sakramentalare": "sakramental",
    "sakramentalares": "sakramental",
    "sakramentalas": "sakramental",
    "sakramentalast": "sakramental",
    "sakramentalaste": "sakramental",
    "sakramentalastes": "sakramental",
    "sakramentalasts": "sakramental",
    "sakramentale": "sakramental",
    "sakramentales": "sakramental",
    "sakramentals": "sakramental",
    "sakramentalt": "sakramental",
    "sakramentalts": "sakramental",
    "sakramenten": "sakrament",
    "sakramentens": "sakrament",
    "sakramentet": "sakrament",
    "sakramentets": "sakrament",
    "sakraments": "sakrament",
    "sakramentskade": "sakramentskad",
    "sakramentskades": "sakramentskad",
    "sakramentskads": "sakramentskad",
    "sakramentskat": "sakramentskad",
    "sakramentskats": "sakramentskad",
    "sakramentsskåpen": "sakramentsskåp",
    "sakramentsskåpens": "sakramentsskåp",
    "sakramentsskåpet": "sakramentsskåp",
    "sakramentsskåpets": "sakramentsskåp",
    "sakramentsskåps": "sakramentsskåp",
    "sakregisterna": "sakregister",
    "sakregisternas": "sakregister",
    "sakregisters": "sakregister",
    "sakregistren": "sakregister",
    "sakregistrens": "sakregister",
    "sakregistret": "sakregister",
    "sakregistrets": "sakregister",
    "sakrilegie": "sakrilegium",
    "sakrilegier": "sakrilegium",
    "sakrilegierna": "sakrilegium",
    "sakrilegiernas": "sakrilegium",
    "sakrilegiers": "sakrilegium",
    "sakrilegiet": "sakrilegium",
    "sakrilegiets": "sakrilegium",
    "sakrilegiums": "sakrilegium",
    "sakristi": "sakristia",
    "sakristian": "sakristia",
    "sakristians": "sakristia",
    "sakristias": "sakristia",
    "sakristie": "sakristia",
    "sakristior": "sakristia",
    "sakristiorna": "sakristia",
    "sakristiornas": "sakristia",
    "sakristiors": "sakristia",
    "sakristis": "sakristia",
    "sakrosankta": "sakrosankt",
    "sakrosanktare": "sakrosankt",
    "sakrosanktares": "sakrosankt",
    "sakrosanktas": "sakrosankt",
    "sakrosanktast": "sakrosankt",
    "sakrosanktaste": "sakrosankt",
    "sakrosanktastes": "sakrosankt",
    "sakrosanktasts": "sakrosankt",
    "sakrosankte": "sakrosankt",
    "sakrosanktes": "sakrosankt",
    "sakrosanktheten": "sakrosankthet",
    "sakrosankthetens": "sakrosankthet",
    "sakrosankthets": "sakrosankthet",
    "sakrosankts": "sakrosankt",
    "sakrosanta": "sakrosant",
    "sakrosantare": "sakrosant",
    "sakrosantares": "sakrosant",
    "sakrosantas": "sakrosant",
    "sakrosantast": "sakrosant",
    "sakrosantaste": "sakrosant",
    "sakrosantastes": "sakrosant",
    "sakrosantasts": "sakrosant",
    "sakrosante": "sakrosant",
    "sakrosantes": "sakrosant",
    "sakrosants": "sakrosant",
    "sakrätten": "sakrätt",
    "sakrättens": "sakrätt",
    "sakrätts": "sakrätt",
    "sakrättsliga": "sakrättslig",
    "sakrättsligare": "sakrättslig",
    "sakrättsligares": "sakrättslig",
    "sakrättsligas": "sakrättslig",
    "sakrättsligast": "sakrättslig",
    "sakrättsligaste": "sakrättslig",
    "sakrättsligastes": "sakrättslig",
    "sakrättsligasts": "sakrättslig",
    "sakrättslige": "sakrättslig",
    "sakrättsliges": "sakrättslig",
    "sakrättsligs": "sakrättslig",
    "sakrättsligt": "sakrättslig",
    "sakrättsligts": "sakrättslig",
    "saks": "sak",
    "sakskadan": "sakskada",
    "sakskadans": "sakskada",
    "sakskadas": "sakskada",
    "sakskade": "sakskada",
    "sakskador": "sakskada",
    "sakskadorna": "sakskada",
    "sakskadornas": "sakskada",
    "sakskadors": "sakskada",
    "sakskälen": "sakskäl",
    "sakskälens": "sakskäl",
    "sakskälet": "sakskäl",
    "sakskälets": "sakskäl",
    "sakskäls": "sakskäl",
    "saksökandes": "saksökande",
    "saksökandet": "saksökande",
    "saksökandets": "saksökande",
    "saksökeriet": "saksökeri",
    "saksökeriets": "saksökeri",
    "saksökeris": "saksökeri",
    "saksökerit": "saksökeri",
    "saksökerits": "saksökeri",
    "saktad": "sakta",
    "saktade": "sakta",
    "saktades": "sakta",
    "saktads": "sakta",
    "saktande": "sakta",
    "saktanden": "saktande",
    "saktandena": "saktande",
    "saktandenas": "saktande",
    "saktandens": "saktande",
    "saktandes": "saktande",
    "saktandet": "saktande",
    "saktandets": "saktande",
    "saktar": "sakta",
    "saktare": "sakta",
    "saktas": "sakta",
    "saktast": "sakta",
    "saktat": "sakta",
    "saktats": "sakta",
    "saktfärdiga": "saktfärdig",
    "saktfärdigare": "saktfärdig",
    "saktfärdigares": "saktfärdig",
    "saktfärdigas": "saktfärdig",
    "saktfärdigast": "saktfärdig",
    "saktfärdigaste": "saktfärdig",
    "saktfärdigastes": "saktfärdig",
    "saktfärdigasts": "saktfärdig",
    "saktfärdige": "saktfärdig",
    "saktfärdiges": "saktfärdig",
    "saktfärdigheten": "saktfärdighet",
    "saktfärdighetens": "saktfärdighet",
    "saktfärdighets": "saktfärdighet",
    "saktfärdigs": "saktfärdig",
    "saktfärdigt": "saktfärdig",
    "saktfärdigts": "saktfärdig",
    "saktmodet": "saktmod",
    "saktmodets": "saktmod",
    "saktmodiga": "saktmodig",
    "saktmodigare": "saktmodig",
    "saktmodigares": "saktmodig",
    "saktmodigas": "saktmodig",
    "saktmodigast": "saktmodig",
    "saktmodigaste": "saktmodig",
    "saktmodigastes": "saktmodig",
    "saktmodigasts": "saktmodig",
    "saktmodige": "saktmodig",
    "saktmodiges": "saktmodig",
    "saktmodigheten": "saktmodighet",
    "saktmodighetens": "saktmodighet",
    "saktmodighets": "saktmodighet",
    "saktmodigs": "saktmodig",
    "saktmodigt": "saktmodig",
    "saktmodigts": "saktmodig",
    "saktmods": "saktmod",
    "sakuppgiften": "sakuppgift",
    "sakuppgiftens": "sakuppgift",
    "sakuppgifter": "sakuppgift",
    "sakuppgifterna": "sakuppgift",
    "sakuppgifternas": "sakuppgift",
    "sakuppgifters": "sakuppgift",
    "sakuppgifts": "sakuppgift",
    "sakupplysningar": "sakupplysning",
    "sakupplysningarna": "sakupplysning",
    "sakupplysningarnas": "sakupplysning",
    "sakupplysningars": "sakupplysning",
    "sakupplysningen": "sakupplysning",
    "sakupplysningens": "sakupplysning",
    "sakupplysnings": "sakupplysning",
    "sakäganden": "sakägande",
    "sakägandena": "sakägande",
    "sakägandenas": "sakägande",
    "sakägandens": "sakägande",
    "sakägandes": "sakägande",
    "sakägar": "sakägare",
    "sakägaren": "sakägare",
    "sakägarens": "sakägare",
    "sakägares": "sakägare",
    "sakägarna": "sakägare",
    "sakägarnas": "sakägare",
    "sakén": "saké",
    "sakéns": "saké",
    "sakés": "saké",
    "sakören": "saköre",
    "sakörena": "saköre",
    "sakörenas": "saköre",
    "sakörens": "saköre",
    "saköres": "saköre",
    "saköreslängden": "saköreslängd",
    "saköreslängdens": "saköreslängd",
    "saköreslängder": "saköreslängd",
    "saköreslängderna": "saköreslängd",
    "saköreslängdernas": "saköreslängd",
    "saköreslängders": "saköreslängd",
    "saköreslängds": "saköreslängd",
    "saköret": "saköre",
    "sakörets": "saköre",
    "sal": "sala",
    "salad": "sala",
    "salade": "sala",
    "salades": "sala",
    "saladjären": "saladjär",
    "saladjärens": "saladjär",
    "saladjärer": "saladjär",
    "saladjärerna": "saladjär",
    "saladjärernas": "saladjär",
    "saladjärers": "saladjär",
    "saladjärs": "saladjär",
    "salads": "sala",
    "salamandern": "salamander",
    "salamanderns": "salamander",
    "salamanders": "salamander",
    "salamandrar": "salamander",
    "salamandrarna": "salamander",
    "salamandrarnas": "salamander",
    "salamandrars": "salamander",
    "salamin": "salami",
    "salamins": "salami",
    "salamis": "salami",
    "salande": "sala",
    "salanden": "salande",
    "salandena": "salande",
    "salandenas": "salande",
    "salandens": "salande",
    "salandes": "salande",
    "salandet": "salande",
    "salandets": "salande",
    "salar": "sala",
    "salarna": "sal",
    "salarnas": "sal",
    "salars": "sal",
    "salas": "sala",
    "salat": "sala",
    "salats": "salat",
    "salbanden": "salband",
    "salbandens": "salband",
    "salbandet": "salband",
    "salbandets": "salband",
    "salbands": "salband",
    "salderad": "saldera",
    "salderade": "saldera",
    "salderades": "saldera",
    "salderads": "saldera",
    "salderande": "saldera",
    "salderanden": "salderande",
    "salderandena": "salderande",
    "salderandenas": "salderande",
    "salderandens": "salderande",
    "salderandes": "salderande",
    "salderandet": "salderande",
    "salderandets": "salderande",
    "salderar": "saldera",
    "salderas": "saldera",
    "salderat": "saldera",
    "salderats": "saldera",
    "salderbara": "salderbar",
    "salderbarare": "salderbar",
    "salderbarares": "salderbar",
    "salderbaras": "salderbar",
    "salderbarast": "salderbar",
    "salderbaraste": "salderbar",
    "salderbarastes": "salderbar",
    "salderbarasts": "salderbar",
    "salderbare": "salderbar",
    "salderbares": "salderbar",
    "salderbarheten": "salderbarhet",
    "salderbarhetens": "salderbarhet",
    "salderbarhets": "salderbarhet",
    "salderbars": "salderbar",
    "salderbart": "salderbar",
    "salderbarts": "salderbar",
    "salderingar": "saldering",
    "salderingarna": "saldering",
    "salderingarnas": "saldering",
    "salderingars": "saldering",
    "salderingen": "saldering",
    "salderingens": "saldering",
    "salderings": "saldering",
    "saldon": "saldo",
    "saldona": "saldo",
    "saldonas": "saldo",
    "saldons": "saldo",
    "saldos": "saldo",
    "saldot": "saldo",
    "saldots": "saldo",
    "salen": "sal",
    "salens": "sal",
    "salepen": "salep",
    "salepens": "salep",
    "saleps": "salep",
    "salepsroten": "salepsrot",
    "salepsrotens": "salepsrot",
    "salepsrots": "salepsrot",
    "salicylbomullen": "salicylbomull",
    "salicylbomullens": "salicylbomull",
    "salicylbomulls": "salicylbomull",
    "salicylsyran": "salicylsyra",
    "salicylsyrans": "salicylsyra",
    "salicylsyras": "salicylsyra",
    "salicylsyre": "salicylsyra",
    "salicylsyrepulvers": "salicylsyrepulver",
    "salicylsyrepulvret": "salicylsyrepulver",
    "salicylsyrepulvrets": "salicylsyrepulver",
    "saliga": "salig",
    "saligare": "salig",
    "saligares": "salig",
    "saligas": "salig",
    "saligast": "salig",
    "saligaste": "salig",
    "saligastes": "salig",
    "saligasts": "salig",
    "salige": "salig",
    "saliges": "salig",
    "saligförklarad": "saligförklara",
    "saligförklarade": "saligförklara",
    "saligförklarades": "saligförklara",
    "saligförklarads": "saligförklara",
    "saligförklarande": "saligförklara",
    "saligförklaranden": "saligförklarande",
    "saligförklarandena": "saligförklarande",
    "saligförklarandenas": "saligförklarande",
    "saligförklarandens": "saligförklarande",
    "saligförklarandes": "saligförklarande",
    "saligförklarandet": "saligförklarande",
    "saligförklarandets": "saligförklarande",
    "saligförklarar": "saligförklara",
    "saligförklaras": "saligförklara",
    "saligförklarat": "saligförklara",
    "saligförklarats": "saligförklara",
    "saligheten": "salighet",
    "salighetens": "salighet",
    "saligheter": "salighet",
    "saligheterna": "salighet",
    "saligheternas": "salighet",
    "saligheters": "salighet",
    "salighets": "salighet",
    "salighetsläran": "salighetslära",
    "salighetslärans": "salighetslära",
    "salighetsläras": "salighetslära",
    "salighetsläre": "salighetslära",
    "salighetsläro": "salighetslära",
    "salighetsläror": "salighetslära",
    "salighetslärorna": "salighetslära",
    "salighetslärornas": "salighetslära",
    "salighetslärors": "salighetslära",
    "salighetsmedels": "salighetsmedel",
    "salighetsmedlen": "salighetsmedel",
    "salighetsmedlens": "salighetsmedel",
    "salighetsmedlet": "salighetsmedel",
    "salighetsmedlets": "salighetsmedel",
    "salighetsrusen": "salighetsrus",
    "salighetsrusens": "salighetsrus",
    "salighetsruset": "salighetsrus",
    "salighetsrusets": "salighetsrus",
    "salighetsvägar": "salighetsväg",
    "salighetsvägarna": "salighetsväg",
    "salighetsvägarnas": "salighetsväg",
    "salighetsvägars": "salighetsväg",
    "salighetsvägen": "salighetsväg",
    "salighetsvägens": "salighetsväg",
    "salighetsvägs": "salighetsväg",
    "saligprisningar": "saligprisning",
    "saligprisningarna": "saligprisning",
    "saligprisningarnas": "saligprisning",
    "saligprisningars": "saligprisning",
    "saligprisningen": "saligprisning",
    "saligprisningens": "saligprisning",
    "saligprisnings": "saligprisning",
    "saligs": "salig",
    "saligt": "salig",
    "saligts": "salig",
    "salinen": "salin",
    "salinens": "salin",
    "saliner": "salin",
    "salinerna": "salin",
    "salinernas": "salin",
    "saliners": "salin",
    "saliniteten": "salinitet",
    "salinitetens": "salinitet",
    "saliniteter": "salinitet",
    "saliniteterna": "salinitet",
    "saliniteternas": "salinitet",
    "saliniteters": "salinitet",
    "salinitets": "salinitet",
    "salins": "salin",
    "saliska": "salisk",
    "saliskare": "salisk",
    "saliskares": "salisk",
    "saliskas": "salisk",
    "saliskast": "salisk",
    "saliskaste": "salisk",
    "saliskastes": "salisk",
    "saliskasts": "salisk",
    "saliske": "salisk",
    "saliskes": "salisk",
    "salisks": "salisk",
    "saliskt": "salisk",
    "saliskts": "salisk",
    "salivationen": "salivation",
    "salivationens": "salivation",
    "salivationer": "salivation",
    "salivationerna": "salivation",
    "salivationernas": "salivation",
    "salivationers": "salivation",
    "salivations": "salivation",
    "saliven": "saliv",
    "salivens": "saliv",
    "saliverade": "salivera",
    "saliverades": "salivera",
    "saliverande": "salivera",
    "saliveranden": "saliverande",
    "saliverandena": "saliverande",
    "saliverandenas": "saliverande",
    "saliverandens": "saliverande",
    "saliverandes": "saliverande",
    "saliverandet": "saliverande",
    "saliverandets": "saliverande",
    "saliverar": "salivera",
    "saliveras": "salivera",
    "saliverat": "salivera",
    "saliverats": "salivera",
    "saliveringar": "salivering",
    "saliveringarna": "salivering",
    "saliveringarnas": "salivering",
    "saliveringars": "salivering",
    "saliveringen": "salivering",
    "saliveringens": "salivering",
    "saliverings": "salivering",
    "salivproven": "salivprov",
    "salivprovens": "salivprov",
    "salivprover": "salivprov",
    "salivproverna": "salivprov",
    "salivprovernas": "salivprov",
    "salivprovers": "salivprov",
    "salivprovet": "salivprov",
    "salivprovets": "salivprov",
    "salivprovs": "salivprov",
    "salivs": "saliv",
    "salivsugar": "salivsugare",
    "salivsugaren": "salivsugare",
    "salivsugarens": "salivsugare",
    "salivsugares": "salivsugare",
    "salivsugarna": "salivsugare",
    "salivsugarnas": "salivsugare",
    "salivsugars": "salivsug",
    "salivsugen": "salivsug",
    "salivsugens": "salivsug",
    "salivsugs": "salivsug",
    "salladen": "sallad",
    "salladens": "sallad",
    "sallader": "sallad",
    "salladerna": "sallad",
    "salladernas": "sallad",
    "salladers": "sallad",
    "sallads": "sallad",
    "salladsbaren": "salladsbar",
    "salladsbarens": "salladsbar",
    "salladsbarer": "salladsbar",
    "salladsbarerna": "salladsbar",
    "salladsbarernas": "salladsbar",
    "salladsbarers": "salladsbar",
    "salladsbars": "salladsbar",
    "salladsbesticken": "salladsbestick",
    "salladsbestickens": "salladsbestick",
    "salladsbesticket": "salladsbestick",
    "salladsbestickets": "salladsbestick",
    "salladsbesticks": "salladsbestick",
    "salladsgurk": "salladsgurka",
    "salladsgurkan": "salladsgurka",
    "salladsgurkans": "salladsgurka",
    "salladsgurkas": "salladsgurka",
    "salladsgurke": "salladsgurka",
    "salladsgurkor": "salladsgurka",
    "salladsgurkorna": "salladsgurka",
    "salladsgurkornas": "salladsgurka",
    "salladsgurkors": "salladsgurka",
    "salladsgurks": "salladsgurka",
    "salladshuvuden": "salladshuvud",
    "salladshuvudena": "salladshuvud",
    "salladshuvudenas": "salladshuvud",
    "salladshuvudens": "salladshuvud",
    "salladshuvudet": "salladshuvud",
    "salladshuvudets": "salladshuvud",
    "salladshuvuds": "salladshuvud",
    "salladsskålar": "salladsskål",
    "salladsskålarna": "salladsskål",
    "salladsskålarnas": "salladsskål",
    "salladsskålars": "salladsskål",
    "salladsskålen": "salladsskål",
    "salladsskålens": "salladsskål",
    "salladsskåls": "salladsskål",
    "sallaten": "sallat",
    "sallatens": "sallat",
    "sallats": "sallat",
    "salmiaken": "salmiak",
    "salmiakens": "salmiak",
    "salmiaks": "salmiak",
    "salmiakspriten": "salmiaksprit",
    "salmiakspritens": "salmiaksprit",
    "salmiaksprits": "salmiaksprit",
    "salmonellainfekterade": "salmonellainfekterad",
    "salmonellainfekterades": "salmonellainfekterad",
    "salmonellainfekterads": "salmonellainfekterad",
    "salmonellainfekterat": "salmonellainfekterad",
    "salmonellainfekterats": "salmonellainfekterad",
    "salmonellan": "salmonella",
    "salmonellans": "salmonella",
    "salmonellas": "salmonella",
    "salningar": "salning",
    "salningarna": "salning",
    "salningarnas": "salning",
    "salningars": "salning",
    "salningen": "salning",
    "salningens": "salning",
    "salnings": "salning",
    "salningshornen": "salningshorn",
    "salningshornens": "salningshorn",
    "salningshornet": "salningshorn",
    "salningshornets": "salningshorn",
    "salningshorns": "salningshorn",
    "salomoniern": "salomonier",
    "salomonierna": "salomonier",
    "salomoniernas": "salomonier",
    "salomonierns": "salomonier",
    "salomoniers": "salomonier",
    "salomoniska": "salomonisk",
    "salomoniskare": "salomonisk",
    "salomoniskares": "salomonisk",
    "salomoniskas": "salomonisk",
    "salomoniskast": "salomonisk",
    "salomoniskaste": "salomonisk",
    "salomoniskastes": "salomonisk",
    "salomoniskasts": "salomonisk",
    "salomoniske": "salomonisk",
    "salomoniskes": "salomonisk",
    "salomonisks": "salomonisk",
    "salomoniskt": "salomonisk",
    "salomoniskts": "salomonisk",
    "salomonska": "salomonsk",
    "salomonskan": "salomonska",
    "salomonskans": "salomonska",
    "salomonskare": "salomonsk",
    "salomonskares": "salomonsk",
    "salomonskas": "salomonska",
    "salomonskast": "salomonsk",
    "salomonskaste": "salomonsk",
    "salomonskastes": "salomonsk",
    "salomonskasts": "salomonsk",
    "salomonske": "salomonska",
    "salomonskes": "salomonsk",
    "salomonskor": "salomonska",
    "salomonskorna": "salomonska",
    "salomonskornas": "salomonska",
    "salomonskors": "salomonska",
    "salomonsks": "salomonsk",
    "salomonskt": "salomonsk",
    "salomonskts": "salomonsk",
    "salongen": "salong",
    "salongens": "salong",
    "salonger": "salong",
    "salongerna": "salong",
    "salongernas": "salong",
    "salongers": "salong",
    "salongs": "salong",
    "salongsberusade": "salongsberusad",
    "salongsberusades": "salongsberusad",
    "salongsberusads": "salongsberusad",
    "salongsberusat": "salongsberusad",
    "salongsberusats": "salongsberusad",
    "salongsbiljetten": "salongsbiljett",
    "salongsbiljettens": "salongsbiljett",
    "salongsbiljetter": "salongsbiljett",
    "salongsbiljetterna": "salongsbiljett",
    "salongsbiljetternas": "salongsbiljett",
    "salongsbiljetters": "salongsbiljett",
    "salongsbiljetts": "salongsbiljett",
    "salongsbolsjeviken": "salongsbolsjevik",
    "salongsbolsjevikens": "salongsbolsjevik",
    "salongsbolsjeviker": "salongsbolsjevik",
    "salongsbolsjevikerna": "salongsbolsjevik",
    "salongsbolsjevikernas": "salongsbolsjevik",
    "salongsbolsjevikers": "salongsbolsjevik",
    "salongsbolsjeviks": "salongsbolsjevik",
    "salongsbåtar": "salongsbåt",
    "salongsbåtarna": "salongsbåt",
    "salongsbåtarnas": "salongsbåt",
    "salongsbåtars": "salongsbåt",
    "salongsbåten": "salongsbåt",
    "salongsbåtens": "salongsbåt",
    "salongsbåts": "salongsbåt",
    "salongsfilosofen": "salongsfilosof",
    "salongsfilosofens": "salongsfilosof",
    "salongsfilosofer": "salongsfilosof",
    "salongsfilosoferna": "salongsfilosof",
    "salongsfilosofernas": "salongsfilosof",
    "salongsfilosofers": "salongsfilosof",
    "salongsfilosofs": "salongsfilosof",
    "salongsfähiga": "salongsfähig",
    "salongsfähigare": "salongsfähig",
    "salongsfähigares": "salongsfähig",
    "salongsfähigas": "salongsfähig",
    "salongsfähigast": "salongsfähig",
    "salongsfähigaste": "salongsfähig",
    "salongsfähigastes": "salongsfähig",
    "salongsfähigasts": "salongsfähig",
    "salongsfähige": "salongsfähig",
    "salongsfähiges": "salongsfähig",
    "salongsfähigheten": "salongsfähighet",
    "salongsfähighetens": "salongsfähighet",
    "salongsfähighets": "salongsfähighet",
    "salongsfähigs": "salongsfähig",
    "salongsfähigt": "salongsfähig",
    "salongsfähigts": "salongsfähig",
    "salongsgevären": "salongsgevär",
    "salongsgevärens": "salongsgevär",
    "salongsgeväret": "salongsgevär",
    "salongsgevärets": "salongsgevär",
    "salongsgevärs": "salongsgevär",
    "salongskomedien": "salongskomedi",
    "salongskomediens": "salongskomedi",
    "salongskomedier": "salongskomedi",
    "salongskomedierna": "salongskomedi",
    "salongskomediernas": "salongskomedi",
    "salongskomediers": "salongskomedi",
    "salongskomedin": "salongskomedi",
    "salongskomedins": "salongskomedi",
    "salongskomedis": "salongskomedi",
    "salongskommunisten": "salongskommunist",
    "salongskommunistens": "salongskommunist",
    "salongskommunister": "salongskommunist",
    "salongskommunisterna": "salongskommunist",
    "salongskommunisternas": "salongskommunist",
    "salongskommunisters": "salongskommunist",
    "salongskommunists": "salongskommunist",
    "salongslejonen": "salongslejon",
    "salongslejonens": "salongslejon",
    "salongslejonet": "salongslejon",
    "salongslejonets": "salongslejon",
    "salongslejons": "salongslejon",
    "salongsmässiga": "salongsmässig",
    "salongsmässigare": "salongsmässig",
    "salongsmässigares": "salongsmässig",
    "salongsmässigas": "salongsmässig",
    "salongsmässigast": "salongsmässig",
    "salongsmässigaste": "salongsmässig",
    "salongsmässigastes": "salongsmässig",
    "salongsmässigasts": "salongsmässig",
    "salongsmässige": "salongsmässig",
    "salongsmässiges": "salongsmässig",
    "salongsmässigs": "salongsmässig",
    "salongsmässigt": "salongsmässig",
    "salongsmässigts": "salongsmässig",
    "salongsorkestern": "salongsorkester",
    "salongsorkesterns": "salongsorkester",
    "salongsorkesters": "salongsorkester",
    "salongsorkestrar": "salongsorkester",
    "salongsorkestrarna": "salongsorkester",
    "salongsorkestrarnas": "salongsorkester",
    "salongsorkestrars": "salongsorkester",
    "salongsruffar": "salongsruff",
    "salongsruffarna": "salongsruff",
    "salongsruffarnas": "salongsruff",
    "salongsruffars": "salongsruff",
    "salongsruffen": "salongsruff",
    "salongsruffens": "salongsruff",
    "salongsruffs": "salongsruff",
    "salongsuppassar": "salongsuppassare",
    "salongsuppassaren": "salongsuppassare",
    "salongsuppassarens": "salongsuppassare",
    "salongsuppassares": "salongsuppassare",
    "salongsuppassarna": "salongsuppassare",
    "salongsuppassarnas": "salongsuppassare",
    "salongsvagnar": "salongsvagn",
    "salongsvagnarna": "salongsvagn",
    "salongsvagnarnas": "salongsvagn",
    "salongsvagnars": "salongsvagn",
    "salongsvagnen": "salongsvagn",
    "salongsvagnens": "salongsvagn",
    "salongsvagns": "salongsvagn",
    "saloondörrar": "saloondörr",
    "saloondörrarna": "saloondörr",
    "saloondörrarnas": "saloondörr",
    "saloondörrars": "saloondörr",
    "saloondörren": "saloondörr",
    "saloondörrens": "saloondörr",
    "saloondörrs": "saloondörr",
    "saloonen": "saloon",
    "saloonens": "saloon",
    "salooner": "saloon",
    "saloonerna": "saloon",
    "saloonernas": "saloon",
    "salooners": "saloon",
    "saloons": "saloon",
    "salpeterbakterien": "salpeterbakterie",
    "salpeterbakteriens": "salpeterbakterie",
    "salpeterbakterier": "salpeterbakterie",
    "salpeterbakterierna": "salpeterbakterie",
    "salpeterbakteriernas": "salpeterbakterie",
    "salpeterbakteriers": "salpeterbakterie",
    "salpeterbakteries": "salpeterbakterie",
    "salpetergruv": "salpetergruva",
    "salpetergruvan": "salpetergruva",
    "salpetergruvans": "salpetergruva",
    "salpetergruvas": "salpetergruva",
    "salpetergruve": "salpetergruva",
    "salpetergruvor": "salpetergruva",
    "salpetergruvorna": "salpetergruva",
    "salpetergruvornas": "salpetergruva",
    "salpetergruvors": "salpetergruva",
    "salpetergruvs": "salpetergruva",
    "salpetern": "salpeter",
    "salpeterns": "salpeter",
    "salpeters": "salpeter",
    "salpetersjuderier": "salpetersjuderi",
    "salpetersjuderierna": "salpetersjuderi",
    "salpetersjuderiernas": "salpetersjuderi",
    "salpetersjuderiers": "salpetersjuderi",
    "salpetersjuderiet": "salpetersjuderi",
    "salpetersjuderiets": "salpetersjuderi",
    "salpetersjuderis": "salpetersjuderi",
    "salpetersjuderit": "salpetersjuderi",
    "salpetersjuderits": "salpetersjuderi",
    "salpetersyran": "salpetersyra",
    "salpetersyrans": "salpetersyra",
    "salpetersyras": "salpetersyra",
    "salpetersyre": "salpetersyra",
    "salpetersyrligheten": "salpetersyrlighet",
    "salpetersyrlighetens": "salpetersyrlighet",
    "salpetersyrligheter": "salpetersyrlighet",
    "salpetersyrligheterna": "salpetersyrlighet",
    "salpetersyrligheternas": "salpetersyrlighet",
    "salpetersyrligheters": "salpetersyrlighet",
    "salpetersyrlighets": "salpetersyrlighet",
    "salpingiten": "salpingit",
    "salpingitens": "salpingit",
    "salpingiter": "salpingit",
    "salpingiterna": "salpingit",
    "salpingiternas": "salpingit",
    "salpingiters": "salpingit",
    "salpingits": "salpingit",
    "sals": "sal",
    "salskrak": "salskrake",
    "salskrakar": "salskrake",
    "salskrakarna": "salskrake",
    "salskrakarnas": "salskrake",
    "salskrakars": "salskrake",
    "salskraken": "salskrake",
    "salskrakens": "salskrake",
    "salskrakes": "salskrake",
    "salskraks": "salskrake",
    "salspatienten": "salspatient",
    "salspatientens": "salspatient",
    "salspatienter": "salspatient",
    "salspatienterna": "salspatient",
    "salspatienternas": "salspatient",
    "salspatienters": "salspatient",
    "salspatients": "salspatient",
    "salt": "salta",
    "salta": "salt",
    "saltad": "salta",
    "saltade": "salta",
    "saltades": "salta",
    "saltads": "salta",
    "saltande": "salta",
    "saltanden": "saltande",
    "saltandena": "saltande",
    "saltandenas": "saltande",
    "saltandens": "saltande",
    "saltandes": "saltande",
    "saltandet": "saltande",
    "saltandets": "saltande",
    "saltar": "salta",
    "saltare": "salt",
    "saltares": "salt",
    "saltas": "salta",
    "saltast": "salt",
    "saltaste": "salt",
    "saltastes": "salt",
    "saltasts": "salt",
    "saltat": "salta",
    "saltats": "salta",
    "saltavlagringar": "saltavlagring",
    "saltavlagringarna": "saltavlagring",
    "saltavlagringarnas": "saltavlagring",
    "saltavlagringars": "saltavlagring",
    "saltavlagringen": "saltavlagring",
    "saltavlagringens": "saltavlagring",
    "saltavlagrings": "saltavlagring",
    "saltbaden": "saltbad",
    "saltbadens": "saltbad",
    "saltbadet": "saltbad",
    "saltbadets": "saltbad",
    "saltbads": "saltbad",
    "saltbassängen": "saltbassäng",
    "saltbassängens": "saltbassäng",
    "saltbassänger": "saltbassäng",
    "saltbassängerna": "saltbassäng",
    "saltbassängernas": "saltbassäng",
    "saltbassängers": "saltbassäng",
    "saltbassängs": "saltbassäng",
    "saltbehoven": "saltbehov",
    "saltbehovens": "saltbehov",
    "saltbehovet": "saltbehov",
    "saltbehovets": "saltbehov",
    "saltbehovs": "saltbehov",
    "saltbemängda": "saltbemängd",
    "saltbemängdare": "saltbemängd",
    "saltbemängdares": "saltbemängd",
    "saltbemängdas": "saltbemängd",
    "saltbemängdast": "saltbemängd",
    "saltbemängdaste": "saltbemängd",
    "saltbemängdastes": "saltbemängd",
    "saltbemängdasts": "saltbemängd",
    "saltbemängde": "saltbemängd",
    "saltbemängdes": "saltbemängd",
    "saltbemängdheten": "saltbemängdhet",
    "saltbemängdhetens": "saltbemängdhet",
    "saltbemängdhets": "saltbemängdhet",
    "saltbemängds": "saltbemängd",
    "saltbemängt": "saltbemängd",
    "saltbemängts": "saltbemängd",
    "saltbildar": "saltbildare",
    "saltbildaren": "saltbildare",
    "saltbildarens": "saltbildare",
    "saltbildares": "saltbildare",
    "saltbildarna": "saltbildare",
    "saltbildarnas": "saltbildare",
    "saltdammar": "saltdamm",
    "saltdammarna": "saltdamm",
    "saltdammarnas": "saltdamm",
    "saltdammars": "saltdamm",
    "saltdammen": "saltdamm",
    "saltdammens": "saltdamm",
    "saltdamms": "saltdamm",
    "salte": "salt",
    "salter": "salt",
    "salterier": "salteri",
    "salterierna": "salteri",
    "salteriernas": "salteri",
    "salteriers": "salteri",
    "salteriet": "salteri",
    "salteriets": "salteri",
    "salteris": "salteri",
    "salterit": "salteri",
    "salterits": "salteri",
    "salterna": "salt",
    "salternas": "salt",
    "salters": "salt",
    "saltes": "salt",
    "saltet": "salt",
    "saltets": "salt",
    "saltfisken": "saltfisk",
    "saltfiskens": "saltfisk",
    "saltfisks": "saltfisk",
    "saltglasyren": "saltglasyr",
    "saltglasyrens": "saltglasyr",
    "saltglasyrs": "saltglasyr",
    "saltgropar": "saltgrop",
    "saltgroparna": "saltgrop",
    "saltgroparnas": "saltgrop",
    "saltgropars": "saltgrop",
    "saltgropen": "saltgrop",
    "saltgropens": "saltgrop",
    "saltgrops": "saltgrop",
    "saltgruv": "saltgruva",
    "saltgruvan": "saltgruva",
    "saltgruvans": "saltgruva",
    "saltgruvas": "saltgruva",
    "saltgruve": "saltgruva",
    "saltgruvor": "saltgruva",
    "saltgruvorna": "saltgruva",
    "saltgruvornas": "saltgruva",
    "saltgruvors": "saltgruva",
    "saltgruvs": "saltgruva",
    "saltgurk": "saltgurka",
    "saltgurkan": "saltgurka",
    "saltgurkans": "saltgurka",
    "saltgurkas": "saltgurka",
    "saltgurke": "saltgurka",
    "saltgurkor": "saltgurka",
    "saltgurkorna": "saltgurka",
    "saltgurkornas": "saltgurka",
    "saltgurkors": "saltgurka",
    "saltgurks": "saltgurka",
    "salthalten": "salthalt",
    "salthaltens": "salthalt",
    "salthalter": "salthalt",
    "salthalterna": "salthalt",
    "salthalternas": "salthalt",
    "salthalters": "salthalt",
    "salthaltiga": "salthaltig",
    "salthaltigare": "salthaltig",
    "salthaltigares": "salthaltig",
    "salthaltigas": "salthaltig",
    "salthaltigast": "salthaltig",
    "salthaltigaste": "salthaltig",
    "salthaltigastes": "salthaltig",
    "salthaltigasts": "salthaltig",
    "salthaltige": "salthaltig",
    "salthaltiges": "salthaltig",
    "salthaltigs": "salthaltig",
    "salthaltigt": "salthaltig",
    "salthaltigts": "salthaltig",
    "salthalts": "salthalt",
    "saltheten": "salthet",
    "salthetens": "salthet",
    "salthets": "salthet",
    "saltiga": "saltig",
    "saltigare": "saltig",
    "saltigares": "saltig",
    "saltigas": "saltig",
    "saltigast": "saltig",
    "saltigaste": "saltig",
    "saltigastes": "saltig",
    "saltigasts": "saltig",
    "saltige": "saltig",
    "saltiges": "saltig",
    "saltigheten": "saltighet",
    "saltighetens": "saltighet",
    "saltighets": "saltighet",
    "saltigs": "saltig",
    "saltigt": "saltig",
    "saltigts": "saltig",
    "saltimboccan": "saltimbocca",
    "saltimboccans": "saltimbocca",
    "saltimboccas": "saltimbocca",
    "saltkaren": "saltkar",
    "saltkarens": "saltkar",
    "saltkaret": "saltkar",
    "saltkarets": "saltkar",
    "saltkars": "saltkar",
    "saltkoncentrationen": "saltkoncentration",
    "saltkoncentrationens": "saltkoncentration",
    "saltkoncentrationer": "saltkoncentration",
    "saltkoncentrationerna": "saltkoncentration",
    "saltkoncentrationernas": "saltkoncentration",
    "saltkoncentrationers": "saltkoncentration",
    "saltkoncentrations": "saltkoncentration",
    "saltkristallen": "saltkristall",
    "saltkristallens": "saltkristall",
    "saltkristaller": "saltkristall",
    "saltkristallerna": "saltkristall",
    "saltkristallernas": "saltkristall",
    "saltkristallers": "saltkristall",
    "saltkristalls": "saltkristall",
    "saltkäll": "saltkälla",
    "saltkällan": "saltkälla",
    "saltkällans": "saltkälla",
    "saltkällas": "saltkälla",
    "saltkälle": "saltkälla",
    "saltkällor": "saltkälla",
    "saltkällorna": "saltkälla",
    "saltkällornas": "saltkälla",
    "saltkällors": "saltkälla",
    "saltkälls": "saltkälla",
    "saltlaken": "saltlake",
    "saltlakens": "saltlake",
    "saltlakes": "saltlake",
    "saltlång": "saltlånga",
    "saltlångan": "saltlånga",
    "saltlångans": "saltlånga",
    "saltlångas": "saltlånga",
    "saltlånge": "saltlånga",
    "saltlångor": "saltlånga",
    "saltlångorna": "saltlånga",
    "saltlångornas": "saltlånga",
    "saltlångors": "saltlånga",
    "saltlångs": "saltlånga",
    "saltlösningar": "saltlösning",
    "saltlösningarna": "saltlösning",
    "saltlösningarnas": "saltlösning",
    "saltlösningars": "saltlösning",
    "saltlösningen": "saltlösning",
    "saltlösningens": "saltlösning",
    "saltlösnings": "saltlösning",
    "saltomortalen": "saltomortal",
    "saltomortalens": "saltomortal",
    "saltomortaler": "saltomortal",
    "saltomortalerna": "saltomortal",
    "saltomortalernas": "saltomortal",
    "saltomortalers": "saltomortal",
    "saltomortals": "saltomortal",
    "saltprovar": "saltprovare",
    "saltprovaren": "saltprovare",
    "saltprovarens": "saltprovare",
    "saltprovares": "saltprovare",
    "saltprovarna": "saltprovare",
    "saltprovarnas": "saltprovare",
    "salts": "salt",
    "saltsjöar": "saltsjö",
    "saltsjöarna": "saltsjö",
    "saltsjöarnas": "saltsjö",
    "saltsjöars": "saltsjö",
    "saltsjöbadsandan": "saltsjöbadsanda",
    "saltsjöbadsandans": "saltsjöbadsanda",
    "saltsjöbadsandas": "saltsjöbadsanda",
    "saltsjön": "saltsjö",
    "saltsjöns": "saltsjö",
    "saltsjös": "saltsjö",
    "saltsleken": "saltsleke",
    "saltslekena": "saltsleke",
    "saltslekenas": "saltsleke",
    "saltslekens": "saltsleke",
    "saltslekes": "saltsleke",
    "saltsleket": "saltsleke",
    "saltslekets": "saltsleke",
    "saltsleks": "saltsleke",
    "saltspadet": "saltspad",
    "saltspadets": "saltspad",
    "saltspads": "saltspad",
    "saltstenen": "saltsten",
    "saltstenens": "saltsten",
    "saltstens": "saltsten",
    "saltstoden": "saltstod",
    "saltstodens": "saltstod",
    "saltstoder": "saltstod",
    "saltstoderna": "saltstod",
    "saltstodernas": "saltstod",
    "saltstoders": "saltstod",
    "saltstods": "saltstod",
    "saltströar": "saltströare",
    "saltströaren": "saltströare",
    "saltströarens": "saltströare",
    "saltströares": "saltströare",
    "saltströarna": "saltströare",
    "saltströarnas": "saltströare",
    "saltstänkta": "saltstänkt",
    "saltstänktare": "saltstänkt",
    "saltstänktares": "saltstänkt",
    "saltstänktas": "saltstänkt",
    "saltstänktast": "saltstänkt",
    "saltstänktaste": "saltstänkt",
    "saltstänktastes": "saltstänkt",
    "saltstänktasts": "saltstänkt",
    "saltstänkte": "saltstänkt",
    "saltstänktes": "saltstänkt",
    "saltstänktheten": "saltstänkthet",
    "saltstänkthetens": "saltstänkthet",
    "saltstänkthets": "saltstänkthet",
    "saltstänkts": "saltstänkt",
    "saltsyran": "saltsyra",
    "saltsyrans": "saltsyra",
    "saltsyras": "saltsyra",
    "saltsyre": "saltsyra",
    "saltutvinningar": "saltutvinning",
    "saltutvinningarna": "saltutvinning",
    "saltutvinningarnas": "saltutvinning",
    "saltutvinningars": "saltutvinning",
    "saltutvinningen": "saltutvinning",
    "saltutvinningens": "saltutvinning",
    "saltutvinnings": "saltutvinning",
    "saltvattens": "saltvatten",
    "saltvattensfiskar": "saltvattensfisk",
    "saltvattensfiskarna": "saltvattensfisk",
    "saltvattensfiskarnas": "saltvattensfisk",
    "saltvattensfiskars": "saltvattensfisk",
    "saltvattensfisken": "saltvattensfisk",
    "saltvattensfiskens": "saltvattensfisk",
    "saltvattensfisks": "saltvattensfisk",
    "saltvattensnäck": "saltvattensnäcka",
    "saltvattensnäckan": "saltvattensnäcka",
    "saltvattensnäckans": "saltvattensnäcka",
    "saltvattensnäckas": "saltvattensnäcka",
    "saltvattensnäcke": "saltvattensnäcka",
    "saltvattensnäckor": "saltvattensnäcka",
    "saltvattensnäckorna": "saltvattensnäcka",
    "saltvattensnäckornas": "saltvattensnäcka",
    "saltvattensnäckors": "saltvattensnäcka",
    "saltvattensnäcks": "saltvattensnäcka",
    "saltvattnen": "saltvatten",
    "saltvattnens": "saltvatten",
    "saltvattnet": "saltvatten",
    "saltvattnets": "saltvatten",
    "saltverken": "saltverk",
    "saltverkens": "saltverk",
    "saltverket": "saltverk",
    "saltverkets": "saltverk",
    "saltverks": "saltverk",
    "saltväxten": "saltväxt",
    "saltväxtens": "saltväxt",
    "saltväxter": "saltväxt",
    "saltväxterna": "saltväxt",
    "saltväxternas": "saltväxt",
    "saltväxters": "saltväxt",
    "saltväxts": "saltväxt",
    "saltängar": "saltäng",
    "saltängarna": "saltäng",
    "saltängarnas": "saltäng",
    "saltängars": "saltäng",
    "saltängen": "saltäng",
    "saltängens": "saltäng",
    "saltängs": "saltäng",
    "saltökenn": "saltöken",
    "saltökenns": "saltöken",
    "saltökens": "saltöken",
    "saltöknar": "saltöken",
    "saltöknarna": "saltöken",
    "saltöknarnas": "saltöken",
    "saltöknars": "saltöken",
    "saltörten": "saltört",
    "saltörtens": "saltört",
    "saltörter": "saltört",
    "saltörterna": "saltört",
    "saltörternas": "saltört",
    "saltörters": "saltört",
    "saltörts": "saltört",
    "salubjud": "salubjuda",
    "salubjudande": "salubjuda",
    "salubjudanden": "salubjudande",
    "salubjudandena": "salubjudande",
    "salubjudandenas": "salubjudande",
    "salubjudandens": "salubjudande",
    "salubjudandes": "salubjudande",
    "salubjudandet": "salubjudande",
    "salubjudandets": "salubjudande",
    "salubjudas": "salubjuda",
    "salubjude": "salubjuda",
    "salubjuden": "salubjuda",
    "salubjudens": "salubjuda",
    "salubjuder": "salubjuda",
    "salubjudes": "salubjuda",
    "salubjudet": "salubjuda",
    "salubjudets": "salubjuda",
    "salubjudit": "salubjuda",
    "salubjudits": "salubjuda",
    "salubjudna": "salubjuda",
    "salubjudnas": "salubjuda",
    "salubjudne": "salubjuda",
    "salubjudnes": "salubjuda",
    "salubjuds": "salubjuda",
    "salubjöd": "salubjuda",
    "salubjöde": "salubjuda",
    "salubjödes": "salubjuda",
    "salubjöds": "salubjuda",
    "salubrinen": "salubrin",
    "salubrinens": "salubrin",
    "salubrinet": "salubrin",
    "salubrinets": "salubrin",
    "salubrins": "salubrin",
    "saluför": "saluföra",
    "saluförande": "saluföra",
    "saluföranden": "saluförande",
    "saluförandena": "saluförande",
    "saluförandenas": "saluförande",
    "saluförandens": "saluförande",
    "saluförandes": "saluförande",
    "saluförandet": "saluförande",
    "saluförandets": "saluförande",
    "saluföras": "saluföra",
    "saluförd": "saluföra",
    "saluförda": "saluföra",
    "salufördas": "saluföra",
    "saluförde": "saluföra",
    "salufördes": "saluföra",
    "saluförds": "saluföra",
    "saluföres": "saluföra",
    "saluförs": "saluföra",
    "salufört": "saluföra",
    "saluförts": "saluföra",
    "saluhallar": "saluhall",
    "saluhallarna": "saluhall",
    "saluhallarnas": "saluhall",
    "saluhallars": "saluhall",
    "saluhallen": "saluhall",
    "saluhallens": "saluhall",
    "saluhalls": "saluhall",
    "saluprisen": "salupris",
    "saluprisens": "salupris",
    "salupriser": "salupris",
    "salupriserna": "salupris",
    "saluprisernas": "salupris",
    "saluprisers": "salupris",
    "salupriset": "salupris",
    "saluprisets": "salupris",
    "salustånden": "salustånd",
    "saluståndens": "salustånd",
    "saluståndet": "salustånd",
    "saluståndets": "salustånd",
    "salustånds": "salustånd",
    "salutdagar": "salutdag",
    "salutdagarna": "salutdag",
    "salutdagarnas": "salutdag",
    "salutdagars": "salutdag",
    "salutdagen": "salutdag",
    "salutdagens": "salutdag",
    "salutdags": "salutdag",
    "saluten": "salut",
    "salutens": "salut",
    "saluter": "salut",
    "saluterad": "salutera",
    "saluterade": "salutera",
    "saluterades": "salutera",
    "saluterads": "salutera",
    "saluterande": "salutera",
    "saluteranden": "saluterande",
    "saluterandena": "saluterande",
    "saluterandenas": "saluterande",
    "saluterandens": "saluterande",
    "saluterandes": "saluterande",
    "saluterandet": "saluterande",
    "saluterandets": "saluterande",
    "saluterar": "salutera",
    "saluteras": "salutera",
    "saluterat": "salutera",
    "saluterats": "salutera",
    "saluterbara": "saluterbar",
    "saluterbarare": "saluterbar",
    "saluterbarares": "saluterbar",
    "saluterbaras": "saluterbar",
    "saluterbarast": "saluterbar",
    "saluterbaraste": "saluterbar",
    "saluterbarastes": "saluterbar",
    "saluterbarasts": "saluterbar",
    "saluterbare": "saluterbar",
    "saluterbares": "saluterbar",
    "saluterbarheten": "saluterbarhet",
    "saluterbarhetens": "saluterbarhet",
    "saluterbarhets": "saluterbarhet",
    "saluterbars": "saluterbar",
    "saluterbart": "saluterbar",
    "saluterbarts": "saluterbar",
    "saluteringar": "salutering",
    "saluteringarna": "salutering",
    "saluteringarnas": "salutering",
    "saluteringars": "salutering",
    "saluteringen": "salutering",
    "saluteringens": "salutering",
    "saluterings": "salutering",
    "saluterna": "salut",
    "saluternas": "salut",
    "saluters": "salut",
    "salutkanonen": "salutkanon",
    "salutkanonens": "salutkanon",
    "salutkanoner": "salutkanon",
    "salutkanonerna": "salutkanon",
    "salutkanonernas": "salutkanon",
    "salutkanoners": "salutkanon",
    "salutkanons": "salutkanon",
    "salutorgen": "salutorg",
    "salutorgens": "salutorg",
    "salutorget": "salutorg",
    "salutorgets": "salutorg",
    "salutorgs": "salutorg",
    "saluts": "salut",
    "salutskjutningar": "salutskjutning",
    "salutskjutningarna": "salutskjutning",
    "salutskjutningarnas": "salutskjutning",
    "salutskjutningars": "salutskjutning",
    "salutskjutningen": "salutskjutning",
    "salutskjutningens": "salutskjutning",
    "salutskjutnings": "salutskjutning",
    "salutskotten": "salutskott",
    "salutskottens": "salutskott",
    "salutskottet": "salutskott",
    "salutskottets": "salutskott",
    "salutskotts": "salutskott",
    "saluvärden": "saluvärde",
    "saluvärdena": "saluvärde",
    "saluvärdenas": "saluvärde",
    "saluvärdens": "saluvärde",
    "saluvärdes": "saluvärde",
    "saluvärdet": "saluvärde",
    "saluvärdets": "saluvärde",
    "salv": "salva",
    "salvadoranen": "salvadoran",
    "salvadoranens": "salvadoran",
    "salvadoraner": "salvadoran",
    "salvadoranerna": "salvadoran",
    "salvadoranernas": "salvadoran",
    "salvadoraners": "salvadoran",
    "salvadorans": "salvadoran",
    "salvadoranska": "salvadoransk",
    "salvadoranskan": "salvadoranska",
    "salvadoranskans": "salvadoranska",
    "salvadoranskare": "salvadoransk",
    "salvadoranskares": "salvadoransk",
    "salvadoranskas": "salvadoranska",
    "salvadoranskast": "salvadoransk",
    "salvadoranskaste": "salvadoransk",
    "salvadoranskastes": "salvadoransk",
    "salvadoranskasts": "salvadoransk",
    "salvadoranske": "salvadoranska",
    "salvadoranskes": "salvadoransk",
    "salvadoranskor": "salvadoranska",
    "salvadoranskorna": "salvadoranska",
    "salvadoranskornas": "salvadoranska",
    "salvadoranskors": "salvadoranska",
    "salvadoransks": "salvadoransk",
    "salvadoranskt": "salvadoransk",
    "salvadoranskts": "salvadoransk",
    "salvan": "salva",
    "salvans": "salva",
    "salvarsanen": "salvarsan",
    "salvarsanens": "salvarsan",
    "salvarsanet": "salvarsan",
    "salvarsanets": "salvarsan",
    "salvarsans": "salvarsan",
    "salvas": "salva",
    "salvationisten": "salvationist",
    "salvationistens": "salvationist",
    "salvationister": "salvationist",
    "salvationisterna": "salvationist",
    "salvationisternas": "salvationist",
    "salvationisters": "salvationist",
    "salvationists": "salvationist",
    "salve": "salva",
    "salvelden": "salveld",
    "salveldens": "salveld",
    "salvelds": "salveld",
    "salvelsefulla": "salvelsefull",
    "salvelsefullare": "salvelsefull",
    "salvelsefullares": "salvelsefull",
    "salvelsefullas": "salvelsefull",
    "salvelsefullast": "salvelsefull",
    "salvelsefullaste": "salvelsefull",
    "salvelsefullastes": "salvelsefull",
    "salvelsefullasts": "salvelsefull",
    "salvelsefulle": "salvelsefull",
    "salvelsefulles": "salvelsefull",
    "salvelsefullheten": "salvelsefullhet",
    "salvelsefullhetens": "salvelsefullhet",
    "salvelsefullheter": "salvelsefullhet",
    "salvelsefullheterna": "salvelsefullhet",
    "salvelsefullheternas": "salvelsefullhet",
    "salvelsefullheters": "salvelsefullhet",
    "salvelsefullhets": "salvelsefullhet",
    "salvelsefulls": "salvelsefull",
    "salvelsefullt": "salvelsefull",
    "salvelsefullts": "salvelsefull",
    "salvelsen": "salvelse",
    "salvelsens": "salvelse",
    "salvelses": "salvelse",
    "salvi": "salvia",
    "salvian": "salvia",
    "salvians": "salvia",
    "salvias": "salvia",
    "salvie": "salvia",
    "salvior": "salvia",
    "salviorna": "salvia",
    "salviornas": "salvia",
    "salviors": "salvia",
    "salvis": "salvia",
    "salvkanonen": "salvkanon",
    "salvkanonens": "salvkanon",
    "salvkanoner": "salvkanon",
    "salvkanonerna": "salvkanon",
    "salvkanonernas": "salvkanon",
    "salvkanoners": "salvkanon",
    "salvkanons": "salvkanon",
    "salvor": "salva",
    "salvorna": "salva",
    "salvornas": "salva",
    "salvors": "salva",
    "salvs": "salva",
    "sam": "simma",
    "samarbetade": "samarbeta",
    "samarbetades": "samarbeta",
    "samarbetande": "samarbeta",
    "samarbetanden": "samarbetande",
    "samarbetandena": "samarbetande",
    "samarbetandenas": "samarbetande",
    "samarbetandens": "samarbetande",
    "samarbetandes": "samarbetande",
    "samarbetandet": "samarbetande",
    "samarbetandets": "samarbetande",
    "samarbetar": "samarbeta",
    "samarbetas": "samarbeta",
    "samarbetat": "samarbeta",
    "samarbetats": "samarbeta",
    "samarbeten": "samarbete",
    "samarbetena": "samarbete",
    "samarbetenas": "samarbete",
    "samarbetens": "samarbete",
    "samarbetes": "samarbete",
    "samarbetet": "samarbete",
    "samarbetets": "samarbete",
    "samarbets": "samarbete",
    "samarbetsmannen": "samarbetsman",
    "samarbetsmannens": "samarbetsman",
    "samarbetsmans": "samarbetsman",
    "samarbetsmän": "samarbetsman",
    "samarbetsmännen": "samarbetsman",
    "samarbetsmännens": "samarbetsman",
    "samarbetsmäns": "samarbetsman",
    "samarbetsorganen": "samarbetsorgan",
    "samarbetsorganens": "samarbetsorgan",
    "samarbetsorganet": "samarbetsorgan",
    "samarbetsorganets": "samarbetsorgan",
    "samarbetsorganisationen": "samarbetsorganisation",
    "samarbetsorganisationens": "samarbetsorganisation",
    "samarbetsorganisationer": "samarbetsorganisation",
    "samarbetsorganisationerna": "samarbetsorganisation",
    "samarbetsorganisationernas": "samarbetsorganisation",
    "samarbetsorganisationers": "samarbetsorganisation",
    "samarbetsorganisations": "samarbetsorganisation",
    "samarbetsorgans": "samarbetsorgan",
    "samarbetspartnern": "samarbetspartner",
    "samarbetspartnerna": "samarbetspartner",
    "samarbetspartnernas": "samarbetspartner",
    "samarbetspartnerns": "samarbetspartner",
    "samarbetspartners": "samarbetspartner",
    "samarbetspartnersarna": "samarbetspartner",
    "samarbetspartnersarnas": "samarbetspartner",
    "samarbetspartnersen": "samarbetspartner",
    "samarbetspartnersens": "samarbetspartner",
    "samarbetsvilliga": "samarbetsvillig",
    "samarbetsvilligare": "samarbetsvillig",
    "samarbetsvilligares": "samarbetsvillig",
    "samarbetsvilligas": "samarbetsvillig",
    "samarbetsvilligast": "samarbetsvillig",
    "samarbetsvilligaste": "samarbetsvillig",
    "samarbetsvilligastes": "samarbetsvillig",
    "samarbetsvilligasts": "samarbetsvillig",
    "samarbetsvillige": "samarbetsvillig",
    "samarbetsvilliges": "samarbetsvillig",
    "samarbetsvilligheten": "samarbetsvillighet",
    "samarbetsvillighetens": "samarbetsvillighet",
    "samarbetsvillighets": "samarbetsvillighet",
    "samarbetsvilligs": "samarbetsvillig",
    "samarbetsvilligt": "samarbetsvillig",
    "samarbetsvilligts": "samarbetsvillig",
    "samariet": "samarium",
    "samariets": "samarium",
    "samariten": "samarit",
    "samaritens": "samarit",
    "samariter": "samarit",
    "samariterna": "samarit",
    "samariternas": "samarit",
    "samariters": "samarit",
    "samaritlåd": "samaritlåda",
    "samaritlådan": "samaritlåda",
    "samaritlådans": "samaritlåda",
    "samaritlådas": "samaritlåda",
    "samaritlåde": "samaritlåda",
    "samaritlådor": "samaritlåda",
    "samaritlådorna": "samaritlåda",
    "samaritlådornas": "samaritlåda",
    "samaritlådors": "samaritlåda",
    "samaritlåds": "samaritlåda",
    "samarits": "samarit",
    "samariumet": "samarium",
    "samariumets": "samarium",
    "samariums": "samarium",
    "samarven": "samarv",
    "samarvens": "samarv",
    "samarvet": "samarv",
    "samarvets": "samarv",
    "samarvs": "samarv",
    "samb": "samba",
    "sambadansar": "sambadansare",
    "sambadansaren": "sambadansare",
    "sambadansarens": "sambadansare",
    "sambadansares": "sambadansare",
    "sambadansarna": "sambadansare",
    "sambadansarnas": "sambadansare",
    "samban": "samba",
    "sambanden": "samband",
    "sambandens": "samband",
    "sambandet": "samband",
    "sambandets": "samband",
    "sambands": "samband",
    "sambandsofficerare": "sambandsofficer",
    "sambandsofficerares": "sambandsofficer",
    "sambandsofficerarna": "sambandsofficer",
    "sambandsofficerarnas": "sambandsofficer",
    "sambandsofficeren": "sambandsofficer",
    "sambandsofficerens": "sambandsofficer",
    "sambandsofficern": "sambandsofficer",
    "sambandsofficerns": "sambandsofficer",
    "sambandsofficers": "sambandsofficer",
    "sambans": "samba",
    "sambas": "samba",
    "sambe": "samba",
    "sambeskatt": "sambeskatta",
    "sambeskattad": "sambeskatta",
    "sambeskattade": "sambeskatta",
    "sambeskattades": "sambeskatta",
    "sambeskattads": "sambeskatta",
    "sambeskattande": "sambeskatta",
    "sambeskattanden": "sambeskattande",
    "sambeskattandena": "sambeskattande",
    "sambeskattandenas": "sambeskattande",
    "sambeskattandens": "sambeskattande",
    "sambeskattandes": "sambeskattande",
    "sambeskattandet": "sambeskattande",
    "sambeskattandets": "sambeskattande",
    "sambeskattar": "sambeskatta",
    "sambeskattas": "sambeskatta",
    "sambeskattat": "sambeskatta",
    "sambeskattats": "sambeskatta",
    "sambeskattningar": "sambeskattning",
    "sambeskattningarna": "sambeskattning",
    "sambeskattningarnas": "sambeskattning",
    "sambeskattningars": "sambeskattning",
    "sambeskattningen": "sambeskattning",
    "sambeskattningens": "sambeskattning",
    "sambeskattnings": "sambeskattning",
    "sambladiga": "sambladig",
    "sambladigare": "sambladig",
    "sambladigares": "sambladig",
    "sambladigas": "sambladig",
    "sambladigast": "sambladig",
    "sambladigaste": "sambladig",
    "sambladigastes": "sambladig",
    "sambladigasts": "sambladig",
    "sambladige": "sambladig",
    "sambladiges": "sambladig",
    "sambladigs": "sambladig",
    "sambladigt": "sambladig",
    "sambladigts": "sambladig",
    "samboavtalen": "samboavtal",
    "samboavtalens": "samboavtal",
    "samboavtalet": "samboavtal",
    "samboavtalets": "samboavtal",
    "samboavtals": "samboavtal",
    "sambodd": "sambo",
    "sambodda": "sambo",
    "samboddas": "sambo",
    "sambodde": "sambo",
    "samboddes": "sambo",
    "sambodds": "sambo",
    "samboende": "sambo",
    "samboenden": "samboende",
    "samboendena": "samboende",
    "samboendenas": "samboende",
    "samboendens": "samboende",
    "samboendes": "samboende",
    "samboendet": "samboende",
    "samboendets": "samboende",
    "sambon": "sambo",
    "sambons": "sambo",
    "sambor": "sambo",
    "samborden": "sambord",
    "sambordens": "sambord",
    "sambordet": "sambord",
    "sambordets": "sambord",
    "sambords": "sambord",
    "samborna": "sambo",
    "sambornas": "sambo",
    "sambors": "sambo",
    "sambos": "sambo",
    "sambosen": "sambo",
    "sambosens": "sambo",
    "sambott": "sambo",
    "sambotts": "sambo",
    "sambovåldet": "sambovåld",
    "sambovåldets": "sambovåld",
    "sambovålds": "sambovåld",
    "sambruket": "sambruk",
    "sambrukets": "sambruk",
    "sambruks": "sambruk",
    "sambs": "samba",
    "sambuc": "sambuca",
    "sambucan": "sambuca",
    "sambucans": "sambuca",
    "sambucas": "sambuca",
    "sambuce": "sambuca",
    "sambucor": "sambuca",
    "sambucorna": "sambuca",
    "sambucornas": "sambuca",
    "sambucors": "sambuca",
    "sambucs": "sambuca",
    "sambyggar": "sambyggare",
    "sambyggaren": "sambyggare",
    "sambyggarens": "sambyggare",
    "sambyggares": "sambyggare",
    "sambyggarna": "sambyggare",
    "sambyggarnas": "sambyggare",
    "samdräkten": "samdräkt",
    "samdräktens": "samdräkt",
    "samdräkts": "samdräkt",
    "samebyar": "sameby",
    "samebyarna": "sameby",
    "samebyarnas": "sameby",
    "samebyars": "sameby",
    "samebyn": "sameby",
    "samebyns": "sameby",
    "samebys": "sameby",
    "samekulturen": "samekultur",
    "samekulturens": "samekultur",
    "samekulturer": "samekultur",
    "samekulturerna": "samekultur",
    "samekulturernas": "samekultur",
    "samekulturers": "samekultur",
    "samekulturs": "samekultur",
    "samelandet": "sameland",
    "samelandets": "sameland",
    "samelands": "sameland",
    "sameländer": "sameland",
    "sameländerna": "sameland",
    "sameländernas": "sameland",
    "sameländers": "sameland",
    "samen": "same",
    "samens": "same",
    "samer": "same",
    "samerna": "same",
    "samernas": "same",
    "samers": "same",
    "sames": "same",
    "samexistensen": "samexistens",
    "samexistensens": "samexistens",
    "samfunden": "samfund",
    "samfundens": "samfund",
    "samfundet": "samfund",
    "samfundets": "samfund",
    "samfunds": "samfund",
    "samfundsmässiga": "samfundsmässig",
    "samfundsmässigare": "samfundsmässig",
    "samfundsmässigares": "samfundsmässig",
    "samfundsmässigas": "samfundsmässig",
    "samfundsmässigast": "samfundsmässig",
    "samfundsmässigaste": "samfundsmässig",
    "samfundsmässigastes": "samfundsmässig",
    "samfundsmässigasts": "samfundsmässig",
    "samfundsmässige": "samfundsmässig",
    "samfundsmässiges": "samfundsmässig",
    "samfundsmässigs": "samfundsmässig",
    "samfundsmässigt": "samfundsmässig",
    "samfundsmässigts": "samfundsmässig",
    "samfällda": "samfälld",
    "samfälldare": "samfälld",
    "samfälldares": "samfälld",
    "samfälldas": "samfälld",
    "samfälldast": "samfälld",
    "samfälldaste": "samfälld",
    "samfälldastes": "samfälld",
    "samfälldasts": "samfälld",
    "samfällde": "samfälld",
    "samfälldes": "samfälld",
    "samfällds": "samfälld",
    "samfälliga": "samfällig",
    "samfälligare": "samfällig",
    "samfälligares": "samfällig",
    "samfälligas": "samfällig",
    "samfälligast": "samfällig",
    "samfälligaste": "samfällig",
    "samfälligastes": "samfällig",
    "samfälligasts": "samfällig",
    "samfällige": "samfällig",
    "samfälliges": "samfällig",
    "samfälligheten": "samfällighet",
    "samfällighetens": "samfällighet",
    "samfälligheter": "samfällighet",
    "samfälligheterna": "samfällighet",
    "samfälligheternas": "samfällighet",
    "samfälligheters": "samfällighet",
    "samfällighets": "samfällighet",
    "samfälligs": "samfällig",
    "samfälligt": "samfällig",
    "samfälligts": "samfällig",
    "samfällt": "samfälld",
    "samfällts": "samfälld",
    "samfärden": "samfärd",
    "samfärdens": "samfärd",
    "samfärds": "samfärd",
    "samfärdseln": "samfärdsel",
    "samfärdselns": "samfärdsel",
    "samfärdsels": "samfärdsel",
    "samfärdsleden": "samfärdsled",
    "samfärdsledens": "samfärdsled",
    "samfärdsleder": "samfärdsled",
    "samfärdslederna": "samfärdsled",
    "samfärdsledernas": "samfärdsled",
    "samfärdsleders": "samfärdsled",
    "samfärdsleds": "samfärdsled",
    "samfärdsmedels": "samfärdsmedel",
    "samfärdsmedlen": "samfärdsmedel",
    "samfärdsmedlens": "samfärdsmedel",
    "samfärdsmedlet": "samfärdsmedel",
    "samfärdsmedlets": "samfärdsmedel",
    "samförståndet": "samförstånd",
    "samförståndets": "samförstånd",
    "samförstånds": "samförstånd",
    "samgick": "samgå",
    "samgicks": "samgå",
    "samginge": "samgå",
    "samginges": "samgå",
    "samgående": "samgå",
    "samgåendes": "samgående",
    "samgåendet": "samgående",
    "samgåendets": "samgående",
    "samgånge": "samgå",
    "samgången": "samgå",
    "samgångens": "samgå",
    "samgånges": "samgå",
    "samgånget": "samgå",
    "samgångets": "samgå",
    "samgångna": "samgå",
    "samgångnas": "samgå",
    "samgångne": "samgå",
    "samgångnes": "samgå",
    "samgår": "samgå",
    "samgås": "samgå",
    "samgått": "samgå",
    "samgåtts": "samgå",
    "samhälleliga": "samhällelig",
    "samhälleligare": "samhällelig",
    "samhälleligares": "samhällelig",
    "samhälleligas": "samhällelig",
    "samhälleligast": "samhällelig",
    "samhälleligaste": "samhällelig",
    "samhälleligastes": "samhällelig",
    "samhälleligasts": "samhällelig",
    "samhällelige": "samhällelig",
    "samhälleliges": "samhällelig",
    "samhälleligheten": "samhällelighet",
    "samhällelighetens": "samhällelighet",
    "samhällelighets": "samhällelighet",
    "samhälleligs": "samhällelig",
    "samhälleligt": "samhällelig",
    "samhälleligts": "samhällelig",
    "samhällen": "samhälle",
    "samhällena": "samhälle",
    "samhällenas": "samhälle",
    "samhällens": "samhälle",
    "samhälles": "samhälle",
    "samhället": "samhälle",
    "samhällets": "samhälle",
    "samhälls": "samhälle",
    "samhällsarbeten": "samhällsarbete",
    "samhällsarbetena": "samhällsarbete",
    "samhällsarbetenas": "samhällsarbete",
    "samhällsarbetens": "samhällsarbete",
    "samhällsarbetes": "samhällsarbete",
    "samhällsarbetet": "samhällsarbete",
    "samhällsarbetets": "samhällsarbete",
    "samhällsarbets": "samhällsarbete",
    "samhällsbevakningar": "samhällsbevakning",
    "samhällsbevakningarna": "samhällsbevakning",
    "samhällsbevakningarnas": "samhällsbevakning",
    "samhällsbevakningars": "samhällsbevakning",
    "samhällsbevakningen": "samhällsbevakning",
    "samhällsbevakningens": "samhällsbevakning",
    "samhällsbevaknings": "samhällsbevakning",
    "samhällsbevarar": "samhällsbevarare",
    "samhällsbevararen": "samhällsbevarare",
    "samhällsbevararens": "samhällsbevarare",
    "samhällsbevarares": "samhällsbevarare",
    "samhällsbevararna": "samhällsbevarare",
    "samhällsbevararnas": "samhällsbevarare",
    "samhällsdebatten": "samhällsdebatt",
    "samhällsdebattens": "samhällsdebatt",
    "samhällsdebatter": "samhällsdebatt",
    "samhällsdebatterna": "samhällsdebatt",
    "samhällsdebatternas": "samhällsdebatt",
    "samhällsdebatters": "samhällsdebatt",
    "samhällsdebatts": "samhällsdebatt",
    "samhällsekonomien": "samhällsekonomi",
    "samhällsekonomiens": "samhällsekonomi",
    "samhällsekonomin": "samhällsekonomi",
    "samhällsekonomins": "samhällsekonomi",
    "samhällsekonomis": "samhällsekonomi",
    "samhällsekonomiska": "samhällsekonomisk",
    "samhällsekonomiskare": "samhällsekonomisk",
    "samhällsekonomiskares": "samhällsekonomisk",
    "samhällsekonomiskas": "samhällsekonomisk",
    "samhällsekonomiskast": "samhällsekonomisk",
    "samhällsekonomiskaste": "samhällsekonomisk",
    "samhällsekonomiskastes": "samhällsekonomisk",
    "samhällsekonomiskasts": "samhällsekonomisk",
    "samhällsekonomiske": "samhällsekonomisk",
    "samhällsekonomiskes": "samhällsekonomisk",
    "samhällsekonomisks": "samhällsekonomisk",
    "samhällsekonomiskt": "samhällsekonomisk",
    "samhällsekonomiskts": "samhällsekonomisk",
    "samhällsfar": "samhällsfara",
    "samhällsfaran": "samhällsfara",
    "samhällsfarans": "samhällsfara",
    "samhällsfaras": "samhällsfara",
    "samhällsfare": "samhällsfara",
    "samhällsfarliga": "samhällsfarlig",
    "samhällsfarligare": "samhällsfarlig",
    "samhällsfarligares": "samhällsfarlig",
    "samhällsfarligas": "samhällsfarlig",
    "samhällsfarligast": "samhällsfarlig",
    "samhällsfarligaste": "samhällsfarlig",
    "samhällsfarligastes": "samhällsfarlig",
    "samhällsfarligasts": "samhällsfarlig",
    "samhällsfarlige": "samhällsfarlig",
    "samhällsfarliges": "samhällsfarlig",
    "samhällsfarligheten": "samhällsfarlighet",
    "samhällsfarlighetens": "samhällsfarlighet",
    "samhällsfarlighets": "samhällsfarlighet",
    "samhällsfarligs": "samhällsfarlig",
    "samhällsfarligt": "samhällsfarlig",
    "samhällsfarligts": "samhällsfarlig",
    "samhällsfaro": "samhällsfara",
    "samhällsfaror": "samhällsfara",
    "samhällsfarorna": "samhällsfara",
    "samhällsfarornas": "samhällsfara",
    "samhällsfarors": "samhällsfara",
    "samhällsfars": "samhällsfara",
    "samhällsfasaden": "samhällsfasad",
    "samhällsfasadens": "samhällsfasad",
    "samhällsfasader": "samhällsfasad",
    "samhällsfasaderna": "samhällsfasad",
    "samhällsfasadernas": "samhällsfasad",
    "samhällsfasaders": "samhällsfasad",
    "samhällsfasads": "samhällsfasad",
    "samhällsfientliga": "samhällsfientlig",
    "samhällsfientligare": "samhällsfientlig",
    "samhällsfientligares": "samhällsfientlig",
    "samhällsfientligas": "samhällsfientlig",
    "samhällsfientligast": "samhällsfientlig",
    "samhällsfientligaste": "samhällsfientlig",
    "samhällsfientligastes": "samhällsfientlig",
    "samhällsfientligasts": "samhällsfientlig",
    "samhällsfientlige": "samhällsfientlig",
    "samhällsfientliges": "samhällsfientlig",
    "samhällsfientligheten": "samhällsfientlighet",
    "samhällsfientlighetens": "samhällsfientlighet",
    "samhällsfientlighets": "samhällsfientlighet",
    "samhällsfientligs": "samhällsfientlig",
    "samhällsfientligt": "samhällsfientlig",
    "samhällsfientligts": "samhällsfientlig",
    "samhällsformen": "samhällsform",
    "samhällsformens": "samhällsform",
    "samhällsformer": "samhällsform",
    "samhällsformerna": "samhällsform",
    "samhällsformernas": "samhällsform",
    "samhällsformers": "samhällsform",
    "samhällsforms": "samhällsform",
    "samhällsforskar": "samhällsforskare",
    "samhällsforskaren": "samhällsforskare",
    "samhällsforskarens": "samhällsforskare",
    "samhällsforskares": "samhällsforskare",
    "samhällsforskarna": "samhällsforskare",
    "samhällsforskarnas": "samhällsforskare",
    "samhällsfrånvända": "samhällsfrånvänd",
    "samhällsfrånvändare": "samhällsfrånvänd",
    "samhällsfrånvändares": "samhällsfrånvänd",
    "samhällsfrånvändas": "samhällsfrånvänd",
    "samhällsfrånvändast": "samhällsfrånvänd",
    "samhällsfrånvändaste": "samhällsfrånvänd",
    "samhällsfrånvändastes": "samhällsfrånvänd",
    "samhällsfrånvändasts": "samhällsfrånvänd",
    "samhällsfrånvände": "samhällsfrånvänd",
    "samhällsfrånvändes": "samhällsfrånvänd",
    "samhällsfrånvändheten": "samhällsfrånvändhet",
    "samhällsfrånvändhetens": "samhällsfrånvändhet",
    "samhällsfrånvändhets": "samhällsfrånvändhet",
    "samhällsfrånvänds": "samhällsfrånvänd",
    "samhällsfrånvänt": "samhällsfrånvänd",
    "samhällsfrånvänts": "samhällsfrånvänd",
    "samhällsfunktionen": "samhällsfunktion",
    "samhällsfunktionens": "samhällsfunktion",
    "samhällsfunktioner": "samhällsfunktion",
    "samhällsfunktionerna": "samhällsfunktion",
    "samhällsfunktionernas": "samhällsfunktion",
    "samhällsfunktioners": "samhällsfunktion",
    "samhällsfunktions": "samhällsfunktion",
    "samhällsförbättrar": "samhällsförbättrare",
    "samhällsförbättraren": "samhällsförbättrare",
    "samhällsförbättrarens": "samhällsförbättrare",
    "samhällsförbättrares": "samhällsförbättrare",
    "samhällsförbättrarna": "samhällsförbättrare",
    "samhällsförbättrarnas": "samhällsförbättrare",
    "samhällsfördragen": "samhällsfördrag",
    "samhällsfördragens": "samhällsfördrag",
    "samhällsfördraget": "samhällsfördrag",
    "samhällsfördragets": "samhällsfördrag",
    "samhällsfördrags": "samhällsfördrag",
    "samhällsgruppen": "samhällsgrupp",
    "samhällsgruppens": "samhällsgrupp",
    "samhällsgrupper": "samhällsgrupp",
    "samhällsgrupperna": "samhällsgrupp",
    "samhällsgruppernas": "samhällsgrupp",
    "samhällsgruppers": "samhällsgrupp",
    "samhällsgrupps": "samhällsgrupp",
    "samhällshjälpen": "samhällshjälp",
    "samhällshjälpens": "samhällshjälp",
    "samhällshjälps": "samhällshjälp",
    "samhällsinflytandes": "samhällsinflytande",
    "samhällsinflytandet": "samhällsinflytande",
    "samhällsinflytandets": "samhällsinflytande",
    "samhällsinformationen": "samhällsinformation",
    "samhällsinformationens": "samhällsinformation",
    "samhällsinformationer": "samhällsinformation",
    "samhällsinformationerna": "samhällsinformation",
    "samhällsinformationernas": "samhällsinformation",
    "samhällsinformationers": "samhällsinformation",
    "samhällsinformations": "samhällsinformation",
    "samhällsingripanden": "samhällsingripande",
    "samhällsingripandena": "samhällsingripande",
    "samhällsingripandenas": "samhällsingripande",
    "samhällsingripandens": "samhällsingripande",
    "samhällsingripandes": "samhällsingripande",
    "samhällsingripandet": "samhällsingripande",
    "samhällsingripandets": "samhällsingripande",
    "samhällsinsatsen": "samhällsinsats",
    "samhällsinsatsens": "samhällsinsats",
    "samhällsinsatser": "samhällsinsats",
    "samhällsinsatserna": "samhällsinsats",
    "samhällsinsatsernas": "samhällsinsats",
    "samhällsinsatsers": "samhällsinsats",
    "samhällsintresserade": "samhällsintresserad",
    "samhällsintresserades": "samhällsintresserad",
    "samhällsintresserads": "samhällsintresserad",
    "samhällsintresserat": "samhällsintresserad",
    "samhällsintresserats": "samhällsintresserad",
    "samhällsjournalistiken": "samhällsjournalistik",
    "samhällsjournalistikens": "samhällsjournalistik",
    "samhällsjournalistiks": "samhällsjournalistik",
    "samhällsklassen": "samhällsklass",
    "samhällsklassens": "samhällsklass",
    "samhällsklasser": "samhällsklass",
    "samhällsklasserna": "samhällsklass",
    "samhällsklassernas": "samhällsklass",
    "samhällsklassers": "samhällsklass",
    "samhällskontrakten": "samhällskontrakt",
    "samhällskontraktens": "samhällskontrakt",
    "samhällskontraktet": "samhällskontrakt",
    "samhällskontraktets": "samhällskontrakt",
    "samhällskontrakts": "samhällskontrakt",
    "samhällskostnaden": "samhällskostnad",
    "samhällskostnadens": "samhällskostnad",
    "samhällskostnader": "samhällskostnad",
    "samhällskostnaderna": "samhällskostnad",
    "samhällskostnadernas": "samhällskostnad",
    "samhällskostnaders": "samhällskostnad",
    "samhällskostnads": "samhällskostnad",
    "samhällskritiken": "samhällskritik",
    "samhällskritikens": "samhällskritik",
    "samhällskritikern": "samhällskritiker",
    "samhällskritikerna": "samhällskritiker",
    "samhällskritikernas": "samhällskritiker",
    "samhällskritikerns": "samhällskritiker",
    "samhällskritikers": "samhällskritiker",
    "samhällskritiks": "samhällskritik",
    "samhällskritiska": "samhällskritisk",
    "samhällskritiskare": "samhällskritisk",
    "samhällskritiskares": "samhällskritisk",
    "samhällskritiskas": "samhällskritisk",
    "samhällskritiskast": "samhällskritisk",
    "samhällskritiskaste": "samhällskritisk",
    "samhällskritiskastes": "samhällskritisk",
    "samhällskritiskasts": "samhällskritisk",
    "samhällskritiske": "samhällskritisk",
    "samhällskritiskes": "samhällskritisk",
    "samhällskritisks": "samhällskritisk",
    "samhällskritiskt": "samhällskritisk",
    "samhällskritiskts": "samhällskritisk",
    "samhällskroppar": "samhällskropp",
    "samhällskropparna": "samhällskropp",
    "samhällskropparnas": "samhällskropp",
    "samhällskroppars": "samhällskropp",
    "samhällskroppen": "samhällskropp",
    "samhällskroppens": "samhällskropp",
    "samhällskropps": "samhällskropp",
    "samhällskunskapen": "samhällskunskap",
    "samhällskunskapens": "samhällskunskap",
    "samhällskunskaps": "samhällskunskap",
    "samhällskunskapslärar": "samhällskunskapslärare",
    "samhällskunskapsläraren": "samhällskunskapslärare",
    "samhällskunskapslärarens": "samhällskunskapslärare",
    "samhällskunskapslärares": "samhällskunskapslärare",
    "samhällskunskapslärarna": "samhällskunskapslärare",
    "samhällskunskapslärarnas": "samhällskunskapslärare",
    "samhällslivet": "samhällsliv",
    "samhällslivets": "samhällsliv",
    "samhällslivs": "samhällsliv",
    "samhällsläran": "samhällslära",
    "samhällslärans": "samhällslära",
    "samhällsläras": "samhällslära",
    "samhällsmaskineriet": "samhällsmaskineri",
    "samhällsmaskineriets": "samhällsmaskineri",
    "samhällsmaskineris": "samhällsmaskineri",
    "samhällsmaskinerit": "samhällsmaskineri",
    "samhällsmaskinerits": "samhällsmaskineri",
    "samhällsmässiga": "samhällsmässig",
    "samhällsmässigare": "samhällsmässig",
    "samhällsmässigares": "samhällsmässig",
    "samhällsmässigas": "samhällsmässig",
    "samhällsmässigast": "samhällsmässig",
    "samhällsmässigaste": "samhällsmässig",
    "samhällsmässigastes": "samhällsmässig",
    "samhällsmässigasts": "samhällsmässig",
    "samhällsmässige": "samhällsmässig",
    "samhällsmässiges": "samhällsmässig",
    "samhällsmässigs": "samhällsmässig",
    "samhällsmässigt": "samhällsmässig",
    "samhällsmässigts": "samhällsmässig",
    "samhällsnormen": "samhällsnorm",
    "samhällsnormens": "samhällsnorm",
    "samhällsnormer": "samhällsnorm",
    "samhällsnormerna": "samhällsnorm",
    "samhällsnormernas": "samhällsnorm",
    "samhällsnormers": "samhällsnorm",
    "samhällsnorms": "samhällsnorm",
    "samhällsnyttan": "samhällsnytta",
    "samhällsnyttans": "samhällsnytta",
    "samhällsnyttas": "samhällsnytta",
    "samhällsnytte": "samhällsnytta",
    "samhällsnyttiga": "samhällsnyttig",
    "samhällsnyttigare": "samhällsnyttig",
    "samhällsnyttigares": "samhällsnyttig",
    "samhällsnyttigas": "samhällsnyttig",
    "samhällsnyttigast": "samhällsnyttig",
    "samhällsnyttigaste": "samhällsnyttig",
    "samhällsnyttigastes": "samhällsnyttig",
    "samhällsnyttigasts": "samhällsnyttig",
    "samhällsnyttige": "samhällsnyttig",
    "samhällsnyttiges": "samhällsnyttig",
    "samhällsnyttigheten": "samhällsnyttighet",
    "samhällsnyttighetens": "samhällsnyttighet",
    "samhällsnyttighets": "samhällsnyttighet",
    "samhällsnyttigs": "samhällsnyttig",
    "samhällsnyttigt": "samhällsnyttig",
    "samhällsnyttigts": "samhällsnyttig",
    "samhällsnytto": "samhällsnytta",
    "samhällsnyttor": "samhällsnytta",
    "samhällsnyttorna": "samhällsnytta",
    "samhällsnyttornas": "samhällsnytta",
    "samhällsnyttors": "samhällsnytta",
    "samhällsområden": "samhällsområde",
    "samhällsområdena": "samhällsområde",
    "samhällsområdenas": "samhällsområde",
    "samhällsområdens": "samhällsområde",
    "samhällsområdes": "samhällsområde",
    "samhällsområdet": "samhällsområde",
    "samhällsområdets": "samhällsområde",
    "samhällsomstörtar": "samhällsomstörtare",
    "samhällsomstörtaren": "samhällsomstörtare",
    "samhällsomstörtarens": "samhällsomstörtare",
    "samhällsomstörtares": "samhällsomstörtare",
    "samhällsomstörtarna": "samhällsomstörtare",
    "samhällsomstörtarnas": "samhällsomstörtare",
    "samhällsordningar": "samhällsordning",
    "samhällsordningarna": "samhällsordning",
    "samhällsordningarnas": "samhällsordning",
    "samhällsordningars": "samhällsordning",
    "samhällsordningen": "samhällsordning",
    "samhällsordningens": "samhällsordning",
    "samhällsordnings": "samhällsordning",
    "samhällsorganen": "samhällsorgan",
    "samhällsorganens": "samhällsorgan",
    "samhällsorganet": "samhällsorgan",
    "samhällsorganets": "samhällsorgan",
    "samhällsorgans": "samhällsorgan",
    "samhällsplanerade": "samhällsplanera",
    "samhällsplanerades": "samhällsplanera",
    "samhällsplanerande": "samhällsplanera",
    "samhällsplaneranden": "samhällsplanerande",
    "samhällsplanerandena": "samhällsplanerande",
    "samhällsplanerandenas": "samhällsplanerande",
    "samhällsplanerandens": "samhällsplanerande",
    "samhällsplanerandes": "samhällsplanerande",
    "samhällsplanerandet": "samhällsplanerande",
    "samhällsplanerandets": "samhällsplanerande",
    "samhällsplanerar": "samhällsplanerare",
    "samhällsplaneraren": "samhällsplanerare",
    "samhällsplanerarens": "samhällsplanerare",
    "samhällsplanerares": "samhällsplanerare",
    "samhällsplanerarna": "samhällsplanerare",
    "samhällsplanerarnas": "samhällsplanerare",
    "samhällsplaneras": "samhällsplanera",
    "samhällsplanerat": "samhällsplanera",
    "samhällsplanerats": "samhällsplanera",
    "samhällsplaneringar": "samhällsplanering",
    "samhällsplaneringarna": "samhällsplanering",
    "samhällsplaneringarnas": "samhällsplanering",
    "samhällsplaneringars": "samhällsplanering",
    "samhällsplaneringen": "samhällsplanering",
    "samhällsplaneringens": "samhällsplanering",
    "samhällsplanerings": "samhällsplanering",
    "samhällspolitiken": "samhällspolitik",
    "samhällspolitikens": "samhällspolitik",
    "samhällspolitiks": "samhällspolitik",
    "samhällspolitiska": "samhällspolitisk",
    "samhällspolitiskas": "samhällspolitisk",
    "samhällspolitiske": "samhällspolitisk",
    "samhällspolitiskes": "samhällspolitisk",
    "samhällspolitisks": "samhällspolitisk",
    "samhällspolitiskt": "samhällspolitisk",
    "samhällspolitiskts": "samhällspolitisk",
    "samhällsproblemen": "samhällsproblem",
    "samhällsproblemens": "samhällsproblem",
    "samhällsproblemet": "samhällsproblem",
    "samhällsproblemets": "samhällsproblem",
    "samhällsproblems": "samhällsproblem",
    "samhällspyramiden": "samhällspyramid",
    "samhällspyramidens": "samhällspyramid",
    "samhällspyramider": "samhällspyramid",
    "samhällspyramiderna": "samhällspyramid",
    "samhällspyramidernas": "samhällspyramid",
    "samhällspyramiders": "samhällspyramid",
    "samhällspyramids": "samhällspyramid",
    "samhällsrepresentanten": "samhällsrepresentant",
    "samhällsrepresentantens": "samhällsrepresentant",
    "samhällsrepresentanter": "samhällsrepresentant",
    "samhällsrepresentanterna": "samhällsrepresentant",
    "samhällsrepresentanternas": "samhällsrepresentant",
    "samhällsrepresentanters": "samhällsrepresentant",
    "samhällsrepresentants": "samhällsrepresentant",
    "samhällsservicen": "samhällsservice",
    "samhällsservicens": "samhällsservice",
    "samhällsservices": "samhällsservice",
    "samhällssfären": "samhällssfär",
    "samhällssfärens": "samhällssfär",
    "samhällssfärer": "samhällssfär",
    "samhällssfärerna": "samhällssfär",
    "samhällssfärernas": "samhällssfär",
    "samhällssfärers": "samhällssfär",
    "samhällssfärs": "samhällssfär",
    "samhällsskicken": "samhällsskick",
    "samhällsskickens": "samhällsskick",
    "samhällsskicket": "samhällsskick",
    "samhällsskickets": "samhällsskick",
    "samhällsskicks": "samhällsskick",
    "samhällsskikten": "samhällsskikt",
    "samhällsskiktens": "samhällsskikt",
    "samhällsskiktet": "samhällsskikt",
    "samhällsskiktets": "samhällsskikt",
    "samhällsskikts": "samhällsskikt",
    "samhällsskildringar": "samhällsskildring",
    "samhällsskildringarna": "samhällsskildring",
    "samhällsskildringarnas": "samhällsskildring",
    "samhällsskildringars": "samhällsskildring",
    "samhällsskildringen": "samhällsskildring",
    "samhällsskildringens": "samhällsskildring",
    "samhällsskildrings": "samhällsskildring",
    "samhällssolidariska": "samhällssolidarisk",
    "samhällssolidariskare": "samhällssolidarisk",
    "samhällssolidariskares": "samhällssolidarisk",
    "samhällssolidariskas": "samhällssolidarisk",
    "samhällssolidariskast": "samhällssolidarisk",
    "samhällssolidariskaste": "samhällssolidarisk",
    "samhällssolidariskastes": "samhällssolidarisk",
    "samhällssolidariskasts": "samhällssolidarisk",
    "samhällssolidariske": "samhällssolidarisk",
    "samhällssolidariskes": "samhällssolidarisk",
    "samhällssolidarisks": "samhällssolidarisk",
    "samhällssolidariskt": "samhällssolidarisk",
    "samhällssolidariskts": "samhällssolidarisk",
    "samhällsstyrningar": "samhällsstyrning",
    "samhällsstyrningarna": "samhällsstyrning",
    "samhällsstyrningarnas": "samhällsstyrning",
    "samhällsstyrningars": "samhällsstyrning",
    "samhällsstyrningen": "samhällsstyrning",
    "samhällsstyrningens": "samhällsstyrning",
    "samhällsstyrnings": "samhällsstyrning",
    "samhällsställningar": "samhällsställning",
    "samhällsställningarna": "samhällsställning",
    "samhällsställningarnas": "samhällsställning",
    "samhällsställningars": "samhällsställning",
    "samhällsställningen": "samhällsställning",
    "samhällsställningens": "samhällsställning",
    "samhällsställnings": "samhällsställning",
    "samhällsstödet": "samhällsstöd",
    "samhällsstödets": "samhällsstöd",
    "samhällsstöds": "samhällsstöd",
    "samhällssymbolen": "samhällssymbol",
    "samhällssymbolens": "samhällssymbol",
    "samhällssymboler": "samhällssymbol",
    "samhällssymbolerna": "samhällssymbol",
    "samhällssymbolernas": "samhällssymbol",
    "samhällssymbolers": "samhällssymbol",
    "samhällssymbols": "samhällssymbol",
    "samhällssynen": "samhällssyn",
    "samhällssynens": "samhällssyn",
    "samhällssyner": "samhällssyn",
    "samhällssynerna": "samhällssyn",
    "samhällssynernas": "samhällssyn",
    "samhällssyners": "samhällssyn",
    "samhällssyns": "samhällssyn",
    "samhällssystemen": "samhällssystem",
    "samhällssystemens": "samhällssystem",
    "samhällssystemet": "samhällssystem",
    "samhällssystemets": "samhällssystem",
    "samhällssystems": "samhällssystem",
    "samhällstillvända": "samhällstillvänd",
    "samhällstillvändare": "samhällstillvänd",
    "samhällstillvändares": "samhällstillvänd",
    "samhällstillvändas": "samhällstillvänd",
    "samhällstillvändast": "samhällstillvänd",
    "samhällstillvändaste": "samhällstillvänd",
    "samhällstillvändastes": "samhällstillvänd",
    "samhällstillvändasts": "samhällstillvänd",
    "samhällstillvände": "samhällstillvänd",
    "samhällstillvändes": "samhällstillvänd",
    "samhällstillvändheten": "samhällstillvändhet",
    "samhällstillvändhetens": "samhällstillvändhet",
    "samhällstillvändhets": "samhällstillvändhet",
    "samhällstillvänds": "samhällstillvänd",
    "samhällstillvänt": "samhällstillvänd",
    "samhällstillvänts": "samhällstillvänd",
    "samhällsuppbyggnaden": "samhällsuppbyggnad",
    "samhällsuppbyggnadens": "samhällsuppbyggnad",
    "samhällsuppbyggnader": "samhällsuppbyggnad",
    "samhällsuppbyggnaderna": "samhällsuppbyggnad",
    "samhällsuppbyggnadernas": "samhällsuppbyggnad",
    "samhällsuppbyggnaders": "samhällsuppbyggnad",
    "samhällsuppbyggnads": "samhällsuppbyggnad",
    "samhällsutvecklingar": "samhällsutveckling",
    "samhällsutvecklingarna": "samhällsutveckling",
    "samhällsutvecklingarnas": "samhällsutveckling",
    "samhällsutvecklingars": "samhällsutveckling",
    "samhällsutvecklingen": "samhällsutveckling",
    "samhällsutvecklingens": "samhällsutveckling",
    "samhällsutvecklings": "samhällsutveckling",
    "samhällsvarelsen": "samhällsvarelse",
    "samhällsvarelsens": "samhällsvarelse",
    "samhällsvarelser": "samhällsvarelse",
    "samhällsvarelserna": "samhällsvarelse",
    "samhällsvarelsernas": "samhällsvarelse",
    "samhällsvarelsers": "samhällsvarelse",
    "samhällsvarelses": "samhällsvarelse",
    "samhällsvetar": "samhällsvetare",
    "samhällsvetaren": "samhällsvetare",
    "samhällsvetarens": "samhällsvetare",
    "samhällsvetares": "samhällsvetare",
    "samhällsvetarna": "samhällsvetare",
    "samhällsvetarnas": "samhällsvetare",
    "samhällsvetenskapen": "samhällsvetenskap",
    "samhällsvetenskapens": "samhällsvetenskap",
    "samhällsvetenskaper": "samhällsvetenskap",
    "samhällsvetenskaperna": "samhällsvetenskap",
    "samhällsvetenskapernas": "samhällsvetenskap",
    "samhällsvetenskapers": "samhällsvetenskap",
    "samhällsvetenskapliga": "samhällsvetenskaplig",
    "samhällsvetenskapligare": "samhällsvetenskaplig",
    "samhällsvetenskapligares": "samhällsvetenskaplig",
    "samhällsvetenskapligas": "samhällsvetenskaplig",
    "samhällsvetenskapligast": "samhällsvetenskaplig",
    "samhällsvetenskapligaste": "samhällsvetenskaplig",
    "samhällsvetenskapligastes": "samhällsvetenskaplig",
    "samhällsvetenskapligasts": "samhällsvetenskaplig",
    "samhällsvetenskaplige": "samhällsvetenskaplig",
    "samhällsvetenskapliges": "samhällsvetenskaplig",
    "samhällsvetenskapligheten": "samhällsvetenskaplighet",
    "samhällsvetenskaplighetens": "samhällsvetenskaplighet",
    "samhällsvetenskaplighets": "samhällsvetenskaplighet",
    "samhällsvetenskapligs": "samhällsvetenskaplig",
    "samhällsvetenskapligt": "samhällsvetenskaplig",
    "samhällsvetenskapligts": "samhällsvetenskaplig",
    "samhällsvetenskaps": "samhällsvetenskap",
    "samhällsvården": "samhällsvård",
    "samhällsvårdens": "samhällsvård",
    "samhällsvårds": "samhällsvård",
    "samhällsövervakningar": "samhällsövervakning",
    "samhällsövervakningarna": "samhällsövervakning",
    "samhällsövervakningarnas": "samhällsövervakning",
    "samhällsövervakningars": "samhällsövervakning",
    "samhällsövervakningen": "samhällsövervakning",
    "samhällsövervakningens": "samhällsövervakning",
    "samhällsövervaknings": "samhällsövervakning",
    "samhöriga": "samhörig",
    "samhörigare": "samhörig",
    "samhörigares": "samhörig",
    "samhörigas": "samhörig",
    "samhörigast": "samhörig",
    "samhörigaste": "samhörig",
    "samhörigastes": "samhörig",
    "samhörigasts": "samhörig",
    "samhörige": "samhörig",
    "samhöriges": "samhörig",
    "samhörigheten": "samhörighet",
    "samhörighetens": "samhörighet",
    "samhörigheter": "samhörighet",
    "samhörigheterna": "samhörighet",
    "samhörigheternas": "samhörighet",
    "samhörigheters": "samhörighet",
    "samhörighets": "samhörighet",
    "samhörighetskänsl": "samhörighetskänsla",
    "samhörighetskänslan": "samhörighetskänsla",
    "samhörighetskänslans": "samhörighetskänsla",
    "samhörighetskänslas": "samhörighetskänsla",
    "samhörighetskänsle": "samhörighetskänsla",
    "samhörighetskänslo": "samhörighetskänsla",
    "samhörighetskänslor": "samhörighetskänsla",
    "samhörighetskänslorna": "samhörighetskänsla",
    "samhörighetskänslornas": "samhörighetskänsla",
    "samhörighetskänslors": "samhörighetskänsla",
    "samhörigs": "samhörig",
    "samhörigt": "samhörig",
    "samhörigts": "samhörig",
    "samisk": "samiska",
    "samiska": "samisk",
    "samiskan": "samiska",
    "samiskans": "samiska",
    "samiskare": "samisk",
    "samiskares": "samisk",
    "samiskas": "samiska",
    "samiskast": "samisk",
    "samiskaste": "samisk",
    "samiskastes": "samisk",
    "samiskasts": "samisk",
    "samiske": "samisk",
    "samiskes": "samisk",
    "samisks": "samisk",
    "samiskt": "samisk",
    "samiskts": "samisk",
    "samizdatar": "samizdat",
    "samizdatarna": "samizdat",
    "samizdatarnas": "samizdat",
    "samizdatars": "samizdat",
    "samizdaten": "samizdat",
    "samizdatens": "samizdat",
    "samizdats": "samizdat",
    "samk": "samka",
    "samkad": "samka",
    "samkade": "samka",
    "samkades": "samka",
    "samkads": "samka",
    "samkande": "samka",
    "samkanden": "samkande",
    "samkandena": "samkande",
    "samkandenas": "samkande",
    "samkandens": "samkande",
    "samkandes": "samkande",
    "samkandet": "samkande",
    "samkandets": "samkande",
    "samkar": "samka",
    "samkas": "samka",
    "samkat": "samka",
    "samkats": "samka",
    "samklangen": "samklang",
    "samklangens": "samklang",
    "samklangs": "samklang",
    "samklingade": "samklinga",
    "samklingades": "samklinga",
    "samklingande": "samklinga",
    "samklinganden": "samklingande",
    "samklingandena": "samklingande",
    "samklingandenas": "samklingande",
    "samklingandens": "samklingande",
    "samklingandes": "samklingande",
    "samklingandet": "samklingande",
    "samklingandets": "samklingande",
    "samklingar": "samklinga",
    "samklingas": "samklinga",
    "samklingat": "samklinga",
    "samklingats": "samklinga",
    "samkvämen": "samkväm",
    "samkvämens": "samkväm",
    "samkvämet": "samkväm",
    "samkvämets": "samkväm",
    "samkväms": "samkväm",
    "samkänslan": "samkänsla",
    "samkänslans": "samkänsla",
    "samkänslas": "samkänsla",
    "samkänsle": "samkänsla",
    "samkänslo": "samkänsla",
    "samkönade": "samkönad",
    "samkönades": "samkönad",
    "samkönads": "samkönad",
    "samkönat": "samkönad",
    "samkönats": "samkönad",
    "samköpen": "samköp",
    "samköpens": "samköp",
    "samköpet": "samköp",
    "samköpets": "samköp",
    "samköps": "samköp",
    "samkör": "samköra",
    "samkörande": "samköra",
    "samköranden": "samkörande",
    "samkörandena": "samkörande",
    "samkörandenas": "samkörande",
    "samkörandens": "samkörande",
    "samkörandes": "samkörande",
    "samkörandet": "samkörande",
    "samkörandets": "samkörande",
    "samköras": "samköra",
    "samkörd": "samköra",
    "samkörda": "samköra",
    "samkördas": "samköra",
    "samkörde": "samköra",
    "samkördes": "samköra",
    "samkörds": "samköra",
    "samköres": "samköra",
    "samkörningar": "samkörning",
    "samkörningarna": "samkörning",
    "samkörningarnas": "samkörning",
    "samkörningars": "samkörning",
    "samkörningen": "samkörning",
    "samkörningens": "samkörning",
    "samkörnings": "samkörning",
    "samkörs": "samköra",
    "samkört": "samköra",
    "samkörts": "samköra",
    "samlad": "samla",
    "samlade": "samlad",
    "samlades": "samlas",
    "samlads": "samlad",
    "samlagen": "samlag",
    "samlagens": "samlag",
    "samlaget": "samlag",
    "samlagets": "samlag",
    "samlags": "samlag",
    "samlagsdebuten": "samlagsdebut",
    "samlagsdebutens": "samlagsdebut",
    "samlagsdebuts": "samlagsdebut",
    "samlagspartnern": "samlagspartner",
    "samlagspartnerna": "samlagspartner",
    "samlagspartnernas": "samlagspartner",
    "samlagspartnerns": "samlagspartner",
    "samlagspartners": "samlagspartner",
    "samlagspartnersarna": "samlagspartner",
    "samlagspartnersarnas": "samlagspartner",
    "samlagspartnersen": "samlagspartner",
    "samlagspartnersens": "samlagspartner",
    "samlagsställningar": "samlagsställning",
    "samlagsställningarna": "samlagsställning",
    "samlagsställningarnas": "samlagsställning",
    "samlagsställningars": "samlagsställning",
    "samlagsställningen": "samlagsställning",
    "samlagsställningens": "samlagsställning",
    "samlagsställnings": "samlagsställning",
    "samlande": "samla",
    "samlanden": "samlande",
    "samlandena": "samlande",
    "samlandenas": "samlande",
    "samlandens": "samlande",
    "samlandes": "samlande",
    "samlandet": "samlande",
    "samlandets": "samlande",
    "samlar": "samlare",
    "samlaren": "samlare",
    "samlarens": "samlare",
    "samlares": "samlare",
    "samlarfolken": "samlarfolk",
    "samlarfolkens": "samlarfolk",
    "samlarfolket": "samlarfolk",
    "samlarfolkets": "samlarfolk",
    "samlarfolks": "samlarfolk",
    "samlarföremålen": "samlarföremål",
    "samlarföremålens": "samlarföremål",
    "samlarföremålet": "samlarföremål",
    "samlarföremålets": "samlarföremål",
    "samlarföremåls": "samlarföremål",
    "samlarinstinkten": "samlarinstinkt",
    "samlarinstinktens": "samlarinstinkt",
    "samlarinstinkts": "samlarinstinkt",
    "samlarna": "samlare",
    "samlarnas": "samlare",
    "samlarsyssl": "samlarsyssla",
    "samlarsysslan": "samlarsyssla",
    "samlarsysslans": "samlarsyssla",
    "samlarsysslas": "samlarsyssla",
    "samlarsyssle": "samlarsyssla",
    "samlarsysslo": "samlarsyssla",
    "samlarsysslor": "samlarsyssla",
    "samlarsysslorna": "samlarsyssla",
    "samlarsysslornas": "samlarsyssla",
    "samlarsysslors": "samlarsyssla",
    "samlarvärdes": "samlarvärde",
    "samlarvärdet": "samlarvärde",
    "samlarvärdets": "samlarvärde",
    "samlas": "samla",
    "samlat": "samlad",
    "samlats": "samlas",
    "samlevnaden": "samlevnad",
    "samlevnadens": "samlevnad",
    "samlevnader": "samlevnad",
    "samlevnaderna": "samlevnad",
    "samlevnadernas": "samlevnad",
    "samlevnaders": "samlevnad",
    "samlevnads": "samlevnad",
    "samlingar": "samling",
    "samlingarna": "samling",
    "samlingarnas": "samling",
    "samlingars": "samling",
    "samlingen": "samling",
    "samlingens": "samling",
    "samlings": "samling",
    "samlingsbanden": "samlingsband",
    "samlingsbandens": "samlingsband",
    "samlingsbandet": "samlingsband",
    "samlingsbandets": "samlingsband",
    "samlingsbands": "samlingsband",
    "samlingslinsen": "samlingslins",
    "samlingslinsens": "samlingslins",
    "samlingslinser": "samlingslins",
    "samlingslinserna": "samlingslins",
    "samlingslinsernas": "samlingslins",
    "samlingslinsers": "samlingslins",
    "samlingslokalen": "samlingslokal",
    "samlingslokalens": "samlingslokal",
    "samlingslokaler": "samlingslokal",
    "samlingslokalerna": "samlingslokal",
    "samlingslokalernas": "samlingslokal",
    "samlingslokalers": "samlingslokal",
    "samlingslokals": "samlingslokal",
    "samlingsnamnen": "samlingsnamn",
    "samlingsnamnens": "samlingsnamn",
    "samlingsnamnet": "samlingsnamn",
    "samlingsnamnets": "samlingsnamn",
    "samlingsnamns": "samlingsnamn",
    "samlingspartier": "samlingsparti",
    "samlingspartierna": "samlingsparti",
    "samlingspartiernas": "samlingsparti",
    "samlingspartiers": "samlingsparti",
    "samlingspartiet": "samlingsparti",
    "samlingspartiets": "samlingsparti",
    "samlingspartis": "samlingsparti",
    "samlingspartit": "samlingsparti",
    "samlingspartits": "samlingsparti",
    "samlingsplatsen": "samlingsplats",
    "samlingsplatsens": "samlingsplats",
    "samlingsplatser": "samlingsplats",
    "samlingsplatserna": "samlingsplats",
    "samlingsplatsernas": "samlingsplats",
    "samlingsplatsers": "samlingsplats",
    "samlingspunkten": "samlingspunkt",
    "samlingspunktens": "samlingspunkt",
    "samlingspunkter": "samlingspunkt",
    "samlingspunkterna": "samlingspunkt",
    "samlingspunkternas": "samlingspunkt",
    "samlingspunkters": "samlingspunkt",
    "samlingspunkts": "samlingspunkt",
    "samlingspärmar": "samlingspärm",
    "samlingspärmarna": "samlingspärm",
    "samlingspärmarnas": "samlingspärm",
    "samlingspärmars": "samlingspärm",
    "samlingspärmen": "samlingspärm",
    "samlingspärmens": "samlingspärm",
    "samlingspärms": "samlingspärm",
    "samlingsregeringar": "samlingsregering",
    "samlingsregeringarna": "samlingsregering",
    "samlingsregeringarnas": "samlingsregering",
    "samlingsregeringars": "samlingsregering",
    "samlingsregeringen": "samlingsregering",
    "samlingsregeringens": "samlingsregering",
    "samlingsregerings": "samlingsregering",
    "samlingsrummen": "samlingsrum",
    "samlingsrummens": "samlingsrum",
    "samlingsrummet": "samlingsrum",
    "samlingsrummets": "samlingsrum",
    "samlingsrums": "samlingsrum",
    "samlingssalar": "samlingssal",
    "samlingssalarna": "samlingssal",
    "samlingssalarnas": "samlingssal",
    "samlingssalars": "samlingssal",
    "samlingssalen": "samlingssal",
    "samlingssalens": "samlingssal",
    "samlingssals": "samlingssal",
    "samlingsverken": "samlingsverk",
    "samlingsverkens": "samlingsverk",
    "samlingsverket": "samlingsverk",
    "samlingsverkets": "samlingsverk",
    "samlingsverks": "samlingsverk",
    "samlivet": "samliv",
    "samlivets": "samliv",
    "samlivs": "samliv",
    "sammalda": "sammald",
    "sammaldare": "sammald",
    "sammaldares": "sammald",
    "sammaldas": "sammald",
    "sammaldast": "sammald",
    "sammaldaste": "sammald",
    "sammaldastes": "sammald",
    "sammaldasts": "sammald",
    "sammalde": "sammald",
    "sammaldes": "sammald",
    "sammalds": "sammald",
    "sammalens": "sammalen",
    "sammalet": "sammalen",
    "sammalets": "sammalen",
    "sammalna": "sammalen",
    "sammalnare": "sammalen",
    "sammalnares": "sammalen",
    "sammalnas": "sammalen",
    "sammalnast": "sammalen",
    "sammalnaste": "sammalen",
    "sammalnastes": "sammalen",
    "sammalnasts": "sammalen",
    "sammalne": "sammalen",
    "sammalnes": "sammalen",
    "sammalt": "sammald",
    "sammalts": "sammald",
    "sammanavlad": "sammanavla",
    "sammanavlade": "sammanavla",
    "sammanavlades": "sammanavla",
    "sammanavlads": "sammanavla",
    "sammanavlande": "sammanavla",
    "sammanavlanden": "sammanavlande",
    "sammanavlandena": "sammanavlande",
    "sammanavlandenas": "sammanavlande",
    "sammanavlandens": "sammanavlande",
    "sammanavlandes": "sammanavlande",
    "sammanavlandet": "sammanavlande",
    "sammanavlandets": "sammanavlande",
    "sammanavlar": "sammanavla",
    "sammanavlas": "sammanavla",
    "sammanavlat": "sammanavla",
    "sammanavlats": "sammanavla",
    "sammanband": "sammanbinda",
    "sammanbands": "sammanbinda",
    "sammanbind": "sammanbinda",
    "sammanbindande": "sammanbinda",
    "sammanbindanden": "sammanbindande",
    "sammanbindandena": "sammanbindande",
    "sammanbindandenas": "sammanbindande",
    "sammanbindandens": "sammanbindande",
    "sammanbindandes": "sammanbindande",
    "sammanbindandet": "sammanbindande",
    "sammanbindandets": "sammanbindande",
    "sammanbindas": "sammanbinda",
    "sammanbinde": "sammanbinda",
    "sammanbinder": "sammanbinda",
    "sammanbindes": "sammanbinda",
    "sammanbindningar": "sammanbindning",
    "sammanbindningarna": "sammanbindning",
    "sammanbindningarnas": "sammanbindning",
    "sammanbindningars": "sammanbindning",
    "sammanbindningen": "sammanbindning",
    "sammanbindningens": "sammanbindning",
    "sammanbindnings": "sammanbindning",
    "sammanbinds": "sammanbinda",
    "sammanbitens": "sammanbiten",
    "sammanbitet": "sammanbiten",
    "sammanbitets": "sammanbiten",
    "sammanbitna": "sammanbiten",
    "sammanbitnare": "sammanbiten",
    "sammanbitnares": "sammanbiten",
    "sammanbitnas": "sammanbiten",
    "sammanbitnast": "sammanbiten",
    "sammanbitnaste": "sammanbiten",
    "sammanbitnastes": "sammanbiten",
    "sammanbitnasts": "sammanbiten",
    "sammanbitne": "sammanbiten",
    "sammanbitnes": "sammanbiten",
    "sammanbland": "sammanblanda",
    "sammanblandad": "sammanblanda",
    "sammanblandade": "sammanblanda",
    "sammanblandades": "sammanblanda",
    "sammanblandads": "sammanblanda",
    "sammanblandande": "sammanblanda",
    "sammanblandanden": "sammanblandande",
    "sammanblandandena": "sammanblandande",
    "sammanblandandenas": "sammanblandande",
    "sammanblandandens": "sammanblandande",
    "sammanblandandes": "sammanblandande",
    "sammanblandandet": "sammanblandande",
    "sammanblandandets": "sammanblandande",
    "sammanblandar": "sammanblanda",
    "sammanblandas": "sammanblanda",
    "sammanblandat": "sammanblanda",
    "sammanblandats": "sammanblanda",
    "sammanblandningar": "sammanblandning",
    "sammanblandningarna": "sammanblandning",
    "sammanblandningarnas": "sammanblandning",
    "sammanblandningars": "sammanblandning",
    "sammanblandningen": "sammanblandning",
    "sammanblandningens": "sammanblandning",
    "sammanblandnings": "sammanblandning",
    "sammanbodd": "sammanbo",
    "sammanbodda": "sammanbo",
    "sammanboddas": "sammanbo",
    "sammanbodde": "sammanbo",
    "sammanboddes": "sammanbo",
    "sammanbodds": "sammanbo",
    "sammanboende": "sammanbo",
    "sammanboenden": "sammanboende",
    "sammanboendena": "sammanboende",
    "sammanboendenas": "sammanboende",
    "sammanboendens": "sammanboende",
    "sammanboendes": "sammanboende",
    "sammanboendet": "sammanboende",
    "sammanboendets": "sammanboende",
    "sammanbor": "sammanbo",
    "sammanbos": "sammanbo",
    "sammanbott": "sammanbo",
    "sammanbotts": "sammanbo",
    "sammanbragta": "sammanbragt",
    "sammanbragtare": "sammanbragt",
    "sammanbragtares": "sammanbragt",
    "sammanbragtas": "sammanbragt",
    "sammanbragtast": "sammanbragt",
    "sammanbragtaste": "sammanbragt",
    "sammanbragtastes": "sammanbragt",
    "sammanbragtasts": "sammanbragt",
    "sammanbragte": "sammanbragt",
    "sammanbragtes": "sammanbragt",
    "sammanbragts": "sammanbragt",
    "sammanbrotten": "sammanbrott",
    "sammanbrottens": "sammanbrott",
    "sammanbrottet": "sammanbrott",
    "sammanbrottets": "sammanbrott",
    "sammanbrotts": "sammanbrott",
    "sammanbunde": "sammanbinda",
    "sammanbunden": "sammanbinda",
    "sammanbundens": "sammanbinda",
    "sammanbundes": "sammanbinda",
    "sammanbundet": "sammanbinda",
    "sammanbundets": "sammanbinda",
    "sammanbundit": "sammanbinda",
    "sammanbundits": "sammanbinda",
    "sammanbundna": "sammanbinda",
    "sammanbundnas": "sammanbinda",
    "sammanbundne": "sammanbinda",
    "sammanbundnes": "sammanbinda",
    "sammandrabb": "sammandrabba",
    "sammandrabbad": "sammandrabba",
    "sammandrabbade": "sammandrabba",
    "sammandrabbades": "sammandrabba",
    "sammandrabbads": "sammandrabba",
    "sammandrabbande": "sammandrabba",
    "sammandrabbanden": "sammandrabbande",
    "sammandrabbandena": "sammandrabbande",
    "sammandrabbandenas": "sammandrabbande",
    "sammandrabbandens": "sammandrabbande",
    "sammandrabbandes": "sammandrabbande",
    "sammandrabbandet": "sammandrabbande",
    "sammandrabbandets": "sammandrabbande",
    "sammandrabbar": "sammandrabba",
    "sammandrabbas": "sammandrabba",
    "sammandrabbat": "sammandrabba",
    "sammandrabbats": "sammandrabba",
    "sammandrabbningar": "sammandrabbning",
    "sammandrabbningarna": "sammandrabbning",
    "sammandrabbningarnas": "sammandrabbning",
    "sammandrabbningars": "sammandrabbning",
    "sammandrabbningen": "sammandrabbning",
    "sammandrabbningens": "sammandrabbning",
    "sammandrabbnings": "sammandrabbning",
    "sammandrag": "sammandra",
    "sammandraga": "sammandra",
    "sammandragande": "sammandra",
    "sammandraganden": "sammandragande",
    "sammandragandena": "sammandragande",
    "sammandragandenas": "sammandragande",
    "sammandragandens": "sammandragande",
    "sammandragandes": "sammandragande",
    "sammandragandet": "sammandragande",
    "sammandragandets": "sammandragande",
    "sammandragas": "sammandra",
    "sammandrage": "sammandra",
    "sammandragen": "sammandrag",
    "sammandragens": "sammandrag",
    "sammandrager": "sammandra",
    "sammandrages": "sammandra",
    "sammandraget": "sammandrag",
    "sammandragets": "sammandrag",
    "sammandragit": "sammandra",
    "sammandragits": "sammandra",
    "sammandragna": "sammandra",
    "sammandragnas": "sammandra",
    "sammandragne": "sammandra",
    "sammandragnes": "sammandra",
    "sammandragningar": "sammandragning",
    "sammandragningarna": "sammandragning",
    "sammandragningarnas": "sammandragning",
    "sammandragningars": "sammandragning",
    "sammandragningen": "sammandragning",
    "sammandragningens": "sammandragning",
    "sammandragnings": "sammandragning",
    "sammandrags": "sammandrag",
    "sammandrar": "sammandra",
    "sammandras": "sammandra",
    "sammandrog": "sammandra",
    "sammandroge": "sammandra",
    "sammandroges": "sammandra",
    "sammandrogs": "sammandra",
    "sammanfall": "sammanfalla",
    "sammanfallande": "sammanfalla",
    "sammanfallanden": "sammanfallande",
    "sammanfallandena": "sammanfallande",
    "sammanfallandenas": "sammanfallande",
    "sammanfallandens": "sammanfallande",
    "sammanfallandes": "sammanfallande",
    "sammanfallandet": "sammanfallande",
    "sammanfallandets": "sammanfallande",
    "sammanfallas": "sammanfalla",
    "sammanfalle": "sammanfalla",
    "sammanfallen": "sammanfalla",
    "sammanfallens": "sammanfalla",
    "sammanfaller": "sammanfalla",
    "sammanfalles": "sammanfalla",
    "sammanfallet": "sammanfalla",
    "sammanfallets": "sammanfalla",
    "sammanfallit": "sammanfalla",
    "sammanfallits": "sammanfalla",
    "sammanfallna": "sammanfalla",
    "sammanfallnas": "sammanfalla",
    "sammanfallne": "sammanfalla",
    "sammanfallnes": "sammanfalla",
    "sammanfalls": "sammanfalla",
    "sammanfatt": "sammanfatta",
    "sammanfattad": "sammanfatta",
    "sammanfattade": "sammanfatta",
    "sammanfattades": "sammanfatta",
    "sammanfattads": "sammanfatta",
    "sammanfattande": "sammanfatta",
    "sammanfattanden": "sammanfattande",
    "sammanfattandena": "sammanfattande",
    "sammanfattandenas": "sammanfattande",
    "sammanfattandens": "sammanfattande",
    "sammanfattandes": "sammanfattande",
    "sammanfattandet": "sammanfattande",
    "sammanfattandets": "sammanfattande",
    "sammanfattar": "sammanfatta",
    "sammanfattas": "sammanfatta",
    "sammanfattat": "sammanfatta",
    "sammanfattats": "sammanfatta",
    "sammanfattningar": "sammanfattning",
    "sammanfattningarna": "sammanfattning",
    "sammanfattningarnas": "sammanfattning",
    "sammanfattningars": "sammanfattning",
    "sammanfattningen": "sammanfattning",
    "sammanfattningens": "sammanfattning",
    "sammanfattnings": "sammanfattning",
    "sammanflät": "sammanfläta",
    "sammanflätad": "sammanfläta",
    "sammanflätade": "sammanfläta",
    "sammanflätades": "sammanfläta",
    "sammanflätads": "sammanfläta",
    "sammanflätande": "sammanfläta",
    "sammanflätanden": "sammanflätande",
    "sammanflätandena": "sammanflätande",
    "sammanflätandenas": "sammanflätande",
    "sammanflätandens": "sammanflätande",
    "sammanflätandes": "sammanflätande",
    "sammanflätandet": "sammanflätande",
    "sammanflätandets": "sammanflätande",
    "sammanflätar": "sammanfläta",
    "sammanflätas": "sammanfläta",
    "sammanflätat": "sammanfläta",
    "sammanflätats": "sammanfläta",
    "sammanflöden": "sammanflöde",
    "sammanflödena": "sammanflöde",
    "sammanflödenas": "sammanflöde",
    "sammanflödens": "sammanflöde",
    "sammanflödes": "sammanflöde",
    "sammanflödet": "sammanflöde",
    "sammanflödets": "sammanflöde",
    "sammanfog": "sammanfoga",
    "sammanfogad": "sammanfoga",
    "sammanfogade": "sammanfoga",
    "sammanfogades": "sammanfoga",
    "sammanfogads": "sammanfoga",
    "sammanfogande": "sammanfoga",
    "sammanfoganden": "sammanfogande",
    "sammanfogandena": "sammanfogande",
    "sammanfogandenas": "sammanfogande",
    "sammanfogandens": "sammanfogande",
    "sammanfogandes": "sammanfogande",
    "sammanfogandet": "sammanfogande",
    "sammanfogandets": "sammanfogande",
    "sammanfogar": "sammanfoga",
    "sammanfogas": "sammanfoga",
    "sammanfogat": "sammanfoga",
    "sammanfogats": "sammanfoga",
    "sammanfogningar": "sammanfogning",
    "sammanfogningarna": "sammanfogning",
    "sammanfogningarnas": "sammanfogning",
    "sammanfogningars": "sammanfogning",
    "sammanfogningen": "sammanfogning",
    "sammanfogningens": "sammanfogning",
    "sammanfognings": "sammanfogning",
    "sammanföll": "sammanfalla",
    "sammanfölle": "sammanfalla",
    "sammanfölles": "sammanfalla",
    "sammanfölls": "sammanfalla",
    "sammanför": "sammanföra",
    "sammanförande": "sammanföra",
    "sammanföranden": "sammanförande",
    "sammanförandena": "sammanförande",
    "sammanförandenas": "sammanförande",
    "sammanförandens": "sammanförande",
    "sammanförandes": "sammanförande",
    "sammanförandet": "sammanförande",
    "sammanförandets": "sammanförande",
    "sammanföras": "sammanföra",
    "sammanförd": "sammanföra",
    "sammanförda": "sammanföra",
    "sammanfördas": "sammanföra",
    "sammanförde": "sammanföra",
    "sammanfördes": "sammanföra",
    "sammanförds": "sammanföra",
    "sammanföres": "sammanföra",
    "sammanförs": "sammanföra",
    "sammanfört": "sammanföra",
    "sammanförts": "sammanföra",
    "sammangick": "sammangå",
    "sammangicks": "sammangå",
    "sammanginge": "sammangå",
    "sammanginges": "sammangå",
    "sammangyttrade": "sammangyttrad",
    "sammangyttrades": "sammangyttrad",
    "sammangyttrads": "sammangyttrad",
    "sammangyttrat": "sammangyttrad",
    "sammangyttrats": "sammangyttrad",
    "sammangående": "sammangå",
    "sammangåenden": "sammangående",
    "sammangåendena": "sammangående",
    "sammangåendenas": "sammangående",
    "sammangåendens": "sammangående",
    "sammangåendes": "sammangående",
    "sammangåendet": "sammangående",
    "sammangåendets": "sammangående",
    "sammangånge": "sammangå",
    "sammangången": "sammangå",
    "sammangångens": "sammangå",
    "sammangånges": "sammangå",
    "sammangånget": "sammangå",
    "sammangångets": "sammangå",
    "sammangångna": "sammangå",
    "sammangångnas": "sammangå",
    "sammangångne": "sammangå",
    "sammangångnes": "sammangå",
    "sammangår": "sammangå",
    "sammangås": "sammangå",
    "sammangått": "sammangå",
    "sammangåtts": "sammangå",
    "sammanhangen": "sammanhang",
    "sammanhangens": "sammanhang",
    "sammanhanget": "sammanhang",
    "sammanhangets": "sammanhang",
    "sammanhangs": "sammanhang",
    "sammanhop": "sammanhopa",
    "sammanhopad": "sammanhopa",
    "sammanhopade": "sammanhopa",
    "sammanhopades": "sammanhopa",
    "sammanhopads": "sammanhopa",
    "sammanhopande": "sammanhopa",
    "sammanhopanden": "sammanhopande",
    "sammanhopandena": "sammanhopande",
    "sammanhopandenas": "sammanhopande",
    "sammanhopandens": "sammanhopande",
    "sammanhopandes": "sammanhopande",
    "sammanhopandet": "sammanhopande",
    "sammanhopandets": "sammanhopande",
    "sammanhopar": "sammanhopa",
    "sammanhopas": "sammanhopa",
    "sammanhopat": "sammanhopa",
    "sammanhopats": "sammanhopa",
    "sammanhäng": "sammanhänga",
    "sammanhängande": "sammanhänga",
    "sammanhänganden": "sammanhängande",
    "sammanhängandena": "sammanhängande",
    "sammanhängandenas": "sammanhängande",
    "sammanhängandens": "sammanhängande",
    "sammanhängandes": "sammanhängande",
    "sammanhängandet": "sammanhängande",
    "sammanhängandets": "sammanhängande",
    "sammanhängas": "sammanhänga",
    "sammanhängd": "sammanhänga",
    "sammanhängda": "sammanhänga",
    "sammanhängdas": "sammanhänga",
    "sammanhängde": "sammanhänga",
    "sammanhängdes": "sammanhänga",
    "sammanhängds": "sammanhänga",
    "sammanhänger": "sammanhänga",
    "sammanhänges": "sammanhänga",
    "sammanhängs": "sammanhänga",
    "sammanhängt": "sammanhänga",
    "sammanhängts": "sammanhänga",
    "sammanhåll": "sammanhålla",
    "sammanhållande": "sammanhålla",
    "sammanhållanden": "sammanhållande",
    "sammanhållandena": "sammanhållande",
    "sammanhållandenas": "sammanhållande",
    "sammanhållandens": "sammanhållande",
    "sammanhållandes": "sammanhållande",
    "sammanhållandet": "sammanhållande",
    "sammanhållandets": "sammanhållande",
    "sammanhållas": "sammanhålla",
    "sammanhålle": "sammanhålla",
    "sammanhållen": "sammanhålla",
    "sammanhållens": "sammanhållen",
    "sammanhåller": "sammanhålla",
    "sammanhålles": "sammanhålla",
    "sammanhållet": "sammanhållen",
    "sammanhållets": "sammanhållen",
    "sammanhålliga": "sammanhållig",
    "sammanhålligare": "sammanhållig",
    "sammanhålligares": "sammanhållig",
    "sammanhålligas": "sammanhållig",
    "sammanhålligast": "sammanhållig",
    "sammanhålligaste": "sammanhållig",
    "sammanhålligastes": "sammanhållig",
    "sammanhålligasts": "sammanhållig",
    "sammanhållige": "sammanhållig",
    "sammanhålliges": "sammanhållig",
    "sammanhålligheten": "sammanhållighet",
    "sammanhållighetens": "sammanhållighet",
    "sammanhållighets": "sammanhållighet",
    "sammanhålligs": "sammanhållig",
    "sammanhålligt": "sammanhållig",
    "sammanhålligts": "sammanhållig",
    "sammanhållit": "sammanhålla",
    "sammanhållits": "sammanhålla",
    "sammanhållna": "sammanhållen",
    "sammanhållnare": "sammanhållen",
    "sammanhållnares": "sammanhållen",
    "sammanhållnas": "sammanhållen",
    "sammanhållnast": "sammanhållen",
    "sammanhållnaste": "sammanhållen",
    "sammanhållnastes": "sammanhållen",
    "sammanhållnasts": "sammanhållen",
    "sammanhållne": "sammanhållen",
    "sammanhållnes": "sammanhållen",
    "sammanhållningar": "sammanhållning",
    "sammanhållningarna": "sammanhållning",
    "sammanhållningarnas": "sammanhållning",
    "sammanhållningars": "sammanhållning",
    "sammanhållningen": "sammanhållning",
    "sammanhållningens": "sammanhållning",
    "sammanhållnings": "sammanhållning",
    "sammanhålls": "sammanhålla",
    "sammanhöll": "sammanhålla",
    "sammanhölle": "sammanhålla",
    "sammanhölles": "sammanhålla",
    "sammanhölls": "sammanhålla",
    "sammanjämk": "sammanjämka",
    "sammanjämkad": "sammanjämka",
    "sammanjämkade": "sammanjämka",
    "sammanjämkades": "sammanjämka",
    "sammanjämkads": "sammanjämka",
    "sammanjämkande": "sammanjämka",
    "sammanjämkanden": "sammanjämkande",
    "sammanjämkandena": "sammanjämkande",
    "sammanjämkandenas": "sammanjämkande",
    "sammanjämkandens": "sammanjämkande",
    "sammanjämkandes": "sammanjämkande",
    "sammanjämkandet": "sammanjämkande",
    "sammanjämkandets": "sammanjämkande",
    "sammanjämkar": "sammanjämka",
    "sammanjämkas": "sammanjämka",
    "sammanjämkat": "sammanjämka",
    "sammanjämkats": "sammanjämka",
    "sammankall": "sammankalla",
    "sammankallad": "sammankalla",
    "sammankallade": "sammankalla",
    "sammankallades": "sammankalla",
    "sammankallads": "sammankalla",
    "sammankallande": "sammankalla",
    "sammankallanden": "sammankallande",
    "sammankallandena": "sammankallande",
    "sammankallandenas": "sammankallande",
    "sammankallandens": "sammankallande",
    "sammankallandes": "sammankallande",
    "sammankallandet": "sammankallande",
    "sammankallandets": "sammankallande",
    "sammankallar": "sammankalla",
    "sammankallas": "sammankalla",
    "sammankallat": "sammankalla",
    "sammankallats": "sammankalla",
    "sammankomsten": "sammankomst",
    "sammankomstens": "sammankomst",
    "sammankomster": "sammankomst",
    "sammankomsterna": "sammankomst",
    "sammankomsternas": "sammankomst",
    "sammankomsters": "sammankomst",
    "sammankomsts": "sammankomst",
    "sammankopplad": "sammankoppla",
    "sammankopplade": "sammankoppla",
    "sammankopplades": "sammankoppla",
    "sammankopplads": "sammankoppla",
    "sammankopplande": "sammankoppla",
    "sammankopplanden": "sammankopplande",
    "sammankopplandena": "sammankopplande",
    "sammankopplandenas": "sammankopplande",
    "sammankopplandens": "sammankopplande",
    "sammankopplandes": "sammankopplande",
    "sammankopplandet": "sammankopplande",
    "sammankopplandets": "sammankopplande",
    "sammankopplar": "sammankoppla",
    "sammankopplas": "sammankoppla",
    "sammankopplat": "sammankoppla",
    "sammankopplats": "sammankoppla",
    "sammanla": "sammanlägga",
    "sammanlade": "sammanlägga",
    "sammanlades": "sammanlägga",
    "sammanlagd": "sammanlägga",
    "sammanlagda": "sammanlägga",
    "sammanlagdare": "sammanlagd",
    "sammanlagdares": "sammanlagd",
    "sammanlagdas": "sammanlägga",
    "sammanlagdast": "sammanlagd",
    "sammanlagdaste": "sammanlagd",
    "sammanlagdastes": "sammanlagd",
    "sammanlagdasts": "sammanlagd",
    "sammanlagde": "sammanlägga",
    "sammanlagdes": "sammanlägga",
    "sammanlagds": "sammanlägga",
    "sammanlagt": "sammanlägga",
    "sammanlagts": "sammanlägga",
    "sammanlas": "sammanlägga",
    "sammanlev": "sammanleva",
    "sammanlevande": "sammanleva",
    "sammanlevanden": "sammanlevande",
    "sammanlevandena": "sammanlevande",
    "sammanlevandenas": "sammanlevande",
    "sammanlevandens": "sammanlevande",
    "sammanlevandes": "sammanlevande",
    "sammanlevandet": "sammanlevande",
    "sammanlevandets": "sammanlevande",
    "sammanlevas": "sammanleva",
    "sammanlevat": "sammanleva",
    "sammanlevats": "sammanleva",
    "sammanlevd": "sammanleva",
    "sammanlevda": "sammanleva",
    "sammanlevdas": "sammanleva",
    "sammanlevde": "sammanleva",
    "sammanlevdes": "sammanleva",
    "sammanlevds": "sammanleva",
    "sammanlever": "sammanleva",
    "sammanleves": "sammanleva",
    "sammanlevs": "sammanleva",
    "sammanlevt": "sammanleva",
    "sammanlevts": "sammanleva",
    "sammanlägg": "sammanlägga",
    "sammanläggande": "sammanlägga",
    "sammanlägganden": "sammanläggande",
    "sammanläggandena": "sammanläggande",
    "sammanläggandenas": "sammanläggande",
    "sammanläggandens": "sammanläggande",
    "sammanläggandes": "sammanläggande",
    "sammanläggandet": "sammanläggande",
    "sammanläggandets": "sammanläggande",
    "sammanläggas": "sammanlägga",
    "sammanlägger": "sammanlägga",
    "sammanlägges": "sammanlägga",
    "sammanläggningar": "sammanläggning",
    "sammanläggningarna": "sammanläggning",
    "sammanläggningarnas": "sammanläggning",
    "sammanläggningars": "sammanläggning",
    "sammanläggningen": "sammanläggning",
    "sammanläggningens": "sammanläggning",
    "sammanläggnings": "sammanläggning",
    "sammanläggningsavhandlingar": "sammanläggningsavhandling",
    "sammanläggningsavhandlingarna": "sammanläggningsavhandling",
    "sammanläggningsavhandlingarnas": "sammanläggningsavhandling",
    "sammanläggningsavhandlingars": "sammanläggningsavhandling",
    "sammanläggningsavhandlingen": "sammanläggningsavhandling",
    "sammanläggningsavhandlingens": "sammanläggningsavhandling",
    "sammanläggningsavhandlings": "sammanläggningsavhandling",
    "sammanläggs": "sammanlägga",
    "sammanlänk": "sammanlänka",
    "sammanlänkad": "sammanlänka",
    "sammanlänkade": "sammanlänka",
    "sammanlänkades": "sammanlänka",
    "sammanlänkads": "sammanlänka",
    "sammanlänkande": "sammanlänka",
    "sammanlänkanden": "sammanlänkande",
    "sammanlänkandena": "sammanlänkande",
    "sammanlänkandenas": "sammanlänkande",
    "sammanlänkandens": "sammanlänkande",
    "sammanlänkandes": "sammanlänkande",
    "sammanlänkandet": "sammanlänkande",
    "sammanlänkandets": "sammanlänkande",
    "sammanlänkar": "sammanlänka",
    "sammanlänkas": "sammanlänka",
    "sammanlänkat": "sammanlänka",
    "sammanlänkats": "sammanlänka",
    "sammanlöp": "sammanlöpa",
    "sammanlöpande": "sammanlöpa",
    "sammanlöpanden": "sammanlöpande",
    "sammanlöpandena": "sammanlöpande",
    "sammanlöpandenas": "sammanlöpande",
    "sammanlöpandens": "sammanlöpande",
    "sammanlöpandes": "sammanlöpande",
    "sammanlöpandet": "sammanlöpande",
    "sammanlöpandets": "sammanlöpande",
    "sammanlöpas": "sammanlöpa",
    "sammanlöper": "sammanlöpa",
    "sammanlöpes": "sammanlöpa",
    "sammanlöps": "sammanlöpa",
    "sammanlöpt": "sammanlöpa",
    "sammanlöpta": "sammanlöpa",
    "sammanlöptas": "sammanlöpa",
    "sammanlöpte": "sammanlöpa",
    "sammanlöptes": "sammanlöpa",
    "sammanlöpts": "sammanlöpa",
    "sammanpack": "sammanpacka",
    "sammanpackad": "sammanpacka",
    "sammanpackade": "sammanpacka",
    "sammanpackades": "sammanpacka",
    "sammanpackads": "sammanpacka",
    "sammanpackande": "sammanpacka",
    "sammanpackanden": "sammanpackande",
    "sammanpackandena": "sammanpackande",
    "sammanpackandenas": "sammanpackande",
    "sammanpackandens": "sammanpackande",
    "sammanpackandes": "sammanpackande",
    "sammanpackandet": "sammanpackande",
    "sammanpackandets": "sammanpackande",
    "sammanpackar": "sammanpacka",
    "sammanpackas": "sammanpacka",
    "sammanpackat": "sammanpacka",
    "sammanpackats": "sammanpacka",
    "sammanpress": "sammanpressa",
    "sammanpressad": "sammanpressa",
    "sammanpressade": "sammanpressa",
    "sammanpressades": "sammanpressa",
    "sammanpressads": "sammanpressa",
    "sammanpressande": "sammanpressa",
    "sammanpressanden": "sammanpressande",
    "sammanpressandena": "sammanpressande",
    "sammanpressandenas": "sammanpressande",
    "sammanpressandens": "sammanpressande",
    "sammanpressandes": "sammanpressande",
    "sammanpressandet": "sammanpressande",
    "sammanpressandets": "sammanpressande",
    "sammanpressar": "sammanpressa",
    "sammanpressas": "sammanpressa",
    "sammanpressat": "sammanpressa",
    "sammanpressats": "sammanpressa",
    "sammanring": "sammanringa",
    "sammanringande": "sammanringa",
    "sammanringanden": "sammanringande",
    "sammanringandena": "sammanringande",
    "sammanringandenas": "sammanringande",
    "sammanringandens": "sammanringande",
    "sammanringandes": "sammanringande",
    "sammanringandet": "sammanringande",
    "sammanringandets": "sammanringande",
    "sammanringas": "sammanringa",
    "sammanringd": "sammanringa",
    "sammanringda": "sammanringa",
    "sammanringdas": "sammanringa",
    "sammanringde": "sammanringa",
    "sammanringdes": "sammanringa",
    "sammanringds": "sammanringa",
    "sammanringer": "sammanringa",
    "sammanringes": "sammanringa",
    "sammanrings": "sammanringa",
    "sammanringt": "sammanringa",
    "sammanringts": "sammanringa",
    "sammanräkn": "sammanräkna",
    "sammanräknad": "sammanräkna",
    "sammanräknade": "sammanräkna",
    "sammanräknades": "sammanräkna",
    "sammanräknads": "sammanräkna",
    "sammanräknande": "sammanräkna",
    "sammanräknanden": "sammanräknande",
    "sammanräknandena": "sammanräknande",
    "sammanräknandenas": "sammanräknande",
    "sammanräknandens": "sammanräknande",
    "sammanräknandes": "sammanräknande",
    "sammanräknandet": "sammanräknande",
    "sammanräknandets": "sammanräknande",
    "sammanräknar": "sammanräkna",
    "sammanräknas": "sammanräkna",
    "sammanräknat": "sammanräkna",
    "sammanräknats": "sammanräkna",
    "sammanräkningar": "sammanräkning",
    "sammanräkningarna": "sammanräkning",
    "sammanräkningarnas": "sammanräkning",
    "sammanräkningars": "sammanräkning",
    "sammanräkningen": "sammanräkning",
    "sammanräkningens": "sammanräkning",
    "sammanräknings": "sammanräkning",
    "sammansatt": "sammansätta",
    "sammansatta": "sammansätta",
    "sammansattare": "sammansatt",
    "sammansattares": "sammansatt",
    "sammansattas": "sammansätta",
    "sammansattast": "sammansatt",
    "sammansattaste": "sammansatt",
    "sammansattastes": "sammansatt",
    "sammansattasts": "sammansatt",
    "sammansatte": "sammansätta",
    "sammansattes": "sammansätta",
    "sammansattheten": "sammansatthet",
    "sammansatthetens": "sammansatthet",
    "sammansatthets": "sammansatthet",
    "sammansatts": "sammansätta",
    "sammanskjut": "sammanskjuta",
    "sammanskjutande": "sammanskjuta",
    "sammanskjutanden": "sammanskjutande",
    "sammanskjutandena": "sammanskjutande",
    "sammanskjutandenas": "sammanskjutande",
    "sammanskjutandens": "sammanskjutande",
    "sammanskjutandes": "sammanskjutande",
    "sammanskjutandet": "sammanskjutande",
    "sammanskjutandets": "sammanskjutande",
    "sammanskjutas": "sammanskjuta",
    "sammanskjute": "sammanskjuta",
    "sammanskjuten": "sammanskjuta",
    "sammanskjutens": "sammanskjuta",
    "sammanskjuter": "sammanskjuta",
    "sammanskjutes": "sammanskjuta",
    "sammanskjutet": "sammanskjuta",
    "sammanskjutets": "sammanskjuta",
    "sammanskjutit": "sammanskjuta",
    "sammanskjutits": "sammanskjuta",
    "sammanskjutna": "sammanskjuta",
    "sammanskjutnas": "sammanskjuta",
    "sammanskjutne": "sammanskjuta",
    "sammanskjutnes": "sammanskjuta",
    "sammanskjuts": "sammanskjuta",
    "sammanskotten": "sammanskott",
    "sammanskottens": "sammanskott",
    "sammanskottet": "sammanskott",
    "sammanskottets": "sammanskott",
    "sammanskotts": "sammanskott",
    "sammanskrev": "sammanskriva",
    "sammanskrevs": "sammanskriva",
    "sammanskriv": "sammanskriva",
    "sammanskrivande": "sammanskriva",
    "sammanskrivanden": "sammanskrivande",
    "sammanskrivandena": "sammanskrivande",
    "sammanskrivandenas": "sammanskrivande",
    "sammanskrivandens": "sammanskrivande",
    "sammanskrivandes": "sammanskrivande",
    "sammanskrivandet": "sammanskrivande",
    "sammanskrivandets": "sammanskrivande",
    "sammanskrivas": "sammanskriva",
    "sammanskrive": "sammanskriva",
    "sammanskriven": "sammanskriva",
    "sammanskrivens": "sammanskriva",
    "sammanskriver": "sammanskriva",
    "sammanskrives": "sammanskriva",
    "sammanskrivet": "sammanskriva",
    "sammanskrivets": "sammanskriva",
    "sammanskrivit": "sammanskriva",
    "sammanskrivits": "sammanskriva",
    "sammanskrivna": "sammanskriva",
    "sammanskrivnas": "sammanskriva",
    "sammanskrivne": "sammanskriva",
    "sammanskrivnes": "sammanskriva",
    "sammanskrivs": "sammanskriva",
    "sammansköt": "sammanskjuta",
    "sammansköte": "sammanskjuta",
    "sammanskötes": "sammanskjuta",
    "sammansköts": "sammanskjuta",
    "sammanslagen": "sammanslå",
    "sammanslagens": "sammanslagen",
    "sammanslaget": "sammanslagen",
    "sammanslagets": "sammanslagen",
    "sammanslagit": "sammanslå",
    "sammanslagits": "sammanslå",
    "sammanslagna": "sammanslagen",
    "sammanslagnare": "sammanslagen",
    "sammanslagnares": "sammanslagen",
    "sammanslagnas": "sammanslagen",
    "sammanslagnast": "sammanslagen",
    "sammanslagnaste": "sammanslagen",
    "sammanslagnastes": "sammanslagen",
    "sammanslagnasts": "sammanslagen",
    "sammanslagne": "sammanslagen",
    "sammanslagnes": "sammanslagen",
    "sammanslagningar": "sammanslagning",
    "sammanslagningarna": "sammanslagning",
    "sammanslagningarnas": "sammanslagning",
    "sammanslagningars": "sammanslagning",
    "sammanslagningen": "sammanslagning",
    "sammanslagningens": "sammanslagning",
    "sammanslagnings": "sammanslagning",
    "sammanslingrade": "sammanslingrad",
    "sammanslingrades": "sammanslingrad",
    "sammanslingrads": "sammanslingrad",
    "sammanslingrat": "sammanslingrad",
    "sammanslingrats": "sammanslingrad",
    "sammanslog": "sammanslå",
    "sammansloge": "sammanslå",
    "sammansloges": "sammanslå",
    "sammanslogs": "sammanslå",
    "sammanslutningar": "sammanslutning",
    "sammanslutningarna": "sammanslutning",
    "sammanslutningarnas": "sammanslutning",
    "sammanslutningars": "sammanslutning",
    "sammanslutningen": "sammanslutning",
    "sammanslutningens": "sammanslutning",
    "sammanslutnings": "sammanslutning",
    "sammanslående": "sammanslå",
    "sammanslåenden": "sammanslående",
    "sammanslåendena": "sammanslående",
    "sammanslåendenas": "sammanslående",
    "sammanslåendens": "sammanslående",
    "sammanslåendes": "sammanslående",
    "sammanslåendet": "sammanslående",
    "sammanslåendets": "sammanslående",
    "sammanslår": "sammanslå",
    "sammanslås": "sammanslå",
    "sammansmält": "sammansmälta",
    "sammansmältande": "sammansmälta",
    "sammansmältanden": "sammansmältande",
    "sammansmältandena": "sammansmältande",
    "sammansmältandenas": "sammansmältande",
    "sammansmältandens": "sammansmältande",
    "sammansmältandes": "sammansmältande",
    "sammansmältandet": "sammansmältande",
    "sammansmältandets": "sammansmältande",
    "sammansmältas": "sammansmälta",
    "sammansmälte": "sammansmälta",
    "sammansmälter": "sammansmälta",
    "sammansmältes": "sammansmälta",
    "sammansmältningar": "sammansmältning",
    "sammansmältningarna": "sammansmältning",
    "sammansmältningarnas": "sammansmältning",
    "sammansmältningars": "sammansmältning",
    "sammansmältningen": "sammansmältning",
    "sammansmältningens": "sammansmältning",
    "sammansmältnings": "sammansmältning",
    "sammansmälts": "sammansmälta",
    "sammanstrål": "sammanstråla",
    "sammanstrålad": "sammanstråla",
    "sammanstrålade": "sammanstråla",
    "sammanstrålades": "sammanstråla",
    "sammanstrålads": "sammanstråla",
    "sammanstrålande": "sammanstråla",
    "sammanstrålanden": "sammanstrålande",
    "sammanstrålandena": "sammanstrålande",
    "sammanstrålandenas": "sammanstrålande",
    "sammanstrålandens": "sammanstrålande",
    "sammanstrålandes": "sammanstrålande",
    "sammanstrålandet": "sammanstrålande",
    "sammanstrålandets": "sammanstrålande",
    "sammanstrålar": "sammanstråla",
    "sammanstrålas": "sammanstråla",
    "sammanstrålat": "sammanstråla",
    "sammanstrålats": "sammanstråla",
    "sammanställ": "sammanställa",
    "sammanställande": "sammanställa",
    "sammanställanden": "sammanställande",
    "sammanställandena": "sammanställande",
    "sammanställandenas": "sammanställande",
    "sammanställandens": "sammanställande",
    "sammanställandes": "sammanställande",
    "sammanställandet": "sammanställande",
    "sammanställandets": "sammanställande",
    "sammanställas": "sammanställa",
    "sammanställd": "sammanställa",
    "sammanställda": "sammanställa",
    "sammanställdas": "sammanställa",
    "sammanställde": "sammanställa",
    "sammanställdes": "sammanställa",
    "sammanställds": "sammanställa",
    "sammanställer": "sammanställa",
    "sammanställes": "sammanställa",
    "sammanställningar": "sammanställning",
    "sammanställningarna": "sammanställning",
    "sammanställningarnas": "sammanställning",
    "sammanställningars": "sammanställning",
    "sammanställningen": "sammanställning",
    "sammanställningens": "sammanställning",
    "sammanställnings": "sammanställning",
    "sammanställs": "sammanställa",
    "sammanställt": "sammanställa",
    "sammanställts": "sammanställa",
    "sammanstöt": "sammanstöta",
    "sammanstötande": "sammanstöta",
    "sammanstötanden": "sammanstötande",
    "sammanstötandena": "sammanstötande",
    "sammanstötandenas": "sammanstötande",
    "sammanstötandens": "sammanstötande",
    "sammanstötandes": "sammanstötande",
    "sammanstötandet": "sammanstötande",
    "sammanstötandets": "sammanstötande",
    "sammanstötas": "sammanstöta",
    "sammanstöter": "sammanstöta",
    "sammanstötes": "sammanstöta",
    "sammanstötningar": "sammanstötning",
    "sammanstötningarna": "sammanstötning",
    "sammanstötningarnas": "sammanstötning",
    "sammanstötningars": "sammanstötning",
    "sammanstötningen": "sammanstötning",
    "sammanstötningens": "sammanstötning",
    "sammanstötnings": "sammanstötning",
    "sammanstöts": "sammanstöta",
    "sammanstött": "sammanstöta",
    "sammanstötta": "sammanstöta",
    "sammanstöttas": "sammanstöta",
    "sammanstötte": "sammanstöta",
    "sammanstöttes": "sammanstöta",
    "sammanstötts": "sammanstöta",
    "sammansvets": "sammansvetsa",
    "sammansvetsad": "sammansvetsa",
    "sammansvetsade": "sammansvetsa",
    "sammansvetsades": "sammansvetsa",
    "sammansvetsads": "sammansvetsa",
    "sammansvetsande": "sammansvetsa",
    "sammansvetsanden": "sammansvetsande",
    "sammansvetsandena": "sammansvetsande",
    "sammansvetsandenas": "sammansvetsande",
    "sammansvetsandens": "sammansvetsande",
    "sammansvetsandes": "sammansvetsande",
    "sammansvetsandet": "sammansvetsande",
    "sammansvetsandets": "sammansvetsande",
    "sammansvetsar": "sammansvetsa",
    "sammansvetsas": "sammansvetsa",
    "sammansvetsat": "sammansvetsa",
    "sammansvetsats": "sammansvetsa",
    "sammansvurens": "sammansvuren",
    "sammansvuret": "sammansvuren",
    "sammansvurets": "sammansvuren",
    "sammansvurna": "sammansvuren",
    "sammansvurnas": "sammansvuren",
    "sammansvurne": "sammansvuren",
    "sammansvurnes": "sammansvuren",
    "sammansvärjningar": "sammansvärjning",
    "sammansvärjningarna": "sammansvärjning",
    "sammansvärjningarnas": "sammansvärjning",
    "sammansvärjningars": "sammansvärjning",
    "sammansvärjningen": "sammansvärjning",
    "sammansvärjningens": "sammansvärjning",
    "sammansvärjnings": "sammansvärjning",
    "sammansätt": "sammansätta",
    "sammansättande": "sammansätta",
    "sammansättanden": "sammansättande",
    "sammansättandena": "sammansättande",
    "sammansättandenas": "sammansättande",
    "sammansättandens": "sammansättande",
    "sammansättandes": "sammansättande",
    "sammansättandet": "sammansättande",
    "sammansättandets": "sammansättande",
    "sammansättas": "sammansätta",
    "sammansätter": "sammansätta",
    "sammansättes": "sammansätta",
    "sammansättningar": "sammansättning",
    "sammansättningarna": "sammansättning",
    "sammansättningarnas": "sammansättning",
    "sammansättningars": "sammansättning",
    "sammansättningen": "sammansättning",
    "sammansättningens": "sammansättning",
    "sammansättnings": "sammansättning",
    "sammansättningsanalysen": "sammansättningsanalys",
    "sammansättningsanalysens": "sammansättningsanalys",
    "sammansättningsanalyser": "sammansättningsanalys",
    "sammansättningsanalyserna": "sammansättningsanalys",
    "sammansättningsanalysernas": "sammansättningsanalys",
    "sammansättningsanalysers": "sammansättningsanalys",
    "sammansättningsfabriken": "sammansättningsfabrik",
    "sammansättningsfabrikens": "sammansättningsfabrik",
    "sammansättningsfabriker": "sammansättningsfabrik",
    "sammansättningsfabrikerna": "sammansättningsfabrik",
    "sammansättningsfabrikernas": "sammansättningsfabrik",
    "sammansättningsfabrikers": "sammansättningsfabrik",
    "sammansättningsfabriks": "sammansättningsfabrik",
    "sammansättningsleden": "sammansättningsled",
    "sammansättningsledens": "sammansättningsled",
    "sammansättningsleder": "sammansättningsled",
    "sammansättningslederna": "sammansättningsled",
    "sammansättningsledernas": "sammansättningsled",
    "sammansättningsleders": "sammansättningsled",
    "sammansättningsledet": "sammansättningsled",
    "sammansättningsledets": "sammansättningsled",
    "sammansättningsleds": "sammansättningsled",
    "sammansätts": "sammansätta",
    "sammantagens": "sammantagen",
    "sammantaget": "sammantagen",
    "sammantagets": "sammantagen",
    "sammantagna": "sammantagen",
    "sammantagnare": "sammantagen",
    "sammantagnares": "sammantagen",
    "sammantagnas": "sammantagen",
    "sammantagnast": "sammantagen",
    "sammantagnaste": "sammantagen",
    "sammantagnastes": "sammantagen",
    "sammantagnasts": "sammantagen",
    "sammantagne": "sammantagen",
    "sammantagnes": "sammantagen",
    "sammantryck": "sammantrycka",
    "sammantryckande": "sammantrycka",
    "sammantryckanden": "sammantryckande",
    "sammantryckandena": "sammantryckande",
    "sammantryckandenas": "sammantryckande",
    "sammantryckandens": "sammantryckande",
    "sammantryckandes": "sammantryckande",
    "sammantryckandet": "sammantryckande",
    "sammantryckandets": "sammantryckande",
    "sammantryckas": "sammantrycka",
    "sammantrycker": "sammantrycka",
    "sammantryckes": "sammantrycka",
    "sammantrycks": "sammantrycka",
    "sammantryckt": "sammantrycka",
    "sammantryckta": "sammantrycka",
    "sammantrycktas": "sammantrycka",
    "sammantryckte": "sammantrycka",
    "sammantrycktes": "sammantrycka",
    "sammantryckts": "sammantrycka",
    "sammanträd": "sammanträda",
    "sammanträdande": "sammanträda",
    "sammanträdanden": "sammanträdande",
    "sammanträdandena": "sammanträdande",
    "sammanträdandenas": "sammanträdande",
    "sammanträdandens": "sammanträdande",
    "sammanträdandes": "sammanträdande",
    "sammanträdandet": "sammanträdande",
    "sammanträdandets": "sammanträdande",
    "sammanträdas": "sammanträda",
    "sammanträdd": "sammanträda",
    "sammanträdda": "sammanträda",
    "sammanträddas": "sammanträda",
    "sammanträdde": "sammanträda",
    "sammanträddes": "sammanträda",
    "sammanträdds": "sammanträda",
    "sammanträden": "sammanträde",
    "sammanträdena": "sammanträde",
    "sammanträdenas": "sammanträde",
    "sammanträdens": "sammanträde",
    "sammanträder": "sammanträda",
    "sammanträdes": "sammanträde",
    "sammanträdesordningar": "sammanträdesordning",
    "sammanträdesordningarna": "sammanträdesordning",
    "sammanträdesordningarnas": "sammanträdesordning",
    "sammanträdesordningars": "sammanträdesordning",
    "sammanträdesordningen": "sammanträdesordning",
    "sammanträdesordningens": "sammanträdesordning",
    "sammanträdesordnings": "sammanträdesordning",
    "sammanträdesrummen": "sammanträdesrum",
    "sammanträdesrummens": "sammanträdesrum",
    "sammanträdesrummet": "sammanträdesrum",
    "sammanträdesrummets": "sammanträdesrum",
    "sammanträdesrums": "sammanträdesrum",
    "sammanträdet": "sammanträde",
    "sammanträdets": "sammanträde",
    "sammanträds": "sammanträda",
    "sammanträff": "sammanträffa",
    "sammanträffad": "sammanträffa",
    "sammanträffade": "sammanträffa",
    "sammanträffades": "sammanträffa",
    "sammanträffads": "sammanträffa",
    "sammanträffande": "sammanträffa",
    "sammanträffanden": "sammanträffande",
    "sammanträffandena": "sammanträffande",
    "sammanträffandenas": "sammanträffande",
    "sammanträffandens": "sammanträffande",
    "sammanträffandes": "sammanträffande",
    "sammanträffandet": "sammanträffande",
    "sammanträffandets": "sammanträffande",
    "sammanträffar": "sammanträffa",
    "sammanträffas": "sammanträffa",
    "sammanträffat": "sammanträffa",
    "sammanträffats": "sammanträffa",
    "sammanträtt": "sammanträda",
    "sammanträtts": "sammanträda",
    "sammanväv": "sammanväva",
    "sammanvävande": "sammanväva",
    "sammanvävanden": "sammanvävande",
    "sammanvävandena": "sammanvävande",
    "sammanvävandenas": "sammanvävande",
    "sammanvävandens": "sammanvävande",
    "sammanvävandes": "sammanvävande",
    "sammanvävandet": "sammanvävande",
    "sammanvävandets": "sammanvävande",
    "sammanvävas": "sammanväva",
    "sammanvävd": "sammanväva",
    "sammanvävda": "sammanväva",
    "sammanvävdas": "sammanväva",
    "sammanvävde": "sammanväva",
    "sammanvävdes": "sammanväva",
    "sammanvävds": "sammanväva",
    "sammanväver": "sammanväva",
    "sammanväves": "sammanväva",
    "sammanvävs": "sammanväva",
    "sammanvävt": "sammanväva",
    "sammanvävts": "sammanväva",
    "sammanväx": "sammanväxa",
    "sammanväxande": "sammanväxa",
    "sammanväxanden": "sammanväxande",
    "sammanväxandena": "sammanväxande",
    "sammanväxandenas": "sammanväxande",
    "sammanväxandens": "sammanväxande",
    "sammanväxandes": "sammanväxande",
    "sammanväxandet": "sammanväxande",
    "sammanväxandets": "sammanväxande",
    "sammanväxas": "sammanväxa",
    "sammanväxer": "sammanväxa",
    "sammanväxes": "sammanväxa",
    "sammanväxs": "sammanväxa",
    "sammanväxt": "sammanväxa",
    "sammanväxta": "sammanväxa",
    "sammanväxtas": "sammanväxa",
    "sammanväxte": "sammanväxa",
    "sammanväxtes": "sammanväxa",
    "sammanväxts": "sammanväxa",
    "sammas": "samma",
    "samme": "simma",
    "sammel": "samla",
    "sammelbanden": "sammelband",
    "sammelbandens": "sammelband",
    "sammelbandet": "sammelband",
    "sammelbandets": "sammelband",
    "sammelbands": "sammelband",
    "sammelnamnen": "sammelnamn",
    "sammelnamnens": "sammelnamn",
    "sammelnamnet": "sammelnamn",
    "sammelnamnets": "sammelnamn",
    "sammelnamns": "sammelnamn",
    "sammelplatsen": "sammelplats",
    "sammelplatsens": "sammelplats",
    "sammelplatser": "sammelplats",
    "sammelplatserna": "sammelplats",
    "sammelplatsernas": "sammelplats",
    "sammelplatsers": "sammelplats",
    "sammelsurie": "sammelsurium",
    "sammelsurier": "sammelsurium",
    "sammelsurierna": "sammelsurium",
    "sammelsuriernas": "sammelsurium",
    "sammelsuriers": "sammelsurium",
    "sammelsuriet": "sammelsurium",
    "sammelsuriets": "sammelsurium",
    "sammelsuriums": "sammelsurium",
    "sammes": "simma",
    "sammeten": "sammet",
    "sammetens": "sammet",
    "sammets": "sammet",
    "sammetsblomsterna": "sammetsblomster",
    "sammetsblomsternas": "sammetsblomster",
    "sammetsblomsters": "sammetsblomster",
    "sammetsblomstren": "sammetsblomster",
    "sammetsblomstrens": "sammetsblomster",
    "sammetsblomstret": "sammetsblomster",
    "sammetsblomstrets": "sammetsblomster",
    "sammetslena": "sammetslen",
    "sammetslenare": "sammetslen",
    "sammetslenares": "sammetslen",
    "sammetslenas": "sammetslen",
    "sammetslenast": "sammetslen",
    "sammetslenaste": "sammetslen",
    "sammetslenastes": "sammetslen",
    "sammetslenasts": "sammetslen",
    "sammetslene": "sammetslen",
    "sammetslenes": "sammetslen",
    "sammetslens": "sammetslen",
    "sammetslent": "sammetslen",
    "sammetslents": "sammetslen",
    "sammetsmjuka": "sammetsmjuk",
    "sammetsmjukare": "sammetsmjuk",
    "sammetsmjukares": "sammetsmjuk",
    "sammetsmjukas": "sammetsmjuk",
    "sammetsmjukast": "sammetsmjuk",
    "sammetsmjukaste": "sammetsmjuk",
    "sammetsmjukastes": "sammetsmjuk",
    "sammetsmjukasts": "sammetsmjuk",
    "sammetsmjuke": "sammetsmjuk",
    "sammetsmjukes": "sammetsmjuk",
    "sammetsmjukheten": "sammetsmjukhet",
    "sammetsmjukhetens": "sammetsmjukhet",
    "sammetsmjukhets": "sammetsmjukhet",
    "sammetsmjuks": "sammetsmjuk",
    "sammetsmjukt": "sammetsmjuk",
    "sammetsmjukts": "sammetsmjuk",
    "sammälden": "sammäld",
    "sammäldens": "sammäld",
    "sammälds": "sammäld",
    "samniten": "samnit",
    "samnitens": "samnit",
    "samniter": "samnit",
    "samniterna": "samnit",
    "samniternas": "samnit",
    "samniters": "samnit",
    "samnits": "samnit",
    "samnordiska": "samnordisk",
    "samnordiskare": "samnordisk",
    "samnordiskares": "samnordisk",
    "samnordiskas": "samnordisk",
    "samnordiskast": "samnordisk",
    "samnordiskaste": "samnordisk",
    "samnordiskastes": "samnordisk",
    "samnordiskasts": "samnordisk",
    "samnordiske": "samnordisk",
    "samnordiskes": "samnordisk",
    "samnordisks": "samnordisk",
    "samnordiskt": "samnordisk",
    "samnordiskts": "samnordisk",
    "samoanen": "samoan",
    "samoanens": "samoan",
    "samoaner": "samoan",
    "samoanerna": "samoan",
    "samoanernas": "samoan",
    "samoaners": "samoan",
    "samoans": "samoan",
    "samoansk": "samoanska",
    "samoanskan": "samoanska",
    "samoanskans": "samoanska",
    "samoanskas": "samoanska",
    "samoanske": "samoanska",
    "samoanskor": "samoanska",
    "samoanskorna": "samoanska",
    "samoanskornas": "samoanska",
    "samoanskors": "samoanska",
    "samojeden": "samojed",
    "samojedens": "samojed",
    "samojeder": "samojed",
    "samojederna": "samojed",
    "samojedernas": "samojed",
    "samojeders": "samojed",
    "samojedisk": "samojediska",
    "samojediskan": "samojediska",
    "samojediskans": "samojediska",
    "samojediskas": "samojediska",
    "samojeds": "samojed",
    "samordnad": "samordna",
    "samordnade": "samordna",
    "samordnades": "samordna",
    "samordnads": "samordna",
    "samordnande": "samordna",
    "samordnanden": "samordnande",
    "samordnandena": "samordnande",
    "samordnandenas": "samordnande",
    "samordnandens": "samordnande",
    "samordnandes": "samordnande",
    "samordnandet": "samordnande",
    "samordnandets": "samordnande",
    "samordnar": "samordnare",
    "samordnaren": "samordnare",
    "samordnarens": "samordnare",
    "samordnares": "samordnare",
    "samordnarna": "samordnare",
    "samordnarnas": "samordnare",
    "samordnas": "samordna",
    "samordnat": "samordna",
    "samordnats": "samordna",
    "samordningar": "samordning",
    "samordningarna": "samordning",
    "samordningarnas": "samordning",
    "samordningars": "samordning",
    "samordningen": "samordning",
    "samordningens": "samordning",
    "samordnings": "samordning",
    "samordningsansvaret": "samordningsansvar",
    "samordningsansvarets": "samordningsansvar",
    "samordningsansvars": "samordningsansvar",
    "samovaren": "samovar",
    "samovarens": "samovar",
    "samovarer": "samovar",
    "samovarerna": "samovar",
    "samovarernas": "samovar",
    "samovarers": "samovar",
    "samovars": "samovar",
    "sampanen": "sampan",
    "sampanens": "sampan",
    "sampaner": "sampan",
    "sampanerna": "sampan",
    "sampanernas": "sampan",
    "sampaners": "sampan",
    "sampans": "sampan",
    "sampel": "sampla",
    "sampels": "sampel",
    "samplad": "sampla",
    "samplade": "sampla",
    "samplades": "sampla",
    "samplads": "sampla",
    "samplande": "sampla",
    "samplanden": "samplande",
    "samplandena": "samplande",
    "samplandenas": "samplande",
    "samplandens": "samplande",
    "samplandes": "samplande",
    "samplandet": "samplande",
    "samplandets": "samplande",
    "samplar": "sampla",
    "samplas": "sampla",
    "samplat": "sampla",
    "samplats": "sampla",
    "samplen": "sampel",
    "samplens": "sampel",
    "samplet": "sampel",
    "samplets": "sampel",
    "samplingar": "sampling",
    "samplingarna": "sampling",
    "samplingarnas": "sampling",
    "samplingars": "sampling",
    "samplingen": "sampling",
    "samplingens": "sampling",
    "samplings": "sampling",
    "samråd": "samråda",
    "samrådande": "samråda",
    "samrådanden": "samrådande",
    "samrådandena": "samrådande",
    "samrådandenas": "samrådande",
    "samrådandens": "samrådande",
    "samrådandes": "samrådande",
    "samrådandet": "samrådande",
    "samrådandets": "samrådande",
    "samrådas": "samråda",
    "samrådd": "samråda",
    "samrådda": "samråda",
    "samråddas": "samråda",
    "samrådde": "samråda",
    "samråddes": "samråda",
    "samrådds": "samråda",
    "samråden": "samråd",
    "samrådens": "samråd",
    "samråder": "samråda",
    "samrådes": "samråda",
    "samrådet": "samråd",
    "samrådets": "samråd",
    "samråds": "samråda",
    "samrått": "samråda",
    "samråtts": "samråda",
    "samröres": "samröre",
    "samröret": "samröre",
    "samrörets": "samröre",
    "sams": "simma",
    "samsad": "samsa",
    "samsade": "samsa",
    "samsades": "samsas",
    "samsads": "samsa",
    "samsande": "samsa",
    "samsanden": "samsande",
    "samsandena": "samsande",
    "samsandenas": "samsande",
    "samsandens": "samsande",
    "samsandes": "samsande",
    "samsandet": "samsande",
    "samsandets": "samsande",
    "samsar": "samsa",
    "samsaran": "samsara",
    "samsarans": "samsara",
    "samsaras": "samsara",
    "samsas": "samsa",
    "samsat": "samsa",
    "samsats": "samsas",
    "samsikten": "samsikt",
    "samsiktens": "samsikt",
    "samsikts": "samsikt",
    "samskolan": "samskola",
    "samskolans": "samskola",
    "samskolas": "samskola",
    "samskole": "samskola",
    "samskolor": "samskola",
    "samskolorna": "samskola",
    "samskolornas": "samskola",
    "samskolors": "samskola",
    "samspelade": "samspela",
    "samspelades": "samspela",
    "samspelande": "samspela",
    "samspelanden": "samspelande",
    "samspelandena": "samspelande",
    "samspelandenas": "samspelande",
    "samspelandens": "samspelande",
    "samspelandes": "samspelande",
    "samspelandet": "samspelande",
    "samspelandets": "samspelande",
    "samspelar": "samspela",
    "samspelas": "samspela",
    "samspelat": "samspela",
    "samspelats": "samspela",
    "samspelet": "samspel",
    "samspelets": "samspel",
    "samspels": "samspel",
    "samspelta": "samspelt",
    "samspeltare": "samspelt",
    "samspeltares": "samspelt",
    "samspeltas": "samspelt",
    "samspeltast": "samspelt",
    "samspeltaste": "samspelt",
    "samspeltastes": "samspelt",
    "samspeltasts": "samspelt",
    "samspelte": "samspelt",
    "samspeltes": "samspelt",
    "samspeltheten": "samspelthet",
    "samspelthetens": "samspelthet",
    "samspelthets": "samspelthet",
    "samspelts": "samspelt",
    "samspråkade": "samspråka",
    "samspråkades": "samspråka",
    "samspråkande": "samspråka",
    "samspråkanden": "samspråkande",
    "samspråkandena": "samspråkande",
    "samspråkandenas": "samspråkande",
    "samspråkandens": "samspråkande",
    "samspråkandes": "samspråkande",
    "samspråkandet": "samspråkande",
    "samspråkandets": "samspråkande",
    "samspråkar": "samspråka",
    "samspråkas": "samspråka",
    "samspråkat": "samspråka",
    "samspråkats": "samspråka",
    "samspråket": "samspråk",
    "samspråkets": "samspråk",
    "samspråks": "samspråk",
    "samstämda": "samstämd",
    "samstämdare": "samstämd",
    "samstämdares": "samstämd",
    "samstämdas": "samstämd",
    "samstämdast": "samstämd",
    "samstämdaste": "samstämd",
    "samstämdastes": "samstämd",
    "samstämdasts": "samstämd",
    "samstämde": "samstämd",
    "samstämdes": "samstämd",
    "samstämdheten": "samstämdhet",
    "samstämdhetens": "samstämdhet",
    "samstämdhets": "samstämdhet",
    "samstämds": "samstämd",
    "samstämmiga": "samstämmig",
    "samstämmigare": "samstämmig",
    "samstämmigares": "samstämmig",
    "samstämmigas": "samstämmig",
    "samstämmigast": "samstämmig",
    "samstämmigaste": "samstämmig",
    "samstämmigastes": "samstämmig",
    "samstämmigasts": "samstämmig",
    "samstämmige": "samstämmig",
    "samstämmiges": "samstämmig",
    "samstämmigheten": "samstämmighet",
    "samstämmighetens": "samstämmighet",
    "samstämmighets": "samstämmighet",
    "samstämmigs": "samstämmig",
    "samstämmigt": "samstämmig",
    "samstämmigts": "samstämmig",
    "samstämt": "samstämd",
    "samstämts": "samstämd",
    "samsun": "samsu",
    "samsuns": "samsu",
    "samsus": "samsu",
    "samsyskonen": "samsyskon",
    "samsyskonens": "samsyskon",
    "samsyskonet": "samsyskon",
    "samsyskonets": "samsyskon",
    "samsyskons": "samsyskon",
    "samsändningar": "samsändning",
    "samsändningarna": "samsändning",
    "samsändningarnas": "samsändning",
    "samsändningars": "samsändning",
    "samsändningen": "samsändning",
    "samsändningens": "samsändning",
    "samsändnings": "samsändning",
    "samtalade": "samtala",
    "samtalades": "samtala",
    "samtalande": "samtala",
    "samtalanden": "samtalande",
    "samtalandena": "samtalande",
    "samtalandenas": "samtalande",
    "samtalandens": "samtalande",
    "samtalandes": "samtalande",
    "samtalandet": "samtalande",
    "samtalandets": "samtalande",
    "samtalar": "samtala",
    "samtalas": "samtala",
    "samtalat": "samtala",
    "samtalats": "samtala",
    "samtalen": "samtal",
    "samtalens": "samtal",
    "samtalet": "samtal",
    "samtalets": "samtal",
    "samtals": "samtal",
    "samtalsavgiften": "samtalsavgift",
    "samtalsavgiftens": "samtalsavgift",
    "samtalsavgifter": "samtalsavgift",
    "samtalsavgifterna": "samtalsavgift",
    "samtalsavgifternas": "samtalsavgift",
    "samtalsavgifters": "samtalsavgift",
    "samtalsavgifts": "samtalsavgift",
    "samtalsgruppen": "samtalsgrupp",
    "samtalsgruppens": "samtalsgrupp",
    "samtalsgrupper": "samtalsgrupp",
    "samtalsgrupperna": "samtalsgrupp",
    "samtalsgruppernas": "samtalsgrupp",
    "samtalsgruppers": "samtalsgrupp",
    "samtalsgrupps": "samtalsgrupp",
    "samtalslägen": "samtalsläge",
    "samtalslägena": "samtalsläge",
    "samtalslägenas": "samtalsläge",
    "samtalslägens": "samtalsläge",
    "samtalsläges": "samtalsläge",
    "samtalsläget": "samtalsläge",
    "samtalslägets": "samtalsläge",
    "samtalsmarkeringar": "samtalsmarkering",
    "samtalsmarkeringarna": "samtalsmarkering",
    "samtalsmarkeringarnas": "samtalsmarkering",
    "samtalsmarkeringars": "samtalsmarkering",
    "samtalsmarkeringen": "samtalsmarkering",
    "samtalsmarkeringens": "samtalsmarkering",
    "samtalsmarkerings": "samtalsmarkering",
    "samtalsmätar": "samtalsmätare",
    "samtalsmätaren": "samtalsmätare",
    "samtalsmätarens": "samtalsmätare",
    "samtalsmätares": "samtalsmätare",
    "samtalsmätarna": "samtalsmätare",
    "samtalsmätarnas": "samtalsmätare",
    "samtalsperioden": "samtalsperiod",
    "samtalsperiodens": "samtalsperiod",
    "samtalsperioder": "samtalsperiod",
    "samtalsperioderna": "samtalsperiod",
    "samtalsperiodernas": "samtalsperiod",
    "samtalsperioders": "samtalsperiod",
    "samtalsperiods": "samtalsperiod",
    "samtalsrummen": "samtalsrum",
    "samtalsrummens": "samtalsrum",
    "samtalsrummet": "samtalsrum",
    "samtalsrummets": "samtalsrum",
    "samtalsrums": "samtalsrum",
    "samtalsräknar": "samtalsräknare",
    "samtalsräknaren": "samtalsräknare",
    "samtalsräknarens": "samtalsräknare",
    "samtalsräknares": "samtalsräknare",
    "samtalsräknarna": "samtalsräknare",
    "samtalsräknarnas": "samtalsräknare",
    "samtalsspråket": "samtalsspråk",
    "samtalsspråkets": "samtalsspråk",
    "samtalsspråks": "samtalsspråk",
    "samtalsterapien": "samtalsterapi",
    "samtalsterapiens": "samtalsterapi",
    "samtalsterapin": "samtalsterapi",
    "samtalsterapins": "samtalsterapi",
    "samtalsterapis": "samtalsterapi",
    "samtalstonen": "samtalston",
    "samtalstonens": "samtalston",
    "samtalstons": "samtalston",
    "samtalsämnen": "samtalsämne",
    "samtalsämnena": "samtalsämne",
    "samtalsämnenas": "samtalsämne",
    "samtalsämnens": "samtalsämne",
    "samtalsämnes": "samtalsämne",
    "samtalsämnet": "samtalsämne",
    "samtalsämnets": "samtalsämne",
    "samtaxerad": "samtaxera",
    "samtaxerade": "samtaxera",
    "samtaxerades": "samtaxera",
    "samtaxerads": "samtaxera",
    "samtaxerande": "samtaxera",
    "samtaxeranden": "samtaxerande",
    "samtaxerandena": "samtaxerande",
    "samtaxerandenas": "samtaxerande",
    "samtaxerandens": "samtaxerande",
    "samtaxerandes": "samtaxerande",
    "samtaxerandet": "samtaxerande",
    "samtaxerandets": "samtaxerande",
    "samtaxerar": "samtaxera",
    "samtaxeras": "samtaxera",
    "samtaxerat": "samtaxera",
    "samtaxerats": "samtaxera",
    "samtaxerbara": "samtaxerbar",
    "samtaxerbarare": "samtaxerbar",
    "samtaxerbarares": "samtaxerbar",
    "samtaxerbaras": "samtaxerbar",
    "samtaxerbarast": "samtaxerbar",
    "samtaxerbaraste": "samtaxerbar",
    "samtaxerbarastes": "samtaxerbar",
    "samtaxerbarasts": "samtaxerbar",
    "samtaxerbare": "samtaxerbar",
    "samtaxerbares": "samtaxerbar",
    "samtaxerbarheten": "samtaxerbarhet",
    "samtaxerbarhetens": "samtaxerbarhet",
    "samtaxerbarhets": "samtaxerbarhet",
    "samtaxerbars": "samtaxerbar",
    "samtaxerbart": "samtaxerbar",
    "samtaxerbarts": "samtaxerbar",
    "samtaxeringar": "samtaxering",
    "samtaxeringarna": "samtaxering",
    "samtaxeringarnas": "samtaxering",
    "samtaxeringars": "samtaxering",
    "samtaxeringen": "samtaxering",
    "samtaxeringens": "samtaxering",
    "samtaxerings": "samtaxering",
    "samtiden": "samtid",
    "samtidens": "samtid",
    "samtidiga": "samtidig",
    "samtidigare": "samtidig",
    "samtidigares": "samtidig",
    "samtidigas": "samtidig",
    "samtidigast": "samtidig",
    "samtidigaste": "samtidig",
    "samtidigastes": "samtidig",
    "samtidigasts": "samtidig",
    "samtidige": "samtidig",
    "samtidiges": "samtidig",
    "samtidigheten": "samtidighet",
    "samtidighetens": "samtidighet",
    "samtidigheter": "samtidighet",
    "samtidigheterna": "samtidighet",
    "samtidigheternas": "samtidighet",
    "samtidigheters": "samtidighet",
    "samtidighets": "samtidighet",
    "samtidigs": "samtidig",
    "samtidigt": "samtidig",
    "samtidigts": "samtidig",
    "samtids": "samtid",
    "samtidshistorian": "samtidshistoria",
    "samtidshistorians": "samtidshistoria",
    "samtidshistorias": "samtidshistoria",
    "samtidshistorien": "samtidshistoria",
    "samtidshistoriens": "samtidshistoria",
    "samtidsmiljöer": "samtidsmiljö",
    "samtidsmiljöerna": "samtidsmiljö",
    "samtidsmiljöernas": "samtidsmiljö",
    "samtidsmiljöers": "samtidsmiljö",
    "samtidsmiljön": "samtidsmiljö",
    "samtidsmiljöns": "samtidsmiljö",
    "samtidsmiljös": "samtidsmiljö",
    "samtidsskildringar": "samtidsskildring",
    "samtidsskildringarna": "samtidsskildring",
    "samtidsskildringarnas": "samtidsskildring",
    "samtidsskildringars": "samtidsskildring",
    "samtidsskildringen": "samtidsskildring",
    "samtidsskildringens": "samtidsskildring",
    "samtidsskildrings": "samtidsskildring",
    "samtliga": "samtlig",
    "samtligas": "samtlig",
    "samtligs": "samtlig",
    "samtligt": "samtlig",
    "samtligts": "samtlig",
    "samtrafiken": "samtrafik",
    "samtrafikens": "samtrafik",
    "samtrafiks": "samtrafik",
    "samtyck": "samtycka",
    "samtyckande": "samtycka",
    "samtyckanden": "samtyckande",
    "samtyckandena": "samtyckande",
    "samtyckandenas": "samtyckande",
    "samtyckandens": "samtyckande",
    "samtyckandes": "samtyckande",
    "samtyckandet": "samtyckande",
    "samtyckandets": "samtyckande",
    "samtyckas": "samtycka",
    "samtycken": "samtycke",
    "samtyckena": "samtycke",
    "samtyckenas": "samtycke",
    "samtyckens": "samtycke",
    "samtycker": "samtycka",
    "samtyckes": "samtycke",
    "samtycket": "samtycke",
    "samtyckets": "samtycke",
    "samtycks": "samtycke",
    "samtyckt": "samtycka",
    "samtyckte": "samtycka",
    "samtycktes": "samtycka",
    "samtyckts": "samtycka",
    "samumen": "samum",
    "samumens": "samum",
    "samums": "samum",
    "samurajen": "samuraj",
    "samurajens": "samuraj",
    "samurajer": "samuraj",
    "samurajerna": "samuraj",
    "samurajernas": "samuraj",
    "samurajers": "samuraj",
    "samurajs": "samuraj",
    "samurajsvärden": "samurajsvärd",
    "samurajsvärdens": "samurajsvärd",
    "samurajsvärdet": "samurajsvärd",
    "samurajsvärdets": "samurajsvärd",
    "samurajsvärds": "samurajsvärd",
    "samvar": "samvara",
    "samvarade": "samvara",
    "samvarades": "samvara",
    "samvarande": "samvara",
    "samvaranden": "samvarande",
    "samvarandena": "samvarande",
    "samvarandenas": "samvarande",
    "samvarandens": "samvarande",
    "samvarandes": "samvarande",
    "samvarandet": "samvarande",
    "samvarandets": "samvarande",
    "samvarar": "samvara",
    "samvaras": "samvara",
    "samvariationen": "samvariation",
    "samvariationens": "samvariation",
    "samvariationer": "samvariation",
    "samvariationerna": "samvariation",
    "samvariationernas": "samvariation",
    "samvariationers": "samvariation",
    "samvariations": "samvariation",
    "samvarit": "samvara",
    "samvarits": "samvara",
    "samvaron": "samvaro",
    "samvarons": "samvaro",
    "samvaros": "samvaro",
    "samverkade": "samverka",
    "samverkades": "samverka",
    "samverkande": "samverka",
    "samverkanden": "samverkande",
    "samverkandena": "samverkande",
    "samverkandenas": "samverkande",
    "samverkandens": "samverkande",
    "samverkandes": "samverkande",
    "samverkandet": "samverkande",
    "samverkandets": "samverkande",
    "samverkans": "samverkan",
    "samverkar": "samverka",
    "samverkas": "samverka",
    "samverkat": "samverka",
    "samverkats": "samverka",
    "samveten": "samvete",
    "samvetena": "samvete",
    "samvetenas": "samvete",
    "samvetens": "samvete",
    "samvetes": "samvete",
    "samvetet": "samvete",
    "samvetets": "samvete",
    "samvets": "samvete",
    "samvetsattacken": "samvetsattack",
    "samvetsattackens": "samvetsattack",
    "samvetsattacker": "samvetsattack",
    "samvetsattackerna": "samvetsattack",
    "samvetsattackernas": "samvetsattack",
    "samvetsattackers": "samvetsattack",
    "samvetsattacks": "samvetsattack",
    "samvetsbetänkligheten": "samvetsbetänklighet",
    "samvetsbetänklighetens": "samvetsbetänklighet",
    "samvetsbetänkligheter": "samvetsbetänklighet",
    "samvetsbetänkligheterna": "samvetsbetänklighet",
    "samvetsbetänkligheternas": "samvetsbetänklighet",
    "samvetsbetänkligheters": "samvetsbetänklighet",
    "samvetsbetänklighets": "samvetsbetänklighet",
    "samvetsfriden": "samvetsfrid",
    "samvetsfridens": "samvetsfrid",
    "samvetsfrids": "samvetsfrid",
    "samvetsfriheten": "samvetsfrihet",
    "samvetsfrihetens": "samvetsfrihet",
    "samvetsfriheter": "samvetsfrihet",
    "samvetsfriheterna": "samvetsfrihet",
    "samvetsfriheternas": "samvetsfrihet",
    "samvetsfriheters": "samvetsfrihet",
    "samvetsfrihets": "samvetsfrihet",
    "samvetsfrågan": "samvetsfråga",
    "samvetsfrågans": "samvetsfråga",
    "samvetsfrågas": "samvetsfråga",
    "samvetsfråge": "samvetsfråga",
    "samvetsfrågor": "samvetsfråga",
    "samvetsfrågorna": "samvetsfråga",
    "samvetsfrågornas": "samvetsfråga",
    "samvetsfrågors": "samvetsfråga",
    "samvetsfångar": "samvetsfånge",
    "samvetsfångarna": "samvetsfånge",
    "samvetsfångarnas": "samvetsfånge",
    "samvetsfångars": "samvetsfånge",
    "samvetsfången": "samvetsfånge",
    "samvetsfångens": "samvetsfånge",
    "samvetsfånges": "samvetsfånge",
    "samvetsförebråelsen": "samvetsförebråelse",
    "samvetsförebråelsens": "samvetsförebråelse",
    "samvetsförebråelser": "samvetsförebråelse",
    "samvetsförebråelserna": "samvetsförebråelse",
    "samvetsförebråelsernas": "samvetsförebråelse",
    "samvetsförebråelsers": "samvetsförebråelse",
    "samvetsförebråelses": "samvetsförebråelse",
    "samvetsgranna": "samvetsgrann",
    "samvetsgrannare": "samvetsgrann",
    "samvetsgrannares": "samvetsgrann",
    "samvetsgrannas": "samvetsgrann",
    "samvetsgrannast": "samvetsgrann",
    "samvetsgrannaste": "samvetsgrann",
    "samvetsgrannastes": "samvetsgrann",
    "samvetsgrannasts": "samvetsgrann",
    "samvetsgranne": "samvetsgrann",
    "samvetsgrannes": "samvetsgrann",
    "samvetsgrannheten": "samvetsgrannhet",
    "samvetsgrannhetens": "samvetsgrannhet",
    "samvetsgrannhets": "samvetsgrannhet",
    "samvetsgranns": "samvetsgrann",
    "samvetsgrant": "samvetsgrann",
    "samvetsgrants": "samvetsgrann",
    "samvetskonflikten": "samvetskonflikt",
    "samvetskonfliktens": "samvetskonflikt",
    "samvetskonflikter": "samvetskonflikt",
    "samvetskonflikterna": "samvetskonflikt",
    "samvetskonflikternas": "samvetskonflikt",
    "samvetskonflikters": "samvetskonflikt",
    "samvetskonflikts": "samvetskonflikt",
    "samvetskvalen": "samvetskval",
    "samvetskvalens": "samvetskval",
    "samvetskvalet": "samvetskval",
    "samvetskvalets": "samvetskval",
    "samvetskvals": "samvetskval",
    "samvetslösa": "samvetslös",
    "samvetslösare": "samvetslös",
    "samvetslösares": "samvetslös",
    "samvetslösas": "samvetslös",
    "samvetslösast": "samvetslös",
    "samvetslösaste": "samvetslös",
    "samvetslösastes": "samvetslös",
    "samvetslösasts": "samvetslös",
    "samvetslöse": "samvetslös",
    "samvetslöses": "samvetslös",
    "samvetslösheten": "samvetslöshet",
    "samvetslöshetens": "samvetslöshet",
    "samvetslösheter": "samvetslöshet",
    "samvetslösheterna": "samvetslöshet",
    "samvetslösheternas": "samvetslöshet",
    "samvetslösheters": "samvetslöshet",
    "samvetslöshets": "samvetslöshet",
    "samvetslöst": "samvetslös",
    "samvetslösts": "samvetslös",
    "samvetsnöden": "samvetsnöd",
    "samvetsnödens": "samvetsnöd",
    "samvetsnöds": "samvetsnöd",
    "samvetspengar": "samvetspeng",
    "samvetspengarna": "samvetspeng",
    "samvetspengarnas": "samvetspeng",
    "samvetspengars": "samvetspeng",
    "samvetspengen": "samvetspeng",
    "samvetspengens": "samvetspeng",
    "samvetspengs": "samvetspeng",
    "samvetsron": "samvetsro",
    "samvetsrons": "samvetsro",
    "samvetsros": "samvetsro",
    "samvetssaken": "samvetssak",
    "samvetssakens": "samvetssak",
    "samvetssaker": "samvetssak",
    "samvetssakerna": "samvetssak",
    "samvetssakernas": "samvetssak",
    "samvetssakers": "samvetssak",
    "samvetssaks": "samvetssak",
    "samvetsskälen": "samvetsskäl",
    "samvetsskälens": "samvetsskäl",
    "samvetsskälet": "samvetsskäl",
    "samvetsskälets": "samvetsskäl",
    "samvetsskäls": "samvetsskäl",
    "samvetsstyngen": "samvetsstyng",
    "samvetsstyngens": "samvetsstyng",
    "samvetsstynget": "samvetsstyng",
    "samvetsstyngets": "samvetsstyng",
    "samvetsstyngs": "samvetsstyng",
    "samvetstvånget": "samvetstvång",
    "samvetstvångets": "samvetstvång",
    "samvetstvångs": "samvetstvång",
    "samvetsäktenskapen": "samvetsäktenskap",
    "samvetsäktenskapens": "samvetsäktenskap",
    "samvetsäktenskapet": "samvetsäktenskap",
    "samvetsäktenskapets": "samvetsäktenskap",
    "samvetsäktenskaps": "samvetsäktenskap",
    "samvetsömheten": "samvetsömhet",
    "samvetsömhetens": "samvetsömhet",
    "samvetsömhets": "samvetsömhet",
    "samvetsömma": "samvetsöm",
    "samvetsömmare": "samvetsöm",
    "samvetsömmares": "samvetsöm",
    "samvetsömmas": "samvetsöm",
    "samvetsömmast": "samvetsöm",
    "samvetsömmaste": "samvetsöm",
    "samvetsömmastes": "samvetsöm",
    "samvetsömmasts": "samvetsöm",
    "samvetsömme": "samvetsöm",
    "samvetsömmes": "samvetsöm",
    "samvetsöms": "samvetsöm",
    "samvetsömt": "samvetsöm",
    "samvetsömts": "samvetsöm",
    "samvälden": "samvälde",
    "samväldena": "samvälde",
    "samväldenas": "samvälde",
    "samväldens": "samvälde",
    "samväldes": "samvälde",
    "samväldet": "samvälde",
    "samväldets": "samvälde",
    "samägandes": "samägande",
    "samägandet": "samägande",
    "samägandets": "samägande",
    "samåk": "samåka",
    "samåkande": "samåka",
    "samåkanden": "samåkande",
    "samåkandena": "samåkande",
    "samåkandenas": "samåkande",
    "samåkandens": "samåkande",
    "samåkandes": "samåkande",
    "samåkandet": "samåkande",
    "samåkandets": "samåkande",
    "samåkas": "samåka",
    "samåker": "samåka",
    "samåkes": "samåka",
    "samåks": "samåka",
    "samåkt": "samåka",
    "samåkte": "samåka",
    "samåktes": "samåka",
    "samåkts": "samåka",
    "sanatorie": "sanatorium",
    "sanatorier": "sanatorium",
    "sanatorierna": "sanatorium",
    "sanatoriernas": "sanatorium",
    "sanatoriers": "sanatorium",
    "sanatoriet": "sanatorium",
    "sanatoriets": "sanatorium",
    "sanatoriums": "sanatorium",
    "sand": "sanda",
    "sandad": "sanda",
    "sandade": "sanda",
    "sandades": "sanda",
    "sandads": "sanda",
    "sandalen": "sandal",
    "sandalens": "sandal",
    "sandaler": "sandal",
    "sandalerna": "sandal",
    "sandalernas": "sandal",
    "sandalers": "sandal",
    "sandaletten": "sandalett",
    "sandalettens": "sandalett",
    "sandaletter": "sandalett",
    "sandaletterna": "sandalett",
    "sandaletternas": "sandalett",
    "sandaletters": "sandalett",
    "sandaletts": "sandalett",
    "sandals": "sandal",
    "sandande": "sanda",
    "sandanden": "sandande",
    "sandandena": "sandande",
    "sandandenas": "sandande",
    "sandandens": "sandande",
    "sandandes": "sandande",
    "sandandet": "sandande",
    "sandandets": "sandande",
    "sandar": "sanda",
    "sandas": "sanda",
    "sandat": "sanda",
    "sandats": "sanda",
    "sandbaden": "sandbad",
    "sandbadens": "sandbad",
    "sandbadet": "sandbad",
    "sandbadets": "sandbad",
    "sandbads": "sandbad",
    "sandbakelsen": "sandbakelse",
    "sandbakelsens": "sandbakelse",
    "sandbakelser": "sandbakelse",
    "sandbakelserna": "sandbakelse",
    "sandbakelsernas": "sandbakelse",
    "sandbakelsers": "sandbakelse",
    "sandbakelses": "sandbakelse",
    "sandbankar": "sandbank",
    "sandbankarna": "sandbank",
    "sandbankarnas": "sandbank",
    "sandbankars": "sandbank",
    "sandbanken": "sandbank",
    "sandbankens": "sandbank",
    "sandbanks": "sandbank",
    "sandbindar": "sandbindare",
    "sandbindaren": "sandbindare",
    "sandbindarens": "sandbindare",
    "sandbindares": "sandbindare",
    "sandbindarna": "sandbindare",
    "sandbindarnas": "sandbindare",
    "sandblandade": "sandblandad",
    "sandblandades": "sandblandad",
    "sandblandads": "sandblandad",
    "sandblandat": "sandblandad",
    "sandblandats": "sandblandad",
    "sandblästern": "sandbläster",
    "sandblästerns": "sandbläster",
    "sandblästers": "sandbläster",
    "sandblästrad": "sandblästra",
    "sandblästrade": "sandblästra",
    "sandblästrades": "sandblästra",
    "sandblästrads": "sandblästra",
    "sandblästrande": "sandblästra",
    "sandblästranden": "sandblästrande",
    "sandblästrandena": "sandblästrande",
    "sandblästrandenas": "sandblästrande",
    "sandblästrandens": "sandblästrande",
    "sandblästrandes": "sandblästrande",
    "sandblästrandet": "sandblästrande",
    "sandblästrandets": "sandblästrande",
    "sandblästrar": "sandblästra",
    "sandblästrarna": "sandbläster",
    "sandblästrarnas": "sandbläster",
    "sandblästrars": "sandbläster",
    "sandblästras": "sandblästra",
    "sandblästrat": "sandblästra",
    "sandblästrats": "sandblästra",
    "sandblästringar": "sandblästring",
    "sandblästringarna": "sandblästring",
    "sandblästringarnas": "sandblästring",
    "sandblästringars": "sandblästring",
    "sandblästringen": "sandblästring",
    "sandblästringens": "sandblästring",
    "sandblästrings": "sandblästring",
    "sandbottens": "sandbotten",
    "sandbottnar": "sandbotten",
    "sandbottnarna": "sandbotten",
    "sandbottnarnas": "sandbotten",
    "sandbottnars": "sandbotten",
    "sandbottnen": "sandbotten",
    "sandbottnens": "sandbotten",
    "sandbruna": "sandbrun",
    "sandbrunare": "sandbrun",
    "sandbrunares": "sandbrun",
    "sandbrunas": "sandbrun",
    "sandbrunast": "sandbrun",
    "sandbrunaste": "sandbrun",
    "sandbrunastes": "sandbrun",
    "sandbrunasts": "sandbrun",
    "sandbrune": "sandbrun",
    "sandbrunes": "sandbrun",
    "sandbruns": "sandbrun",
    "sandbrunt": "sandbrun",
    "sandbrunts": "sandbrun",
    "sanddynen": "sanddyn",
    "sanddynens": "sanddyn",
    "sanddyner": "sanddyn",
    "sanddynerna": "sanddyn",
    "sanddynernas": "sanddyn",
    "sanddyners": "sanddyn",
    "sanddyns": "sanddyn",
    "sandeln": "sandel",
    "sandelns": "sandel",
    "sandeloljan": "sandelolja",
    "sandeloljans": "sandelolja",
    "sandeloljas": "sandelolja",
    "sandelolje": "sandelolja",
    "sandels": "sandel",
    "sandelträden": "sandelträd",
    "sandelträdens": "sandelträd",
    "sandelträdet": "sandelträd",
    "sandelträdets": "sandelträd",
    "sandelträds": "sandelträd",
    "sandelträet": "sandelträ",
    "sandelträets": "sandelträ",
    "sandelträs": "sandelträ",
    "sandelträt": "sandelträ",
    "sandelträts": "sandelträ",
    "sanden": "sand",
    "sandens": "sand",
    "sandflug": "sandfluga",
    "sandflugan": "sandfluga",
    "sandflugans": "sandfluga",
    "sandflugas": "sandfluga",
    "sandfluge": "sandfluga",
    "sandflugebetten": "sandflugebett",
    "sandflugebettens": "sandflugebett",
    "sandflugebettet": "sandflugebett",
    "sandflugebettets": "sandflugebett",
    "sandflugebetts": "sandflugebett",
    "sandflugor": "sandfluga",
    "sandflugorna": "sandfluga",
    "sandflugornas": "sandfluga",
    "sandflugors": "sandfluga",
    "sandflugs": "sandfluga",
    "sandflundran": "sandflundra",
    "sandflundrans": "sandflundra",
    "sandflundras": "sandflundra",
    "sandflundre": "sandflundra",
    "sandflundror": "sandflundra",
    "sandflundrorna": "sandflundra",
    "sandflundrornas": "sandflundra",
    "sandflundrors": "sandflundra",
    "sandflykten": "sandflykt",
    "sandflyktens": "sandflykt",
    "sandflykts": "sandflykt",
    "sandformar": "sandform",
    "sandformarna": "sandform",
    "sandformarnas": "sandform",
    "sandformars": "sandform",
    "sandformen": "sandform",
    "sandformens": "sandform",
    "sandforms": "sandform",
    "sandfärgade": "sandfärgad",
    "sandfärgades": "sandfärgad",
    "sandfärgads": "sandfärgad",
    "sandfärgat": "sandfärgad",
    "sandfärgats": "sandfärgad",
    "sandhavren": "sandhavre",
    "sandhavrens": "sandhavre",
    "sandhavres": "sandhavre",
    "sandhedar": "sandhed",
    "sandhedarna": "sandhed",
    "sandhedarnas": "sandhed",
    "sandhedars": "sandhed",
    "sandheden": "sandhed",
    "sandhedens": "sandhed",
    "sandheds": "sandhed",
    "sandhin": "sandhi",
    "sandhins": "sandhi",
    "sandhis": "sandhi",
    "sandiga": "sandig",
    "sandigare": "sandig",
    "sandigares": "sandig",
    "sandigas": "sandig",
    "sandigast": "sandig",
    "sandigaste": "sandig",
    "sandigastes": "sandig",
    "sandigasts": "sandig",
    "sandige": "sandig",
    "sandiges": "sandig",
    "sandigheten": "sandighet",
    "sandighetens": "sandighet",
    "sandighets": "sandighet",
    "sandigs": "sandig",
    "sandigt": "sandig",
    "sandigts": "sandig",
    "sandjordar": "sandjord",
    "sandjordarna": "sandjord",
    "sandjordarnas": "sandjord",
    "sandjordars": "sandjord",
    "sandjorden": "sandjord",
    "sandjordens": "sandjord",
    "sandjords": "sandjord",
    "sandjägar": "sandjägare",
    "sandjägaren": "sandjägare",
    "sandjägarens": "sandjägare",
    "sandjägares": "sandjägare",
    "sandjägarna": "sandjägare",
    "sandjägarnas": "sandjägare",
    "sandkak": "sandkaka",
    "sandkakan": "sandkaka",
    "sandkakans": "sandkaka",
    "sandkakas": "sandkaka",
    "sandkake": "sandkaka",
    "sandkakor": "sandkaka",
    "sandkakorna": "sandkaka",
    "sandkakornas": "sandkaka",
    "sandkakors": "sandkaka",
    "sandkaks": "sandkaka",
    "sandkornen": "sandkorn",
    "sandkornens": "sandkorn",
    "sandkornet": "sandkorn",
    "sandkornets": "sandkorn",
    "sandkorns": "sandkorn",
    "sandkrassen": "sandkrasse",
    "sandkrassens": "sandkrasse",
    "sandkrasses": "sandkrasse",
    "sandkrypar": "sandkrypare",
    "sandkryparen": "sandkrypare",
    "sandkryparens": "sandkrypare",
    "sandkrypares": "sandkrypare",
    "sandkryparna": "sandkrypare",
    "sandkryparnas": "sandkrypare",
    "sandliljan": "sandlilja",
    "sandliljans": "sandlilja",
    "sandliljas": "sandlilja",
    "sandlilje": "sandlilja",
    "sandliljor": "sandlilja",
    "sandliljorna": "sandlilja",
    "sandliljornas": "sandlilja",
    "sandliljors": "sandlilja",
    "sandlopp": "sandloppa",
    "sandloppan": "sandloppa",
    "sandloppans": "sandloppa",
    "sandloppas": "sandloppa",
    "sandloppe": "sandloppa",
    "sandloppor": "sandloppa",
    "sandlopporna": "sandloppa",
    "sandloppornas": "sandloppa",
    "sandloppors": "sandloppa",
    "sandlopps": "sandloppa",
    "sandlåd": "sandlåda",
    "sandlådan": "sandlåda",
    "sandlådans": "sandlåda",
    "sandlådas": "sandlåda",
    "sandlåde": "sandlåda",
    "sandlådekrigen": "sandlådekrig",
    "sandlådekrigens": "sandlådekrig",
    "sandlådekriget": "sandlådekrig",
    "sandlådekrigets": "sandlådekrig",
    "sandlådekrigs": "sandlådekrig",
    "sandlådor": "sandlåda",
    "sandlådorna": "sandlåda",
    "sandlådornas": "sandlåda",
    "sandlådors": "sandlåda",
    "sandlåds": "sandlåda",
    "sandlöpar": "sandlöpare",
    "sandlöparen": "sandlöpare",
    "sandlöparens": "sandlöpare",
    "sandlöpares": "sandlöpare",
    "sandlöparna": "sandlöpare",
    "sandlöparnas": "sandlöpare",
    "sandmarken": "sandmark",
    "sandmarkens": "sandmark",
    "sandmarker": "sandmark",
    "sandmarkerna": "sandmark",
    "sandmarkernas": "sandmark",
    "sandmarkers": "sandmark",
    "sandmarks": "sandmark",
    "sandmaskar": "sandmask",
    "sandmaskarna": "sandmask",
    "sandmaskarnas": "sandmask",
    "sandmaskars": "sandmask",
    "sandmasken": "sandmask",
    "sandmaskens": "sandmask",
    "sandmasks": "sandmask",
    "sandmussel": "sandmussla",
    "sandmusslan": "sandmussla",
    "sandmusslans": "sandmussla",
    "sandmusslas": "sandmussla",
    "sandmussle": "sandmussla",
    "sandmusslor": "sandmussla",
    "sandmusslorna": "sandmussla",
    "sandmusslornas": "sandmussla",
    "sandmusslors": "sandmussla",
    "sandnarven": "sandnarv",
    "sandnarvens": "sandnarv",
    "sandnarvs": "sandnarv",
    "sandnejlik": "sandnejlika",
    "sandnejlikan": "sandnejlika",
    "sandnejlikans": "sandnejlika",
    "sandnejlikas": "sandnejlika",
    "sandnejlike": "sandnejlika",
    "sandnejlikor": "sandnejlika",
    "sandnejlikorna": "sandnejlika",
    "sandnejlikornas": "sandnejlika",
    "sandnejlikors": "sandnejlika",
    "sandnejliks": "sandnejlika",
    "sandnöreln": "sandnörel",
    "sandnörelns": "sandnörel",
    "sandnörels": "sandnörel",
    "sandpapperen": "sandpapper",
    "sandpapperens": "sandpapper",
    "sandpapperet": "sandpapper",
    "sandpapperets": "sandpapper",
    "sandpapperna": "sandpapper",
    "sandpappernas": "sandpapper",
    "sandpappers": "sandpapper",
    "sandpapprad": "sandpappra",
    "sandpapprade": "sandpappra",
    "sandpapprades": "sandpappra",
    "sandpapprads": "sandpappra",
    "sandpapprande": "sandpappra",
    "sandpappranden": "sandpapprande",
    "sandpapprandena": "sandpapprande",
    "sandpapprandenas": "sandpapprande",
    "sandpapprandens": "sandpapprande",
    "sandpapprandes": "sandpapprande",
    "sandpapprandet": "sandpapprande",
    "sandpapprandets": "sandpapprande",
    "sandpapprar": "sandpappra",
    "sandpappras": "sandpappra",
    "sandpapprat": "sandpappra",
    "sandpapprats": "sandpappra",
    "sandpappren": "sandpapper",
    "sandpapprens": "sandpapper",
    "sandpappret": "sandpapper",
    "sandpapprets": "sandpapper",
    "sandpärl": "sandpärla",
    "sandpärlan": "sandpärla",
    "sandpärlans": "sandpärla",
    "sandpärlas": "sandpärla",
    "sandpärle": "sandpärla",
    "sandpärlor": "sandpärla",
    "sandpärlorna": "sandpärla",
    "sandpärlornas": "sandpärla",
    "sandpärlors": "sandpärla",
    "sandpärls": "sandpärla",
    "sandreveln": "sandrevel",
    "sandrevelns": "sandrevel",
    "sandrevels": "sandrevel",
    "sandreven": "sandrev",
    "sandrevens": "sandrev",
    "sandrevet": "sandrev",
    "sandrevets": "sandrev",
    "sandrevlar": "sandrevel",
    "sandrevlarna": "sandrevel",
    "sandrevlarnas": "sandrevel",
    "sandrevlars": "sandrevel",
    "sandrevs": "sandrev",
    "sandräk": "sandräka",
    "sandräkan": "sandräka",
    "sandräkans": "sandräka",
    "sandräkas": "sandräka",
    "sandräke": "sandräka",
    "sandräkor": "sandräka",
    "sandräkorna": "sandräka",
    "sandräkornas": "sandräka",
    "sandräkors": "sandräka",
    "sandräks": "sandräka",
    "sandrören": "sandrör",
    "sandrörens": "sandrör",
    "sandröret": "sandrör",
    "sandrörets": "sandrör",
    "sandrörs": "sandrör",
    "sandskädd": "sandskädda",
    "sandskäddan": "sandskädda",
    "sandskäddans": "sandskädda",
    "sandskäddas": "sandskädda",
    "sandskädde": "sandskädda",
    "sandskäddor": "sandskädda",
    "sandskäddorna": "sandskädda",
    "sandskäddornas": "sandskädda",
    "sandskäddors": "sandskädda",
    "sandskädds": "sandskädda",
    "sandspåren": "sandspår",
    "sandspårens": "sandspår",
    "sandspåret": "sandspår",
    "sandspårets": "sandspår",
    "sandspårs": "sandspår",
    "sandstenen": "sandsten",
    "sandstenens": "sandsten",
    "sandstens": "sandsten",
    "sandstenshusen": "sandstenshus",
    "sandstenshusens": "sandstenshus",
    "sandstenshuset": "sandstenshus",
    "sandstenshusets": "sandstenshus",
    "sandstenstrapp": "sandstenstrappa",
    "sandstenstrappan": "sandstenstrappa",
    "sandstenstrappans": "sandstenstrappa",
    "sandstenstrappas": "sandstenstrappa",
    "sandstenstrappe": "sandstenstrappa",
    "sandstenstrappor": "sandstenstrappa",
    "sandstenstrapporna": "sandstenstrappa",
    "sandstenstrappornas": "sandstenstrappa",
    "sandstenstrappors": "sandstenstrappa",
    "sandstenstrapps": "sandstenstrappa",
    "sandstormar": "sandstorm",
    "sandstormarna": "sandstorm",
    "sandstormarnas": "sandstorm",
    "sandstormars": "sandstorm",
    "sandstormen": "sandstorm",
    "sandstormens": "sandstorm",
    "sandstorms": "sandstorm",
    "sandstranden": "sandstrand",
    "sandstrandens": "sandstrand",
    "sandstrands": "sandstrand",
    "sandstränder": "sandstrand",
    "sandstränderna": "sandstrand",
    "sandsträndernas": "sandstrand",
    "sandstränders": "sandstrand",
    "sandsugar": "sandsugare",
    "sandsugaren": "sandsugare",
    "sandsugarens": "sandsugare",
    "sandsugares": "sandsugare",
    "sandsugarna": "sandsugare",
    "sandsugarnas": "sandsugare",
    "sandsäckar": "sandsäck",
    "sandsäckarna": "sandsäck",
    "sandsäckarnas": "sandsäck",
    "sandsäckars": "sandsäck",
    "sandsäcken": "sandsäck",
    "sandsäckens": "sandsäck",
    "sandsäcks": "sandsäck",
    "sandtagen": "sandtag",
    "sandtagens": "sandtag",
    "sandtaget": "sandtag",
    "sandtagets": "sandtag",
    "sandtags": "sandtag",
    "sandtraven": "sandtrav",
    "sandtravens": "sandtrav",
    "sandtravs": "sandtrav",
    "sandtäkten": "sandtäkt",
    "sandtäktens": "sandtäkt",
    "sandtäkter": "sandtäkt",
    "sandtäkterna": "sandtäkt",
    "sandtäkternas": "sandtäkt",
    "sandtäkters": "sandtäkt",
    "sandtäkts": "sandtäkt",
    "sanduren": "sandur",
    "sandurens": "sandur",
    "sanduret": "sandur",
    "sandurets": "sandur",
    "sandurs": "sandur",
    "sandvikar": "sandvikare",
    "sandvikaren": "sandvikare",
    "sandvikarens": "sandvikare",
    "sandvikares": "sandvikare",
    "sandvikarna": "sandvikare",
    "sandvikarnas": "sandvikare",
    "sandvit": "sandvita",
    "sandvitan": "sandvita",
    "sandvitans": "sandvita",
    "sandvitas": "sandvita",
    "sandvite": "sandvita",
    "sandvitor": "sandvita",
    "sandvitorna": "sandvita",
    "sandvitornas": "sandvita",
    "sandvitors": "sandvita",
    "sandvits": "sandvita",
    "sandväxten": "sandväxt",
    "sandväxtens": "sandväxt",
    "sandväxter": "sandväxt",
    "sandväxterna": "sandväxt",
    "sandväxternas": "sandväxt",
    "sandväxters": "sandväxt",
    "sandväxts": "sandväxt",
    "sandwichar": "sandwich",
    "sandwicharna": "sandwich",
    "sandwicharnas": "sandwich",
    "sandwichars": "sandwich",
    "sandwichen": "sandwich",
    "sandwichens": "sandwich",
    "sandwichmannen": "sandwichman",
    "sandwichmannens": "sandwichman",
    "sandwichmans": "sandwichman",
    "sandwichmän": "sandwichman",
    "sandwichmännen": "sandwichman",
    "sandwichmännens": "sandwichman",
    "sandwichmäns": "sandwichman",
    "sandwichs": "sandwich",
    "sandödlan": "sandödla",
    "sandödlans": "sandödla",
    "sandödlas": "sandödla",
    "sandödle": "sandödla",
    "sandödlor": "sandödla",
    "sandödlorna": "sandödla",
    "sandödlornas": "sandödla",
    "sandödlors": "sandödla",
    "sandökenn": "sandöken",
    "sandökenns": "sandöken",
    "sandökens": "sandöken",
    "sandöknar": "sandöken",
    "sandöknarna": "sandöken",
    "sandöknarnas": "sandöken",
    "sandöknars": "sandöken",
    "sanerad": "sanera",
    "sanerade": "sanera",
    "sanerades": "sanera",
    "sanerads": "sanera",
    "sanerande": "sanera",
    "saneranden": "sanerande",
    "sanerandena": "sanerande",
    "sanerandenas": "sanerande",
    "sanerandens": "sanerande",
    "sanerandes": "sanerande",
    "sanerandet": "sanerande",
    "sanerandets": "sanerande",
    "sanerar": "sanera",
    "saneras": "sanera",
    "sanerat": "sanera",
    "sanerats": "sanera",
    "sanerbara": "sanerbar",
    "sanerbarare": "sanerbar",
    "sanerbarares": "sanerbar",
    "sanerbaras": "sanerbar",
    "sanerbarast": "sanerbar",
    "sanerbaraste": "sanerbar",
    "sanerbarastes": "sanerbar",
    "sanerbarasts": "sanerbar",
    "sanerbare": "sanerbar",
    "sanerbares": "sanerbar",
    "sanerbarheten": "sanerbarhet",
    "sanerbarhetens": "sanerbarhet",
    "sanerbarhets": "sanerbarhet",
    "sanerbars": "sanerbar",
    "sanerbart": "sanerbar",
    "sanerbarts": "sanerbar",
    "saneringar": "sanering",
    "saneringarna": "sanering",
    "saneringarnas": "sanering",
    "saneringars": "sanering",
    "saneringen": "sanering",
    "saneringens": "sanering",
    "sanerings": "sanering",
    "saneringsfartygen": "saneringsfartyg",
    "saneringsfartygens": "saneringsfartyg",
    "saneringsfartyget": "saneringsfartyg",
    "saneringsfartygets": "saneringsfartyg",
    "saneringsfartygs": "saneringsfartyg",
    "saneringsfastigheten": "saneringsfastighet",
    "saneringsfastighetens": "saneringsfastighet",
    "saneringsfastigheter": "saneringsfastighet",
    "saneringsfastigheterna": "saneringsfastighet",
    "saneringsfastigheternas": "saneringsfastighet",
    "saneringsfastigheters": "saneringsfastighet",
    "saneringsfastighets": "saneringsfastighet",
    "saneringskostnaden": "saneringskostnad",
    "saneringskostnadens": "saneringskostnad",
    "saneringskostnader": "saneringskostnad",
    "saneringskostnaderna": "saneringskostnad",
    "saneringskostnadernas": "saneringskostnad",
    "saneringskostnaders": "saneringskostnad",
    "saneringskostnads": "saneringskostnad",
    "saneringsmedels": "saneringsmedel",
    "saneringsmedlen": "saneringsmedel",
    "saneringsmedlens": "saneringsmedel",
    "saneringsmedlet": "saneringsmedel",
    "saneringsmedlets": "saneringsmedel",
    "saneringsplane": "saneringsplan",
    "saneringsplanen": "saneringsplan",
    "saneringsplanens": "saneringsplan",
    "saneringsplaner": "saneringsplan",
    "saneringsplanerna": "saneringsplan",
    "saneringsplanernas": "saneringsplan",
    "saneringsplaners": "saneringsplan",
    "saneringsplans": "saneringsplan",
    "sanforiserad": "sanforisera",
    "sanforiserade": "sanforisera",
    "sanforiserades": "sanforisera",
    "sanforiserads": "sanforisera",
    "sanforiserande": "sanforisera",
    "sanforiseranden": "sanforiserande",
    "sanforiserandena": "sanforiserande",
    "sanforiserandenas": "sanforiserande",
    "sanforiserandens": "sanforiserande",
    "sanforiserandes": "sanforiserande",
    "sanforiserandet": "sanforiserande",
    "sanforiserandets": "sanforiserande",
    "sanforiserar": "sanforisera",
    "sanforiseras": "sanforisera",
    "sanforiserat": "sanforisera",
    "sanforiserats": "sanforisera",
    "sanforiserbara": "sanforiserbar",
    "sanforiserbarare": "sanforiserbar",
    "sanforiserbarares": "sanforiserbar",
    "sanforiserbaras": "sanforiserbar",
    "sanforiserbarast": "sanforiserbar",
    "sanforiserbaraste": "sanforiserbar",
    "sanforiserbarastes": "sanforiserbar",
    "sanforiserbarasts": "sanforiserbar",
    "sanforiserbare": "sanforiserbar",
    "sanforiserbares": "sanforiserbar",
    "sanforiserbarheten": "sanforiserbarhet",
    "sanforiserbarhetens": "sanforiserbarhet",
    "sanforiserbarhets": "sanforiserbarhet",
    "sanforiserbars": "sanforiserbar",
    "sanforiserbart": "sanforiserbar",
    "sanforiserbarts": "sanforiserbar",
    "sanforiseringar": "sanforisering",
    "sanforiseringarna": "sanforisering",
    "sanforiseringarnas": "sanforisering",
    "sanforiseringars": "sanforisering",
    "sanforiseringen": "sanforisering",
    "sanforiseringens": "sanforisering",
    "sanforiserings": "sanforisering",
    "sangen": "sang",
    "sangens": "sang",
    "sangrian": "sangria",
    "sangrians": "sangria",
    "sangrias": "sangria",
    "sangs": "sang",
    "sangvinikern": "sangviniker",
    "sangvinikerna": "sangviniker",
    "sangvinikernas": "sangviniker",
    "sangvinikerns": "sangviniker",
    "sangvinikers": "sangviniker",
    "sangviniska": "sangvinisk",
    "sangviniskare": "sangvinisk",
    "sangviniskares": "sangvinisk",
    "sangviniskas": "sangvinisk",
    "sangviniskast": "sangvinisk",
    "sangviniskaste": "sangvinisk",
    "sangviniskastes": "sangvinisk",
    "sangviniskasts": "sangvinisk",
    "sangviniske": "sangvinisk",
    "sangviniskes": "sangvinisk",
    "sangvinisks": "sangvinisk",
    "sangviniskt": "sangvinisk",
    "sangviniskts": "sangvinisk",
    "saniteten": "sanitet",
    "sanitetens": "sanitet",
    "saniteter": "sanitet",
    "saniteterna": "sanitet",
    "saniteternas": "sanitet",
    "saniteters": "sanitet",
    "sanitets": "sanitet",
    "sanitetsanstalten": "sanitetsanstalt",
    "sanitetsanstaltens": "sanitetsanstalt",
    "sanitetsanstalter": "sanitetsanstalt",
    "sanitetsanstalterna": "sanitetsanstalt",
    "sanitetsanstalternas": "sanitetsanstalt",
    "sanitetsanstalters": "sanitetsanstalt",
    "sanitetsanstalts": "sanitetsanstalt",
    "sanitetsartikeln": "sanitetsartikel",
    "sanitetsartikelns": "sanitetsartikel",
    "sanitetsartikels": "sanitetsartikel",
    "sanitetsartiklar": "sanitetsartikel",
    "sanitetsartiklarna": "sanitetsartikel",
    "sanitetsartiklarnas": "sanitetsartikel",
    "sanitetsartiklars": "sanitetsartikel",
    "sanitetsbind": "sanitetsbinda",
    "sanitetsbindan": "sanitetsbinda",
    "sanitetsbindans": "sanitetsbinda",
    "sanitetsbindas": "sanitetsbinda",
    "sanitetsbinde": "sanitetsbinda",
    "sanitetsbindor": "sanitetsbinda",
    "sanitetsbindorna": "sanitetsbinda",
    "sanitetsbindornas": "sanitetsbinda",
    "sanitetsbindors": "sanitetsbinda",
    "sanitetsbinds": "sanitetsbinda",
    "sanitetsflagg": "sanitetsflagga",
    "sanitetsflaggan": "sanitetsflagga",
    "sanitetsflaggans": "sanitetsflagga",
    "sanitetsflaggas": "sanitetsflagga",
    "sanitetsflagge": "sanitetsflagga",
    "sanitetsflaggor": "sanitetsflagga",
    "sanitetsflaggorna": "sanitetsflagga",
    "sanitetsflaggornas": "sanitetsflagga",
    "sanitetsflaggors": "sanitetsflagga",
    "sanitetsflaggs": "sanitetsflagga",
    "sanitetsgodset": "sanitetsgods",
    "sanitetsgodsets": "sanitetsgods",
    "sanitetshundar": "sanitetshund",
    "sanitetshundarna": "sanitetshund",
    "sanitetshundarnas": "sanitetshund",
    "sanitetshundars": "sanitetshund",
    "sanitetshunden": "sanitetshund",
    "sanitetshundens": "sanitetshund",
    "sanitetshunds": "sanitetshund",
    "sanitetskompanier": "sanitetskompani",
    "sanitetskompanierna": "sanitetskompani",
    "sanitetskompaniernas": "sanitetskompani",
    "sanitetskompaniers": "sanitetskompani",
    "sanitetskompaniet": "sanitetskompani",
    "sanitetskompaniets": "sanitetskompani",
    "sanitetskompanis": "sanitetskompani",
    "sanitetskompanit": "sanitetskompani",
    "sanitetskompanits": "sanitetskompani",
    "sanitetskärlen": "sanitetskärl",
    "sanitetskärlens": "sanitetskärl",
    "sanitetskärlet": "sanitetskärl",
    "sanitetskärlets": "sanitetskärl",
    "sanitetskärls": "sanitetskärl",
    "sanitetsporslinet": "sanitetsporslin",
    "sanitetsporslinets": "sanitetsporslin",
    "sanitetsporslins": "sanitetsporslin",
    "sanitetstekniken": "sanitetsteknik",
    "sanitetsteknikens": "sanitetsteknik",
    "sanitetsteknikern": "sanitetstekniker",
    "sanitetsteknikerna": "sanitetstekniker",
    "sanitetsteknikernas": "sanitetstekniker",
    "sanitetsteknikerns": "sanitetstekniker",
    "sanitetsteknikers": "sanitetstekniker",
    "sanitetstekniks": "sanitetsteknik",
    "sanitetstruppen": "sanitetstrupp",
    "sanitetstruppens": "sanitetstrupp",
    "sanitetstrupper": "sanitetstrupp",
    "sanitetstrupperna": "sanitetstrupp",
    "sanitetstruppernas": "sanitetstrupp",
    "sanitetstruppers": "sanitetstrupp",
    "sanitetstrupps": "sanitetstrupp",
    "sanitära": "sanitär",
    "sanitärare": "sanitär",
    "sanitärares": "sanitär",
    "sanitäras": "sanitär",
    "sanitärast": "sanitär",
    "sanitäraste": "sanitär",
    "sanitärastes": "sanitär",
    "sanitärasts": "sanitär",
    "sanitäre": "sanitär",
    "sanitäres": "sanitär",
    "sanitärs": "sanitär",
    "sanitärt": "sanitär",
    "sanitärts": "sanitär",
    "sanka": "sank",
    "sankare": "sank",
    "sankares": "sank",
    "sankas": "sank",
    "sankast": "sank",
    "sankaste": "sank",
    "sankastes": "sank",
    "sankasts": "sank",
    "sanke": "sank",
    "sankes": "sank",
    "sankheten": "sankhet",
    "sankhetens": "sankhet",
    "sankhets": "sankhet",
    "sanks": "sank",
    "sankt": "sank",
    "sankta": "sankt",
    "sanktas": "sankt",
    "sanktbernhardshundar": "sanktbernhardshund",
    "sanktbernhardshundarna": "sanktbernhardshund",
    "sanktbernhardshundarnas": "sanktbernhardshund",
    "sanktbernhardshundars": "sanktbernhardshund",
    "sanktbernhardshunden": "sanktbernhardshund",
    "sanktbernhardshundens": "sanktbernhardshund",
    "sanktbernhardshunds": "sanktbernhardshund",
    "sankte": "sankt",
    "sanktes": "sankt",
    "sanktifierad": "sanktifiera",
    "sanktifierade": "sanktifiera",
    "sanktifierades": "sanktifiera",
    "sanktifierads": "sanktifiera",
    "sanktifierande": "sanktifiera",
    "sanktifieranden": "sanktifierande",
    "sanktifierandena": "sanktifierande",
    "sanktifierandenas": "sanktifierande",
    "sanktifierandens": "sanktifierande",
    "sanktifierandes": "sanktifierande",
    "sanktifierandet": "sanktifierande",
    "sanktifierandets": "sanktifierande",
    "sanktifierar": "sanktifiera",
    "sanktifieras": "sanktifiera",
    "sanktifierat": "sanktifiera",
    "sanktifierats": "sanktifiera",
    "sanktifierbara": "sanktifierbar",
    "sanktifierbarare": "sanktifierbar",
    "sanktifierbarares": "sanktifierbar",
    "sanktifierbaras": "sanktifierbar",
    "sanktifierbarast": "sanktifierbar",
    "sanktifierbaraste": "sanktifierbar",
    "sanktifierbarastes": "sanktifierbar",
    "sanktifierbarasts": "sanktifierbar",
    "sanktifierbare": "sanktifierbar",
    "sanktifierbares": "sanktifierbar",
    "sanktifierbarheten": "sanktifierbarhet",
    "sanktifierbarhetens": "sanktifierbarhet",
    "sanktifierbarhets": "sanktifierbarhet",
    "sanktifierbars": "sanktifierbar",
    "sanktifierbart": "sanktifierbar",
    "sanktifierbarts": "sanktifierbar",
    "sanktifieringar": "sanktifiering",
    "sanktifieringarna": "sanktifiering",
    "sanktifieringarnas": "sanktifiering",
    "sanktifieringars": "sanktifiering",
    "sanktifieringen": "sanktifiering",
    "sanktifieringens": "sanktifiering",
    "sanktifierings": "sanktifiering",
    "sanktifikationen": "sanktifikation",
    "sanktifikationens": "sanktifikation",
    "sanktifikationer": "sanktifikation",
    "sanktifikationerna": "sanktifikation",
    "sanktifikationernas": "sanktifikation",
    "sanktifikationers": "sanktifikation",
    "sanktifikations": "sanktifikation",
    "sanktionen": "sanktion",
    "sanktionens": "sanktion",
    "sanktioner": "sanktion",
    "sanktionerad": "sanktionera",
    "sanktionerade": "sanktionera",
    "sanktionerades": "sanktionera",
    "sanktionerads": "sanktionera",
    "sanktionerande": "sanktionera",
    "sanktioneranden": "sanktionerande",
    "sanktionerandena": "sanktionerande",
    "sanktionerandenas": "sanktionerande",
    "sanktionerandens": "sanktionerande",
    "sanktionerandes": "sanktionerande",
    "sanktionerandet": "sanktionerande",
    "sanktionerandets": "sanktionerande",
    "sanktionerar": "sanktionera",
    "sanktioneras": "sanktionera",
    "sanktionerat": "sanktionera",
    "sanktionerats": "sanktionera",
    "sanktionerbara": "sanktionerbar",
    "sanktionerbarare": "sanktionerbar",
    "sanktionerbarares": "sanktionerbar",
    "sanktionerbaras": "sanktionerbar",
    "sanktionerbarast": "sanktionerbar",
    "sanktionerbaraste": "sanktionerbar",
    "sanktionerbarastes": "sanktionerbar",
    "sanktionerbarasts": "sanktionerbar",
    "sanktionerbare": "sanktionerbar",
    "sanktionerbares": "sanktionerbar",
    "sanktionerbarheten": "sanktionerbarhet",
    "sanktionerbarhetens": "sanktionerbarhet",
    "sanktionerbarhets": "sanktionerbarhet",
    "sanktionerbars": "sanktionerbar",
    "sanktionerbart": "sanktionerbar",
    "sanktionerbarts": "sanktionerbar",
    "sanktioneringar": "sanktionering",
    "sanktioneringarna": "sanktionering",
    "sanktioneringarnas": "sanktionering",
    "sanktioneringars": "sanktionering",
    "sanktioneringen": "sanktionering",
    "sanktioneringens": "sanktionering",
    "sanktionerings": "sanktionering",
    "sanktionerna": "sanktion",
    "sanktionernas": "sanktion",
    "sanktioners": "sanktion",
    "sanktions": "sanktion",
    "sanktionspolitiken": "sanktionspolitik",
    "sanktionspolitikens": "sanktionspolitik",
    "sanktionspolitiks": "sanktionspolitik",
    "sanktpaulian": "sanktpaulia",
    "sanktpaulians": "sanktpaulia",
    "sanktpaulias": "sanktpaulia",
    "sanktpaulior": "sanktpaulia",
    "sanktpauliorna": "sanktpaulia",
    "sanktpauliornas": "sanktpaulia",
    "sanktpauliors": "sanktpaulia",
    "sankts": "sankt",
    "sanktuarie": "sanktuarium",
    "sanktuarier": "sanktuarium",
    "sanktuarierna": "sanktuarium",
    "sanktuariernas": "sanktuarium",
    "sanktuariers": "sanktuarium",
    "sanktuariet": "sanktuarium",
    "sanktuariets": "sanktuarium",
    "sanktuariums": "sanktuarium",
    "sanmarinesar": "sanmarinesare",
    "sanmarinesaren": "sanmarinesare",
    "sanmarinesarens": "sanmarinesare",
    "sanmarinesares": "sanmarinesare",
    "sanmarinesarna": "sanmarinesare",
    "sanmarinesarnas": "sanmarinesare",
    "sanmarinesiska": "sanmarinesisk",
    "sanmarinesiskare": "sanmarinesisk",
    "sanmarinesiskares": "sanmarinesisk",
    "sanmarinesiskas": "sanmarinesisk",
    "sanmarinesiskast": "sanmarinesisk",
    "sanmarinesiskaste": "sanmarinesisk",
    "sanmarinesiskastes": "sanmarinesisk",
    "sanmarinesiskasts": "sanmarinesisk",
    "sanmarinesiske": "sanmarinesisk",
    "sanmarinesiskes": "sanmarinesisk",
    "sanmarinesisks": "sanmarinesisk",
    "sanmarinesiskt": "sanmarinesisk",
    "sanmarinesiskts": "sanmarinesisk",
    "sanmariniern": "sanmarinier",
    "sanmarinierna": "sanmarinier",
    "sanmariniernas": "sanmarinier",
    "sanmarinierns": "sanmarinier",
    "sanmariniers": "sanmarinier",
    "sanmarinska": "sanmarinsk",
    "sanmarinskan": "sanmarinska",
    "sanmarinskans": "sanmarinska",
    "sanmarinskare": "sanmarinsk",
    "sanmarinskares": "sanmarinsk",
    "sanmarinskas": "sanmarinska",
    "sanmarinskast": "sanmarinsk",
    "sanmarinskaste": "sanmarinsk",
    "sanmarinskastes": "sanmarinsk",
    "sanmarinskasts": "sanmarinsk",
    "sanmarinske": "sanmarinska",
    "sanmarinskes": "sanmarinsk",
    "sanmarinskor": "sanmarinska",
    "sanmarinskorna": "sanmarinska",
    "sanmarinskornas": "sanmarinska",
    "sanmarinskors": "sanmarinska",
    "sanmarinsks": "sanmarinsk",
    "sanmarinskt": "sanmarinsk",
    "sanmarinskts": "sanmarinsk",
    "sann": "sanna",
    "sanna": "sann",
    "sannad": "sanna",
    "sannade": "sanna",
    "sannades": "sanna",
    "sannads": "sanna",
    "sannande": "sanna",
    "sannanden": "sannande",
    "sannandena": "sannande",
    "sannandenas": "sannande",
    "sannandens": "sannande",
    "sannandes": "sannande",
    "sannandet": "sannande",
    "sannandets": "sannande",
    "sannar": "sanna",
    "sannare": "sann",
    "sannares": "sann",
    "sannas": "sanna",
    "sannast": "sann",
    "sannaste": "sann",
    "sannastes": "sann",
    "sannasts": "sann",
    "sannat": "sanna",
    "sannats": "sanna",
    "sanndrömmar": "sanndröm",
    "sanndrömmarna": "sanndröm",
    "sanndrömmarnas": "sanndröm",
    "sanndrömmars": "sanndröm",
    "sanndrömmen": "sanndröm",
    "sanndrömmens": "sanndröm",
    "sanndröms": "sanndröm",
    "sanne": "sann",
    "sannes": "sann",
    "sannfärdiga": "sannfärdig",
    "sannfärdigare": "sannfärdig",
    "sannfärdigares": "sannfärdig",
    "sannfärdigas": "sannfärdig",
    "sannfärdigast": "sannfärdig",
    "sannfärdigaste": "sannfärdig",
    "sannfärdigastes": "sannfärdig",
    "sannfärdigasts": "sannfärdig",
    "sannfärdige": "sannfärdig",
    "sannfärdiges": "sannfärdig",
    "sannfärdigheten": "sannfärdighet",
    "sannfärdighetens": "sannfärdighet",
    "sannfärdighets": "sannfärdighet",
    "sannfärdigs": "sannfärdig",
    "sannfärdigt": "sannfärdig",
    "sannfärdigts": "sannfärdig",
    "sannheten": "sannhet",
    "sannhetens": "sannhet",
    "sannhets": "sannhet",
    "sanningar": "sanning",
    "sanningarna": "sanning",
    "sanningarnas": "sanning",
    "sanningars": "sanning",
    "sanningen": "sanning",
    "sanningens": "sanning",
    "sannings": "sanning",
    "sanningsanspråken": "sanningsanspråk",
    "sanningsanspråkens": "sanningsanspråk",
    "sanningsanspråket": "sanningsanspråk",
    "sanningsanspråkets": "sanningsanspråk",
    "sanningsanspråks": "sanningsanspråk",
    "sanningsdrogen": "sanningsdrog",
    "sanningsdrogens": "sanningsdrog",
    "sanningsdroger": "sanningsdrog",
    "sanningsdrogerna": "sanningsdrog",
    "sanningsdrogernas": "sanningsdrog",
    "sanningsdrogers": "sanningsdrog",
    "sanningsdrogs": "sanningsdrog",
    "sanningsenliga": "sanningsenlig",
    "sanningsenligare": "sanningsenlig",
    "sanningsenligares": "sanningsenlig",
    "sanningsenligas": "sanningsenlig",
    "sanningsenligast": "sanningsenlig",
    "sanningsenligaste": "sanningsenlig",
    "sanningsenligastes": "sanningsenlig",
    "sanningsenligasts": "sanningsenlig",
    "sanningsenlige": "sanningsenlig",
    "sanningsenliges": "sanningsenlig",
    "sanningsenligheten": "sanningsenlighet",
    "sanningsenlighetens": "sanningsenlighet",
    "sanningsenlighets": "sanningsenlighet",
    "sanningsenligs": "sanningsenlig",
    "sanningsenligt": "sanningsenlig",
    "sanningsenligts": "sanningsenlig",
    "sanningsförsäkrans": "sanningsförsäkran",
    "sanningsförsäkringar": "sanningsförsäkran",
    "sanningsförsäkringarna": "sanningsförsäkran",
    "sanningsförsäkringarnas": "sanningsförsäkran",
    "sanningsförsäkringars": "sanningsförsäkran",
    "sanningshalten": "sanningshalt",
    "sanningshaltens": "sanningshalt",
    "sanningshalts": "sanningshalt",
    "sanningskornen": "sanningskorn",
    "sanningskornens": "sanningskorn",
    "sanningskornet": "sanningskorn",
    "sanningskornets": "sanningskorn",
    "sanningskorns": "sanningskorn",
    "sanningskraven": "sanningskrav",
    "sanningskravens": "sanningskrav",
    "sanningskravet": "sanningskrav",
    "sanningskravets": "sanningskrav",
    "sanningskravs": "sanningskrav",
    "sanningslidelsen": "sanningslidelse",
    "sanningslidelsens": "sanningslidelse",
    "sanningslidelses": "sanningslidelse",
    "sanningslösa": "sanningslös",
    "sanningslösare": "sanningslös",
    "sanningslösares": "sanningslös",
    "sanningslösas": "sanningslös",
    "sanningslösast": "sanningslös",
    "sanningslösaste": "sanningslös",
    "sanningslösastes": "sanningslös",
    "sanningslösasts": "sanningslös",
    "sanningslöse": "sanningslös",
    "sanningslöses": "sanningslös",
    "sanningslösheten": "sanningslöshet",
    "sanningslöshetens": "sanningslöshet",
    "sanningslöshets": "sanningslöshet",
    "sanningslöst": "sanningslös",
    "sanningslösts": "sanningslös",
    "sanningsserumet": "sanningsserum",
    "sanningsserumets": "sanningsserum",
    "sanningsserums": "sanningsserum",
    "sanningssägar": "sanningssägare",
    "sanningssägaren": "sanningssägare",
    "sanningssägarens": "sanningssägare",
    "sanningssägares": "sanningssägare",
    "sanningssägarna": "sanningssägare",
    "sanningssägarnas": "sanningssägare",
    "sanningssökar": "sanningssökare",
    "sanningssökaren": "sanningssökare",
    "sanningssökarens": "sanningssökare",
    "sanningssökares": "sanningssökare",
    "sanningssökarna": "sanningssökare",
    "sanningssökarnas": "sanningssökare",
    "sanningsvittnen": "sanningsvittne",
    "sanningsvittnena": "sanningsvittne",
    "sanningsvittnenas": "sanningsvittne",
    "sanningsvittnens": "sanningsvittne",
    "sanningsvittnes": "sanningsvittne",
    "sanningsvittnet": "sanningsvittne",
    "sanningsvittnets": "sanningsvittne",
    "sanningsvärdes": "sanningsvärde",
    "sanningsvärdet": "sanningsvärde",
    "sanningsvärdets": "sanningsvärde",
    "sannolika": "sannolik",
    "sannolikare": "sannolik",
    "sannolikares": "sannolik",
    "sannolikas": "sannolik",
    "sannolikast": "sannolik",
    "sannolikaste": "sannolik",
    "sannolikastes": "sannolik",
    "sannolikasts": "sannolik",
    "sannolike": "sannolik",
    "sannolikes": "sannolik",
    "sannolikheten": "sannolikhet",
    "sannolikhetens": "sannolikhet",
    "sannolikheter": "sannolikhet",
    "sannolikheterna": "sannolikhet",
    "sannolikheternas": "sannolikhet",
    "sannolikheters": "sannolikhet",
    "sannolikhets": "sannolikhet",
    "sannolikhetsbevisen": "sannolikhetsbevis",
    "sannolikhetsbevisens": "sannolikhetsbevis",
    "sannolikhetsbeviset": "sannolikhetsbevis",
    "sannolikhetsbevisets": "sannolikhetsbevis",
    "sannolikhetskalkylen": "sannolikhetskalkyl",
    "sannolikhetskalkylens": "sannolikhetskalkyl",
    "sannolikhetskalkyler": "sannolikhetskalkyl",
    "sannolikhetskalkylerna": "sannolikhetskalkyl",
    "sannolikhetskalkylernas": "sannolikhetskalkyl",
    "sannolikhetskalkylers": "sannolikhetskalkyl",
    "sannolikhetskalkyls": "sannolikhetskalkyl",
    "sannolikhetsteorien": "sannolikhetsteori",
    "sannolikhetsteoriens": "sannolikhetsteori",
    "sannolikhetsteorier": "sannolikhetsteori",
    "sannolikhetsteorierna": "sannolikhetsteori",
    "sannolikhetsteoriernas": "sannolikhetsteori",
    "sannolikhetsteoriers": "sannolikhetsteori",
    "sannolikhetsteorin": "sannolikhetsteori",
    "sannolikhetsteorins": "sannolikhetsteori",
    "sannolikhetsteoris": "sannolikhetsteori",
    "sannolikhetsvågen": "sannolikhetsvåg",
    "sannolikhetsvågens": "sannolikhetsvåg",
    "sannolikhetsvågor": "sannolikhetsvåg",
    "sannolikhetsvågorna": "sannolikhetsvåg",
    "sannolikhetsvågornas": "sannolikhetsvåg",
    "sannolikhetsvågors": "sannolikhetsvåg",
    "sannolikhetsvågs": "sannolikhetsvåg",
    "sannoliks": "sannolik",
    "sannolikt": "sannolik",
    "sannolikts": "sannolik",
    "sanns": "sann",
    "sannsagan": "sannsaga",
    "sannsagans": "sannsaga",
    "sannsagas": "sannsaga",
    "sannsage": "sannsaga",
    "sannsago": "sannsaga",
    "sannsagor": "sannsaga",
    "sannsagorna": "sannsaga",
    "sannsagornas": "sannsaga",
    "sannsagors": "sannsaga",
    "sannskyldiga": "sannskyldig",
    "sannskyldigare": "sannskyldig",
    "sannskyldigares": "sannskyldig",
    "sannskyldigas": "sannskyldig",
    "sannskyldigast": "sannskyldig",
    "sannskyldigaste": "sannskyldig",
    "sannskyldigastes": "sannskyldig",
    "sannskyldigasts": "sannskyldig",
    "sannskyldige": "sannskyldig",
    "sannskyldiges": "sannskyldig",
    "sannskyldigheten": "sannskyldighet",
    "sannskyldighetens": "sannskyldighet",
    "sannskyldighets": "sannskyldighet",
    "sannskyldigs": "sannskyldig",
    "sannskyldigt": "sannskyldig",
    "sannskyldigts": "sannskyldig",
    "sannspådda": "sannspådd",
    "sannspåddare": "sannspådd",
    "sannspåddares": "sannspådd",
    "sannspåddas": "sannspådd",
    "sannspåddast": "sannspådd",
    "sannspåddaste": "sannspådd",
    "sannspåddastes": "sannspådd",
    "sannspåddasts": "sannspådd",
    "sannspådde": "sannspådd",
    "sannspåddes": "sannspådd",
    "sannspåddheten": "sannspåddhet",
    "sannspåddhetens": "sannspåddhet",
    "sannspåddhets": "sannspåddhet",
    "sannspådds": "sannspådd",
    "sannspått": "sannspådd",
    "sannspåtts": "sannspådd",
    "sansade": "sansad",
    "sansades": "sansad",
    "sansads": "sansad",
    "sansat": "sansad",
    "sansats": "sansad",
    "sansculotten": "sansculotte",
    "sansculottens": "sansculotte",
    "sansculotter": "sansculotte",
    "sansculotterna": "sansculotte",
    "sansculotternas": "sansculotte",
    "sansculotters": "sansculotte",
    "sansculottes": "sansculotte",
    "sansen": "sans",
    "sansens": "sans",
    "sanskriten": "sanskrit",
    "sanskritens": "sanskrit",
    "sanskrits": "sanskrit",
    "sanskulotten": "sanskulott",
    "sanskulottens": "sanskulott",
    "sanskulotter": "sanskulott",
    "sanskulotterna": "sanskulott",
    "sanskulotternas": "sanskulott",
    "sanskulotters": "sanskulott",
    "sanskulotts": "sanskulott",
    "sanslösa": "sanslös",
    "sanslösare": "sanslös",
    "sanslösares": "sanslös",
    "sanslösas": "sanslös",
    "sanslösast": "sanslös",
    "sanslösaste": "sanslös",
    "sanslösastes": "sanslös",
    "sanslösasts": "sanslös",
    "sanslöse": "sanslös",
    "sanslöses": "sanslös",
    "sanslösheten": "sanslöshet",
    "sanslöshetens": "sanslöshet",
    "sanslösheter": "sanslöshet",
    "sanslösheterna": "sanslöshet",
    "sanslösheternas": "sanslöshet",
    "sanslösheters": "sanslöshet",
    "sanslöshets": "sanslöshet",
    "sanslöst": "sanslös",
    "sanslösts": "sanslös",
    "sansningar": "sansning",
    "sansningarna": "sansning",
    "sansningarnas": "sansning",
    "sansningars": "sansning",
    "sansningen": "sansning",
    "sansningens": "sansning",
    "sansnings": "sansning",
    "sant": "sann",
    "sants": "sann",
    "saotomeanen": "saotomean",
    "saotomeanens": "saotomean",
    "saotomeaner": "saotomean",
    "saotomeanerna": "saotomean",
    "saotomeanernas": "saotomean",
    "saotomeaners": "saotomean",
    "saotomeans": "saotomean",
    "saotomeanska": "saotomeansk",
    "saotomeanskan": "saotomeanska",
    "saotomeanskans": "saotomeanska",
    "saotomeanskare": "saotomeansk",
    "saotomeanskares": "saotomeansk",
    "saotomeanskas": "saotomeanska",
    "saotomeanskast": "saotomeansk",
    "saotomeanskaste": "saotomeansk",
    "saotomeanskastes": "saotomeansk",
    "saotomeanskasts": "saotomeansk",
    "saotomeanske": "saotomeanska",
    "saotomeanskes": "saotomeansk",
    "saotomeanskor": "saotomeanska",
    "saotomeanskorna": "saotomeanska",
    "saotomeanskornas": "saotomeanska",
    "saotomeanskors": "saotomeanska",
    "saotomeansks": "saotomeansk",
    "saotomeanskt": "saotomeansk",
    "saotomeanskts": "saotomeansk",
    "sapfiska": "sapfisk",
    "sapfiskare": "sapfisk",
    "sapfiskares": "sapfisk",
    "sapfiskas": "sapfisk",
    "sapfiskast": "sapfisk",
    "sapfiskaste": "sapfisk",
    "sapfiskastes": "sapfisk",
    "sapfiskasts": "sapfisk",
    "sapfiske": "sapfisk",
    "sapfiskes": "sapfisk",
    "sapfisks": "sapfisk",
    "sapfiskt": "sapfisk",
    "sapfiskts": "sapfisk",
    "saponifierad": "saponifiera",
    "saponifierade": "saponifiera",
    "saponifierades": "saponifiera",
    "saponifierads": "saponifiera",
    "saponifierande": "saponifiera",
    "saponifieranden": "saponifierande",
    "saponifierandena": "saponifierande",
    "saponifierandenas": "saponifierande",
    "saponifierandens": "saponifierande",
    "saponifierandes": "saponifierande",
    "saponifierandet": "saponifierande",
    "saponifierandets": "saponifierande",
    "saponifierar": "saponifiera",
    "saponifieras": "saponifiera",
    "saponifierat": "saponifiera",
    "saponifierats": "saponifiera",
    "saponifierbara": "saponifierbar",
    "saponifierbarare": "saponifierbar",
    "saponifierbarares": "saponifierbar",
    "saponifierbaras": "saponifierbar",
    "saponifierbarast": "saponifierbar",
    "saponifierbaraste": "saponifierbar",
    "saponifierbarastes": "saponifierbar",
    "saponifierbarasts": "saponifierbar",
    "saponifierbare": "saponifierbar",
    "saponifierbares": "saponifierbar",
    "saponifierbarheten": "saponifierbarhet",
    "saponifierbarhetens": "saponifierbarhet",
    "saponifierbarhets": "saponifierbarhet",
    "saponifierbars": "saponifierbar",
    "saponifierbart": "saponifierbar",
    "saponifierbarts": "saponifierbar",
    "saponifieringar": "saponifiering",
    "saponifieringarna": "saponifiering",
    "saponifieringarnas": "saponifiering",
    "saponifieringars": "saponifiering",
    "saponifieringen": "saponifiering",
    "saponifieringens": "saponifiering",
    "saponifierings": "saponifiering",
    "saponiner": "saponin",
    "saponinerna": "saponin",
    "saponinernas": "saponin",
    "saponiners": "saponin",
    "saponinet": "saponin",
    "saponinets": "saponin",
    "saponins": "saponin",
    "sappen": "sapp",
    "sappens": "sapp",
    "sapper": "sapp",
    "sapperna": "sapp",
    "sappernas": "sapp",
    "sappers": "sapp",
    "sapps": "sapp",
    "sappören": "sappör",
    "sappörens": "sappör",
    "sappörer": "sappör",
    "sappörerna": "sappör",
    "sappörernas": "sappör",
    "sappörers": "sappör",
    "sappörs": "sappör",
    "saprofyten": "saprofyt",
    "saprofytens": "saprofyt",
    "saprofyter": "saprofyt",
    "saprofyterna": "saprofyt",
    "saprofyternas": "saprofyt",
    "saprofyters": "saprofyt",
    "saprofyts": "saprofyt",
    "saprogena": "saprogen",
    "saprogenare": "saprogen",
    "saprogenares": "saprogen",
    "saprogenas": "saprogen",
    "saprogenast": "saprogen",
    "saprogenaste": "saprogen",
    "saprogenastes": "saprogen",
    "saprogenasts": "saprogen",
    "saprogene": "saprogen",
    "saprogenes": "saprogen",
    "saprogens": "saprogen",
    "saprogent": "saprogen",
    "saprogents": "saprogen",
    "sarabanden": "saraband",
    "sarabandens": "saraband",
    "sarabander": "saraband",
    "sarabanderna": "saraband",
    "sarabandernas": "saraband",
    "sarabanders": "saraband",
    "sarabands": "saraband",
    "saracenen": "saracen",
    "saracenens": "saracen",
    "saracener": "saracen",
    "saracenerna": "saracen",
    "saracenernas": "saracen",
    "saraceners": "saracen",
    "saracens": "saracen",
    "sarafanen": "sarafan",
    "sarafanens": "sarafan",
    "sarafaner": "sarafan",
    "sarafanerna": "sarafan",
    "sarafanernas": "sarafan",
    "sarafaners": "sarafan",
    "sarafans": "sarafan",
    "sardellen": "sardell",
    "sardellens": "sardell",
    "sardeller": "sardell",
    "sardellerna": "sardell",
    "sardellernas": "sardell",
    "sardellers": "sardell",
    "sardells": "sardell",
    "sarden": "sard",
    "sardens": "sard",
    "sarder": "sard",
    "sarderna": "sard",
    "sardernas": "sard",
    "sarders": "sard",
    "sardinar": "sardinare",
    "sardinaren": "sardinare",
    "sardinarens": "sardinare",
    "sardinares": "sardinare",
    "sardinarna": "sardinare",
    "sardinarnas": "sardinare",
    "sardinen": "sardin",
    "sardinens": "sardin",
    "sardiner": "sardin",
    "sardinerna": "sardin",
    "sardinernas": "sardin",
    "sardiners": "sardin",
    "sardinisk": "sardiniska",
    "sardiniska": "sardinisk",
    "sardiniskan": "sardiniska",
    "sardiniskans": "sardiniska",
    "sardiniskare": "sardinisk",
    "sardiniskares": "sardinisk",
    "sardiniskas": "sardiniska",
    "sardiniskast": "sardinisk",
    "sardiniskaste": "sardinisk",
    "sardiniskastes": "sardinisk",
    "sardiniskasts": "sardinisk",
    "sardiniske": "sardiniska",
    "sardiniskes": "sardinisk",
    "sardiniskor": "sardiniska",
    "sardiniskorna": "sardiniska",
    "sardiniskornas": "sardiniska",
    "sardiniskors": "sardiniska",
    "sardinisks": "sardinisk",
    "sardiniskt": "sardinisk",
    "sardiniskts": "sardinisk",
    "sardins": "sardin",
    "sardinsk": "sardinska",
    "sardinska": "sardinsk",
    "sardinskan": "sardinska",
    "sardinskans": "sardinska",
    "sardinskare": "sardinsk",
    "sardinskares": "sardinsk",
    "sardinskas": "sardinska",
    "sardinskast": "sardinsk",
    "sardinskaste": "sardinsk",
    "sardinskastes": "sardinsk",
    "sardinskasts": "sardinsk",
    "sardinske": "sardinska",
    "sardinskes": "sardinsk",
    "sardinskor": "sardinska",
    "sardinskorna": "sardinska",
    "sardinskornas": "sardinska",
    "sardinskors": "sardinska",
    "sardinsks": "sardinsk",
    "sardinskt": "sardinsk",
    "sardinskts": "sardinsk",
    "sardisk": "sardiska",
    "sardiska": "sardisk",
    "sardiskan": "sardiska",
    "sardiskans": "sardiska",
    "sardiskare": "sardisk",
    "sardiskares": "sardisk",
    "sardiskas": "sardiska",
    "sardiskast": "sardisk",
    "sardiskaste": "sardisk",
    "sardiskastes": "sardisk",
    "sardiskasts": "sardisk",
    "sardiske": "sardiska",
    "sardiskes": "sardisk",
    "sardiskor": "sardiska",
    "sardiskorna": "sardiska",
    "sardiskornas": "sardiska",
    "sardiskors": "sardiska",
    "sardisks": "sardisk",
    "sardiskt": "sardisk",
    "sardiskts": "sardisk",
    "sardoniska": "sardonisk",
    "sardoniskare": "sardonisk",
    "sardoniskares": "sardonisk",
    "sardoniskas": "sardonisk",
    "sardoniskast": "sardonisk",
    "sardoniskaste": "sardonisk",
    "sardoniskastes": "sardonisk",
    "sardoniskasts": "sardonisk",
    "sardoniske": "sardonisk",
    "sardoniskes": "sardonisk",
    "sardonisks": "sardonisk",
    "sardoniskt": "sardonisk",
    "sardoniskts": "sardonisk",
    "sardonyxen": "sardonyx",
    "sardonyxens": "sardonyx",
    "sards": "sard",
    "sarg": "sarga",
    "sargad": "sarga",
    "sargade": "sarga",
    "sargades": "sarga",
    "sargads": "sarga",
    "sargande": "sarga",
    "sarganden": "sargande",
    "sargandena": "sargande",
    "sargandenas": "sargande",
    "sargandens": "sargande",
    "sargandes": "sargande",
    "sargandet": "sargande",
    "sargandets": "sargande",
    "sargar": "sarga",
    "sargarna": "sarg",
    "sargarnas": "sarg",
    "sargars": "sarg",
    "sargas": "sarga",
    "sargasson": "sargasso",
    "sargassons": "sargasso",
    "sargassos": "sargasso",
    "sargassotången": "sargassotång",
    "sargassotångens": "sargassotång",
    "sargassotångs": "sargassotång",
    "sargat": "sarga",
    "sargats": "sarga",
    "sargen": "sarg",
    "sargens": "sarg",
    "sarger": "sarg",
    "sargerna": "sarg",
    "sargernas": "sarg",
    "sargers": "sarg",
    "sargs": "sarg",
    "sarier": "sari",
    "sarierna": "sari",
    "sariernas": "sari",
    "sariers": "sari",
    "sarin": "sari",
    "sarins": "sari",
    "saris": "sari",
    "sarisarna": "sari",
    "sarisarnas": "sari",
    "sarkasmen": "sarkasm",
    "sarkasmens": "sarkasm",
    "sarkasmer": "sarkasm",
    "sarkasmerna": "sarkasm",
    "sarkasmernas": "sarkasm",
    "sarkasmers": "sarkasm",
    "sarkasms": "sarkasm",
    "sarkastiska": "sarkastisk",
    "sarkastiskare": "sarkastisk",
    "sarkastiskares": "sarkastisk",
    "sarkastiskas": "sarkastisk",
    "sarkastiskast": "sarkastisk",
    "sarkastiskaste": "sarkastisk",
    "sarkastiskastes": "sarkastisk",
    "sarkastiskasts": "sarkastisk",
    "sarkastiske": "sarkastisk",
    "sarkastiskes": "sarkastisk",
    "sarkastisks": "sarkastisk",
    "sarkastiskt": "sarkastisk",
    "sarkastiskts": "sarkastisk",
    "sarkofagen": "sarkofag",
    "sarkofagens": "sarkofag",
    "sarkofager": "sarkofag",
    "sarkofagerna": "sarkofag",
    "sarkofagernas": "sarkofag",
    "sarkofagers": "sarkofag",
    "sarkofags": "sarkofag",
    "sarkomen": "sarkom",
    "sarkomens": "sarkom",
    "sarkomet": "sarkom",
    "sarkomets": "sarkom",
    "sarkoms": "sarkom",
    "sarongen": "sarong",
    "sarongens": "sarong",
    "saronger": "sarong",
    "sarongerna": "sarong",
    "sarongernas": "sarong",
    "sarongers": "sarong",
    "sarongs": "sarong",
    "sarsen": "sars",
    "sarsens": "sars",
    "sarser": "sars",
    "sarserna": "sars",
    "sarsernas": "sars",
    "sarsers": "sars",
    "sarset": "sars",
    "sarsets": "sars",
    "sarvar": "sarv",
    "sarvarna": "sarv",
    "sarvarnas": "sarv",
    "sarvars": "sarv",
    "sarven": "sarv",
    "sarvens": "sarv",
    "sarvs": "sarv",
    "sas": "säga",
    "sat": "sate",
    "sataniska": "satanisk",
    "sataniskare": "satanisk",
    "sataniskares": "satanisk",
    "sataniskas": "satanisk",
    "sataniskast": "satanisk",
    "sataniskaste": "satanisk",
    "sataniskastes": "satanisk",
    "sataniskasts": "satanisk",
    "sataniske": "satanisk",
    "sataniskes": "satanisk",
    "satanisks": "satanisk",
    "sataniskt": "satanisk",
    "sataniskts": "satanisk",
    "satanismen": "satanism",
    "satanismens": "satanism",
    "satanismer": "satanism",
    "satanismerna": "satanism",
    "satanismernas": "satanism",
    "satanismers": "satanism",
    "satanisms": "satanism",
    "satanisten": "satanist",
    "satanistens": "satanist",
    "satanister": "satanist",
    "satanisterna": "satanist",
    "satanisternas": "satanist",
    "satanisters": "satanist",
    "satanistiska": "satanistisk",
    "satanistiskas": "satanistisk",
    "satanistiske": "satanistisk",
    "satanistiskes": "satanistisk",
    "satanistisks": "satanistisk",
    "satanistiskt": "satanistisk",
    "satanistiskts": "satanistisk",
    "satanists": "satanist",
    "satans": "satan",
    "satansfunderna": "satansfunder",
    "satansfundernas": "satansfunder",
    "satansfunders": "satansfunder",
    "satansfunds": "satansfunder",
    "satanskulten": "satanskult",
    "satanskultens": "satanskult",
    "satanskults": "satanskult",
    "satar": "sate",
    "satarna": "sate",
    "satarnas": "sate",
    "satars": "sate",
    "satellitbanan": "satellitbana",
    "satellitbanans": "satellitbana",
    "satellitbanas": "satellitbana",
    "satellitbane": "satellitbana",
    "satellitbanor": "satellitbana",
    "satellitbanorna": "satellitbana",
    "satellitbanornas": "satellitbana",
    "satellitbanors": "satellitbana",
    "satellitbilden": "satellitbild",
    "satellitbildens": "satellitbild",
    "satellitbilder": "satellitbild",
    "satellitbilderna": "satellitbild",
    "satellitbildernas": "satellitbild",
    "satellitbilders": "satellitbild",
    "satellitbilds": "satellitbild",
    "satelliten": "satellit",
    "satellitens": "satellit",
    "satelliter": "satellit",
    "satelliterna": "satellit",
    "satelliternas": "satellit",
    "satelliters": "satellit",
    "satellitkameran": "satellitkamera",
    "satellitkamerans": "satellitkamera",
    "satellitkameras": "satellitkamera",
    "satellitkameror": "satellitkamera",
    "satellitkamerorna": "satellitkamera",
    "satellitkamerornas": "satellitkamera",
    "satellitkamerors": "satellitkamera",
    "satellitradion": "satellitradio",
    "satellitradions": "satellitradio",
    "satellitradios": "satellitradio",
    "satellitradiostationen": "satellitradiostation",
    "satellitradiostationens": "satellitradiostation",
    "satellitradiostationer": "satellitradiostation",
    "satellitradiostationerna": "satellitradiostation",
    "satellitradiostationernas": "satellitradiostation",
    "satellitradiostationers": "satellitradiostation",
    "satellitradiostations": "satellitradiostation",
    "satellits": "satellit",
    "satellitstaten": "satellitstat",
    "satellitstatens": "satellitstat",
    "satellitstater": "satellitstat",
    "satellitstaterna": "satellitstat",
    "satellitstaternas": "satellitstat",
    "satellitstaters": "satellitstat",
    "satellitstats": "satellitstat",
    "satemspråken": "satemspråk",
    "satemspråkens": "satemspråk",
    "satemspråket": "satemspråk",
    "satemspråkets": "satemspråk",
    "satemspråks": "satemspråk",
    "saten": "sate",
    "satens": "sate",
    "sates": "sate",
    "satinen": "satin",
    "satinens": "satin",
    "satiner": "satin",
    "satinerad": "satinera",
    "satinerade": "satinera",
    "satinerades": "satinera",
    "satinerads": "satinera",
    "satinerande": "satinera",
    "satineranden": "satinerande",
    "satinerandena": "satinerande",
    "satinerandenas": "satinerande",
    "satinerandens": "satinerande",
    "satinerandes": "satinerande",
    "satinerandet": "satinerande",
    "satinerandets": "satinerande",
    "satinerar": "satinera",
    "satineras": "satinera",
    "satinerat": "satinera",
    "satinerats": "satinera",
    "satinerbara": "satinerbar",
    "satinerbarare": "satinerbar",
    "satinerbarares": "satinerbar",
    "satinerbaras": "satinerbar",
    "satinerbarast": "satinerbar",
    "satinerbaraste": "satinerbar",
    "satinerbarastes": "satinerbar",
    "satinerbarasts": "satinerbar",
    "satinerbare": "satinerbar",
    "satinerbares": "satinerbar",
    "satinerbarheten": "satinerbarhet",
    "satinerbarhetens": "satinerbarhet",
    "satinerbarhets": "satinerbarhet",
    "satinerbars": "satinerbar",
    "satinerbart": "satinerbar",
    "satinerbarts": "satinerbar",
    "satineringar": "satinering",
    "satineringarna": "satinering",
    "satineringarnas": "satinering",
    "satineringars": "satinering",
    "satineringen": "satinering",
    "satineringens": "satinering",
    "satinerings": "satinering",
    "satinerna": "satin",
    "satinernas": "satin",
    "satiners": "satin",
    "satinet": "satin",
    "satinets": "satin",
    "satins": "satin",
    "satiren": "satir",
    "satirens": "satir",
    "satirer": "satir",
    "satirerna": "satir",
    "satirernas": "satir",
    "satirers": "satir",
    "satirikern": "satiriker",
    "satirikerna": "satiriker",
    "satirikernas": "satiriker",
    "satirikerns": "satiriker",
    "satirikers": "satiriker",
    "satiriserade": "satirisera",
    "satiriserades": "satirisera",
    "satiriserande": "satirisera",
    "satiriseranden": "satiriserande",
    "satiriserandena": "satiriserande",
    "satiriserandenas": "satiriserande",
    "satiriserandens": "satiriserande",
    "satiriserandes": "satiriserande",
    "satiriserandet": "satiriserande",
    "satiriserandets": "satiriserande",
    "satiriserar": "satirisera",
    "satiriseras": "satirisera",
    "satiriserat": "satirisera",
    "satiriserats": "satirisera",
    "satiriseringar": "satirisering",
    "satiriseringarna": "satirisering",
    "satiriseringarnas": "satirisering",
    "satiriseringars": "satirisering",
    "satiriseringen": "satirisering",
    "satiriseringens": "satirisering",
    "satiriserings": "satirisering",
    "satiriska": "satirisk",
    "satiriskare": "satirisk",
    "satiriskares": "satirisk",
    "satiriskas": "satirisk",
    "satiriskast": "satirisk",
    "satiriskaste": "satirisk",
    "satiriskastes": "satirisk",
    "satiriskasts": "satirisk",
    "satiriske": "satirisk",
    "satiriskes": "satirisk",
    "satirisks": "satirisk",
    "satiriskt": "satirisk",
    "satiriskts": "satirisk",
    "satirs": "satir",
    "satisfaktionen": "satisfaktion",
    "satisfaktionens": "satisfaktion",
    "satisfaktioner": "satisfaktion",
    "satisfaktionerna": "satisfaktion",
    "satisfaktionernas": "satisfaktion",
    "satisfaktioners": "satisfaktion",
    "satisfaktions": "satisfaktion",
    "satisfierad": "satisfiera",
    "satisfierade": "satisfiera",
    "satisfierades": "satisfiera",
    "satisfierads": "satisfiera",
    "satisfierande": "satisfiera",
    "satisfieranden": "satisfierande",
    "satisfierandena": "satisfierande",
    "satisfierandenas": "satisfierande",
    "satisfierandens": "satisfierande",
    "satisfierandes": "satisfierande",
    "satisfierandet": "satisfierande",
    "satisfierandets": "satisfierande",
    "satisfierar": "satisfiera",
    "satisfieras": "satisfiera",
    "satisfierat": "satisfiera",
    "satisfierats": "satisfiera",
    "satisfierbara": "satisfierbar",
    "satisfierbarare": "satisfierbar",
    "satisfierbarares": "satisfierbar",
    "satisfierbaras": "satisfierbar",
    "satisfierbarast": "satisfierbar",
    "satisfierbaraste": "satisfierbar",
    "satisfierbarastes": "satisfierbar",
    "satisfierbarasts": "satisfierbar",
    "satisfierbare": "satisfierbar",
    "satisfierbares": "satisfierbar",
    "satisfierbarheten": "satisfierbarhet",
    "satisfierbarhetens": "satisfierbarhet",
    "satisfierbarhets": "satisfierbarhet",
    "satisfierbars": "satisfierbar",
    "satisfierbart": "satisfierbar",
    "satisfierbarts": "satisfierbar",
    "satisfieringar": "satisfiering",
    "satisfieringarna": "satisfiering",
    "satisfieringarnas": "satisfiering",
    "satisfieringars": "satisfiering",
    "satisfieringen": "satisfiering",
    "satisfieringens": "satisfiering",
    "satisfierings": "satisfiering",
    "satkäringar": "satkäring",
    "satkäringarna": "satkäring",
    "satkäringarnas": "satkäring",
    "satkäringars": "satkäring",
    "satkäringen": "satkäring",
    "satkäringens": "satkäring",
    "satkärings": "satkäring",
    "satkärringar": "satkärring",
    "satkärringarna": "satkärring",
    "satkärringarnas": "satkärring",
    "satkärringars": "satkärring",
    "satkärringen": "satkärring",
    "satkärringens": "satkärring",
    "satkärrings": "satkärring",
    "satmar": "satmara",
    "satmaran": "satmara",
    "satmarans": "satmara",
    "satmaras": "satmara",
    "satmare": "satmara",
    "satmaror": "satmara",
    "satmarorna": "satmara",
    "satmarornas": "satmara",
    "satmarors": "satmara",
    "satmars": "satmara",
    "satrapen": "satrap",
    "satrapens": "satrap",
    "satraper": "satrap",
    "satraperna": "satrap",
    "satrapernas": "satrap",
    "satrapers": "satrap",
    "satrapien": "satrapi",
    "satrapiens": "satrapi",
    "satrapier": "satrapi",
    "satrapierna": "satrapi",
    "satrapiernas": "satrapi",
    "satrapiers": "satrapi",
    "satrapin": "satrapi",
    "satrapins": "satrapi",
    "satrapis": "satrapi",
    "satraps": "satrap",
    "sats": "satsa",
    "satsaccenten": "satsaccent",
    "satsaccentens": "satsaccent",
    "satsaccenter": "satsaccent",
    "satsaccenterna": "satsaccent",
    "satsaccenternas": "satsaccent",
    "satsaccenters": "satsaccent",
    "satsaccents": "satsaccent",
    "satsad": "satsa",
    "satsade": "satsa",
    "satsades": "satsa",
    "satsads": "satsa",
    "satsadverbialen": "satsadverbial",
    "satsadverbialens": "satsadverbial",
    "satsadverbialet": "satsadverbial",
    "satsadverbialets": "satsadverbial",
    "satsadverbials": "satsadverbial",
    "satsanalysen": "satsanalys",
    "satsanalysens": "satsanalys",
    "satsanalyser": "satsanalys",
    "satsanalyserna": "satsanalys",
    "satsanalysernas": "satsanalys",
    "satsanalysers": "satsanalys",
    "satsande": "satsa",
    "satsanden": "satsande",
    "satsandena": "satsande",
    "satsandenas": "satsande",
    "satsandens": "satsande",
    "satsandes": "satsande",
    "satsandet": "satsande",
    "satsandets": "satsande",
    "satsar": "satsa",
    "satsas": "satsa",
    "satsat": "satsa",
    "satsats": "satsa",
    "satsbindningar": "satsbindning",
    "satsbindningarna": "satsbindning",
    "satsbindningarnas": "satsbindning",
    "satsbindningars": "satsbindning",
    "satsbindningen": "satsbindning",
    "satsbindningens": "satsbindning",
    "satsbindnings": "satsbindning",
    "satsborden": "satsbord",
    "satsbordens": "satsbord",
    "satsbordet": "satsbord",
    "satsbordets": "satsbord",
    "satsbords": "satsbord",
    "satsbräd": "satsbräda",
    "satsbrädan": "satsbräda",
    "satsbrädans": "satsbräda",
    "satsbrädas": "satsbräda",
    "satsbräde": "satsbräda",
    "satsbräden": "satsbräde",
    "satsbrädena": "satsbräde",
    "satsbrädenas": "satsbräde",
    "satsbrädens": "satsbräde",
    "satsbrädes": "satsbräde",
    "satsbrädet": "satsbräde",
    "satsbrädets": "satsbräde",
    "satsbrädor": "satsbräda",
    "satsbrädorna": "satsbräda",
    "satsbrädornas": "satsbräda",
    "satsbrädors": "satsbräda",
    "satsbräds": "satsbräda",
    "satsbyggnaden": "satsbyggnad",
    "satsbyggnadens": "satsbyggnad",
    "satsbyggnader": "satsbyggnad",
    "satsbyggnaderna": "satsbyggnad",
    "satsbyggnadernas": "satsbyggnad",
    "satsbyggnaders": "satsbyggnad",
    "satsbyggnads": "satsbyggnad",
    "satsdelar": "satsdel",
    "satsdelarna": "satsdel",
    "satsdelarnas": "satsdel",
    "satsdelars": "satsdel",
    "satsdelen": "satsdel",
    "satsdelens": "satsdel",
    "satsdels": "satsdel",
    "satsen": "sats",
    "satsens": "sats",
    "satser": "sats",
    "satserna": "sats",
    "satsernas": "sats",
    "satsers": "sats",
    "satsflät": "satsfläta",
    "satsflätan": "satsfläta",
    "satsflätans": "satsfläta",
    "satsflätas": "satsfläta",
    "satsfläte": "satsfläta",
    "satsflätor": "satsfläta",
    "satsflätorna": "satsfläta",
    "satsflätornas": "satsfläta",
    "satsflätors": "satsfläta",
    "satsfläts": "satsfläta",
    "satsfogningar": "satsfogning",
    "satsfogningarna": "satsfogning",
    "satsfogningarnas": "satsfogning",
    "satsfogningars": "satsfogning",
    "satsfogningen": "satsfogning",
    "satsfogningens": "satsfogning",
    "satsfognings": "satsfogning",
    "satsförkortningar": "satsförkortning",
    "satsförkortningarna": "satsförkortning",
    "satsförkortningarnas": "satsförkortning",
    "satsförkortningars": "satsförkortning",
    "satsförkortningen": "satsförkortning",
    "satsförkortningens": "satsförkortning",
    "satsförkortnings": "satsförkortning",
    "satskommateringar": "satskommatering",
    "satskommateringarna": "satskommatering",
    "satskommateringarnas": "satskommatering",
    "satskommateringars": "satskommatering",
    "satskommateringen": "satskommatering",
    "satskommateringens": "satskommatering",
    "satskommaterings": "satskommatering",
    "satskompletteringstesten": "satskompletteringstest",
    "satskompletteringstestens": "satskompletteringstest",
    "satskompletteringstester": "satskompletteringstest",
    "satskompletteringstesterna": "satskompletteringstest",
    "satskompletteringstesternas": "satskompletteringstest",
    "satskompletteringstesters": "satskompletteringstest",
    "satskompletteringstestet": "satskompletteringstest",
    "satskompletteringstestets": "satskompletteringstest",
    "satskompletteringstests": "satskompletteringstest",
    "satskonstruktionen": "satskonstruktion",
    "satskonstruktionens": "satskonstruktion",
    "satskonstruktioner": "satskonstruktion",
    "satskonstruktionerna": "satskonstruktion",
    "satskonstruktionernas": "satskonstruktion",
    "satskonstruktioners": "satskonstruktion",
    "satskonstruktions": "satskonstruktion",
    "satsläran": "satslära",
    "satslärans": "satslära",
    "satsläras": "satslära",
    "satslösningar": "satslösning",
    "satslösningarna": "satslösning",
    "satslösningarnas": "satslösning",
    "satslösningars": "satslösning",
    "satslösningen": "satslösning",
    "satslösningens": "satslösning",
    "satslösnings": "satslösning",
    "satsmelodien": "satsmelodi",
    "satsmelodiens": "satsmelodi",
    "satsmelodier": "satsmelodi",
    "satsmelodierna": "satsmelodi",
    "satsmelodiernas": "satsmelodi",
    "satsmelodiers": "satsmelodi",
    "satsmelodin": "satsmelodi",
    "satsmelodins": "satsmelodi",
    "satsmelodis": "satsmelodi",
    "satsningar": "satsning",
    "satsningarna": "satsning",
    "satsningarnas": "satsning",
    "satsningars": "satsning",
    "satsningen": "satsning",
    "satsningens": "satsning",
    "satsnings": "satsning",
    "satstypen": "satstyp",
    "satstypens": "satstyp",
    "satstyper": "satstyp",
    "satstyperna": "satstyp",
    "satstypernas": "satstyp",
    "satstypers": "satstyp",
    "satstyps": "satstyp",
    "satsuman": "satsuma",
    "satsumans": "satsuma",
    "satsumas": "satsuma",
    "satsumasarna": "satsuma",
    "satsumasarnas": "satsuma",
    "satsumasen": "satsuma",
    "satsumasens": "satsuma",
    "satsytan": "satsyta",
    "satsytans": "satsyta",
    "satsytas": "satsyta",
    "satsyte": "satsyta",
    "satsytor": "satsyta",
    "satsytorna": "satsyta",
    "satsytornas": "satsyta",
    "satsytors": "satsyta",
    "satt": "sitta",
    "satta": "sätta",
    "sattare": "satt",
    "sattares": "satt",
    "sattas": "sätta",
    "sattast": "satt",
    "sattaste": "satt",
    "sattastes": "satt",
    "sattasts": "satt",
    "satte": "sätta",
    "sattes": "sätta",
    "sattheten": "satthet",
    "satthetens": "satthet",
    "satthets": "satthet",
    "satts": "sitta",
    "sattygen": "sattyg",
    "sattygens": "sattyg",
    "sattyget": "sattyg",
    "sattygets": "sattyg",
    "sattygs": "sattyg",
    "satungar": "satunge",
    "satungarna": "satunge",
    "satungarnas": "satunge",
    "satungars": "satunge",
    "satungen": "satunge",
    "satungens": "satunge",
    "satunges": "satunge",
    "saturerad": "saturera",
    "saturerade": "saturera",
    "saturerades": "saturera",
    "saturerads": "saturera",
    "saturerande": "saturera",
    "satureranden": "saturerande",
    "saturerandena": "saturerande",
    "saturerandenas": "saturerande",
    "saturerandens": "saturerande",
    "saturerandes": "saturerande",
    "saturerandet": "saturerande",
    "saturerandets": "saturerande",
    "saturerar": "saturera",
    "satureras": "saturera",
    "saturerat": "saturera",
    "saturerats": "saturera",
    "saturerbara": "saturerbar",
    "saturerbarare": "saturerbar",
    "saturerbarares": "saturerbar",
    "saturerbaras": "saturerbar",
    "saturerbarast": "saturerbar",
    "saturerbaraste": "saturerbar",
    "saturerbarastes": "saturerbar",
    "saturerbarasts": "saturerbar",
    "saturerbare": "saturerbar",
    "saturerbares": "saturerbar",
    "saturerbarheten": "saturerbarhet",
    "saturerbarhetens": "saturerbarhet",
    "saturerbarhets": "saturerbarhet",
    "saturerbars": "saturerbar",
    "saturerbart": "saturerbar",
    "saturerbarts": "saturerbar",
    "satureringar": "saturering",
    "satureringarna": "saturering",
    "satureringarnas": "saturering",
    "satureringars": "saturering",
    "satureringen": "saturering",
    "satureringens": "saturering",
    "saturerings": "saturering",
    "saturnalie": "saturnalier",
    "saturnaliefesten": "saturnaliefest",
    "saturnaliefestens": "saturnaliefest",
    "saturnaliefester": "saturnaliefest",
    "saturnaliefesterna": "saturnaliefest",
    "saturnaliefesternas": "saturnaliefest",
    "saturnaliefesters": "saturnaliefest",
    "saturnaliefests": "saturnaliefest",
    "saturnalierna": "saturnalier",
    "saturnaliernas": "saturnalier",
    "saturnaliers": "saturnalier",
    "saturnaliska": "saturnalisk",
    "saturnaliskare": "saturnalisk",
    "saturnaliskares": "saturnalisk",
    "saturnaliskas": "saturnalisk",
    "saturnaliskast": "saturnalisk",
    "saturnaliskaste": "saturnalisk",
    "saturnaliskastes": "saturnalisk",
    "saturnaliskasts": "saturnalisk",
    "saturnaliske": "saturnalisk",
    "saturnaliskes": "saturnalisk",
    "saturnalisks": "saturnalisk",
    "saturnaliskt": "saturnalisk",
    "saturnaliskts": "saturnalisk",
    "saturniska": "saturnisk",
    "saturniskare": "saturnisk",
    "saturniskares": "saturnisk",
    "saturniskas": "saturnisk",
    "saturniskast": "saturnisk",
    "saturniskaste": "saturnisk",
    "saturniskastes": "saturnisk",
    "saturniskasts": "saturnisk",
    "saturniske": "saturnisk",
    "saturniskes": "saturnisk",
    "saturnisks": "saturnisk",
    "saturniskt": "saturnisk",
    "saturniskts": "saturnisk",
    "saturnismen": "saturnism",
    "saturnismens": "saturnism",
    "saturnismer": "saturnism",
    "saturnismerna": "saturnism",
    "saturnismernas": "saturnism",
    "saturnismers": "saturnism",
    "saturnisms": "saturnism",
    "satyrdraman": "satyrdrama",
    "satyrdramana": "satyrdrama",
    "satyrdramanas": "satyrdrama",
    "satyrdramans": "satyrdrama",
    "satyrdramas": "satyrdrama",
    "satyrdramat": "satyrdrama",
    "satyrdramats": "satyrdrama",
    "satyrdramer": "satyrdrama",
    "satyrdramerna": "satyrdrama",
    "satyrdramernas": "satyrdrama",
    "satyrdramers": "satyrdrama",
    "satyren": "satyr",
    "satyrens": "satyr",
    "satyrer": "satyr",
    "satyrerna": "satyr",
    "satyrernas": "satyr",
    "satyrers": "satyr",
    "satyriasisen": "satyriasis",
    "satyriasisens": "satyriasis",
    "satyrs": "satyr",
    "satyrspelen": "satyrspel",
    "satyrspelens": "satyrspel",
    "satyrspelet": "satyrspel",
    "satyrspelets": "satyrspel",
    "satyrspels": "satyrspel",
    "satängen": "satäng",
    "satängens": "satäng",
    "satänger": "satäng",
    "satängerna": "satäng",
    "satängernas": "satäng",
    "satängers": "satäng",
    "satängs": "satäng",
    "saudiaraben": "saudiarab",
    "saudiarabens": "saudiarab",
    "saudiaraber": "saudiarab",
    "saudiaraberna": "saudiarab",
    "saudiarabernas": "saudiarab",
    "saudiarabers": "saudiarab",
    "saudiarabiska": "saudiarabisk",
    "saudiarabiskan": "saudiarabiska",
    "saudiarabiskans": "saudiarabiska",
    "saudiarabiskare": "saudiarabisk",
    "saudiarabiskares": "saudiarabisk",
    "saudiarabiskas": "saudiarabiska",
    "saudiarabiskast": "saudiarabisk",
    "saudiarabiskaste": "saudiarabisk",
    "saudiarabiskastes": "saudiarabisk",
    "saudiarabiskasts": "saudiarabisk",
    "saudiarabiske": "saudiarabiska",
    "saudiarabiskes": "saudiarabisk",
    "saudiarabiskor": "saudiarabiska",
    "saudiarabiskorna": "saudiarabiska",
    "saudiarabiskornas": "saudiarabiska",
    "saudiarabiskors": "saudiarabiska",
    "saudiarabisks": "saudiarabisk",
    "saudiarabiskt": "saudiarabisk",
    "saudiarabiskts": "saudiarabisk",
    "saudiarabs": "saudiarab",
    "saudiern": "saudier",
    "saudierna": "saudier",
    "saudiernas": "saudier",
    "saudierns": "saudier",
    "saudiers": "saudier",
    "saudiska": "saudisk",
    "saudiskare": "saudisk",
    "saudiskares": "saudisk",
    "saudiskas": "saudisk",
    "saudiskast": "saudisk",
    "saudiskaste": "saudisk",
    "saudiskastes": "saudisk",
    "saudiskasts": "saudisk",
    "saudiske": "saudisk",
    "saudiskes": "saudisk",
    "saudisks": "saudisk",
    "saudiskt": "saudisk",
    "saudiskts": "saudisk",
    "sauerkrauten": "sauerkraut",
    "sauerkrautens": "sauerkraut",
    "sauerkrauts": "sauerkraut",
    "saun": "sauna",
    "saunan": "sauna",
    "saunans": "sauna",
    "saunas": "sauna",
    "saune": "sauna",
    "saunor": "sauna",
    "saunorna": "sauna",
    "saunornas": "sauna",
    "saunors": "sauna",
    "sauns": "sauna",
    "sauterad": "sautera",
    "sauterade": "sautera",
    "sauterades": "sautera",
    "sauterads": "sautera",
    "sauterande": "sautera",
    "sauteranden": "sauterande",
    "sauterandena": "sauterande",
    "sauterandenas": "sauterande",
    "sauterandens": "sauterande",
    "sauterandes": "sauterande",
    "sauterandet": "sauterande",
    "sauterandets": "sauterande",
    "sauterar": "sautera",
    "sauteras": "sautera",
    "sauterat": "sautera",
    "sauterats": "sautera",
    "sauterbara": "sauterbar",
    "sauterbarare": "sauterbar",
    "sauterbarares": "sauterbar",
    "sauterbaras": "sauterbar",
    "sauterbarast": "sauterbar",
    "sauterbaraste": "sauterbar",
    "sauterbarastes": "sauterbar",
    "sauterbarasts": "sauterbar",
    "sauterbare": "sauterbar",
    "sauterbares": "sauterbar",
    "sauterbarheten": "sauterbarhet",
    "sauterbarhetens": "sauterbarhet",
    "sauterbarhets": "sauterbarhet",
    "sauterbars": "sauterbar",
    "sauterbart": "sauterbar",
    "sauterbarts": "sauterbar",
    "sauteringar": "sautering",
    "sauteringarna": "sautering",
    "sauteringarnas": "sautering",
    "sauteringars": "sautering",
    "sauteringen": "sautering",
    "sauteringens": "sautering",
    "sauterings": "sautering",
    "sauternesen": "sauternes",
    "sauternesens": "sauternes",
    "sautéer": "sauté",
    "sautéerna": "sauté",
    "sautéernas": "sauté",
    "sautéers": "sauté",
    "sautén": "sauté",
    "sauténs": "sauté",
    "sautés": "sauté",
    "sauverad": "sauvera",
    "sauverade": "sauvera",
    "sauverades": "sauvera",
    "sauverads": "sauvera",
    "sauverande": "sauvera",
    "sauveranden": "sauverande",
    "sauverandena": "sauverande",
    "sauverandenas": "sauverande",
    "sauverandens": "sauverande",
    "sauverandes": "sauverande",
    "sauverandet": "sauverande",
    "sauverandets": "sauverande",
    "sauverar": "sauvera",
    "sauveras": "sauvera",
    "sauverat": "sauvera",
    "sauverats": "sauvera",
    "sauverbara": "sauverbar",
    "sauverbarare": "sauverbar",
    "sauverbarares": "sauverbar",
    "sauverbaras": "sauverbar",
    "sauverbarast": "sauverbar",
    "sauverbaraste": "sauverbar",
    "sauverbarastes": "sauverbar",
    "sauverbarasts": "sauverbar",
    "sauverbare": "sauverbar",
    "sauverbares": "sauverbar",
    "sauverbarheten": "sauverbarhet",
    "sauverbarhetens": "sauverbarhet",
    "sauverbarhets": "sauverbarhet",
    "sauverbars": "sauverbar",
    "sauverbart": "sauverbar",
    "sauverbarts": "sauverbar",
    "sauveringar": "sauvering",
    "sauveringarna": "sauvering",
    "sauveringarnas": "sauvering",
    "sauveringars": "sauvering",
    "sauveringen": "sauvering",
    "sauveringens": "sauvering",
    "sauverings": "sauvering",
    "savade": "sava",
    "savades": "sava",
    "savande": "sava",
    "savanden": "savande",
    "savandena": "savande",
    "savandenas": "savande",
    "savandens": "savande",
    "savandes": "savande",
    "savandet": "savande",
    "savandets": "savande",
    "savannen": "savann",
    "savannens": "savann",
    "savanner": "savann",
    "savannerna": "savann",
    "savannernas": "savann",
    "savanners": "savann",
    "savanns": "savann",
    "savar": "sava",
    "savarinen": "savarin",
    "savarinens": "savarin",
    "savariner": "savarin",
    "savarinerna": "savarin",
    "savarinernas": "savarin",
    "savariners": "savarin",
    "savarins": "savarin",
    "savas": "sava",
    "savat": "sava",
    "savats": "sava",
    "saven": "sav",
    "savens": "sav",
    "saviga": "savig",
    "savigare": "savig",
    "savigares": "savig",
    "savigas": "savig",
    "savigast": "savig",
    "savigaste": "savig",
    "savigastes": "savig",
    "savigasts": "savig",
    "savige": "savig",
    "saviges": "savig",
    "savigs": "savig",
    "savigt": "savig",
    "savigts": "savig",
    "savningar": "savning",
    "savningarna": "savning",
    "savningarnas": "savning",
    "savningars": "savning",
    "savningen": "savning",
    "savningens": "savning",
    "savnings": "savning",
    "savningstiden": "savningstid",
    "savningstidens": "savningstid",
    "savningstider": "savningstid",
    "savningstiderna": "savningstid",
    "savningstidernas": "savningstid",
    "savningstiders": "savningstid",
    "savningstids": "savningstid",
    "savoir-faires": "savoir-faire",
    "savoir-vivres": "savoir-vivre",
    "savojarden": "savojard",
    "savojardens": "savojard",
    "savojarder": "savojard",
    "savojarderna": "savojard",
    "savojardernas": "savojard",
    "savojarders": "savojard",
    "savojards": "savojard",
    "savojkålen": "savojkål",
    "savojkålens": "savojkål",
    "savojkåls": "savojkål",
    "savs": "sav",
    "savtiden": "savtid",
    "savtidens": "savtid",
    "savtider": "savtid",
    "savtiderna": "savtid",
    "savtidernas": "savtid",
    "savtiders": "savtid",
    "savtids": "savtid",
    "sax": "saxa",
    "saxad": "saxa",
    "saxade": "saxa",
    "saxades": "saxa",
    "saxads": "saxa",
    "saxande": "saxa",
    "saxanden": "saxande",
    "saxandena": "saxande",
    "saxandenas": "saxande",
    "saxandens": "saxande",
    "saxandes": "saxande",
    "saxandet": "saxande",
    "saxandets": "saxande",
    "saxar": "saxare",
    "saxaren": "saxare",
    "saxarens": "saxare",
    "saxares": "saxare",
    "saxarmar": "saxarm",
    "saxarmarna": "saxarm",
    "saxarmarnas": "saxarm",
    "saxarmars": "saxarm",
    "saxarmen": "saxarm",
    "saxarmens": "saxarm",
    "saxarms": "saxarm",
    "saxarna": "saxare",
    "saxarnas": "saxare",
    "saxars": "sax",
    "saxas": "saxa",
    "saxat": "saxa",
    "saxats": "saxa",
    "saxbladen": "saxblad",
    "saxbladens": "saxblad",
    "saxbladet": "saxblad",
    "saxbladets": "saxblad",
    "saxblads": "saxblad",
    "saxdomkraften": "saxdomkraft",
    "saxdomkraftens": "saxdomkraft",
    "saxdomkrafter": "saxdomkraft",
    "saxdomkrafterna": "saxdomkraft",
    "saxdomkrafternas": "saxdomkraft",
    "saxdomkrafters": "saxdomkraft",
    "saxdomkrafts": "saxdomkraft",
    "saxen": "sax",
    "saxens": "sax",
    "saxformiga": "saxformig",
    "saxformigare": "saxformig",
    "saxformigares": "saxformig",
    "saxformigas": "saxformig",
    "saxformigast": "saxformig",
    "saxformigaste": "saxformig",
    "saxformigastes": "saxformig",
    "saxformigasts": "saxformig",
    "saxformige": "saxformig",
    "saxformiges": "saxformig",
    "saxformigheten": "saxformighet",
    "saxformighetens": "saxformighet",
    "saxformighets": "saxformighet",
    "saxformigs": "saxformig",
    "saxformigt": "saxformig",
    "saxformigts": "saxformig",
    "saxiska": "saxisk",
    "saxiskare": "saxisk",
    "saxiskares": "saxisk",
    "saxiskas": "saxisk",
    "saxiskast": "saxisk",
    "saxiskaste": "saxisk",
    "saxiskastes": "saxisk",
    "saxiskasts": "saxisk",
    "saxiske": "saxisk",
    "saxiskes": "saxisk",
    "saxisks": "saxisk",
    "saxiskt": "saxisk",
    "saxiskts": "saxisk",
    "saxkrokar": "saxkrok",
    "saxkrokarna": "saxkrok",
    "saxkrokarnas": "saxkrok",
    "saxkrokars": "saxkrok",
    "saxkroken": "saxkrok",
    "saxkrokens": "saxkrok",
    "saxkroks": "saxkrok",
    "saxnäbbar": "saxnäbb",
    "saxnäbbarna": "saxnäbb",
    "saxnäbbarnas": "saxnäbb",
    "saxnäbbars": "saxnäbb",
    "saxnäbben": "saxnäbb",
    "saxnäbbens": "saxnäbb",
    "saxnäbbs": "saxnäbb",
    "saxofonen": "saxofon",
    "saxofonens": "saxofon",
    "saxofoner": "saxofon",
    "saxofonerna": "saxofon",
    "saxofonernas": "saxofon",
    "saxofoners": "saxofon",
    "saxofons": "saxofon",
    "saxredskapen": "saxredskap",
    "saxredskapens": "saxredskap",
    "saxredskapet": "saxredskap",
    "saxredskapets": "saxredskap",
    "saxredskaps": "saxredskap",
    "saxskalmar": "saxskalm",
    "saxskalmarna": "saxskalm",
    "saxskalmarnas": "saxskalm",
    "saxskalmars": "saxskalm",
    "saxskalmen": "saxskalm",
    "saxskalmens": "saxskalm",
    "saxskalms": "saxskalm",
    "saxskänkeln": "saxskänkel",
    "saxskänkelns": "saxskänkel",
    "saxskänkels": "saxskänkel",
    "saxskänklar": "saxskänkel",
    "saxskänklarna": "saxskänkel",
    "saxskänklarnas": "saxskänkel",
    "saxskänklars": "saxskänkel",
    "saxskären": "saxskär",
    "saxskärens": "saxskär",
    "saxskäret": "saxskär",
    "saxskärets": "saxskär",
    "saxskärs": "saxskär",
    "saxsprintar": "saxsprint",
    "saxsprintarna": "saxsprint",
    "saxsprintarnas": "saxsprint",
    "saxsprintars": "saxsprint",
    "saxsprinten": "saxsprint",
    "saxsprintens": "saxsprint",
    "saxsprints": "saxsprint",
    "sbirren": "sbirr",
    "sbirrens": "sbirr",
    "sbirrer": "sbirr",
    "sbirrerna": "sbirr",
    "sbirrernas": "sbirr",
    "sbirrers": "sbirr",
    "sbirrs": "sbirr",
    "scannad": "scanna",
    "scannade": "scanna",
    "scannades": "scanna",
    "scannads": "scanna",
    "scannande": "scanna",
    "scannanden": "scannande",
    "scannandena": "scannande",
    "scannandenas": "scannande",
    "scannandens": "scannande",
    "scannandes": "scannande",
    "scannandet": "scannande",
    "scannandets": "scannande",
    "scannar": "scanna",
    "scannas": "scanna",
    "scannat": "scanna",
    "scannats": "scanna",
    "scannern": "scanner",
    "scannerna": "scanner",
    "scannernas": "scanner",
    "scannerns": "scanner",
    "scanners": "scanner",
    "scannersarna": "scanner",
    "scannersarnas": "scanner",
    "scanningar": "scanning",
    "scanningarna": "scanning",
    "scanningarnas": "scanning",
    "scanningars": "scanning",
    "scanningen": "scanning",
    "scanningens": "scanning",
    "scannings": "scanning",
    "scannrar": "scanner",
    "scannrarna": "scanner",
    "scannrarnas": "scanner",
    "scannrars": "scanner",
    "scarfar": "scarf",
    "scarfarna": "scarf",
    "scarfarnas": "scarf",
    "scarfars": "scarf",
    "scarfen": "scarf",
    "scarfens": "scarf",
    "scarfs": "scarf",
    "scarlatinan": "scarlatina",
    "scarlatinans": "scarlatina",
    "scarlatinas": "scarlatina",
    "scarves": "scarf",
    "scarvesen": "scarf",
    "scarvesens": "scarf",
    "scatsången": "scatsång",
    "scatsångens": "scatsång",
    "scatsångs": "scatsång",
    "scenanvisningar": "scenanvisning",
    "scenanvisningarna": "scenanvisning",
    "scenanvisningarnas": "scenanvisning",
    "scenanvisningars": "scenanvisning",
    "scenanvisningen": "scenanvisning",
    "scenanvisningens": "scenanvisning",
    "scenanvisnings": "scenanvisning",
    "scenarbetar": "scenarbetare",
    "scenarbetaren": "scenarbetare",
    "scenarbetarens": "scenarbetare",
    "scenarbetares": "scenarbetare",
    "scenarbetarna": "scenarbetare",
    "scenarbetarnas": "scenarbetare",
    "scenarier": "scenario",
    "scenarierna": "scenario",
    "scenariernas": "scenario",
    "scenariers": "scenario",
    "scenarion": "scenario",
    "scenariona": "scenario",
    "scenarionas": "scenario",
    "scenarions": "scenario",
    "scenarios": "scenario",
    "scenariot": "scenario",
    "scenariots": "scenario",
    "scenbearbetningar": "scenbearbetning",
    "scenbearbetningarna": "scenbearbetning",
    "scenbearbetningarnas": "scenbearbetning",
    "scenbearbetningars": "scenbearbetning",
    "scenbearbetningen": "scenbearbetning",
    "scenbearbetningens": "scenbearbetning",
    "scenbearbetnings": "scenbearbetning",
    "scenbilden": "scenbild",
    "scenbildens": "scenbild",
    "scenbilder": "scenbild",
    "scenbilderna": "scenbild",
    "scenbildernas": "scenbild",
    "scenbilders": "scenbild",
    "scenbilds": "scenbild",
    "scenen": "scen",
    "scenens": "scen",
    "scener": "scen",
    "scenerier": "sceneri",
    "scenerierna": "sceneri",
    "sceneriernas": "sceneri",
    "sceneriers": "sceneri",
    "sceneriet": "sceneri",
    "sceneriets": "sceneri",
    "sceneris": "sceneri",
    "scenerit": "sceneri",
    "scenerits": "sceneri",
    "scenerna": "scen",
    "scenernas": "scen",
    "sceners": "scen",
    "scenframträdanden": "scenframträdande",
    "scenframträdandena": "scenframträdande",
    "scenframträdandenas": "scenframträdande",
    "scenframträdandens": "scenframträdande",
    "scenframträdandes": "scenframträdande",
    "scenframträdandet": "scenframträdande",
    "scenframträdandets": "scenframträdande",
    "scenförändringar": "scenförändring",
    "scenförändringarna": "scenförändring",
    "scenförändringarnas": "scenförändring",
    "scenförändringars": "scenförändring",
    "scenförändringen": "scenförändring",
    "scenförändringens": "scenförändring",
    "scenförändrings": "scenförändring",
    "sceningångar": "sceningång",
    "sceningångarna": "sceningång",
    "sceningångarnas": "sceningång",
    "sceningångars": "sceningång",
    "sceningången": "sceningång",
    "sceningångens": "sceningång",
    "sceningångs": "sceningång",
    "sceninstruktören": "sceninstruktör",
    "sceninstruktörens": "sceninstruktör",
    "sceninstruktörer": "sceninstruktör",
    "sceninstruktörerna": "sceninstruktör",
    "sceninstruktörernas": "sceninstruktör",
    "sceninstruktörers": "sceninstruktör",
    "sceninstruktörs": "sceninstruktör",
    "sceniska": "scenisk",
    "sceniskare": "scenisk",
    "sceniskares": "scenisk",
    "sceniskas": "scenisk",
    "sceniskast": "scenisk",
    "sceniskaste": "scenisk",
    "sceniskastes": "scenisk",
    "sceniskasts": "scenisk",
    "sceniske": "scenisk",
    "sceniskes": "scenisk",
    "scenisks": "scenisk",
    "sceniskt": "scenisk",
    "sceniskts": "scenisk",
    "scenkonsten": "scenkonst",
    "scenkonstens": "scenkonst",
    "scenkonsts": "scenkonst",
    "scenografen": "scenograf",
    "scenografens": "scenograf",
    "scenografer": "scenograf",
    "scenograferna": "scenograf",
    "scenografernas": "scenograf",
    "scenografers": "scenograf",
    "scenografien": "scenografi",
    "scenografiens": "scenografi",
    "scenografin": "scenografi",
    "scenografins": "scenografi",
    "scenografis": "scenografi",
    "scenografs": "scenograf",
    "scens": "scen",
    "scenshowen": "scenshow",
    "scenshowens": "scenshow",
    "scenshower": "scenshow",
    "scenshowerna": "scenshow",
    "scenshowernas": "scenshow",
    "scenshowers": "scenshow",
    "scenshows": "scenshow",
    "scenskolan": "scenskola",
    "scenskolans": "scenskola",
    "scenskolas": "scenskola",
    "scenskole": "scenskola",
    "scenskolor": "scenskola",
    "scenskolorna": "scenskola",
    "scenskolornas": "scenskola",
    "scenskolors": "scenskola",
    "scenskräcken": "scenskräck",
    "scenskräckens": "scenskräck",
    "scenskräcks": "scenskräck",
    "scenuppföranden": "scenuppförande",
    "scenuppförandena": "scenuppförande",
    "scenuppförandenas": "scenuppförande",
    "scenuppförandens": "scenuppförande",
    "scenuppförandes": "scenuppförande",
    "scenuppförandet": "scenuppförande",
    "scenuppförandets": "scenuppförande",
    "scenuppsättningar": "scenuppsättning",
    "scenuppsättningarna": "scenuppsättning",
    "scenuppsättningarnas": "scenuppsättning",
    "scenuppsättningars": "scenuppsättning",
    "scenuppsättningen": "scenuppsättning",
    "scenuppsättningens": "scenuppsättning",
    "scenuppsättnings": "scenuppsättning",
    "scenuttalet": "scenuttal",
    "scenuttalets": "scenuttal",
    "scenuttals": "scenuttal",
    "scenvanan": "scenvana",
    "scenvanans": "scenvana",
    "scenvanas": "scenvana",
    "scenvane": "scenvana",
    "scenvindar": "scenvind",
    "scenvindarna": "scenvind",
    "scenvindarnas": "scenvind",
    "scenvindars": "scenvind",
    "scenvinden": "scenvind",
    "scenvindens": "scenvind",
    "scenvinds": "scenvind",
    "scenväxlingar": "scenväxling",
    "scenväxlingarna": "scenväxling",
    "scenväxlingarnas": "scenväxling",
    "scenväxlingars": "scenväxling",
    "scenväxlingen": "scenväxling",
    "scenväxlingens": "scenväxling",
    "scenväxlings": "scenväxling",
    "scenöppningar": "scenöppning",
    "scenöppningarna": "scenöppning",
    "scenöppningarnas": "scenöppning",
    "scenöppningars": "scenöppning",
    "scenöppningen": "scenöppning",
    "scenöppningens": "scenöppning",
    "scenöppnings": "scenöppning",
    "scepters": "scepter",
    "sceptren": "scepter",
    "sceptrens": "scepter",
    "sceptret": "scepter",
    "sceptrets": "scepter",
    "schabbel": "schabbla",
    "schabbels": "schabbel",
    "schabbelverket": "schabbelverk",
    "schabbelverkets": "schabbelverk",
    "schabbelverks": "schabbelverk",
    "schabblade": "schabbla",
    "schabblades": "schabbla",
    "schabblande": "schabbla",
    "schabblanden": "schabblande",
    "schabblandena": "schabblande",
    "schabblandenas": "schabblande",
    "schabblandens": "schabblande",
    "schabblandes": "schabblande",
    "schabblandet": "schabblande",
    "schabblandets": "schabblande",
    "schabblar": "schabbla",
    "schabblas": "schabbla",
    "schabblat": "schabbla",
    "schabblats": "schabbla",
    "schabblen": "schabbel",
    "schabblens": "schabbel",
    "schabblet": "schabbel",
    "schabblets": "schabbel",
    "schaberna": "schaber",
    "schabernas": "schaber",
    "schabers": "schaber",
    "schablonavdragen": "schablonavdrag",
    "schablonavdragens": "schablonavdrag",
    "schablonavdraget": "schablonavdrag",
    "schablonavdragets": "schablonavdrag",
    "schablonavdrags": "schablonavdrag",
    "schablonbeloppen": "schablonbelopp",
    "schablonbeloppens": "schablonbelopp",
    "schablonbeloppet": "schablonbelopp",
    "schablonbeloppets": "schablonbelopp",
    "schablonbelopps": "schablonbelopp",
    "schablonen": "schablon",
    "schablonens": "schablon",
    "schabloner": "schablon",
    "schablonerad": "schablonera",
    "schablonerade": "schablonera",
    "schablonerades": "schablonera",
    "schablonerads": "schablonera",
    "schablonerande": "schablonera",
    "schabloneranden": "schablonerande",
    "schablonerandena": "schablonerande",
    "schablonerandenas": "schablonerande",
    "schablonerandens": "schablonerande",
    "schablonerandes": "schablonerande",
    "schablonerandet": "schablonerande",
    "schablonerandets": "schablonerande",
    "schablonerar": "schablonera",
    "schabloneras": "schablonera",
    "schablonerat": "schablonera",
    "schablonerats": "schablonera",
    "schablonerbara": "schablonerbar",
    "schablonerbarare": "schablonerbar",
    "schablonerbarares": "schablonerbar",
    "schablonerbaras": "schablonerbar",
    "schablonerbarast": "schablonerbar",
    "schablonerbaraste": "schablonerbar",
    "schablonerbarastes": "schablonerbar",
    "schablonerbarasts": "schablonerbar",
    "schablonerbare": "schablonerbar",
    "schablonerbares": "schablonerbar",
    "schablonerbarheten": "schablonerbarhet",
    "schablonerbarhetens": "schablonerbarhet",
    "schablonerbarhets": "schablonerbarhet",
    "schablonerbars": "schablonerbar",
    "schablonerbart": "schablonerbar",
    "schablonerbarts": "schablonerbar",
    "schabloneringar": "schablonering",
    "schabloneringarna": "schablonering",
    "schabloneringarnas": "schablonering",
    "schabloneringars": "schablonering",
    "schabloneringen": "schablonering",
    "schabloneringens": "schablonering",
    "schablonerings": "schablonering",
    "schablonerna": "schablon",
    "schablonernas": "schablon",
    "schabloners": "schablon",
    "schabloniserad": "schablonisera",
    "schabloniserade": "schablonisera",
    "schabloniserades": "schablonisera",
    "schabloniserads": "schablonisera",
    "schabloniserande": "schablonisera",
    "schabloniseranden": "schabloniserande",
    "schabloniserandena": "schabloniserande",
    "schabloniserandenas": "schabloniserande",
    "schabloniserandens": "schabloniserande",
    "schabloniserandes": "schabloniserande",
    "schabloniserandet": "schabloniserande",
    "schabloniserandets": "schabloniserande",
    "schabloniserar": "schablonisera",
    "schabloniseras": "schablonisera",
    "schabloniserat": "schablonisera",
    "schabloniserats": "schablonisera",
    "schabloniserbara": "schabloniserbar",
    "schabloniserbarare": "schabloniserbar",
    "schabloniserbarares": "schabloniserbar",
    "schabloniserbaras": "schabloniserbar",
    "schabloniserbarast": "schabloniserbar",
    "schabloniserbaraste": "schabloniserbar",
    "schabloniserbarastes": "schabloniserbar",
    "schabloniserbarasts": "schabloniserbar",
    "schabloniserbare": "schabloniserbar",
    "schabloniserbares": "schabloniserbar",
    "schabloniserbarheten": "schabloniserbarhet",
    "schabloniserbarhetens": "schabloniserbarhet",
    "schabloniserbarhets": "schabloniserbarhet",
    "schabloniserbars": "schabloniserbar",
    "schabloniserbart": "schabloniserbar",
    "schabloniserbarts": "schabloniserbar",
    "schabloniseringar": "schablonisering",
    "schabloniseringarna": "schablonisering",
    "schabloniseringarnas": "schablonisering",
    "schabloniseringars": "schablonisering",
    "schabloniseringen": "schablonisering",
    "schabloniseringens": "schablonisering",
    "schabloniserings": "schablonisering",
    "schablonmässiga": "schablonmässig",
    "schablonmässigare": "schablonmässig",
    "schablonmässigares": "schablonmässig",
    "schablonmässigas": "schablonmässig",
    "schablonmässigast": "schablonmässig",
    "schablonmässigaste": "schablonmässig",
    "schablonmässigastes": "schablonmässig",
    "schablonmässigasts": "schablonmässig",
    "schablonmässige": "schablonmässig",
    "schablonmässiges": "schablonmässig",
    "schablonmässigheten": "schablonmässighet",
    "schablonmässighetens": "schablonmässighet",
    "schablonmässighets": "schablonmässighet",
    "schablonmässigs": "schablonmässig",
    "schablonmässigt": "schablonmässig",
    "schablonmässigts": "schablonmässig",
    "schablons": "schablon",
    "schablontaxerad": "schablontaxera",
    "schablontaxerade": "schablontaxera",
    "schablontaxerades": "schablontaxera",
    "schablontaxerads": "schablontaxera",
    "schablontaxerande": "schablontaxera",
    "schablontaxeranden": "schablontaxerande",
    "schablontaxerandena": "schablontaxerande",
    "schablontaxerandenas": "schablontaxerande",
    "schablontaxerandens": "schablontaxerande",
    "schablontaxerandes": "schablontaxerande",
    "schablontaxerandet": "schablontaxerande",
    "schablontaxerandets": "schablontaxerande",
    "schablontaxerar": "schablontaxera",
    "schablontaxeras": "schablontaxera",
    "schablontaxerat": "schablontaxera",
    "schablontaxerats": "schablontaxera",
    "schablontaxerbara": "schablontaxerbar",
    "schablontaxerbarare": "schablontaxerbar",
    "schablontaxerbarares": "schablontaxerbar",
    "schablontaxerbaras": "schablontaxerbar",
    "schablontaxerbarast": "schablontaxerbar",
    "schablontaxerbaraste": "schablontaxerbar",
    "schablontaxerbarastes": "schablontaxerbar",
    "schablontaxerbarasts": "schablontaxerbar",
    "schablontaxerbare": "schablontaxerbar",
    "schablontaxerbares": "schablontaxerbar",
    "schablontaxerbarheten": "schablontaxerbarhet",
    "schablontaxerbarhetens": "schablontaxerbarhet",
    "schablontaxerbarhets": "schablontaxerbarhet",
    "schablontaxerbars": "schablontaxerbar",
    "schablontaxerbart": "schablontaxerbar",
    "schablontaxerbarts": "schablontaxerbar",
    "schablontaxeringar": "schablontaxering",
    "schablontaxeringarna": "schablontaxering",
    "schablontaxeringarnas": "schablontaxering",
    "schablontaxeringars": "schablontaxering",
    "schablontaxeringen": "schablontaxering",
    "schablontaxeringens": "schablontaxering",
    "schablontaxerings": "schablontaxering",
    "schablontilläggen": "schablontillägg",
    "schablontilläggens": "schablontillägg",
    "schablontillägget": "schablontillägg",
    "schablontilläggets": "schablontillägg",
    "schablontilläggs": "schablontillägg",
    "schabraken": "schabrak",
    "schabrakens": "schabrak",
    "schabraket": "schabrak",
    "schabrakets": "schabrak",
    "schabraks": "schabrak",
    "schack": "schacka",
    "schackad": "schacka",
    "schackade": "schacka",
    "schackades": "schacka",
    "schackads": "schacka",
    "schackande": "schacka",
    "schackanden": "schackande",
    "schackandena": "schackande",
    "schackandenas": "schackande",
    "schackandens": "schackande",
    "schackandes": "schackande",
    "schackandet": "schackande",
    "schackandets": "schackande",
    "schackar": "schacka",
    "schackas": "schacka",
    "schackat": "schacka",
    "schackats": "schacka",
    "schackborden": "schackbord",
    "schackbordens": "schackbord",
    "schackbordet": "schackbord",
    "schackbordets": "schackbord",
    "schackbords": "schackbord",
    "schackbräd": "schackbräda",
    "schackbrädan": "schackbräda",
    "schackbrädans": "schackbräda",
    "schackbrädas": "schackbräda",
    "schackbräde": "schackbräda",
    "schackbräden": "schackbräde",
    "schackbrädena": "schackbräde",
    "schackbrädenas": "schackbräde",
    "schackbrädens": "schackbräde",
    "schackbrädes": "schackbräde",
    "schackbrädet": "schackbräde",
    "schackbrädets": "schackbräde",
    "schackbrädor": "schackbräda",
    "schackbrädorna": "schackbräda",
    "schackbrädornas": "schackbräda",
    "schackbrädors": "schackbräda",
    "schackbräds": "schackbräda",
    "schackdragen": "schackdrag",
    "schackdragens": "schackdrag",
    "schackdraget": "schackdrag",
    "schackdragets": "schackdrag",
    "schackdrags": "schackdrag",
    "schackel": "schackla",
    "schackeln": "schackel",
    "schackelns": "schackel",
    "schackels": "schackel",
    "schacker": "schackra",
    "schackers": "schacker",
    "schacket": "schack",
    "schackets": "schack",
    "schacklad": "schackla",
    "schacklade": "schackla",
    "schacklades": "schackla",
    "schacklads": "schackla",
    "schacklande": "schackla",
    "schacklanden": "schacklande",
    "schacklandena": "schacklande",
    "schacklandenas": "schacklande",
    "schacklandens": "schacklande",
    "schacklandes": "schacklande",
    "schacklandet": "schacklande",
    "schacklandets": "schacklande",
    "schacklar": "schackla",
    "schacklarna": "schackel",
    "schacklarnas": "schackel",
    "schacklars": "schackel",
    "schacklas": "schackla",
    "schacklat": "schackla",
    "schacklats": "schackla",
    "schackmönsterna": "schackmönster",
    "schackmönsternas": "schackmönster",
    "schackmönsters": "schackmönster",
    "schackmönstren": "schackmönster",
    "schackmönstrens": "schackmönster",
    "schackmönstret": "schackmönster",
    "schackmönstrets": "schackmönster",
    "schackningsperioden": "schackningsperiod",
    "schackningsperiodens": "schackningsperiod",
    "schackningsperioder": "schackningsperiod",
    "schackningsperioderna": "schackningsperiod",
    "schackningsperiodernas": "schackningsperiod",
    "schackningsperioders": "schackningsperiod",
    "schackningsperiods": "schackningsperiod",
    "schackpartier": "schackparti",
    "schackpartierna": "schackparti",
    "schackpartiernas": "schackparti",
    "schackpartiers": "schackparti",
    "schackpartiet": "schackparti",
    "schackpartiets": "schackparti",
    "schackpartis": "schackparti",
    "schackpartit": "schackparti",
    "schackpartits": "schackparti",
    "schackpjäsen": "schackpjäs",
    "schackpjäsens": "schackpjäs",
    "schackpjäser": "schackpjäs",
    "schackpjäserna": "schackpjäs",
    "schackpjäsernas": "schackpjäs",
    "schackpjäsers": "schackpjäs",
    "schackproblemen": "schackproblem",
    "schackproblemens": "schackproblem",
    "schackproblemet": "schackproblem",
    "schackproblemets": "schackproblem",
    "schackproblems": "schackproblem",
    "schackrade": "schackra",
    "schackrades": "schackra",
    "schackrande": "schackra",
    "schackranden": "schackrande",
    "schackrandena": "schackrande",
    "schackrandenas": "schackrande",
    "schackrandens": "schackrande",
    "schackrandes": "schackrande",
    "schackrandet": "schackrande",
    "schackrandets": "schackrande",
    "schackrar": "schackrare",
    "schackraren": "schackrare",
    "schackrarens": "schackrare",
    "schackrares": "schackrare",
    "schackrarna": "schackrare",
    "schackrarnas": "schackrare",
    "schackras": "schackra",
    "schackrat": "schackra",
    "schackrats": "schackra",
    "schackret": "schacker",
    "schackrets": "schacker",
    "schacks": "schack",
    "schackspelar": "schackspelare",
    "schackspelaren": "schackspelare",
    "schackspelarens": "schackspelare",
    "schackspelares": "schackspelare",
    "schackspelarna": "schackspelare",
    "schackspelarnas": "schackspelare",
    "schackspelen": "schackspel",
    "schackspelens": "schackspel",
    "schackspelet": "schackspel",
    "schackspelets": "schackspel",
    "schackspels": "schackspel",
    "schackturneringar": "schackturnering",
    "schackturneringarna": "schackturnering",
    "schackturneringarnas": "schackturnering",
    "schackturneringars": "schackturnering",
    "schackturneringen": "schackturnering",
    "schackturneringens": "schackturnering",
    "schackturnerings": "schackturnering",
    "schaggen": "schagg",
    "schaggens": "schagg",
    "schagger": "schagg",
    "schaggerna": "schagg",
    "schaggernas": "schagg",
    "schaggers": "schagg",
    "schaggs": "schagg",
    "schahen": "schah",
    "schahens": "schah",
    "schaher": "schah",
    "schaherna": "schah",
    "schahernas": "schah",
    "schahers": "schah",
    "schahs": "schah",
    "schajasar": "schajas",
    "schajasarna": "schajas",
    "schajasarnas": "schajas",
    "schajasars": "schajas",
    "schajasen": "schajas",
    "schajasens": "schajas",
    "schakalen": "schakal",
    "schakalens": "schakal",
    "schakaler": "schakal",
    "schakalerna": "schakal",
    "schakalernas": "schakal",
    "schakalers": "schakal",
    "schakals": "schakal",
    "schakt": "schakta",
    "schaktad": "schakta",
    "schaktade": "schakta",
    "schaktades": "schakta",
    "schaktads": "schakta",
    "schaktande": "schakta",
    "schaktanden": "schaktande",
    "schaktandena": "schaktande",
    "schaktandenas": "schaktande",
    "schaktandens": "schaktande",
    "schaktandes": "schaktande",
    "schaktandet": "schaktande",
    "schaktandets": "schaktande",
    "schaktar": "schakta",
    "schaktas": "schakta",
    "schaktat": "schakta",
    "schaktats": "schakta",
    "schakten": "schakt",
    "schaktens": "schakt",
    "schaktet": "schakt",
    "schaktets": "schakt",
    "schaktkanten": "schaktkant",
    "schaktkantens": "schaktkant",
    "schaktkanter": "schaktkant",
    "schaktkanterna": "schaktkant",
    "schaktkanternas": "schaktkant",
    "schaktkanters": "schaktkant",
    "schaktkants": "schaktkant",
    "schaktmaskinen": "schaktmaskin",
    "schaktmaskinens": "schaktmaskin",
    "schaktmaskiner": "schaktmaskin",
    "schaktmaskinerna": "schaktmaskin",
    "schaktmaskinernas": "schaktmaskin",
    "schaktmaskiners": "schaktmaskin",
    "schaktmaskins": "schaktmaskin",
    "schaktmassan": "schaktmassa",
    "schaktmassans": "schaktmassa",
    "schaktmassas": "schaktmassa",
    "schaktmasse": "schaktmassa",
    "schaktmassor": "schaktmassa",
    "schaktmassorna": "schaktmassa",
    "schaktmassornas": "schaktmassa",
    "schaktmassors": "schaktmassa",
    "schakts": "schakt",
    "schaktugnar": "schaktugn",
    "schaktugnarna": "schaktugn",
    "schaktugnarnas": "schaktugn",
    "schaktugnars": "schaktugn",
    "schaktugnen": "schaktugn",
    "schaktugnens": "schaktugn",
    "schaktugns": "schaktugn",
    "schakåer": "schakå",
    "schakåerna": "schakå",
    "schakåernas": "schakå",
    "schakåers": "schakå",
    "schakån": "schakå",
    "schakåns": "schakå",
    "schakås": "schakå",
    "schalar": "schal",
    "schalarna": "schal",
    "schalarnas": "schal",
    "schalars": "schal",
    "schalen": "schal",
    "schalens": "schal",
    "schaletten": "schalett",
    "schalettens": "schalett",
    "schaletter": "schalett",
    "schaletterna": "schalett",
    "schaletternas": "schalett",
    "schaletters": "schalett",
    "schaletts": "schalett",
    "schalomen": "schalom",
    "schalomens": "schalom",
    "schalomet": "schalom",
    "schalomets": "schalom",
    "schaloms": "schalom",
    "schalottenlökar": "schalottenlök",
    "schalottenlökarna": "schalottenlök",
    "schalottenlökarnas": "schalottenlök",
    "schalottenlökars": "schalottenlök",
    "schalottenlöken": "schalottenlök",
    "schalottenlökens": "schalottenlök",
    "schalottenlöks": "schalottenlök",
    "schals": "schal",
    "schamanen": "schaman",
    "schamanens": "schaman",
    "schamaner": "schaman",
    "schamanerna": "schaman",
    "schamanernas": "schaman",
    "schamaners": "schaman",
    "schamanismen": "schamanism",
    "schamanismens": "schamanism",
    "schamanismer": "schamanism",
    "schamanismerna": "schamanism",
    "schamanismernas": "schamanism",
    "schamanismers": "schamanism",
    "schamanisms": "schamanism",
    "schamanistiska": "schamanistisk",
    "schamanistiskas": "schamanistisk",
    "schamanistiske": "schamanistisk",
    "schamanistiskes": "schamanistisk",
    "schamanistisks": "schamanistisk",
    "schamanistiskt": "schamanistisk",
    "schamanistiskts": "schamanistisk",
    "schamans": "schaman",
    "schampon": "schampo",
    "schampona": "schampo",
    "schamponas": "schampo",
    "schamponerad": "schamponera",
    "schamponerade": "schamponera",
    "schamponerades": "schamponera",
    "schamponerads": "schamponera",
    "schamponerande": "schamponera",
    "schamponeranden": "schamponerande",
    "schamponerandena": "schamponerande",
    "schamponerandenas": "schamponerande",
    "schamponerandens": "schamponerande",
    "schamponerandes": "schamponerande",
    "schamponerandet": "schamponerande",
    "schamponerandets": "schamponerande",
    "schamponerar": "schamponera",
    "schamponeras": "schamponera",
    "schamponerat": "schamponera",
    "schamponerats": "schamponera",
    "schamponerbara": "schamponerbar",
    "schamponerbarare": "schamponerbar",
    "schamponerbarares": "schamponerbar",
    "schamponerbaras": "schamponerbar",
    "schamponerbarast": "schamponerbar",
    "schamponerbaraste": "schamponerbar",
    "schamponerbarastes": "schamponerbar",
    "schamponerbarasts": "schamponerbar",
    "schamponerbare": "schamponerbar",
    "schamponerbares": "schamponerbar",
    "schamponerbarheten": "schamponerbarhet",
    "schamponerbarhetens": "schamponerbarhet",
    "schamponerbarhets": "schamponerbarhet",
    "schamponerbars": "schamponerbar",
    "schamponerbart": "schamponerbar",
    "schamponerbarts": "schamponerbar",
    "schamponeringar": "schamponering",
    "schamponeringarna": "schamponering",
    "schamponeringarnas": "schamponering",
    "schamponeringars": "schamponering",
    "schamponeringen": "schamponering",
    "schamponeringens": "schamponering",
    "schamponerings": "schamponering",
    "schampons": "schampo",
    "schampopatronen": "schampopatron",
    "schampopatronens": "schampopatron",
    "schampopatroner": "schampopatron",
    "schampopatronerna": "schampopatron",
    "schampopatronernas": "schampopatron",
    "schampopatroners": "schampopatron",
    "schampopatrons": "schampopatron",
    "schampos": "schampo",
    "schampot": "schampo",
    "schampots": "schampo",
    "schangdobela": "schangdobel",
    "schangdobelare": "schangdobel",
    "schangdobelares": "schangdobel",
    "schangdobelas": "schangdobel",
    "schangdobelast": "schangdobel",
    "schangdobelaste": "schangdobel",
    "schangdobelastes": "schangdobel",
    "schangdobelasts": "schangdobel",
    "schangdobele": "schangdobel",
    "schangdobeles": "schangdobel",
    "schangdobels": "schangdobel",
    "schangdobelt": "schangdobel",
    "schangdobelts": "schangdobel",
    "schanghajad": "schanghaja",
    "schanghajade": "schanghaja",
    "schanghajades": "schanghaja",
    "schanghajads": "schanghaja",
    "schanghajande": "schanghaja",
    "schanghajanden": "schanghajande",
    "schanghajandena": "schanghajande",
    "schanghajandenas": "schanghajande",
    "schanghajandens": "schanghajande",
    "schanghajandes": "schanghajande",
    "schanghajandet": "schanghajande",
    "schanghajandets": "schanghajande",
    "schanghajar": "schanghaja",
    "schanghajas": "schanghaja",
    "schanghajat": "schanghaja",
    "schanghajats": "schanghaja",
    "schangtila": "schangtil",
    "schangtilare": "schangtil",
    "schangtilares": "schangtil",
    "schangtilas": "schangtil",
    "schangtilast": "schangtil",
    "schangtilaste": "schangtil",
    "schangtilastes": "schangtil",
    "schangtilasts": "schangtil",
    "schangtile": "schangtil",
    "schangtiles": "schangtil",
    "schangtils": "schangtil",
    "schangtilt": "schangtil",
    "schangtilts": "schangtil",
    "schankern": "schanker",
    "schankerns": "schanker",
    "schankers": "schanker",
    "schapp": "schappa",
    "schappad": "schappa",
    "schappade": "schappa",
    "schappades": "schappa",
    "schappads": "schappa",
    "schappande": "schappa",
    "schappanden": "schappande",
    "schappandena": "schappande",
    "schappandenas": "schappande",
    "schappandens": "schappande",
    "schappandes": "schappande",
    "schappandet": "schappande",
    "schappandets": "schappande",
    "schappar": "schappa",
    "schappas": "schappa",
    "schappat": "schappa",
    "schappats": "schappa",
    "schappen": "schapp",
    "schappens": "schapp",
    "schappet": "schapp",
    "schappets": "schapp",
    "schapps": "schapp",
    "scharlakanet": "scharlakan",
    "scharlakanets": "scharlakan",
    "scharlakans": "scharlakan",
    "scharlakansfebern": "scharlakansfeber",
    "scharlakansfeberns": "scharlakansfeber",
    "scharlakansfebers": "scharlakansfeber",
    "scharlakansrötts": "scharlakansrött",
    "scharneren": "scharner",
    "scharnerens": "scharner",
    "scharneret": "scharner",
    "scharnerets": "scharner",
    "scharners": "scharner",
    "schartauanen": "schartauan",
    "schartauanens": "schartauan",
    "schartauaner": "schartauan",
    "schartauanerna": "schartauan",
    "schartauanernas": "schartauan",
    "schartauaners": "schartauan",
    "schartauanismen": "schartauanism",
    "schartauanismens": "schartauanism",
    "schartauanismer": "schartauanism",
    "schartauanismerna": "schartauanism",
    "schartauanismernas": "schartauanism",
    "schartauanismers": "schartauanism",
    "schartauanisms": "schartauanism",
    "schartauans": "schartauan",
    "schartauanska": "schartauansk",
    "schartauanskare": "schartauansk",
    "schartauanskares": "schartauansk",
    "schartauanskas": "schartauansk",
    "schartauanskast": "schartauansk",
    "schartauanskaste": "schartauansk",
    "schartauanskastes": "schartauansk",
    "schartauanskasts": "schartauansk",
    "schartauanske": "schartauansk",
    "schartauanskes": "schartauansk",
    "schartauansks": "schartauansk",
    "schartauanskt": "schartauansk",
    "schartauanskts": "schartauansk",
    "schas": "schasa",
    "schasad": "schasa",
    "schasade": "schasa",
    "schasades": "schasa",
    "schasads": "schasa",
    "schasande": "schasa",
    "schasanden": "schasande",
    "schasandena": "schasande",
    "schasandenas": "schasande",
    "schasandens": "schasande",
    "schasandes": "schasande",
    "schasandet": "schasande",
    "schasandets": "schasande",
    "schasar": "schasa",
    "schasas": "schasa",
    "schasat": "schasa",
    "schasats": "schasa",
    "schatterad": "schattera",
    "schatterade": "schattera",
    "schatterades": "schattera",
    "schatterads": "schattera",
    "schatterande": "schattera",
    "schatteranden": "schatterande",
    "schatterandena": "schatterande",
    "schatterandenas": "schatterande",
    "schatterandens": "schatterande",
    "schatterandes": "schatterande",
    "schatterandet": "schatterande",
    "schatterandets": "schatterande",
    "schatterar": "schattera",
    "schatteras": "schattera",
    "schatterat": "schattera",
    "schatterats": "schattera",
    "schatterbara": "schatterbar",
    "schatterbarare": "schatterbar",
    "schatterbarares": "schatterbar",
    "schatterbaras": "schatterbar",
    "schatterbarast": "schatterbar",
    "schatterbaraste": "schatterbar",
    "schatterbarastes": "schatterbar",
    "schatterbarasts": "schatterbar",
    "schatterbare": "schatterbar",
    "schatterbares": "schatterbar",
    "schatterbarheten": "schatterbarhet",
    "schatterbarhetens": "schatterbarhet",
    "schatterbarhets": "schatterbarhet",
    "schatterbars": "schatterbar",
    "schatterbart": "schatterbar",
    "schatterbarts": "schatterbar",
    "schatteringar": "schattering",
    "schatteringarna": "schattering",
    "schatteringarnas": "schattering",
    "schatteringars": "schattering",
    "schatteringen": "schattering",
    "schatteringens": "schattering",
    "schatterings": "schattering",
    "schattersömmar": "schattersöm",
    "schattersömmarna": "schattersöm",
    "schattersömmarnas": "schattersöm",
    "schattersömmars": "schattersöm",
    "schattersömmen": "schattersöm",
    "schattersömmens": "schattersöm",
    "schattersöms": "schattersöm",
    "schatullen": "schatull",
    "schatullens": "schatull",
    "schatullet": "schatull",
    "schatullets": "schatull",
    "schatulls": "schatull",
    "schaus": "schau",
    "schavotten": "schavott",
    "schavottens": "schavott",
    "schavotter": "schavott",
    "schavotterade": "schavottera",
    "schavotterades": "schavottera",
    "schavotterande": "schavottera",
    "schavotteranden": "schavotterande",
    "schavotterandena": "schavotterande",
    "schavotterandenas": "schavotterande",
    "schavotterandens": "schavotterande",
    "schavotterandes": "schavotterande",
    "schavotterandet": "schavotterande",
    "schavotterandets": "schavotterande",
    "schavotterar": "schavottera",
    "schavotteras": "schavottera",
    "schavotterat": "schavottera",
    "schavotterats": "schavottera",
    "schavotteringar": "schavottering",
    "schavotteringarna": "schavottering",
    "schavotteringarnas": "schavottering",
    "schavotteringars": "schavottering",
    "schavotteringen": "schavottering",
    "schavotteringens": "schavottering",
    "schavotterings": "schavottering",
    "schavotterna": "schavott",
    "schavotternas": "schavott",
    "schavotters": "schavott",
    "schavotts": "schavott",
    "schejken": "schejk",
    "schejkens": "schejk",
    "schejker": "schejk",
    "schejkerna": "schejk",
    "schejkernas": "schejk",
    "schejkers": "schejk",
    "schejks": "schejk",
    "schellacken": "schellack",
    "schellackens": "schellack",
    "schellacks": "schellack",
    "schemabundens": "schemabunden",
    "schemabundet": "schemabunden",
    "schemabundets": "schemabunden",
    "schemabundna": "schemabunden",
    "schemabundnare": "schemabunden",
    "schemabundnares": "schemabunden",
    "schemabundnas": "schemabunden",
    "schemabundnast": "schemabunden",
    "schemabundnaste": "schemabunden",
    "schemabundnastes": "schemabunden",
    "schemabundnasts": "schemabunden",
    "schemabundne": "schemabunden",
    "schemabundnes": "schemabunden",
    "schemalagda": "schemalagd",
    "schemalagdare": "schemalagd",
    "schemalagdares": "schemalagd",
    "schemalagdas": "schemalagd",
    "schemalagdast": "schemalagd",
    "schemalagdaste": "schemalagd",
    "schemalagdastes": "schemalagd",
    "schemalagdasts": "schemalagd",
    "schemalagde": "schemalagd",
    "schemalagdes": "schemalagd",
    "schemalagds": "schemalagd",
    "schemalagt": "schemalagd",
    "schemalagts": "schemalagd",
    "schemamässiga": "schemamässig",
    "schemamässigare": "schemamässig",
    "schemamässigares": "schemamässig",
    "schemamässigas": "schemamässig",
    "schemamässigast": "schemamässig",
    "schemamässigaste": "schemamässig",
    "schemamässigastes": "schemamässig",
    "schemamässigasts": "schemamässig",
    "schemamässige": "schemamässig",
    "schemamässiges": "schemamässig",
    "schemamässigs": "schemamässig",
    "schemamässigt": "schemamässig",
    "schemamässigts": "schemamässig",
    "scheman": "schema",
    "schemana": "schema",
    "schemanas": "schema",
    "schemans": "schema",
    "schemas": "schema",
    "schemat": "schema",
    "schematiserad": "schematisera",
    "schematiserade": "schematisera",
    "schematiserades": "schematisera",
    "schematiserads": "schematisera",
    "schematiserande": "schematisera",
    "schematiseranden": "schematiserande",
    "schematiserandena": "schematiserande",
    "schematiserandenas": "schematiserande",
    "schematiserandens": "schematiserande",
    "schematiserandes": "schematiserande",
    "schematiserandet": "schematiserande",
    "schematiserandets": "schematiserande",
    "schematiserar": "schematisera",
    "schematiseras": "schematisera",
    "schematiserat": "schematisera",
    "schematiserats": "schematisera",
    "schematiserbara": "schematiserbar",
    "schematiserbarare": "schematiserbar",
    "schematiserbarares": "schematiserbar",
    "schematiserbaras": "schematiserbar",
    "schematiserbarast": "schematiserbar",
    "schematiserbaraste": "schematiserbar",
    "schematiserbarastes": "schematiserbar",
    "schematiserbarasts": "schematiserbar",
    "schematiserbare": "schematiserbar",
    "schematiserbares": "schematiserbar",
    "schematiserbarheten": "schematiserbarhet",
    "schematiserbarhetens": "schematiserbarhet",
    "schematiserbarhets": "schematiserbarhet",
    "schematiserbars": "schematiserbar",
    "schematiserbart": "schematiserbar",
    "schematiserbarts": "schematiserbar",
    "schematiseringar": "schematisering",
    "schematiseringarna": "schematisering",
    "schematiseringarnas": "schematisering",
    "schematiseringars": "schematisering",
    "schematiseringen": "schematisering",
    "schematiseringens": "schematisering",
    "schematiserings": "schematisering",
    "schematiska": "schematisk",
    "schematiskare": "schematisk",
    "schematiskares": "schematisk",
    "schematiskas": "schematisk",
    "schematiskast": "schematisk",
    "schematiskaste": "schematisk",
    "schematiskastes": "schematisk",
    "schematiskasts": "schematisk",
    "schematiske": "schematisk",
    "schematiskes": "schematisk",
    "schematisks": "schematisk",
    "schematiskt": "schematisk",
    "schematiskts": "schematisk",
    "schematismen": "schematism",
    "schematismens": "schematism",
    "schematismer": "schematism",
    "schematismerna": "schematism",
    "schematismernas": "schematism",
    "schematismers": "schematism",
    "schematisms": "schematism",
    "schemats": "schema",
    "schersminen": "schersmin",
    "schersminens": "schersmin",
    "schersminer": "schersmin",
    "schersminerna": "schersmin",
    "schersminernas": "schersmin",
    "schersminers": "schersmin",
    "schersmins": "schersmin",
    "scherzon": "scherzo",
    "scherzona": "scherzo",
    "scherzonas": "scherzo",
    "scherzons": "scherzo",
    "scherzos": "scherzo",
    "scherzot": "scherzo",
    "scherzots": "scherzo",
    "schibboleten": "schibbolet",
    "schibboletens": "schibbolet",
    "schibboleter": "schibbolet",
    "schibboleterna": "schibbolet",
    "schibboleternas": "schibbolet",
    "schibboleters": "schibbolet",
    "schibboletet": "schibbolet",
    "schibboletets": "schibbolet",
    "schibbolets": "schibbolet",
    "schillerkrag": "schillerkrage",
    "schillerkragar": "schillerkrage",
    "schillerkragarna": "schillerkrage",
    "schillerkragarnas": "schillerkrage",
    "schillerkragars": "schillerkrage",
    "schillerkragen": "schillerkrage",
    "schillerkragens": "schillerkrage",
    "schillerkrages": "schillerkrage",
    "schillerkrags": "schillerkrage",
    "schillerstövar": "schillerstövare",
    "schillerstövaren": "schillerstövare",
    "schillerstövarens": "schillerstövare",
    "schillerstövares": "schillerstövare",
    "schillerstövarna": "schillerstövare",
    "schillerstövarnas": "schillerstövare",
    "schillingar": "schilling",
    "schillingarna": "schilling",
    "schillingarnas": "schilling",
    "schillingars": "schilling",
    "schillingen": "schilling",
    "schillingens": "schilling",
    "schillings": "schilling",
    "schimpansen": "schimpans",
    "schimpansens": "schimpans",
    "schimpanser": "schimpans",
    "schimpanserna": "schimpans",
    "schimpansernas": "schimpans",
    "schimpansers": "schimpans",
    "schismatikern": "schismatiker",
    "schismatikerna": "schismatiker",
    "schismatikernas": "schismatiker",
    "schismatikerns": "schismatiker",
    "schismatikers": "schismatiker",
    "schismatiska": "schismatisk",
    "schismatiskare": "schismatisk",
    "schismatiskares": "schismatisk",
    "schismatiskas": "schismatisk",
    "schismatiskast": "schismatisk",
    "schismatiskaste": "schismatisk",
    "schismatiskastes": "schismatisk",
    "schismatiskasts": "schismatisk",
    "schismatiske": "schismatisk",
    "schismatiskes": "schismatisk",
    "schismatisks": "schismatisk",
    "schismatiskt": "schismatisk",
    "schismatiskts": "schismatisk",
    "schismen": "schism",
    "schismens": "schism",
    "schismer": "schism",
    "schismerna": "schism",
    "schismernas": "schism",
    "schismers": "schism",
    "schisms": "schism",
    "schizofrena": "schizofren",
    "schizofrenare": "schizofren",
    "schizofrenares": "schizofren",
    "schizofrenas": "schizofren",
    "schizofrenast": "schizofren",
    "schizofrenaste": "schizofren",
    "schizofrenastes": "schizofren",
    "schizofrenasts": "schizofren",
    "schizofrene": "schizofren",
    "schizofrenes": "schizofren",
    "schizofrenien": "schizofreni",
    "schizofreniens": "schizofreni",
    "schizofrenier": "schizofreni",
    "schizofrenierna": "schizofreni",
    "schizofreniernas": "schizofreni",
    "schizofreniers": "schizofreni",
    "schizofrenin": "schizofreni",
    "schizofrenins": "schizofreni",
    "schizofrenis": "schizofreni",
    "schizofrens": "schizofren",
    "schizofrent": "schizofren",
    "schizofrents": "schizofren",
    "schizoida": "schizoid",
    "schizoidare": "schizoid",
    "schizoidares": "schizoid",
    "schizoidas": "schizoid",
    "schizoidast": "schizoid",
    "schizoidaste": "schizoid",
    "schizoidastes": "schizoid",
    "schizoidasts": "schizoid",
    "schizoide": "schizoid",
    "schizoides": "schizoid",
    "schizoids": "schizoid",
    "schizotyma": "schizotym",
    "schizotymare": "schizotym",
    "schizotymares": "schizotym",
    "schizotymas": "schizotym",
    "schizotymast": "schizotym",
    "schizotymaste": "schizotym",
    "schizotymastes": "schizotym",
    "schizotymasts": "schizotym",
    "schizotyme": "schizotym",
    "schizotymes": "schizotym",
    "schizotymien": "schizotymi",
    "schizotymiens": "schizotymi",
    "schizotymin": "schizotymi",
    "schizotymins": "schizotymi",
    "schizotymis": "schizotymi",
    "schizotyms": "schizotym",
    "schizotymt": "schizotym",
    "schizotymts": "schizotym",
    "schizziga": "schizzig",
    "schizzigare": "schizzig",
    "schizzigares": "schizzig",
    "schizzigas": "schizzig",
    "schizzigast": "schizzig",
    "schizzigaste": "schizzig",
    "schizzigastes": "schizzig",
    "schizzigasts": "schizzig",
    "schizzige": "schizzig",
    "schizziges": "schizzig",
    "schizzigheten": "schizzighet",
    "schizzighetens": "schizzighet",
    "schizzighets": "schizzighet",
    "schizzigs": "schizzig",
    "schizzigt": "schizzig",
    "schizzigts": "schizzig",
    "schlagerbidragen": "schlagerbidrag",
    "schlagerbidragens": "schlagerbidrag",
    "schlagerbidraget": "schlagerbidrag",
    "schlagerbidragets": "schlagerbidrag",
    "schlagerbidrags": "schlagerbidrag",
    "schlagerbråken": "schlagerbråk",
    "schlagerbråkens": "schlagerbråk",
    "schlagerbråket": "schlagerbråk",
    "schlagerbråkets": "schlagerbråk",
    "schlagerbråks": "schlagerbråk",
    "schlagermusiken": "schlagermusik",
    "schlagermusikens": "schlagermusik",
    "schlagermusiks": "schlagermusik",
    "schlagern": "schlager",
    "schlagerna": "schlager",
    "schlagernas": "schlager",
    "schlagerns": "schlager",
    "schlagers": "schlager",
    "schlagersarna": "schlager",
    "schlagersarnas": "schlager",
    "schlagertexten": "schlagertext",
    "schlagertextens": "schlagertext",
    "schlagertexter": "schlagertext",
    "schlagertexterna": "schlagertext",
    "schlagertexternas": "schlagertext",
    "schlagertexters": "schlagertext",
    "schlagertexts": "schlagertext",
    "schlagrar": "schlager",
    "schlagrarna": "schlager",
    "schlagrarnas": "schlager",
    "schlagrars": "schlager",
    "schlaraffenlands": "schlaraffenland",
    "schnauzern": "schnauzer",
    "schnauzerns": "schnauzer",
    "schnauzers": "schnauzer",
    "schnauzrar": "schnauzer",
    "schnauzrarna": "schnauzer",
    "schnauzrarnas": "schnauzer",
    "schnauzrars": "schnauzer",
    "schnellklopsen": "schnellklops",
    "schnellklopsens": "schnellklops",
    "schnitzeln": "schnitzel",
    "schnitzelns": "schnitzel",
    "schnitzels": "schnitzel",
    "schnitzlar": "schnitzel",
    "schnitzlarna": "schnitzel",
    "schnitzlarnas": "schnitzel",
    "schnitzlars": "schnitzel",
    "schoddyn": "schoddy",
    "schoddyns": "schoddy",
    "schoddys": "schoddy",
    "schottisar": "schottis",
    "schottisarna": "schottis",
    "schottisarnas": "schottis",
    "schottisars": "schottis",
    "schottisen": "schottis",
    "schottisens": "schottis",
    "schrammelkvartetten": "schrammelkvartett",
    "schrammelkvartettens": "schrammelkvartett",
    "schrammelkvartetter": "schrammelkvartett",
    "schrammelkvartetterna": "schrammelkvartett",
    "schrammelkvartetternas": "schrammelkvartett",
    "schrammelkvartetters": "schrammelkvartett",
    "schrammelkvartetts": "schrammelkvartett",
    "schrammelmusiken": "schrammelmusik",
    "schrammelmusikens": "schrammelmusik",
    "schrammelmusiks": "schrammelmusik",
    "schumringar": "schumring",
    "schumringarna": "schumring",
    "schumringarnas": "schumring",
    "schumringars": "schumring",
    "schumringen": "schumring",
    "schumringens": "schumring",
    "schumrings": "schumring",
    "schvabacken": "schvaback",
    "schvabackens": "schvaback",
    "schvabacks": "schvaback",
    "schveif": "schveifa",
    "schveifad": "schveifa",
    "schveifade": "schveifa",
    "schveifades": "schveifa",
    "schveifads": "schveifa",
    "schveifande": "schveifa",
    "schveifanden": "schveifande",
    "schveifandena": "schveifande",
    "schveifandenas": "schveifande",
    "schveifandens": "schveifande",
    "schveifandes": "schveifande",
    "schveifandet": "schveifande",
    "schveifandets": "schveifande",
    "schveifar": "schveifa",
    "schveifas": "schveifa",
    "schveifat": "schveifa",
    "schveifats": "schveifa",
    "schvungen": "schvung",
    "schvungens": "schvung",
    "schvungfulla": "schvungfull",
    "schvungfullare": "schvungfull",
    "schvungfullares": "schvungfull",
    "schvungfullas": "schvungfull",
    "schvungfullast": "schvungfull",
    "schvungfullaste": "schvungfull",
    "schvungfullastes": "schvungfull",
    "schvungfullasts": "schvungfull",
    "schvungfulle": "schvungfull",
    "schvungfulles": "schvungfull",
    "schvungfullheten": "schvungfullhet",
    "schvungfullhetens": "schvungfullhet",
    "schvungfullhets": "schvungfullhet",
    "schvungfulls": "schvungfull",
    "schvungfullt": "schvungfull",
    "schvungfullts": "schvungfull",
    "schvungiga": "schvungig",
    "schvungigare": "schvungig",
    "schvungigares": "schvungig",
    "schvungigas": "schvungig",
    "schvungigast": "schvungig",
    "schvungigaste": "schvungig",
    "schvungigastes": "schvungig",
    "schvungigasts": "schvungig",
    "schvungige": "schvungig",
    "schvungiges": "schvungig",
    "schvungigheten": "schvungighet",
    "schvungighetens": "schvungighet",
    "schvungighets": "schvungighet",
    "schvungigs": "schvungig",
    "schvungigt": "schvungig",
    "schvungigts": "schvungig",
    "schvungs": "schvung",
    "schwa-ljuden": "schwa-ljud",
    "schwa-ljudens": "schwa-ljud",
    "schwa-ljudet": "schwa-ljud",
    "schwa-ljudets": "schwa-ljud",
    "schwa-ljuds": "schwa-ljud",
    "schwabachen": "schwabach",
    "schwabachens": "schwabach",
    "schwabachs": "schwabach",
    "schwarzwaldtårt": "schwarzwaldtårta",
    "schwarzwaldtårtan": "schwarzwaldtårta",
    "schwarzwaldtårtans": "schwarzwaldtårta",
    "schwarzwaldtårtas": "schwarzwaldtårta",
    "schwarzwaldtårte": "schwarzwaldtårta",
    "schwarzwaldtårtor": "schwarzwaldtårta",
    "schwarzwaldtårtorna": "schwarzwaldtårta",
    "schwarzwaldtårtornas": "schwarzwaldtårta",
    "schwarzwaldtårtors": "schwarzwaldtårta",
    "schwarzwaldtårts": "schwarzwaldtårta",
    "schweizar": "schweizare",
    "schweizaren": "schweizare",
    "schweizarens": "schweizare",
    "schweizares": "schweizare",
    "schweizarna": "schweizare",
    "schweizarnas": "schweizare",
    "schweizerfrancen": "schweizerfranc",
    "schweizerfrancens": "schweizerfranc",
    "schweizerfrancs": "schweizerfranc",
    "schweizerfrancsen": "schweizerfranc",
    "schweizerfrancsens": "schweizerfranc",
    "schweizerier": "schweizeri",
    "schweizerierna": "schweizeri",
    "schweizeriernas": "schweizeri",
    "schweizeriers": "schweizeri",
    "schweizeriet": "schweizeri",
    "schweizeriets": "schweizeri",
    "schweizeris": "schweizeri",
    "schweizerit": "schweizeri",
    "schweizerits": "schweizeri",
    "schweizernöten": "schweizernöt",
    "schweizernötens": "schweizernöt",
    "schweizernöts": "schweizernöt",
    "schweizernötter": "schweizernöt",
    "schweizernötterna": "schweizernöt",
    "schweizernötternas": "schweizernöt",
    "schweizernötters": "schweizernöt",
    "schweizerostar": "schweizerost",
    "schweizerostarna": "schweizerost",
    "schweizerostarnas": "schweizerost",
    "schweizerostars": "schweizerost",
    "schweizerosten": "schweizerost",
    "schweizerostens": "schweizerost",
    "schweizerosts": "schweizerost",
    "schweiziska": "schweizisk",
    "schweiziskan": "schweiziska",
    "schweiziskans": "schweiziska",
    "schweiziskare": "schweizisk",
    "schweiziskares": "schweizisk",
    "schweiziskas": "schweiziska",
    "schweiziskast": "schweizisk",
    "schweiziskaste": "schweizisk",
    "schweiziskastes": "schweizisk",
    "schweiziskasts": "schweizisk",
    "schweiziske": "schweiziska",
    "schweiziskes": "schweizisk",
    "schweiziskor": "schweiziska",
    "schweiziskorna": "schweiziska",
    "schweiziskornas": "schweiziska",
    "schweiziskors": "schweiziska",
    "schweizisks": "schweizisk",
    "schweiziskt": "schweizisk",
    "schweiziskts": "schweizisk",
    "schwungen": "schwung",
    "schwungens": "schwung",
    "schwungfulla": "schwungfull",
    "schwungfullare": "schwungfull",
    "schwungfullares": "schwungfull",
    "schwungfullas": "schwungfull",
    "schwungfullast": "schwungfull",
    "schwungfullaste": "schwungfull",
    "schwungfullastes": "schwungfull",
    "schwungfullasts": "schwungfull",
    "schwungfulle": "schwungfull",
    "schwungfulles": "schwungfull",
    "schwungfullheten": "schwungfullhet",
    "schwungfullhetens": "schwungfullhet",
    "schwungfullhets": "schwungfullhet",
    "schwungfulls": "schwungfull",
    "schwungfullt": "schwungfull",
    "schwungfullts": "schwungfull",
    "schwungiga": "schwungig",
    "schwungigare": "schwungig",
    "schwungigares": "schwungig",
    "schwungigas": "schwungig",
    "schwungigast": "schwungig",
    "schwungigaste": "schwungig",
    "schwungigastes": "schwungig",
    "schwungigasts": "schwungig",
    "schwungige": "schwungig",
    "schwungiges": "schwungig",
    "schwungigheten": "schwungighet",
    "schwungighetens": "schwungighet",
    "schwungighets": "schwungighet",
    "schwungigs": "schwungig",
    "schwungigt": "schwungig",
    "schwungigts": "schwungig",
    "schwungs": "schwung",
    "schwyzerdütschs": "schwyzerdütsch",
    "schwyzertütschs": "schwyzertütsch",
    "schyssta": "schysst",
    "schysstare": "schysst",
    "schysstares": "schysst",
    "schysstas": "schysst",
    "schysstast": "schysst",
    "schysstaste": "schysst",
    "schysstastes": "schysst",
    "schysstasts": "schysst",
    "schysste": "schysst",
    "schysstes": "schysst",
    "schysstheten": "schyssthet",
    "schyssthetens": "schyssthet",
    "schyssthets": "schyssthet",
    "schyssts": "schysst",
    "schysta": "schyst",
    "schystare": "schyst",
    "schystares": "schyst",
    "schystas": "schyst",
    "schystast": "schyst",
    "schystaste": "schyst",
    "schystastes": "schyst",
    "schystasts": "schyst",
    "schyste": "schyst",
    "schystes": "schyst",
    "schystheten": "schysthet",
    "schysthetens": "schysthet",
    "schysthets": "schysthet",
    "schysts": "schyst",
    "schäferhattar": "schäferhatt",
    "schäferhattarna": "schäferhatt",
    "schäferhattarnas": "schäferhatt",
    "schäferhattars": "schäferhatt",
    "schäferhatten": "schäferhatt",
    "schäferhattens": "schäferhatt",
    "schäferhatts": "schäferhatt",
    "schäferhundar": "schäferhund",
    "schäferhundarna": "schäferhund",
    "schäferhundarnas": "schäferhund",
    "schäferhundars": "schäferhund",
    "schäferhunden": "schäferhund",
    "schäferhundens": "schäferhund",
    "schäferhunds": "schäferhund",
    "schäferier": "schäferi",
    "schäferierna": "schäferi",
    "schäferiernas": "schäferi",
    "schäferiers": "schäferi",
    "schäferiet": "schäferi",
    "schäferiets": "schäferi",
    "schäferis": "schäferi",
    "schäferit": "schäferi",
    "schäferits": "schäferi",
    "schäfern": "schäfer",
    "schäferns": "schäfer",
    "schäfers": "schäfer",
    "schäfervalpar": "schäfervalp",
    "schäfervalparna": "schäfervalp",
    "schäfervalparnas": "schäfervalp",
    "schäfervalpars": "schäfervalp",
    "schäfervalpen": "schäfervalp",
    "schäfervalpens": "schäfervalp",
    "schäfervalps": "schäfervalp",
    "schäfrar": "schäfer",
    "schäfrarna": "schäfer",
    "schäfrarnas": "schäfer",
    "schäfrars": "schäfer",
    "schäsar": "schäs",
    "schäsarna": "schäs",
    "schäsarnas": "schäs",
    "schäsars": "schäs",
    "schäsen": "schäs",
    "schäsens": "schäs",
    "schäslongen": "schäslong",
    "schäslongens": "schäslong",
    "schäslonger": "schäslong",
    "schäslongerna": "schäslong",
    "schäslongernas": "schäslong",
    "schäslongers": "schäslong",
    "schäslongs": "schäslong",
    "schået": "schå",
    "schåets": "schå",
    "schås": "schå",
    "schåt": "schå",
    "schåts": "schå",
    "sci-fi-rull": "sci-fi-rulle",
    "sci-fi-rullar": "sci-fi-rulle",
    "sci-fi-rullarna": "sci-fi-rulle",
    "sci-fi-rullarnas": "sci-fi-rulle",
    "sci-fi-rullars": "sci-fi-rulle",
    "sci-fi-rullen": "sci-fi-rulle",
    "sci-fi-rullens": "sci-fi-rulle",
    "sci-fi-rulles": "sci-fi-rulle",
    "sci-fi-rulls": "sci-fi-rulle",
    "science-fictionromanen": "science-fictionroman",
    "science-fictionromanens": "science-fictionroman",
    "science-fictionromaner": "science-fictionroman",
    "science-fictionromanerna": "science-fictionroman",
    "science-fictionromanernas": "science-fictionroman",
    "science-fictionromaners": "science-fictionroman",
    "science-fictionromans": "science-fictionroman",
    "sciencefictionlitteraturen": "sciencefictionlitteratur",
    "sciencefictionlitteraturens": "sciencefictionlitteratur",
    "sciencefictionlitteraturs": "sciencefictionlitteratur",
    "scientisten": "scientist",
    "scientistens": "scientist",
    "scientister": "scientist",
    "scientisterna": "scientist",
    "scientisternas": "scientist",
    "scientisters": "scientist",
    "scientists": "scientist",
    "scientologen": "scientolog",
    "scientologens": "scientolog",
    "scientologer": "scientolog",
    "scientologerna": "scientolog",
    "scientologernas": "scientolog",
    "scientologers": "scientolog",
    "scientologien": "scientologi",
    "scientologiens": "scientologi",
    "scientologin": "scientologi",
    "scientologins": "scientologi",
    "scientologis": "scientologi",
    "scientologs": "scientolog",
    "scill": "scilla",
    "scillan": "scilla",
    "scillans": "scilla",
    "scillas": "scilla",
    "scille": "scilla",
    "scillor": "scilla",
    "scillorna": "scilla",
    "scillornas": "scilla",
    "scillors": "scilla",
    "scills": "scilla",
    "scintigrafien": "scintigrafi",
    "scintigrafiens": "scintigrafi",
    "scintigrafin": "scintigrafi",
    "scintigrafins": "scintigrafi",
    "scintigrafis": "scintigrafi",
    "scintillationen": "scintillation",
    "scintillationens": "scintillation",
    "scintillationer": "scintillation",
    "scintillationerna": "scintillation",
    "scintillationernas": "scintillation",
    "scintillationers": "scintillation",
    "scintillations": "scintillation",
    "sciroccon": "scirocco",
    "sciroccons": "scirocco",
    "sciroccor": "scirocco",
    "sciroccorna": "scirocco",
    "sciroccornas": "scirocco",
    "sciroccors": "scirocco",
    "sciroccos": "scirocco",
    "sciroccosen": "scirocco",
    "sciroccosens": "scirocco",
    "sconen": "scone",
    "sconens": "scone",
    "sconer": "scone",
    "sconerna": "scone",
    "sconernas": "scone",
    "sconers": "scone",
    "scones": "scone",
    "sconesen": "scone",
    "sconesens": "scone",
    "scoopen": "scoop",
    "scoopens": "scoop",
    "scoopet": "scoop",
    "scoopets": "scoop",
    "scoops": "scoop",
    "scootern": "scooter",
    "scooterns": "scooter",
    "scooters": "scooter",
    "scootrar": "scooter",
    "scootrarna": "scooter",
    "scootrarnas": "scooter",
    "scootrars": "scooter",
    "scopolaminen": "scopolamin",
    "scopolaminens": "scopolamin",
    "scopolaminer": "scopolamin",
    "scopolaminerna": "scopolamin",
    "scopolaminernas": "scopolamin",
    "scopolaminers": "scopolamin",
    "scopolaminet": "scopolamin",
    "scopolaminets": "scopolamin",
    "scopolamins": "scopolamin",
    "scouten": "scout",
    "scoutens": "scout",
    "scouter": "scout",
    "scouterna": "scout",
    "scouternas": "scout",
    "scouters": "scout",
    "scouthälsningar": "scouthälsning",
    "scouthälsningarna": "scouthälsning",
    "scouthälsningarnas": "scouthälsning",
    "scouthälsningars": "scouthälsning",
    "scouthälsningen": "scouthälsning",
    "scouthälsningens": "scouthälsning",
    "scouthälsnings": "scouthälsning",
    "scoutingen": "scouting",
    "scoutingens": "scouting",
    "scoutings": "scouting",
    "scoutjamboreen": "scoutjamboree",
    "scoutjamboreens": "scoutjamboree",
    "scoutjamboreer": "scoutjamboree",
    "scoutjamboreerna": "scoutjamboree",
    "scoutjamboreernas": "scoutjamboree",
    "scoutjamboreers": "scoutjamboree",
    "scoutjamborees": "scoutjamboree",
    "scoutkåren": "scoutkår",
    "scoutkårens": "scoutkår",
    "scoutkårer": "scoutkår",
    "scoutkårerna": "scoutkår",
    "scoutkårernas": "scoutkår",
    "scoutkårers": "scoutkår",
    "scoutkårs": "scoutkår",
    "scoutlagar": "scoutlag",
    "scoutlagarna": "scoutlag",
    "scoutlagarnas": "scoutlag",
    "scoutlagars": "scoutlag",
    "scoutlagen": "scoutlag",
    "scoutlagens": "scoutlag",
    "scoutlags": "scoutlag",
    "scoutlägerna": "scoutläger",
    "scoutlägernas": "scoutläger",
    "scoutlägers": "scoutläger",
    "scoutlägren": "scoutläger",
    "scoutlägrens": "scoutläger",
    "scoutlägret": "scoutläger",
    "scoutlägrets": "scoutläger",
    "scoutlöften": "scoutlöfte",
    "scoutlöftena": "scoutlöfte",
    "scoutlöftenas": "scoutlöfte",
    "scoutlöftens": "scoutlöfte",
    "scoutlöftes": "scoutlöfte",
    "scoutlöftet": "scoutlöfte",
    "scoutlöftets": "scoutlöfte",
    "scoutmässiga": "scoutmässig",
    "scoutmässigare": "scoutmässig",
    "scoutmässigares": "scoutmässig",
    "scoutmässigas": "scoutmässig",
    "scoutmässigast": "scoutmässig",
    "scoutmässigaste": "scoutmässig",
    "scoutmässigastes": "scoutmässig",
    "scoutmässigasts": "scoutmässig",
    "scoutmässige": "scoutmässig",
    "scoutmässiges": "scoutmässig",
    "scoutmässigs": "scoutmässig",
    "scoutmässigt": "scoutmässig",
    "scoutmässigts": "scoutmässig",
    "scoutpatrullen": "scoutpatrull",
    "scoutpatrullens": "scoutpatrull",
    "scoutpatruller": "scoutpatrull",
    "scoutpatrullerna": "scoutpatrull",
    "scoutpatrullernas": "scoutpatrull",
    "scoutpatrullers": "scoutpatrull",
    "scoutpatrulls": "scoutpatrull",
    "scoutrörelsen": "scoutrörelse",
    "scoutrörelsens": "scoutrörelse",
    "scoutrörelses": "scoutrörelse",
    "scouts": "scout",
    "scratchmannen": "scratchman",
    "scratchmannens": "scratchman",
    "scratchmans": "scratchman",
    "scratchmän": "scratchman",
    "scratchmännen": "scratchman",
    "scratchmännens": "scratchman",
    "scratchmäns": "scratchman",
    "screentrycket": "screentryck",
    "screentryckets": "screentryck",
    "screentrycks": "screentryck",
    "script-girlen": "script-girl",
    "script-girlens": "script-girl",
    "script-girls": "script-girl",
    "script-girlsarna": "script-girl",
    "script-girlsarnas": "script-girl",
    "script-girlsen": "script-girl",
    "script-girlsens": "script-girl",
    "scriptan": "scripta",
    "scriptans": "scripta",
    "scriptas": "scripta",
    "scripte": "scripta",
    "scriptor": "scripta",
    "scriptorna": "scripta",
    "scriptornas": "scripta",
    "scriptors": "scripta",
    "scrotums": "scrotum",
    "seansen": "seans",
    "seansens": "seans",
    "seanser": "seans",
    "seanserna": "seans",
    "seansernas": "seans",
    "seansers": "seans",
    "sebara": "sebar",
    "sebarare": "sebar",
    "sebarares": "sebar",
    "sebaras": "sebar",
    "sebarast": "sebar",
    "sebaraste": "sebar",
    "sebarastes": "sebar",
    "sebarasts": "sebar",
    "sebare": "sebar",
    "sebares": "sebar",
    "sebarheten": "sebarhet",
    "sebarhetens": "sebarhet",
    "sebarhets": "sebarhet",
    "sebars": "sebar",
    "sebart": "sebar",
    "sebarts": "sebar",
    "seborréen": "seborré",
    "seborréens": "seborré",
    "seborréer": "seborré",
    "seborréerna": "seborré",
    "seborréernas": "seborré",
    "seborréers": "seborré",
    "seborrén": "seborré",
    "seborréns": "seborré",
    "seborrés": "seborré",
    "sebran": "sebra",
    "sebrans": "sebra",
    "sebras": "sebra",
    "sebror": "sebra",
    "sebrorna": "sebra",
    "sebrornas": "sebra",
    "sebrors": "sebra",
    "sebuer": "sebu",
    "sebuerna": "sebu",
    "sebuernas": "sebu",
    "sebuers": "sebu",
    "sebun": "sebu",
    "sebuns": "sebu",
    "sebus": "sebu",
    "seccomålningar": "seccomålning",
    "seccomålningarna": "seccomålning",
    "seccomålningarnas": "seccomålning",
    "seccomålningars": "seccomålning",
    "seccomålningen": "seccomålning",
    "seccomålningens": "seccomålning",
    "seccomålnings": "seccomålning",
    "secs": "sec",
    "sedanen": "sedan",
    "sedanens": "sedan",
    "sedaner": "sedan",
    "sedanerna": "sedan",
    "sedanernas": "sedan",
    "sedaners": "sedan",
    "sedans": "sedan",
    "sedativ": "sedativum",
    "sedativa": "sedativ",
    "sedativare": "sedativ",
    "sedativares": "sedativ",
    "sedativas": "sedativ",
    "sedativast": "sedativ",
    "sedativaste": "sedativ",
    "sedativastes": "sedativ",
    "sedativasts": "sedativ",
    "sedative": "sedativ",
    "sedativen": "sedativum",
    "sedativens": "sedativum",
    "sedativer": "sedativum",
    "sedativerna": "sedativum",
    "sedativernas": "sedativum",
    "sedativers": "sedativum",
    "sedatives": "sedativ",
    "sedativet": "sedativum",
    "sedativets": "sedativum",
    "sedativs": "sedativum",
    "sedativt": "sedativ",
    "sedativts": "sedativ",
    "sedativumet": "sedativum",
    "sedativumets": "sedativum",
    "sedativums": "sedativum",
    "sedd": "se",
    "sedda": "se",
    "seddas": "se",
    "sedde": "se",
    "seddes": "se",
    "sedds": "se",
    "sede": "sed",
    "sedebetygen": "sedebetyg",
    "sedebetygens": "sedebetyg",
    "sedebetyget": "sedebetyg",
    "sedebetygets": "sedebetyg",
    "sedebetygs": "sedebetyg",
    "sedefördärvet": "sedefördärv",
    "sedefördärvets": "sedefördärv",
    "sedefördärvs": "sedefördärv",
    "sedeförfallet": "sedeförfall",
    "sedeförfallets": "sedeförfall",
    "sedeförfalls": "sedeförfall",
    "sedekomedien": "sedekomedi",
    "sedekomediens": "sedekomedi",
    "sedekomedier": "sedekomedi",
    "sedekomedierna": "sedekomedi",
    "sedekomediernas": "sedekomedi",
    "sedekomediers": "sedekomedi",
    "sedekomedin": "sedekomedi",
    "sedekomedins": "sedekomedi",
    "sedekomedis": "sedekomedi",
    "sedelautomaten": "sedelautomat",
    "sedelautomatens": "sedelautomat",
    "sedelautomater": "sedelautomat",
    "sedelautomaterna": "sedelautomat",
    "sedelautomaternas": "sedelautomat",
    "sedelautomaters": "sedelautomat",
    "sedelautomats": "sedelautomat",
    "sedeln": "sedel",
    "sedelns": "sedel",
    "sedelpressar": "sedelpress",
    "sedelpressarna": "sedelpress",
    "sedelpressarnas": "sedelpress",
    "sedelpressars": "sedelpress",
    "sedelpressen": "sedelpress",
    "sedelpressens": "sedelpress",
    "sedelreserven": "sedelreserv",
    "sedelreservens": "sedelreserv",
    "sedelreserver": "sedelreserv",
    "sedelreserverna": "sedelreserv",
    "sedelreservernas": "sedelreserv",
    "sedelreservers": "sedelreserv",
    "sedelreservs": "sedelreserv",
    "sedels": "sedel",
    "sedelstockar": "sedelstock",
    "sedelstockarna": "sedelstock",
    "sedelstockarnas": "sedelstock",
    "sedelstockars": "sedelstock",
    "sedelstocken": "sedelstock",
    "sedelstockens": "sedelstock",
    "sedelstocks": "sedelstock",
    "sedeltäckningar": "sedeltäckning",
    "sedeltäckningarna": "sedeltäckning",
    "sedeltäckningarnas": "sedeltäckning",
    "sedeltäckningars": "sedeltäckning",
    "sedeltäckningen": "sedeltäckning",
    "sedeltäckningens": "sedeltäckning",
    "sedeltäcknings": "sedeltäckning",
    "sedeläran": "sedelära",
    "sedelärans": "sedelära",
    "sedeläras": "sedelära",
    "seden": "sed",
    "sedens": "sed",
    "seder": "sed",
    "sederna": "sed",
    "sedernas": "sed",
    "sederomanen": "sederoman",
    "sederomanens": "sederoman",
    "sederomaner": "sederoman",
    "sederomanerna": "sederoman",
    "sederomanernas": "sederoman",
    "sederomaners": "sederoman",
    "sederomans": "sederoman",
    "seders": "sed",
    "sedesamheten": "sedesamhet",
    "sedesamhetens": "sedesamhet",
    "sedesamhets": "sedesamhet",
    "sedesamma": "sedesam",
    "sedesammare": "sedesam",
    "sedesammares": "sedesam",
    "sedesammas": "sedesam",
    "sedesammast": "sedesam",
    "sedesammaste": "sedesam",
    "sedesammastes": "sedesam",
    "sedesammasts": "sedesam",
    "sedesamme": "sedesam",
    "sedesammes": "sedesam",
    "sedesams": "sedesam",
    "sedesamt": "sedesam",
    "sedesamts": "sedesam",
    "sedesen": "sedes",
    "sedesens": "sedes",
    "sedeser": "sedes",
    "sedeserna": "sedes",
    "sedesernas": "sedes",
    "sedesers": "sedes",
    "sedeskildringar": "sedeskildring",
    "sedeskildringarna": "sedeskildring",
    "sedeskildringarnas": "sedeskildring",
    "sedeskildringars": "sedeskildring",
    "sedeskildringen": "sedeskildring",
    "sedeskildringens": "sedeskildring",
    "sedeskildrings": "sedeskildring",
    "sedeslösa": "sedeslös",
    "sedeslösare": "sedeslös",
    "sedeslösares": "sedeslös",
    "sedeslösas": "sedeslös",
    "sedeslösast": "sedeslös",
    "sedeslösaste": "sedeslös",
    "sedeslösastes": "sedeslös",
    "sedeslösasts": "sedeslös",
    "sedeslöse": "sedeslös",
    "sedeslöses": "sedeslös",
    "sedeslösheten": "sedeslöshet",
    "sedeslöshetens": "sedeslöshet",
    "sedeslöshets": "sedeslöshet",
    "sedeslöst": "sedeslös",
    "sedeslösts": "sedeslös",
    "sediga": "sedig",
    "sedigare": "sedig",
    "sedigares": "sedig",
    "sedigas": "sedig",
    "sedigast": "sedig",
    "sedigaste": "sedig",
    "sedigastes": "sedig",
    "sedigasts": "sedig",
    "sedige": "sedig",
    "sediges": "sedig",
    "sedigs": "sedig",
    "sedigt": "sedig",
    "sedigts": "sedig",
    "sedimenten": "sediment",
    "sedimentens": "sediment",
    "sedimenterad": "sedimentera",
    "sedimenterade": "sedimentera",
    "sedimenterades": "sedimentera",
    "sedimenterads": "sedimentera",
    "sedimenterande": "sedimentera",
    "sedimenteranden": "sedimenterande",
    "sedimenterandena": "sedimenterande",
    "sedimenterandenas": "sedimenterande",
    "sedimenterandens": "sedimenterande",
    "sedimenterandes": "sedimenterande",
    "sedimenterandet": "sedimenterande",
    "sedimenterandets": "sedimenterande",
    "sedimenterar": "sedimentera",
    "sedimenteras": "sedimentera",
    "sedimenterat": "sedimentera",
    "sedimenterats": "sedimentera",
    "sedimenterbara": "sedimenterbar",
    "sedimenterbarare": "sedimenterbar",
    "sedimenterbarares": "sedimenterbar",
    "sedimenterbaras": "sedimenterbar",
    "sedimenterbarast": "sedimenterbar",
    "sedimenterbaraste": "sedimenterbar",
    "sedimenterbarastes": "sedimenterbar",
    "sedimenterbarasts": "sedimenterbar",
    "sedimenterbare": "sedimenterbar",
    "sedimenterbares": "sedimenterbar",
    "sedimenterbarheten": "sedimenterbarhet",
    "sedimenterbarhetens": "sedimenterbarhet",
    "sedimenterbarhets": "sedimenterbarhet",
    "sedimenterbars": "sedimenterbar",
    "sedimenterbart": "sedimenterbar",
    "sedimenterbarts": "sedimenterbar",
    "sedimenteringar": "sedimentering",
    "sedimenteringarna": "sedimentering",
    "sedimenteringarnas": "sedimentering",
    "sedimenteringars": "sedimentering",
    "sedimenteringen": "sedimentering",
    "sedimenteringens": "sedimentering",
    "sedimenterings": "sedimentering",
    "sedimentet": "sediment",
    "sedimentets": "sediment",
    "sedimentkärn": "sedimentkärna",
    "sedimentkärnan": "sedimentkärna",
    "sedimentkärnans": "sedimentkärna",
    "sedimentkärnas": "sedimentkärna",
    "sedimentkärne": "sedimentkärna",
    "sedimentkärnor": "sedimentkärna",
    "sedimentkärnorna": "sedimentkärna",
    "sedimentkärnornas": "sedimentkärna",
    "sedimentkärnors": "sedimentkärna",
    "sedimentkärns": "sedimentkärna",
    "sedimentlagerna": "sedimentlager",
    "sedimentlagernas": "sedimentlager",
    "sedimentlagers": "sedimentlager",
    "sedimentlagren": "sedimentlager",
    "sedimentlagrens": "sedimentlager",
    "sedimentlagret": "sedimentlager",
    "sedimentlagrets": "sedimentlager",
    "sedimentproven": "sedimentprov",
    "sedimentprovens": "sedimentprov",
    "sedimentprover": "sedimentprov",
    "sedimentproverna": "sedimentprov",
    "sedimentprovernas": "sedimentprov",
    "sedimentprovers": "sedimentprov",
    "sedimentprovet": "sedimentprov",
    "sedimentprovets": "sedimentprov",
    "sedimentprovs": "sedimentprov",
    "sediments": "sediment",
    "sedimentära": "sedimentär",
    "sedimentärare": "sedimentär",
    "sedimentärares": "sedimentär",
    "sedimentäras": "sedimentär",
    "sedimentärast": "sedimentär",
    "sedimentäraste": "sedimentär",
    "sedimentärastes": "sedimentär",
    "sedimentärasts": "sedimentär",
    "sedimentäre": "sedimentär",
    "sedimentäres": "sedimentär",
    "sedimentärs": "sedimentär",
    "sedimentärt": "sedimentär",
    "sedimentärts": "sedimentär",
    "sedlar": "sedel",
    "sedlarna": "sedel",
    "sedlarnas": "sedel",
    "sedlars": "sedel",
    "sedliga": "sedlig",
    "sedligare": "sedlig",
    "sedligares": "sedlig",
    "sedligas": "sedlig",
    "sedligast": "sedlig",
    "sedligaste": "sedlig",
    "sedligastes": "sedlig",
    "sedligasts": "sedlig",
    "sedlige": "sedlig",
    "sedliges": "sedlig",
    "sedligheten": "sedlighet",
    "sedlighetens": "sedlighet",
    "sedligheter": "sedlighet",
    "sedligheterna": "sedlighet",
    "sedligheternas": "sedlighet",
    "sedligheters": "sedlighet",
    "sedlighets": "sedlighet",
    "sedlighetsbrotten": "sedlighetsbrott",
    "sedlighetsbrottens": "sedlighetsbrott",
    "sedlighetsbrottet": "sedlighetsbrott",
    "sedlighetsbrottets": "sedlighetsbrott",
    "sedlighetsbrotts": "sedlighetsbrott",
    "sedlighetsivern": "sedlighetsiver",
    "sedlighetsiverns": "sedlighetsiver",
    "sedlighetsivers": "sedlighetsiver",
    "sedligs": "sedlig",
    "sedligt": "sedlig",
    "sedligts": "sedlig",
    "seds": "sed",
    "sedumen": "sedum",
    "sedumens": "sedum",
    "sedums": "sedum",
    "sedvanan": "sedvana",
    "sedvanans": "sedvana",
    "sedvanas": "sedvana",
    "sedvane": "sedvana",
    "sedvanerätten": "sedvanerätt",
    "sedvanerättens": "sedvanerätt",
    "sedvanerätts": "sedvanerätt",
    "sedvanliga": "sedvanlig",
    "sedvanligare": "sedvanlig",
    "sedvanligares": "sedvanlig",
    "sedvanligas": "sedvanlig",
    "sedvanligast": "sedvanlig",
    "sedvanligaste": "sedvanlig",
    "sedvanligastes": "sedvanlig",
    "sedvanligasts": "sedvanlig",
    "sedvanlige": "sedvanlig",
    "sedvanliges": "sedvanlig",
    "sedvanligheten": "sedvanlighet",
    "sedvanlighetens": "sedvanlighet",
    "sedvanlighets": "sedvanlighet",
    "sedvanligs": "sedvanlig",
    "sedvanligt": "sedvanlig",
    "sedvanligts": "sedvanlig",
    "sedvanor": "sedvana",
    "sedvanorna": "sedvana",
    "sedvanornas": "sedvana",
    "sedvanors": "sedvana",
    "sedvänjan": "sedvänja",
    "sedvänjans": "sedvänja",
    "sedvänjas": "sedvänja",
    "sedvänje": "sedvänja",
    "sedvänjor": "sedvänja",
    "sedvänjorna": "sedvänja",
    "sedvänjornas": "sedvänja",
    "sedvänjors": "sedvänja",
    "seed": "seeda",
    "seedad": "seeda",
    "seedade": "seeda",
    "seedades": "seeda",
    "seedads": "seeda",
    "seedande": "seeda",
    "seedanden": "seedande",
    "seedandena": "seedande",
    "seedandenas": "seedande",
    "seedandens": "seedande",
    "seedandes": "seedande",
    "seedandet": "seedande",
    "seedandets": "seedande",
    "seedar": "seeda",
    "seedas": "seeda",
    "seedat": "seeda",
    "seedats": "seeda",
    "seende": "se",
    "seenden": "seende",
    "seendena": "seende",
    "seendenas": "seende",
    "seendens": "seende",
    "seendes": "seende",
    "seendet": "seende",
    "seendets": "seende",
    "sefarden": "sefard",
    "sefardens": "sefard",
    "sefarder": "sefard",
    "sefarderna": "sefard",
    "sefardernas": "sefard",
    "sefarders": "sefard",
    "sefards": "sefard",
    "sefiren": "sefir",
    "sefirens": "sefir",
    "sefirgarnet": "sefirgarn",
    "sefirgarnets": "sefirgarn",
    "sefirgarns": "sefirgarn",
    "sefirs": "sefir",
    "sefyren": "sefyr",
    "sefyrens": "sefyr",
    "sefyrer": "sefyr",
    "sefyrerna": "sefyr",
    "sefyrernas": "sefyr",
    "sefyrers": "sefyr",
    "sefyrn": "sefyr",
    "sefyrns": "sefyr",
    "sefyrs": "sefyr",
    "seg": "sega",
    "sega": "seg",
    "segade": "sega",
    "segades": "sega",
    "segande": "sega",
    "seganden": "segande",
    "segandena": "segande",
    "segandenas": "segande",
    "segandens": "segande",
    "segandes": "segande",
    "segandet": "segande",
    "segandets": "segande",
    "segar": "sega",
    "segare": "seg",
    "segares": "seg",
    "segas": "sega",
    "segast": "seg",
    "segaste": "seg",
    "segastes": "seg",
    "segasts": "seg",
    "segat": "sega",
    "segats": "sega",
    "segdrag": "segdra",
    "segdraga": "segdra",
    "segdragande": "segdra",
    "segdraganden": "segdragande",
    "segdragandena": "segdragande",
    "segdragandenas": "segdragande",
    "segdragandens": "segdragande",
    "segdragandes": "segdragande",
    "segdragandet": "segdragande",
    "segdragandets": "segdragande",
    "segdragas": "segdra",
    "segdrage": "segdra",
    "segdragen": "segdra",
    "segdragens": "segdragen",
    "segdrager": "segdra",
    "segdrages": "segdra",
    "segdraget": "segdragen",
    "segdragets": "segdragen",
    "segdragit": "segdra",
    "segdragits": "segdra",
    "segdragna": "segdragen",
    "segdragnare": "segdragen",
    "segdragnares": "segdragen",
    "segdragnas": "segdragen",
    "segdragnast": "segdragen",
    "segdragnaste": "segdragen",
    "segdragnastes": "segdragen",
    "segdragnasts": "segdragen",
    "segdragne": "segdragen",
    "segdragnes": "segdragen",
    "segdrags": "segdra",
    "segdrar": "segdra",
    "segdras": "segdra",
    "segdrog": "segdra",
    "segdroge": "segdra",
    "segdroges": "segdra",
    "segdrogs": "segdra",
    "sege": "seg",
    "segel": "segla",
    "segelare": "segelarea",
    "segelarean": "segelarea",
    "segelareans": "segelarea",
    "segelareas": "segelarea",
    "segelaree": "segelarea",
    "segelareor": "segelarea",
    "segelareorna": "segelarea",
    "segelareornas": "segelarea",
    "segelareors": "segelarea",
    "segelares": "segelarea",
    "segelbara": "segelbar",
    "segelbarare": "segelbar",
    "segelbarares": "segelbar",
    "segelbaras": "segelbar",
    "segelbarast": "segelbar",
    "segelbaraste": "segelbar",
    "segelbarastes": "segelbar",
    "segelbarasts": "segelbar",
    "segelbare": "segelbar",
    "segelbares": "segelbar",
    "segelbarheten": "segelbarhet",
    "segelbarhetens": "segelbarhet",
    "segelbarhets": "segelbarhet",
    "segelbars": "segelbar",
    "segelbart": "segelbar",
    "segelbarts": "segelbar",
    "segelbärgningar": "segelbärgning",
    "segelbärgningarna": "segelbärgning",
    "segelbärgningarnas": "segelbärgning",
    "segelbärgningars": "segelbärgning",
    "segelbärgningen": "segelbärgning",
    "segelbärgningens": "segelbärgning",
    "segelbärgnings": "segelbärgning",
    "segelbåtar": "segelbåt",
    "segelbåtarna": "segelbåt",
    "segelbåtarnas": "segelbåt",
    "segelbåtars": "segelbåt",
    "segelbåten": "segelbåt",
    "segelbåtens": "segelbåt",
    "segelbåts": "segelbåt",
    "segeldukar": "segelduk",
    "segeldukarna": "segelduk",
    "segeldukarnas": "segelduk",
    "segeldukars": "segelduk",
    "segelduken": "segelduk",
    "segeldukens": "segelduk",
    "segelduks": "segelduk",
    "segelfarten": "segelfart",
    "segelfartens": "segelfart",
    "segelfarts": "segelfart",
    "segelfartygen": "segelfartyg",
    "segelfartygens": "segelfartyg",
    "segelfartyget": "segelfartyg",
    "segelfartygets": "segelfartyg",
    "segelfartygs": "segelfartyg",
    "segelfluge": "segelflyga",
    "segelfluges": "segelflyga",
    "segelflugit": "segelflyga",
    "segelflugits": "segelflyga",
    "segelflyg": "segelflyga",
    "segelflygande": "segelflyga",
    "segelflyganden": "segelflygande",
    "segelflygandena": "segelflygande",
    "segelflygandenas": "segelflygande",
    "segelflygandens": "segelflygande",
    "segelflygandes": "segelflygande",
    "segelflygandet": "segelflygande",
    "segelflygandets": "segelflygande",
    "segelflygas": "segelflyga",
    "segelflyge": "segelflyga",
    "segelflygen": "segelflyg",
    "segelflygens": "segelflyg",
    "segelflyger": "segelflyga",
    "segelflyges": "segelflyga",
    "segelflyget": "segelflyg",
    "segelflygets": "segelflyg",
    "segelflygningar": "segelflygning",
    "segelflygningarna": "segelflygning",
    "segelflygningarnas": "segelflygning",
    "segelflygningars": "segelflygning",
    "segelflygningen": "segelflygning",
    "segelflygningens": "segelflygning",
    "segelflygnings": "segelflygning",
    "segelflygplanen": "segelflygplan",
    "segelflygplanens": "segelflygplan",
    "segelflygplanet": "segelflygplan",
    "segelflygplanets": "segelflygplan",
    "segelflygplans": "segelflygplan",
    "segelflygs": "segelflyga",
    "segelflykten": "segelflykt",
    "segelflyktens": "segelflykt",
    "segelflykts": "segelflykt",
    "segelflög": "segelflyga",
    "segelflögs": "segelflyga",
    "segelfria": "segelfri",
    "segelfriare": "segelfri",
    "segelfriares": "segelfri",
    "segelfrias": "segelfri",
    "segelfriast": "segelfri",
    "segelfriaste": "segelfri",
    "segelfriastes": "segelfri",
    "segelfriasts": "segelfri",
    "segelfrie": "segelfri",
    "segelfries": "segelfri",
    "segelfris": "segelfri",
    "segelfritt": "segelfri",
    "segelfritts": "segelfri",
    "segelföringar": "segelföring",
    "segelföringarna": "segelföring",
    "segelföringarnas": "segelföring",
    "segelföringars": "segelföring",
    "segelföringen": "segelföring",
    "segelföringens": "segelföring",
    "segelförings": "segelföring",
    "segelgarnet": "segelgarn",
    "segelgarnets": "segelgarn",
    "segelgarns": "segelgarn",
    "segeljakten": "segeljakt",
    "segeljaktens": "segeljakt",
    "segeljakter": "segeljakt",
    "segeljakterna": "segeljakt",
    "segeljakternas": "segeljakt",
    "segeljakters": "segeljakt",
    "segeljakts": "segeljakt",
    "segeljoll": "segeljolle",
    "segeljollar": "segeljolle",
    "segeljollarna": "segeljolle",
    "segeljollarnas": "segeljolle",
    "segeljollars": "segeljolle",
    "segeljollen": "segeljolle",
    "segeljollens": "segeljolle",
    "segeljolles": "segeljolle",
    "segeljolls": "segeljolle",
    "segelkanoten": "segelkanot",
    "segelkanotens": "segelkanot",
    "segelkanoter": "segelkanot",
    "segelkanoterna": "segelkanot",
    "segelkanoternas": "segelkanot",
    "segelkanoters": "segelkanot",
    "segelkanots": "segelkanot",
    "segelkapellen": "segelkapell",
    "segelkapellens": "segelkapell",
    "segelkapellet": "segelkapell",
    "segelkapellets": "segelkapell",
    "segelkapells": "segelkapell",
    "segelleden": "segelled",
    "segelledens": "segelled",
    "segelleder": "segelled",
    "segellederna": "segelled",
    "segelledernas": "segelled",
    "segelleders": "segelled",
    "segelleds": "segelled",
    "segelmakar": "segelmakare",
    "segelmakaren": "segelmakare",
    "segelmakarens": "segelmakare",
    "segelmakares": "segelmakare",
    "segelmakarna": "segelmakare",
    "segelmakarnas": "segelmakare",
    "segelmakerier": "segelmakeri",
    "segelmakerierna": "segelmakeri",
    "segelmakeriernas": "segelmakeri",
    "segelmakeriers": "segelmakeri",
    "segelmakeriet": "segelmakeri",
    "segelmakeriets": "segelmakeri",
    "segelmakeris": "segelmakeri",
    "segelmakerit": "segelmakeri",
    "segelmakerits": "segelmakeri",
    "segelmärken": "segelmärke",
    "segelmärkena": "segelmärke",
    "segelmärkenas": "segelmärke",
    "segelmärkens": "segelmärke",
    "segelmärkes": "segelmärke",
    "segelmärket": "segelmärke",
    "segelmärkets": "segelmärke",
    "segelränn": "segelränna",
    "segelrännan": "segelränna",
    "segelrännans": "segelränna",
    "segelrännas": "segelränna",
    "segelränne": "segelränna",
    "segelrännor": "segelränna",
    "segelrännorna": "segelränna",
    "segelrännornas": "segelränna",
    "segelrännors": "segelränna",
    "segelränns": "segelränna",
    "segels": "segel",
    "segelskridskon": "segelskridsko",
    "segelskridskons": "segelskridsko",
    "segelskridskor": "segelskridsko",
    "segelskridskorna": "segelskridsko",
    "segelskridskornas": "segelskridsko",
    "segelskridskors": "segelskridsko",
    "segelskridskos": "segelskridsko",
    "segelskut": "segelskuta",
    "segelskutan": "segelskuta",
    "segelskutans": "segelskuta",
    "segelskutas": "segelskuta",
    "segelskute": "segelskuta",
    "segelskutor": "segelskuta",
    "segelskutorna": "segelskuta",
    "segelskutornas": "segelskuta",
    "segelskutors": "segelskuta",
    "segelskuts": "segelskuta",
    "segelsporten": "segelsport",
    "segelsportens": "segelsport",
    "segelsports": "segelsport",
    "segelställen": "segelställ",
    "segelställens": "segelställ",
    "segelstället": "segelställ",
    "segelställets": "segelställ",
    "segelställs": "segelställ",
    "segelsömmar": "segelsömmare",
    "segelsömmaren": "segelsömmare",
    "segelsömmarens": "segelsömmare",
    "segelsömmares": "segelsömmare",
    "segelsömmarna": "segelsömmare",
    "segelsömmarnas": "segelsömmare",
    "segelytan": "segelyta",
    "segelytans": "segelyta",
    "segelytas": "segelyta",
    "segelyte": "segelyta",
    "segelytor": "segelyta",
    "segelytorna": "segelyta",
    "segelytornas": "segelyta",
    "segelytors": "segelyta",
    "segerfesten": "segerfest",
    "segerfestens": "segerfest",
    "segerfester": "segerfest",
    "segerfesterna": "segerfest",
    "segerfesternas": "segerfest",
    "segerfesters": "segerfest",
    "segerfests": "segerfest",
    "segerherrar": "segerherre",
    "segerherrarna": "segerherre",
    "segerherrarnas": "segerherre",
    "segerherrars": "segerherre",
    "segerherren": "segerherre",
    "segerherrens": "segerherre",
    "segerherres": "segerherre",
    "segerhuv": "segerhuva",
    "segerhuvan": "segerhuva",
    "segerhuvans": "segerhuva",
    "segerhuvas": "segerhuva",
    "segerhuve": "segerhuva",
    "segerhuvor": "segerhuva",
    "segerhuvorna": "segerhuva",
    "segerhuvornas": "segerhuva",
    "segerhuvors": "segerhuva",
    "segerhuvs": "segerhuva",
    "segerkransar": "segerkrans",
    "segerkransarna": "segerkrans",
    "segerkransarnas": "segerkrans",
    "segerkransars": "segerkrans",
    "segerkransen": "segerkrans",
    "segerkransens": "segerkrans",
    "segerkrönta": "segerkrönt",
    "segerkröntare": "segerkrönt",
    "segerkröntares": "segerkrönt",
    "segerkröntas": "segerkrönt",
    "segerkröntast": "segerkrönt",
    "segerkröntaste": "segerkrönt",
    "segerkröntastes": "segerkrönt",
    "segerkröntasts": "segerkrönt",
    "segerkrönte": "segerkrönt",
    "segerkröntes": "segerkrönt",
    "segerkrönts": "segerkrönt",
    "segermonumenten": "segermonument",
    "segermonumentens": "segermonument",
    "segermonumentet": "segermonument",
    "segermonumentets": "segermonument",
    "segermonuments": "segermonument",
    "segern": "seger",
    "segerns": "seger",
    "segerrika": "segerrik",
    "segerrikare": "segerrik",
    "segerrikares": "segerrik",
    "segerrikas": "segerrik",
    "segerrikast": "segerrik",
    "segerrikaste": "segerrik",
    "segerrikastes": "segerrik",
    "segerrikasts": "segerrik",
    "segerrike": "segerrik",
    "segerrikes": "segerrik",
    "segerrikheten": "segerrikhet",
    "segerrikhetens": "segerrikhet",
    "segerrikhets": "segerrikhet",
    "segerriks": "segerrik",
    "segerrikt": "segerrik",
    "segerrikts": "segerrik",
    "segers": "seger",
    "segersmajlen": "segersmajl",
    "segersmajlens": "segersmajl",
    "segersmajlet": "segersmajl",
    "segersmajlets": "segersmajl",
    "segersmajls": "segersmajl",
    "segersälla": "segersäll",
    "segersällare": "segersäll",
    "segersällares": "segersäll",
    "segersällas": "segersäll",
    "segersällast": "segersäll",
    "segersällaste": "segersäll",
    "segersällastes": "segersäll",
    "segersällasts": "segersäll",
    "segersälle": "segersäll",
    "segersälles": "segersäll",
    "segersällheten": "segersällhet",
    "segersällhetens": "segersällhet",
    "segersällhets": "segersällhet",
    "segersälls": "segersäll",
    "segersällt": "segersäll",
    "segersällts": "segersäll",
    "segertågen": "segertåg",
    "segertågens": "segertåg",
    "segertåget": "segertåg",
    "segertågets": "segertåg",
    "segertågs": "segertåg",
    "segervissa": "segerviss",
    "segervissare": "segerviss",
    "segervissares": "segerviss",
    "segervissas": "segerviss",
    "segervissast": "segerviss",
    "segervissaste": "segerviss",
    "segervissastes": "segerviss",
    "segervissasts": "segerviss",
    "segervisse": "segerviss",
    "segervisses": "segerviss",
    "segervissheten": "segervisshet",
    "segervisshetens": "segervisshet",
    "segervisshets": "segervisshet",
    "segervisst": "segerviss",
    "segervissts": "segerviss",
    "segeryran": "segeryra",
    "segeryrans": "segeryra",
    "segeryras": "segeryra",
    "seges": "seg",
    "segheten": "seghet",
    "seghetens": "seghet",
    "segheter": "seghet",
    "segheterna": "seghet",
    "segheternas": "seghet",
    "segheters": "seghet",
    "seghets": "seghet",
    "seghärd": "seghärda",
    "seghärdad": "seghärda",
    "seghärdade": "seghärda",
    "seghärdades": "seghärda",
    "seghärdads": "seghärda",
    "seghärdande": "seghärda",
    "seghärdanden": "seghärdande",
    "seghärdandena": "seghärdande",
    "seghärdandenas": "seghärdande",
    "seghärdandens": "seghärdande",
    "seghärdandes": "seghärdande",
    "seghärdandet": "seghärdande",
    "seghärdandets": "seghärdande",
    "seghärdar": "seghärda",
    "seghärdas": "seghärda",
    "seghärdat": "seghärda",
    "seghärdats": "seghärda",
    "seglad": "segla",
    "seglade": "segla",
    "seglades": "segla",
    "seglads": "segla",
    "seglande": "segla",
    "seglanden": "seglande",
    "seglandena": "seglande",
    "seglandenas": "seglande",
    "seglandens": "seglande",
    "seglandes": "seglande",
    "seglandet": "seglande",
    "seglandets": "seglande",
    "seglar": "seglare",
    "seglaren": "seglare",
    "seglarens": "seglare",
    "seglares": "seglare",
    "seglarmöss": "seglarmössa",
    "seglarmössan": "seglarmössa",
    "seglarmössans": "seglarmössa",
    "seglarmössas": "seglarmössa",
    "seglarmösse": "seglarmössa",
    "seglarmössor": "seglarmössa",
    "seglarmössorna": "seglarmössa",
    "seglarmössornas": "seglarmössa",
    "seglarmössors": "seglarmössa",
    "seglarna": "seglare",
    "seglarnas": "seglare",
    "seglarstöveln": "seglarstövel",
    "seglarstövelns": "seglarstövel",
    "seglarstövels": "seglarstövel",
    "seglarstövlar": "seglarstövel",
    "seglarstövlarna": "seglarstövel",
    "seglarstövlarnas": "seglarstövel",
    "seglarstövlars": "seglarstövel",
    "seglas": "segla",
    "seglat": "segla",
    "seglationen": "seglation",
    "seglationens": "seglation",
    "seglationer": "seglation",
    "seglationerna": "seglation",
    "seglationernas": "seglation",
    "seglationers": "seglation",
    "seglations": "seglation",
    "seglationsklara": "seglationsklar",
    "seglationsklarare": "seglationsklar",
    "seglationsklarares": "seglationsklar",
    "seglationsklaras": "seglationsklar",
    "seglationsklarast": "seglationsklar",
    "seglationsklaraste": "seglationsklar",
    "seglationsklarastes": "seglationsklar",
    "seglationsklarasts": "seglationsklar",
    "seglationsklare": "seglationsklar",
    "seglationsklares": "seglationsklar",
    "seglationsklars": "seglationsklar",
    "seglationsklart": "seglationsklar",
    "seglationsklarts": "seglationsklar",
    "seglats": "segla",
    "seglatsen": "seglats",
    "seglatsens": "seglats",
    "seglatser": "seglats",
    "seglatserna": "seglats",
    "seglatsernas": "seglats",
    "seglatsers": "seglats",
    "seglen": "segel",
    "seglens": "segel",
    "seglet": "segel",
    "seglets": "segel",
    "seglingar": "segling",
    "seglingarna": "segling",
    "seglingarnas": "segling",
    "seglingars": "segling",
    "seglingen": "segling",
    "seglingens": "segling",
    "seglings": "segling",
    "seglingsbeskrivningar": "seglingsbeskrivning",
    "seglingsbeskrivningarna": "seglingsbeskrivning",
    "seglingsbeskrivningarnas": "seglingsbeskrivning",
    "seglingsbeskrivningars": "seglingsbeskrivning",
    "seglingsbeskrivningen": "seglingsbeskrivning",
    "seglingsbeskrivningens": "seglingsbeskrivning",
    "seglingsbeskrivnings": "seglingsbeskrivning",
    "seglingsfria": "seglingsfri",
    "seglingsfriare": "seglingsfri",
    "seglingsfriares": "seglingsfri",
    "seglingsfrias": "seglingsfri",
    "seglingsfriast": "seglingsfri",
    "seglingsfriaste": "seglingsfri",
    "seglingsfriastes": "seglingsfri",
    "seglingsfriasts": "seglingsfri",
    "seglingsfrie": "seglingsfri",
    "seglingsfries": "seglingsfri",
    "seglingsfris": "seglingsfri",
    "seglingsfritt": "seglingsfri",
    "seglingsfritts": "seglingsfri",
    "seglivade": "seglivad",
    "seglivades": "seglivad",
    "seglivads": "seglivad",
    "seglivat": "seglivad",
    "seglivats": "seglivad",
    "segmentbåg": "segmentbåge",
    "segmentbågar": "segmentbåge",
    "segmentbågarna": "segmentbåge",
    "segmentbågarnas": "segmentbåge",
    "segmentbågars": "segmentbåge",
    "segmentbågen": "segmentbåge",
    "segmentbågens": "segmentbåge",
    "segmentbåges": "segmentbåge",
    "segmentbågs": "segmentbåge",
    "segmentella": "segmentell",
    "segmentellare": "segmentell",
    "segmentellares": "segmentell",
    "segmentellas": "segmentell",
    "segmentellast": "segmentell",
    "segmentellaste": "segmentell",
    "segmentellastes": "segmentell",
    "segmentellasts": "segmentell",
    "segmentelle": "segmentell",
    "segmentelles": "segmentell",
    "segmentells": "segmentell",
    "segmentellt": "segmentell",
    "segmentellts": "segmentell",
    "segmenten": "segment",
    "segmentens": "segment",
    "segmenterad": "segmentera",
    "segmenterade": "segmentera",
    "segmenterades": "segmentera",
    "segmenterads": "segmentera",
    "segmenterande": "segmentera",
    "segmenteranden": "segmenterande",
    "segmenterandena": "segmenterande",
    "segmenterandenas": "segmenterande",
    "segmenterandens": "segmenterande",
    "segmenterandes": "segmenterande",
    "segmenterandet": "segmenterande",
    "segmenterandets": "segmenterande",
    "segmenterar": "segmentera",
    "segmenteras": "segmentera",
    "segmenterat": "segmentera",
    "segmenterats": "segmentera",
    "segmenterbara": "segmenterbar",
    "segmenterbarare": "segmenterbar",
    "segmenterbarares": "segmenterbar",
    "segmenterbaras": "segmenterbar",
    "segmenterbarast": "segmenterbar",
    "segmenterbaraste": "segmenterbar",
    "segmenterbarastes": "segmenterbar",
    "segmenterbarasts": "segmenterbar",
    "segmenterbare": "segmenterbar",
    "segmenterbares": "segmenterbar",
    "segmenterbarheten": "segmenterbarhet",
    "segmenterbarhetens": "segmenterbarhet",
    "segmenterbarhets": "segmenterbarhet",
    "segmenterbars": "segmenterbar",
    "segmenterbart": "segmenterbar",
    "segmenterbarts": "segmenterbar",
    "segmenteringar": "segmentering",
    "segmenteringarna": "segmentering",
    "segmenteringarnas": "segmentering",
    "segmenteringars": "segmentering",
    "segmenteringen": "segmentering",
    "segmenteringens": "segmentering",
    "segmenterings": "segmentering",
    "segmentet": "segment",
    "segmentets": "segment",
    "segments": "segment",
    "segmogens": "segmogen",
    "segmoget": "segmogen",
    "segmogets": "segmogen",
    "segmogna": "segmogen",
    "segmognare": "segmogen",
    "segmognares": "segmogen",
    "segmognas": "segmogen",
    "segmognast": "segmogen",
    "segmognaste": "segmogen",
    "segmognastes": "segmogen",
    "segmognasts": "segmogen",
    "segmogne": "segmogen",
    "segmognes": "segmogen",
    "segnade": "segna",
    "segnades": "segna",
    "segnande": "segna",
    "segnanden": "segnande",
    "segnandena": "segnande",
    "segnandenas": "segnande",
    "segnandens": "segnande",
    "segnandes": "segnande",
    "segnandet": "segnande",
    "segnandets": "segnande",
    "segnar": "segna",
    "segnas": "segna",
    "segnat": "segna",
    "segnats": "segna",
    "segrad": "segra",
    "segrade": "segra",
    "segrades": "segra",
    "segrads": "segra",
    "segrande": "segra",
    "segranden": "segrande",
    "segrandena": "segrande",
    "segrandenas": "segrande",
    "segrandens": "segrande",
    "segrandes": "segrande",
    "segrandet": "segrande",
    "segrandets": "segrande",
    "segrar": "segrare",
    "segraren": "segrare",
    "segrarens": "segrare",
    "segrares": "segrare",
    "segrarna": "segrare",
    "segrarnas": "segrare",
    "segrars": "seger",
    "segras": "segra",
    "segrat": "segra",
    "segrats": "segra",
    "segregaten": "segregat",
    "segregatens": "segregat",
    "segregatet": "segregat",
    "segregatets": "segregat",
    "segregationen": "segregation",
    "segregationens": "segregation",
    "segregationer": "segregation",
    "segregationerna": "segregation",
    "segregationernas": "segregation",
    "segregationers": "segregation",
    "segregations": "segregation",
    "segregats": "segregat",
    "segregerad": "segregera",
    "segregerade": "segregera",
    "segregerades": "segregera",
    "segregerads": "segregera",
    "segregerande": "segregera",
    "segregeranden": "segregerande",
    "segregerandena": "segregerande",
    "segregerandenas": "segregerande",
    "segregerandens": "segregerande",
    "segregerandes": "segregerande",
    "segregerandet": "segregerande",
    "segregerandets": "segregerande",
    "segregerar": "segregera",
    "segregeras": "segregera",
    "segregerat": "segregera",
    "segregerats": "segregera",
    "segregerbara": "segregerbar",
    "segregerbarare": "segregerbar",
    "segregerbarares": "segregerbar",
    "segregerbaras": "segregerbar",
    "segregerbarast": "segregerbar",
    "segregerbaraste": "segregerbar",
    "segregerbarastes": "segregerbar",
    "segregerbarasts": "segregerbar",
    "segregerbare": "segregerbar",
    "segregerbares": "segregerbar",
    "segregerbarheten": "segregerbarhet",
    "segregerbarhetens": "segregerbarhet",
    "segregerbarhets": "segregerbarhet",
    "segregerbars": "segregerbar",
    "segregerbart": "segregerbar",
    "segregerbarts": "segregerbar",
    "segregeringar": "segregering",
    "segregeringarna": "segregering",
    "segregeringarnas": "segregering",
    "segregeringars": "segregering",
    "segregeringen": "segregering",
    "segregeringens": "segregering",
    "segregerings": "segregering",
    "segringar": "segring",
    "segringarna": "segring",
    "segringarnas": "segring",
    "segringars": "segring",
    "segringen": "segring",
    "segringens": "segring",
    "segrings": "segring",
    "segs": "seg",
    "segslitens": "segsliten",
    "segslitet": "segsliten",
    "segslitets": "segsliten",
    "segslitna": "segsliten",
    "segslitnare": "segsliten",
    "segslitnares": "segsliten",
    "segslitnas": "segsliten",
    "segslitnast": "segsliten",
    "segslitnaste": "segsliten",
    "segslitnastes": "segsliten",
    "segslitnasts": "segsliten",
    "segslitne": "segsliten",
    "segslitnes": "segsliten",
    "segt": "seg",
    "segts": "seg",
    "seigneuren": "seigneur",
    "seigneurens": "seigneur",
    "seigneurer": "seigneur",
    "seigneurerna": "seigneur",
    "seigneurernas": "seigneur",
    "seigneurers": "seigneur",
    "seigneurs": "seigneur",
    "seismiska": "seismisk",
    "seismiskare": "seismisk",
    "seismiskares": "seismisk",
    "seismiskas": "seismisk",
    "seismiskast": "seismisk",
    "seismiskaste": "seismisk",
    "seismiskastes": "seismisk",
    "seismiskasts": "seismisk",
    "seismiske": "seismisk",
    "seismiskes": "seismisk",
    "seismisks": "seismisk",
    "seismiskt": "seismisk",
    "seismiskts": "seismisk",
    "seismografen": "seismograf",
    "seismografens": "seismograf",
    "seismografer": "seismograf",
    "seismograferna": "seismograf",
    "seismografernas": "seismograf",
    "seismografers": "seismograf",
    "seismografs": "seismograf",
    "seismogrammen": "seismogram",
    "seismogrammens": "seismogram",
    "seismogrammet": "seismogram",
    "seismogrammets": "seismogram",
    "seismograms": "seismogram",
    "seismologien": "seismologi",
    "seismologiens": "seismologi",
    "seismologin": "seismologi",
    "seismologins": "seismologi",
    "seismologis": "seismologi",
    "seismometern": "seismometer",
    "seismometerns": "seismometer",
    "seismometers": "seismometer",
    "seismometrar": "seismometer",
    "seismometrarna": "seismometer",
    "seismometrarnas": "seismometer",
    "seismometrars": "seismometer",
    "sej": "sig",
    "sejar": "sej",
    "sejarna": "sej",
    "sejarnas": "sej",
    "sejars": "sej",
    "sejdade": "sejda",
    "sejdades": "sejda",
    "sejdande": "sejda",
    "sejdanden": "sejdande",
    "sejdandena": "sejdande",
    "sejdandenas": "sejdande",
    "sejdandens": "sejdande",
    "sejdandes": "sejdande",
    "sejdandet": "sejdande",
    "sejdandets": "sejdande",
    "sejdar": "sejdare",
    "sejdaren": "sejdare",
    "sejdarens": "sejdare",
    "sejdares": "sejdare",
    "sejdarna": "sejdare",
    "sejdarnas": "sejdare",
    "sejdas": "sejda",
    "sejdat": "sejda",
    "sejdats": "sejda",
    "sejdeln": "sejdel",
    "sejdelns": "sejdel",
    "sejdels": "sejdel",
    "sejden": "sejd",
    "sejdens": "sejd",
    "sejdlar": "sejdel",
    "sejdlarna": "sejdel",
    "sejdlarnas": "sejdel",
    "sejdlars": "sejdel",
    "sejds": "sejd",
    "sejen": "sej",
    "sejens": "sej",
    "sejmen": "sejm",
    "sejmens": "sejm",
    "sejms": "sejm",
    "sejnfallen": "sejnfall",
    "sejnfallens": "sejnfall",
    "sejnfallet": "sejnfall",
    "sejnfallets": "sejnfall",
    "sejnfalls": "sejnfall",
    "sejouren": "sejour",
    "sejourens": "sejour",
    "sejourer": "sejour",
    "sejourerna": "sejour",
    "sejourernas": "sejour",
    "sejourers": "sejour",
    "sejours": "sejour",
    "sejs": "sejsa",
    "sejsad": "sejsa",
    "sejsade": "sejsa",
    "sejsades": "sejsa",
    "sejsads": "sejsa",
    "sejsande": "sejsa",
    "sejsanden": "sejsande",
    "sejsandena": "sejsande",
    "sejsandenas": "sejsande",
    "sejsandens": "sejsande",
    "sejsandes": "sejsande",
    "sejsandet": "sejsande",
    "sejsandets": "sejsande",
    "sejsar": "sejsa",
    "sejsas": "sejsa",
    "sejsat": "sejsa",
    "sejsats": "sejsa",
    "sejsingar": "sejsing",
    "sejsingarna": "sejsing",
    "sejsingarnas": "sejsing",
    "sejsingars": "sejsing",
    "sejsingen": "sejsing",
    "sejsingens": "sejsing",
    "sejsings": "sejsing",
    "sejsningar": "sejsning",
    "sejsningarna": "sejsning",
    "sejsningarnas": "sejsning",
    "sejsningars": "sejsning",
    "sejsningen": "sejsning",
    "sejsningens": "sejsning",
    "sejsnings": "sejsning",
    "sejt": "sejte",
    "sejtar": "sejte",
    "sejtarna": "sejte",
    "sejtarnas": "sejte",
    "sejtars": "sejte",
    "sejten": "sejte",
    "sejtens": "sejte",
    "sejtes": "sejte",
    "sejts": "sejte",
    "sekanten": "sekant",
    "sekantens": "sekant",
    "sekanter": "sekant",
    "sekanterna": "sekant",
    "sekanternas": "sekant",
    "sekanters": "sekant",
    "sekants": "sekant",
    "sekatören": "sekatör",
    "sekatörens": "sekatör",
    "sekatörer": "sekatör",
    "sekatörerna": "sekatör",
    "sekatörernas": "sekatör",
    "sekatörers": "sekatör",
    "sekatörs": "sekatör",
    "sekelgamla": "sekelgammal",
    "sekelgamlas": "sekelgammal",
    "sekelgamle": "sekelgammal",
    "sekelgamles": "sekelgammal",
    "sekelgammals": "sekelgammal",
    "sekelgammalt": "sekelgammal",
    "sekelgammalts": "sekelgammal",
    "sekellånga": "sekellång",
    "sekellångare": "sekellång",
    "sekellångares": "sekellång",
    "sekellångas": "sekellång",
    "sekellångast": "sekellång",
    "sekellångaste": "sekellång",
    "sekellångastes": "sekellång",
    "sekellångasts": "sekellång",
    "sekellånge": "sekellång",
    "sekellånges": "sekellång",
    "sekellångs": "sekellång",
    "sekellångt": "sekellång",
    "sekellångts": "sekellång",
    "sekels": "sekel",
    "sekelskiften": "sekelskifte",
    "sekelskiftena": "sekelskifte",
    "sekelskiftenas": "sekelskifte",
    "sekelskiftens": "sekelskifte",
    "sekelskiftes": "sekelskifte",
    "sekelskiftesintellektuella": "sekelskiftesintellektuell",
    "sekelskiftesintellektuellas": "sekelskiftesintellektuell",
    "sekelskiftesintellektuelle": "sekelskiftesintellektuell",
    "sekelskiftesintellektuelles": "sekelskiftesintellektuell",
    "sekelskiftesintellektuells": "sekelskiftesintellektuell",
    "sekelskiftesintellektuellt": "sekelskiftesintellektuell",
    "sekelskiftesintellektuellts": "sekelskiftesintellektuell",
    "sekelskiftet": "sekelskifte",
    "sekelskiftets": "sekelskifte",
    "sekelskiftshusen": "sekelskiftshus",
    "sekelskiftshusens": "sekelskiftshus",
    "sekelskiftshuset": "sekelskiftshus",
    "sekelskiftshusets": "sekelskiftshus",
    "sekinen": "sekin",
    "sekinens": "sekin",
    "sekiner": "sekin",
    "sekinerna": "sekin",
    "sekinernas": "sekin",
    "sekiners": "sekin",
    "sekins": "sekin",
    "seklen": "sekel",
    "seklens": "sekel",
    "sekler": "sekel",
    "seklerna": "sekel",
    "seklernas": "sekel",
    "seklers": "sekel",
    "seklet": "sekel",
    "seklets": "sekel",
    "sekonden": "sekond",
    "sekondens": "sekond",
    "sekonder": "sekond",
    "sekonderad": "sekondera",
    "sekonderade": "sekondera",
    "sekonderades": "sekondera",
    "sekonderads": "sekondera",
    "sekonderande": "sekondera",
    "sekonderanden": "sekonderande",
    "sekonderandena": "sekonderande",
    "sekonderandenas": "sekonderande",
    "sekonderandens": "sekonderande",
    "sekonderandes": "sekonderande",
    "sekonderandet": "sekonderande",
    "sekonderandets": "sekonderande",
    "sekonderar": "sekondera",
    "sekonderas": "sekondera",
    "sekonderat": "sekondera",
    "sekonderats": "sekondera",
    "sekonderbara": "sekonderbar",
    "sekonderbarare": "sekonderbar",
    "sekonderbarares": "sekonderbar",
    "sekonderbaras": "sekonderbar",
    "sekonderbarast": "sekonderbar",
    "sekonderbaraste": "sekonderbar",
    "sekonderbarastes": "sekonderbar",
    "sekonderbarasts": "sekonderbar",
    "sekonderbare": "sekonderbar",
    "sekonderbares": "sekonderbar",
    "sekonderbarheten": "sekonderbarhet",
    "sekonderbarhetens": "sekonderbarhet",
    "sekonderbarhets": "sekonderbarhet",
    "sekonderbars": "sekonderbar",
    "sekonderbart": "sekonderbar",
    "sekonderbarts": "sekonderbar",
    "sekonderingar": "sekondering",
    "sekonderingarna": "sekondering",
    "sekonderingarnas": "sekondering",
    "sekonderingars": "sekondering",
    "sekonderingen": "sekondering",
    "sekonderingens": "sekondering",
    "sekonderings": "sekondering",
    "sekonderna": "sekond",
    "sekondernas": "sekond",
    "sekonders": "sekond",
    "sekonds": "sekond",
    "sekreta": "sekret",
    "sekretare": "sekret",
    "sekretares": "sekret",
    "sekretariaten": "sekretariat",
    "sekretariatens": "sekretariat",
    "sekretariatet": "sekretariat",
    "sekretariatets": "sekretariat",
    "sekretariats": "sekretariat",
    "sekretas": "sekret",
    "sekretast": "sekret",
    "sekretaste": "sekret",
    "sekretastes": "sekret",
    "sekretasts": "sekret",
    "sekrete": "sekret",
    "sekreten": "sekret",
    "sekretens": "sekret",
    "sekreterar": "sekreterare",
    "sekreteraren": "sekreterare",
    "sekreterarens": "sekreterare",
    "sekreterares": "sekreterare",
    "sekreterarfågeln": "sekreterarfågel",
    "sekreterarfågelns": "sekreterarfågel",
    "sekreterarfågels": "sekreterarfågel",
    "sekreterarfåglar": "sekreterarfågel",
    "sekreterarfåglarna": "sekreterarfågel",
    "sekreterarfåglarnas": "sekreterarfågel",
    "sekreterarfåglars": "sekreterarfågel",
    "sekreterarna": "sekreterare",
    "sekreterarnas": "sekreterare",
    "sekretes": "sekret",
    "sekretessbela": "sekretessbelägga",
    "sekretessbelade": "sekretessbelägga",
    "sekretessbelades": "sekretessbelägga",
    "sekretessbelagd": "sekretessbelägga",
    "sekretessbelagda": "sekretessbelägga",
    "sekretessbelagdas": "sekretessbelägga",
    "sekretessbelagde": "sekretessbelägga",
    "sekretessbelagdes": "sekretessbelägga",
    "sekretessbelagds": "sekretessbelägga",
    "sekretessbelagt": "sekretessbelägga",
    "sekretessbelagts": "sekretessbelägga",
    "sekretessbelas": "sekretessbelägga",
    "sekretessbelägg": "sekretessbelägga",
    "sekretessbeläggande": "sekretessbelägga",
    "sekretessbelägganden": "sekretessbeläggande",
    "sekretessbeläggandena": "sekretessbeläggande",
    "sekretessbeläggandenas": "sekretessbeläggande",
    "sekretessbeläggandens": "sekretessbeläggande",
    "sekretessbeläggandes": "sekretessbeläggande",
    "sekretessbeläggandet": "sekretessbeläggande",
    "sekretessbeläggandets": "sekretessbeläggande",
    "sekretessbeläggas": "sekretessbelägga",
    "sekretessbelägger": "sekretessbelägga",
    "sekretessbelägges": "sekretessbelägga",
    "sekretessbeläggs": "sekretessbelägga",
    "sekretessen": "sekretess",
    "sekretessens": "sekretess",
    "sekretessprövningar": "sekretessprövning",
    "sekretessprövningarna": "sekretessprövning",
    "sekretessprövningarnas": "sekretessprövning",
    "sekretessprövningars": "sekretessprövning",
    "sekretessprövningen": "sekretessprövning",
    "sekretessprövningens": "sekretessprövning",
    "sekretessprövnings": "sekretessprövning",
    "sekretet": "sekret",
    "sekretets": "sekret",
    "sekretionen": "sekretion",
    "sekretionens": "sekretion",
    "sekretioner": "sekretion",
    "sekretionerna": "sekretion",
    "sekretionernas": "sekretion",
    "sekretioners": "sekretion",
    "sekretions": "sekretion",
    "sekretionsrubbningar": "sekretionsrubbning",
    "sekretionsrubbningarna": "sekretionsrubbning",
    "sekretionsrubbningarnas": "sekretionsrubbning",
    "sekretionsrubbningars": "sekretionsrubbning",
    "sekretionsrubbningen": "sekretionsrubbning",
    "sekretionsrubbningens": "sekretionsrubbning",
    "sekretionsrubbnings": "sekretionsrubbning",
    "sekretoriska": "sekretorisk",
    "sekretoriskare": "sekretorisk",
    "sekretoriskares": "sekretorisk",
    "sekretoriskas": "sekretorisk",
    "sekretoriskast": "sekretorisk",
    "sekretoriskaste": "sekretorisk",
    "sekretoriskastes": "sekretorisk",
    "sekretoriskasts": "sekretorisk",
    "sekretoriske": "sekretorisk",
    "sekretoriskes": "sekretorisk",
    "sekretorisks": "sekretorisk",
    "sekretoriskt": "sekretorisk",
    "sekretoriskts": "sekretorisk",
    "sekrets": "sekret",
    "sekretären": "sekretär",
    "sekretärens": "sekretär",
    "sekretärer": "sekretär",
    "sekretärerna": "sekretär",
    "sekretärernas": "sekretär",
    "sekretärers": "sekretär",
    "sekretärs": "sekretär",
    "sekten": "sekt",
    "sektens": "sekt",
    "sekter": "sekt",
    "sekterismen": "sekterism",
    "sekterismens": "sekterism",
    "sekterismer": "sekterism",
    "sekterismerna": "sekterism",
    "sekterismernas": "sekterism",
    "sekterismers": "sekterism",
    "sekterisms": "sekterism",
    "sekteristiska": "sekteristisk",
    "sekteristiskare": "sekteristisk",
    "sekteristiskares": "sekteristisk",
    "sekteristiskas": "sekteristisk",
    "sekteristiskast": "sekteristisk",
    "sekteristiskaste": "sekteristisk",
    "sekteristiskastes": "sekteristisk",
    "sekteristiskasts": "sekteristisk",
    "sekteristiske": "sekteristisk",
    "sekteristiskes": "sekteristisk",
    "sekteristisks": "sekteristisk",
    "sekteristiskt": "sekteristisk",
    "sekteristiskts": "sekteristisk",
    "sektern": "sekter",
    "sekterna": "sekt",
    "sekternas": "sekt",
    "sekterns": "sekter",
    "sekters": "sekter",
    "sektionen": "sektion",
    "sektionens": "sektion",
    "sektioner": "sektion",
    "sektionerna": "sektion",
    "sektionernas": "sektion",
    "sektioners": "sektion",
    "sektions": "sektion",
    "sektmentaliteten": "sektmentalitet",
    "sektmentalitetens": "sektmentalitet",
    "sektmentaliteter": "sektmentalitet",
    "sektmentaliteterna": "sektmentalitet",
    "sektmentaliteternas": "sektmentalitet",
    "sektmentaliteters": "sektmentalitet",
    "sektmentalitets": "sektmentalitet",
    "sektorer": "sektor",
    "sektorerna": "sektor",
    "sektorernas": "sektor",
    "sektorers": "sektor",
    "sektorfyrar": "sektorfyr",
    "sektorfyrarna": "sektorfyr",
    "sektorfyrarnas": "sektorfyr",
    "sektorfyrars": "sektorfyr",
    "sektorfyren": "sektorfyr",
    "sektorfyrens": "sektorfyr",
    "sektorfyrs": "sektorfyr",
    "sektoriella": "sektoriell",
    "sektoriellare": "sektoriell",
    "sektoriellares": "sektoriell",
    "sektoriellas": "sektoriell",
    "sektoriellast": "sektoriell",
    "sektoriellaste": "sektoriell",
    "sektoriellastes": "sektoriell",
    "sektoriellasts": "sektoriell",
    "sektorielle": "sektoriell",
    "sektorielles": "sektoriell",
    "sektoriells": "sektoriell",
    "sektoriellt": "sektoriell",
    "sektoriellts": "sektoriell",
    "sektorn": "sektor",
    "sektorns": "sektor",
    "sektorportar": "sektorport",
    "sektorportarna": "sektorport",
    "sektorportarnas": "sektorport",
    "sektorportars": "sektorport",
    "sektorporten": "sektorport",
    "sektorportens": "sektorport",
    "sektorports": "sektorport",
    "sektors": "sektor",
    "sekts": "sekt",
    "sekularisationen": "sekularisation",
    "sekularisationens": "sekularisation",
    "sekularisationer": "sekularisation",
    "sekularisationerna": "sekularisation",
    "sekularisationernas": "sekularisation",
    "sekularisationers": "sekularisation",
    "sekularisations": "sekularisation",
    "sekulariserad": "sekularisera",
    "sekulariserade": "sekularisera",
    "sekulariserades": "sekularisera",
    "sekulariserads": "sekularisera",
    "sekulariserande": "sekularisera",
    "sekulariseranden": "sekulariserande",
    "sekulariserandena": "sekulariserande",
    "sekulariserandenas": "sekulariserande",
    "sekulariserandens": "sekulariserande",
    "sekulariserandes": "sekulariserande",
    "sekulariserandet": "sekulariserande",
    "sekulariserandets": "sekulariserande",
    "sekulariserar": "sekularisera",
    "sekulariseras": "sekularisera",
    "sekulariserat": "sekularisera",
    "sekulariserats": "sekularisera",
    "sekulariserbara": "sekulariserbar",
    "sekulariserbarare": "sekulariserbar",
    "sekulariserbarares": "sekulariserbar",
    "sekulariserbaras": "sekulariserbar",
    "sekulariserbarast": "sekulariserbar",
    "sekulariserbaraste": "sekulariserbar",
    "sekulariserbarastes": "sekulariserbar",
    "sekulariserbarasts": "sekulariserbar",
    "sekulariserbare": "sekulariserbar",
    "sekulariserbares": "sekulariserbar",
    "sekulariserbarheten": "sekulariserbarhet",
    "sekulariserbarhetens": "sekulariserbarhet",
    "sekulariserbarhets": "sekulariserbarhet",
    "sekulariserbars": "sekulariserbar",
    "sekulariserbart": "sekulariserbar",
    "sekulariserbarts": "sekulariserbar",
    "sekulariseringar": "sekularisering",
    "sekulariseringarna": "sekularisering",
    "sekulariseringarnas": "sekularisering",
    "sekulariseringars": "sekularisering",
    "sekulariseringen": "sekularisering",
    "sekulariseringens": "sekularisering",
    "sekulariserings": "sekularisering",
    "sekularprästen": "sekularpräst",
    "sekularprästens": "sekularpräst",
    "sekularpräster": "sekularpräst",
    "sekularprästerna": "sekularpräst",
    "sekularprästernas": "sekularpräst",
    "sekularprästers": "sekularpräst",
    "sekularprästs": "sekularpräst",
    "sekularsnillen": "sekularsnille",
    "sekularsnillena": "sekularsnille",
    "sekularsnillenas": "sekularsnille",
    "sekularsnillens": "sekularsnille",
    "sekularsnilles": "sekularsnille",
    "sekularsnillet": "sekularsnille",
    "sekularsnillets": "sekularsnille",
    "sekularsnills": "sekularsnille",
    "sekulära": "sekulär",
    "sekulärare": "sekulär",
    "sekulärares": "sekulär",
    "sekuläras": "sekulär",
    "sekulärast": "sekulär",
    "sekuläraste": "sekulär",
    "sekulärastes": "sekulär",
    "sekulärasts": "sekulär",
    "sekuläre": "sekulär",
    "sekuläres": "sekulär",
    "sekulärs": "sekulär",
    "sekulärt": "sekulär",
    "sekulärts": "sekulär",
    "sekundanten": "sekundant",
    "sekundantens": "sekundant",
    "sekundanter": "sekundant",
    "sekundanterna": "sekundant",
    "sekundanternas": "sekundant",
    "sekundanters": "sekundant",
    "sekundants": "sekundant",
    "sekundchefen": "sekundchef",
    "sekundchefens": "sekundchef",
    "sekundchefer": "sekundchef",
    "sekundcheferna": "sekundchef",
    "sekundchefernas": "sekundchef",
    "sekundchefers": "sekundchef",
    "sekundchefs": "sekundchef",
    "sekunden": "sekund",
    "sekundens": "sekund",
    "sekunder": "sekund",
    "sekunderad": "sekundera",
    "sekunderade": "sekundera",
    "sekunderades": "sekundera",
    "sekunderads": "sekundera",
    "sekunderande": "sekundera",
    "sekunderanden": "sekunderande",
    "sekunderandena": "sekunderande",
    "sekunderandenas": "sekunderande",
    "sekunderandens": "sekunderande",
    "sekunderandes": "sekunderande",
    "sekunderandet": "sekunderande",
    "sekunderandets": "sekunderande",
    "sekunderar": "sekundera",
    "sekunderas": "sekundera",
    "sekunderat": "sekundera",
    "sekunderats": "sekundera",
    "sekunderbara": "sekunderbar",
    "sekunderbarare": "sekunderbar",
    "sekunderbarares": "sekunderbar",
    "sekunderbaras": "sekunderbar",
    "sekunderbarast": "sekunderbar",
    "sekunderbaraste": "sekunderbar",
    "sekunderbarastes": "sekunderbar",
    "sekunderbarasts": "sekunderbar",
    "sekunderbare": "sekunderbar",
    "sekunderbares": "sekunderbar",
    "sekunderbarheten": "sekunderbarhet",
    "sekunderbarhetens": "sekunderbarhet",
    "sekunderbarhets": "sekunderbarhet",
    "sekunderbars": "sekunderbar",
    "sekunderbart": "sekunderbar",
    "sekunderbarts": "sekunderbar",
    "sekunderingar": "sekundering",
    "sekunderingarna": "sekundering",
    "sekunderingarnas": "sekundering",
    "sekunderingars": "sekundering",
    "sekunderingen": "sekundering",
    "sekunderingens": "sekundering",
    "sekunderings": "sekundering",
    "sekunderna": "sekund",
    "sekundernas": "sekund",
    "sekunders": "sekund",
    "sekundmetern": "sekundmeter",
    "sekundmeterna": "sekundmeter",
    "sekundmeternas": "sekundmeter",
    "sekundmeterns": "sekundmeter",
    "sekundmeters": "sekundmeter",
    "sekunds": "sekund",
    "sekundvisar": "sekundvisare",
    "sekundvisaren": "sekundvisare",
    "sekundvisarens": "sekundvisare",
    "sekundvisares": "sekundvisare",
    "sekundvisarna": "sekundvisare",
    "sekundvisarnas": "sekundvisare",
    "sekundära": "sekundär",
    "sekundärare": "sekundär",
    "sekundärares": "sekundär",
    "sekundäras": "sekundär",
    "sekundärast": "sekundär",
    "sekundäraste": "sekundär",
    "sekundärastes": "sekundär",
    "sekundärasts": "sekundär",
    "sekundärbelysningar": "sekundärbelysning",
    "sekundärbelysningarna": "sekundärbelysning",
    "sekundärbelysningarnas": "sekundärbelysning",
    "sekundärbelysningars": "sekundärbelysning",
    "sekundärbelysningen": "sekundärbelysning",
    "sekundärbelysningens": "sekundärbelysning",
    "sekundärbelysnings": "sekundärbelysning",
    "sekundäre": "sekundär",
    "sekundäres": "sekundär",
    "sekundärgruppen": "sekundärgrupp",
    "sekundärgruppens": "sekundärgrupp",
    "sekundärgrupper": "sekundärgrupp",
    "sekundärgrupperna": "sekundärgrupp",
    "sekundärgruppernas": "sekundärgrupp",
    "sekundärgruppers": "sekundärgrupp",
    "sekundärgrupps": "sekundärgrupp",
    "sekundärinfektionen": "sekundärinfektion",
    "sekundärinfektionens": "sekundärinfektion",
    "sekundärinfektioner": "sekundärinfektion",
    "sekundärinfektionerna": "sekundärinfektion",
    "sekundärinfektionernas": "sekundärinfektion",
    "sekundärinfektioners": "sekundärinfektion",
    "sekundärinfektions": "sekundärinfektion",
    "sekundärkommunen": "sekundärkommun",
    "sekundärkommunens": "sekundärkommun",
    "sekundärkommuner": "sekundärkommun",
    "sekundärkommunerna": "sekundärkommun",
    "sekundärkommunernas": "sekundärkommun",
    "sekundärkommuners": "sekundärkommun",
    "sekundärkommuns": "sekundärkommun",
    "sekundärluften": "sekundärluft",
    "sekundärluftens": "sekundärluft",
    "sekundärlufts": "sekundärluft",
    "sekundärminnen": "sekundärminne",
    "sekundärminnena": "sekundärminne",
    "sekundärminnenas": "sekundärminne",
    "sekundärminnens": "sekundärminne",
    "sekundärminnes": "sekundärminne",
    "sekundärminnet": "sekundärminne",
    "sekundärminnets": "sekundärminne",
    "sekundärs": "sekundär",
    "sekundärskolan": "sekundärskola",
    "sekundärskolans": "sekundärskola",
    "sekundärskolas": "sekundärskola",
    "sekundärskole": "sekundärskola",
    "sekundärskolor": "sekundärskola",
    "sekundärskolorna": "sekundärskola",
    "sekundärskolornas": "sekundärskola",
    "sekundärskolors": "sekundärskola",
    "sekundärspol": "sekundärspole",
    "sekundärspolar": "sekundärspole",
    "sekundärspolarna": "sekundärspole",
    "sekundärspolarnas": "sekundärspole",
    "sekundärspolars": "sekundärspole",
    "sekundärspolen": "sekundärspole",
    "sekundärspolens": "sekundärspole",
    "sekundärspoles": "sekundärspole",
    "sekundärspols": "sekundärspole",
    "sekundärstadie": "sekundärstadium",
    "sekundärstadier": "sekundärstadium",
    "sekundärstadierna": "sekundärstadium",
    "sekundärstadiernas": "sekundärstadium",
    "sekundärstadiers": "sekundärstadium",
    "sekundärstadiet": "sekundärstadium",
    "sekundärstadiets": "sekundärstadium",
    "sekundärstadiums": "sekundärstadium",
    "sekundärströmmar": "sekundärström",
    "sekundärströmmarna": "sekundärström",
    "sekundärströmmarnas": "sekundärström",
    "sekundärströmmars": "sekundärström",
    "sekundärströmmen": "sekundärström",
    "sekundärströmmens": "sekundärström",
    "sekundärströms": "sekundärström",
    "sekundärt": "sekundär",
    "sekundärts": "sekundär",
    "sekvensen": "sekvens",
    "sekvensens": "sekvens",
    "sekvenser": "sekvens",
    "sekvenserad": "sekvensera",
    "sekvenserade": "sekvensera",
    "sekvenserades": "sekvensera",
    "sekvenserads": "sekvensera",
    "sekvenserande": "sekvensera",
    "sekvenseranden": "sekvenserande",
    "sekvenserandena": "sekvenserande",
    "sekvenserandenas": "sekvenserande",
    "sekvenserandens": "sekvenserande",
    "sekvenserandes": "sekvenserande",
    "sekvenserandet": "sekvenserande",
    "sekvenserandets": "sekvenserande",
    "sekvenserar": "sekvensera",
    "sekvenseras": "sekvensera",
    "sekvenserat": "sekvensera",
    "sekvenserats": "sekvensera",
    "sekvenseringar": "sekvensering",
    "sekvenseringarna": "sekvensering",
    "sekvenseringarnas": "sekvensering",
    "sekvenseringars": "sekvensering",
    "sekvenseringen": "sekvensering",
    "sekvenseringens": "sekvensering",
    "sekvenserings": "sekvensering",
    "sekvenserna": "sekvens",
    "sekvensernas": "sekvens",
    "sekvensers": "sekvens",
    "sekventiella": "sekventiell",
    "sekventiellas": "sekventiell",
    "sekventielle": "sekventiell",
    "sekventielles": "sekventiell",
    "sekventiells": "sekventiell",
    "sekventiellt": "sekventiell",
    "sekventiellts": "sekventiell",
    "sekvestern": "sekvester",
    "sekvesterns": "sekvester",
    "sekvesters": "sekvester",
    "sekvestrerad": "sekvestrera",
    "sekvestrerade": "sekvestrera",
    "sekvestrerades": "sekvestrera",
    "sekvestrerads": "sekvestrera",
    "sekvestrerande": "sekvestrera",
    "sekvestreranden": "sekvestrerande",
    "sekvestrerandena": "sekvestrerande",
    "sekvestrerandenas": "sekvestrerande",
    "sekvestrerandens": "sekvestrerande",
    "sekvestrerandes": "sekvestrerande",
    "sekvestrerandet": "sekvestrerande",
    "sekvestrerandets": "sekvestrerande",
    "sekvestrerar": "sekvestrera",
    "sekvestreras": "sekvestrera",
    "sekvestrerat": "sekvestrera",
    "sekvestrerats": "sekvestrera",
    "sekvestrerbara": "sekvestrerbar",
    "sekvestrerbarare": "sekvestrerbar",
    "sekvestrerbarares": "sekvestrerbar",
    "sekvestrerbaras": "sekvestrerbar",
    "sekvestrerbarast": "sekvestrerbar",
    "sekvestrerbaraste": "sekvestrerbar",
    "sekvestrerbarastes": "sekvestrerbar",
    "sekvestrerbarasts": "sekvestrerbar",
    "sekvestrerbare": "sekvestrerbar",
    "sekvestrerbares": "sekvestrerbar",
    "sekvestrerbarheten": "sekvestrerbarhet",
    "sekvestrerbarhetens": "sekvestrerbarhet",
    "sekvestrerbarhets": "sekvestrerbarhet",
    "sekvestrerbars": "sekvestrerbar",
    "sekvestrerbart": "sekvestrerbar",
    "sekvestrerbarts": "sekvestrerbar",
    "sekvestreringar": "sekvestrering",
    "sekvestreringarna": "sekvestrering",
    "sekvestreringarnas": "sekvestrering",
    "sekvestreringars": "sekvestrering",
    "sekvestreringen": "sekvestrering",
    "sekvestreringens": "sekvestrering",
    "sekvestrerings": "sekvestrering",
    "sel": "sele",
    "selad": "sela",
    "selade": "sela",
    "selades": "sela",
    "selads": "sela",
    "selande": "sela",
    "selanden": "selande",
    "selandena": "selande",
    "selandenas": "selande",
    "selandens": "selande",
    "selandes": "selande",
    "selandet": "selande",
    "selandets": "selande",
    "selar": "sele",
    "selarna": "sele",
    "selarnas": "sele",
    "selars": "sele",
    "selas": "sela",
    "selat": "sela",
    "selats": "sela",
    "selbrotten": "selbrott",
    "selbrottens": "selbrott",
    "selbrottet": "selbrott",
    "selbrottets": "selbrott",
    "selbrotts": "selbrott",
    "selbrutens": "selbruten",
    "selbrutet": "selbruten",
    "selbrutets": "selbruten",
    "selbrutna": "selbruten",
    "selbrutnare": "selbruten",
    "selbrutnares": "selbruten",
    "selbrutnas": "selbruten",
    "selbrutnast": "selbruten",
    "selbrutnaste": "selbruten",
    "selbrutnastes": "selbruten",
    "selbrutnasts": "selbruten",
    "selbrutne": "selbruten",
    "selbrutnes": "selbruten",
    "seldonen": "seldon",
    "seldonens": "seldon",
    "seldonet": "seldon",
    "seldonets": "seldon",
    "seldons": "seldon",
    "selekterad": "selektera",
    "selekterade": "selektera",
    "selekterades": "selektera",
    "selekterads": "selektera",
    "selekterande": "selektera",
    "selekteranden": "selekterande",
    "selekterandena": "selekterande",
    "selekterandenas": "selekterande",
    "selekterandens": "selekterande",
    "selekterandes": "selekterande",
    "selekterandet": "selekterande",
    "selekterandets": "selekterande",
    "selekterar": "selektera",
    "selekteras": "selektera",
    "selekterat": "selektera",
    "selekterats": "selektera",
    "selekterbara": "selekterbar",
    "selekterbarare": "selekterbar",
    "selekterbarares": "selekterbar",
    "selekterbaras": "selekterbar",
    "selekterbarast": "selekterbar",
    "selekterbaraste": "selekterbar",
    "selekterbarastes": "selekterbar",
    "selekterbarasts": "selekterbar",
    "selekterbare": "selekterbar",
    "selekterbares": "selekterbar",
    "selekterbarheten": "selekterbarhet",
    "selekterbarhetens": "selekterbarhet",
    "selekterbarhets": "selekterbarhet",
    "selekterbars": "selekterbar",
    "selekterbart": "selekterbar",
    "selekterbarts": "selekterbar",
    "selekteringar": "selektering",
    "selekteringarna": "selektering",
    "selekteringarnas": "selektering",
    "selekteringars": "selektering",
    "selekteringen": "selektering",
    "selekteringens": "selektering",
    "selekterings": "selektering",
    "selektionen": "selektion",
    "selektionens": "selektion",
    "selektioner": "selektion",
    "selektionerna": "selektion",
    "selektionernas": "selektion",
    "selektioners": "selektion",
    "selektions": "selektion",
    "selektionsläran": "selektionslära",
    "selektionslärans": "selektionslära",
    "selektionsläras": "selektionslära",
    "selektiva": "selektiv",
    "selektivare": "selektiv",
    "selektivares": "selektiv",
    "selektivas": "selektiv",
    "selektivast": "selektiv",
    "selektivaste": "selektiv",
    "selektivastes": "selektiv",
    "selektivasts": "selektiv",
    "selektive": "selektiv",
    "selektives": "selektiv",
    "selektiviteten": "selektivitet",
    "selektivitetens": "selektivitet",
    "selektiviteter": "selektivitet",
    "selektiviteterna": "selektivitet",
    "selektiviteternas": "selektivitet",
    "selektiviteters": "selektivitet",
    "selektivitets": "selektivitet",
    "selektivs": "selektiv",
    "selektivt": "selektiv",
    "selektivts": "selektiv",
    "selen": "sele",
    "selencellen": "selencell",
    "selencellens": "selencell",
    "selenceller": "selencell",
    "selencellerna": "selencell",
    "selencellernas": "selencell",
    "selencellers": "selencell",
    "selencells": "selencell",
    "selenen": "selen",
    "selenens": "selen",
    "selenet": "selen",
    "selenets": "selen",
    "selens": "selen",
    "seles": "sele",
    "selet": "sel",
    "selets": "sel",
    "selleribottens": "selleribotten",
    "selleribottnar": "selleribotten",
    "selleribottnarna": "selleribotten",
    "selleribottnarnas": "selleribotten",
    "selleribottnars": "selleribotten",
    "selleribottnen": "selleribotten",
    "selleribottnens": "selleribotten",
    "sellerikålen": "sellerikål",
    "sellerikålens": "sellerikål",
    "sellerikåls": "sellerikål",
    "sellerin": "selleri",
    "sellerins": "selleri",
    "selleris": "selleri",
    "seloten": "selot",
    "selotens": "selot",
    "seloter": "selot",
    "seloterna": "selot",
    "seloternas": "selot",
    "seloters": "selot",
    "selots": "selot",
    "sels": "sele",
    "seltersglasen": "seltersglas",
    "seltersglasens": "seltersglas",
    "seltersglaset": "seltersglas",
    "seltersglasets": "seltersglas",
    "seltersvattens": "seltersvatten",
    "seltersvattnet": "seltersvatten",
    "seltersvattnets": "seltersvatten",
    "seltygen": "seltyg",
    "seltygens": "seltyg",
    "seltyget": "seltyg",
    "seltygets": "seltyg",
    "seltygs": "seltyg",
    "semaforalfabeten": "semaforalfabet",
    "semaforalfabetens": "semaforalfabet",
    "semaforalfabetet": "semaforalfabet",
    "semaforalfabetets": "semaforalfabet",
    "semaforalfabets": "semaforalfabet",
    "semaforen": "semafor",
    "semaforens": "semafor",
    "semaforer": "semafor",
    "semaforerad": "semaforera",
    "semaforerade": "semaforera",
    "semaforerades": "semaforera",
    "semaforerads": "semaforera",
    "semaforerande": "semaforera",
    "semaforeranden": "semaforerande",
    "semaforerandena": "semaforerande",
    "semaforerandenas": "semaforerande",
    "semaforerandens": "semaforerande",
    "semaforerandes": "semaforerande",
    "semaforerandet": "semaforerande",
    "semaforerandets": "semaforerande",
    "semaforerar": "semaforera",
    "semaforeras": "semaforera",
    "semaforerat": "semaforera",
    "semaforerats": "semaforera",
    "semaforerbara": "semaforerbar",
    "semaforerbarare": "semaforerbar",
    "semaforerbarares": "semaforerbar",
    "semaforerbaras": "semaforerbar",
    "semaforerbarast": "semaforerbar",
    "semaforerbaraste": "semaforerbar",
    "semaforerbarastes": "semaforerbar",
    "semaforerbarasts": "semaforerbar",
    "semaforerbare": "semaforerbar",
    "semaforerbares": "semaforerbar",
    "semaforerbarheten": "semaforerbarhet",
    "semaforerbarhetens": "semaforerbarhet",
    "semaforerbarhets": "semaforerbarhet",
    "semaforerbars": "semaforerbar",
    "semaforerbart": "semaforerbar",
    "semaforerbarts": "semaforerbar",
    "semaforeringar": "semaforering",
    "semaforeringarna": "semaforering",
    "semaforeringarnas": "semaforering",
    "semaforeringars": "semaforering",
    "semaforeringen": "semaforering",
    "semaforeringens": "semaforering",
    "semaforerings": "semaforering",
    "semaforerna": "semafor",
    "semaforernas": "semafor",
    "semaforers": "semafor",
    "semaforflagg": "semaforflagga",
    "semaforflaggan": "semaforflagga",
    "semaforflaggans": "semaforflagga",
    "semaforflaggas": "semaforflagga",
    "semaforflagge": "semaforflagga",
    "semaforflaggor": "semaforflagga",
    "semaforflaggorna": "semaforflagga",
    "semaforflaggornas": "semaforflagga",
    "semaforflaggors": "semaforflagga",
    "semaforflaggs": "semaforflagga",
    "semafors": "semafor",
    "semantiken": "semantik",
    "semantikens": "semantik",
    "semantiks": "semantik",
    "semantiska": "semantisk",
    "semantiskare": "semantisk",
    "semantiskares": "semantisk",
    "semantiskas": "semantisk",
    "semantiskast": "semantisk",
    "semantiskaste": "semantisk",
    "semantiskastes": "semantisk",
    "semantiskasts": "semantisk",
    "semantiske": "semantisk",
    "semantiskes": "semantisk",
    "semantisks": "semantisk",
    "semantiskt": "semantisk",
    "semantiskts": "semantisk",
    "semasiologien": "semasiologi",
    "semasiologiens": "semasiologi",
    "semasiologin": "semasiologi",
    "semasiologins": "semasiologi",
    "semasiologis": "semasiologi",
    "semel": "semla",
    "sememen": "semem",
    "sememens": "semem",
    "sememet": "semem",
    "sememets": "semem",
    "semems": "semem",
    "semesterarvoden": "semesterarvode",
    "semesterarvodena": "semesterarvode",
    "semesterarvodenas": "semesterarvode",
    "semesterarvodens": "semesterarvode",
    "semesterarvodes": "semesterarvode",
    "semesterarvodet": "semesterarvode",
    "semesterarvodets": "semesterarvode",
    "semesterbyar": "semesterby",
    "semesterbyarna": "semesterby",
    "semesterbyarnas": "semesterby",
    "semesterbyars": "semesterby",
    "semesterbyn": "semesterby",
    "semesterbyns": "semesterby",
    "semesterbys": "semesterby",
    "semesterdagar": "semesterdag",
    "semesterdagarna": "semesterdag",
    "semesterdagarnas": "semesterdag",
    "semesterdagars": "semesterdag",
    "semesterdagen": "semesterdag",
    "semesterdagens": "semesterdag",
    "semesterdags": "semesterdag",
    "semesterersättningar": "semesterersättning",
    "semesterersättningarna": "semesterersättning",
    "semesterersättningarnas": "semesterersättning",
    "semesterersättningars": "semesterersättning",
    "semesterersättningen": "semesterersättning",
    "semesterersättningens": "semesterersättning",
    "semesterersättnings": "semesterersättning",
    "semesterfirar": "semesterfirare",
    "semesterfiraren": "semesterfirare",
    "semesterfirarens": "semesterfirare",
    "semesterfirares": "semesterfirare",
    "semesterfirarna": "semesterfirare",
    "semesterfirarnas": "semesterfirare",
    "semesterfynden": "semesterfynd",
    "semesterfyndens": "semesterfynd",
    "semesterfyndet": "semesterfynd",
    "semesterfyndets": "semesterfynd",
    "semesterfynds": "semesterfynd",
    "semesterkameran": "semesterkamera",
    "semesterkamerans": "semesterkamera",
    "semesterkameras": "semesterkamera",
    "semesterkameror": "semesterkamera",
    "semesterkamerorna": "semesterkamera",
    "semesterkamerornas": "semesterkamera",
    "semesterkamerors": "semesterkamera",
    "semesterkassan": "semesterkassa",
    "semesterkassans": "semesterkassa",
    "semesterkassas": "semesterkassa",
    "semesterkasse": "semesterkassa",
    "semesterkassor": "semesterkassa",
    "semesterkassorna": "semesterkassa",
    "semesterkassornas": "semesterkassa",
    "semesterkassors": "semesterkassa",
    "semesterlönen": "semesterlön",
    "semesterlönens": "semesterlön",
    "semesterlöner": "semesterlön",
    "semesterlönerna": "semesterlön",
    "semesterlönernas": "semesterlön",
    "semesterlöners": "semesterlön",
    "semesterlöns": "semesterlön",
    "semestermånaden": "semestermånad",
    "semestermånadens": "semestermånad",
    "semestermånader": "semestermånad",
    "semestermånaderna": "semestermånad",
    "semestermånadernas": "semestermånad",
    "semestermånaders": "semestermånad",
    "semestermånads": "semestermånad",
    "semestern": "semester",
    "semesterns": "semester",
    "semesterorten": "semesterort",
    "semesterortens": "semesterort",
    "semesterorter": "semesterort",
    "semesterorterna": "semesterort",
    "semesterorternas": "semesterort",
    "semesterorters": "semesterort",
    "semesterorts": "semesterort",
    "semesterpengar": "semesterpeng",
    "semesterpengarna": "semesterpeng",
    "semesterpengarnas": "semesterpeng",
    "semesterpengars": "semesterpeng",
    "semesterpengen": "semesterpeng",
    "semesterpengens": "semesterpeng",
    "semesterpengs": "semesterpeng",
    "semesterres": "semesterresa",
    "semesterresande": "semesterresa",
    "semesterresandes": "semesterresa",
    "semesterresas": "semesterresa",
    "semesterreser": "semesterresa",
    "semesterreses": "semesterresa",
    "semesterrest": "semesterresa",
    "semesterreste": "semesterresa",
    "semesterrestes": "semesterresa",
    "semesterrests": "semesterresa",
    "semesters": "semester",
    "semesterstängde": "semesterstängd",
    "semesterstängdes": "semesterstängd",
    "semesterstängds": "semesterstängd",
    "semesterstängt": "semesterstängd",
    "semesterstängts": "semesterstängd",
    "semestertiden": "semestertid",
    "semestertidens": "semestertid",
    "semestertider": "semestertid",
    "semestertiderna": "semestertid",
    "semestertidernas": "semestertid",
    "semestertiders": "semestertid",
    "semestertids": "semestertid",
    "semestertilläggen": "semestertillägg",
    "semestertilläggens": "semestertillägg",
    "semestertillägget": "semestertillägg",
    "semestertilläggets": "semestertillägg",
    "semestertilläggs": "semestertillägg",
    "semestrade": "semestra",
    "semestrades": "semestra",
    "semestrande": "semestra",
    "semestranden": "semestrande",
    "semestrandena": "semestrande",
    "semestrandenas": "semestrande",
    "semestrandens": "semestrande",
    "semestrandes": "semestrande",
    "semestrandet": "semestrande",
    "semestrandets": "semestrande",
    "semestrar": "semestra",
    "semestrarna": "semester",
    "semestrarnas": "semester",
    "semestrars": "semester",
    "semestras": "semestra",
    "semestrat": "semestra",
    "semestrats": "semestra",
    "semiautomatiska": "semiautomatisk",
    "semiautomatiskas": "semiautomatisk",
    "semiautomatiske": "semiautomatisk",
    "semiautomatiskes": "semiautomatisk",
    "semiautomatisks": "semiautomatisk",
    "semiautomatiskt": "semiautomatisk",
    "semiautomatiskts": "semiautomatisk",
    "semifinalen": "semifinal",
    "semifinalens": "semifinal",
    "semifinaler": "semifinal",
    "semifinalerna": "semifinal",
    "semifinalernas": "semifinal",
    "semifinalers": "semifinal",
    "semifinals": "semifinal",
    "semikolonen": "semikolon",
    "semikolonens": "semikolon",
    "semikolonet": "semikolon",
    "semikolonets": "semikolon",
    "semikolons": "semikolon",
    "seminarier": "seminarium",
    "seminarierna": "seminarium",
    "seminariernas": "seminarium",
    "seminariers": "seminarium",
    "seminariet": "seminarium",
    "seminariets": "seminarium",
    "seminaristen": "seminarist",
    "seminaristens": "seminarist",
    "seminarister": "seminarist",
    "seminaristerna": "seminarist",
    "seminaristernas": "seminarist",
    "seminaristers": "seminarist",
    "seminarists": "seminarist",
    "seminariumet": "seminarium",
    "seminariumets": "seminarium",
    "seminariums": "seminarium",
    "seminationen": "semination",
    "seminationens": "semination",
    "seminationer": "semination",
    "seminationerna": "semination",
    "seminationernas": "semination",
    "seminationers": "semination",
    "seminations": "semination",
    "seminaveln": "seminavel",
    "seminavelns": "seminavel",
    "seminavels": "seminavel",
    "seminerad": "seminera",
    "seminerade": "seminera",
    "seminerades": "seminera",
    "seminerads": "seminera",
    "seminerande": "seminera",
    "semineranden": "seminerande",
    "seminerandena": "seminerande",
    "seminerandenas": "seminerande",
    "seminerandens": "seminerande",
    "seminerandes": "seminerande",
    "seminerandet": "seminerande",
    "seminerandets": "seminerande",
    "seminerar": "seminera",
    "semineras": "seminera",
    "seminerat": "seminera",
    "seminerats": "seminera",
    "seminerbara": "seminerbar",
    "seminerbarare": "seminerbar",
    "seminerbarares": "seminerbar",
    "seminerbaras": "seminerbar",
    "seminerbarast": "seminerbar",
    "seminerbaraste": "seminerbar",
    "seminerbarastes": "seminerbar",
    "seminerbarasts": "seminerbar",
    "seminerbare": "seminerbar",
    "seminerbares": "seminerbar",
    "seminerbarheten": "seminerbarhet",
    "seminerbarhetens": "seminerbarhet",
    "seminerbarhets": "seminerbarhet",
    "seminerbars": "seminerbar",
    "seminerbart": "seminerbar",
    "seminerbarts": "seminerbar",
    "semineringar": "seminering",
    "semineringarna": "seminering",
    "semineringarnas": "seminering",
    "semineringars": "seminering",
    "semineringen": "seminering",
    "semineringens": "seminering",
    "seminerings": "seminering",
    "seminstationen": "seminstation",
    "seminstationens": "seminstation",
    "seminstationer": "seminstation",
    "seminstationerna": "seminstation",
    "seminstationernas": "seminstation",
    "seminstationers": "seminstation",
    "seminstations": "seminstation",
    "seminören": "seminör",
    "seminörens": "seminör",
    "seminörer": "seminör",
    "seminörerna": "seminör",
    "seminörernas": "seminör",
    "seminörers": "seminör",
    "seminörs": "seminör",
    "semiologien": "semiologi",
    "semiologiens": "semiologi",
    "semiologin": "semiologi",
    "semiologins": "semiologi",
    "semiologis": "semiologi",
    "semiotiken": "semiotik",
    "semiotikens": "semiotik",
    "semiotiks": "semiotik",
    "semiotiska": "semiotisk",
    "semiotiskare": "semiotisk",
    "semiotiskares": "semiotisk",
    "semiotiskas": "semiotisk",
    "semiotiskast": "semiotisk",
    "semiotiskaste": "semiotisk",
    "semiotiskastes": "semiotisk",
    "semiotiskasts": "semiotisk",
    "semiotiske": "semiotisk",
    "semiotiskes": "semiotisk",
    "semiotisks": "semiotisk",
    "semiotiskt": "semiotisk",
    "semiotiskts": "semiotisk",
    "semipermeabels": "semipermeabel",
    "semipermeabelt": "semipermeabel",
    "semipermeabelts": "semipermeabel",
    "semipermeabla": "semipermeabel",
    "semipermeablare": "semipermeabel",
    "semipermeablares": "semipermeabel",
    "semipermeablas": "semipermeabel",
    "semipermeablast": "semipermeabel",
    "semipermeablaste": "semipermeabel",
    "semipermeablastes": "semipermeabel",
    "semipermeablasts": "semipermeabel",
    "semipermeable": "semipermeabel",
    "semipermeables": "semipermeabel",
    "semiten": "semit",
    "semitens": "semit",
    "semiter": "semit",
    "semiterna": "semit",
    "semiternas": "semit",
    "semiters": "semit",
    "semitiska": "semitisk",
    "semitiskare": "semitisk",
    "semitiskares": "semitisk",
    "semitiskas": "semitisk",
    "semitiskast": "semitisk",
    "semitiskaste": "semitisk",
    "semitiskastes": "semitisk",
    "semitiskasts": "semitisk",
    "semitiske": "semitisk",
    "semitiskes": "semitisk",
    "semitisks": "semitisk",
    "semitiskt": "semitisk",
    "semitiskts": "semitisk",
    "semitisten": "semitist",
    "semitistens": "semitist",
    "semitister": "semitist",
    "semitisterna": "semitist",
    "semitisternas": "semitist",
    "semitisters": "semitist",
    "semitists": "semitist",
    "semitrailern": "semitrailer",
    "semitrailerna": "semitrailer",
    "semitrailernas": "semitrailer",
    "semitrailerns": "semitrailer",
    "semitrailers": "semitrailer",
    "semitrailersarna": "semitrailer",
    "semitrailersarnas": "semitrailer",
    "semitrailrar": "semitrailer",
    "semitrailrarna": "semitrailer",
    "semitrailrarnas": "semitrailer",
    "semitrailrars": "semitrailer",
    "semits": "semit",
    "semlan": "semla",
    "semlans": "semla",
    "semlas": "semla",
    "semle": "semla",
    "semlor": "semla",
    "semlorna": "semla",
    "semlornas": "semla",
    "semlors": "semla",
    "semologien": "semologi",
    "semologiens": "semologi",
    "semologin": "semologi",
    "semologins": "semologi",
    "semologis": "semologi",
    "semologiska": "semologisk",
    "semologiskare": "semologisk",
    "semologiskares": "semologisk",
    "semologiskas": "semologisk",
    "semologiskast": "semologisk",
    "semologiskaste": "semologisk",
    "semologiskastes": "semologisk",
    "semologiskasts": "semologisk",
    "semologiske": "semologisk",
    "semologiskes": "semologisk",
    "semologisks": "semologisk",
    "semologiskt": "semologisk",
    "semologiskts": "semologisk",
    "sen": "sena",
    "sena": "sen",
    "senan": "sena",
    "senans": "sena",
    "senantika": "senantik",
    "senantikare": "senantik",
    "senantikares": "senantik",
    "senantikas": "senantik",
    "senantikast": "senantik",
    "senantikaste": "senantik",
    "senantikastes": "senantik",
    "senantikasts": "senantik",
    "senantike": "senantik",
    "senantiken": "senantik",
    "senantikens": "senantik",
    "senantikes": "senantik",
    "senantiks": "senantik",
    "senantikt": "senantik",
    "senantikts": "senantik",
    "senapen": "senap",
    "senapens": "senap",
    "senaps": "senap",
    "senapsdegar": "senapsdeg",
    "senapsdegarna": "senapsdeg",
    "senapsdegarnas": "senapsdeg",
    "senapsdegars": "senapsdeg",
    "senapsdegen": "senapsdeg",
    "senapsdegens": "senapsdeg",
    "senapsdegs": "senapsdeg",
    "senapsgasen": "senapsgas",
    "senapsgasens": "senapsgas",
    "senapsgula": "senapsgul",
    "senapsgulas": "senapsgul",
    "senapsgule": "senapsgul",
    "senapsgules": "senapsgul",
    "senapsguls": "senapsgul",
    "senapsgult": "senapsgul",
    "senapsgults": "senapsgul",
    "senapskornen": "senapskorn",
    "senapskornens": "senapskorn",
    "senapskornet": "senapskorn",
    "senapskornets": "senapskorn",
    "senapskorns": "senapskorn",
    "senare": "sen",
    "senarela": "senarelägga",
    "senarelade": "senarelägga",
    "senarelades": "senarelägga",
    "senarelagd": "senarelägga",
    "senarelagda": "senarelägga",
    "senarelagdas": "senarelägga",
    "senarelagde": "senarelägga",
    "senarelagdes": "senarelägga",
    "senarelagds": "senarelägga",
    "senarelagt": "senarelägga",
    "senarelagts": "senarelägga",
    "senarelas": "senarelägga",
    "senarelägg": "senarelägga",
    "senareläggande": "senarelägga",
    "senarelägganden": "senareläggande",
    "senareläggandena": "senareläggande",
    "senareläggandenas": "senareläggande",
    "senareläggandens": "senareläggande",
    "senareläggandes": "senareläggande",
    "senareläggandet": "senareläggande",
    "senareläggandets": "senareläggande",
    "senareläggas": "senarelägga",
    "senarelägger": "senarelägga",
    "senarelägges": "senarelägga",
    "senareläggs": "senarelägga",
    "senaren": "senar",
    "senarens": "senar",
    "senarer": "senar",
    "senarerna": "senar",
    "senarernas": "senar",
    "senarers": "senar",
    "senares": "sen",
    "senars": "senar",
    "senas": "sena",
    "senast": "sen",
    "senaste": "sen",
    "senastes": "sen",
    "senasts": "sen",
    "senaten": "senat",
    "senatens": "senat",
    "senater": "senat",
    "senaterna": "senat",
    "senaternas": "senat",
    "senaters": "senat",
    "senatorer": "senator",
    "senatorerna": "senator",
    "senatorernas": "senator",
    "senatorers": "senator",
    "senatorn": "senator",
    "senatorns": "senator",
    "senators": "senator",
    "senats": "senat",
    "sendraget": "sendrag",
    "sendragets": "sendrag",
    "sendrags": "sendrag",
    "sene": "sena",
    "senegalesen": "senegales",
    "senegalesens": "senegales",
    "senegaleser": "senegales",
    "senegaleserna": "senegales",
    "senegalesernas": "senegales",
    "senegalesers": "senegales",
    "senegalesiska": "senegalesisk",
    "senegalesiskan": "senegalesiska",
    "senegalesiskans": "senegalesiska",
    "senegalesiskare": "senegalesisk",
    "senegalesiskares": "senegalesisk",
    "senegalesiskas": "senegalesiska",
    "senegalesiskast": "senegalesisk",
    "senegalesiskaste": "senegalesisk",
    "senegalesiskastes": "senegalesisk",
    "senegalesiskasts": "senegalesisk",
    "senegalesiske": "senegalesiska",
    "senegalesiskes": "senegalesisk",
    "senegalesiskor": "senegalesiska",
    "senegalesiskorna": "senegalesiska",
    "senegalesiskornas": "senegalesiska",
    "senegalesiskors": "senegalesiska",
    "senegalesisks": "senegalesisk",
    "senegalesiskt": "senegalesisk",
    "senegalesiskts": "senegalesisk",
    "senes": "sen",
    "senfärdiga": "senfärdig",
    "senfärdigare": "senfärdig",
    "senfärdigares": "senfärdig",
    "senfärdigas": "senfärdig",
    "senfärdigast": "senfärdig",
    "senfärdigaste": "senfärdig",
    "senfärdigastes": "senfärdig",
    "senfärdigasts": "senfärdig",
    "senfärdige": "senfärdig",
    "senfärdiges": "senfärdig",
    "senfärdigheten": "senfärdighet",
    "senfärdighetens": "senfärdighet",
    "senfärdighets": "senfärdighet",
    "senfärdigs": "senfärdig",
    "senfärdigt": "senfärdig",
    "senfärdigts": "senfärdig",
    "senfångade": "senfångad",
    "senfångades": "senfångad",
    "senfångads": "senfångad",
    "senfångat": "senfångad",
    "senfångats": "senfångad",
    "senfödda": "senfödd",
    "senföddare": "senfödd",
    "senföddares": "senfödd",
    "senföddas": "senfödd",
    "senföddast": "senfödd",
    "senföddaste": "senfödd",
    "senföddastes": "senfödd",
    "senföddasts": "senfödd",
    "senfödde": "senfödd",
    "senföddes": "senfödd",
    "senfödds": "senfödd",
    "senfött": "senfödd",
    "senfötts": "senfödd",
    "sengångar": "sengångare",
    "sengångaraktiga": "sengångaraktig",
    "sengångaraktigare": "sengångaraktig",
    "sengångaraktigares": "sengångaraktig",
    "sengångaraktigas": "sengångaraktig",
    "sengångaraktigast": "sengångaraktig",
    "sengångaraktigaste": "sengångaraktig",
    "sengångaraktigastes": "sengångaraktig",
    "sengångaraktigasts": "sengångaraktig",
    "sengångaraktige": "sengångaraktig",
    "sengångaraktiges": "sengångaraktig",
    "sengångaraktigheten": "sengångaraktighet",
    "sengångaraktighetens": "sengångaraktighet",
    "sengångaraktighets": "sengångaraktighet",
    "sengångaraktigs": "sengångaraktig",
    "sengångaraktigt": "sengångaraktig",
    "sengångaraktigts": "sengångaraktig",
    "sengångaren": "sengångare",
    "sengångarens": "sengångare",
    "sengångares": "sengångare",
    "sengångarna": "sengångare",
    "sengångarnas": "sengångare",
    "senheten": "senhet",
    "senhetens": "senhet",
    "senhets": "senhet",
    "senhinnan": "senhinna",
    "senhinnans": "senhinna",
    "senhinnas": "senhinna",
    "senhinne": "senhinna",
    "senhinnor": "senhinna",
    "senhinnorna": "senhinna",
    "senhinnornas": "senhinna",
    "senhinnors": "senhinna",
    "senhöstar": "senhöst",
    "senhöstarna": "senhöst",
    "senhöstarnas": "senhöst",
    "senhöstars": "senhöst",
    "senhösten": "senhöst",
    "senhöstens": "senhöst",
    "senhösts": "senhöst",
    "seniga": "senig",
    "senigare": "senig",
    "senigares": "senig",
    "senigas": "senig",
    "senigast": "senig",
    "senigaste": "senig",
    "senigastes": "senig",
    "senigasts": "senig",
    "senige": "senig",
    "seniges": "senig",
    "senigs": "senig",
    "senigt": "senig",
    "senigts": "senig",
    "senila": "senil",
    "senilare": "senil",
    "senilares": "senil",
    "senilas": "senil",
    "senilast": "senil",
    "senilaste": "senil",
    "senilastes": "senil",
    "senilasts": "senil",
    "senildementa": "senildement",
    "senildementare": "senildement",
    "senildementares": "senildement",
    "senildementas": "senildement",
    "senildementast": "senildement",
    "senildementaste": "senildement",
    "senildementastes": "senildement",
    "senildementasts": "senildement",
    "senildemente": "senildement",
    "senildementes": "senildement",
    "senildements": "senildement",
    "senildementt": "senildement",
    "senildementts": "senildement",
    "senile": "senil",
    "seniles": "senil",
    "seniliteten": "senilitet",
    "senilitetens": "senilitet",
    "seniliteter": "senilitet",
    "seniliteterna": "senilitet",
    "seniliteternas": "senilitet",
    "seniliteters": "senilitet",
    "senilitets": "senilitet",
    "senils": "senil",
    "senilt": "senil",
    "senilts": "senil",
    "seniora": "senior",
    "seniorare": "senior",
    "seniorares": "senior",
    "senioras": "senior",
    "seniorast": "senior",
    "senioraste": "senior",
    "seniorastes": "senior",
    "seniorasts": "senior",
    "senioratet": "seniorat",
    "senioratets": "seniorat",
    "seniorats": "seniorat",
    "seniore": "senior",
    "senioren": "senior",
    "seniorens": "senior",
    "seniorer": "senior",
    "seniorerna": "senior",
    "seniorernas": "senior",
    "seniorers": "senior",
    "seniores": "senior",
    "seniors": "senior",
    "seniort": "senior",
    "seniorts": "senior",
    "senklappen": "senklapp",
    "senklappens": "senklapp",
    "senklapps": "senklapp",
    "senknarret": "senknarr",
    "senknarrets": "senknarr",
    "senknarrs": "senknarr",
    "senknutar": "senknut",
    "senknutarna": "senknut",
    "senknutarnas": "senknut",
    "senknutars": "senknut",
    "senknuten": "senknut",
    "senknutens": "senknut",
    "senknuts": "senknut",
    "senkommens": "senkommen",
    "senkommet": "senkommen",
    "senkommets": "senkommen",
    "senkomna": "senkommen",
    "senkomnare": "senkommen",
    "senkomnares": "senkommen",
    "senkomnas": "senkommen",
    "senkomnast": "senkommen",
    "senkomnaste": "senkommen",
    "senkomnastes": "senkommen",
    "senkomnasts": "senkommen",
    "senkomne": "senkommen",
    "senkomnes": "senkommen",
    "sennan": "senna",
    "sennans": "senna",
    "sennas": "senna",
    "senor": "sena",
    "senorganen": "senorgan",
    "senorganens": "senorgan",
    "senorganet": "senorgan",
    "senorganets": "senorgan",
    "senorgans": "senorgan",
    "senorna": "sena",
    "senornas": "sena",
    "senors": "sena",
    "senromerska": "senromersk",
    "senromerskare": "senromersk",
    "senromerskares": "senromersk",
    "senromerskas": "senromersk",
    "senromerskast": "senromersk",
    "senromerskaste": "senromersk",
    "senromerskastes": "senromersk",
    "senromerskasts": "senromersk",
    "senromerske": "senromersk",
    "senromerskes": "senromersk",
    "senromersks": "senromersk",
    "senromerskt": "senromersk",
    "senromerskts": "senromersk",
    "sens": "sena",
    "sensationella": "sensationell",
    "sensationellare": "sensationell",
    "sensationellares": "sensationell",
    "sensationellas": "sensationell",
    "sensationellast": "sensationell",
    "sensationellaste": "sensationell",
    "sensationellastes": "sensationell",
    "sensationellasts": "sensationell",
    "sensationelle": "sensationell",
    "sensationelles": "sensationell",
    "sensationells": "sensationell",
    "sensationellt": "sensationell",
    "sensationellts": "sensationell",
    "sensationen": "sensation",
    "sensationens": "sensation",
    "sensationer": "sensation",
    "sensationerna": "sensation",
    "sensationernas": "sensation",
    "sensationers": "sensation",
    "sensations": "sensation",
    "sensationsbetonade": "sensationsbetonad",
    "sensationsbetonades": "sensationsbetonad",
    "sensationsbetonads": "sensationsbetonad",
    "sensationsbetonat": "sensationsbetonad",
    "sensationsbetonats": "sensationsbetonad",
    "sensationsjournalistiken": "sensationsjournalistik",
    "sensationsjournalistikens": "sensationsjournalistik",
    "sensationsjournalistiks": "sensationsjournalistik",
    "sensationslystens": "sensationslysten",
    "sensationslystet": "sensationslysten",
    "sensationslystets": "sensationslysten",
    "sensationslystna": "sensationslysten",
    "sensationslystnare": "sensationslysten",
    "sensationslystnares": "sensationslysten",
    "sensationslystnas": "sensationslysten",
    "sensationslystnast": "sensationslysten",
    "sensationslystnaste": "sensationslysten",
    "sensationslystnastes": "sensationslysten",
    "sensationslystnasts": "sensationslysten",
    "sensationslystne": "sensationslysten",
    "sensationslystnes": "sensationslysten",
    "sensibels": "sensibel",
    "sensibelt": "sensibel",
    "sensibelts": "sensibel",
    "sensibiliserad": "sensibilisera",
    "sensibiliserade": "sensibilisera",
    "sensibiliserades": "sensibilisera",
    "sensibiliserads": "sensibilisera",
    "sensibiliserande": "sensibilisera",
    "sensibiliseranden": "sensibiliserande",
    "sensibiliserandena": "sensibiliserande",
    "sensibiliserandenas": "sensibiliserande",
    "sensibiliserandens": "sensibiliserande",
    "sensibiliserandes": "sensibiliserande",
    "sensibiliserandet": "sensibiliserande",
    "sensibiliserandets": "sensibiliserande",
    "sensibiliserar": "sensibilisera",
    "sensibiliseras": "sensibilisera",
    "sensibiliserat": "sensibilisera",
    "sensibiliserats": "sensibilisera",
    "sensibiliserbara": "sensibiliserbar",
    "sensibiliserbarare": "sensibiliserbar",
    "sensibiliserbarares": "sensibiliserbar",
    "sensibiliserbaras": "sensibiliserbar",
    "sensibiliserbarast": "sensibiliserbar",
    "sensibiliserbaraste": "sensibiliserbar",
    "sensibiliserbarastes": "sensibiliserbar",
    "sensibiliserbarasts": "sensibiliserbar",
    "sensibiliserbare": "sensibiliserbar",
    "sensibiliserbares": "sensibiliserbar",
    "sensibiliserbarheten": "sensibiliserbarhet",
    "sensibiliserbarhetens": "sensibiliserbarhet",
    "sensibiliserbarhets": "sensibiliserbarhet",
    "sensibiliserbars": "sensibiliserbar",
    "sensibiliserbart": "sensibiliserbar",
    "sensibiliserbarts": "sensibiliserbar",
    "sensibiliseringar": "sensibilisering",
    "sensibiliseringarna": "sensibilisering",
    "sensibiliseringarnas": "sensibilisering",
    "sensibiliseringars": "sensibilisering",
    "sensibiliseringen": "sensibilisering",
    "sensibiliseringens": "sensibilisering",
    "sensibiliserings": "sensibilisering",
    "sensibiliteten": "sensibilitet",
    "sensibilitetens": "sensibilitet",
    "sensibiliteter": "sensibilitet",
    "sensibiliteterna": "sensibilitet",
    "sensibiliteternas": "sensibilitet",
    "sensibiliteters": "sensibilitet",
    "sensibilitets": "sensibilitet",
    "sensibla": "sensibel",
    "sensiblare": "sensibel",
    "sensiblares": "sensibel",
    "sensiblas": "sensibel",
    "sensiblast": "sensibel",
    "sensiblaste": "sensibel",
    "sensiblastes": "sensibel",
    "sensiblasts": "sensibel",
    "sensible": "sensibel",
    "sensibles": "sensibel",
    "sensigruppen": "sensigrupp",
    "sensigruppens": "sensigrupp",
    "sensigrupper": "sensigrupp",
    "sensigrupperna": "sensigrupp",
    "sensigruppernas": "sensigrupp",
    "sensigruppers": "sensigrupp",
    "sensigrupps": "sensigrupp",
    "sensitiv": "sensitiva",
    "sensitiva": "sensitiv",
    "sensitivan": "sensitiva",
    "sensitivans": "sensitiva",
    "sensitivare": "sensitiv",
    "sensitivares": "sensitiv",
    "sensitivas": "sensitiva",
    "sensitivast": "sensitiv",
    "sensitivaste": "sensitiv",
    "sensitivastes": "sensitiv",
    "sensitivasts": "sensitiv",
    "sensitive": "sensitiva",
    "sensitives": "sensitiv",
    "sensitiviteten": "sensitivitet",
    "sensitivitetens": "sensitivitet",
    "sensitiviteter": "sensitivitet",
    "sensitiviteterna": "sensitivitet",
    "sensitiviteternas": "sensitivitet",
    "sensitiviteters": "sensitivitet",
    "sensitivitets": "sensitivitet",
    "sensitivitetstalangen": "sensitivitetstalang",
    "sensitivitetstalangens": "sensitivitetstalang",
    "sensitivitetstalanger": "sensitivitetstalang",
    "sensitivitetstalangerna": "sensitivitetstalang",
    "sensitivitetstalangernas": "sensitivitetstalang",
    "sensitivitetstalangers": "sensitivitetstalang",
    "sensitivitetstalangs": "sensitivitetstalang",
    "sensitivitetsträningar": "sensitivitetsträning",
    "sensitivitetsträningarna": "sensitivitetsträning",
    "sensitivitetsträningarnas": "sensitivitetsträning",
    "sensitivitetsträningars": "sensitivitetsträning",
    "sensitivitetsträningen": "sensitivitetsträning",
    "sensitivitetsträningens": "sensitivitetsträning",
    "sensitivitetstränings": "sensitivitetsträning",
    "sensitivor": "sensitiva",
    "sensitivorna": "sensitiva",
    "sensitivornas": "sensitiva",
    "sensitivors": "sensitiva",
    "sensitivs": "sensitiva",
    "sensitivt": "sensitiv",
    "sensitivts": "sensitiv",
    "sensiträningar": "sensiträning",
    "sensiträningarna": "sensiträning",
    "sensiträningarnas": "sensiträning",
    "sensiträningars": "sensiträning",
    "sensiträningen": "sensiträning",
    "sensiträningens": "sensiträning",
    "sensitränings": "sensiträning",
    "senskid": "senskida",
    "senskidan": "senskida",
    "senskidans": "senskida",
    "senskidas": "senskida",
    "senskide": "senskida",
    "senskidor": "senskida",
    "senskidorna": "senskida",
    "senskidornas": "senskida",
    "senskidors": "senskida",
    "senskids": "senskida",
    "sensmoralen": "sensmoral",
    "sensmoralens": "sensmoral",
    "sensmoraler": "sensmoral",
    "sensmoralerna": "sensmoral",
    "sensmoralernas": "sensmoral",
    "sensmoralers": "sensmoral",
    "sensmorals": "sensmoral",
    "sensommaren": "sensommar",
    "sensommarens": "sensommar",
    "sensommarflug": "sensommarfluga",
    "sensommarflugan": "sensommarfluga",
    "sensommarflugans": "sensommarfluga",
    "sensommarflugas": "sensommarfluga",
    "sensommarfluge": "sensommarfluga",
    "sensommarflugor": "sensommarfluga",
    "sensommarflugorna": "sensommarfluga",
    "sensommarflugornas": "sensommarfluga",
    "sensommarflugors": "sensommarfluga",
    "sensommarflugs": "sensommarfluga",
    "sensommarn": "sensommar",
    "sensommarns": "sensommar",
    "sensommars": "sensommar",
    "sensomotoriska": "sensomotorisk",
    "sensomotoriskare": "sensomotorisk",
    "sensomotoriskares": "sensomotorisk",
    "sensomotoriskas": "sensomotorisk",
    "sensomotoriskast": "sensomotorisk",
    "sensomotoriskaste": "sensomotorisk",
    "sensomotoriskastes": "sensomotorisk",
    "sensomotoriskasts": "sensomotorisk",
    "sensomotoriske": "sensomotorisk",
    "sensomotoriskes": "sensomotorisk",
    "sensomotorisks": "sensomotorisk",
    "sensomotoriskt": "sensomotorisk",
    "sensomotoriskts": "sensomotorisk",
    "sensomrar": "sensommar",
    "sensomrarna": "sensommar",
    "sensomrarnas": "sensommar",
    "sensomrars": "sensommar",
    "sensorer": "sensor",
    "sensorerna": "sensor",
    "sensorernas": "sensor",
    "sensorers": "sensor",
    "sensoriska": "sensorisk",
    "sensoriskare": "sensorisk",
    "sensoriskares": "sensorisk",
    "sensoriskas": "sensorisk",
    "sensoriskast": "sensorisk",
    "sensoriskaste": "sensorisk",
    "sensoriskastes": "sensorisk",
    "sensoriskasts": "sensorisk",
    "sensoriske": "sensorisk",
    "sensoriskes": "sensorisk",
    "sensorisks": "sensorisk",
    "sensoriskt": "sensorisk",
    "sensoriskts": "sensorisk",
    "sensorn": "sensor",
    "sensorns": "sensor",
    "sensors": "sensor",
    "sensualismen": "sensualism",
    "sensualismens": "sensualism",
    "sensualismer": "sensualism",
    "sensualismerna": "sensualism",
    "sensualismernas": "sensualism",
    "sensualismers": "sensualism",
    "sensualisms": "sensualism",
    "sensualistiska": "sensualistisk",
    "sensualistiskas": "sensualistisk",
    "sensualistiske": "sensualistisk",
    "sensualistiskes": "sensualistisk",
    "sensualistisks": "sensualistisk",
    "sensualistiskt": "sensualistisk",
    "sensualistiskts": "sensualistisk",
    "sensualiteten": "sensualitet",
    "sensualitetens": "sensualitet",
    "sensualiteter": "sensualitet",
    "sensualiteterna": "sensualitet",
    "sensualiteternas": "sensualitet",
    "sensualiteters": "sensualitet",
    "sensualitets": "sensualitet",
    "sensuella": "sensuell",
    "sensuellare": "sensuell",
    "sensuellares": "sensuell",
    "sensuellas": "sensuell",
    "sensuellast": "sensuell",
    "sensuellaste": "sensuell",
    "sensuellastes": "sensuell",
    "sensuellasts": "sensuell",
    "sensuelle": "sensuell",
    "sensuelles": "sensuell",
    "sensuells": "sensuell",
    "sensuellt": "sensuell",
    "sensuellts": "sensuell",
    "sent": "sen",
    "sentensen": "sentens",
    "sentensens": "sentens",
    "sentenser": "sentens",
    "sentenserna": "sentens",
    "sentensernas": "sentens",
    "sentensers": "sentens",
    "sentensiösa": "sentensiös",
    "sentensiösare": "sentensiös",
    "sentensiösares": "sentensiös",
    "sentensiösas": "sentensiös",
    "sentensiösast": "sentensiös",
    "sentensiösaste": "sentensiös",
    "sentensiösastes": "sentensiös",
    "sentensiösasts": "sentensiös",
    "sentensiöse": "sentensiös",
    "sentensiöses": "sentensiös",
    "sentensiöst": "sentensiös",
    "sentensiösts": "sentensiös",
    "sententiösa": "sententiös",
    "sententiösare": "sententiös",
    "sententiösares": "sententiös",
    "sententiösas": "sententiös",
    "sententiösast": "sententiös",
    "sententiösaste": "sententiös",
    "sententiösastes": "sententiös",
    "sententiösasts": "sententiös",
    "sententiöse": "sententiös",
    "sententiöses": "sententiös",
    "sententiöst": "sententiös",
    "sententiösts": "sententiös",
    "senterad": "sentera",
    "senterade": "sentera",
    "senterades": "sentera",
    "senterads": "sentera",
    "senterande": "sentera",
    "senteranden": "senterande",
    "senterandena": "senterande",
    "senterandenas": "senterande",
    "senterandens": "senterande",
    "senterandes": "senterande",
    "senterandet": "senterande",
    "senterandets": "senterande",
    "senterar": "sentera",
    "senteras": "sentera",
    "senterat": "sentera",
    "senterats": "sentera",
    "senterbara": "senterbar",
    "senterbarare": "senterbar",
    "senterbarares": "senterbar",
    "senterbaras": "senterbar",
    "senterbarast": "senterbar",
    "senterbaraste": "senterbar",
    "senterbarastes": "senterbar",
    "senterbarasts": "senterbar",
    "senterbare": "senterbar",
    "senterbares": "senterbar",
    "senterbarheten": "senterbarhet",
    "senterbarhetens": "senterbarhet",
    "senterbarhets": "senterbarhet",
    "senterbars": "senterbar",
    "senterbart": "senterbar",
    "senterbarts": "senterbar",
    "senteringar": "sentering",
    "senteringarna": "sentering",
    "senteringarnas": "sentering",
    "senteringars": "sentering",
    "senteringen": "sentering",
    "senteringens": "sentering",
    "senterings": "sentering",
    "sentimentala": "sentimental",
    "sentimentalare": "sentimental",
    "sentimentalares": "sentimental",
    "sentimentalas": "sentimental",
    "sentimentalast": "sentimental",
    "sentimentalaste": "sentimental",
    "sentimentalastes": "sentimental",
    "sentimentalasts": "sentimental",
    "sentimentale": "sentimental",
    "sentimentales": "sentimental",
    "sentimentaliteten": "sentimentalitet",
    "sentimentalitetens": "sentimentalitet",
    "sentimentaliteter": "sentimentalitet",
    "sentimentaliteterna": "sentimentalitet",
    "sentimentaliteternas": "sentimentalitet",
    "sentimentaliteters": "sentimentalitet",
    "sentimentalitets": "sentimentalitet",
    "sentimentals": "sentimental",
    "sentimentalt": "sentimental",
    "sentimentalts": "sentimental",
    "sentimenten": "sentiment",
    "sentimentens": "sentiment",
    "sentimentet": "sentiment",
    "sentimentets": "sentiment",
    "sentiments": "sentiment",
    "sents": "sen",
    "senvintern": "senvinter",
    "senvinterns": "senvinter",
    "senvinters": "senvinter",
    "senvintrar": "senvinter",
    "senvintrarna": "senvinter",
    "senvintrarnas": "senvinter",
    "senvintrars": "senvinter",
    "senvägarna": "senvägar",
    "senvägarnas": "senvägar",
    "senvägars": "senvägar",
    "senvårar": "senvår",
    "senvårarna": "senvår",
    "senvårarnas": "senvår",
    "senvårars": "senvår",
    "senvåren": "senvår",
    "senvårens": "senvår",
    "senvårs": "senvår",
    "separabels": "separabel",
    "separabelt": "separabel",
    "separabelts": "separabel",
    "separabla": "separabel",
    "separablare": "separabel",
    "separablares": "separabel",
    "separablas": "separabel",
    "separablast": "separabel",
    "separablaste": "separabel",
    "separablastes": "separabel",
    "separablasts": "separabel",
    "separable": "separabel",
    "separables": "separabel",
    "separata": "separat",
    "separatare": "separat",
    "separatares": "separat",
    "separatas": "separat",
    "separatast": "separat",
    "separataste": "separat",
    "separatastes": "separat",
    "separatasts": "separat",
    "separate": "separat",
    "separaten": "separat",
    "separatens": "separat",
    "separates": "separat",
    "separatet": "separat",
    "separatets": "separat",
    "separatfjädringar": "separatfjädring",
    "separatfjädringarna": "separatfjädring",
    "separatfjädringarnas": "separatfjädring",
    "separatfjädringars": "separatfjädring",
    "separatfjädringen": "separatfjädring",
    "separatfjädringens": "separatfjädring",
    "separatfjädrings": "separatfjädring",
    "separatfreden": "separatfred",
    "separatfredens": "separatfred",
    "separatfreder": "separatfred",
    "separatfrederna": "separatfred",
    "separatfredernas": "separatfred",
    "separatfreders": "separatfred",
    "separatfreds": "separatfred",
    "separationen": "separation",
    "separationens": "separation",
    "separationer": "separation",
    "separationerna": "separation",
    "separationernas": "separation",
    "separationers": "separation",
    "separations": "separation",
    "separationsångesten": "separationsångest",
    "separationsångestens": "separationsångest",
    "separationsångests": "separationsångest",
    "separatismen": "separatism",
    "separatismens": "separatism",
    "separatismer": "separatism",
    "separatismerna": "separatism",
    "separatismernas": "separatism",
    "separatismers": "separatism",
    "separatisms": "separatism",
    "separatisten": "separatist",
    "separatistens": "separatist",
    "separatister": "separatist",
    "separatisterna": "separatist",
    "separatisternas": "separatist",
    "separatisters": "separatist",
    "separatistiska": "separatistisk",
    "separatistiskare": "separatistisk",
    "separatistiskares": "separatistisk",
    "separatistiskas": "separatistisk",
    "separatistiskast": "separatistisk",
    "separatistiskaste": "separatistisk",
    "separatistiskastes": "separatistisk",
    "separatistiskasts": "separatistisk",
    "separatistiske": "separatistisk",
    "separatistiskes": "separatistisk",
    "separatistisks": "separatistisk",
    "separatistiskt": "separatistisk",
    "separatistiskts": "separatistisk",
    "separatistledar": "separatistledare",
    "separatistledaren": "separatistledare",
    "separatistledarens": "separatistledare",
    "separatistledares": "separatistledare",
    "separatistledarna": "separatistledare",
    "separatistledarnas": "separatistledare",
    "separatiströrelsen": "separatiströrelse",
    "separatiströrelsens": "separatiströrelse",
    "separatiströrelser": "separatiströrelse",
    "separatiströrelserna": "separatiströrelse",
    "separatiströrelsernas": "separatiströrelse",
    "separatiströrelsers": "separatiströrelse",
    "separatiströrelses": "separatiströrelse",
    "separatists": "separatist",
    "separatorer": "separator",
    "separatorerna": "separator",
    "separatorernas": "separator",
    "separatorers": "separator",
    "separatorn": "separator",
    "separatorns": "separator",
    "separators": "separator",
    "separats": "separat",
    "separatutställningar": "separatutställning",
    "separatutställningarna": "separatutställning",
    "separatutställningarnas": "separatutställning",
    "separatutställningars": "separatutställning",
    "separatutställningen": "separatutställning",
    "separatutställningens": "separatutställning",
    "separatutställnings": "separatutställning",
    "separerad": "separera",
    "separerade": "separera",
    "separerades": "separera",
    "separerads": "separera",
    "separerande": "separera",
    "separeranden": "separerande",
    "separerandena": "separerande",
    "separerandenas": "separerande",
    "separerandens": "separerande",
    "separerandes": "separerande",
    "separerandet": "separerande",
    "separerandets": "separerande",
    "separerar": "separera",
    "separeras": "separera",
    "separerat": "separera",
    "separerats": "separera",
    "separerbara": "separerbar",
    "separerbarare": "separerbar",
    "separerbarares": "separerbar",
    "separerbaras": "separerbar",
    "separerbarast": "separerbar",
    "separerbaraste": "separerbar",
    "separerbarastes": "separerbar",
    "separerbarasts": "separerbar",
    "separerbare": "separerbar",
    "separerbares": "separerbar",
    "separerbarheten": "separerbarhet",
    "separerbarhetens": "separerbarhet",
    "separerbarhets": "separerbarhet",
    "separerbars": "separerbar",
    "separerbart": "separerbar",
    "separerbarts": "separerbar",
    "separeringar": "separering",
    "separeringarna": "separering",
    "separeringarnas": "separering",
    "separeringars": "separering",
    "separeringen": "separering",
    "separeringens": "separering",
    "separerings": "separering",
    "sepiafärgade": "sepiafärgad",
    "sepiafärgades": "sepiafärgad",
    "sepiafärgads": "sepiafärgad",
    "sepiafärgat": "sepiafärgad",
    "sepiafärgats": "sepiafärgad",
    "sepian": "sepia",
    "sepians": "sepia",
    "sepias": "sepia",
    "sepiatoningar": "sepiatoning",
    "sepiatoningarna": "sepiatoning",
    "sepiatoningarnas": "sepiatoning",
    "sepiatoningars": "sepiatoning",
    "sepiatoningen": "sepiatoning",
    "sepiatoningens": "sepiatoning",
    "sepiatonings": "sepiatoning",
    "seponerad": "seponera",
    "seponerade": "seponera",
    "seponerades": "seponera",
    "seponerads": "seponera",
    "seponerande": "seponera",
    "seponerandes": "seponera",
    "seponerar": "seponera",
    "seponeras": "seponera",
    "seponerat": "seponera",
    "seponerats": "seponera",
    "sepoyen": "sepoy",
    "sepoyens": "sepoy",
    "sepoys": "sepoy",
    "sepoysarna": "sepoy",
    "sepoysarnas": "sepoy",
    "sepoysen": "sepoy",
    "sepoysens": "sepoy",
    "sepsisen": "sepsis",
    "sepsisens": "sepsis",
    "septembers": "september",
    "septennie": "septennium",
    "septennier": "septennium",
    "septennierna": "septennium",
    "septenniernas": "septennium",
    "septenniers": "septennium",
    "septenniet": "septennium",
    "septenniets": "septennium",
    "septenniums": "septennium",
    "septetten": "septett",
    "septettens": "septett",
    "septetter": "septett",
    "septetterna": "septett",
    "septetternas": "septett",
    "septetters": "septett",
    "septetts": "septett",
    "septiktankar": "septiktank",
    "septiktankarna": "septiktank",
    "septiktankarnas": "septiktank",
    "septiktankars": "septiktank",
    "septiktanken": "septiktank",
    "septiktankens": "septiktank",
    "septiktanks": "septiktank",
    "septim": "septima",
    "septiman": "septima",
    "septimans": "septima",
    "septimas": "septima",
    "septime": "septima",
    "septimor": "septima",
    "septimorna": "septima",
    "septimornas": "septima",
    "septimors": "septima",
    "septims": "septima",
    "septiska": "septisk",
    "septiskare": "septisk",
    "septiskares": "septisk",
    "septiskas": "septisk",
    "septiskast": "septisk",
    "septiskaste": "septisk",
    "septiskastes": "septisk",
    "septiskasts": "septisk",
    "septiske": "septisk",
    "septiskes": "septisk",
    "septisks": "septisk",
    "septiskt": "septisk",
    "septiskts": "septisk",
    "septuagesimas": "septuagesima",
    "sequoian": "sequoia",
    "sequoians": "sequoia",
    "sequoias": "sequoia",
    "ser": "se",
    "sera": "serum",
    "serafen": "seraf",
    "serafens": "seraf",
    "serafer": "seraf",
    "seraferna": "seraf",
    "serafernas": "seraf",
    "serafers": "seraf",
    "serafimerbanden": "serafimerband",
    "serafimerbandens": "serafimerband",
    "serafimerbandet": "serafimerband",
    "serafimerbandets": "serafimerband",
    "serafimerbands": "serafimerband",
    "serafiska": "serafisk",
    "serafiskare": "serafisk",
    "serafiskares": "serafisk",
    "serafiskas": "serafisk",
    "serafiskast": "serafisk",
    "serafiskaste": "serafisk",
    "serafiskastes": "serafisk",
    "serafiskasts": "serafisk",
    "serafiske": "serafisk",
    "serafiskes": "serafisk",
    "serafisks": "serafisk",
    "serafiskt": "serafisk",
    "serafiskts": "serafisk",
    "serafs": "seraf",
    "seraljen": "seralj",
    "seraljens": "seralj",
    "seraljer": "seralj",
    "seraljerna": "seralj",
    "seraljernas": "seralj",
    "seraljers": "seralj",
    "seraljs": "seralj",
    "serana": "serum",
    "seranas": "serum",
    "seras": "serum",
    "serben": "serb",
    "serbens": "serb",
    "serber": "serb",
    "serberna": "serb",
    "serbernas": "serb",
    "serbers": "serb",
    "serbisk": "serbiska",
    "serbiska": "serbisk",
    "serbiskan": "serbiska",
    "serbiskans": "serbiska",
    "serbiskare": "serbisk",
    "serbiskares": "serbisk",
    "serbiskas": "serbiska",
    "serbiskast": "serbisk",
    "serbiskaste": "serbisk",
    "serbiskastes": "serbisk",
    "serbiskasts": "serbisk",
    "serbiske": "serbisk",
    "serbiskes": "serbisk",
    "serbisks": "serbisk",
    "serbiskt": "serbisk",
    "serbiskts": "serbisk",
    "serbledar": "serbledare",
    "serbledaren": "serbledare",
    "serbledarens": "serbledare",
    "serbledares": "serbledare",
    "serbledarna": "serbledare",
    "serbledarnas": "serbledare",
    "serbokroatisk": "serbokroatiska",
    "serbokroatiska": "serbokroatisk",
    "serbokroatiskan": "serbokroatiska",
    "serbokroatiskans": "serbokroatiska",
    "serbokroatiskare": "serbokroatisk",
    "serbokroatiskares": "serbokroatisk",
    "serbokroatiskas": "serbokroatiska",
    "serbokroatiskast": "serbokroatisk",
    "serbokroatiskaste": "serbokroatisk",
    "serbokroatiskastes": "serbokroatisk",
    "serbokroatiskasts": "serbokroatisk",
    "serbokroatiske": "serbokroatisk",
    "serbokroatiskes": "serbokroatisk",
    "serbokroatisks": "serbokroatisk",
    "serbokroatiskt": "serbokroatisk",
    "serbokroatiskts": "serbokroatisk",
    "serbs": "serb",
    "serena": "seren",
    "serenaden": "serenad",
    "serenadens": "serenad",
    "serenader": "serenad",
    "serenaderna": "serenad",
    "serenadernas": "serenad",
    "serenaders": "serenad",
    "serenads": "serenad",
    "serenare": "seren",
    "serenares": "seren",
    "serenas": "seren",
    "serenast": "seren",
    "serenaste": "seren",
    "serenastes": "seren",
    "serenasts": "seren",
    "serene": "seren",
    "serenes": "seren",
    "sereniteten": "serenitet",
    "serenitetens": "serenitet",
    "sereniteter": "serenitet",
    "sereniteterna": "serenitet",
    "sereniteternas": "serenitet",
    "sereniteters": "serenitet",
    "serenitets": "serenitet",
    "serens": "seren",
    "serent": "seren",
    "serents": "seren",
    "sergeanten": "sergeant",
    "sergeantens": "sergeant",
    "sergeanter": "sergeant",
    "sergeanterna": "sergeant",
    "sergeanternas": "sergeant",
    "sergeanters": "sergeant",
    "sergeants": "sergeant",
    "seriefiguren": "seriefigur",
    "seriefigurens": "seriefigur",
    "seriefigurer": "seriefigur",
    "seriefigurerna": "seriefigur",
    "seriefigurernas": "seriefigur",
    "seriefigurers": "seriefigur",
    "seriefigurs": "seriefigur",
    "serieinlärningar": "serieinlärning",
    "serieinlärningarna": "serieinlärning",
    "serieinlärningarnas": "serieinlärning",
    "serieinlärningars": "serieinlärning",
    "serieinlärningen": "serieinlärning",
    "serieinlärningens": "serieinlärning",
    "serieinlärnings": "serieinlärning",
    "seriekopplad": "seriekoppla",
    "seriekopplade": "seriekoppla",
    "seriekopplades": "seriekoppla",
    "seriekopplads": "seriekoppla",
    "seriekopplande": "seriekoppla",
    "seriekopplanden": "seriekopplande",
    "seriekopplandena": "seriekopplande",
    "seriekopplandenas": "seriekopplande",
    "seriekopplandens": "seriekopplande",
    "seriekopplandes": "seriekopplande",
    "seriekopplandet": "seriekopplande",
    "seriekopplandets": "seriekopplande",
    "seriekopplar": "seriekoppla",
    "seriekopplas": "seriekoppla",
    "seriekopplat": "seriekoppla",
    "seriekopplats": "seriekoppla",
    "seriekopplingar": "seriekoppling",
    "seriekopplingarna": "seriekoppling",
    "seriekopplingarnas": "seriekoppling",
    "seriekopplingars": "seriekoppling",
    "seriekopplingen": "seriekoppling",
    "seriekopplingens": "seriekoppling",
    "seriekopplings": "seriekoppling",
    "seriekrockar": "seriekrock",
    "seriekrockarna": "seriekrock",
    "seriekrockarnas": "seriekrock",
    "seriekrockars": "seriekrock",
    "seriekrocken": "seriekrock",
    "seriekrockens": "seriekrock",
    "seriekrocks": "seriekrock",
    "seriella": "seriell",
    "seriellare": "seriell",
    "seriellares": "seriell",
    "seriellas": "seriell",
    "seriellast": "seriell",
    "seriellaste": "seriell",
    "seriellastes": "seriell",
    "seriellasts": "seriell",
    "serielle": "seriell",
    "serielles": "seriell",
    "seriells": "seriell",
    "seriellt": "seriell",
    "seriellts": "seriell",
    "seriemagasinen": "seriemagasin",
    "seriemagasinens": "seriemagasin",
    "seriemagasinet": "seriemagasin",
    "seriemagasinets": "seriemagasin",
    "seriemagasins": "seriemagasin",
    "seriematchen": "seriematch",
    "seriematchens": "seriematch",
    "seriematcher": "seriematch",
    "seriematcherna": "seriematch",
    "seriematchernas": "seriematch",
    "seriematchers": "seriematch",
    "seriematchs": "seriematch",
    "seriemorden": "seriemord",
    "seriemordens": "seriemord",
    "seriemordet": "seriemord",
    "seriemordets": "seriemord",
    "seriemords": "seriemord",
    "seriemässiga": "seriemässig",
    "seriemässigare": "seriemässig",
    "seriemässigares": "seriemässig",
    "seriemässigas": "seriemässig",
    "seriemässigast": "seriemässig",
    "seriemässigaste": "seriemässig",
    "seriemässigastes": "seriemässig",
    "seriemässigasts": "seriemässig",
    "seriemässige": "seriemässig",
    "seriemässiges": "seriemässig",
    "seriemässigs": "seriemässig",
    "seriemässigt": "seriemässig",
    "seriemässigts": "seriemässig",
    "seriemördar": "seriemördare",
    "seriemördaren": "seriemördare",
    "seriemördarens": "seriemördare",
    "seriemördares": "seriemördare",
    "seriemördarna": "seriemördare",
    "seriemördarnas": "seriemördare",
    "serien": "serie",
    "seriens": "serie",
    "serieproduktionen": "serieproduktion",
    "serieproduktionens": "serieproduktion",
    "serieproduktioner": "serieproduktion",
    "serieproduktionerna": "serieproduktion",
    "serieproduktionernas": "serieproduktion",
    "serieproduktioners": "serieproduktion",
    "serieproduktions": "serieproduktion",
    "serier": "serie",
    "serierna": "serie",
    "seriernas": "serie",
    "seriers": "serie",
    "serierutan": "serieruta",
    "serierutans": "serieruta",
    "serierutas": "serieruta",
    "serierute": "serieruta",
    "serierutor": "serieruta",
    "serierutorna": "serieruta",
    "serierutornas": "serieruta",
    "serierutors": "serieruta",
    "series": "serie",
    "seriespelen": "seriespel",
    "seriespelens": "seriespel",
    "seriespelet": "seriespel",
    "seriespelets": "seriespel",
    "seriespels": "seriespel",
    "serietecknar": "serietecknare",
    "serietecknaren": "serietecknare",
    "serietecknarens": "serietecknare",
    "serietecknares": "serietecknare",
    "serietecknarna": "serietecknare",
    "serietecknarnas": "serietecknare",
    "serietidningar": "serietidning",
    "serietidningarna": "serietidning",
    "serietidningarnas": "serietidning",
    "serietidningars": "serietidning",
    "serietidningen": "serietidning",
    "serietidningens": "serietidning",
    "serietidnings": "serietidning",
    "serietillverk": "serietillverka",
    "serietillverkad": "serietillverka",
    "serietillverkade": "serietillverka",
    "serietillverkades": "serietillverka",
    "serietillverkads": "serietillverka",
    "serietillverkande": "serietillverka",
    "serietillverkanden": "serietillverkande",
    "serietillverkandena": "serietillverkande",
    "serietillverkandenas": "serietillverkande",
    "serietillverkandens": "serietillverkande",
    "serietillverkandes": "serietillverkande",
    "serietillverkandet": "serietillverkande",
    "serietillverkandets": "serietillverkande",
    "serietillverkar": "serietillverka",
    "serietillverkas": "serietillverka",
    "serietillverkat": "serietillverka",
    "serietillverkats": "serietillverka",
    "serietillverkningar": "serietillverkning",
    "serietillverkningarna": "serietillverkning",
    "serietillverkningarnas": "serietillverkning",
    "serietillverkningars": "serietillverkning",
    "serietillverkningen": "serietillverkning",
    "serietillverkningens": "serietillverkning",
    "serietillverknings": "serietillverkning",
    "seriffen": "seriff",
    "seriffens": "seriff",
    "seriffer": "seriff",
    "serifferna": "seriff",
    "seriffernas": "seriff",
    "seriffers": "seriff",
    "seriffs": "seriff",
    "serigrafien": "serigrafi",
    "serigrafiens": "serigrafi",
    "serigrafier": "serigrafi",
    "serigrafierna": "serigrafi",
    "serigrafiernas": "serigrafi",
    "serigrafiers": "serigrafi",
    "serigrafin": "serigrafi",
    "serigrafins": "serigrafi",
    "serigrafis": "serigrafi",
    "seriositeten": "seriositet",
    "seriositetens": "seriositet",
    "seriositeter": "seriositet",
    "seriositeterna": "seriositet",
    "seriositeternas": "seriositet",
    "seriositeters": "seriositet",
    "seriositets": "seriositet",
    "seriösa": "seriös",
    "seriösare": "seriös",
    "seriösares": "seriös",
    "seriösas": "seriös",
    "seriösast": "seriös",
    "seriösaste": "seriös",
    "seriösastes": "seriös",
    "seriösasts": "seriös",
    "seriöse": "seriös",
    "seriöses": "seriös",
    "seriöst": "seriös",
    "seriösts": "seriös",
    "serologien": "serologi",
    "serologiens": "serologi",
    "serologin": "serologi",
    "serologins": "serologi",
    "serologis": "serologi",
    "serotoninen": "serotonin",
    "serotoninens": "serotonin",
    "serotoniner": "serotonin",
    "serotoninerna": "serotonin",
    "serotoninernas": "serotonin",
    "serotoniners": "serotonin",
    "serotoninet": "serotonin",
    "serotoninets": "serotonin",
    "serotonins": "serotonin",
    "serpenten": "serpent",
    "serpentens": "serpent",
    "serpenter": "serpent",
    "serpenterna": "serpent",
    "serpenternas": "serpent",
    "serpenters": "serpent",
    "serpentinen": "serpentin",
    "serpentinens": "serpentin",
    "serpentiner": "serpentin",
    "serpentinerna": "serpentin",
    "serpentinernas": "serpentin",
    "serpentiners": "serpentin",
    "serpentiniseringar": "serpentinisering",
    "serpentiniseringarna": "serpentinisering",
    "serpentiniseringarnas": "serpentinisering",
    "serpentiniseringars": "serpentinisering",
    "serpentiniseringen": "serpentinisering",
    "serpentiniseringens": "serpentinisering",
    "serpentiniserings": "serpentinisering",
    "serpentins": "serpentin",
    "serpents": "serpent",
    "serumdiagnostiken": "serumdiagnostik",
    "serumdiagnostikens": "serumdiagnostik",
    "serumdiagnostiks": "serumdiagnostik",
    "serumen": "serum",
    "serumens": "serum",
    "serumet": "serum",
    "serumets": "serum",
    "serums": "serum",
    "serumterapien": "serumterapi",
    "serumterapiens": "serumterapi",
    "serumterapin": "serumterapi",
    "serumterapins": "serumterapi",
    "serumterapis": "serumterapi",
    "serv": "serve",
    "servad": "serva",
    "servade": "serva",
    "servades": "serva",
    "servads": "serva",
    "servalen": "serval",
    "servalens": "serval",
    "servaler": "serval",
    "servalerna": "serval",
    "servalernas": "serval",
    "servalers": "serval",
    "servals": "serval",
    "servande": "serva",
    "servanden": "servande",
    "servandena": "servande",
    "servandenas": "servande",
    "servandens": "servande",
    "servandes": "servande",
    "servandet": "servande",
    "servandets": "servande",
    "servar": "serve",
    "servarna": "serve",
    "servarnas": "serve",
    "servars": "serve",
    "servas": "serva",
    "servat": "serva",
    "servats": "serva",
    "servbollar": "servboll",
    "servbollarna": "servboll",
    "servbollarnas": "servboll",
    "servbollars": "servboll",
    "servbollen": "servboll",
    "servbollens": "servboll",
    "servbolls": "servboll",
    "servebollar": "serveboll",
    "servebollarna": "serveboll",
    "servebollarnas": "serveboll",
    "servebollars": "serveboll",
    "servebollen": "serveboll",
    "servebollens": "serveboll",
    "servebolls": "serveboll",
    "serveessen": "serveess",
    "serveessens": "serveess",
    "serveesset": "serveess",
    "serveessets": "serveess",
    "servegamen": "servegame",
    "servegamens": "servegame",
    "servegames": "servegame",
    "servegamet": "servegame",
    "servegamets": "servegame",
    "servelinjen": "servelinje",
    "servelinjens": "servelinje",
    "servelinjer": "servelinje",
    "servelinjerna": "servelinje",
    "servelinjernas": "servelinje",
    "servelinjers": "servelinje",
    "servelinjes": "servelinje",
    "serven": "serve",
    "servens": "serve",
    "serverad": "servera",
    "serverade": "servera",
    "serverades": "servera",
    "serverads": "servera",
    "serverande": "servera",
    "serveranden": "serverande",
    "serverandena": "serverande",
    "serverandenas": "serverande",
    "serverandens": "serverande",
    "serverandes": "serverande",
    "serverandet": "serverande",
    "serverandets": "serverande",
    "serverar": "servera",
    "serveras": "servera",
    "serverat": "servera",
    "serverats": "servera",
    "serverbara": "serverbar",
    "serverbarare": "serverbar",
    "serverbarares": "serverbar",
    "serverbaras": "serverbar",
    "serverbarast": "serverbar",
    "serverbaraste": "serverbar",
    "serverbarastes": "serverbar",
    "serverbarasts": "serverbar",
    "serverbare": "serverbar",
    "serverbares": "serverbar",
    "serverbarheten": "serverbarhet",
    "serverbarhetens": "serverbarhet",
    "serverbarhets": "serverbarhet",
    "serverbars": "serverbar",
    "serverbart": "serverbar",
    "serverbarts": "serverbar",
    "serveringar": "servering",
    "serveringarna": "servering",
    "serveringarnas": "servering",
    "serveringars": "servering",
    "serveringen": "servering",
    "serveringens": "servering",
    "serverings": "servering",
    "serveringsavgiften": "serveringsavgift",
    "serveringsavgiftens": "serveringsavgift",
    "serveringsavgifter": "serveringsavgift",
    "serveringsavgifterna": "serveringsavgift",
    "serveringsavgifternas": "serveringsavgift",
    "serveringsavgifters": "serveringsavgift",
    "serveringsavgifts": "serveringsavgift",
    "serveringsborden": "serveringsbord",
    "serveringsbordens": "serveringsbord",
    "serveringsbordet": "serveringsbord",
    "serveringsbordets": "serveringsbord",
    "serveringsbords": "serveringsbord",
    "serveringsfaten": "serveringsfat",
    "serveringsfatens": "serveringsfat",
    "serveringsfatet": "serveringsfat",
    "serveringsfatets": "serveringsfat",
    "serveringsfats": "serveringsfat",
    "serveringsgångar": "serveringsgång",
    "serveringsgångarna": "serveringsgång",
    "serveringsgångarnas": "serveringsgång",
    "serveringsgångars": "serveringsgång",
    "serveringsgången": "serveringsgång",
    "serveringsgångens": "serveringsgång",
    "serveringsgångs": "serveringsgång",
    "serveringskorkar": "serveringskork",
    "serveringskorkarna": "serveringskork",
    "serveringskorkarnas": "serveringskork",
    "serveringskorkars": "serveringskork",
    "serveringskorken": "serveringskork",
    "serveringskorkens": "serveringskork",
    "serveringskorks": "serveringskork",
    "serveringsrummen": "serveringsrum",
    "serveringsrummens": "serveringsrum",
    "serveringsrummet": "serveringsrum",
    "serveringsrummets": "serveringsrum",
    "serveringsrums": "serveringsrum",
    "serveringsvagnar": "serveringsvagn",
    "serveringsvagnarna": "serveringsvagn",
    "serveringsvagnarnas": "serveringsvagn",
    "serveringsvagnars": "serveringsvagn",
    "serveringsvagnen": "serveringsvagn",
    "serveringsvagnens": "serveringsvagn",
    "serveringsvagns": "serveringsvagn",
    "servern": "server",
    "serverns": "server",
    "servers": "server",
    "serverutan": "serveruta",
    "serverutans": "serveruta",
    "serverutas": "serveruta",
    "serverute": "serveruta",
    "serverutor": "serveruta",
    "serverutorna": "serveruta",
    "serverutornas": "serveruta",
    "serverutors": "serveruta",
    "serves": "serve",
    "servessen": "servess",
    "servessens": "servess",
    "servesset": "servess",
    "servessets": "servess",
    "servettbrytningar": "servettbrytning",
    "servettbrytningarna": "servettbrytning",
    "servettbrytningarnas": "servettbrytning",
    "servettbrytningars": "servettbrytning",
    "servettbrytningen": "servettbrytning",
    "servettbrytningens": "servettbrytning",
    "servettbrytnings": "servettbrytning",
    "servetten": "servett",
    "servettens": "servett",
    "servetter": "servett",
    "servetterna": "servett",
    "servetternas": "servett",
    "servetters": "servett",
    "servettringar": "servettring",
    "servettringarna": "servettring",
    "servettringarnas": "servettring",
    "servettringars": "servettring",
    "servettringen": "servettring",
    "servettringens": "servettring",
    "servettrings": "servettring",
    "servetts": "servett",
    "serveuppkasten": "serveuppkast",
    "serveuppkastens": "serveuppkast",
    "serveuppkastet": "serveuppkast",
    "serveuppkastets": "serveuppkast",
    "serveuppkasts": "serveuppkast",
    "servgamen": "servgame",
    "servgamens": "servgame",
    "servgames": "servgame",
    "servgamet": "servgame",
    "servgamets": "servgame",
    "servicebilar": "servicebil",
    "servicebilarna": "servicebil",
    "servicebilarnas": "servicebil",
    "servicebilars": "servicebil",
    "servicebilen": "servicebil",
    "servicebilens": "servicebil",
    "servicebils": "servicebil",
    "servicebostaden": "servicebostad",
    "servicebostadens": "servicebostad",
    "servicebostads": "servicebostad",
    "servicebostan": "servicebostad",
    "servicebostans": "servicebostad",
    "servicebostäder": "servicebostad",
    "servicebostäderna": "servicebostad",
    "servicebostädernas": "servicebostad",
    "servicebostäders": "servicebostad",
    "serviceboxar": "servicebox",
    "serviceboxarna": "servicebox",
    "serviceboxarnas": "servicebox",
    "serviceboxars": "servicebox",
    "serviceboxen": "servicebox",
    "serviceboxens": "servicebox",
    "servicebutiken": "servicebutik",
    "servicebutikens": "servicebutik",
    "servicebutiker": "servicebutik",
    "servicebutikerna": "servicebutik",
    "servicebutikernas": "servicebutik",
    "servicebutikers": "servicebutik",
    "servicebutiks": "servicebutik",
    "servicehusen": "servicehus",
    "servicehusens": "servicehus",
    "servicehuset": "servicehus",
    "servicehusets": "servicehus",
    "serviceinrättningar": "serviceinrättning",
    "serviceinrättningarna": "serviceinrättning",
    "serviceinrättningarnas": "serviceinrättning",
    "serviceinrättningars": "serviceinrättning",
    "serviceinrättningen": "serviceinrättning",
    "serviceinrättningens": "serviceinrättning",
    "serviceinrättnings": "serviceinrättning",
    "serviceluck": "servicelucka",
    "serviceluckan": "servicelucka",
    "serviceluckans": "servicelucka",
    "serviceluckas": "servicelucka",
    "servicelucke": "servicelucka",
    "serviceluckor": "servicelucka",
    "serviceluckorna": "servicelucka",
    "serviceluckornas": "servicelucka",
    "serviceluckors": "servicelucka",
    "servicelucks": "servicelucka",
    "servicelägenheten": "servicelägenhet",
    "servicelägenhetens": "servicelägenhet",
    "servicelägenheter": "servicelägenhet",
    "servicelägenheterna": "servicelägenhet",
    "servicelägenheternas": "servicelägenhet",
    "servicelägenheters": "servicelägenhet",
    "servicelägenhets": "servicelägenhet",
    "servicemannen": "serviceman",
    "servicemannens": "serviceman",
    "servicemans": "serviceman",
    "servicemän": "serviceman",
    "servicemännen": "serviceman",
    "servicemännens": "serviceman",
    "servicemäns": "serviceman",
    "servicemässiga": "servicemässig",
    "servicemässigare": "servicemässig",
    "servicemässigares": "servicemässig",
    "servicemässigas": "servicemässig",
    "servicemässigast": "servicemässig",
    "servicemässigaste": "servicemässig",
    "servicemässigastes": "servicemässig",
    "servicemässigasts": "servicemässig",
    "servicemässige": "servicemässig",
    "servicemässiges": "servicemässig",
    "servicemässigs": "servicemässig",
    "servicemässigt": "servicemässig",
    "servicemässigts": "servicemässig",
    "servicen": "service",
    "servicens": "service",
    "servicenäringar": "servicenäring",
    "servicenäringarna": "servicenäring",
    "servicenäringarnas": "servicenäring",
    "servicenäringars": "servicenäring",
    "servicenäringen": "servicenäring",
    "servicenäringens": "servicenäring",
    "servicenärings": "servicenäring",
    "servicepersonalen": "servicepersonal",
    "servicepersonalens": "servicepersonal",
    "servicepersonaler": "servicepersonal",
    "servicepersonalerna": "servicepersonal",
    "servicepersonalernas": "servicepersonal",
    "servicepersonalers": "servicepersonal",
    "servicepersonals": "servicepersonal",
    "services": "service",
    "servicestationen": "servicestation",
    "servicestationens": "servicestation",
    "servicestationer": "servicestation",
    "servicestationerna": "servicestation",
    "servicestationernas": "servicestation",
    "servicestationers": "servicestation",
    "servicestations": "servicestation",
    "serviceyrken": "serviceyrke",
    "serviceyrkena": "serviceyrke",
    "serviceyrkenas": "serviceyrke",
    "serviceyrkens": "serviceyrke",
    "serviceyrkes": "serviceyrke",
    "serviceyrket": "serviceyrke",
    "serviceyrkets": "serviceyrke",
    "servila": "servil",
    "servilare": "servil",
    "servilares": "servil",
    "servilas": "servil",
    "servilast": "servil",
    "servilaste": "servil",
    "servilastes": "servil",
    "servilasts": "servil",
    "servile": "servil",
    "serviles": "servil",
    "servilismen": "servilism",
    "servilismens": "servilism",
    "servilismer": "servilism",
    "servilismerna": "servilism",
    "servilismernas": "servilism",
    "servilismers": "servilism",
    "servilisms": "servilism",
    "serviliteten": "servilitet",
    "servilitetens": "servilitet",
    "serviliteter": "servilitet",
    "serviliteterna": "servilitet",
    "serviliteternas": "servilitet",
    "serviliteters": "servilitet",
    "servilitets": "servilitet",
    "servils": "servil",
    "servilt": "servil",
    "servilts": "servil",
    "servisen": "servis",
    "servisens": "servis",
    "serviser": "servis",
    "serviserna": "servis",
    "servisernas": "servis",
    "servisers": "servis",
    "servisledningar": "servisledning",
    "servisledningarna": "servisledning",
    "servisledningarnas": "servisledning",
    "servisledningars": "servisledning",
    "servisledningen": "servisledning",
    "servisledningens": "servisledning",
    "servislednings": "servisledning",
    "servitrisen": "servitris",
    "servitrisens": "servitris",
    "servitriser": "servitris",
    "servitriserna": "servitris",
    "servitrisernas": "servitris",
    "servitrisers": "servitris",
    "servituten": "servitut",
    "servitutens": "servitut",
    "servitutet": "servitut",
    "servitutets": "servitut",
    "servituts": "servitut",
    "servitören": "servitör",
    "servitörens": "servitör",
    "servitörer": "servitör",
    "servitörerna": "servitör",
    "servitörernas": "servitör",
    "servitörers": "servitör",
    "servitörs": "servitör",
    "servlinjen": "servlinje",
    "servlinjens": "servlinje",
    "servlinjer": "servlinje",
    "servlinjerna": "servlinje",
    "servlinjernas": "servlinje",
    "servlinjers": "servlinje",
    "servlinjes": "servlinje",
    "servobromsar": "servobroms",
    "servobromsarna": "servobroms",
    "servobromsarnas": "servobroms",
    "servobromsars": "servobroms",
    "servobromsen": "servobroms",
    "servobromsens": "servobroms",
    "servomotorer": "servomotor",
    "servomotorerna": "servomotor",
    "servomotorernas": "servomotor",
    "servomotorers": "servomotor",
    "servomotorn": "servomotor",
    "servomotorns": "servomotor",
    "servomotors": "servomotor",
    "servostyrningar": "servostyrning",
    "servostyrningarna": "servostyrning",
    "servostyrningarnas": "servostyrning",
    "servostyrningars": "servostyrning",
    "servostyrningen": "servostyrning",
    "servostyrningens": "servostyrning",
    "servostyrnings": "servostyrning",
    "servrar": "server",
    "servrarna": "server",
    "servrarnas": "server",
    "servrars": "server",
    "servrutan": "servruta",
    "servrutans": "servruta",
    "servrutas": "servruta",
    "servrute": "servruta",
    "servrutor": "servruta",
    "servrutorna": "servruta",
    "servrutornas": "servruta",
    "servrutors": "servruta",
    "servs": "serve",
    "serösa": "serös",
    "serösare": "serös",
    "serösares": "serös",
    "serösas": "serös",
    "serösast": "serös",
    "serösaste": "serös",
    "serösastes": "serös",
    "serösasts": "serös",
    "seröse": "serös",
    "seröses": "serös",
    "seröst": "serös",
    "serösts": "serös",
    "sesamen": "sesam",
    "sesamens": "sesam",
    "sesamfröen": "sesamfrö",
    "sesamfröens": "sesamfrö",
    "sesamfröet": "sesamfrö",
    "sesamfröets": "sesamfrö",
    "sesamfrön": "sesamfrö",
    "sesamfröna": "sesamfrö",
    "sesamfrönas": "sesamfrö",
    "sesamfröns": "sesamfrö",
    "sesamfrös": "sesamfrö",
    "sesamfröt": "sesamfrö",
    "sesamfröts": "sesamfrö",
    "sesams": "sesam",
    "sess": "sessa",
    "sessan": "sessa",
    "sessans": "sessa",
    "sessas": "sessa",
    "sesse": "sessa",
    "sessionen": "session",
    "sessionens": "session",
    "sessioner": "session",
    "sessionerna": "session",
    "sessionernas": "session",
    "sessioners": "session",
    "sessions": "session",
    "sessor": "sessa",
    "sessorna": "sessa",
    "sessornas": "sessa",
    "sessors": "sessa",
    "set": "s",
    "setbollar": "setboll",
    "setbollarna": "setboll",
    "setbollarnas": "setboll",
    "setbollars": "setboll",
    "setbollen": "setboll",
    "setbollens": "setboll",
    "setbolls": "setboll",
    "seten": "set",
    "setens": "set",
    "setet": "set",
    "setets": "set",
    "sets": "set",
    "sett": "se",
    "settern": "setter",
    "setterns": "setter",
    "setters": "setter",
    "settlementen": "settlement",
    "settlementens": "settlement",
    "settlementet": "settlement",
    "settlementets": "settlement",
    "settlements": "settlement",
    "settrar": "setter",
    "settrarna": "setter",
    "settrarnas": "setter",
    "settrars": "setter",
    "setts": "se",
    "sevärda": "sevärd",
    "sevärdare": "sevärd",
    "sevärdares": "sevärd",
    "sevärdas": "sevärd",
    "sevärdast": "sevärd",
    "sevärdaste": "sevärd",
    "sevärdastes": "sevärd",
    "sevärdasts": "sevärd",
    "sevärde": "sevärd",
    "sevärdes": "sevärd",
    "sevärdheten": "sevärdhet",
    "sevärdhetens": "sevärdhet",
    "sevärdheter": "sevärdhet",
    "sevärdheterna": "sevärdhet",
    "sevärdheternas": "sevärdhet",
    "sevärdheters": "sevärdhet",
    "sevärdhets": "sevärdhet",
    "sevärds": "sevärd",
    "sevärt": "sevärd",
    "sevärts": "sevärd",
    "sexaffären": "sexaffär",
    "sexaffärens": "sexaffär",
    "sexaffärer": "sexaffär",
    "sexaffärerna": "sexaffär",
    "sexaffärernas": "sexaffär",
    "sexaffärers": "sexaffär",
    "sexaffärs": "sexaffär",
    "sexagesimas": "sexagesima",
    "sexakten": "sexakt",
    "sexaktens": "sexakt",
    "sexakter": "sexakt",
    "sexakterna": "sexakt",
    "sexakternas": "sexakt",
    "sexakters": "sexakt",
    "sexakts": "sexakt",
    "sexan": "sexa",
    "sexans": "sexa",
    "sexas": "sexa",
    "sexbomben": "sexbomb",
    "sexbombens": "sexbomb",
    "sexbomber": "sexbomb",
    "sexbomberna": "sexbomb",
    "sexbombernas": "sexbomb",
    "sexbombers": "sexbomb",
    "sexbombs": "sexbomb",
    "sexbrotten": "sexbrott",
    "sexbrottens": "sexbrott",
    "sexbrottet": "sexbrott",
    "sexbrottets": "sexbrott",
    "sexbrotts": "sexbrott",
    "sexdebuten": "sexdebut",
    "sexdebutens": "sexdebut",
    "sexdebuter": "sexdebut",
    "sexdebuterna": "sexdebut",
    "sexdebuternas": "sexdebut",
    "sexdebuters": "sexdebut",
    "sexdebuts": "sexdebut",
    "sexdubben": "sexdubbel",
    "sexdubbens": "sexdubbel",
    "sexdubbet": "sexdubbel",
    "sexdubbets": "sexdubbel",
    "sexdubblad": "sexdubbla",
    "sexdubblade": "sexdubbla",
    "sexdubblades": "sexdubbla",
    "sexdubblads": "sexdubbla",
    "sexdubblande": "sexdubbla",
    "sexdubblanden": "sexdubblande",
    "sexdubblandena": "sexdubblande",
    "sexdubblandenas": "sexdubblande",
    "sexdubblandens": "sexdubblande",
    "sexdubblandes": "sexdubblande",
    "sexdubblandet": "sexdubblande",
    "sexdubblandets": "sexdubblande",
    "sexdubblar": "sexdubbla",
    "sexdubblas": "sexdubbla",
    "sexdubblat": "sexdubbla",
    "sexdubblats": "sexdubbla",
    "sexdubbna": "sexdubbel",
    "sexdubbnas": "sexdubbel",
    "sexdubbne": "sexdubbel",
    "sexdubbnes": "sexdubbel",
    "sexet": "sex",
    "sexets": "sex",
    "sexexperten": "sexexpert",
    "sexexpertens": "sexexpert",
    "sexexperter": "sexexpert",
    "sexexperterna": "sexexpert",
    "sexexperternas": "sexexpert",
    "sexexperters": "sexexpert",
    "sexexperts": "sexexpert",
    "sexfaldiga": "sexfaldig",
    "sexfaldigas": "sexfaldig",
    "sexfaldige": "sexfaldig",
    "sexfaldiges": "sexfaldig",
    "sexfaldigs": "sexfaldig",
    "sexfaldigt": "sexfaldig",
    "sexfaldigts": "sexfaldig",
    "sexfixerade": "sexfixerad",
    "sexfixerades": "sexfixerad",
    "sexfixerads": "sexfixerad",
    "sexfixerat": "sexfixerad",
    "sexfixerats": "sexfixerad",
    "sexfotingar": "sexfoting",
    "sexfotingarna": "sexfoting",
    "sexfotingarnas": "sexfoting",
    "sexfotingars": "sexfoting",
    "sexfotingen": "sexfoting",
    "sexfotingens": "sexfoting",
    "sexfotings": "sexfoting",
    "sexförbrytar": "sexförbrytare",
    "sexförbrytaren": "sexförbrytare",
    "sexförbrytarens": "sexförbrytare",
    "sexförbrytares": "sexförbrytare",
    "sexförbrytarna": "sexförbrytare",
    "sexförbrytarnas": "sexförbrytare",
    "sexhjälpmedels": "sexhjälpmedel",
    "sexhjälpmedlen": "sexhjälpmedel",
    "sexhjälpmedlens": "sexhjälpmedel",
    "sexhjälpmedlet": "sexhjälpmedel",
    "sexhjälpmedlets": "sexhjälpmedel",
    "sexhändelsen": "sexhändelse",
    "sexhändelsens": "sexhändelse",
    "sexhändelser": "sexhändelse",
    "sexhändelserna": "sexhändelse",
    "sexhändelsernas": "sexhändelse",
    "sexhändelsers": "sexhändelse",
    "sexhändelses": "sexhändelse",
    "sexiga": "sexig",
    "sexigare": "sexig",
    "sexigares": "sexig",
    "sexigas": "sexig",
    "sexigast": "sexig",
    "sexigaste": "sexig",
    "sexigastes": "sexig",
    "sexigasts": "sexig",
    "sexige": "sexig",
    "sexiges": "sexig",
    "sexigs": "sexig",
    "sexigt": "sexig",
    "sexigts": "sexig",
    "sexismen": "sexism",
    "sexismens": "sexism",
    "sexismer": "sexism",
    "sexismerna": "sexism",
    "sexismernas": "sexism",
    "sexismers": "sexism",
    "sexisms": "sexism",
    "sexistiska": "sexistisk",
    "sexistiskas": "sexistisk",
    "sexistiske": "sexistisk",
    "sexistiskes": "sexistisk",
    "sexistisks": "sexistisk",
    "sexistiskt": "sexistisk",
    "sexistiskts": "sexistisk",
    "sexkantiga": "sexkantig",
    "sexkantigare": "sexkantig",
    "sexkantigares": "sexkantig",
    "sexkantigas": "sexkantig",
    "sexkantigast": "sexkantig",
    "sexkantigaste": "sexkantig",
    "sexkantigastes": "sexkantig",
    "sexkantigasts": "sexkantig",
    "sexkantige": "sexkantig",
    "sexkantiges": "sexkantig",
    "sexkantigs": "sexkantig",
    "sexkantigt": "sexkantig",
    "sexkantigts": "sexkantig",
    "sexkantsnyckeln": "sexkantsnyckel",
    "sexkantsnyckelns": "sexkantsnyckel",
    "sexkantsnyckels": "sexkantsnyckel",
    "sexkantsnycklar": "sexkantsnyckel",
    "sexkantsnycklarna": "sexkantsnyckel",
    "sexkantsnycklarnas": "sexkantsnyckel",
    "sexkantsnycklars": "sexkantsnyckel",
    "sexklippen": "sexklipp",
    "sexklippens": "sexklipp",
    "sexklippet": "sexklipp",
    "sexklippets": "sexklipp",
    "sexklipps": "sexklipp",
    "sexköpen": "sexköp",
    "sexköpens": "sexköp",
    "sexköpet": "sexköp",
    "sexköpets": "sexköp",
    "sexköps": "sexköp",
    "sexköpslagar": "sexköpslag",
    "sexköpslagarna": "sexköpslag",
    "sexköpslagarnas": "sexköpslag",
    "sexköpslagars": "sexköpslag",
    "sexköpslagen": "sexköpslag",
    "sexköpslagens": "sexköpslag",
    "sexköpslags": "sexköpslag",
    "sexleksaken": "sexleksak",
    "sexleksakens": "sexleksak",
    "sexleksaker": "sexleksak",
    "sexleksakerna": "sexleksak",
    "sexleksakernas": "sexleksak",
    "sexleksakers": "sexleksak",
    "sexleksaks": "sexleksak",
    "sexlingar": "sexling",
    "sexlingarna": "sexling",
    "sexlingarnas": "sexling",
    "sexlingars": "sexling",
    "sexlingen": "sexling",
    "sexlingens": "sexling",
    "sexlings": "sexling",
    "sexlusten": "sexlust",
    "sexlustens": "sexlust",
    "sexlusts": "sexlust",
    "sexmissbruket": "sexmissbruk",
    "sexmissbrukets": "sexmissbruk",
    "sexmissbruks": "sexmissbruk",
    "sexmorden": "sexmord",
    "sexmordens": "sexmord",
    "sexmordet": "sexmord",
    "sexmordets": "sexmord",
    "sexmords": "sexmord",
    "sexmyten": "sexmyt",
    "sexmytens": "sexmyt",
    "sexmyter": "sexmyt",
    "sexmyterna": "sexmyt",
    "sexmyternas": "sexmyt",
    "sexmyters": "sexmyt",
    "sexmyts": "sexmyt",
    "sexmästar": "sexmästare",
    "sexmästaren": "sexmästare",
    "sexmästarens": "sexmästare",
    "sexmästares": "sexmästare",
    "sexmästarna": "sexmästare",
    "sexmästarnas": "sexmästare",
    "sexologien": "sexologi",
    "sexologiens": "sexologi",
    "sexologin": "sexologi",
    "sexologins": "sexologi",
    "sexologis": "sexologi",
    "sexor": "sexa",
    "sexorna": "sexa",
    "sexornas": "sexa",
    "sexors": "sexa",
    "sexpackar": "sexpack",
    "sexpackarna": "sexpack",
    "sexpackarnas": "sexpack",
    "sexpackars": "sexpack",
    "sexpacken": "sexpack",
    "sexpackens": "sexpack",
    "sexpacks": "sexpack",
    "sexpartnern": "sexpartner",
    "sexpartnerna": "sexpartner",
    "sexpartnernas": "sexpartner",
    "sexpartnerns": "sexpartner",
    "sexpartners": "sexpartner",
    "sexpartnersarna": "sexpartner",
    "sexpartnersarnas": "sexpartner",
    "sexpartnersen": "sexpartner",
    "sexpartnersens": "sexpartner",
    "sexpartssamtalen": "sexpartssamtal",
    "sexpartssamtalens": "sexpartssamtal",
    "sexpartssamtalet": "sexpartssamtal",
    "sexpartssamtalets": "sexpartssamtal",
    "sexpartssamtals": "sexpartssamtal",
    "sexpipiga": "sexpipig",
    "sexpipigare": "sexpipig",
    "sexpipigares": "sexpipig",
    "sexpipigas": "sexpipig",
    "sexpipigast": "sexpipig",
    "sexpipigaste": "sexpipig",
    "sexpipigastes": "sexpipig",
    "sexpipigasts": "sexpipig",
    "sexpipige": "sexpipig",
    "sexpipiges": "sexpipig",
    "sexpipigs": "sexpipig",
    "sexpipigt": "sexpipig",
    "sexpipigts": "sexpipig",
    "sexradiga": "sexradig",
    "sexradigare": "sexradig",
    "sexradigares": "sexradig",
    "sexradigas": "sexradig",
    "sexradigast": "sexradig",
    "sexradigaste": "sexradig",
    "sexradigastes": "sexradig",
    "sexradigasts": "sexradig",
    "sexradige": "sexradig",
    "sexradiges": "sexradig",
    "sexradigs": "sexradig",
    "sexradigt": "sexradig",
    "sexradigts": "sexradig",
    "sexrådgivar": "sexrådgivare",
    "sexrådgivaren": "sexrådgivare",
    "sexrådgivarens": "sexrådgivare",
    "sexrådgivares": "sexrådgivare",
    "sexrådgivarna": "sexrådgivare",
    "sexrådgivarnas": "sexrådgivare",
    "sexscenen": "sexscen",
    "sexscenens": "sexscen",
    "sexscener": "sexscen",
    "sexscenerna": "sexscen",
    "sexscenernas": "sexscen",
    "sexsceners": "sexscen",
    "sexscens": "sexscen",
    "sexsiffriga": "sexsiffrig",
    "sexsiffrigare": "sexsiffrig",
    "sexsiffrigares": "sexsiffrig",
    "sexsiffrigas": "sexsiffrig",
    "sexsiffrigast": "sexsiffrig",
    "sexsiffrigaste": "sexsiffrig",
    "sexsiffrigastes": "sexsiffrig",
    "sexsiffrigasts": "sexsiffrig",
    "sexsiffrige": "sexsiffrig",
    "sexsiffriges": "sexsiffrig",
    "sexsiffrigs": "sexsiffrig",
    "sexsiffrigt": "sexsiffrig",
    "sexsiffrigts": "sexsiffrig",
    "sexskandalen": "sexskandal",
    "sexskandalens": "sexskandal",
    "sexskandaler": "sexskandal",
    "sexskandalerna": "sexskandal",
    "sexskandalernas": "sexskandal",
    "sexskandalers": "sexskandal",
    "sexskandals": "sexskandal",
    "sexslavar": "sexslav",
    "sexslavarna": "sexslav",
    "sexslavarnas": "sexslav",
    "sexslavars": "sexslav",
    "sexslaven": "sexslav",
    "sexslavens": "sexslav",
    "sexslavs": "sexslav",
    "sexsnårets": "sexsnåret",
    "sexspannen": "sexspann",
    "sexspannens": "sexspann",
    "sexspannet": "sexspann",
    "sexspannets": "sexspann",
    "sexspanns": "sexspann",
    "sextanten": "sextant",
    "sextantens": "sextant",
    "sextanter": "sextant",
    "sextanterna": "sextant",
    "sextanternas": "sextant",
    "sextanters": "sextant",
    "sextants": "sextant",
    "sexten": "sext",
    "sextens": "sext",
    "sexter": "sext",
    "sexterna": "sext",
    "sexternas": "sext",
    "sexters": "sext",
    "sextetten": "sextett",
    "sextettens": "sextett",
    "sextetter": "sextett",
    "sextetterna": "sextett",
    "sextetternas": "sextett",
    "sextetters": "sextett",
    "sextetts": "sextett",
    "sextionde": "sextio",
    "sextiondedelar": "sextiondedel",
    "sextiondedelarna": "sextiondedel",
    "sextiondedelarnas": "sextiondedel",
    "sextiondedelars": "sextiondedel",
    "sextiondedelen": "sextiondedel",
    "sextiondedelens": "sextiondedel",
    "sextiondedels": "sextiondedel",
    "sextiondelar": "sextiondel",
    "sextiondelarna": "sextiondel",
    "sextiondelarnas": "sextiondel",
    "sextiondelars": "sextiondel",
    "sextiondelen": "sextiondel",
    "sextiondelens": "sextiondel",
    "sextiondels": "sextiondel",
    "sextiondes": "sextio",
    "sextionionde": "sextionio",
    "sextioniondes": "sextionio",
    "sextionios": "sextionio",
    "sextios": "sextio",
    "sextiotalet": "sextiotal",
    "sextiotalets": "sextiotal",
    "sextiotals": "sextiotal",
    "sextioårsjubileer": "sextioårsjubileum",
    "sextioårsjubileerna": "sextioårsjubileum",
    "sextioårsjubileernas": "sextioårsjubileum",
    "sextioårsjubileers": "sextioårsjubileum",
    "sextioårsjubileet": "sextioårsjubileum",
    "sextioårsjubileets": "sextioårsjubileum",
    "sextioårsjubilei": "sextioårsjubileum",
    "sextioårsjubileums": "sextioårsjubileum",
    "sextis": "sexti",
    "sextitalet": "sextital",
    "sextitalets": "sextital",
    "sextitals": "sextital",
    "sextiårsjubileer": "sextiårsjubileum",
    "sextiårsjubileerna": "sextiårsjubileum",
    "sextiårsjubileernas": "sextiårsjubileum",
    "sextiårsjubileers": "sextiårsjubileum",
    "sextiårsjubileet": "sextiårsjubileum",
    "sextiårsjubileets": "sextiårsjubileum",
    "sextiårsjubilei": "sextiårsjubileum",
    "sextiårsjubileums": "sextiårsjubileum",
    "sextjänsten": "sextjänst",
    "sextjänstens": "sextjänst",
    "sextjänster": "sextjänst",
    "sextjänsterna": "sextjänst",
    "sextjänsternas": "sextjänst",
    "sextjänsters": "sextjänst",
    "sextjänsts": "sextjänst",
    "sextolen": "sextol",
    "sextolens": "sextol",
    "sextoler": "sextol",
    "sextolerna": "sextol",
    "sextolernas": "sextol",
    "sextolers": "sextol",
    "sextols": "sextol",
    "sextonde": "sexton",
    "sextondes": "sexton",
    "sextonhundratalet": "sextonhundratal",
    "sextonhundratalets": "sextonhundratal",
    "sextonhundratals": "sextonhundratal",
    "sextons": "sexton",
    "sextonsnårets": "sextonsnåret",
    "sextonåriga": "sextonårig",
    "sextonårigas": "sextonårig",
    "sextonårige": "sextonårig",
    "sextonåriges": "sextonårig",
    "sextonårigs": "sextonårig",
    "sextonårigt": "sextonårig",
    "sextonårigts": "sextonårig",
    "sextonåringar": "sextonåring",
    "sextonåringarna": "sextonåring",
    "sextonåringarnas": "sextonåring",
    "sextonåringars": "sextonåring",
    "sextonåringen": "sextonåring",
    "sextonåringens": "sextonåring",
    "sextonårings": "sextonåring",
    "sexts": "sext",
    "sextumsspikar": "sextumsspik",
    "sextumsspikarna": "sextumsspik",
    "sextumsspikarnas": "sextumsspik",
    "sextumsspikars": "sextumsspik",
    "sextumsspiken": "sextumsspik",
    "sextumsspikens": "sextumsspik",
    "sextumsspiks": "sextumsspik",
    "sexualakten": "sexualakt",
    "sexualaktens": "sexualakt",
    "sexualakter": "sexualakt",
    "sexualakterna": "sexualakt",
    "sexualakternas": "sexualakt",
    "sexualakters": "sexualakt",
    "sexualakts": "sexualakt",
    "sexualbrotten": "sexualbrott",
    "sexualbrottens": "sexualbrott",
    "sexualbrottet": "sexualbrott",
    "sexualbrottets": "sexualbrott",
    "sexualbrotts": "sexualbrott",
    "sexualcykeln": "sexualcykel",
    "sexualcykelns": "sexualcykel",
    "sexualcykels": "sexualcykel",
    "sexualcyklar": "sexualcykel",
    "sexualcyklarna": "sexualcykel",
    "sexualcyklarnas": "sexualcykel",
    "sexualcyklars": "sexualcykel",
    "sexualcykler": "sexualcykel",
    "sexualcyklerna": "sexualcykel",
    "sexualcyklernas": "sexualcykel",
    "sexualcyklers": "sexualcykel",
    "sexualdriften": "sexualdrift",
    "sexualdriftens": "sexualdrift",
    "sexualdrifter": "sexualdrift",
    "sexualdrifterna": "sexualdrift",
    "sexualdrifternas": "sexualdrift",
    "sexualdrifters": "sexualdrift",
    "sexualdrifts": "sexualdrift",
    "sexualian": "sexualia",
    "sexualiana": "sexualia",
    "sexualianas": "sexualia",
    "sexualians": "sexualia",
    "sexualias": "sexualia",
    "sexualiserad": "sexualisera",
    "sexualiserade": "sexualisera",
    "sexualiserades": "sexualisera",
    "sexualiserads": "sexualisera",
    "sexualiserande": "sexualisera",
    "sexualiseranden": "sexualiserande",
    "sexualiserandena": "sexualiserande",
    "sexualiserandenas": "sexualiserande",
    "sexualiserandens": "sexualiserande",
    "sexualiserandes": "sexualiserande",
    "sexualiserandet": "sexualiserande",
    "sexualiserandets": "sexualiserande",
    "sexualiserar": "sexualisera",
    "sexualiseras": "sexualisera",
    "sexualiserat": "sexualisera",
    "sexualiserats": "sexualisera",
    "sexualiserbara": "sexualiserbar",
    "sexualiserbarare": "sexualiserbar",
    "sexualiserbarares": "sexualiserbar",
    "sexualiserbaras": "sexualiserbar",
    "sexualiserbarast": "sexualiserbar",
    "sexualiserbaraste": "sexualiserbar",
    "sexualiserbarastes": "sexualiserbar",
    "sexualiserbarasts": "sexualiserbar",
    "sexualiserbare": "sexualiserbar",
    "sexualiserbares": "sexualiserbar",
    "sexualiserbarheten": "sexualiserbarhet",
    "sexualiserbarhetens": "sexualiserbarhet",
    "sexualiserbarhets": "sexualiserbarhet",
    "sexualiserbars": "sexualiserbar",
    "sexualiserbart": "sexualiserbar",
    "sexualiserbarts": "sexualiserbar",
    "sexualiseringar": "sexualisering",
    "sexualiseringarna": "sexualisering",
    "sexualiseringarnas": "sexualisering",
    "sexualiseringars": "sexualisering",
    "sexualiseringen": "sexualisering",
    "sexualiseringens": "sexualisering",
    "sexualiserings": "sexualisering",
    "sexualiteten": "sexualitet",
    "sexualitetens": "sexualitet",
    "sexualiteter": "sexualitet",
    "sexualiteterna": "sexualitet",
    "sexualiteternas": "sexualitet",
    "sexualiteters": "sexualitet",
    "sexualitets": "sexualitet",
    "sexualkunskapen": "sexualkunskap",
    "sexualkunskapens": "sexualkunskap",
    "sexualkunskaps": "sexualkunskap",
    "sexuallivet": "sexualliv",
    "sexuallivets": "sexualliv",
    "sexuallivs": "sexualliv",
    "sexualmorden": "sexualmord",
    "sexualmordens": "sexualmord",
    "sexualmordet": "sexualmord",
    "sexualmordets": "sexualmord",
    "sexualmords": "sexualmord",
    "sexualorganen": "sexualorgan",
    "sexualorganens": "sexualorgan",
    "sexualorganet": "sexualorgan",
    "sexualorganets": "sexualorgan",
    "sexualorgans": "sexualorgan",
    "sexualradikaliteten": "sexualradikalitet",
    "sexualradikalitetens": "sexualradikalitet",
    "sexualradikalitets": "sexualradikalitet",
    "sexualsystemet": "sexualsystem",
    "sexualsystemets": "sexualsystem",
    "sexualsystems": "sexualsystem",
    "sexualupplysningar": "sexualupplysning",
    "sexualupplysningarna": "sexualupplysning",
    "sexualupplysningarnas": "sexualupplysning",
    "sexualupplysningars": "sexualupplysning",
    "sexualupplysningen": "sexualupplysning",
    "sexualupplysningens": "sexualupplysning",
    "sexualupplysnings": "sexualupplysning",
    "sexuella": "sexuell",
    "sexuellare": "sexuell",
    "sexuellares": "sexuell",
    "sexuellas": "sexuell",
    "sexuellast": "sexuell",
    "sexuellaste": "sexuell",
    "sexuellastes": "sexuell",
    "sexuellasts": "sexuell",
    "sexuelle": "sexuell",
    "sexuelles": "sexuell",
    "sexuells": "sexuell",
    "sexuellt": "sexuell",
    "sexuellts": "sexuell",
    "sexuologien": "sexuologi",
    "sexuologiens": "sexuologi",
    "sexuologin": "sexuologi",
    "sexuologins": "sexuologi",
    "sexuologis": "sexuologi",
    "sexutnyttjad": "sexutnyttja",
    "sexutnyttjade": "sexutnyttja",
    "sexutnyttjades": "sexutnyttja",
    "sexutnyttjads": "sexutnyttja",
    "sexutnyttjande": "sexutnyttja",
    "sexutnyttjanden": "sexutnyttjande",
    "sexutnyttjandena": "sexutnyttjande",
    "sexutnyttjandenas": "sexutnyttjande",
    "sexutnyttjandens": "sexutnyttjande",
    "sexutnyttjandes": "sexutnyttjande",
    "sexutnyttjandet": "sexutnyttjande",
    "sexutnyttjandets": "sexutnyttjande",
    "sexutnyttjar": "sexutnyttja",
    "sexutnyttjas": "sexutnyttja",
    "sexutnyttjat": "sexutnyttja",
    "sexutnyttjats": "sexutnyttja",
    "sexåriga": "sexårig",
    "sexårigas": "sexårig",
    "sexårige": "sexårig",
    "sexåriges": "sexårig",
    "sexårigs": "sexårig",
    "sexårigt": "sexårig",
    "sexårigts": "sexårig",
    "sexåringar": "sexåring",
    "sexåringarna": "sexåring",
    "sexåringarnas": "sexåring",
    "sexåringars": "sexåring",
    "sexåringen": "sexåring",
    "sexåringens": "sexåring",
    "sexårings": "sexåring",
    "sexårsperioden": "sexårsperiod",
    "sexårsperiodens": "sexårsperiod",
    "sexårsperioder": "sexårsperiod",
    "sexårsperioderna": "sexårsperiod",
    "sexårsperiodernas": "sexårsperiod",
    "sexårsperioders": "sexårsperiod",
    "sexårsperiods": "sexårsperiod",
    "seychelliern": "seychellier",
    "seychellierna": "seychellier",
    "seychelliernas": "seychellier",
    "seychellierns": "seychellier",
    "seychelliers": "seychellier",
    "seychelliska": "seychellisk",
    "seychelliskan": "seychelliska",
    "seychelliskans": "seychelliska",
    "seychelliskare": "seychellisk",
    "seychelliskares": "seychellisk",
    "seychelliskas": "seychelliska",
    "seychelliskast": "seychellisk",
    "seychelliskaste": "seychellisk",
    "seychelliskastes": "seychellisk",
    "seychelliskasts": "seychellisk",
    "seychelliske": "seychelliska",
    "seychelliskes": "seychellisk",
    "seychelliskor": "seychelliska",
    "seychelliskorna": "seychelliska",
    "seychelliskornas": "seychelliska",
    "seychelliskors": "seychelliska",
    "seychellisks": "seychellisk",
    "seychelliskt": "seychellisk",
    "seychelliskts": "seychellisk",
    "señor": "señora",
    "señoran": "señora",
    "señorans": "señora",
    "señoras": "señora",
    "señore": "señora",
    "señoren": "señor",
    "señorens": "señor",
    "señorer": "señor",
    "señorerna": "señor",
    "señorernas": "señor",
    "señorers": "señor",
    "señorit": "señorita",
    "señoritan": "señorita",
    "señoritans": "señorita",
    "señoritas": "señorita",
    "señorite": "señorita",
    "señoritor": "señorita",
    "señoritorna": "señorita",
    "señoritornas": "señorita",
    "señoritors": "señorita",
    "señorits": "señorita",
    "señoror": "señora",
    "señororna": "señora",
    "señorornas": "señora",
    "señorors": "señora",
    "señors": "señora",
    "sfinxen": "sfinx",
    "sfinxens": "sfinx",
    "sfinxer": "sfinx",
    "sfinxerna": "sfinx",
    "sfinxernas": "sfinx",
    "sfinxers": "sfinx",
    "sfragistiken": "sfragistik",
    "sfragistikens": "sfragistik",
    "sfragistiks": "sfragistik",
    "sfumatos": "sfumato",
    "sfären": "sfär",
    "sfärens": "sfär",
    "sfärer": "sfär",
    "sfärerna": "sfär",
    "sfärernas": "sfär",
    "sfärers": "sfär",
    "sfäriska": "sfärisk",
    "sfäriskare": "sfärisk",
    "sfäriskares": "sfärisk",
    "sfäriskas": "sfärisk",
    "sfäriskast": "sfärisk",
    "sfäriskaste": "sfärisk",
    "sfäriskastes": "sfärisk",
    "sfäriskasts": "sfärisk",
    "sfäriske": "sfärisk",
    "sfäriskes": "sfärisk",
    "sfärisks": "sfärisk",
    "sfäriskt": "sfärisk",
    "sfäriskts": "sfärisk",
    "sfäroiden": "sfäroid",
    "sfäroidens": "sfäroid",
    "sfäroider": "sfäroid",
    "sfäroiderna": "sfäroid",
    "sfäroidernas": "sfäroid",
    "sfäroiders": "sfäroid",
    "sfäroids": "sfäroid",
    "sfärometern": "sfärometer",
    "sfärometerns": "sfärometer",
    "sfärometers": "sfärometer",
    "sfärometrar": "sfärometer",
    "sfärometrarna": "sfärometer",
    "sfärometrarnas": "sfärometer",
    "sfärometrars": "sfärometer",
    "sfärs": "sfär",
    "sgraffitos": "sgraffito",
    "shagen": "shag",
    "shagens": "shag",
    "shags": "shag",
    "shahen": "shah",
    "shahens": "shah",
    "shaher": "shah",
    "shaherna": "shah",
    "shahernas": "shah",
    "shahers": "shah",
    "shahs": "shah",
    "shakade": "shaka",
    "shakades": "shaka",
    "shakande": "shaka",
    "shakanden": "shakande",
    "shakandena": "shakande",
    "shakandenas": "shakande",
    "shakandens": "shakande",
    "shakandes": "shakande",
    "shakandet": "shakande",
    "shakandets": "shakande",
    "shakar": "shaka",
    "shakas": "shaka",
    "shakat": "shaka",
    "shakats": "shaka",
    "shaken": "shake",
    "shakens": "shake",
    "shakern": "shaker",
    "shakerna": "shaker",
    "shakernas": "shaker",
    "shakerns": "shaker",
    "shakers": "shaker",
    "shakersarna": "shaker",
    "shakersarnas": "shaker",
    "shakes": "shake",
    "shakrar": "shaker",
    "shakrarna": "shaker",
    "shakrarnas": "shaker",
    "shakrars": "shaker",
    "shaktin": "shakti",
    "shaktins": "shakti",
    "shaktis": "shakti",
    "shamanen": "shaman",
    "shamanens": "shaman",
    "shamaner": "shaman",
    "shamanerna": "shaman",
    "shamanernas": "shaman",
    "shamaners": "shaman",
    "shamanismen": "shamanism",
    "shamanismens": "shamanism",
    "shamanismer": "shamanism",
    "shamanismerna": "shamanism",
    "shamanismernas": "shamanism",
    "shamanismers": "shamanism",
    "shamanisms": "shamanism",
    "shamans": "shaman",
    "shamponerad": "shamponera",
    "shamponerade": "shamponera",
    "shamponerades": "shamponera",
    "shamponerads": "shamponera",
    "shamponerande": "shamponera",
    "shamponeranden": "shamponerande",
    "shamponerandena": "shamponerande",
    "shamponerandenas": "shamponerande",
    "shamponerandens": "shamponerande",
    "shamponerandes": "shamponerande",
    "shamponerandet": "shamponerande",
    "shamponerandets": "shamponerande",
    "shamponerar": "shamponera",
    "shamponeras": "shamponera",
    "shamponerat": "shamponera",
    "shamponerats": "shamponera",
    "shamponerbara": "shamponerbar",
    "shamponerbarare": "shamponerbar",
    "shamponerbarares": "shamponerbar",
    "shamponerbaras": "shamponerbar",
    "shamponerbarast": "shamponerbar",
    "shamponerbaraste": "shamponerbar",
    "shamponerbarastes": "shamponerbar",
    "shamponerbarasts": "shamponerbar",
    "shamponerbare": "shamponerbar",
    "shamponerbares": "shamponerbar",
    "shamponerbarheten": "shamponerbarhet",
    "shamponerbarhetens": "shamponerbarhet",
    "shamponerbarhets": "shamponerbarhet",
    "shamponerbars": "shamponerbar",
    "shamponerbart": "shamponerbar",
    "shamponerbarts": "shamponerbar",
    "shamponeringar": "shamponering",
    "shamponeringarna": "shamponering",
    "shamponeringarnas": "shamponering",
    "shamponeringars": "shamponering",
    "shamponeringen": "shamponering",
    "shamponeringens": "shamponering",
    "shamponerings": "shamponering",
    "shampoon": "shampoo",
    "shampoona": "shampoo",
    "shampoonas": "shampoo",
    "shampoons": "shampoo",
    "shampoos": "shampoo",
    "shampoot": "shampoo",
    "shampoots": "shampoo",
    "shanghajad": "shanghaja",
    "shanghajade": "shanghaja",
    "shanghajades": "shanghaja",
    "shanghajads": "shanghaja",
    "shanghajande": "shanghaja",
    "shanghajanden": "shanghajande",
    "shanghajandena": "shanghajande",
    "shanghajandenas": "shanghajande",
    "shanghajandens": "shanghajande",
    "shanghajandes": "shanghajande",
    "shanghajandet": "shanghajande",
    "shanghajandets": "shanghajande",
    "shanghajar": "shanghaja",
    "shanghajas": "shanghaja",
    "shanghajat": "shanghaja",
    "shanghajats": "shanghaja",
    "shanties": "shanty",
    "shantiesarna": "shanty",
    "shantiesarnas": "shanty",
    "shantungen": "shantung",
    "shantungens": "shantung",
    "shantungs": "shantung",
    "shantyn": "shanty",
    "shantyns": "shanty",
    "shantys": "shanty",
    "shejken": "shejk",
    "shejkens": "shejk",
    "shejker": "shejk",
    "shejkerna": "shejk",
    "shejkernas": "shejk",
    "shejkers": "shejk",
    "shejks": "shejk",
    "shelfen": "shelf",
    "shelfens": "shelf",
    "shelfisen": "shelfis",
    "shelfisens": "shelfis",
    "shelfs": "shelf",
    "shellacken": "shellack",
    "shellackens": "shellack",
    "shellacker": "shellack",
    "shellackerna": "shellack",
    "shellackernas": "shellack",
    "shellackers": "shellack",
    "shellacket": "shellack",
    "shellackets": "shellack",
    "shellacks": "shellack",
    "shelterdäcken": "shelterdäck",
    "shelterdäckens": "shelterdäck",
    "shelterdäcket": "shelterdäck",
    "shelterdäckets": "shelterdäck",
    "shelterdäcks": "shelterdäck",
    "sheriffen": "sheriff",
    "sheriffens": "sheriff",
    "sheriffer": "sheriff",
    "sherifferna": "sheriff",
    "sheriffernas": "sheriff",
    "sheriffers": "sheriff",
    "sheriffs": "sheriff",
    "sherpan": "sherpa",
    "sherpans": "sherpa",
    "sherpas": "sherpa",
    "sherpor": "sherpa",
    "sherporna": "sherpa",
    "sherpornas": "sherpa",
    "sherpors": "sherpa",
    "sherryn": "sherry",
    "sherryns": "sherry",
    "sherrys": "sherry",
    "shetlandsponnier": "shetlandsponny",
    "shetlandsponnierna": "shetlandsponny",
    "shetlandsponniernas": "shetlandsponny",
    "shetlandsponniers": "shetlandsponny",
    "shetlandsponnies": "shetlandsponny",
    "shetlandsponniesarna": "shetlandsponny",
    "shetlandsponniesarnas": "shetlandsponny",
    "shetlandsponnyer": "shetlandsponny",
    "shetlandsponnyerna": "shetlandsponny",
    "shetlandsponnyernas": "shetlandsponny",
    "shetlandsponnyers": "shetlandsponny",
    "shetlandsponnyn": "shetlandsponny",
    "shetlandsponnyns": "shetlandsponny",
    "shetlandsponnys": "shetlandsponny",
    "shetlandsponnysar": "shetlandsponny",
    "shetlandsponnysarna": "shetlandsponny",
    "shetlandsponnysarnas": "shetlandsponny",
    "shetlandsponnysars": "shetlandsponny",
    "shetlandströj": "shetlandströja",
    "shetlandströjan": "shetlandströja",
    "shetlandströjans": "shetlandströja",
    "shetlandströjas": "shetlandströja",
    "shetlandströje": "shetlandströja",
    "shetlandströjor": "shetlandströja",
    "shetlandströjorna": "shetlandströja",
    "shetlandströjornas": "shetlandströja",
    "shetlandströjors": "shetlandströja",
    "shetlandströjs": "shetlandströja",
    "shetlandsullen": "shetlandsull",
    "shetlandsullens": "shetlandsull",
    "shetlandsulls": "shetlandsull",
    "shetländska": "shetländsk",
    "shetländskare": "shetländsk",
    "shetländskares": "shetländsk",
    "shetländskas": "shetländsk",
    "shetländskast": "shetländsk",
    "shetländskaste": "shetländsk",
    "shetländskastes": "shetländsk",
    "shetländskasts": "shetländsk",
    "shetländske": "shetländsk",
    "shetländskes": "shetländsk",
    "shetländsks": "shetländsk",
    "shetländskt": "shetländsk",
    "shetländskts": "shetländsk",
    "shiamuslimen": "shiamuslim",
    "shiamuslimens": "shiamuslim",
    "shiamuslimer": "shiamuslim",
    "shiamuslimerna": "shiamuslim",
    "shiamuslimernas": "shiamuslim",
    "shiamuslimers": "shiamuslim",
    "shiamuslims": "shiamuslim",
    "shiamuslimska": "shiamuslimsk",
    "shiamuslimskas": "shiamuslimsk",
    "shiamuslimske": "shiamuslimsk",
    "shiamuslimskes": "shiamuslimsk",
    "shiamuslimsks": "shiamuslimsk",
    "shiamuslimskt": "shiamuslimsk",
    "shiamuslimskts": "shiamuslimsk",
    "shias": "shia",
    "shiiten": "shiit",
    "shiitens": "shiit",
    "shiiter": "shiit",
    "shiiterna": "shiit",
    "shiiternas": "shiit",
    "shiiters": "shiit",
    "shiitiska": "shiitisk",
    "shiitiskas": "shiitisk",
    "shiitiske": "shiitisk",
    "shiitiskes": "shiitisk",
    "shiitisks": "shiitisk",
    "shiitiskt": "shiitisk",
    "shiitiskts": "shiitisk",
    "shiits": "shiit",
    "shillingen": "shilling",
    "shillingens": "shilling",
    "shillings": "shilling",
    "shillingsen": "shilling",
    "shillingsens": "shilling",
    "shingel": "shingla",
    "shingeln": "shingel",
    "shingelns": "shingel",
    "shingels": "shingel",
    "shinglad": "shingla",
    "shinglade": "shingla",
    "shinglades": "shingla",
    "shinglads": "shingla",
    "shinglande": "shingla",
    "shinglanden": "shinglande",
    "shinglandena": "shinglande",
    "shinglandenas": "shinglande",
    "shinglandens": "shinglande",
    "shinglandes": "shinglande",
    "shinglandet": "shinglande",
    "shinglandets": "shinglande",
    "shinglar": "shingla",
    "shinglas": "shingla",
    "shinglat": "shingla",
    "shinglats": "shingla",
    "shintoismen": "shintoism",
    "shintoismens": "shintoism",
    "shintoismer": "shintoism",
    "shintoismerna": "shintoism",
    "shintoismernas": "shintoism",
    "shintoismers": "shintoism",
    "shintoisms": "shintoism",
    "shintoistiska": "shintoistisk",
    "shintoistiskas": "shintoistisk",
    "shintoistiske": "shintoistisk",
    "shintoistiskes": "shintoistisk",
    "shintoistisks": "shintoistisk",
    "shintoistiskt": "shintoistisk",
    "shintoistiskts": "shintoistisk",
    "shippingen": "shipping",
    "shippingens": "shipping",
    "shippings": "shipping",
    "shirtingen": "shirting",
    "shirtingens": "shirting",
    "shirtings": "shirting",
    "shoddyn": "shoddy",
    "shoddyns": "shoddy",
    "shoddys": "shoddy",
    "shoguner": "shogun",
    "shogunerna": "shogun",
    "shogunernas": "shogun",
    "shoguners": "shogun",
    "shoguns": "shogun",
    "shopar": "shop",
    "shoparna": "shop",
    "shoparnas": "shop",
    "shopars": "shop",
    "shopen": "shop",
    "shopens": "shop",
    "shoppade": "shoppa",
    "shoppades": "shoppa",
    "shoppande": "shoppa",
    "shoppanden": "shoppande",
    "shoppandena": "shoppande",
    "shoppandenas": "shoppande",
    "shoppandens": "shoppande",
    "shoppandes": "shoppande",
    "shoppandet": "shoppande",
    "shoppandets": "shoppande",
    "shoppar": "shoppa",
    "shoppas": "shoppa",
    "shoppat": "shoppa",
    "shoppats": "shoppa",
    "shoppingcenters": "shoppingcenter",
    "shoppingcentra": "shoppingcentrum",
    "shoppingcentrana": "shoppingcentrum",
    "shoppingcentranas": "shoppingcentrum",
    "shoppingcentras": "shoppingcentrum",
    "shoppingcentrer": "shoppingcentrum",
    "shoppingcentrerna": "shoppingcentrum",
    "shoppingcentrernas": "shoppingcentrum",
    "shoppingcentrers": "shoppingcentrum",
    "shoppingcentret": "shoppingcentrum",
    "shoppingcentrets": "shoppingcentrum",
    "shoppingcentrumen": "shoppingcentrum",
    "shoppingcentrumens": "shoppingcentrum",
    "shoppingcentrumet": "shoppingcentrum",
    "shoppingcentrumets": "shoppingcentrum",
    "shoppingcentrums": "shoppingcentrum",
    "shoppingen": "shopping",
    "shoppingens": "shopping",
    "shoppinggallerian": "shoppinggalleria",
    "shoppinggallerians": "shoppinggalleria",
    "shoppinggallerias": "shoppinggalleria",
    "shoppinggallerior": "shoppinggalleria",
    "shoppinggalleriorna": "shoppinggalleria",
    "shoppinggalleriornas": "shoppinggalleria",
    "shoppinggalleriors": "shoppinggalleria",
    "shoppings": "shopping",
    "shoppingturen": "shoppingtur",
    "shoppingturens": "shoppingtur",
    "shoppingturer": "shoppingtur",
    "shoppingturerna": "shoppingtur",
    "shoppingturernas": "shoppingtur",
    "shoppingturers": "shoppingtur",
    "shoppingturs": "shoppingtur",
    "shoppingvagnar": "shoppingvagn",
    "shoppingvagnarna": "shoppingvagn",
    "shoppingvagnarnas": "shoppingvagn",
    "shoppingvagnars": "shoppingvagn",
    "shoppingvagnen": "shoppingvagn",
    "shoppingvagnens": "shoppingvagn",
    "shoppingvagns": "shoppingvagn",
    "shoppingväsk": "shoppingväska",
    "shoppingväskan": "shoppingväska",
    "shoppingväskans": "shoppingväska",
    "shoppingväskas": "shoppingväska",
    "shoppingväske": "shoppingväska",
    "shoppingväskor": "shoppingväska",
    "shoppingväskorna": "shoppingväska",
    "shoppingväskornas": "shoppingväska",
    "shoppingväskors": "shoppingväska",
    "shops": "shop",
    "shortad": "shorta",
    "shortade": "shorta",
    "shortades": "shorta",
    "shortads": "shorta",
    "shortande": "shorta",
    "shortanden": "shortande",
    "shortandena": "shortande",
    "shortandenas": "shortande",
    "shortandens": "shortande",
    "shortandes": "shortande",
    "shortandet": "shortande",
    "shortandets": "shortande",
    "shortar": "shorta",
    "shortas": "shorta",
    "shortat": "shorta",
    "shortats": "shorta",
    "shortingar": "shorting",
    "shortingarna": "shorting",
    "shortingarnas": "shorting",
    "shortingars": "shorting",
    "shortingen": "shorting",
    "shortingens": "shorting",
    "shortings": "shorting",
    "shortningar": "shortning",
    "shortningarna": "shortning",
    "shortningarnas": "shortning",
    "shortningars": "shortning",
    "shortningen": "shortning",
    "shortningens": "shortning",
    "shortnings": "shortning",
    "shortsen": "shorts",
    "shortsens": "shorts",
    "showade": "showa",
    "showades": "showa",
    "showande": "showa",
    "showanden": "showande",
    "showandena": "showande",
    "showandenas": "showande",
    "showandens": "showande",
    "showandes": "showande",
    "showandet": "showande",
    "showandets": "showande",
    "showar": "showa",
    "showas": "showa",
    "showat": "showa",
    "showats": "showa",
    "showbizen": "showbiz",
    "showbizens": "showbiz",
    "showen": "show",
    "showens": "show",
    "shower": "show",
    "showerna": "show",
    "showernas": "show",
    "showers": "show",
    "showmässiga": "showmässig",
    "showmässigare": "showmässig",
    "showmässigares": "showmässig",
    "showmässigas": "showmässig",
    "showmässigast": "showmässig",
    "showmässigaste": "showmässig",
    "showmässigastes": "showmässig",
    "showmässigasts": "showmässig",
    "showmässige": "showmässig",
    "showmässiges": "showmässig",
    "showmässigs": "showmässig",
    "showmässigt": "showmässig",
    "showmässigts": "showmässig",
    "shows": "show",
    "showvärdar": "showvärd",
    "showvärdarna": "showvärd",
    "showvärdarnas": "showvärd",
    "showvärdars": "showvärd",
    "showvärden": "showvärd",
    "showvärdens": "showvärd",
    "showvärdinnan": "showvärdinna",
    "showvärdinnans": "showvärdinna",
    "showvärdinnas": "showvärdinna",
    "showvärdinne": "showvärdinna",
    "showvärdinnor": "showvärdinna",
    "showvärdinnorna": "showvärdinna",
    "showvärdinnornas": "showvärdinna",
    "showvärdinnors": "showvärdinna",
    "showvärds": "showvärd",
    "shuffle-boarden": "shuffle-board",
    "shuffle-boardens": "shuffle-board",
    "shuffle-boardet": "shuffle-board",
    "shuffle-boardets": "shuffle-board",
    "shuffle-boards": "shuffle-board",
    "shunt": "shunta",
    "shuntad": "shunta",
    "shuntade": "shunta",
    "shuntades": "shunta",
    "shuntads": "shunta",
    "shuntande": "shunta",
    "shuntanden": "shuntande",
    "shuntandena": "shuntande",
    "shuntandenas": "shuntande",
    "shuntandens": "shuntande",
    "shuntandes": "shuntande",
    "shuntandet": "shuntande",
    "shuntandets": "shuntande",
    "shuntar": "shunta",
    "shuntarna": "shunt",
    "shuntarnas": "shunt",
    "shuntars": "shunt",
    "shuntas": "shunta",
    "shuntat": "shunta",
    "shuntats": "shunta",
    "shunten": "shunt",
    "shuntens": "shunt",
    "shuntkopplingar": "shuntkoppling",
    "shuntkopplingarna": "shuntkoppling",
    "shuntkopplingarnas": "shuntkoppling",
    "shuntkopplingars": "shuntkoppling",
    "shuntkopplingen": "shuntkoppling",
    "shuntkopplingens": "shuntkoppling",
    "shuntkopplings": "shuntkoppling",
    "shunts": "shunt",
    "shuntventilen": "shuntventil",
    "shuntventilens": "shuntventil",
    "shuntventiler": "shuntventil",
    "shuntventilerna": "shuntventil",
    "shuntventilernas": "shuntventil",
    "shuntventilers": "shuntventil",
    "shuntventils": "shuntventil",
    "siade": "sia",
    "siades": "sia",
    "sialen": "sial",
    "sialens": "sial",
    "sials": "sial",
    "siamesen": "siames",
    "siamesens": "siames",
    "siameser": "siames",
    "siameserna": "siames",
    "siamesernas": "siames",
    "siamesers": "siames",
    "siamesiska": "siamesisk",
    "siamesiskare": "siamesisk",
    "siamesiskares": "siamesisk",
    "siamesiskas": "siamesisk",
    "siamesiskast": "siamesisk",
    "siamesiskaste": "siamesisk",
    "siamesiskastes": "siamesisk",
    "siamesiskasts": "siamesisk",
    "siamesiske": "siamesisk",
    "siamesiskes": "siamesisk",
    "siamesisks": "siamesisk",
    "siamesiskt": "siamesisk",
    "siamesiskts": "siamesisk",
    "siameskatten": "siameskatt",
    "siameskattens": "siameskatt",
    "siameskatter": "siameskatt",
    "siameskatterna": "siameskatt",
    "siameskatternas": "siameskatt",
    "siameskatters": "siameskatt",
    "siameskatts": "siameskatt",
    "siande": "sia",
    "sianden": "siande",
    "siandena": "siande",
    "siandenas": "siande",
    "siandens": "siande",
    "siandes": "siande",
    "siandet": "siande",
    "siandets": "siande",
    "siar": "siare",
    "siaren": "siare",
    "siarens": "siare",
    "siares": "siare",
    "siarna": "siare",
    "siarnas": "siare",
    "sias": "sia",
    "siat": "sia",
    "siats": "sia",
    "sibetdjuren": "sibetdjur",
    "sibetdjurens": "sibetdjur",
    "sibetdjuret": "sibetdjur",
    "sibetdjurets": "sibetdjur",
    "sibetdjurs": "sibetdjur",
    "sibeten": "sibet",
    "sibetens": "sibet",
    "sibeter": "sibet",
    "sibeterna": "sibet",
    "sibeternas": "sibet",
    "sibeters": "sibet",
    "sibetkatten": "sibetkatt",
    "sibetkattens": "sibetkatt",
    "sibetkatter": "sibetkatt",
    "sibetkatterna": "sibetkatt",
    "sibetkatternas": "sibetkatt",
    "sibetkatters": "sibetkatt",
    "sibetkatts": "sibetkatt",
    "sibetoljan": "sibetolja",
    "sibetoljans": "sibetolja",
    "sibetoljas": "sibetolja",
    "sibetolje": "sibetolja",
    "sibets": "sibet",
    "sibiriern": "sibirier",
    "sibirierna": "sibirier",
    "sibiriernas": "sibirier",
    "sibirierns": "sibirier",
    "sibiriers": "sibirier",
    "sibiriska": "sibirisk",
    "sibiriskare": "sibirisk",
    "sibiriskares": "sibirisk",
    "sibiriskas": "sibirisk",
    "sibiriskast": "sibirisk",
    "sibiriskaste": "sibirisk",
    "sibiriskastes": "sibirisk",
    "sibiriskasts": "sibirisk",
    "sibiriske": "sibirisk",
    "sibiriskes": "sibirisk",
    "sibirisks": "sibirisk",
    "sibiriskt": "sibirisk",
    "sibiriskts": "sibirisk",
    "sibyll": "sibylla",
    "sibyllan": "sibylla",
    "sibyllans": "sibylla",
    "sibyllas": "sibylla",
    "sibylle": "sibylla",
    "sibyllinska": "sibyllinsk",
    "sibyllinskare": "sibyllinsk",
    "sibyllinskares": "sibyllinsk",
    "sibyllinskas": "sibyllinsk",
    "sibyllinskast": "sibyllinsk",
    "sibyllinskaste": "sibyllinsk",
    "sibyllinskastes": "sibyllinsk",
    "sibyllinskasts": "sibyllinsk",
    "sibyllinske": "sibyllinsk",
    "sibyllinskes": "sibyllinsk",
    "sibyllinsks": "sibyllinsk",
    "sibyllinskt": "sibyllinsk",
    "sibyllinskts": "sibyllinsk",
    "sibyllor": "sibylla",
    "sibyllorna": "sibylla",
    "sibyllornas": "sibylla",
    "sibyllors": "sibylla",
    "sibylls": "sibylla",
    "sicilianar": "sicilianare",
    "sicilianaren": "sicilianare",
    "sicilianarens": "sicilianare",
    "sicilianares": "sicilianare",
    "sicilianarna": "sicilianare",
    "sicilianarnas": "sicilianare",
    "sicilianen": "sicilian",
    "sicilianens": "sicilian",
    "sicilianer": "sicilian",
    "sicilianerna": "sicilian",
    "sicilianernas": "sicilian",
    "sicilianers": "sicilian",
    "sicilians": "sicilian",
    "sicilianska": "siciliansk",
    "sicilianskan": "sicilianska",
    "sicilianskans": "sicilianska",
    "sicilianskare": "siciliansk",
    "sicilianskares": "siciliansk",
    "sicilianskas": "sicilianska",
    "sicilianskast": "siciliansk",
    "sicilianskaste": "siciliansk",
    "sicilianskastes": "siciliansk",
    "sicilianskasts": "siciliansk",
    "sicilianske": "sicilianska",
    "sicilianskes": "siciliansk",
    "sicilianskor": "sicilianska",
    "sicilianskorna": "sicilianska",
    "sicilianskornas": "sicilianska",
    "sicilianskors": "sicilianska",
    "siciliansks": "siciliansk",
    "sicilianskt": "siciliansk",
    "sicilianskts": "siciliansk",
    "sickad": "sicka",
    "sickade": "sicka",
    "sickades": "sicka",
    "sickads": "sicka",
    "sickande": "sicka",
    "sickanden": "sickande",
    "sickandena": "sickande",
    "sickandenas": "sickande",
    "sickandens": "sickande",
    "sickandes": "sickande",
    "sickandet": "sickande",
    "sickandets": "sickande",
    "sickar": "sicka",
    "sickarna": "sick",
    "sickarnas": "sick",
    "sickars": "sick",
    "sickas": "sicka",
    "sickat": "sicka",
    "sickativen": "sickativ",
    "sickativens": "sickativ",
    "sickativet": "sickativ",
    "sickativets": "sickativ",
    "sickativs": "sickativ",
    "sickats": "sicka",
    "sickeln": "sickel",
    "sickelns": "sickel",
    "sickels": "sickel",
    "sicken": "sick",
    "sickens": "sicken",
    "sicket": "sicken",
    "sickets": "sicken",
    "sicklad": "sickla",
    "sicklade": "sickla",
    "sicklades": "sickla",
    "sicklads": "sickla",
    "sicklande": "sickla",
    "sicklanden": "sicklande",
    "sicklandena": "sicklande",
    "sicklandenas": "sicklande",
    "sicklandens": "sicklande",
    "sicklandes": "sicklande",
    "sicklandet": "sicklande",
    "sicklandets": "sicklande",
    "sicklar": "sickla",
    "sicklarna": "sickel",
    "sicklarnas": "sickel",
    "sicklars": "sickel",
    "sicklas": "sickla",
    "sicklat": "sickla",
    "sicklats": "sickla",
    "sicklecellsanemien": "sicklecellsanemi",
    "sicklecellsanemiens": "sicklecellsanemi",
    "sicklecellsanemin": "sicklecellsanemi",
    "sicklecellsanemins": "sicklecellsanemi",
    "sicklecellsanemis": "sicklecellsanemi",
    "sicklingar": "sickling",
    "sicklingarna": "sickling",
    "sicklingarnas": "sickling",
    "sicklingars": "sickling",
    "sicklingen": "sickling",
    "sicklingens": "sickling",
    "sicklings": "sickling",
    "sickna": "sicken",
    "sicknare": "sicken",
    "sicknares": "sicken",
    "sicknas": "sicken",
    "sicknast": "sicken",
    "sicknaste": "sicken",
    "sicknastes": "sicken",
    "sicknasts": "sicken",
    "sickne": "sicken",
    "sicknes": "sicken",
    "sicks": "sick",
    "sicksackad": "sicksacka",
    "sicksackade": "sicksacka",
    "sicksackades": "sicksacka",
    "sicksackads": "sicksacka",
    "sicksackande": "sicksacka",
    "sicksackanden": "sicksackande",
    "sicksackandena": "sicksackande",
    "sicksackandenas": "sicksackande",
    "sicksackandens": "sicksackande",
    "sicksackandes": "sicksackande",
    "sicksackandet": "sicksackande",
    "sicksackandets": "sicksackande",
    "sicksackar": "sicksacka",
    "sicksackas": "sicksacka",
    "sicksackat": "sicksacka",
    "sicksackats": "sicksacka",
    "sicksacken": "sicksack",
    "sicksackens": "sicksack",
    "sicksacks": "sicksack",
    "sid": "sida",
    "sida": "sid",
    "sidan": "sida",
    "sidans": "sida",
    "sidare": "sid",
    "sidares": "sid",
    "sidas": "sida",
    "sidast": "sid",
    "sidaste": "sid",
    "sidastes": "sid",
    "sidasts": "sid",
    "sidben": "sidbena",
    "sidbenan": "sidbena",
    "sidbenans": "sidbena",
    "sidbenas": "sidbena",
    "sidbene": "sidbena",
    "sidbenor": "sidbena",
    "sidbenorna": "sidbena",
    "sidbenornas": "sidbena",
    "sidbenors": "sidbena",
    "sidbens": "sidbena",
    "sidbyten": "sidbyte",
    "sidbytena": "sidbyte",
    "sidbytenas": "sidbyte",
    "sidbytens": "sidbyte",
    "sidbytes": "sidbyte",
    "sidbytet": "sidbyte",
    "sidbytets": "sidbyte",
    "side": "sida",
    "sideboarden": "sideboard",
    "sideboardens": "sideboard",
    "sideboardet": "sideboard",
    "sideboardets": "sideboard",
    "sideboards": "sideboard",
    "sidenap": "sidenapa",
    "sidenapan": "sidenapa",
    "sidenapans": "sidenapa",
    "sidenapas": "sidenapa",
    "sidenape": "sidenapa",
    "sidenapor": "sidenapa",
    "sidenaporna": "sidenapa",
    "sidenapornas": "sidenapa",
    "sidenapors": "sidenapa",
    "sidenaps": "sidenapa",
    "sidendraperier": "sidendraperi",
    "sidendraperierna": "sidendraperi",
    "sidendraperiernas": "sidendraperi",
    "sidendraperiers": "sidendraperi",
    "sidendraperiet": "sidendraperi",
    "sidendraperiets": "sidendraperi",
    "sidendraperis": "sidendraperi",
    "sidendraperit": "sidendraperi",
    "sidendraperits": "sidendraperi",
    "sidenet": "siden",
    "sidenets": "siden",
    "sidenkuddar": "sidenkudde",
    "sidenkuddarna": "sidenkudde",
    "sidenkuddarnas": "sidenkudde",
    "sidenkuddars": "sidenkudde",
    "sidenkudden": "sidenkudde",
    "sidenkuddens": "sidenkudde",
    "sidenkuddes": "sidenkudde",
    "sidennäsdukar": "sidennäsduk",
    "sidennäsdukarna": "sidennäsduk",
    "sidennäsdukarnas": "sidennäsduk",
    "sidennäsdukars": "sidennäsduk",
    "sidennäsduken": "sidennäsduk",
    "sidennäsdukens": "sidennäsduk",
    "sidennäsduks": "sidennäsduk",
    "sidenrosen": "sidenros",
    "sidenrosens": "sidenros",
    "sidenrosor": "sidenros",
    "sidenrosorna": "sidenros",
    "sidenrosornas": "sidenros",
    "sidenrosors": "sidenros",
    "sidens": "siden",
    "sidenskärmar": "sidenskärm",
    "sidenskärmarna": "sidenskärm",
    "sidenskärmarnas": "sidenskärm",
    "sidenskärmars": "sidenskärm",
    "sidenskärmen": "sidenskärm",
    "sidenskärmens": "sidenskärm",
    "sidenskärms": "sidenskärm",
    "sidensvansar": "sidensvans",
    "sidensvansarna": "sidensvans",
    "sidensvansarnas": "sidensvans",
    "sidensvansars": "sidensvans",
    "sidensvansen": "sidensvans",
    "sidensvansens": "sidensvans",
    "sidentygen": "sidentyg",
    "sidentygens": "sidentyg",
    "sidentyger": "sidentyg",
    "sidentygerna": "sidentyg",
    "sidentygernas": "sidentyg",
    "sidentygers": "sidentyg",
    "sidentyget": "sidentyg",
    "sidentygets": "sidentyg",
    "sidentygs": "sidentyg",
    "sidenvita": "sidenvit",
    "sidenvitare": "sidenvit",
    "sidenvitares": "sidenvit",
    "sidenvitas": "sidenvit",
    "sidenvitast": "sidenvit",
    "sidenvitaste": "sidenvit",
    "sidenvitastes": "sidenvit",
    "sidenvitasts": "sidenvit",
    "sidenvite": "sidenvit",
    "sidenvites": "sidenvit",
    "sidenvits": "sidenvit",
    "sidenvitt": "sidenvit",
    "sidenvitts": "sidenvit",
    "sideriska": "siderisk",
    "sideriskare": "siderisk",
    "sideriskares": "siderisk",
    "sideriskas": "siderisk",
    "sideriskast": "siderisk",
    "sideriskaste": "siderisk",
    "sideriskastes": "siderisk",
    "sideriskasts": "siderisk",
    "sideriske": "siderisk",
    "sideriskes": "siderisk",
    "siderisks": "siderisk",
    "sideriskt": "siderisk",
    "sideriskts": "siderisk",
    "sideriten": "siderit",
    "sideritens": "siderit",
    "siderits": "siderit",
    "siderosen": "sideros",
    "siderosens": "sideros",
    "siderurgien": "siderurgi",
    "siderurgiens": "siderurgi",
    "siderurgin": "siderurgi",
    "siderurgins": "siderurgi",
    "siderurgis": "siderurgi",
    "sides": "sida",
    "sidfläsket": "sidfläsk",
    "sidfläskets": "sidfläsk",
    "sidfläsks": "sidfläsk",
    "sidiga": "sidig",
    "sidigare": "sidig",
    "sidigares": "sidig",
    "sidigas": "sidig",
    "sidigast": "sidig",
    "sidigaste": "sidig",
    "sidigastes": "sidig",
    "sidigasts": "sidig",
    "sidige": "sidig",
    "sidiges": "sidig",
    "sidigs": "sidig",
    "sidigt": "sidig",
    "sidigts": "sidig",
    "sidingar": "siding",
    "sidingarna": "siding",
    "sidingarnas": "siding",
    "sidingars": "siding",
    "sidingen": "siding",
    "sidingens": "siding",
    "sidings": "siding",
    "sidlinjen": "sidlinje",
    "sidlinjens": "sidlinje",
    "sidlinjer": "sidlinje",
    "sidlinjerna": "sidlinje",
    "sidlinjernas": "sidlinje",
    "sidlinjers": "sidlinje",
    "sidlinjes": "sidlinje",
    "sidlända": "sidländ",
    "sidländare": "sidländ",
    "sidländares": "sidländ",
    "sidländas": "sidländ",
    "sidländast": "sidländ",
    "sidländaste": "sidländ",
    "sidländastes": "sidländ",
    "sidländasts": "sidländ",
    "sidlände": "sidländ",
    "sidländes": "sidländ",
    "sidländs": "sidländ",
    "sidlänt": "sidländ",
    "sidlänta": "sidlänt",
    "sidläntare": "sidlänt",
    "sidläntares": "sidlänt",
    "sidläntas": "sidlänt",
    "sidläntast": "sidlänt",
    "sidläntaste": "sidlänt",
    "sidläntastes": "sidlänt",
    "sidläntasts": "sidlänt",
    "sidlänte": "sidlänt",
    "sidläntes": "sidlänt",
    "sidlänts": "sidlänt",
    "sidnummerna": "sidnummer",
    "sidnummernas": "sidnummer",
    "sidnummers": "sidnummer",
    "sidnumren": "sidnummer",
    "sidnumrens": "sidnummer",
    "sidnumrerad": "sidnumrera",
    "sidnumrerade": "sidnumrera",
    "sidnumrerades": "sidnumrera",
    "sidnumrerads": "sidnumrera",
    "sidnumrerande": "sidnumrera",
    "sidnumreranden": "sidnumrerande",
    "sidnumrerandena": "sidnumrerande",
    "sidnumrerandenas": "sidnumrerande",
    "sidnumrerandens": "sidnumrerande",
    "sidnumrerandes": "sidnumrerande",
    "sidnumrerandet": "sidnumrerande",
    "sidnumrerandets": "sidnumrerande",
    "sidnumrerar": "sidnumrera",
    "sidnumreras": "sidnumrera",
    "sidnumrerat": "sidnumrera",
    "sidnumrerats": "sidnumrera",
    "sidnumrerbara": "sidnumrerbar",
    "sidnumrerbarare": "sidnumrerbar",
    "sidnumrerbarares": "sidnumrerbar",
    "sidnumrerbaras": "sidnumrerbar",
    "sidnumrerbarast": "sidnumrerbar",
    "sidnumrerbaraste": "sidnumrerbar",
    "sidnumrerbarastes": "sidnumrerbar",
    "sidnumrerbarasts": "sidnumrerbar",
    "sidnumrerbare": "sidnumrerbar",
    "sidnumrerbares": "sidnumrerbar",
    "sidnumrerbarheten": "sidnumrerbarhet",
    "sidnumrerbarhetens": "sidnumrerbarhet",
    "sidnumrerbarhets": "sidnumrerbarhet",
    "sidnumrerbars": "sidnumrerbar",
    "sidnumrerbart": "sidnumrerbar",
    "sidnumrerbarts": "sidnumrerbar",
    "sidnumreringar": "sidnumrering",
    "sidnumreringarna": "sidnumrering",
    "sidnumreringarnas": "sidnumrering",
    "sidnumreringars": "sidnumrering",
    "sidnumreringen": "sidnumrering",
    "sidnumreringens": "sidnumrering",
    "sidnumrerings": "sidnumrering",
    "sidnumret": "sidnummer",
    "sidnumrets": "sidnummer",
    "sido": "sida",
    "sidoaltar": "sidoaltare",
    "sidoaltaren": "sidoaltare",
    "sidoaltarens": "sidoaltare",
    "sidoaltares": "sidoaltare",
    "sidoaltaret": "sidoaltare",
    "sidoaltarets": "sidoaltare",
    "sidoaltarna": "sidoaltare",
    "sidoaltarnas": "sidoaltare",
    "sidoapparaten": "sidoapparat",
    "sidoapparatens": "sidoapparat",
    "sidoapparater": "sidoapparat",
    "sidoapparaterna": "sidoapparat",
    "sidoapparaternas": "sidoapparat",
    "sidoapparaters": "sidoapparat",
    "sidoapparats": "sidoapparat",
    "sidoarven": "sidoarv",
    "sidoarvens": "sidoarv",
    "sidoarvet": "sidoarv",
    "sidoarvets": "sidoarv",
    "sidoarvingar": "sidoarvinge",
    "sidoarvingarna": "sidoarvinge",
    "sidoarvingarnas": "sidoarvinge",
    "sidoarvingars": "sidoarvinge",
    "sidoarvingen": "sidoarvinge",
    "sidoarvingens": "sidoarvinge",
    "sidoarvinges": "sidoarvinge",
    "sidoarvs": "sidoarv",
    "sidobanan": "sidobana",
    "sidobanans": "sidobana",
    "sidobanas": "sidobana",
    "sidobane": "sidobana",
    "sidobanor": "sidobana",
    "sidobanorna": "sidobana",
    "sidobanornas": "sidobana",
    "sidobanors": "sidobana",
    "sidobelysningar": "sidobelysning",
    "sidobelysningarna": "sidobelysning",
    "sidobelysningarnas": "sidobelysning",
    "sidobelysningars": "sidobelysning",
    "sidobelysningen": "sidobelysning",
    "sidobelysningens": "sidobelysning",
    "sidobelysnings": "sidobelysning",
    "sidoblickar": "sidoblick",
    "sidoblickarna": "sidoblick",
    "sidoblickarnas": "sidoblick",
    "sidoblickars": "sidoblick",
    "sidoblicken": "sidoblick",
    "sidoblickens": "sidoblick",
    "sidoblicks": "sidoblick",
    "sidoborden": "sidobord",
    "sidobordens": "sidobord",
    "sidobordet": "sidobord",
    "sidobordets": "sidobord",
    "sidobords": "sidobord",
    "sidobyggnaden": "sidobyggnad",
    "sidobyggnadens": "sidobyggnad",
    "sidobyggnader": "sidobyggnad",
    "sidobyggnaderna": "sidobyggnad",
    "sidobyggnadernas": "sidobyggnad",
    "sidobyggnaders": "sidobyggnad",
    "sidobyggnads": "sidobyggnad",
    "sidodalar": "sidodal",
    "sidodalarna": "sidodal",
    "sidodalarnas": "sidodal",
    "sidodalars": "sidodal",
    "sidodalen": "sidodal",
    "sidodalens": "sidodal",
    "sidodals": "sidodal",
    "sidodäcken": "sidodäck",
    "sidodäckens": "sidodäck",
    "sidodäcket": "sidodäck",
    "sidodäckets": "sidodäck",
    "sidodäcks": "sidodäck",
    "sidodörrar": "sidodörr",
    "sidodörrarna": "sidodörr",
    "sidodörrarnas": "sidodörr",
    "sidodörrars": "sidodörr",
    "sidodörren": "sidodörr",
    "sidodörrens": "sidodörr",
    "sidodörrs": "sidodörr",
    "sidoeffekten": "sidoeffekt",
    "sidoeffektens": "sidoeffekt",
    "sidoeffekter": "sidoeffekt",
    "sidoeffekterna": "sidoeffekt",
    "sidoeffekternas": "sidoeffekt",
    "sidoeffekters": "sidoeffekt",
    "sidoeffekts": "sidoeffekt",
    "sidoentréer": "sidoentré",
    "sidoentréerna": "sidoentré",
    "sidoentréernas": "sidoentré",
    "sidoentréers": "sidoentré",
    "sidoentrén": "sidoentré",
    "sidoentréns": "sidoentré",
    "sidoentrés": "sidoentré",
    "sidogat": "sidogata",
    "sidogatan": "sidogata",
    "sidogatans": "sidogata",
    "sidogatas": "sidogata",
    "sidogate": "sidogata",
    "sidogator": "sidogata",
    "sidogatorna": "sidogata",
    "sidogatornas": "sidogata",
    "sidogators": "sidogata",
    "sidogats": "sidogata",
    "sidogevären": "sidogevär",
    "sidogevärens": "sidogevär",
    "sidogeväret": "sidogevär",
    "sidogevärets": "sidogevär",
    "sidogevärs": "sidogevär",
    "sidohandtagen": "sidohandtag",
    "sidohandtagens": "sidohandtag",
    "sidohandtaget": "sidohandtag",
    "sidohandtagets": "sidohandtag",
    "sidohandtags": "sidohandtag",
    "sidohänsynen": "sidohänsyn",
    "sidohänsynens": "sidohänsyn",
    "sidohänsyns": "sidohänsyn",
    "sidoinflytandes": "sidoinflytande",
    "sidoinflytandet": "sidoinflytande",
    "sidoinflytandets": "sidoinflytande",
    "sidoingångar": "sidoingång",
    "sidoingångarna": "sidoingång",
    "sidoingångarnas": "sidoingång",
    "sidoingångars": "sidoingång",
    "sidoingången": "sidoingång",
    "sidoingångens": "sidoingång",
    "sidoingångs": "sidoingång",
    "sidoinkomsten": "sidoinkomst",
    "sidoinkomstens": "sidoinkomst",
    "sidoinkomster": "sidoinkomst",
    "sidoinkomsterna": "sidoinkomst",
    "sidoinkomsternas": "sidoinkomst",
    "sidoinkomsters": "sidoinkomst",
    "sidoinkomsts": "sidoinkomst",
    "sidojusteringar": "sidojustering",
    "sidojusteringarna": "sidojustering",
    "sidojusteringarnas": "sidojustering",
    "sidojusteringars": "sidojustering",
    "sidojusteringen": "sidojustering",
    "sidojusteringens": "sidojustering",
    "sidojusterings": "sidojustering",
    "sidolantern": "sidolanterna",
    "sidolanternan": "sidolanterna",
    "sidolanternans": "sidolanterna",
    "sidolanternas": "sidolanterna",
    "sidolanterne": "sidolanterna",
    "sidolanternor": "sidolanterna",
    "sidolanternorna": "sidolanterna",
    "sidolanternornas": "sidolanterna",
    "sidolanternors": "sidolanterna",
    "sidolanterns": "sidolanterna",
    "sidolinjen": "sidolinje",
    "sidolinjens": "sidolinje",
    "sidolinjeorganen": "sidolinjeorgan",
    "sidolinjeorganens": "sidolinjeorgan",
    "sidolinjeorganet": "sidolinjeorgan",
    "sidolinjeorganets": "sidolinjeorgan",
    "sidolinjeorgans": "sidolinjeorgan",
    "sidolinjer": "sidolinje",
    "sidolinjerna": "sidolinje",
    "sidolinjernas": "sidolinje",
    "sidolinjers": "sidolinje",
    "sidolinjes": "sidolinje",
    "sidoordnade": "sidoordnad",
    "sidoordnades": "sidoordnad",
    "sidoordnads": "sidoordnad",
    "sidoordnat": "sidoordnad",
    "sidoordnats": "sidoordnad",
    "sidoplanen": "sidoplan",
    "sidoplanens": "sidoplan",
    "sidoplanet": "sidoplan",
    "sidoplanets": "sidoplan",
    "sidoplans": "sidoplan",
    "sidor": "sida",
    "sidorna": "sida",
    "sidornas": "sida",
    "sidoroders": "sidoroder",
    "sidorodren": "sidoroder",
    "sidorodrens": "sidoroder",
    "sidorodret": "sidoroder",
    "sidorodrets": "sidoroder",
    "sidors": "sida",
    "sidoskeppen": "sidoskepp",
    "sidoskeppens": "sidoskepp",
    "sidoskeppet": "sidoskepp",
    "sidoskeppets": "sidoskepp",
    "sidoskepps": "sidoskepp",
    "sidoskotten": "sidoskott",
    "sidoskottens": "sidoskott",
    "sidoskottet": "sidoskott",
    "sidoskottets": "sidoskott",
    "sidoskotts": "sidoskott",
    "sidosprången": "sidosprång",
    "sidosprångens": "sidosprång",
    "sidosprånget": "sidosprång",
    "sidosprångets": "sidosprång",
    "sidosprångs": "sidosprång",
    "sidospåren": "sidospår",
    "sidospårens": "sidospår",
    "sidospåret": "sidospår",
    "sidospårets": "sidospår",
    "sidospårs": "sidospår",
    "sidoteman": "sidotema",
    "sidotemana": "sidotema",
    "sidotemanas": "sidotema",
    "sidotemans": "sidotema",
    "sidotemas": "sidotema",
    "sidotemat": "sidotema",
    "sidotemata": "sidotema",
    "sidotematana": "sidotema",
    "sidotematanas": "sidotema",
    "sidotematas": "sidotema",
    "sidotemats": "sidotema",
    "sidovapens": "sidovapen",
    "sidovapnen": "sidovapen",
    "sidovapnens": "sidovapen",
    "sidovapnet": "sidovapen",
    "sidovapnets": "sidovapen",
    "sidovinkeln": "sidovinkel",
    "sidovinkelns": "sidovinkel",
    "sidovinkels": "sidovinkel",
    "sidovinklar": "sidovinkel",
    "sidovinklarna": "sidovinkel",
    "sidovinklarnas": "sidovinkel",
    "sidovinklars": "sidovinkel",
    "sidovägar": "sidoväg",
    "sidovägarna": "sidoväg",
    "sidovägarnas": "sidoväg",
    "sidovägars": "sidoväg",
    "sidovägen": "sidoväg",
    "sidovägens": "sidoväg",
    "sidovägs": "sidoväg",
    "sidroderna": "sidroder",
    "sidrodernas": "sidroder",
    "sidroders": "sidroder",
    "sidrodren": "sidroder",
    "sidrodrens": "sidroder",
    "sidrodret": "sidroder",
    "sidrodrets": "sidroder",
    "sids": "sid",
    "sidskruvar": "sidskruv",
    "sidskruvarna": "sidskruv",
    "sidskruvarnas": "sidskruv",
    "sidskruvars": "sidskruv",
    "sidskruven": "sidskruv",
    "sidskruvens": "sidskruv",
    "sidskruvs": "sidskruv",
    "sidstepp": "sidsteppa",
    "sidsteppad": "sidsteppa",
    "sidsteppade": "sidsteppa",
    "sidsteppades": "sidsteppa",
    "sidsteppads": "sidsteppa",
    "sidsteppande": "sidsteppa",
    "sidsteppanden": "sidsteppande",
    "sidsteppandena": "sidsteppande",
    "sidsteppandenas": "sidsteppande",
    "sidsteppandens": "sidsteppande",
    "sidsteppandes": "sidsteppande",
    "sidsteppandet": "sidsteppande",
    "sidsteppandets": "sidsteppande",
    "sidsteppar": "sidsteppa",
    "sidsteppas": "sidsteppa",
    "sidsteppat": "sidsteppa",
    "sidsteppats": "sidsteppa",
    "sidvagnar": "sidvagn",
    "sidvagnarna": "sidvagn",
    "sidvagnarnas": "sidvagn",
    "sidvagnars": "sidvagn",
    "sidvagnen": "sidvagn",
    "sidvagnens": "sidvagn",
    "sidvagns": "sidvagn",
    "sidvallar": "sidvall",
    "sidvallarna": "sidvall",
    "sidvallarnas": "sidvall",
    "sidvallars": "sidvall",
    "sidvallen": "sidvall",
    "sidvallens": "sidvall",
    "sidvalls": "sidvall",
    "sidvördnaden": "sidvördnad",
    "sidvördnadens": "sidvördnad",
    "sidvördnader": "sidvördnad",
    "sidvördnaderna": "sidvördnad",
    "sidvördnadernas": "sidvördnad",
    "sidvördnaders": "sidvördnad",
    "sidvördnads": "sidvördnad",
    "siemensen": "siemens",
    "siemensens": "siemens",
    "sienan": "siena",
    "sienans": "siena",
    "sienas": "siena",
    "sierraleoniern": "sierraleonier",
    "sierraleonierna": "sierraleonier",
    "sierraleoniernas": "sierraleonier",
    "sierraleonierns": "sierraleonier",
    "sierraleoniers": "sierraleonier",
    "sierraleonska": "sierraleonsk",
    "sierraleonskan": "sierraleonska",
    "sierraleonskans": "sierraleonska",
    "sierraleonskare": "sierraleonsk",
    "sierraleonskares": "sierraleonsk",
    "sierraleonskas": "sierraleonska",
    "sierraleonskast": "sierraleonsk",
    "sierraleonskaste": "sierraleonsk",
    "sierraleonskastes": "sierraleonsk",
    "sierraleonskasts": "sierraleonsk",
    "sierraleonske": "sierraleonska",
    "sierraleonskes": "sierraleonsk",
    "sierraleonskor": "sierraleonska",
    "sierraleonskorna": "sierraleonska",
    "sierraleonskornas": "sierraleonska",
    "sierraleonskors": "sierraleonska",
    "sierraleonsks": "sierraleonsk",
    "sierraleonskt": "sierraleonsk",
    "sierraleonskts": "sierraleonsk",
    "sierskan": "sierska",
    "sierskans": "sierska",
    "sierskas": "sierska",
    "sierske": "sierska",
    "sierskor": "sierska",
    "sierskorna": "sierska",
    "sierskornas": "sierska",
    "sierskors": "sierska",
    "siest": "siesta",
    "siestan": "siesta",
    "siestans": "siesta",
    "siestas": "siesta",
    "sieste": "siesta",
    "siestor": "siesta",
    "siestorna": "siesta",
    "siestornas": "siesta",
    "siestors": "siesta",
    "sieverten": "sievert",
    "sievertens": "sievert",
    "sieverts": "sievert",
    "siffer": "siffra",
    "sifferbetygen": "sifferbetyg",
    "sifferbetygens": "sifferbetyg",
    "sifferbetyget": "sifferbetyg",
    "sifferbetygets": "sifferbetyg",
    "sifferbetygs": "sifferbetyg",
    "sifferblinda": "sifferblind",
    "sifferblindare": "sifferblind",
    "sifferblindares": "sifferblind",
    "sifferblindas": "sifferblind",
    "sifferblindast": "sifferblind",
    "sifferblindaste": "sifferblind",
    "sifferblindastes": "sifferblind",
    "sifferblindasts": "sifferblind",
    "sifferblinde": "sifferblind",
    "sifferblindes": "sifferblind",
    "sifferblindheten": "sifferblindhet",
    "sifferblindhetens": "sifferblindhet",
    "sifferblindhets": "sifferblindhet",
    "sifferblinds": "sifferblind",
    "sifferblint": "sifferblind",
    "sifferblints": "sifferblind",
    "sifferkarlar": "sifferkarl",
    "sifferkarlarna": "sifferkarl",
    "sifferkarlarnas": "sifferkarl",
    "sifferkarlars": "sifferkarl",
    "sifferkarlen": "sifferkarl",
    "sifferkarlens": "sifferkarl",
    "sifferkarls": "sifferkarl",
    "sifferkombinationen": "sifferkombination",
    "sifferkombinationens": "sifferkombination",
    "sifferkombinationer": "sifferkombination",
    "sifferkombinationerna": "sifferkombination",
    "sifferkombinationernas": "sifferkombination",
    "sifferkombinationers": "sifferkombination",
    "sifferkombinations": "sifferkombination",
    "sifferminnes": "sifferminne",
    "sifferminnet": "sifferminne",
    "sifferminnets": "sifferminne",
    "siffermässiga": "siffermässig",
    "siffermässigare": "siffermässig",
    "siffermässigares": "siffermässig",
    "siffermässigas": "siffermässig",
    "siffermässigast": "siffermässig",
    "siffermässigaste": "siffermässig",
    "siffermässigastes": "siffermässig",
    "siffermässigasts": "siffermässig",
    "siffermässige": "siffermässig",
    "siffermässiges": "siffermässig",
    "siffermässigs": "siffermässig",
    "siffermässigt": "siffermässig",
    "siffermässigts": "siffermässig",
    "sifferpussels": "sifferpussel",
    "sifferpusslen": "sifferpussel",
    "sifferpusslens": "sifferpussel",
    "sifferpusslet": "sifferpussel",
    "sifferpusslets": "sifferpussel",
    "sifferräkningar": "sifferräkning",
    "sifferräkningarna": "sifferräkning",
    "sifferräkningarnas": "sifferräkning",
    "sifferräkningars": "sifferräkning",
    "sifferräkningen": "sifferräkning",
    "sifferräkningens": "sifferräkning",
    "sifferräknings": "sifferräkning",
    "sifferstansar": "sifferstans",
    "sifferstansarna": "sifferstans",
    "sifferstansarnas": "sifferstans",
    "sifferstansars": "sifferstans",
    "sifferstansen": "sifferstans",
    "sifferstansens": "sifferstans",
    "siffersumman": "siffersumma",
    "siffersummans": "siffersumma",
    "siffersummas": "siffersumma",
    "siffersumme": "siffersumma",
    "siffersummor": "siffersumma",
    "siffersummorna": "siffersumma",
    "siffersummornas": "siffersumma",
    "siffersummors": "siffersumma",
    "siffertavel": "siffertavla",
    "siffertavlan": "siffertavla",
    "siffertavlans": "siffertavla",
    "siffertavlas": "siffertavla",
    "siffertavle": "siffertavla",
    "siffertavlor": "siffertavla",
    "siffertavlorna": "siffertavla",
    "siffertavlornas": "siffertavla",
    "siffertavlors": "siffertavla",
    "siffertipset": "siffertips",
    "siffertipsets": "siffertips",
    "sifferuppgiften": "sifferuppgift",
    "sifferuppgiftens": "sifferuppgift",
    "sifferuppgifter": "sifferuppgift",
    "sifferuppgifterna": "sifferuppgift",
    "sifferuppgifternas": "sifferuppgift",
    "sifferuppgifters": "sifferuppgift",
    "sifferuppgifts": "sifferuppgift",
    "siffran": "siffra",
    "siffrans": "siffra",
    "siffras": "siffra",
    "siffre": "siffra",
    "siffror": "siffra",
    "siffrorna": "siffra",
    "siffrornas": "siffra",
    "siffrors": "siffra",
    "sifo:s": "sifo",
    "sifonen": "sifon",
    "sifonens": "sifon",
    "sifoner": "sifon",
    "sifonerna": "sifon",
    "sifonernas": "sifon",
    "sifoners": "sifon",
    "sifons": "sifon",
    "sifoundersökningar": "sifoundersökning",
    "sifoundersökningarna": "sifoundersökning",
    "sifoundersökningarnas": "sifoundersökning",
    "sifoundersökningars": "sifoundersökning",
    "sifoundersökningen": "sifoundersökning",
    "sifoundersökningens": "sifoundersökning",
    "sifoundersöknings": "sifoundersökning",
    "sigeln": "sigel",
    "sigelns": "sigel",
    "sigels": "sigel",
    "sightseeingar": "sightseeing",
    "sightseeingarna": "sightseeing",
    "sightseeingarnas": "sightseeing",
    "sightseeingars": "sightseeing",
    "sightseeingen": "sightseeing",
    "sightseeingens": "sightseeing",
    "sightseeings": "sightseeing",
    "sigillbevarar": "sigillbevarare",
    "sigillbevararen": "sigillbevarare",
    "sigillbevararens": "sigillbevarare",
    "sigillbevarares": "sigillbevarare",
    "sigillbevararna": "sigillbevarare",
    "sigillbevararnas": "sigillbevarare",
    "sigillen": "sigill",
    "sigillens": "sigill",
    "sigillerad": "sigillera",
    "sigillerade": "sigillera",
    "sigillerades": "sigillera",
    "sigillerads": "sigillera",
    "sigillerande": "sigillera",
    "sigilleranden": "sigillerande",
    "sigillerandena": "sigillerande",
    "sigillerandenas": "sigillerande",
    "sigillerandens": "sigillerande",
    "sigillerandes": "sigillerande",
    "sigillerandet": "sigillerande",
    "sigillerandets": "sigillerande",
    "sigillerar": "sigillera",
    "sigilleras": "sigillera",
    "sigillerat": "sigillera",
    "sigillerats": "sigillera",
    "sigillerbara": "sigillerbar",
    "sigillerbarare": "sigillerbar",
    "sigillerbarares": "sigillerbar",
    "sigillerbaras": "sigillerbar",
    "sigillerbarast": "sigillerbar",
    "sigillerbaraste": "sigillerbar",
    "sigillerbarastes": "sigillerbar",
    "sigillerbarasts": "sigillerbar",
    "sigillerbare": "sigillerbar",
    "sigillerbares": "sigillerbar",
    "sigillerbarheten": "sigillerbarhet",
    "sigillerbarhetens": "sigillerbarhet",
    "sigillerbarhets": "sigillerbarhet",
    "sigillerbars": "sigillerbar",
    "sigillerbart": "sigillerbar",
    "sigillerbarts": "sigillerbar",
    "sigilleringar": "sigillering",
    "sigilleringarna": "sigillering",
    "sigilleringarnas": "sigillering",
    "sigilleringars": "sigillering",
    "sigilleringen": "sigillering",
    "sigilleringens": "sigillering",
    "sigillerings": "sigillering",
    "sigillet": "sigill",
    "sigillets": "sigill",
    "sigillografien": "sigillografi",
    "sigillografiens": "sigillografi",
    "sigillografin": "sigillografi",
    "sigillografins": "sigillografi",
    "sigillografis": "sigillografi",
    "sigillringar": "sigillring",
    "sigillringarna": "sigillring",
    "sigillringarnas": "sigillring",
    "sigillringars": "sigillring",
    "sigillringen": "sigillring",
    "sigillringens": "sigillring",
    "sigillrings": "sigillring",
    "sigills": "sigill",
    "sigillstampar": "sigillstamp",
    "sigillstamparna": "sigillstamp",
    "sigillstamparnas": "sigillstamp",
    "sigillstampars": "sigillstamp",
    "sigillstampen": "sigillstamp",
    "sigillstampens": "sigillstamp",
    "sigillstamps": "sigillstamp",
    "sigillstämpeln": "sigillstämpel",
    "sigillstämpelns": "sigillstämpel",
    "sigillstämpels": "sigillstämpel",
    "sigillstämplar": "sigillstämpel",
    "sigillstämplarna": "sigillstämpel",
    "sigillstämplarnas": "sigillstämpel",
    "sigillstämplars": "sigillstämpel",
    "sigler": "sigel",
    "siglerna": "sigel",
    "siglernas": "sigel",
    "siglers": "sigel",
    "sigman": "sigma",
    "sigmana": "sigma",
    "sigmanas": "sigma",
    "sigmans": "sigma",
    "sigmas": "sigma",
    "sigmat": "sigma",
    "sigmats": "sigma",
    "signa": "signum",
    "signad": "signa",
    "signade": "signa",
    "signades": "signa",
    "signads": "signa",
    "signalbanan": "signalbana",
    "signalbanans": "signalbana",
    "signalbanas": "signalbana",
    "signalbane": "signalbana",
    "signalbanor": "signalbana",
    "signalbanorna": "signalbana",
    "signalbanornas": "signalbana",
    "signalbanors": "signalbana",
    "signalblossen": "signalbloss",
    "signalblossens": "signalbloss",
    "signalblosset": "signalbloss",
    "signalblossets": "signalbloss",
    "signalboken": "signalbok",
    "signalbokens": "signalbok",
    "signalboks": "signalbok",
    "signalböcker": "signalbok",
    "signalböckerna": "signalbok",
    "signalböckernas": "signalbok",
    "signalböckers": "signalbok",
    "signaldukar": "signalduk",
    "signaldukarna": "signalduk",
    "signaldukarnas": "signalduk",
    "signaldukars": "signalduk",
    "signalduken": "signalduk",
    "signaldukens": "signalduk",
    "signalduks": "signalduk",
    "signaleldar": "signaleld",
    "signaleldarna": "signaleld",
    "signaleldarnas": "signaleld",
    "signaleldars": "signaleld",
    "signalelden": "signaleld",
    "signaleldens": "signaleld",
    "signalelds": "signaleld",
    "signalementen": "signalement",
    "signalementens": "signalement",
    "signalementet": "signalement",
    "signalementets": "signalement",
    "signalements": "signalement",
    "signalen": "signal",
    "signalens": "signal",
    "signaler": "signal",
    "signalerad": "signalera",
    "signalerade": "signalera",
    "signalerades": "signalera",
    "signalerads": "signalera",
    "signalerande": "signalera",
    "signaleranden": "signalerande",
    "signalerandena": "signalerande",
    "signalerandenas": "signalerande",
    "signalerandens": "signalerande",
    "signalerandes": "signalerande",
    "signalerandet": "signalerande",
    "signalerandets": "signalerande",
    "signalerar": "signalera",
    "signaleras": "signalera",
    "signalerat": "signalera",
    "signalerats": "signalera",
    "signalerbara": "signalerbar",
    "signalerbarare": "signalerbar",
    "signalerbarares": "signalerbar",
    "signalerbaras": "signalerbar",
    "signalerbarast": "signalerbar",
    "signalerbaraste": "signalerbar",
    "signalerbarastes": "signalerbar",
    "signalerbarasts": "signalerbar",
    "signalerbare": "signalerbar",
    "signalerbares": "signalerbar",
    "signalerbarheten": "signalerbarhet",
    "signalerbarhetens": "signalerbarhet",
    "signalerbarhets": "signalerbarhet",
    "signalerbars": "signalerbar",
    "signalerbart": "signalerbar",
    "signalerbarts": "signalerbar",
    "signaleringar": "signalering",
    "signaleringarna": "signalering",
    "signaleringarnas": "signalering",
    "signaleringars": "signalering",
    "signaleringen": "signalering",
    "signaleringens": "signalering",
    "signalerings": "signalering",
    "signalerna": "signal",
    "signalernas": "signal",
    "signalers": "signal",
    "signalflagg": "signalflagga",
    "signalflaggan": "signalflagga",
    "signalflaggans": "signalflagga",
    "signalflaggas": "signalflagga",
    "signalflagge": "signalflagga",
    "signalflaggor": "signalflagga",
    "signalflaggorna": "signalflagga",
    "signalflaggornas": "signalflagga",
    "signalflaggors": "signalflagga",
    "signalflaggs": "signalflagga",
    "signalhastigheten": "signalhastighet",
    "signalhastighetens": "signalhastighet",
    "signalhastigheter": "signalhastighet",
    "signalhastigheterna": "signalhastighet",
    "signalhastigheternas": "signalhastighet",
    "signalhastigheters": "signalhastighet",
    "signalhastighets": "signalhastighet",
    "signalhornen": "signalhorn",
    "signalhornens": "signalhorn",
    "signalhornet": "signalhorn",
    "signalhornets": "signalhorn",
    "signalhorns": "signalhorn",
    "signalisten": "signalist",
    "signalistens": "signalist",
    "signalister": "signalist",
    "signalisterna": "signalist",
    "signalisternas": "signalist",
    "signalisters": "signalist",
    "signalists": "signalist",
    "signalkräft": "signalkräfta",
    "signalkräftan": "signalkräfta",
    "signalkräftans": "signalkräfta",
    "signalkräftas": "signalkräfta",
    "signalkräfte": "signalkräfta",
    "signalkräftor": "signalkräfta",
    "signalkräftorna": "signalkräfta",
    "signalkräftornas": "signalkräfta",
    "signalkräftors": "signalkräfta",
    "signalkräfts": "signalkräfta",
    "signalmönsterna": "signalmönster",
    "signalmönsternas": "signalmönster",
    "signalmönsters": "signalmönster",
    "signalmönstren": "signalmönster",
    "signalmönstrens": "signalmönster",
    "signalmönstret": "signalmönster",
    "signalmönstrets": "signalmönster",
    "signalpistolen": "signalpistol",
    "signalpistolens": "signalpistol",
    "signalpistoler": "signalpistol",
    "signalpistolerna": "signalpistol",
    "signalpistolernas": "signalpistol",
    "signalpistolers": "signalpistol",
    "signalpistols": "signalpistol",
    "signalreglerade": "signalreglerad",
    "signalreglerades": "signalreglerad",
    "signalreglerads": "signalreglerad",
    "signalreglerat": "signalreglerad",
    "signalreglerats": "signalreglerad",
    "signalrötts": "signalrött",
    "signals": "signal",
    "signalskyddet": "signalskydd",
    "signalskyddets": "signalskydd",
    "signalskydds": "signalskydd",
    "signalspad": "signalspade",
    "signalspadar": "signalspade",
    "signalspadarna": "signalspade",
    "signalspadarnas": "signalspade",
    "signalspadars": "signalspade",
    "signalspaden": "signalspade",
    "signalspadens": "signalspade",
    "signalspades": "signalspade",
    "signalspads": "signalspade",
    "signalspaningar": "signalspaning",
    "signalspaningarna": "signalspaning",
    "signalspaningarnas": "signalspaning",
    "signalspaningars": "signalspaning",
    "signalspaningen": "signalspaning",
    "signalspaningens": "signalspaning",
    "signalspanings": "signalspaning",
    "signalställen": "signalställ",
    "signalställens": "signalställ",
    "signalstället": "signalställ",
    "signalställets": "signalställ",
    "signalställs": "signalställ",
    "signalsubstansen": "signalsubstans",
    "signalsubstansens": "signalsubstans",
    "signalsubstanser": "signalsubstans",
    "signalsubstanserna": "signalsubstans",
    "signalsubstansernas": "signalsubstans",
    "signalsubstansers": "signalsubstans",
    "signaltjänsten": "signaltjänst",
    "signaltjänstens": "signaltjänst",
    "signaltjänsts": "signaltjänst",
    "signaltruppen": "signaltrupp",
    "signaltruppens": "signaltrupp",
    "signaltrupper": "signaltrupp",
    "signaltrupperna": "signaltrupp",
    "signaltruppernas": "signaltrupp",
    "signaltruppers": "signaltrupp",
    "signaltrupps": "signaltrupp",
    "signaluren": "signalur",
    "signalurens": "signalur",
    "signaluret": "signalur",
    "signalurets": "signalur",
    "signalurs": "signalur",
    "signalöverföringen": "signalöverföring",
    "signalöverföringens": "signalöverföring",
    "signalöverförings": "signalöverföring",
    "signana": "signum",
    "signanas": "signum",
    "signande": "signa",
    "signanden": "signande",
    "signandena": "signande",
    "signandenas": "signande",
    "signandens": "signande",
    "signandes": "signande",
    "signandet": "signande",
    "signandets": "signande",
    "signar": "signa",
    "signas": "signum",
    "signat": "signa",
    "signats": "signa",
    "signaturen": "signatur",
    "signaturens": "signatur",
    "signaturer": "signatur",
    "signaturerna": "signatur",
    "signaturernas": "signatur",
    "signaturers": "signatur",
    "signaturmelodien": "signaturmelodi",
    "signaturmelodiens": "signaturmelodi",
    "signaturmelodier": "signaturmelodi",
    "signaturmelodierna": "signaturmelodi",
    "signaturmelodiernas": "signaturmelodi",
    "signaturmelodiers": "signaturmelodi",
    "signaturmelodin": "signaturmelodi",
    "signaturmelodins": "signaturmelodi",
    "signaturmelodis": "signaturmelodi",
    "signaturmässiga": "signaturmässig",
    "signaturmässigare": "signaturmässig",
    "signaturmässigares": "signaturmässig",
    "signaturmässigas": "signaturmässig",
    "signaturmässigast": "signaturmässig",
    "signaturmässigaste": "signaturmässig",
    "signaturmässigastes": "signaturmässig",
    "signaturmässigasts": "signaturmässig",
    "signaturmässige": "signaturmässig",
    "signaturmässiges": "signaturmässig",
    "signaturmässigs": "signaturmässig",
    "signaturmässigt": "signaturmässig",
    "signaturmässigts": "signaturmässig",
    "signaturs": "signatur",
    "signatären": "signatär",
    "signatärens": "signatär",
    "signatärer": "signatär",
    "signatärerna": "signatär",
    "signatärernas": "signatär",
    "signatärers": "signatär",
    "signatärmakten": "signatärmakt",
    "signatärmaktens": "signatärmakt",
    "signatärmakter": "signatärmakt",
    "signatärmakterna": "signatärmakt",
    "signatärmakternas": "signatärmakt",
    "signatärmakters": "signatärmakt",
    "signatärmakts": "signatärmakt",
    "signatärs": "signatär",
    "signelsen": "signelse",
    "signelsens": "signelse",
    "signelser": "signelse",
    "signelserna": "signelse",
    "signelsernas": "signelse",
    "signelsers": "signelse",
    "signelses": "signelse",
    "signerad": "signera",
    "signerade": "signera",
    "signerades": "signera",
    "signerads": "signera",
    "signerande": "signera",
    "signeranden": "signerande",
    "signerandena": "signerande",
    "signerandenas": "signerande",
    "signerandens": "signerande",
    "signerandes": "signerande",
    "signerandet": "signerande",
    "signerandets": "signerande",
    "signerar": "signera",
    "signeras": "signera",
    "signerat": "signera",
    "signerats": "signera",
    "signerbara": "signerbar",
    "signerbarare": "signerbar",
    "signerbarares": "signerbar",
    "signerbaras": "signerbar",
    "signerbarast": "signerbar",
    "signerbaraste": "signerbar",
    "signerbarastes": "signerbar",
    "signerbarasts": "signerbar",
    "signerbare": "signerbar",
    "signerbares": "signerbar",
    "signerbarheten": "signerbarhet",
    "signerbarhetens": "signerbarhet",
    "signerbarhets": "signerbarhet",
    "signerbars": "signerbar",
    "signerbart": "signerbar",
    "signerbarts": "signerbar",
    "signerier": "signeri",
    "signerierna": "signeri",
    "signeriernas": "signeri",
    "signeriers": "signeri",
    "signeriet": "signeri",
    "signeriets": "signeri",
    "signeringar": "signering",
    "signeringarna": "signering",
    "signeringarnas": "signering",
    "signeringars": "signering",
    "signeringen": "signering",
    "signeringens": "signering",
    "signerings": "signering",
    "signeris": "signeri",
    "signerit": "signeri",
    "signerits": "signeri",
    "signeten": "signet",
    "signetens": "signet",
    "signetet": "signet",
    "signetets": "signet",
    "signetringar": "signetring",
    "signetringarna": "signetring",
    "signetringarnas": "signetring",
    "signetringars": "signetring",
    "signetringen": "signetring",
    "signetringens": "signetring",
    "signetrings": "signetring",
    "signets": "signet",
    "signifikansen": "signifikans",
    "signifikansens": "signifikans",
    "signifikanser": "signifikans",
    "signifikanserna": "signifikans",
    "signifikansernas": "signifikans",
    "signifikansers": "signifikans",
    "signifikansprövningar": "signifikansprövning",
    "signifikansprövningarna": "signifikansprövning",
    "signifikansprövningarnas": "signifikansprövning",
    "signifikansprövningars": "signifikansprövning",
    "signifikansprövningen": "signifikansprövning",
    "signifikansprövningens": "signifikansprövning",
    "signifikansprövnings": "signifikansprövning",
    "signifikanta": "signifikant",
    "signifikantare": "signifikant",
    "signifikantares": "signifikant",
    "signifikantas": "signifikant",
    "signifikantast": "signifikant",
    "signifikantaste": "signifikant",
    "signifikantastes": "signifikant",
    "signifikantasts": "signifikant",
    "signifikante": "signifikant",
    "signifikantes": "signifikant",
    "signifikants": "signifikant",
    "signifikativa": "signifikativ",
    "signifikativare": "signifikativ",
    "signifikativares": "signifikativ",
    "signifikativas": "signifikativ",
    "signifikativast": "signifikativ",
    "signifikativaste": "signifikativ",
    "signifikativastes": "signifikativ",
    "signifikativasts": "signifikativ",
    "signifikative": "signifikativ",
    "signifikatives": "signifikativ",
    "signifikativs": "signifikativ",
    "signifikativt": "signifikativ",
    "signifikativts": "signifikativ",
    "signor": "signora",
    "signoran": "signora",
    "signorans": "signora",
    "signoras": "signora",
    "signore": "signora",
    "signoren": "signor",
    "signorens": "signor",
    "signorer": "signor",
    "signorerna": "signor",
    "signorernas": "signor",
    "signorers": "signor",
    "signorin": "signorina",
    "signorinan": "signorina",
    "signorinans": "signorina",
    "signorinas": "signorina",
    "signorine": "signorina",
    "signorinor": "signorina",
    "signorinorna": "signorina",
    "signorinornas": "signorina",
    "signorinors": "signorina",
    "signorins": "signorina",
    "signoror": "signora",
    "signororna": "signora",
    "signorornas": "signora",
    "signorors": "signora",
    "signors": "signora",
    "signumen": "signum",
    "signumens": "signum",
    "signumet": "signum",
    "signumets": "signum",
    "signums": "signum",
    "sikahjortar": "sikahjort",
    "sikahjortarna": "sikahjort",
    "sikahjortarnas": "sikahjort",
    "sikahjortars": "sikahjort",
    "sikahjorten": "sikahjort",
    "sikahjortens": "sikahjort",
    "sikahjorts": "sikahjort",
    "sikar": "sik",
    "sikarna": "sik",
    "sikarnas": "sik",
    "sikars": "sik",
    "sikeln": "sikel",
    "sikelns": "sikel",
    "sikels": "sikel",
    "siken": "sik",
    "sikens": "sik",
    "sikhen": "sikh",
    "sikhens": "sikh",
    "sikher": "sikh",
    "sikherna": "sikh",
    "sikhernas": "sikh",
    "sikhers": "sikh",
    "sikhs": "sikh",
    "siklar": "sikel",
    "siklarna": "sikel",
    "siklarnas": "sikel",
    "siklars": "sikel",
    "siklöj": "siklöja",
    "siklöjan": "siklöja",
    "siklöjans": "siklöja",
    "siklöjas": "siklöja",
    "siklöje": "siklöja",
    "siklöjor": "siklöja",
    "siklöjorna": "siklöja",
    "siklöjornas": "siklöja",
    "siklöjors": "siklöja",
    "siklöjs": "siklöja",
    "siks": "sik",
    "sikt": "sikta",
    "siktad": "sikta",
    "siktade": "sikta",
    "siktades": "sikta",
    "siktads": "sikta",
    "siktande": "sikta",
    "siktanden": "siktande",
    "siktandena": "siktande",
    "siktandenas": "siktande",
    "siktandens": "siktande",
    "siktandes": "siktande",
    "siktandet": "siktande",
    "siktandets": "siktande",
    "siktar": "sikta",
    "siktarna": "sikt",
    "siktarnas": "sikt",
    "siktars": "sikt",
    "siktas": "sikta",
    "siktat": "sikta",
    "siktats": "sikta",
    "siktbara": "siktbar",
    "siktbarare": "siktbar",
    "siktbarares": "siktbar",
    "siktbaras": "siktbar",
    "siktbarast": "siktbar",
    "siktbaraste": "siktbar",
    "siktbarastes": "siktbar",
    "siktbarasts": "siktbar",
    "siktbare": "siktbar",
    "siktbares": "siktbar",
    "siktbarheten": "siktbarhet",
    "siktbarhetens": "siktbarhet",
    "siktbarhets": "siktbarhet",
    "siktbars": "siktbar",
    "siktbart": "siktbar",
    "siktbarts": "siktbar",
    "siktbröden": "siktbröd",
    "siktbrödens": "siktbröd",
    "siktbrödet": "siktbröd",
    "siktbrödets": "siktbröd",
    "siktbröds": "siktbröd",
    "siktdjupet": "siktdjup",
    "siktdjupets": "siktdjup",
    "siktdjups": "siktdjup",
    "siktdukar": "siktduk",
    "siktdukarna": "siktduk",
    "siktdukarnas": "siktduk",
    "siktdukars": "siktduk",
    "siktduken": "siktduk",
    "siktdukens": "siktduk",
    "siktduks": "siktduk",
    "sikten": "sikte",
    "siktena": "sikte",
    "siktenas": "sikte",
    "siktens": "sikte",
    "siktes": "sikte",
    "siktet": "sikte",
    "siktets": "sikte",
    "siktiga": "siktig",
    "siktigare": "siktig",
    "siktigares": "siktig",
    "siktigas": "siktig",
    "siktigast": "siktig",
    "siktigaste": "siktig",
    "siktigastes": "siktig",
    "siktigasts": "siktig",
    "siktige": "siktig",
    "siktiges": "siktig",
    "siktigheten": "siktighet",
    "siktighetens": "siktighet",
    "siktighets": "siktighet",
    "siktigs": "siktig",
    "siktigt": "siktig",
    "siktigts": "siktig",
    "siktkak": "siktkaka",
    "siktkakan": "siktkaka",
    "siktkakans": "siktkaka",
    "siktkakas": "siktkaka",
    "siktkake": "siktkaka",
    "siktkakor": "siktkaka",
    "siktkakorna": "siktkaka",
    "siktkakornas": "siktkaka",
    "siktkakors": "siktkaka",
    "siktkaks": "siktkaka",
    "siktlinjen": "siktlinje",
    "siktlinjens": "siktlinje",
    "siktlinjer": "siktlinje",
    "siktlinjerna": "siktlinje",
    "siktlinjernas": "siktlinje",
    "siktlinjers": "siktlinje",
    "siktlinjes": "siktlinje",
    "siktmjölet": "siktmjöl",
    "siktmjölets": "siktmjöl",
    "siktmjöls": "siktmjöl",
    "siktramar": "siktram",
    "siktramarna": "siktram",
    "siktramarnas": "siktram",
    "siktramars": "siktram",
    "siktramen": "siktram",
    "siktramens": "siktram",
    "siktrams": "siktram",
    "sikts": "sikt",
    "siktskår": "siktskåra",
    "siktskåran": "siktskåra",
    "siktskårans": "siktskåra",
    "siktskåras": "siktskåra",
    "siktskåre": "siktskåra",
    "siktskåror": "siktskåra",
    "siktskårorna": "siktskåra",
    "siktskårornas": "siktskåra",
    "siktskårors": "siktskåra",
    "siktskårs": "siktskåra",
    "siktsträck": "siktsträcka",
    "siktsträckan": "siktsträcka",
    "siktsträckans": "siktsträcka",
    "siktsträckas": "siktsträcka",
    "siktsträcke": "siktsträcka",
    "siktsträckor": "siktsträcka",
    "siktsträckorna": "siktsträcka",
    "siktsträckornas": "siktsträcka",
    "siktsträckors": "siktsträcka",
    "siktsträcks": "siktsträcka",
    "sil": "sila",
    "silad": "sila",
    "silade": "sila",
    "silades": "sila",
    "silads": "sila",
    "silande": "sila",
    "silanden": "silande",
    "silandena": "silande",
    "silandenas": "silande",
    "silandens": "silande",
    "silandes": "silande",
    "silandet": "silande",
    "silandets": "silande",
    "silar": "sila",
    "silarna": "sil",
    "silarnas": "sil",
    "silars": "sil",
    "silas": "sila",
    "silat": "sila",
    "silats": "sila",
    "silbenen": "silben",
    "silbenens": "silben",
    "silbenet": "silben",
    "silbenets": "silben",
    "silbens": "silben",
    "sildukar": "silduk",
    "sildukarna": "silduk",
    "sildukarnas": "silduk",
    "sildukars": "silduk",
    "silduken": "silduk",
    "sildukens": "silduk",
    "silduks": "silduk",
    "silen": "sil",
    "silenen": "silen",
    "silenens": "silen",
    "silener": "silen",
    "silenerna": "silen",
    "silenernas": "silen",
    "sileners": "silen",
    "silens": "silen",
    "sileshåret": "sileshår",
    "sileshårets": "sileshår",
    "sileshårs": "sileshår",
    "silhuetten": "silhuett",
    "silhuettens": "silhuett",
    "silhuetter": "silhuett",
    "silhuetterad": "silhuettera",
    "silhuetterade": "silhuettera",
    "silhuetterades": "silhuettera",
    "silhuetterads": "silhuettera",
    "silhuetterande": "silhuettera",
    "silhuetteranden": "silhuetterande",
    "silhuetterandena": "silhuetterande",
    "silhuetterandenas": "silhuetterande",
    "silhuetterandens": "silhuetterande",
    "silhuetterandes": "silhuetterande",
    "silhuetterandet": "silhuetterande",
    "silhuetterandets": "silhuetterande",
    "silhuetterar": "silhuettera",
    "silhuetteras": "silhuettera",
    "silhuetterat": "silhuettera",
    "silhuetterats": "silhuettera",
    "silhuetterbara": "silhuetterbar",
    "silhuetterbarare": "silhuetterbar",
    "silhuetterbarares": "silhuetterbar",
    "silhuetterbaras": "silhuetterbar",
    "silhuetterbarast": "silhuetterbar",
    "silhuetterbaraste": "silhuetterbar",
    "silhuetterbarastes": "silhuetterbar",
    "silhuetterbarasts": "silhuetterbar",
    "silhuetterbare": "silhuetterbar",
    "silhuetterbares": "silhuetterbar",
    "silhuetterbarheten": "silhuetterbarhet",
    "silhuetterbarhetens": "silhuetterbarhet",
    "silhuetterbarhets": "silhuetterbarhet",
    "silhuetterbars": "silhuetterbar",
    "silhuetterbart": "silhuetterbar",
    "silhuetterbarts": "silhuetterbar",
    "silhuetteringar": "silhuettering",
    "silhuetteringarna": "silhuettering",
    "silhuetteringarnas": "silhuettering",
    "silhuetteringars": "silhuettering",
    "silhuetteringen": "silhuettering",
    "silhuetteringens": "silhuettering",
    "silhuetterings": "silhuettering",
    "silhuetterna": "silhuett",
    "silhuetternas": "silhuett",
    "silhuetters": "silhuett",
    "silhuetts": "silhuett",
    "siliciet": "silicium",
    "siliciets": "silicium",
    "siliciumet": "silicium",
    "siliciumets": "silicium",
    "siliciums": "silicium",
    "silikaten": "silikat",
    "silikatens": "silikat",
    "silikater": "silikat",
    "silikaterna": "silikat",
    "silikaternas": "silikat",
    "silikaters": "silikat",
    "silikatet": "silikat",
    "silikatets": "silikat",
    "silikats": "silikat",
    "silikonbrösten": "silikonbröst",
    "silikonbröstens": "silikonbröst",
    "silikonbröstet": "silikonbröst",
    "silikonbröstets": "silikonbröst",
    "silikonbrösts": "silikonbröst",
    "silikonen": "silikon",
    "silikonens": "silikon",
    "silikoner": "silikon",
    "silikonerna": "silikon",
    "silikonernas": "silikon",
    "silikoners": "silikon",
    "silikonet": "silikon",
    "silikonets": "silikon",
    "silikonimplantaten": "silikonimplantat",
    "silikonimplantatens": "silikonimplantat",
    "silikonimplantatet": "silikonimplantat",
    "silikonimplantatets": "silikonimplantat",
    "silikonimplantats": "silikonimplantat",
    "silikonlisten": "silikonlist",
    "silikonlistens": "silikonlist",
    "silikonlister": "silikonlist",
    "silikonlisterna": "silikonlist",
    "silikonlisternas": "silikonlist",
    "silikonlisters": "silikonlist",
    "silikonlists": "silikonlist",
    "silikons": "silikon",
    "silikosen": "silikos",
    "silikosens": "silikos",
    "silkeap": "silkeapa",
    "silkeapan": "silkeapa",
    "silkeapans": "silkeapa",
    "silkeapas": "silkeapa",
    "silkeape": "silkeapa",
    "silkeapor": "silkeapa",
    "silkeaporna": "silkeapa",
    "silkeapornas": "silkeapa",
    "silkeapors": "silkeapa",
    "silkeaps": "silkeapa",
    "silkegarnen": "silkegarn",
    "silkegarnens": "silkegarn",
    "silkegarner": "silkegarn",
    "silkegarnerna": "silkegarn",
    "silkegarnernas": "silkegarn",
    "silkegarners": "silkegarn",
    "silkegarnet": "silkegarn",
    "silkegarnets": "silkegarn",
    "silkegarns": "silkegarn",
    "silken": "silke",
    "silkena": "silke",
    "silkenas": "silke",
    "silkens": "silke",
    "silkepapperen": "silkepapper",
    "silkepapperens": "silkepapper",
    "silkepapperet": "silkepapper",
    "silkepapperets": "silkepapper",
    "silkepapperna": "silkepapper",
    "silkepappernas": "silkepapper",
    "silkepappers": "silkepapper",
    "silkepappren": "silkepapper",
    "silkepapprens": "silkepapper",
    "silkepappret": "silkepapper",
    "silkepapprets": "silkepapper",
    "silkes": "silke",
    "silkesap": "silkesapa",
    "silkesapan": "silkesapa",
    "silkesapans": "silkesapa",
    "silkesapas": "silkesapa",
    "silkesape": "silkesapa",
    "silkesapor": "silkesapa",
    "silkesaporna": "silkesapa",
    "silkesapornas": "silkesapa",
    "silkesapors": "silkesapa",
    "silkesaps": "silkesapa",
    "silkesbanden": "silkesband",
    "silkesbandens": "silkesband",
    "silkesbandet": "silkesband",
    "silkesbandets": "silkesband",
    "silkesbands": "silkesband",
    "silkesbomullen": "silkesbomull",
    "silkesbomullens": "silkesbomull",
    "silkesbomulls": "silkesbomull",
    "silkesfjärilar": "silkesfjäril",
    "silkesfjärilarna": "silkesfjäril",
    "silkesfjärilarnas": "silkesfjäril",
    "silkesfjärilars": "silkesfjäril",
    "silkesfjärilen": "silkesfjäril",
    "silkesfjärilens": "silkesfjäril",
    "silkesfjäriln": "silkesfjäril",
    "silkesfjärilns": "silkesfjäril",
    "silkesfjärils": "silkesfjäril",
    "silkeshar": "silkeshare",
    "silkesharar": "silkeshare",
    "silkeshararna": "silkeshare",
    "silkeshararnas": "silkeshare",
    "silkesharars": "silkeshare",
    "silkesharen": "silkeshare",
    "silkesharens": "silkeshare",
    "silkeshares": "silkeshare",
    "silkeshars": "silkeshare",
    "silkeskaninen": "silkeskanin",
    "silkeskaninens": "silkeskanin",
    "silkeskaniner": "silkeskanin",
    "silkeskaninerna": "silkeskanin",
    "silkeskaninernas": "silkeskanin",
    "silkeskaniners": "silkeskanin",
    "silkeskanins": "silkeskanin",
    "silkeslarven": "silkeslarv",
    "silkeslarvens": "silkeslarv",
    "silkeslarver": "silkeslarv",
    "silkeslarverna": "silkeslarv",
    "silkeslarvernas": "silkeslarv",
    "silkeslarvers": "silkeslarv",
    "silkeslarvs": "silkeslarv",
    "silkeslena": "silkeslen",
    "silkeslenare": "silkeslen",
    "silkeslenares": "silkeslen",
    "silkeslenas": "silkeslen",
    "silkeslenast": "silkeslen",
    "silkeslenaste": "silkeslen",
    "silkeslenastes": "silkeslen",
    "silkeslenasts": "silkeslen",
    "silkeslene": "silkeslen",
    "silkeslenes": "silkeslen",
    "silkeslens": "silkeslen",
    "silkeslent": "silkeslen",
    "silkeslents": "silkeslen",
    "silkesmaskar": "silkesmask",
    "silkesmaskarna": "silkesmask",
    "silkesmaskarnas": "silkesmask",
    "silkesmaskars": "silkesmask",
    "silkesmasken": "silkesmask",
    "silkesmaskens": "silkesmask",
    "silkesmasks": "silkesmask",
    "silkesnör": "silkesnöre",
    "silkesnören": "silkesnöre",
    "silkesnörena": "silkesnöre",
    "silkesnörenas": "silkesnöre",
    "silkesnörens": "silkesnöre",
    "silkesnöres": "silkesnöre",
    "silkesnöret": "silkesnöre",
    "silkesnörets": "silkesnöre",
    "silkesnörs": "silkesnöre",
    "silkesodlingar": "silkesodling",
    "silkesodlingarna": "silkesodling",
    "silkesodlingarnas": "silkesodling",
    "silkesodlingars": "silkesodling",
    "silkesodlingen": "silkesodling",
    "silkesodlingens": "silkesodling",
    "silkesodlings": "silkesodling",
    "silkespapperet": "silkespapper",
    "silkespapperets": "silkespapper",
    "silkespappers": "silkespapper",
    "silkespappret": "silkespapper",
    "silkespapprets": "silkespapper",
    "silkespinnar": "silkespinnare",
    "silkespinnaren": "silkespinnare",
    "silkespinnarens": "silkespinnare",
    "silkespinnares": "silkespinnare",
    "silkespinnarna": "silkespinnare",
    "silkespinnarnas": "silkespinnare",
    "silkessnör": "silkessnöre",
    "silkessnören": "silkessnöre",
    "silkessnörena": "silkessnöre",
    "silkessnörenas": "silkessnöre",
    "silkessnörens": "silkessnöre",
    "silkessnöres": "silkessnöre",
    "silkessnöret": "silkessnöre",
    "silkessnörets": "silkessnöre",
    "silkessnörs": "silkessnöre",
    "silkesspinnar": "silkesspinnare",
    "silkesspinnaren": "silkesspinnare",
    "silkesspinnarens": "silkesspinnare",
    "silkesspinnares": "silkesspinnare",
    "silkesspinnarna": "silkesspinnare",
    "silkesspinnarnas": "silkesspinnare",
    "silkesstickade": "silkesstickad",
    "silkesstickades": "silkesstickad",
    "silkesstickads": "silkesstickad",
    "silkesstickat": "silkesstickad",
    "silkesstickats": "silkesstickad",
    "silkesstrump": "silkesstrumpa",
    "silkesstrumpan": "silkesstrumpa",
    "silkesstrumpans": "silkesstrumpa",
    "silkesstrumpas": "silkesstrumpa",
    "silkesstrumpe": "silkesstrumpa",
    "silkesstrumpor": "silkesstrumpa",
    "silkesstrumporna": "silkesstrumpa",
    "silkesstrumpornas": "silkesstrumpa",
    "silkesstrumpors": "silkesstrumpa",
    "silkesstrumps": "silkesstrumpa",
    "silkestickade": "silkestickad",
    "silkestickades": "silkestickad",
    "silkestickads": "silkestickad",
    "silkestickat": "silkestickad",
    "silkestickats": "silkestickad",
    "silkestrump": "silkestrumpa",
    "silkestrumpan": "silkestrumpa",
    "silkestrumpans": "silkestrumpa",
    "silkestrumpas": "silkestrumpa",
    "silkestrumpe": "silkestrumpa",
    "silkestrumpor": "silkestrumpa",
    "silkestrumporna": "silkestrumpa",
    "silkestrumpornas": "silkestrumpa",
    "silkestrumpors": "silkestrumpa",
    "silkestrumps": "silkestrumpa",
    "silkestrådar": "silkestråd",
    "silkestrådarna": "silkestråd",
    "silkestrådarnas": "silkestråd",
    "silkestrådars": "silkestråd",
    "silkestråden": "silkestråd",
    "silkestrådens": "silkestråd",
    "silkestråds": "silkestråd",
    "silkesvantarna": "silkesvantar",
    "silkesvantarnas": "silkesvantar",
    "silkesvantars": "silkesvantar",
    "silkesvante": "silkesvantar",
    "silket": "silke",
    "silkets": "silke",
    "silkiga": "silkig",
    "silkigare": "silkig",
    "silkigares": "silkig",
    "silkigas": "silkig",
    "silkigast": "silkig",
    "silkigaste": "silkig",
    "silkigastes": "silkig",
    "silkigasts": "silkig",
    "silkige": "silkig",
    "silkiges": "silkig",
    "silkigheten": "silkighet",
    "silkighetens": "silkighet",
    "silkighets": "silkighet",
    "silkigs": "silkig",
    "silkigt": "silkig",
    "silkigts": "silkig",
    "sillar": "sill",
    "sillarna": "sill",
    "sillarnas": "sill",
    "sillars": "sill",
    "sillavfallen": "sillavfall",
    "sillavfallens": "sillavfall",
    "sillavfallet": "sillavfall",
    "sillavfallets": "sillavfall",
    "sillavfalls": "sillavfall",
    "sillbitar": "sillbit",
    "sillbitarna": "sillbit",
    "sillbitarnas": "sillbit",
    "sillbitars": "sillbit",
    "sillbiten": "sillbit",
    "sillbitens": "sillbit",
    "sillbits": "sillbit",
    "sillblixtar": "sillblixt",
    "sillblixtarna": "sillblixt",
    "sillblixtarnas": "sillblixt",
    "sillblixtars": "sillblixt",
    "sillblixten": "sillblixt",
    "sillblixtens": "sillblixt",
    "sillblixts": "sillblixt",
    "sillbrick": "sillbricka",
    "sillbrickan": "sillbricka",
    "sillbrickans": "sillbricka",
    "sillbrickas": "sillbricka",
    "sillbricke": "sillbricka",
    "sillbrickor": "sillbricka",
    "sillbrickorna": "sillbricka",
    "sillbrickornas": "sillbricka",
    "sillbrickors": "sillbricka",
    "sillbricks": "sillbricka",
    "sillbull": "sillbulle",
    "sillbullar": "sillbulle",
    "sillbullarna": "sillbulle",
    "sillbullarnas": "sillbulle",
    "sillbullars": "sillbulle",
    "sillbullen": "sillbulle",
    "sillbullens": "sillbulle",
    "sillbulles": "sillbulle",
    "sillbulls": "sillbulle",
    "sillen": "sill",
    "sillens": "sill",
    "sillfiléer": "sillfilé",
    "sillfiléerna": "sillfilé",
    "sillfiléernas": "sillfilé",
    "sillfiléers": "sillfilé",
    "sillfilén": "sillfilé",
    "sillfiléns": "sillfilé",
    "sillfilés": "sillfilé",
    "sillfrukostar": "sillfrukost",
    "sillfrukostarna": "sillfrukost",
    "sillfrukostarnas": "sillfrukost",
    "sillfrukostars": "sillfrukost",
    "sillfrukosten": "sillfrukost",
    "sillfrukostens": "sillfrukost",
    "sillfrukosts": "sillfrukost",
    "sillgrissl": "sillgrissla",
    "sillgrisslan": "sillgrissla",
    "sillgrisslans": "sillgrissla",
    "sillgrisslas": "sillgrissla",
    "sillgrissle": "sillgrissla",
    "sillgrisslor": "sillgrissla",
    "sillgrisslorna": "sillgrissla",
    "sillgrisslornas": "sillgrissla",
    "sillgrisslors": "sillgrissla",
    "sillguanon": "sillguano",
    "sillguanons": "sillguano",
    "sillguanos": "sillguano",
    "sillguanot": "sillguano",
    "sillguanots": "sillguano",
    "sillinläggningar": "sillinläggning",
    "sillinläggningarna": "sillinläggning",
    "sillinläggningarnas": "sillinläggning",
    "sillinläggningars": "sillinläggning",
    "sillinläggningen": "sillinläggning",
    "sillinläggningens": "sillinläggning",
    "sillinläggnings": "sillinläggning",
    "sillkungar": "sillkung",
    "sillkungarna": "sillkung",
    "sillkungarnas": "sillkung",
    "sillkungars": "sillkung",
    "sillkungen": "sillkung",
    "sillkungens": "sillkung",
    "sillkungs": "sillkung",
    "sillmjölet": "sillmjöl",
    "sillmjölets": "sillmjöl",
    "sillmjölk": "sillmjölke",
    "sillmjölkar": "sillmjölke",
    "sillmjölkarna": "sillmjölke",
    "sillmjölkarnas": "sillmjölke",
    "sillmjölkars": "sillmjölke",
    "sillmjölken": "sillmjölke",
    "sillmjölkens": "sillmjölke",
    "sillmjölkes": "sillmjölke",
    "sillmjölks": "sillmjölke",
    "sillmjöls": "sillmjöl",
    "sillperioden": "sillperiod",
    "sillperiodens": "sillperiod",
    "sillperioder": "sillperiod",
    "sillperioderna": "sillperiod",
    "sillperiodernas": "sillperiod",
    "sillperioders": "sillperiod",
    "sillperiods": "sillperiod",
    "sillpuddingar": "sillpudding",
    "sillpuddingarna": "sillpudding",
    "sillpuddingarnas": "sillpudding",
    "sillpuddingars": "sillpudding",
    "sillpuddingen": "sillpudding",
    "sillpuddingens": "sillpudding",
    "sillpuddings": "sillpudding",
    "sills": "sill",
    "sillsalladen": "sillsallad",
    "sillsalladens": "sillsallad",
    "sillsallader": "sillsallad",
    "sillsalladerna": "sillsallad",
    "sillsalladernas": "sillsallad",
    "sillsalladers": "sillsallad",
    "sillsallads": "sillsallad",
    "sillsallaten": "sillsallat",
    "sillsallatens": "sillsallat",
    "sillsallater": "sillsallat",
    "sillsallaterna": "sillsallat",
    "sillsallaternas": "sillsallat",
    "sillsallaters": "sillsallat",
    "sillsallats": "sillsallat",
    "sillstrypar": "sillstrypare",
    "sillstryparen": "sillstrypare",
    "sillstryparens": "sillstrypare",
    "sillstrypares": "sillstrypare",
    "sillstryparna": "sillstrypare",
    "sillstryparnas": "sillstrypare",
    "silltrutar": "silltrut",
    "silltrutarna": "silltrut",
    "silltrutarnas": "silltrut",
    "silltrutars": "silltrut",
    "silltruten": "silltrut",
    "silltrutens": "silltrut",
    "silltruts": "silltrut",
    "sillvalar": "sillval",
    "sillvalarna": "sillval",
    "sillvalarnas": "sillval",
    "sillvalars": "sillval",
    "sillvalen": "sillval",
    "sillvalens": "sillval",
    "sillvals": "sillval",
    "sillvrakningar": "sillvrakning",
    "sillvrakningarna": "sillvrakning",
    "sillvrakningarnas": "sillvrakning",
    "sillvrakningars": "sillvrakning",
    "sillvrakningen": "sillvrakning",
    "sillvrakningens": "sillvrakning",
    "sillvraknings": "sillvrakning",
    "sillåd": "sillåda",
    "sillådan": "sillåda",
    "sillådans": "sillåda",
    "sillådas": "sillåda",
    "sillåde": "sillåda",
    "sillådor": "sillåda",
    "sillådorna": "sillåda",
    "sillådornas": "sillåda",
    "sillådors": "sillåda",
    "sillåds": "sillåda",
    "silon": "silo",
    "silons": "silo",
    "silor": "silo",
    "silorna": "silo",
    "silornas": "silo",
    "silors": "silo",
    "silos": "silo",
    "silosen": "silo",
    "silosens": "silo",
    "sils": "sil",
    "silten": "silt",
    "siltens": "silt",
    "silts": "silt",
    "siluetten": "siluett",
    "siluettens": "siluett",
    "siluetter": "siluett",
    "siluetterad": "siluettera",
    "siluetterade": "siluettera",
    "siluetterades": "siluettera",
    "siluetterads": "siluettera",
    "siluetterande": "siluettera",
    "siluetteranden": "siluetterande",
    "siluetterandena": "siluetterande",
    "siluetterandenas": "siluetterande",
    "siluetterandens": "siluetterande",
    "siluetterandes": "siluetterande",
    "siluetterandet": "siluetterande",
    "siluetterandets": "siluetterande",
    "siluetterar": "siluettera",
    "siluetteras": "siluettera",
    "siluetterat": "siluettera",
    "siluetterats": "siluettera",
    "siluetterbara": "siluetterbar",
    "siluetterbarare": "siluetterbar",
    "siluetterbarares": "siluetterbar",
    "siluetterbaras": "siluetterbar",
    "siluetterbarast": "siluetterbar",
    "siluetterbaraste": "siluetterbar",
    "siluetterbarastes": "siluetterbar",
    "siluetterbarasts": "siluetterbar",
    "siluetterbare": "siluetterbar",
    "siluetterbares": "siluetterbar",
    "siluetterbarheten": "siluetterbarhet",
    "siluetterbarhetens": "siluetterbarhet",
    "siluetterbarhets": "siluetterbarhet",
    "siluetterbars": "siluetterbar",
    "siluetterbart": "siluetterbar",
    "siluetterbarts": "siluetterbar",
    "siluetteringar": "siluettering",
    "siluetteringarna": "siluettering",
    "siluetteringarnas": "siluettering",
    "siluetteringars": "siluettering",
    "siluetteringen": "siluettering",
    "siluetteringens": "siluettering",
    "siluetterings": "siluettering",
    "siluetterna": "siluett",
    "siluetternas": "siluett",
    "siluetters": "siluett",
    "siluetts": "siluett",
    "siluren": "silur",
    "silurens": "silur",
    "silurs": "silur",
    "silverbeslagen": "silverbeslag",
    "silverbeslagens": "silverbeslag",
    "silverbeslaget": "silverbeslag",
    "silverbeslagets": "silverbeslag",
    "silverbeslags": "silverbeslag",
    "silverbladet": "silverblad",
    "silverbladets": "silverblad",
    "silverblads": "silverblad",
    "silverblonda": "silverblond",
    "silverblondare": "silverblond",
    "silverblondares": "silverblond",
    "silverblondas": "silverblond",
    "silverblondast": "silverblond",
    "silverblondaste": "silverblond",
    "silverblondastes": "silverblond",
    "silverblondasts": "silverblond",
    "silverblonde": "silverblond",
    "silverblondes": "silverblond",
    "silverblondheten": "silverblondhet",
    "silverblondhetens": "silverblondhet",
    "silverblondhets": "silverblondhet",
    "silverblonds": "silverblond",
    "silverblont": "silverblond",
    "silverblonts": "silverblond",
    "silverbromiden": "silverbromid",
    "silverbromidens": "silverbromid",
    "silverbromids": "silverbromid",
    "silverbrudparen": "silverbrudpar",
    "silverbrudparens": "silverbrudpar",
    "silverbrudparet": "silverbrudpar",
    "silverbrudparets": "silverbrudpar",
    "silverbrudpars": "silverbrudpar",
    "silverbröllopen": "silverbröllop",
    "silverbröllopens": "silverbröllop",
    "silverbröllopet": "silverbröllop",
    "silverbröllopets": "silverbröllop",
    "silverbröllops": "silverbröllop",
    "silverbägar": "silverbägare",
    "silverbägaren": "silverbägare",
    "silverbägarens": "silverbägare",
    "silverbägares": "silverbägare",
    "silverbägarna": "silverbägare",
    "silverbägarnas": "silverbägare",
    "silverfasanen": "silverfasan",
    "silverfasanens": "silverfasan",
    "silverfasaner": "silverfasan",
    "silverfasanerna": "silverfasan",
    "silverfasanernas": "silverfasan",
    "silverfasaners": "silverfasan",
    "silverfasans": "silverfasan",
    "silverfaten": "silverfat",
    "silverfatens": "silverfat",
    "silverfatet": "silverfat",
    "silverfatets": "silverfat",
    "silverfats": "silverfat",
    "silverfem": "silverfemma",
    "silverfemman": "silverfemma",
    "silverfemmans": "silverfemma",
    "silverfemmas": "silverfemma",
    "silverfemme": "silverfemma",
    "silverfemmor": "silverfemma",
    "silverfemmorna": "silverfemma",
    "silverfemmornas": "silverfemma",
    "silverfemmors": "silverfemma",
    "silverfems": "silverfemma",
    "silverfiskar": "silverfisk",
    "silverfiskarna": "silverfisk",
    "silverfiskarnas": "silverfisk",
    "silverfiskars": "silverfisk",
    "silverfisken": "silverfisk",
    "silverfiskens": "silverfisk",
    "silverfisks": "silverfisk",
    "silverfolien": "silverfolie",
    "silverfoliens": "silverfolie",
    "silverfolier": "silverfolie",
    "silverfolierna": "silverfolie",
    "silverfoliernas": "silverfolie",
    "silverfoliers": "silverfolie",
    "silverfolies": "silverfolie",
    "silverfoliet": "silverfolie",
    "silverfoliets": "silverfolie",
    "silverfärgade": "silverfärgad",
    "silverfärgades": "silverfärgad",
    "silverfärgads": "silverfärgad",
    "silverfärgat": "silverfärgad",
    "silverfärgats": "silverfärgad",
    "silverföremålen": "silverföremål",
    "silverföremålens": "silverföremål",
    "silverföremålet": "silverföremål",
    "silverföremålets": "silverföremål",
    "silverföremåls": "silverföremål",
    "silverglansen": "silverglans",
    "silverglansens": "silverglans",
    "silvergranar": "silvergran",
    "silvergranarna": "silvergran",
    "silvergranarnas": "silvergran",
    "silvergranars": "silvergran",
    "silvergranen": "silvergran",
    "silvergranens": "silvergran",
    "silvergrans": "silvergran",
    "silvergroggar": "silvergrogg",
    "silvergroggarna": "silvergrogg",
    "silvergroggarnas": "silvergrogg",
    "silvergroggars": "silvergrogg",
    "silvergroggen": "silvergrogg",
    "silvergroggens": "silvergrogg",
    "silvergroggs": "silvergrogg",
    "silvergruv": "silvergruva",
    "silvergruvan": "silvergruva",
    "silvergruvans": "silvergruva",
    "silvergruvas": "silvergruva",
    "silvergruve": "silvergruva",
    "silvergruvor": "silvergruva",
    "silvergruvorna": "silvergruva",
    "silvergruvornas": "silvergruva",
    "silvergruvors": "silvergruva",
    "silvergruvs": "silvergruva",
    "silvergråa": "silvergrå",
    "silvergråare": "silvergrå",
    "silvergråares": "silvergrå",
    "silvergråas": "silvergrå",
    "silvergråast": "silvergrå",
    "silvergråaste": "silvergrå",
    "silvergråastes": "silvergrå",
    "silvergråasts": "silvergrå",
    "silvergråe": "silvergrå",
    "silvergråes": "silvergrå",
    "silvergrås": "silvergrå",
    "silvergrått": "silvergrå",
    "silvergråtts": "silvergrå",
    "silverhalten": "silverhalt",
    "silverhaltens": "silverhalt",
    "silverhalter": "silverhalt",
    "silverhalterna": "silverhalt",
    "silverhalternas": "silverhalt",
    "silverhalters": "silverhalt",
    "silverhaltiga": "silverhaltig",
    "silverhaltigare": "silverhaltig",
    "silverhaltigares": "silverhaltig",
    "silverhaltigas": "silverhaltig",
    "silverhaltigast": "silverhaltig",
    "silverhaltigaste": "silverhaltig",
    "silverhaltigastes": "silverhaltig",
    "silverhaltigasts": "silverhaltig",
    "silverhaltige": "silverhaltig",
    "silverhaltiges": "silverhaltig",
    "silverhaltigs": "silverhaltig",
    "silverhaltigt": "silverhaltig",
    "silverhaltigts": "silverhaltig",
    "silverhalts": "silverhalt",
    "silverinfatt": "silverinfatta",
    "silverinfattad": "silverinfatta",
    "silverinfattade": "silverinfatta",
    "silverinfattades": "silverinfatta",
    "silverinfattads": "silverinfatta",
    "silverinfattande": "silverinfatta",
    "silverinfattanden": "silverinfattande",
    "silverinfattandena": "silverinfattande",
    "silverinfattandenas": "silverinfattande",
    "silverinfattandens": "silverinfattande",
    "silverinfattandes": "silverinfattande",
    "silverinfattandet": "silverinfattande",
    "silverinfattandets": "silverinfattande",
    "silverinfattar": "silverinfatta",
    "silverinfattas": "silverinfatta",
    "silverinfattat": "silverinfatta",
    "silverinfattats": "silverinfatta",
    "silverklangen": "silverklang",
    "silverklangens": "silverklang",
    "silverklangs": "silverklang",
    "silverklara": "silverklar",
    "silverklarare": "silverklar",
    "silverklarares": "silverklar",
    "silverklaras": "silverklar",
    "silverklarast": "silverklar",
    "silverklaraste": "silverklar",
    "silverklarastes": "silverklar",
    "silverklarasts": "silverklar",
    "silverklare": "silverklar",
    "silverklares": "silverklar",
    "silverklars": "silverklar",
    "silverklart": "silverklar",
    "silverklarts": "silverklar",
    "silverkloriden": "silverklorid",
    "silverkloridens": "silverklorid",
    "silverklorids": "silverklorid",
    "silverlejonen": "silverlejon",
    "silverlejonens": "silverlejon",
    "silverlejonet": "silverlejon",
    "silverlejonets": "silverlejon",
    "silverlejons": "silverlejon",
    "silvermagistern": "silvermagister",
    "silvermagisterns": "silvermagister",
    "silvermagisters": "silvermagister",
    "silvermagistrar": "silvermagister",
    "silvermagistrarna": "silvermagister",
    "silvermagistrarnas": "silvermagister",
    "silvermagistrars": "silvermagister",
    "silvermedaljen": "silvermedalj",
    "silvermedaljens": "silvermedalj",
    "silvermedaljer": "silvermedalj",
    "silvermedaljerna": "silvermedalj",
    "silvermedaljernas": "silvermedalj",
    "silvermedaljers": "silvermedalj",
    "silvermedaljs": "silvermedalj",
    "silvermynten": "silvermynt",
    "silvermyntens": "silvermynt",
    "silvermyntet": "silvermynt",
    "silvermyntets": "silvermynt",
    "silvermynts": "silvermynt",
    "silvernitratet": "silvernitrat",
    "silvernitratets": "silvernitrat",
    "silvernitrats": "silvernitrat",
    "silverpengar": "silverpeng",
    "silverpengarna": "silverpeng",
    "silverpengarnas": "silverpeng",
    "silverpengars": "silverpeng",
    "silverpengen": "silverpeng",
    "silverpengens": "silverpeng",
    "silverpengs": "silverpeng",
    "silverpenningar": "silverpenning",
    "silverpenningarna": "silverpenning",
    "silverpenningarnas": "silverpenning",
    "silverpenningars": "silverpenning",
    "silverpenningen": "silverpenning",
    "silverpenningens": "silverpenning",
    "silverpennings": "silverpenning",
    "silverpokalen": "silverpokal",
    "silverpokalens": "silverpokal",
    "silverpokaler": "silverpokal",
    "silverpokalerna": "silverpokal",
    "silverpokalernas": "silverpokal",
    "silverpokalers": "silverpokal",
    "silverpokals": "silverpokal",
    "silverpoppeln": "silverpoppel",
    "silverpoppelns": "silverpoppel",
    "silverpoppels": "silverpoppel",
    "silverpopplar": "silverpoppel",
    "silverpopplarna": "silverpoppel",
    "silverpopplarnas": "silverpoppel",
    "silverpopplars": "silverpoppel",
    "silverproberingar": "silverprobering",
    "silverproberingarna": "silverprobering",
    "silverproberingarnas": "silverprobering",
    "silverproberingars": "silverprobering",
    "silverproberingen": "silverprobering",
    "silverproberingens": "silverprobering",
    "silverproberings": "silverprobering",
    "silverputsen": "silverputs",
    "silverputsens": "silverputs",
    "silverrävar": "silverräv",
    "silverrävarna": "silverräv",
    "silverrävarnas": "silverräv",
    "silverrävars": "silverräv",
    "silverräven": "silverräv",
    "silverrävens": "silverräv",
    "silverrävs": "silverräv",
    "silvers": "silver",
    "silversalter": "silversalt",
    "silversalterna": "silversalt",
    "silversalternas": "silversalt",
    "silversalters": "silversalt",
    "silversaltet": "silversalt",
    "silversaltets": "silversalt",
    "silversalts": "silversalt",
    "silverservisen": "silverservis",
    "silverservisens": "silverservis",
    "silverserviser": "silverservis",
    "silverserviserna": "silverservis",
    "silverservisernas": "silverservis",
    "silverservisers": "silverservis",
    "silverskedar": "silversked",
    "silverskedarna": "silversked",
    "silverskedarnas": "silversked",
    "silverskedars": "silversked",
    "silverskeden": "silversked",
    "silverskedens": "silversked",
    "silverskeds": "silversked",
    "silverslevar": "silverslev",
    "silverslevarna": "silverslev",
    "silverslevarnas": "silverslev",
    "silverslevars": "silverslev",
    "silversleven": "silverslev",
    "silverslevens": "silverslev",
    "silverslevs": "silverslev",
    "silversmeden": "silversmed",
    "silversmedens": "silversmed",
    "silversmeder": "silversmed",
    "silversmederna": "silversmed",
    "silversmedernas": "silversmed",
    "silversmeders": "silversmed",
    "silversmeds": "silversmed",
    "silversmiden": "silversmide",
    "silversmidena": "silversmide",
    "silversmidenas": "silversmide",
    "silversmidens": "silversmide",
    "silversmides": "silversmide",
    "silversmidet": "silversmide",
    "silversmidets": "silversmide",
    "silverstickade": "silverstickad",
    "silverstickades": "silverstickad",
    "silverstickads": "silverstickad",
    "silverstickat": "silverstickad",
    "silverstickats": "silverstickad",
    "silverstämpeln": "silverstämpel",
    "silverstämpelns": "silverstämpel",
    "silverstämpels": "silverstämpel",
    "silverstämplar": "silverstämpel",
    "silverstämplarna": "silverstämpel",
    "silverstämplarnas": "silverstämpel",
    "silverstämplars": "silverstämpel",
    "silvertack": "silvertacka",
    "silvertackan": "silvertacka",
    "silvertackans": "silvertacka",
    "silvertackas": "silvertacka",
    "silvertacke": "silvertacka",
    "silvertackor": "silvertacka",
    "silvertackorna": "silvertacka",
    "silvertackornas": "silvertacka",
    "silvertackors": "silvertacka",
    "silvertacks": "silvertacka",
    "silverteet": "silverte",
    "silverteets": "silverte",
    "silvertejpen": "silvertejp",
    "silvertejpens": "silvertejp",
    "silvertejps": "silvertejp",
    "silvertes": "silverte",
    "silvertet": "silverte",
    "silvertets": "silverte",
    "silvertrådar": "silvertråd",
    "silvertrådarna": "silvertråd",
    "silvertrådarnas": "silvertråd",
    "silvertrådars": "silvertråd",
    "silvertråden": "silvertråd",
    "silvertrådens": "silvertråd",
    "silvertråds": "silvertråd",
    "silvertärn": "silvertärna",
    "silvertärnan": "silvertärna",
    "silvertärnans": "silvertärna",
    "silvertärnas": "silvertärna",
    "silvertärne": "silvertärna",
    "silvertärnor": "silvertärna",
    "silvertärnorna": "silvertärna",
    "silvertärnornas": "silvertärna",
    "silvertärnors": "silvertärna",
    "silvertärns": "silvertärna",
    "silvervitts": "silvervitt",
    "silvervågen": "silvervåg",
    "silvervågens": "silvervåg",
    "silvervågor": "silvervåg",
    "silvervågorna": "silvervåg",
    "silvervågornas": "silvervåg",
    "silvervågors": "silvervåg",
    "silvervågs": "silvervåg",
    "silverörten": "silverört",
    "silverörtens": "silverört",
    "silverörts": "silverört",
    "silvrad": "silvra",
    "silvrade": "silvrad",
    "silvrades": "silvrad",
    "silvrads": "silvrad",
    "silvrande": "silvra",
    "silvranden": "silvrande",
    "silvrandena": "silvrande",
    "silvrandenas": "silvrande",
    "silvrandens": "silvrande",
    "silvrandes": "silvrande",
    "silvrandet": "silvrande",
    "silvrandets": "silvrande",
    "silvrar": "silvra",
    "silvras": "silvra",
    "silvrat": "silvrad",
    "silvrats": "silvrad",
    "silvren": "silver",
    "silvrens": "silver",
    "silvret": "silver",
    "silvrets": "silver",
    "silvriga": "silvrig",
    "silvrigare": "silvrig",
    "silvrigares": "silvrig",
    "silvrigas": "silvrig",
    "silvrigast": "silvrig",
    "silvrigaste": "silvrig",
    "silvrigastes": "silvrig",
    "silvrigasts": "silvrig",
    "silvrige": "silvrig",
    "silvriges": "silvrig",
    "silvrigheten": "silvrighet",
    "silvrighetens": "silvrighet",
    "silvrighets": "silvrighet",
    "silvrigs": "silvrig",
    "silvrigt": "silvrig",
    "silvrigts": "silvrig",
    "sim": "simma",
    "simanden": "simand",
    "simandens": "simand",
    "simands": "simand",
    "simbassängen": "simbassäng",
    "simbassängens": "simbassäng",
    "simbassänger": "simbassäng",
    "simbassängerna": "simbassäng",
    "simbassängernas": "simbassäng",
    "simbassängers": "simbassäng",
    "simbassängs": "simbassäng",
    "simblås": "simblåsa",
    "simblåsan": "simblåsa",
    "simblåsans": "simblåsa",
    "simblåsas": "simblåsa",
    "simblåse": "simblåsa",
    "simblåsor": "simblåsa",
    "simblåsorna": "simblåsa",
    "simblåsornas": "simblåsa",
    "simblåsors": "simblåsa",
    "simborgarmärken": "simborgarmärke",
    "simborgarmärkena": "simborgarmärke",
    "simborgarmärkenas": "simborgarmärke",
    "simborgarmärkens": "simborgarmärke",
    "simborgarmärkes": "simborgarmärke",
    "simborgarmärket": "simborgarmärke",
    "simborgarmärkets": "simborgarmärke",
    "simbyx": "simbyxa",
    "simbyxan": "simbyxa",
    "simbyxans": "simbyxa",
    "simbyxas": "simbyxa",
    "simbyxe": "simbyxa",
    "simbyxor": "simbyxa",
    "simbyxorna": "simbyxa",
    "simbyxornas": "simbyxa",
    "simbyxors": "simbyxa",
    "simbälten": "simbälte",
    "simbältena": "simbälte",
    "simbältenas": "simbälte",
    "simbältens": "simbälte",
    "simbältes": "simbälte",
    "simbältet": "simbälte",
    "simbältets": "simbälte",
    "simdräkten": "simdräkt",
    "simdräktens": "simdräkt",
    "simdräkter": "simdräkt",
    "simdräkterna": "simdräkt",
    "simdräkternas": "simdräkt",
    "simdräkters": "simdräkt",
    "simdräkts": "simdräkt",
    "simdyn": "simdyna",
    "simdynan": "simdyna",
    "simdynans": "simdyna",
    "simdynas": "simdyna",
    "simdyne": "simdyna",
    "simdynor": "simdyna",
    "simdynorna": "simdyna",
    "simdynornas": "simdyna",
    "simdynors": "simdyna",
    "simdyns": "simdyna",
    "simfen": "simfena",
    "simfenan": "simfena",
    "simfenans": "simfena",
    "simfenas": "simfena",
    "simfene": "simfena",
    "simfenor": "simfena",
    "simfenorna": "simfena",
    "simfenornas": "simfena",
    "simfenors": "simfena",
    "simfens": "simfena",
    "simflott": "simflotte",
    "simflottar": "simflotte",
    "simflottarna": "simflotte",
    "simflottarnas": "simflotte",
    "simflottars": "simflotte",
    "simflotten": "simflotte",
    "simflottens": "simflotte",
    "simflottes": "simflotte",
    "simflotts": "simflotte",
    "simfoten": "simfot",
    "simfotens": "simfot",
    "simfots": "simfot",
    "simfågeln": "simfågel",
    "simfågelns": "simfågel",
    "simfågels": "simfågel",
    "simfåglar": "simfågel",
    "simfåglarna": "simfågel",
    "simfåglarnas": "simfågel",
    "simfåglars": "simfågel",
    "simfötter": "simfot",
    "simfötterna": "simfot",
    "simfötternas": "simfot",
    "simfötters": "simfot",
    "simhallar": "simhall",
    "simhallarna": "simhall",
    "simhallarnas": "simhall",
    "simhallars": "simhall",
    "simhallen": "simhall",
    "simhallens": "simhall",
    "simhalls": "simhall",
    "simhallstaken": "simhallstak",
    "simhallstakens": "simhallstak",
    "simhallstaket": "simhallstak",
    "simhallstakets": "simhallstak",
    "simhallstaks": "simhallstak",
    "simhoppen": "simhopp",
    "simhoppens": "simhopp",
    "simhoppet": "simhopp",
    "simhoppets": "simhopp",
    "simhopps": "simhopp",
    "simhuden": "simhud",
    "simhudens": "simhud",
    "simhuds": "simhud",
    "similin": "simili",
    "similins": "simili",
    "similis": "simili",
    "similit": "simili",
    "similits": "simili",
    "simkandidaten": "simkandidat",
    "simkandidatens": "simkandidat",
    "simkandidater": "simkandidat",
    "simkandidaterna": "simkandidat",
    "simkandidaternas": "simkandidat",
    "simkandidaters": "simkandidat",
    "simkandidats": "simkandidat",
    "simklubbar": "simklubb",
    "simklubbarna": "simklubb",
    "simklubbarnas": "simklubb",
    "simklubbars": "simklubb",
    "simklubben": "simklubb",
    "simklubbens": "simklubb",
    "simklubbs": "simklubb",
    "simkunniga": "simkunnig",
    "simkunnigare": "simkunnig",
    "simkunnigares": "simkunnig",
    "simkunnigas": "simkunnig",
    "simkunnigast": "simkunnig",
    "simkunnigaste": "simkunnig",
    "simkunnigastes": "simkunnig",
    "simkunnigasts": "simkunnig",
    "simkunnige": "simkunnig",
    "simkunniges": "simkunnig",
    "simkunnigheten": "simkunnighet",
    "simkunnighetens": "simkunnighet",
    "simkunnighets": "simkunnighet",
    "simkunnigs": "simkunnig",
    "simkunnigt": "simkunnig",
    "simkunnigts": "simkunnig",
    "simlärar": "simlärare",
    "simläraren": "simlärare",
    "simlärarens": "simlärare",
    "simlärares": "simlärare",
    "simlärarna": "simlärare",
    "simlärarnas": "simlärare",
    "simmad": "simma",
    "simmade": "simma",
    "simmades": "simma",
    "simmads": "simma",
    "simmagistern": "simmagister",
    "simmagisterns": "simmagister",
    "simmagisters": "simmagister",
    "simmagistrar": "simmagister",
    "simmagistrarna": "simmagister",
    "simmagistrarnas": "simmagister",
    "simmagistrars": "simmagister",
    "simmande": "simma",
    "simmanden": "simmande",
    "simmandena": "simmande",
    "simmandenas": "simmande",
    "simmandens": "simmande",
    "simmandes": "simmande",
    "simmandet": "simmande",
    "simmandets": "simmande",
    "simmar": "simmare",
    "simmaren": "simmare",
    "simmarens": "simmare",
    "simmares": "simmare",
    "simmarna": "simmare",
    "simmarnas": "simmare",
    "simmas": "simma",
    "simmat": "simma",
    "simmats": "simma",
    "simme": "simma",
    "simmes": "simma",
    "simmiga": "simmig",
    "simmigare": "simmig",
    "simmigares": "simmig",
    "simmigas": "simmig",
    "simmigast": "simmig",
    "simmigaste": "simmig",
    "simmigastes": "simmig",
    "simmigasts": "simmig",
    "simmige": "simmig",
    "simmiges": "simmig",
    "simmigheten": "simmighet",
    "simmighetens": "simmighet",
    "simmighets": "simmighet",
    "simmigs": "simmig",
    "simmigt": "simmig",
    "simmigts": "simmig",
    "simmärken": "simmärke",
    "simmärkena": "simmärke",
    "simmärkenas": "simmärke",
    "simmärkens": "simmärke",
    "simmärkes": "simmärke",
    "simmärket": "simmärke",
    "simmärkets": "simmärke",
    "simningar": "simning",
    "simningarna": "simning",
    "simningarnas": "simning",
    "simningars": "simning",
    "simningen": "simning",
    "simningens": "simning",
    "simnings": "simning",
    "simonien": "simoni",
    "simoniens": "simoni",
    "simonin": "simoni",
    "simonins": "simoni",
    "simonis": "simoni",
    "simorganen": "simorgan",
    "simorganens": "simorgan",
    "simorganet": "simorgan",
    "simorganets": "simorgan",
    "simorgans": "simorgan",
    "simp": "simpa",
    "simpan": "simpa",
    "simpans": "simpa",
    "simpas": "simpa",
    "simpe": "simpa",
    "simpelkortet": "simpelkort",
    "simpelkortets": "simpelkort",
    "simpelkorts": "simpelkort",
    "simpels": "simpel",
    "simpelt": "simpel",
    "simpelts": "simpel",
    "simpla": "simpel",
    "simplare": "simpel",
    "simplares": "simpel",
    "simplas": "simpel",
    "simplast": "simpel",
    "simplaste": "simpel",
    "simplastes": "simpel",
    "simplasts": "simpel",
    "simple": "simpel",
    "simples": "simpel",
    "simplexen": "simplex",
    "simplexens": "simplex",
    "simplexet": "simplex",
    "simplexets": "simplex",
    "simplexpål": "simplexpåle",
    "simplexpålar": "simplexpåle",
    "simplexpålarna": "simplexpåle",
    "simplexpålarnas": "simplexpåle",
    "simplexpålars": "simplexpåle",
    "simplexpålen": "simplexpåle",
    "simplexpålens": "simplexpåle",
    "simplexpåles": "simplexpåle",
    "simplexpåls": "simplexpåle",
    "simplextelegrafien": "simplextelegrafi",
    "simplextelegrafiens": "simplextelegrafi",
    "simplextelegrafin": "simplextelegrafi",
    "simplextelegrafins": "simplextelegrafi",
    "simplextelegrafis": "simplextelegrafi",
    "simplextrafiken": "simplextrafik",
    "simplextrafikens": "simplextrafik",
    "simplextrafiks": "simplextrafik",
    "simplifierad": "simplifiera",
    "simplifierade": "simplifiera",
    "simplifierades": "simplifiera",
    "simplifierads": "simplifiera",
    "simplifierande": "simplifiera",
    "simplifieranden": "simplifierande",
    "simplifierandena": "simplifierande",
    "simplifierandenas": "simplifierande",
    "simplifierandens": "simplifierande",
    "simplifierandes": "simplifierande",
    "simplifierandet": "simplifierande",
    "simplifierandets": "simplifierande",
    "simplifierar": "simplifiera",
    "simplifieras": "simplifiera",
    "simplifierat": "simplifiera",
    "simplifierats": "simplifiera",
    "simplifierbara": "simplifierbar",
    "simplifierbarare": "simplifierbar",
    "simplifierbarares": "simplifierbar",
    "simplifierbaras": "simplifierbar",
    "simplifierbarast": "simplifierbar",
    "simplifierbaraste": "simplifierbar",
    "simplifierbarastes": "simplifierbar",
    "simplifierbarasts": "simplifierbar",
    "simplifierbare": "simplifierbar",
    "simplifierbares": "simplifierbar",
    "simplifierbarheten": "simplifierbarhet",
    "simplifierbarhetens": "simplifierbarhet",
    "simplifierbarhets": "simplifierbarhet",
    "simplifierbars": "simplifierbar",
    "simplifierbart": "simplifierbar",
    "simplifierbarts": "simplifierbar",
    "simplifieringar": "simplifiering",
    "simplifieringarna": "simplifiering",
    "simplifieringarnas": "simplifiering",
    "simplifieringars": "simplifiering",
    "simplifieringen": "simplifiering",
    "simplifieringens": "simplifiering",
    "simplifierings": "simplifiering",
    "simpor": "simpa",
    "simporna": "simpa",
    "simpornas": "simpa",
    "simpors": "simpa",
    "simpromotionen": "simpromotion",
    "simpromotionens": "simpromotion",
    "simpromotioner": "simpromotion",
    "simpromotionerna": "simpromotion",
    "simpromotionernas": "simpromotion",
    "simpromotioners": "simpromotion",
    "simpromotions": "simpromotion",
    "simproven": "simprov",
    "simprovens": "simprov",
    "simprovet": "simprov",
    "simprovets": "simprov",
    "simprovs": "simprov",
    "simps": "simpa",
    "sims": "simsa",
    "simsad": "simsa",
    "simsade": "simsa",
    "simsades": "simsa",
    "simsads": "simsa",
    "simsande": "simsa",
    "simsanden": "simsande",
    "simsandena": "simsande",
    "simsandenas": "simsande",
    "simsandens": "simsande",
    "simsandes": "simsande",
    "simsandet": "simsande",
    "simsandets": "simsande",
    "simsar": "simsa",
    "simsas": "simsa",
    "simsat": "simsa",
    "simsats": "simsa",
    "simsen": "sims",
    "simsens": "sims",
    "simser": "sims",
    "simserna": "sims",
    "simsernas": "sims",
    "simsers": "sims",
    "simshyveln": "simshyvel",
    "simshyvelns": "simshyvel",
    "simshyvels": "simshyvel",
    "simshyvlar": "simshyvel",
    "simshyvlarna": "simshyvel",
    "simshyvlarnas": "simshyvel",
    "simshyvlars": "simshyvel",
    "simskolan": "simskola",
    "simskolans": "simskola",
    "simskolas": "simskola",
    "simskole": "simskola",
    "simskolor": "simskola",
    "simskolorna": "simskola",
    "simskolornas": "simskola",
    "simskolors": "simskola",
    "simsnäpp": "simsnäppa",
    "simsnäppan": "simsnäppa",
    "simsnäppans": "simsnäppa",
    "simsnäppas": "simsnäppa",
    "simsnäppe": "simsnäppa",
    "simsnäppor": "simsnäppa",
    "simsnäpporna": "simsnäppa",
    "simsnäppornas": "simsnäppa",
    "simsnäppors": "simsnäppa",
    "simsnäpps": "simsnäppa",
    "simsätten": "simsätt",
    "simsättens": "simsätt",
    "simsättet": "simsätt",
    "simsättets": "simsätt",
    "simsätts": "simsätt",
    "simtagen": "simtag",
    "simtagens": "simtag",
    "simtaget": "simtag",
    "simtagets": "simtag",
    "simtags": "simtag",
    "simträningar": "simträning",
    "simträningarna": "simträning",
    "simträningarnas": "simträning",
    "simträningars": "simträning",
    "simträningen": "simträning",
    "simträningens": "simträning",
    "simtränings": "simträning",
    "simturen": "simtur",
    "simturens": "simtur",
    "simturer": "simtur",
    "simturerna": "simtur",
    "simturernas": "simtur",
    "simturers": "simtur",
    "simturs": "simtur",
    "simtävlingar": "simtävling",
    "simtävlingarna": "simtävling",
    "simtävlingarnas": "simtävling",
    "simtävlingars": "simtävling",
    "simtävlingen": "simtävling",
    "simtävlingens": "simtävling",
    "simtävlings": "simtävling",
    "simulanten": "simulant",
    "simulantens": "simulant",
    "simulanter": "simulant",
    "simulanterna": "simulant",
    "simulanternas": "simulant",
    "simulanters": "simulant",
    "simulants": "simulant",
    "simulationen": "simulation",
    "simulationens": "simulation",
    "simulationer": "simulation",
    "simulationerna": "simulation",
    "simulationernas": "simulation",
    "simulationers": "simulation",
    "simulations": "simulation",
    "simulatorer": "simulator",
    "simulatorerna": "simulator",
    "simulatorernas": "simulator",
    "simulatorers": "simulator",
    "simulatorn": "simulator",
    "simulatorns": "simulator",
    "simulators": "simulator",
    "simulerad": "simulera",
    "simulerade": "simulera",
    "simulerades": "simulera",
    "simulerads": "simulera",
    "simulerande": "simulera",
    "simuleranden": "simulerande",
    "simulerandena": "simulerande",
    "simulerandenas": "simulerande",
    "simulerandens": "simulerande",
    "simulerandes": "simulerande",
    "simulerandet": "simulerande",
    "simulerandets": "simulerande",
    "simulerar": "simulera",
    "simuleras": "simulera",
    "simulerat": "simulera",
    "simulerats": "simulera",
    "simulerbara": "simulerbar",
    "simulerbarare": "simulerbar",
    "simulerbarares": "simulerbar",
    "simulerbaras": "simulerbar",
    "simulerbarast": "simulerbar",
    "simulerbaraste": "simulerbar",
    "simulerbarastes": "simulerbar",
    "simulerbarasts": "simulerbar",
    "simulerbare": "simulerbar",
    "simulerbares": "simulerbar",
    "simulerbarheten": "simulerbarhet",
    "simulerbarhetens": "simulerbarhet",
    "simulerbarhets": "simulerbarhet",
    "simulerbars": "simulerbar",
    "simulerbart": "simulerbar",
    "simulerbarts": "simulerbar",
    "simuleringar": "simulering",
    "simuleringarna": "simulering",
    "simuleringarnas": "simulering",
    "simuleringars": "simulering",
    "simuleringen": "simulering",
    "simuleringens": "simulering",
    "simulerings": "simulering",
    "simultana": "simultan",
    "simultanare": "simultan",
    "simultanares": "simultan",
    "simultanas": "simultan",
    "simultanast": "simultan",
    "simultanaste": "simultan",
    "simultanastes": "simultan",
    "simultanasts": "simultan",
    "simultane": "simultan",
    "simultanes": "simultan",
    "simultanismen": "simultanism",
    "simultanismens": "simultanism",
    "simultanismer": "simultanism",
    "simultanismerna": "simultanism",
    "simultanismernas": "simultanism",
    "simultanismers": "simultanism",
    "simultanisms": "simultanism",
    "simultans": "simultan",
    "simultanscenen": "simultanscen",
    "simultanscenens": "simultanscen",
    "simultanscener": "simultanscen",
    "simultanscenerna": "simultanscen",
    "simultanscenernas": "simultanscen",
    "simultansceners": "simultanscen",
    "simultanscens": "simultanscen",
    "simultanschacket": "simultanschack",
    "simultanschackets": "simultanschack",
    "simultanschacks": "simultanschack",
    "simultant": "simultan",
    "simultantolk": "simultantolka",
    "simultantolkad": "simultantolka",
    "simultantolkade": "simultantolka",
    "simultantolkades": "simultantolka",
    "simultantolkads": "simultantolka",
    "simultantolkande": "simultantolka",
    "simultantolkanden": "simultantolkande",
    "simultantolkandena": "simultantolkande",
    "simultantolkandenas": "simultantolkande",
    "simultantolkandens": "simultantolkande",
    "simultantolkandes": "simultantolkande",
    "simultantolkandet": "simultantolkande",
    "simultantolkandets": "simultantolkande",
    "simultantolkar": "simultantolka",
    "simultantolkarna": "simultantolk",
    "simultantolkarnas": "simultantolk",
    "simultantolkars": "simultantolk",
    "simultantolkas": "simultantolka",
    "simultantolkat": "simultantolka",
    "simultantolkats": "simultantolka",
    "simultantolken": "simultantolk",
    "simultantolkens": "simultantolk",
    "simultantolkningar": "simultantolkning",
    "simultantolkningarna": "simultantolkning",
    "simultantolkningarnas": "simultantolkning",
    "simultantolkningars": "simultantolkning",
    "simultantolkningen": "simultantolkning",
    "simultantolkningens": "simultantolkning",
    "simultantolknings": "simultantolkning",
    "simultantolks": "simultantolk",
    "simultants": "simultan",
    "simänder": "simand",
    "simänderna": "simand",
    "simändernas": "simand",
    "simänders": "simand",
    "sin": "sina",
    "sina": "sig",
    "sinade": "sina",
    "sinades": "sina",
    "sinande": "sina",
    "sinanden": "sinande",
    "sinandena": "sinande",
    "sinandenas": "sinande",
    "sinandens": "sinande",
    "sinandes": "sinande",
    "sinandet": "sinande",
    "sinandets": "sinande",
    "sinar": "sina",
    "sinas": "sina",
    "sinat": "sina",
    "sinats": "sina",
    "sinders": "sinder",
    "sindren": "sinder",
    "sindrens": "sinder",
    "sindret": "sinder",
    "sindrets": "sinder",
    "sinekuren": "sinekur",
    "sinekurens": "sinekur",
    "sinekurer": "sinekur",
    "sinekurerna": "sinekur",
    "sinekurernas": "sinekur",
    "sinekurers": "sinekur",
    "sinekurs": "sinekur",
    "sinfoni": "sinfonia",
    "sinfonian": "sinfonia",
    "sinfonians": "sinfonia",
    "sinfonias": "sinfonia",
    "sinfonie": "sinfonia",
    "sinfonior": "sinfonia",
    "sinfoniorna": "sinfonia",
    "sinfoniornas": "sinfonia",
    "sinfoniors": "sinfonia",
    "sinfonis": "sinfonia",
    "singalesen": "singales",
    "singalesens": "singales",
    "singaleser": "singales",
    "singaleserna": "singales",
    "singalesernas": "singales",
    "singalesers": "singales",
    "singalesisk": "singalesiska",
    "singalesiska": "singalesisk",
    "singalesiskan": "singalesiska",
    "singalesiskans": "singalesiska",
    "singalesiskare": "singalesisk",
    "singalesiskares": "singalesisk",
    "singalesiskas": "singalesiska",
    "singalesiskast": "singalesisk",
    "singalesiskaste": "singalesisk",
    "singalesiskastes": "singalesisk",
    "singalesiskasts": "singalesisk",
    "singalesiske": "singalesiska",
    "singalesiskes": "singalesisk",
    "singalesiskor": "singalesiska",
    "singalesiskorna": "singalesiska",
    "singalesiskornas": "singalesiska",
    "singalesiskors": "singalesiska",
    "singalesisks": "singalesisk",
    "singalesiskt": "singalesisk",
    "singalesiskts": "singalesisk",
    "singaporianen": "singaporian",
    "singaporianens": "singaporian",
    "singaporianer": "singaporian",
    "singaporianerna": "singaporian",
    "singaporianernas": "singaporian",
    "singaporianers": "singaporian",
    "singaporians": "singaporian",
    "singaporianskan": "singaporianska",
    "singaporianskans": "singaporianska",
    "singaporianskas": "singaporianska",
    "singaporianske": "singaporianska",
    "singaporianskor": "singaporianska",
    "singaporianskorna": "singaporianska",
    "singaporianskornas": "singaporianska",
    "singaporianskors": "singaporianska",
    "singel": "singla",
    "singelmamman": "singelmamma",
    "singelmammans": "singelmamma",
    "singelmammas": "singelmamma",
    "singelmamme": "singelmamma",
    "singelmammor": "singelmamma",
    "singelmammorna": "singelmamma",
    "singelmammornas": "singelmamma",
    "singelmammors": "singelmamma",
    "singeln": "singel",
    "singelns": "singel",
    "singelolyck": "singelolycka",
    "singelolyckan": "singelolycka",
    "singelolyckans": "singelolycka",
    "singelolyckas": "singelolycka",
    "singelolycke": "singelolycka",
    "singelolyckor": "singelolycka",
    "singelolyckorna": "singelolycka",
    "singelolyckornas": "singelolycka",
    "singelolyckors": "singelolycka",
    "singelolycks": "singelolycka",
    "singels": "singel",
    "singelspelen": "singelspel",
    "singelspelens": "singelspel",
    "singelspelet": "singelspel",
    "singelspelets": "singelspel",
    "singelspels": "singelspel",
    "singlade": "singla",
    "singlades": "singla",
    "singlande": "singla",
    "singlanden": "singlande",
    "singlandena": "singlande",
    "singlandenas": "singlande",
    "singlandens": "singlande",
    "singlandes": "singlande",
    "singlandet": "singlande",
    "singlandets": "singlande",
    "singlar": "singla",
    "singlarna": "singel",
    "singlarnas": "singel",
    "singlars": "singel",
    "singlas": "singla",
    "singlat": "singla",
    "singlats": "singla",
    "singlet": "singel",
    "singlets": "singel",
    "singulara": "singular",
    "singularare": "singular",
    "singularares": "singular",
    "singularas": "singular",
    "singularast": "singular",
    "singularaste": "singular",
    "singularastes": "singular",
    "singularasts": "singular",
    "singulare": "singular",
    "singularen": "singular",
    "singularens": "singular",
    "singularer": "singular",
    "singularerna": "singular",
    "singularernas": "singular",
    "singularers": "singular",
    "singulares": "singular",
    "singularisen": "singularis",
    "singularisens": "singularis",
    "singulariteten": "singularitet",
    "singularitetens": "singularitet",
    "singulariteter": "singularitet",
    "singulariteterna": "singularitet",
    "singulariteternas": "singularitet",
    "singulariteters": "singularitet",
    "singularitets": "singularitet",
    "singulars": "singular",
    "singulart": "singular",
    "singularts": "singular",
    "singuljära": "singuljär",
    "singuljärare": "singuljär",
    "singuljärares": "singuljär",
    "singuljäras": "singuljär",
    "singuljärast": "singuljär",
    "singuljäraste": "singuljär",
    "singuljärastes": "singuljär",
    "singuljärasts": "singuljär",
    "singuljäre": "singuljär",
    "singuljäres": "singuljär",
    "singuljärs": "singuljär",
    "singuljärt": "singuljär",
    "singuljärts": "singuljär",
    "singulära": "singulär",
    "singulärare": "singulär",
    "singulärares": "singulär",
    "singuläras": "singulär",
    "singulärast": "singulär",
    "singuläraste": "singulär",
    "singulärastes": "singulär",
    "singulärasts": "singulär",
    "singuläre": "singulär",
    "singuläres": "singulär",
    "singulärs": "singulär",
    "singulärt": "singulär",
    "singulärts": "singulär",
    "sinisterheten": "sinisterhet",
    "sinisterhetens": "sinisterhet",
    "sinisterhets": "sinisterhet",
    "sinisters": "sinister",
    "sinistert": "sinister",
    "sinisterts": "sinister",
    "sinistra": "sinister",
    "sinistrare": "sinister",
    "sinistrares": "sinister",
    "sinistras": "sinister",
    "sinistrast": "sinister",
    "sinistraste": "sinister",
    "sinistrastes": "sinister",
    "sinistrasts": "sinister",
    "sinistre": "sinister",
    "sinistres": "sinister",
    "sink": "sinka",
    "sinkabirums": "sinkabirum",
    "sinkad": "sinka",
    "sinkade": "sinka",
    "sinkades": "sinka",
    "sinkads": "sinka",
    "sinkadusen": "sinkadus",
    "sinkadusens": "sinkadus",
    "sinkaduser": "sinkadus",
    "sinkaduserna": "sinkadus",
    "sinkadusernas": "sinkadus",
    "sinkadusers": "sinkadus",
    "sinkande": "sinka",
    "sinkanden": "sinkande",
    "sinkandena": "sinkande",
    "sinkandenas": "sinkande",
    "sinkandens": "sinkande",
    "sinkandes": "sinkande",
    "sinkandet": "sinkande",
    "sinkandets": "sinkande",
    "sinkar": "sinka",
    "sinkas": "sinka",
    "sinkat": "sinka",
    "sinkats": "sinka",
    "sinket": "sink",
    "sinkets": "sink",
    "sinks": "sink",
    "sinnade": "sinnad",
    "sinnades": "sinnad",
    "sinnads": "sinnad",
    "sinnat": "sinnad",
    "sinnats": "sinnad",
    "sinnebilden": "sinnebild",
    "sinnebildens": "sinnebild",
    "sinnebilder": "sinnebild",
    "sinnebilderna": "sinnebild",
    "sinnebildernas": "sinnebild",
    "sinnebilders": "sinnebild",
    "sinnebilds": "sinnebild",
    "sinnelaget": "sinnelag",
    "sinnelagets": "sinnelag",
    "sinnelags": "sinnelag",
    "sinnen": "sinne",
    "sinnena": "sinne",
    "sinnenas": "sinne",
    "sinnens": "sinne",
    "sinnes": "sinne",
    "sinnesanalogien": "sinnesanalogi",
    "sinnesanalogiens": "sinnesanalogi",
    "sinnesanalogier": "sinnesanalogi",
    "sinnesanalogierna": "sinnesanalogi",
    "sinnesanalogiernas": "sinnesanalogi",
    "sinnesanalogiers": "sinnesanalogi",
    "sinnesanalogin": "sinnesanalogi",
    "sinnesanalogins": "sinnesanalogi",
    "sinnesanalogis": "sinnesanalogi",
    "sinnescellen": "sinnescell",
    "sinnescellens": "sinnescell",
    "sinnesceller": "sinnescell",
    "sinnescellerna": "sinnescell",
    "sinnescellernas": "sinnescell",
    "sinnescellers": "sinnescell",
    "sinnescells": "sinnescell",
    "sinnesfriden": "sinnesfrid",
    "sinnesfridens": "sinnesfrid",
    "sinnesfrids": "sinnesfrid",
    "sinnesförfattningar": "sinnesförfattning",
    "sinnesförfattningarna": "sinnesförfattning",
    "sinnesförfattningarnas": "sinnesförfattning",
    "sinnesförfattningars": "sinnesförfattning",
    "sinnesförfattningen": "sinnesförfattning",
    "sinnesförfattningens": "sinnesförfattning",
    "sinnesförfattnings": "sinnesförfattning",
    "sinnesförnimmelsen": "sinnesförnimmelse",
    "sinnesförnimmelsens": "sinnesförnimmelse",
    "sinnesförnimmelser": "sinnesförnimmelse",
    "sinnesförnimmelserna": "sinnesförnimmelse",
    "sinnesförnimmelsernas": "sinnesförnimmelse",
    "sinnesförnimmelsers": "sinnesförnimmelse",
    "sinnesförnimmelses": "sinnesförnimmelse",
    "sinnesförvirrade": "sinnesförvirrad",
    "sinnesförvirrades": "sinnesförvirrad",
    "sinnesförvirrads": "sinnesförvirrad",
    "sinnesförvirrat": "sinnesförvirrad",
    "sinnesförvirrats": "sinnesförvirrad",
    "sinnesförvirringar": "sinnesförvirring",
    "sinnesförvirringarna": "sinnesförvirring",
    "sinnesförvirringarnas": "sinnesförvirring",
    "sinnesförvirringars": "sinnesförvirring",
    "sinnesförvirringen": "sinnesförvirring",
    "sinnesförvirringens": "sinnesförvirring",
    "sinnesförvirrings": "sinnesförvirring",
    "sinnesglädjen": "sinnesglädje",
    "sinnesglädjens": "sinnesglädje",
    "sinnesglädjes": "sinnesglädje",
    "sinnesintrycken": "sinnesintryck",
    "sinnesintryckens": "sinnesintryck",
    "sinnesintrycket": "sinnesintryck",
    "sinnesintryckets": "sinnesintryck",
    "sinnesintrycks": "sinnesintryck",
    "sinneslugnet": "sinneslugn",
    "sinneslugnets": "sinneslugn",
    "sinneslugns": "sinneslugn",
    "sinnesnerven": "sinnesnerv",
    "sinnesnervens": "sinnesnerv",
    "sinnesnerver": "sinnesnerv",
    "sinnesnerverna": "sinnesnerv",
    "sinnesnervernas": "sinnesnerv",
    "sinnesnervers": "sinnesnerv",
    "sinnesnervs": "sinnesnerv",
    "sinnesnärvaron": "sinnesnärvaro",
    "sinnesnärvarons": "sinnesnärvaro",
    "sinnesnärvaros": "sinnesnärvaro",
    "sinnesorganen": "sinnesorgan",
    "sinnesorganens": "sinnesorgan",
    "sinnesorganet": "sinnesorgan",
    "sinnesorganets": "sinnesorgan",
    "sinnesorgans": "sinnesorgan",
    "sinnesrubbade": "sinnesrubbad",
    "sinnesrubbades": "sinnesrubbad",
    "sinnesrubbads": "sinnesrubbad",
    "sinnesrubbat": "sinnesrubbad",
    "sinnesrubbats": "sinnesrubbad",
    "sinnesrubbningar": "sinnesrubbning",
    "sinnesrubbningarna": "sinnesrubbning",
    "sinnesrubbningarnas": "sinnesrubbning",
    "sinnesrubbningars": "sinnesrubbning",
    "sinnesrubbningen": "sinnesrubbning",
    "sinnesrubbningens": "sinnesrubbning",
    "sinnesrubbnings": "sinnesrubbning",
    "sinnesrörelsen": "sinnesrörelse",
    "sinnesrörelsens": "sinnesrörelse",
    "sinnesrörelser": "sinnesrörelse",
    "sinnesrörelserna": "sinnesrörelse",
    "sinnesrörelsernas": "sinnesrörelse",
    "sinnesrörelsers": "sinnesrörelse",
    "sinnesrörelses": "sinnesrörelse",
    "sinnessjuka": "sinnessjuk",
    "sinnessjukare": "sinnessjuk",
    "sinnessjukares": "sinnessjuk",
    "sinnessjukas": "sinnessjuk",
    "sinnessjukast": "sinnessjuk",
    "sinnessjukaste": "sinnessjuk",
    "sinnessjukastes": "sinnessjuk",
    "sinnessjukasts": "sinnessjuk",
    "sinnessjukdomar": "sinnessjukdom",
    "sinnessjukdomarna": "sinnessjukdom",
    "sinnessjukdomarnas": "sinnessjukdom",
    "sinnessjukdomars": "sinnessjukdom",
    "sinnessjukdomen": "sinnessjukdom",
    "sinnessjukdomens": "sinnessjukdom",
    "sinnessjukdoms": "sinnessjukdom",
    "sinnessjuke": "sinnessjuk",
    "sinnessjukes": "sinnessjuk",
    "sinnessjukheten": "sinnessjukhet",
    "sinnessjukhetens": "sinnessjukhet",
    "sinnessjukhets": "sinnessjukhet",
    "sinnessjukhusen": "sinnessjukhus",
    "sinnessjukhusens": "sinnessjukhus",
    "sinnessjukhuset": "sinnessjukhus",
    "sinnessjukhusets": "sinnessjukhus",
    "sinnessjukläkar": "sinnessjukläkare",
    "sinnessjukläkaren": "sinnessjukläkare",
    "sinnessjukläkarens": "sinnessjukläkare",
    "sinnessjukläkares": "sinnessjukläkare",
    "sinnessjukläkarna": "sinnessjukläkare",
    "sinnessjukläkarnas": "sinnessjukläkare",
    "sinnessjuks": "sinnessjuk",
    "sinnessjukt": "sinnessjuk",
    "sinnessjukts": "sinnessjuk",
    "sinnessjukvården": "sinnessjukvård",
    "sinnessjukvårdens": "sinnessjukvård",
    "sinnessjukvårds": "sinnessjukvård",
    "sinnesslöa": "sinnesslö",
    "sinnesslöare": "sinnesslö",
    "sinnesslöares": "sinnesslö",
    "sinnesslöas": "sinnesslö",
    "sinnesslöast": "sinnesslö",
    "sinnesslöaste": "sinnesslö",
    "sinnesslöastes": "sinnesslö",
    "sinnesslöasts": "sinnesslö",
    "sinnesslöe": "sinnesslö",
    "sinnesslöes": "sinnesslö",
    "sinnesslös": "sinnesslö",
    "sinnesslött": "sinnesslö",
    "sinnesslötts": "sinnesslö",
    "sinnesstämningar": "sinnesstämning",
    "sinnesstämningarna": "sinnesstämning",
    "sinnesstämningarnas": "sinnesstämning",
    "sinnesstämningars": "sinnesstämning",
    "sinnesstämningen": "sinnesstämning",
    "sinnesstämningens": "sinnesstämning",
    "sinnesstämnings": "sinnesstämning",
    "sinnessvaga": "sinnessvag",
    "sinnessvagare": "sinnessvag",
    "sinnessvagares": "sinnessvag",
    "sinnessvagas": "sinnessvag",
    "sinnessvagast": "sinnessvag",
    "sinnessvagaste": "sinnessvag",
    "sinnessvagastes": "sinnessvag",
    "sinnessvagasts": "sinnessvag",
    "sinnessvage": "sinnessvag",
    "sinnessvages": "sinnessvag",
    "sinnessvagheten": "sinnessvaghet",
    "sinnessvaghetens": "sinnessvaghet",
    "sinnessvaghets": "sinnessvaghet",
    "sinnessvags": "sinnessvag",
    "sinnessvagt": "sinnessvag",
    "sinnessvagts": "sinnessvag",
    "sinnesundersökningar": "sinnesundersökning",
    "sinnesundersökningarna": "sinnesundersökning",
    "sinnesundersökningarnas": "sinnesundersökning",
    "sinnesundersökningars": "sinnesundersökning",
    "sinnesundersökningen": "sinnesundersökning",
    "sinnesundersökningens": "sinnesundersökning",
    "sinnesundersöknings": "sinnesundersökning",
    "sinnesupplevelsen": "sinnesupplevelse",
    "sinnesupplevelsens": "sinnesupplevelse",
    "sinnesupplevelser": "sinnesupplevelse",
    "sinnesupplevelserna": "sinnesupplevelse",
    "sinnesupplevelsernas": "sinnesupplevelse",
    "sinnesupplevelsers": "sinnesupplevelse",
    "sinnesupplevelses": "sinnesupplevelse",
    "sinnesvill": "sinnesvilla",
    "sinnesvillan": "sinnesvilla",
    "sinnesvillans": "sinnesvilla",
    "sinnesvillas": "sinnesvilla",
    "sinnesville": "sinnesvilla",
    "sinnesvillor": "sinnesvilla",
    "sinnesvillorna": "sinnesvilla",
    "sinnesvillornas": "sinnesvilla",
    "sinnesvillors": "sinnesvilla",
    "sinnesvills": "sinnesvilla",
    "sinnet": "sinne",
    "sinnets": "sinne",
    "sinnevärlden": "sinnevärld",
    "sinnevärldens": "sinnevärld",
    "sinnevärlds": "sinnevärld",
    "sinnliga": "sinnlig",
    "sinnligare": "sinnlig",
    "sinnligares": "sinnlig",
    "sinnligas": "sinnlig",
    "sinnligast": "sinnlig",
    "sinnligaste": "sinnlig",
    "sinnligastes": "sinnlig",
    "sinnligasts": "sinnlig",
    "sinnlige": "sinnlig",
    "sinnliges": "sinnlig",
    "sinnligheten": "sinnlighet",
    "sinnlighetens": "sinnlighet",
    "sinnligheter": "sinnlighet",
    "sinnligheterna": "sinnlighet",
    "sinnligheternas": "sinnlighet",
    "sinnligheters": "sinnlighet",
    "sinnlighets": "sinnlighet",
    "sinnligs": "sinnlig",
    "sinnligt": "sinnlig",
    "sinnligts": "sinnlig",
    "sinnrika": "sinnrik",
    "sinnrikare": "sinnrik",
    "sinnrikares": "sinnrik",
    "sinnrikas": "sinnrik",
    "sinnrikast": "sinnrik",
    "sinnrikaste": "sinnrik",
    "sinnrikastes": "sinnrik",
    "sinnrikasts": "sinnrik",
    "sinnrike": "sinnrik",
    "sinnrikes": "sinnrik",
    "sinnrikheten": "sinnrikhet",
    "sinnrikhetens": "sinnrikhet",
    "sinnrikhets": "sinnrikhet",
    "sinnriks": "sinnrik",
    "sinnrikt": "sinnrik",
    "sinnrikts": "sinnrik",
    "sinologen": "sinolog",
    "sinologens": "sinolog",
    "sinologer": "sinolog",
    "sinologerna": "sinolog",
    "sinologernas": "sinolog",
    "sinologers": "sinolog",
    "sinologien": "sinologi",
    "sinologiens": "sinologi",
    "sinologin": "sinologi",
    "sinologins": "sinologi",
    "sinologis": "sinologi",
    "sinologs": "sinolog",
    "sinter": "sintra",
    "sintern": "sinter",
    "sinterns": "sinter",
    "sinters": "sinter",
    "sintrad": "sintra",
    "sintrade": "sintra",
    "sintrades": "sintra",
    "sintrads": "sintra",
    "sintrande": "sintra",
    "sintranden": "sintrande",
    "sintrandena": "sintrande",
    "sintrandenas": "sintrande",
    "sintrandens": "sintrande",
    "sintrandes": "sintrande",
    "sintrandet": "sintrande",
    "sintrandets": "sintrande",
    "sintrar": "sintra",
    "sintras": "sintra",
    "sintrat": "sintra",
    "sintrats": "sintra",
    "sinuiten": "sinuit",
    "sinuitens": "sinuit",
    "sinuiter": "sinuit",
    "sinuiterna": "sinuit",
    "sinuiternas": "sinuit",
    "sinuiters": "sinuit",
    "sinuits": "sinuit",
    "sinusar": "sinus",
    "sinusarna": "sinus",
    "sinusarnas": "sinus",
    "sinusars": "sinus",
    "sinusen": "sinus",
    "sinusens": "sinus",
    "sinusiten": "sinusit",
    "sinusitens": "sinusit",
    "sinusiter": "sinusit",
    "sinusiterna": "sinusit",
    "sinusiternas": "sinusit",
    "sinusiters": "sinusit",
    "sinusits": "sinusit",
    "sinuskurv": "sinuskurva",
    "sinuskurvan": "sinuskurva",
    "sinuskurvans": "sinuskurva",
    "sinuskurvas": "sinuskurva",
    "sinuskurve": "sinuskurva",
    "sinuskurvor": "sinuskurva",
    "sinuskurvorna": "sinuskurva",
    "sinuskurvornas": "sinuskurva",
    "sinuskurvors": "sinuskurva",
    "sinuskurvs": "sinuskurva",
    "sinustonen": "sinuston",
    "sinustonens": "sinuston",
    "sinustoner": "sinuston",
    "sinustonerna": "sinuston",
    "sinustonernas": "sinuston",
    "sinustoners": "sinuston",
    "sinustons": "sinuston",
    "sinusvågen": "sinusvåg",
    "sinusvågens": "sinusvåg",
    "sinusvågor": "sinusvåg",
    "sinusvågorna": "sinusvåg",
    "sinusvågornas": "sinusvåg",
    "sinusvågors": "sinusvåg",
    "sinusvågs": "sinusvåg",
    "sionismen": "sionism",
    "sionismens": "sionism",
    "sionismer": "sionism",
    "sionismerna": "sionism",
    "sionismernas": "sionism",
    "sionismers": "sionism",
    "sionisms": "sionism",
    "sionisten": "sionist",
    "sionistens": "sionist",
    "sionister": "sionist",
    "sionisterna": "sionist",
    "sionisternas": "sionist",
    "sionisters": "sionist",
    "sionistiska": "sionistisk",
    "sionistiskas": "sionistisk",
    "sionistiske": "sionistisk",
    "sionistiskes": "sionistisk",
    "sionistisks": "sionistisk",
    "sionistiskt": "sionistisk",
    "sionistiskts": "sionistisk",
    "sionists": "sionist",
    "siouxen": "sioux",
    "siouxens": "sioux",
    "siouxer": "sioux",
    "siouxerna": "sioux",
    "siouxernas": "sioux",
    "siouxers": "sioux",
    "sipp": "sippa",
    "sippa": "sipp",
    "sippan": "sippa",
    "sippans": "sippa",
    "sippare": "sipp",
    "sippares": "sipp",
    "sippas": "sippa",
    "sippast": "sipp",
    "sippaste": "sipp",
    "sippastes": "sipp",
    "sippasts": "sipp",
    "sippe": "sippa",
    "sippes": "sipp",
    "sippheten": "sipphet",
    "sipphetens": "sipphet",
    "sipphets": "sipphet",
    "sippor": "sippa",
    "sipporna": "sippa",
    "sippornas": "sippa",
    "sippors": "sippa",
    "sipprade": "sippra",
    "sipprades": "sippra",
    "sipprande": "sippra",
    "sippranden": "sipprande",
    "sipprandena": "sipprande",
    "sipprandenas": "sipprande",
    "sipprandens": "sipprande",
    "sipprandes": "sipprande",
    "sipprandet": "sipprande",
    "sipprandets": "sipprande",
    "sipprar": "sippra",
    "sippras": "sippra",
    "sipprat": "sippra",
    "sipprats": "sippra",
    "sipps": "sippa",
    "sippt": "sipp",
    "sippts": "sipp",
    "sir": "sira",
    "sirad": "sira",
    "sirade": "sira",
    "sirades": "sira",
    "sirads": "sira",
    "sirande": "sira",
    "siranden": "sirande",
    "sirandena": "sirande",
    "sirandenas": "sirande",
    "sirandens": "sirande",
    "sirandes": "sirande",
    "sirandet": "sirande",
    "sirandets": "sirande",
    "sirapen": "sirap",
    "sirapens": "sirap",
    "siraps": "sirap",
    "sirapslena": "sirapslen",
    "sirapslenare": "sirapslen",
    "sirapslenares": "sirapslen",
    "sirapslenas": "sirapslen",
    "sirapslenast": "sirapslen",
    "sirapslenaste": "sirapslen",
    "sirapslenastes": "sirapslen",
    "sirapslenasts": "sirapslen",
    "sirapslene": "sirapslen",
    "sirapslenes": "sirapslen",
    "sirapslens": "sirapslen",
    "sirapslent": "sirapslen",
    "sirapslents": "sirapslen",
    "sirapslimp": "sirapslimpa",
    "sirapslimpan": "sirapslimpa",
    "sirapslimpans": "sirapslimpa",
    "sirapslimpas": "sirapslimpa",
    "sirapslimpe": "sirapslimpa",
    "sirapslimpor": "sirapslimpa",
    "sirapslimporna": "sirapslimpa",
    "sirapslimpornas": "sirapslimpa",
    "sirapslimpors": "sirapslimpa",
    "sirapslimps": "sirapslimpa",
    "sirapssöta": "sirapssöt",
    "sirapssötare": "sirapssöt",
    "sirapssötares": "sirapssöt",
    "sirapssötas": "sirapssöt",
    "sirapssötast": "sirapssöt",
    "sirapssötaste": "sirapssöt",
    "sirapssötastes": "sirapssöt",
    "sirapssötasts": "sirapssöt",
    "sirapssöte": "sirapssöt",
    "sirapssötes": "sirapssöt",
    "sirapssötheten": "sirapssöthet",
    "sirapssöthetens": "sirapssöthet",
    "sirapssöthets": "sirapssöthet",
    "sirapssöts": "sirapssöt",
    "sirapssött": "sirapssöt",
    "sirapssötts": "sirapssöt",
    "sirar": "sira",
    "siras": "sira",
    "sirat": "sira",
    "siraten": "sirat",
    "siratens": "sirat",
    "sirater": "sirat",
    "siraterna": "sirat",
    "siraternas": "sirat",
    "siraters": "sirat",
    "siratliga": "siratlig",
    "siratligare": "siratlig",
    "siratligares": "siratlig",
    "siratligas": "siratlig",
    "siratligast": "siratlig",
    "siratligaste": "siratlig",
    "siratligastes": "siratlig",
    "siratligasts": "siratlig",
    "siratlige": "siratlig",
    "siratliges": "siratlig",
    "siratligheten": "siratlighet",
    "siratlighetens": "siratlighet",
    "siratlighets": "siratlighet",
    "siratligs": "siratlig",
    "siratligt": "siratlig",
    "siratligts": "siratlig",
    "sirats": "sirat",
    "sirendjuren": "sirendjur",
    "sirendjurens": "sirendjur",
    "sirendjuret": "sirendjur",
    "sirendjurets": "sirendjur",
    "sirendjurs": "sirendjur",
    "sirenen": "siren",
    "sirenens": "siren",
    "sirener": "siren",
    "sirenerna": "siren",
    "sirenernas": "siren",
    "sireners": "siren",
    "sirens": "siren",
    "siret": "sir",
    "sirets": "sir",
    "sirliga": "sirlig",
    "sirligare": "sirlig",
    "sirligares": "sirlig",
    "sirligas": "sirlig",
    "sirligast": "sirlig",
    "sirligaste": "sirlig",
    "sirligastes": "sirlig",
    "sirligasts": "sirlig",
    "sirlige": "sirlig",
    "sirliges": "sirlig",
    "sirligheten": "sirlighet",
    "sirlighetens": "sirlighet",
    "sirligheter": "sirlighet",
    "sirligheterna": "sirlighet",
    "sirligheternas": "sirlighet",
    "sirligheters": "sirlighet",
    "sirlighets": "sirlighet",
    "sirligs": "sirlig",
    "sirligt": "sirlig",
    "sirligts": "sirlig",
    "sirockon": "sirocko",
    "sirockons": "sirocko",
    "sirockos": "sirocko",
    "sirpade": "sirpa",
    "sirpades": "sirpa",
    "sirpande": "sirpa",
    "sirpanden": "sirpande",
    "sirpandena": "sirpande",
    "sirpandenas": "sirpande",
    "sirpandens": "sirpande",
    "sirpandes": "sirpande",
    "sirpandet": "sirpande",
    "sirpandets": "sirpande",
    "sirpar": "sirpa",
    "sirpas": "sirpa",
    "sirpat": "sirpa",
    "sirpats": "sirpa",
    "sirpet": "sirp",
    "sirpets": "sirp",
    "sirps": "sirp",
    "sirr": "sirra",
    "sirrade": "sirra",
    "sirrades": "sirra",
    "sirrande": "sirra",
    "sirranden": "sirrande",
    "sirrandena": "sirrande",
    "sirrandenas": "sirrande",
    "sirrandens": "sirrande",
    "sirrandes": "sirrande",
    "sirrandet": "sirrande",
    "sirrandets": "sirrande",
    "sirrar": "sirra",
    "sirras": "sirra",
    "sirrat": "sirra",
    "sirrats": "sirra",
    "sirs": "sir",
    "sisade": "sisa",
    "sisades": "sisa",
    "sisalen": "sisal",
    "sisalens": "sisal",
    "sisalhampan": "sisalhampa",
    "sisalhampans": "sisalhampa",
    "sisalhampas": "sisalhampa",
    "sisals": "sisal",
    "sisande": "sisa",
    "sisanden": "sisande",
    "sisandena": "sisande",
    "sisandenas": "sisande",
    "sisandens": "sisande",
    "sisandes": "sisande",
    "sisandet": "sisande",
    "sisandets": "sisande",
    "sisar": "sisa",
    "sisas": "sisa",
    "sisat": "sisa",
    "sisats": "sisa",
    "siseln": "sisel",
    "siselns": "sisel",
    "sisels": "sisel",
    "siset": "sis",
    "sisets": "sis",
    "sisk": "siska",
    "siskan": "siska",
    "siskans": "siska",
    "siskas": "siska",
    "siske": "siska",
    "siskor": "siska",
    "siskorna": "siska",
    "siskornas": "siska",
    "siskors": "siska",
    "sislar": "sisel",
    "sislarna": "sisel",
    "sislarnas": "sisel",
    "sislars": "sisel",
    "sista-minutenresan": "sista-minutenresa",
    "sista-minutenresans": "sista-minutenresa",
    "sista-minutenresas": "sista-minutenresa",
    "sista-minutenrese": "sista-minutenresa",
    "sista-minutenresor": "sista-minutenresa",
    "sista-minutenresorna": "sista-minutenresa",
    "sista-minutenresornas": "sista-minutenresa",
    "sista-minutenresors": "sista-minutenresa",
    "sistan": "sista",
    "sistans": "sista",
    "sistas": "sista",
    "sistbemäldas": "sistbemälda",
    "sistbemälde": "sistbemälda",
    "sistbemäldes": "sistbemälda",
    "sistbemältas": "sistbemälta",
    "sistbemälte": "sistbemälta",
    "sistbemältes": "sistbemälta",
    "siste": "sista",
    "sistens": "sisten",
    "sistes": "sista",
    "sistlidens": "sistliden",
    "sistlidet": "sistliden",
    "sistlidets": "sistliden",
    "sistlidna": "sistliden",
    "sistlidnare": "sistliden",
    "sistlidnares": "sistliden",
    "sistlidnas": "sistliden",
    "sistlidnast": "sistliden",
    "sistlidnaste": "sistliden",
    "sistlidnastes": "sistliden",
    "sistlidnasts": "sistliden",
    "sistlidne": "sistliden",
    "sistlidnes": "sistliden",
    "sistnämndas": "sistnämnda",
    "sistnämnde": "sistnämnda",
    "sistnämndes": "sistnämnda",
    "sisun": "sisu",
    "sisuns": "sisu",
    "sisus": "sisu",
    "sisyfusarbeten": "sisyfusarbete",
    "sisyfusarbetena": "sisyfusarbete",
    "sisyfusarbetenas": "sisyfusarbete",
    "sisyfusarbetens": "sisyfusarbete",
    "sisyfusarbetes": "sisyfusarbete",
    "sisyfusarbetet": "sisyfusarbete",
    "sisyfusarbetets": "sisyfusarbete",
    "sisyfusarbets": "sisyfusarbete",
    "sitaren": "sitar",
    "sitarens": "sitar",
    "sitarer": "sitar",
    "sitarerna": "sitar",
    "sitarernas": "sitar",
    "sitarers": "sitar",
    "sitars": "sitar",
    "sitcomen": "sitcom",
    "sitcomens": "sitcom",
    "sitcommar": "sitcom",
    "sitcommarna": "sitcom",
    "sitcommarnas": "sitcom",
    "sitcommars": "sitcom",
    "sitcommen": "sitcom",
    "sitcommens": "sitcom",
    "sitcoms": "sitcom",
    "sitcomsen": "sitcom",
    "sitcomsens": "sitcom",
    "sitkomen": "sitkom",
    "sitkomens": "sitkom",
    "sitkommar": "sitkom",
    "sitkommarna": "sitkom",
    "sitkommarnas": "sitkom",
    "sitkommars": "sitkom",
    "sitkommen": "sitkom",
    "sitkommens": "sitkom",
    "sitkoms": "sitkom",
    "sitkomsen": "sitkom",
    "sitkomsens": "sitkom",
    "sitsar": "sits",
    "sitsarna": "sits",
    "sitsarnas": "sits",
    "sitsars": "sits",
    "sitsen": "sits",
    "sitsens": "sits",
    "sitt": "sitta",
    "sittande": "sitta",
    "sittanden": "sittande",
    "sittandena": "sittande",
    "sittandenas": "sittande",
    "sittandens": "sittande",
    "sittandes": "sittande",
    "sittandet": "sittande",
    "sittandets": "sittande",
    "sittas": "sitta",
    "sittbadkaren": "sittbadkar",
    "sittbadkarens": "sittbadkar",
    "sittbadkaret": "sittbadkar",
    "sittbadkarets": "sittbadkar",
    "sittbadkars": "sittbadkar",
    "sittbenen": "sittben",
    "sittbenens": "sittben",
    "sittbenet": "sittben",
    "sittbenets": "sittben",
    "sittbens": "sittben",
    "sittbrunnar": "sittbrunn",
    "sittbrunnarna": "sittbrunn",
    "sittbrunnarnas": "sittbrunn",
    "sittbrunnars": "sittbrunn",
    "sittbrunnen": "sittbrunn",
    "sittbrunnens": "sittbrunn",
    "sittbrunns": "sittbrunn",
    "sittbräd": "sittbräda",
    "sittbrädan": "sittbräda",
    "sittbrädans": "sittbräda",
    "sittbrädas": "sittbräda",
    "sittbräde": "sittbräda",
    "sittbräden": "sittbräde",
    "sittbrädena": "sittbräde",
    "sittbrädenas": "sittbräde",
    "sittbrädens": "sittbräde",
    "sittbrädes": "sittbräde",
    "sittbrädet": "sittbräde",
    "sittbrädets": "sittbräde",
    "sittbrädor": "sittbräda",
    "sittbrädorna": "sittbräda",
    "sittbrädornas": "sittbräda",
    "sittbrädors": "sittbräda",
    "sittbräds": "sittbräda",
    "sitte": "sitta",
    "sitter": "sitta",
    "sittern": "sitter",
    "sitterna": "sitter",
    "sitternas": "sitter",
    "sitterns": "sitter",
    "sitters": "sitter",
    "sittersarna": "sitter",
    "sittersarnas": "sitter",
    "sittes": "sitta",
    "sittgruppen": "sittgrupp",
    "sittgruppens": "sittgrupp",
    "sittgrupper": "sittgrupp",
    "sittgrupperna": "sittgrupp",
    "sittgruppernas": "sittgrupp",
    "sittgruppers": "sittgrupp",
    "sittgrupps": "sittgrupp",
    "sittmöbeln": "sittmöbel",
    "sittmöbelns": "sittmöbel",
    "sittmöbels": "sittmöbel",
    "sittmöbler": "sittmöbel",
    "sittmöblerna": "sittmöbel",
    "sittmöblernas": "sittmöbel",
    "sittmöblers": "sittmöbel",
    "sittningar": "sittning",
    "sittningarna": "sittning",
    "sittningarnas": "sittning",
    "sittningars": "sittning",
    "sittningen": "sittning",
    "sittningens": "sittning",
    "sittnings": "sittning",
    "sittoppar": "sittopp",
    "sittopparna": "sittopp",
    "sittopparnas": "sittopp",
    "sittoppars": "sittopp",
    "sittoppen": "sittopp",
    "sittoppens": "sittopp",
    "sittopps": "sittopp",
    "sittpinn": "sittpinne",
    "sittpinnar": "sittpinne",
    "sittpinnarna": "sittpinne",
    "sittpinnarnas": "sittpinne",
    "sittpinnars": "sittpinne",
    "sittpinnen": "sittpinne",
    "sittpinnens": "sittpinne",
    "sittpinnes": "sittpinne",
    "sittpinns": "sittpinne",
    "sittplatsen": "sittplats",
    "sittplatsens": "sittplats",
    "sittplatser": "sittplats",
    "sittplatserna": "sittplats",
    "sittplatsernas": "sittplats",
    "sittplatsers": "sittplats",
    "sittrar": "sitter",
    "sittrarna": "sitter",
    "sittrarnas": "sitter",
    "sittrars": "sitter",
    "sittriktiga": "sittriktig",
    "sittriktigare": "sittriktig",
    "sittriktigares": "sittriktig",
    "sittriktigas": "sittriktig",
    "sittriktigast": "sittriktig",
    "sittriktigaste": "sittriktig",
    "sittriktigastes": "sittriktig",
    "sittriktigasts": "sittriktig",
    "sittriktige": "sittriktig",
    "sittriktiges": "sittriktig",
    "sittriktigheten": "sittriktighet",
    "sittriktighetens": "sittriktighet",
    "sittriktighets": "sittriktighet",
    "sittriktigs": "sittriktig",
    "sittriktigt": "sittriktig",
    "sittriktigts": "sittriktig",
    "sitts": "sitta",
    "sittstrejkade": "sittstrejka",
    "sittstrejkades": "sittstrejka",
    "sittstrejkande": "sittstrejka",
    "sittstrejkanden": "sittstrejkande",
    "sittstrejkandena": "sittstrejkande",
    "sittstrejkandenas": "sittstrejkande",
    "sittstrejkandens": "sittstrejkande",
    "sittstrejkandes": "sittstrejkande",
    "sittstrejkandet": "sittstrejkande",
    "sittstrejkandets": "sittstrejkande",
    "sittstrejkar": "sittstrejka",
    "sittstrejkas": "sittstrejka",
    "sittstrejkat": "sittstrejka",
    "sittstrejkats": "sittstrejka",
    "sittstrejken": "sittstrejk",
    "sittstrejkens": "sittstrejk",
    "sittstrejker": "sittstrejk",
    "sittstrejkerna": "sittstrejk",
    "sittstrejkernas": "sittstrejk",
    "sittstrejkers": "sittstrejk",
    "sittstrejks": "sittstrejk",
    "sittställningar": "sittställning",
    "sittställningarna": "sittställning",
    "sittställningarnas": "sittställning",
    "sittställningars": "sittställning",
    "sittställningen": "sittställning",
    "sittställningens": "sittställning",
    "sittställnings": "sittställning",
    "sittstänger": "sittstång",
    "sittstängerna": "sittstång",
    "sittstängernas": "sittstång",
    "sittstängers": "sittstång",
    "sittstången": "sittstång",
    "sittstångens": "sittstång",
    "sittstångs": "sittstång",
    "sittup": "sittupa",
    "sittupade": "sittupa",
    "sittupades": "sittupa",
    "sittupande": "sittupa",
    "sittupanden": "sittupande",
    "sittupandena": "sittupande",
    "sittupandenas": "sittupande",
    "sittupandens": "sittupande",
    "sittupandes": "sittupande",
    "sittupandet": "sittupande",
    "sittupandets": "sittupande",
    "sittupar": "sittupa",
    "sittuparna": "sittup",
    "sittuparnas": "sittup",
    "sittupars": "sittup",
    "sittupas": "sittupa",
    "sittupat": "sittupa",
    "sittupats": "sittupa",
    "sittupen": "sittup",
    "sittupens": "sittup",
    "sittupp": "sittuppa",
    "sittuppade": "sittuppa",
    "sittuppades": "sittuppa",
    "sittuppande": "sittuppa",
    "sittuppanden": "sittuppande",
    "sittuppandena": "sittuppande",
    "sittuppandenas": "sittuppande",
    "sittuppandens": "sittuppande",
    "sittuppandes": "sittuppande",
    "sittuppandet": "sittuppande",
    "sittuppandets": "sittuppande",
    "sittuppar": "sittuppa",
    "sittupparna": "sittupp",
    "sittupparnas": "sittupp",
    "sittuppars": "sittupp",
    "sittuppas": "sittuppa",
    "sittuppat": "sittuppa",
    "sittuppats": "sittuppa",
    "sittuppen": "sittupp",
    "sittuppens": "sittupp",
    "sittupps": "sittupp",
    "sittuppsarna": "sittupp",
    "sittuppsarnas": "sittupp",
    "sittuppsen": "sittupp",
    "sittuppsens": "sittupp",
    "sittups": "sittup",
    "sittupsarna": "sittup",
    "sittupsarnas": "sittup",
    "sittupsen": "sittup",
    "sittupsens": "sittup",
    "sittvagnar": "sittvagn",
    "sittvagnarna": "sittvagn",
    "sittvagnarnas": "sittvagn",
    "sittvagnars": "sittvagn",
    "sittvagnen": "sittvagn",
    "sittvagnens": "sittvagn",
    "sittvagns": "sittvagn",
    "sittvänliga": "sittvänlig",
    "sittvänligare": "sittvänlig",
    "sittvänligares": "sittvänlig",
    "sittvänligas": "sittvänlig",
    "sittvänligast": "sittvänlig",
    "sittvänligaste": "sittvänlig",
    "sittvänligastes": "sittvänlig",
    "sittvänligasts": "sittvänlig",
    "sittvänlige": "sittvänlig",
    "sittvänliges": "sittvänlig",
    "sittvänligheten": "sittvänlighet",
    "sittvänlighetens": "sittvänlighet",
    "sittvänlighets": "sittvänlighet",
    "sittvänligs": "sittvänlig",
    "sittvänligt": "sittvänlig",
    "sittvänligts": "sittvänlig",
    "situationen": "situation",
    "situationens": "situation",
    "situationer": "situation",
    "situationerna": "situation",
    "situationernas": "situation",
    "situationers": "situation",
    "situations": "situation",
    "situationsbilden": "situationsbild",
    "situationsbildens": "situationsbild",
    "situationsbilder": "situationsbild",
    "situationsbilderna": "situationsbild",
    "situationsbildernas": "situationsbild",
    "situationsbilders": "situationsbild",
    "situationsbilds": "situationsbild",
    "situationskomiken": "situationskomik",
    "situationskomikens": "situationskomik",
    "situationskomiks": "situationskomik",
    "situerade": "situerad",
    "situerades": "situerad",
    "situerads": "situerad",
    "situerat": "situerad",
    "situerats": "situerad",
    "situp": "situpa",
    "situpade": "situpa",
    "situpades": "situpa",
    "situpande": "situpa",
    "situpanden": "situpande",
    "situpandena": "situpande",
    "situpandenas": "situpande",
    "situpandens": "situpande",
    "situpandes": "situpande",
    "situpandet": "situpande",
    "situpandets": "situpande",
    "situpar": "situpa",
    "situparna": "situp",
    "situparnas": "situp",
    "situpars": "situp",
    "situpas": "situpa",
    "situpat": "situpa",
    "situpats": "situpa",
    "situpen": "situp",
    "situpens": "situp",
    "situpp": "situppa",
    "situppade": "situppa",
    "situppades": "situppa",
    "situppande": "situppa",
    "situppanden": "situppande",
    "situppandena": "situppande",
    "situppandenas": "situppande",
    "situppandens": "situppande",
    "situppandes": "situppande",
    "situppandet": "situppande",
    "situppandets": "situppande",
    "situppar": "situppa",
    "situpparna": "situpp",
    "situpparnas": "situpp",
    "situppars": "situpp",
    "situppas": "situppa",
    "situppat": "situppa",
    "situppats": "situppa",
    "situppen": "situpp",
    "situppens": "situpp",
    "situpps": "situpp",
    "situppsarna": "situpp",
    "situppsarnas": "situpp",
    "situppsen": "situpp",
    "situppsens": "situpp",
    "situps": "situp",
    "situpsarna": "situp",
    "situpsarnas": "situp",
    "situpsen": "situp",
    "situpsens": "situp",
    "sj-ljuden": "sj-ljud",
    "sj-ljudens": "sj-ljud",
    "sj-ljudet": "sj-ljud",
    "sj-ljudets": "sj-ljud",
    "sj-ljuds": "sj-ljud",
    "sjabbel": "sjabbla",
    "sjabbels": "sjabbel",
    "sjabbiga": "sjabbig",
    "sjabbigare": "sjabbig",
    "sjabbigares": "sjabbig",
    "sjabbigas": "sjabbig",
    "sjabbigast": "sjabbig",
    "sjabbigaste": "sjabbig",
    "sjabbigastes": "sjabbig",
    "sjabbigasts": "sjabbig",
    "sjabbige": "sjabbig",
    "sjabbiges": "sjabbig",
    "sjabbigheten": "sjabbighet",
    "sjabbighetens": "sjabbighet",
    "sjabbighets": "sjabbighet",
    "sjabbigs": "sjabbig",
    "sjabbigt": "sjabbig",
    "sjabbigts": "sjabbig",
    "sjabblade": "sjabbla",
    "sjabblades": "sjabbla",
    "sjabblande": "sjabbla",
    "sjabblanden": "sjabblande",
    "sjabblandena": "sjabblande",
    "sjabblandenas": "sjabblande",
    "sjabblandens": "sjabblande",
    "sjabblandes": "sjabblande",
    "sjabblandet": "sjabblande",
    "sjabblandets": "sjabblande",
    "sjabblar": "sjabbla",
    "sjabblas": "sjabbla",
    "sjabblat": "sjabbla",
    "sjabblats": "sjabbla",
    "sjabblen": "sjabbel",
    "sjabblens": "sjabbel",
    "sjabblet": "sjabbel",
    "sjabblets": "sjabbel",
    "sjaberna": "sjaber",
    "sjabernas": "sjaber",
    "sjabers": "sjaber",
    "sjaggen": "sjagg",
    "sjaggens": "sjagg",
    "sjagger": "sjagg",
    "sjaggerna": "sjagg",
    "sjaggernas": "sjagg",
    "sjaggers": "sjagg",
    "sjaggs": "sjagg",
    "sjajasar": "sjajas",
    "sjajasarna": "sjajas",
    "sjajasarnas": "sjajas",
    "sjajasars": "sjajas",
    "sjajasen": "sjajas",
    "sjajasens": "sjajas",
    "sjakalen": "sjakal",
    "sjakalens": "sjakal",
    "sjakaler": "sjakal",
    "sjakalerna": "sjakal",
    "sjakalernas": "sjakal",
    "sjakalers": "sjakal",
    "sjakals": "sjakal",
    "sjalar": "sjal",
    "sjalarna": "sjal",
    "sjalarnas": "sjal",
    "sjalars": "sjal",
    "sjalen": "sjal",
    "sjalens": "sjal",
    "sjaletten": "sjalett",
    "sjalettens": "sjalett",
    "sjaletter": "sjalett",
    "sjaletterna": "sjalett",
    "sjaletternas": "sjalett",
    "sjaletters": "sjalett",
    "sjaletts": "sjalett",
    "sjalkrag": "sjalkrage",
    "sjalkragar": "sjalkrage",
    "sjalkragarna": "sjalkrage",
    "sjalkragarnas": "sjalkrage",
    "sjalkragars": "sjalkrage",
    "sjalkragen": "sjalkrage",
    "sjalkragens": "sjalkrage",
    "sjalkrages": "sjalkrage",
    "sjalkrags": "sjalkrage",
    "sjals": "sjal",
    "sjan": "sjana",
    "sjanan": "sjana",
    "sjanans": "sjana",
    "sjanas": "sjana",
    "sjane": "sjana",
    "sjangdobels": "sjangdobel",
    "sjangdobelt": "sjangdobel",
    "sjangdobelts": "sjangdobel",
    "sjangdobla": "sjangdobel",
    "sjangdoblare": "sjangdobel",
    "sjangdoblares": "sjangdobel",
    "sjangdoblas": "sjangdobel",
    "sjangdoblast": "sjangdobel",
    "sjangdoblaste": "sjangdobel",
    "sjangdoblastes": "sjangdobel",
    "sjangdoblasts": "sjangdobel",
    "sjangdoble": "sjangdobel",
    "sjangdobles": "sjangdobel",
    "sjanghajad": "sjanghaja",
    "sjanghajade": "sjanghaja",
    "sjanghajades": "sjanghaja",
    "sjanghajads": "sjanghaja",
    "sjanghajande": "sjanghaja",
    "sjanghajanden": "sjanghajande",
    "sjanghajandena": "sjanghajande",
    "sjanghajandenas": "sjanghajande",
    "sjanghajandens": "sjanghajande",
    "sjanghajandes": "sjanghajande",
    "sjanghajandet": "sjanghajande",
    "sjanghajandets": "sjanghajande",
    "sjanghajar": "sjanghaja",
    "sjanghajas": "sjanghaja",
    "sjanghajat": "sjanghaja",
    "sjanghajats": "sjanghaja",
    "sjangserade": "sjangsera",
    "sjangserades": "sjangsera",
    "sjangserande": "sjangsera",
    "sjangseranden": "sjangserande",
    "sjangserandena": "sjangserande",
    "sjangserandenas": "sjangserande",
    "sjangserandens": "sjangserande",
    "sjangserandes": "sjangserande",
    "sjangserandet": "sjangserande",
    "sjangserandets": "sjangserande",
    "sjangserar": "sjangsera",
    "sjangseras": "sjangsera",
    "sjangserat": "sjangsera",
    "sjangserats": "sjangsera",
    "sjangseringar": "sjangsering",
    "sjangseringarna": "sjangsering",
    "sjangseringarnas": "sjangsering",
    "sjangseringars": "sjangsering",
    "sjangseringen": "sjangsering",
    "sjangseringens": "sjangsering",
    "sjangserings": "sjangsering",
    "sjangtila": "sjangtil",
    "sjangtilare": "sjangtil",
    "sjangtilares": "sjangtil",
    "sjangtilas": "sjangtil",
    "sjangtilast": "sjangtil",
    "sjangtilaste": "sjangtil",
    "sjangtilastes": "sjangtil",
    "sjangtilasts": "sjangtil",
    "sjangtile": "sjangtil",
    "sjangtiles": "sjangtil",
    "sjangtils": "sjangtil",
    "sjangtilt": "sjangtil",
    "sjangtilts": "sjangtil",
    "sjanor": "sjana",
    "sjanorna": "sjana",
    "sjanornas": "sjana",
    "sjanors": "sjana",
    "sjans": "sjana",
    "sjapp": "sjappa",
    "sjappad": "sjappa",
    "sjappade": "sjappa",
    "sjappades": "sjappa",
    "sjappads": "sjappa",
    "sjappande": "sjappa",
    "sjappanden": "sjappande",
    "sjappandena": "sjappande",
    "sjappandenas": "sjappande",
    "sjappandens": "sjappande",
    "sjappandes": "sjappande",
    "sjappandet": "sjappande",
    "sjappandets": "sjappande",
    "sjappar": "sjappa",
    "sjappas": "sjappa",
    "sjappat": "sjappa",
    "sjappats": "sjappa",
    "sjappen": "sjapp",
    "sjappens": "sjapp",
    "sjappet": "sjapp",
    "sjappets": "sjapp",
    "sjapps": "sjapp",
    "sjas": "sjasa",
    "sjasad": "sjasa",
    "sjasade": "sjasa",
    "sjasades": "sjasa",
    "sjasads": "sjasa",
    "sjasande": "sjasa",
    "sjasanden": "sjasande",
    "sjasandena": "sjasande",
    "sjasandenas": "sjasande",
    "sjasandens": "sjasande",
    "sjasandes": "sjasande",
    "sjasandet": "sjasande",
    "sjasandets": "sjasande",
    "sjasar": "sjasa",
    "sjasas": "sjasa",
    "sjasat": "sjasa",
    "sjasats": "sjasa",
    "sjask": "sjaska",
    "sjaskade": "sjaska",
    "sjaskades": "sjaska",
    "sjaskande": "sjaska",
    "sjaskanden": "sjaskande",
    "sjaskandena": "sjaskande",
    "sjaskandenas": "sjaskande",
    "sjaskandens": "sjaskande",
    "sjaskandes": "sjaskande",
    "sjaskandet": "sjaskande",
    "sjaskandets": "sjaskande",
    "sjaskar": "sjasker",
    "sjaskarna": "sjasker",
    "sjaskarnas": "sjasker",
    "sjaskars": "sjasker",
    "sjaskas": "sjaska",
    "sjaskat": "sjaska",
    "sjaskats": "sjaska",
    "sjaskern": "sjasker",
    "sjaskerns": "sjasker",
    "sjaskers": "sjasker",
    "sjaskiga": "sjaskig",
    "sjaskigare": "sjaskig",
    "sjaskigares": "sjaskig",
    "sjaskigas": "sjaskig",
    "sjaskigast": "sjaskig",
    "sjaskigaste": "sjaskig",
    "sjaskigastes": "sjaskig",
    "sjaskigasts": "sjaskig",
    "sjaskige": "sjaskig",
    "sjaskiges": "sjaskig",
    "sjaskigheten": "sjaskighet",
    "sjaskighetens": "sjaskighet",
    "sjaskigheter": "sjaskighet",
    "sjaskigheterna": "sjaskighet",
    "sjaskigheternas": "sjaskighet",
    "sjaskigheters": "sjaskighet",
    "sjaskighets": "sjaskighet",
    "sjaskigs": "sjaskig",
    "sjaskigt": "sjaskig",
    "sjaskigts": "sjaskig",
    "sjaskrar": "sjasker",
    "sjaskrarna": "sjasker",
    "sjaskrarnas": "sjasker",
    "sjaskrars": "sjasker",
    "sjasliken": "sjaslik",
    "sjaslikens": "sjaslik",
    "sjasliks": "sjaslik",
    "sjav": "sjava",
    "sjavade": "sjava",
    "sjavades": "sjava",
    "sjavande": "sjava",
    "sjavanden": "sjavande",
    "sjavandena": "sjavande",
    "sjavandenas": "sjavande",
    "sjavandens": "sjavande",
    "sjavandes": "sjavande",
    "sjavandet": "sjavande",
    "sjavandets": "sjavande",
    "sjavar": "sjava",
    "sjavas": "sjava",
    "sjavat": "sjava",
    "sjavats": "sjava",
    "sjaviga": "sjavig",
    "sjavigare": "sjavig",
    "sjavigares": "sjavig",
    "sjavigas": "sjavig",
    "sjavigast": "sjavig",
    "sjavigaste": "sjavig",
    "sjavigastes": "sjavig",
    "sjavigasts": "sjavig",
    "sjavige": "sjavig",
    "sjaviges": "sjavig",
    "sjavigs": "sjavig",
    "sjavigt": "sjavig",
    "sjavigts": "sjavig",
    "sjoken": "sjok",
    "sjokens": "sjok",
    "sjoket": "sjok",
    "sjokets": "sjok",
    "sjoks": "sjok",
    "sjuan": "sjua",
    "sjuans": "sjua",
    "sjuarmade": "sjuarmad",
    "sjuarmades": "sjuarmad",
    "sjuarmads": "sjuarmad",
    "sjuarmat": "sjuarmad",
    "sjuarmats": "sjuarmad",
    "sjuas": "sjua",
    "sjubarnspappan": "sjubarnspappa",
    "sjubarnspappans": "sjubarnspappa",
    "sjubarnspappas": "sjubarnspappa",
    "sjubarnspappor": "sjubarnspappa",
    "sjubarnspapporna": "sjubarnspappa",
    "sjubarnspappornas": "sjubarnspappa",
    "sjubarnspappors": "sjubarnspappa",
    "sjubbar": "sjubb",
    "sjubbarna": "sjubb",
    "sjubbarnas": "sjubb",
    "sjubbars": "sjubb",
    "sjubben": "sjubb",
    "sjubbens": "sjubb",
    "sjubbs": "sjubb",
    "sjud": "sjuda",
    "sjudagarsveck": "sjudagarsvecka",
    "sjudagarsveckan": "sjudagarsvecka",
    "sjudagarsveckans": "sjudagarsvecka",
    "sjudagarsveckas": "sjudagarsvecka",
    "sjudagarsvecke": "sjudagarsvecka",
    "sjudagarsvecko": "sjudagarsvecka",
    "sjudagarsveckor": "sjudagarsvecka",
    "sjudagarsveckorna": "sjudagarsvecka",
    "sjudagarsveckornas": "sjudagarsvecka",
    "sjudagarsveckors": "sjudagarsvecka",
    "sjudagarsvecks": "sjudagarsvecka",
    "sjudande": "sjuda",
    "sjudanden": "sjudande",
    "sjudandena": "sjudande",
    "sjudandenas": "sjudande",
    "sjudandens": "sjudande",
    "sjudandes": "sjudande",
    "sjudandet": "sjudande",
    "sjudandets": "sjudande",
    "sjudas": "sjuda",
    "sjude": "sjuda",
    "sjuder": "sjuda",
    "sjudes": "sjuda",
    "sjudimensionella": "sjudimensionell",
    "sjudimensionellare": "sjudimensionell",
    "sjudimensionellares": "sjudimensionell",
    "sjudimensionellas": "sjudimensionell",
    "sjudimensionellast": "sjudimensionell",
    "sjudimensionellaste": "sjudimensionell",
    "sjudimensionellastes": "sjudimensionell",
    "sjudimensionellasts": "sjudimensionell",
    "sjudimensionelle": "sjudimensionell",
    "sjudimensionelles": "sjudimensionell",
    "sjudimensionells": "sjudimensionell",
    "sjudimensionellt": "sjudimensionell",
    "sjudimensionellts": "sjudimensionell",
    "sjudit": "sjuda",
    "sjudits": "sjuda",
    "sjuds": "sjuda",
    "sjudubben": "sjudubbel",
    "sjudubbens": "sjudubbel",
    "sjudubbet": "sjudubbel",
    "sjudubbets": "sjudubbel",
    "sjudubbna": "sjudubbel",
    "sjudubbnas": "sjudubbel",
    "sjudubbne": "sjudubbel",
    "sjudubbnes": "sjudubbel",
    "sjufaldiga": "sjufaldig",
    "sjufaldigad": "sjufaldiga",
    "sjufaldigade": "sjufaldiga",
    "sjufaldigades": "sjufaldiga",
    "sjufaldigads": "sjufaldiga",
    "sjufaldigande": "sjufaldiga",
    "sjufaldiganden": "sjufaldigande",
    "sjufaldigandena": "sjufaldigande",
    "sjufaldigandenas": "sjufaldigande",
    "sjufaldigandens": "sjufaldigande",
    "sjufaldigandes": "sjufaldigande",
    "sjufaldigandet": "sjufaldigande",
    "sjufaldigandets": "sjufaldigande",
    "sjufaldigar": "sjufaldiga",
    "sjufaldigas": "sjufaldiga",
    "sjufaldigat": "sjufaldiga",
    "sjufaldigats": "sjufaldiga",
    "sjufaldige": "sjufaldig",
    "sjufaldiges": "sjufaldig",
    "sjufaldigs": "sjufaldig",
    "sjufaldigt": "sjufaldig",
    "sjufaldigts": "sjufaldig",
    "sjuglasvagnar": "sjuglasvagn",
    "sjuglasvagnarna": "sjuglasvagn",
    "sjuglasvagnarnas": "sjuglasvagn",
    "sjuglasvagnars": "sjuglasvagn",
    "sjuglasvagnen": "sjuglasvagn",
    "sjuglasvagnens": "sjuglasvagn",
    "sjuglasvagns": "sjuglasvagn",
    "sjuhundrade": "sjuhundra",
    "sjuhundrades": "sjuhundra",
    "sjuhundras": "sjuhundra",
    "sjuk": "sjuka",
    "sjuka": "sjuk",
    "sjukan": "sjuka",
    "sjukanmäl": "sjukanmäla",
    "sjukanmälande": "sjukanmäla",
    "sjukanmälanden": "sjukanmälande",
    "sjukanmälandena": "sjukanmälande",
    "sjukanmälandenas": "sjukanmälande",
    "sjukanmälandens": "sjukanmälande",
    "sjukanmälandes": "sjukanmälande",
    "sjukanmälandet": "sjukanmälande",
    "sjukanmälandets": "sjukanmälande",
    "sjukanmälas": "sjukanmäla",
    "sjukanmäld": "sjukanmäla",
    "sjukanmälda": "sjukanmäla",
    "sjukanmäldas": "sjukanmäla",
    "sjukanmälde": "sjukanmäla",
    "sjukanmäldes": "sjukanmäla",
    "sjukanmälds": "sjukanmäla",
    "sjukanmäler": "sjukanmäla",
    "sjukanmäles": "sjukanmäla",
    "sjukanmäls": "sjukanmäla",
    "sjukanmält": "sjukanmäla",
    "sjukanmälts": "sjukanmäla",
    "sjukans": "sjuka",
    "sjukare": "sjuk",
    "sjukares": "sjuk",
    "sjukas": "sjuka",
    "sjukast": "sjuk",
    "sjukaste": "sjuk",
    "sjukastes": "sjuk",
    "sjukasts": "sjuk",
    "sjukavdragen": "sjukavdrag",
    "sjukavdragens": "sjukavdrag",
    "sjukavdraget": "sjukavdrag",
    "sjukavdragets": "sjukavdrag",
    "sjukavdrags": "sjukavdrag",
    "sjukbesöken": "sjukbesök",
    "sjukbesökens": "sjukbesök",
    "sjukbesöket": "sjukbesök",
    "sjukbesökets": "sjukbesök",
    "sjukbesöks": "sjukbesök",
    "sjukbuden": "sjukbud",
    "sjukbudens": "sjukbud",
    "sjukbudet": "sjukbud",
    "sjukbudets": "sjukbud",
    "sjukbuds": "sjukbud",
    "sjukbäddar": "sjukbädd",
    "sjukbäddarna": "sjukbädd",
    "sjukbäddarnas": "sjukbädd",
    "sjukbäddars": "sjukbädd",
    "sjukbädden": "sjukbädd",
    "sjukbäddens": "sjukbädd",
    "sjukbädds": "sjukbädd",
    "sjukbärar": "sjukbärare",
    "sjukbäraren": "sjukbärare",
    "sjukbärarens": "sjukbärare",
    "sjukbärares": "sjukbärare",
    "sjukbärarna": "sjukbärare",
    "sjukbärarnas": "sjukbärare",
    "sjukdagar": "sjukdag",
    "sjukdagarna": "sjukdag",
    "sjukdagarnas": "sjukdag",
    "sjukdagars": "sjukdag",
    "sjukdagen": "sjukdag",
    "sjukdagens": "sjukdag",
    "sjukdags": "sjukdag",
    "sjukdomar": "sjukdom",
    "sjukdomarna": "sjukdom",
    "sjukdomarnas": "sjukdom",
    "sjukdomars": "sjukdom",
    "sjukdomen": "sjukdom",
    "sjukdomens": "sjukdom",
    "sjukdoms": "sjukdom",
    "sjukdomsbilden": "sjukdomsbild",
    "sjukdomsbildens": "sjukdomsbild",
    "sjukdomsbilder": "sjukdomsbild",
    "sjukdomsbilderna": "sjukdomsbild",
    "sjukdomsbildernas": "sjukdomsbild",
    "sjukdomsbilders": "sjukdomsbild",
    "sjukdomsbilds": "sjukdomsbild",
    "sjukdomsförklaringar": "sjukdomsförklaring",
    "sjukdomsförklaringarna": "sjukdomsförklaring",
    "sjukdomsförklaringarnas": "sjukdomsförklaring",
    "sjukdomsförklaringars": "sjukdomsförklaring",
    "sjukdomsförklaringen": "sjukdomsförklaring",
    "sjukdomsförklaringens": "sjukdomsförklaring",
    "sjukdomsförklarings": "sjukdomsförklaring",
    "sjukdomsförloppen": "sjukdomsförlopp",
    "sjukdomsförloppens": "sjukdomsförlopp",
    "sjukdomsförloppet": "sjukdomsförlopp",
    "sjukdomsförloppets": "sjukdomsförlopp",
    "sjukdomsförlopps": "sjukdomsförlopp",
    "sjukdomshistorian": "sjukdomshistoria",
    "sjukdomshistorians": "sjukdomshistoria",
    "sjukdomshistorias": "sjukdomshistoria",
    "sjukdomshistorien": "sjukdomshistoria",
    "sjukdomshistoriens": "sjukdomshistoria",
    "sjukdomshistorier": "sjukdomshistoria",
    "sjukdomshistorierna": "sjukdomshistoria",
    "sjukdomshistoriernas": "sjukdomshistoria",
    "sjukdomshistoriers": "sjukdomshistoria",
    "sjukdomsklassade": "sjukdomsklassad",
    "sjukdomsklassades": "sjukdomsklassad",
    "sjukdomsklassads": "sjukdomsklassad",
    "sjukdomsklassat": "sjukdomsklassad",
    "sjukdomsklassats": "sjukdomsklassad",
    "sjukdomssymptomen": "sjukdomssymptom",
    "sjukdomssymptomens": "sjukdomssymptom",
    "sjukdomssymptomet": "sjukdomssymptom",
    "sjukdomssymptomets": "sjukdomssymptom",
    "sjukdomssymptoms": "sjukdomssymptom",
    "sjukdomssymtomen": "sjukdomssymtom",
    "sjukdomssymtomens": "sjukdomssymtom",
    "sjukdomssymtomet": "sjukdomssymtom",
    "sjukdomssymtomets": "sjukdomssymtom",
    "sjukdomssymtoms": "sjukdomssymtom",
    "sjukdomstillstånden": "sjukdomstillstånd",
    "sjukdomstillståndens": "sjukdomstillstånd",
    "sjukdomstillståndet": "sjukdomstillstånd",
    "sjukdomstillståndets": "sjukdomstillstånd",
    "sjukdomstillstånds": "sjukdomstillstånd",
    "sjuke": "sjuka",
    "sjukersättningar": "sjukersättning",
    "sjukersättningarna": "sjukersättning",
    "sjukersättningarnas": "sjukersättning",
    "sjukersättningars": "sjukersättning",
    "sjukersättningen": "sjukersättning",
    "sjukersättningens": "sjukersättning",
    "sjukersättnings": "sjukersättning",
    "sjukes": "sjuk",
    "sjukfrånvaron": "sjukfrånvaro",
    "sjukfrånvarons": "sjukfrånvaro",
    "sjukfrånvaros": "sjukfrånvaro",
    "sjukförsäkringar": "sjukförsäkring",
    "sjukförsäkringarna": "sjukförsäkring",
    "sjukförsäkringarnas": "sjukförsäkring",
    "sjukförsäkringars": "sjukförsäkring",
    "sjukförsäkringen": "sjukförsäkring",
    "sjukförsäkringens": "sjukförsäkring",
    "sjukförsäkrings": "sjukförsäkring",
    "sjukgymnasten": "sjukgymnast",
    "sjukgymnastens": "sjukgymnast",
    "sjukgymnaster": "sjukgymnast",
    "sjukgymnasterna": "sjukgymnast",
    "sjukgymnasternas": "sjukgymnast",
    "sjukgymnasters": "sjukgymnast",
    "sjukgymnastiken": "sjukgymnastik",
    "sjukgymnastikens": "sjukgymnastik",
    "sjukgymnastiks": "sjukgymnastik",
    "sjukgymnasts": "sjukgymnast",
    "sjukhemmen": "sjukhem",
    "sjukhemmens": "sjukhem",
    "sjukhemmet": "sjukhem",
    "sjukhemmets": "sjukhem",
    "sjukhems": "sjukhem",
    "sjukheten": "sjukhet",
    "sjukhetens": "sjukhet",
    "sjukheter": "sjukhet",
    "sjukheterna": "sjukhet",
    "sjukheternas": "sjukhet",
    "sjukheters": "sjukhet",
    "sjukhets": "sjukhet",
    "sjukhusavdelningar": "sjukhusavdelning",
    "sjukhusavdelningarna": "sjukhusavdelning",
    "sjukhusavdelningarnas": "sjukhusavdelning",
    "sjukhusavdelningars": "sjukhusavdelning",
    "sjukhusavdelningen": "sjukhusavdelning",
    "sjukhusavdelningens": "sjukhusavdelning",
    "sjukhusavdelnings": "sjukhusavdelning",
    "sjukhusbäddar": "sjukhusbädd",
    "sjukhusbäddarna": "sjukhusbädd",
    "sjukhusbäddarnas": "sjukhusbädd",
    "sjukhusbäddars": "sjukhusbädd",
    "sjukhusbädden": "sjukhusbädd",
    "sjukhusbäddens": "sjukhusbädd",
    "sjukhusbädds": "sjukhusbädd",
    "sjukhusdirektören": "sjukhusdirektör",
    "sjukhusdirektörens": "sjukhusdirektör",
    "sjukhusdirektörer": "sjukhusdirektör",
    "sjukhusdirektörerna": "sjukhusdirektör",
    "sjukhusdirektörernas": "sjukhusdirektör",
    "sjukhusdirektörers": "sjukhusdirektör",
    "sjukhusdirektörn": "sjukhusdirektör",
    "sjukhusdirektörns": "sjukhusdirektör",
    "sjukhusdirektörs": "sjukhusdirektör",
    "sjukhusen": "sjukhus",
    "sjukhusens": "sjukhus",
    "sjukhusentréer": "sjukhusentré",
    "sjukhusentréerna": "sjukhusentré",
    "sjukhusentréernas": "sjukhusentré",
    "sjukhusentréers": "sjukhusentré",
    "sjukhusentrén": "sjukhusentré",
    "sjukhusentréns": "sjukhusentré",
    "sjukhusentrés": "sjukhusentré",
    "sjukhuset": "sjukhus",
    "sjukhusets": "sjukhus",
    "sjukhuskorridoren": "sjukhuskorridor",
    "sjukhuskorridorens": "sjukhuskorridor",
    "sjukhuskorridorer": "sjukhuskorridor",
    "sjukhuskorridorerna": "sjukhuskorridor",
    "sjukhuskorridorernas": "sjukhuskorridor",
    "sjukhuskorridorers": "sjukhuskorridor",
    "sjukhuskorridors": "sjukhuskorridor",
    "sjukhusrena": "sjukhusren",
    "sjukhusrenare": "sjukhusren",
    "sjukhusrenares": "sjukhusren",
    "sjukhusrenas": "sjukhusren",
    "sjukhusrenast": "sjukhusren",
    "sjukhusrenaste": "sjukhusren",
    "sjukhusrenastes": "sjukhusren",
    "sjukhusrenasts": "sjukhusren",
    "sjukhusrene": "sjukhusren",
    "sjukhusrenes": "sjukhusren",
    "sjukhusrens": "sjukhusren",
    "sjukhusrent": "sjukhusren",
    "sjukhusrents": "sjukhusren",
    "sjukhussalar": "sjukhussal",
    "sjukhussalarna": "sjukhussal",
    "sjukhussalarnas": "sjukhussal",
    "sjukhussalars": "sjukhussal",
    "sjukhussalen": "sjukhussal",
    "sjukhussalens": "sjukhussal",
    "sjukhussals": "sjukhussal",
    "sjukhussjukan": "sjukhussjuka",
    "sjukhussjukans": "sjukhussjuka",
    "sjukhussjukas": "sjukhussjuka",
    "sjukhussjuke": "sjukhussjuka",
    "sjukhussjuks": "sjukhussjuka",
    "sjukhussängar": "sjukhussäng",
    "sjukhussängarna": "sjukhussäng",
    "sjukhussängarnas": "sjukhussäng",
    "sjukhussängars": "sjukhussäng",
    "sjukhussängen": "sjukhussäng",
    "sjukhussängens": "sjukhussäng",
    "sjukhussängs": "sjukhussäng",
    "sjukhusvården": "sjukhusvård",
    "sjukhusvårdens": "sjukhusvård",
    "sjukhusvårds": "sjukhusvård",
    "sjukjournalen": "sjukjournal",
    "sjukjournalens": "sjukjournal",
    "sjukjournaler": "sjukjournal",
    "sjukjournalerna": "sjukjournal",
    "sjukjournalernas": "sjukjournal",
    "sjukjournalers": "sjukjournal",
    "sjukjournals": "sjukjournal",
    "sjukkassan": "sjukkassa",
    "sjukkassans": "sjukkassa",
    "sjukkassas": "sjukkassa",
    "sjukkasse": "sjukkassa",
    "sjukkassor": "sjukkassa",
    "sjukkassorna": "sjukkassa",
    "sjukkassornas": "sjukkassa",
    "sjukkassors": "sjukkassa",
    "sjuklediga": "sjukledig",
    "sjukledigare": "sjukledig",
    "sjukledigares": "sjukledig",
    "sjukledigas": "sjukledig",
    "sjukledigast": "sjukledig",
    "sjukledigaste": "sjukledig",
    "sjukledigastes": "sjukledig",
    "sjukledigasts": "sjukledig",
    "sjukledige": "sjukledig",
    "sjuklediges": "sjukledig",
    "sjukledigheten": "sjukledighet",
    "sjukledighetens": "sjukledighet",
    "sjukledigheter": "sjukledighet",
    "sjukledigheterna": "sjukledighet",
    "sjukledigheternas": "sjukledighet",
    "sjukledigheters": "sjukledighet",
    "sjukledighets": "sjukledighet",
    "sjukledigs": "sjukledig",
    "sjukledigt": "sjukledig",
    "sjukledigts": "sjukledig",
    "sjukliga": "sjuklig",
    "sjukligare": "sjuklig",
    "sjukligares": "sjuklig",
    "sjukligas": "sjuklig",
    "sjukligast": "sjuklig",
    "sjukligaste": "sjuklig",
    "sjukligastes": "sjuklig",
    "sjukligasts": "sjuklig",
    "sjuklige": "sjuklig",
    "sjukliges": "sjuklig",
    "sjukligheten": "sjuklighet",
    "sjuklighetens": "sjuklighet",
    "sjukligheter": "sjuklighet",
    "sjukligheterna": "sjuklighet",
    "sjukligheternas": "sjuklighet",
    "sjukligheters": "sjuklighet",
    "sjuklighets": "sjuklighet",
    "sjukligs": "sjuklig",
    "sjukligt": "sjuklig",
    "sjukligts": "sjuklig",
    "sjuklingar": "sjukling",
    "sjuklingarna": "sjukling",
    "sjuklingarnas": "sjukling",
    "sjuklingars": "sjukling",
    "sjuklingen": "sjukling",
    "sjuklingens": "sjukling",
    "sjuklings": "sjukling",
    "sjuklägerna": "sjukläger",
    "sjuklägernas": "sjukläger",
    "sjuklägers": "sjukläger",
    "sjuklägren": "sjukläger",
    "sjuklägrens": "sjukläger",
    "sjuklägret": "sjukläger",
    "sjuklägrets": "sjukläger",
    "sjuknade": "sjukna",
    "sjuknades": "sjukna",
    "sjuknande": "sjukna",
    "sjuknanden": "sjuknande",
    "sjuknandena": "sjuknande",
    "sjuknandenas": "sjuknande",
    "sjuknandens": "sjuknande",
    "sjuknandes": "sjuknande",
    "sjuknandet": "sjuknande",
    "sjuknandets": "sjuknande",
    "sjuknar": "sjukna",
    "sjuknas": "sjukna",
    "sjuknat": "sjukna",
    "sjuknats": "sjukna",
    "sjukor": "sjuka",
    "sjukorna": "sjuka",
    "sjukornas": "sjuka",
    "sjukors": "sjuka",
    "sjukpengen": "sjukpeng",
    "sjukpengens": "sjukpeng",
    "sjukpengs": "sjukpeng",
    "sjukpenningar": "sjukpenning",
    "sjukpenningarna": "sjukpenning",
    "sjukpenningarnas": "sjukpenning",
    "sjukpenningars": "sjukpenning",
    "sjukpenningen": "sjukpenning",
    "sjukpenningens": "sjukpenning",
    "sjukpennings": "sjukpenning",
    "sjukpensionen": "sjukpension",
    "sjukpensionens": "sjukpension",
    "sjukpensioner": "sjukpension",
    "sjukpensionerna": "sjukpension",
    "sjukpensionernas": "sjukpension",
    "sjukpensioners": "sjukpension",
    "sjukpensions": "sjukpension",
    "sjukregeln": "sjukregel",
    "sjukregelns": "sjukregel",
    "sjukregels": "sjukregel",
    "sjukregler": "sjukregel",
    "sjukreglerna": "sjukregel",
    "sjukreglernas": "sjukregel",
    "sjukreglers": "sjukregel",
    "sjuks": "sjuka",
    "sjukskrev": "sjukskriva",
    "sjukskrevs": "sjukskriva",
    "sjukskriv": "sjukskriva",
    "sjukskrivande": "sjukskriva",
    "sjukskrivanden": "sjukskrivande",
    "sjukskrivandena": "sjukskrivande",
    "sjukskrivandenas": "sjukskrivande",
    "sjukskrivandens": "sjukskrivande",
    "sjukskrivandes": "sjukskrivande",
    "sjukskrivandet": "sjukskrivande",
    "sjukskrivandets": "sjukskrivande",
    "sjukskrivas": "sjukskriva",
    "sjukskrive": "sjukskriva",
    "sjukskriven": "sjukskriva",
    "sjukskrivens": "sjukskriva",
    "sjukskriver": "sjukskriva",
    "sjukskrives": "sjukskriva",
    "sjukskrivet": "sjukskriva",
    "sjukskrivets": "sjukskriva",
    "sjukskrivit": "sjukskriva",
    "sjukskrivits": "sjukskriva",
    "sjukskrivna": "sjukskriva",
    "sjukskrivnas": "sjukskriva",
    "sjukskrivne": "sjukskriva",
    "sjukskrivnes": "sjukskriva",
    "sjukskrivningar": "sjukskrivning",
    "sjukskrivningarna": "sjukskrivning",
    "sjukskrivningarnas": "sjukskrivning",
    "sjukskrivningars": "sjukskrivning",
    "sjukskrivningen": "sjukskrivning",
    "sjukskrivningens": "sjukskrivning",
    "sjukskrivnings": "sjukskrivning",
    "sjukskrivs": "sjukskriva",
    "sjukskötar": "sjukskötare",
    "sjukskötaren": "sjukskötare",
    "sjukskötarens": "sjukskötare",
    "sjukskötares": "sjukskötare",
    "sjukskötarna": "sjukskötare",
    "sjukskötarnas": "sjukskötare",
    "sjuksköterskan": "sjuksköterska",
    "sjuksköterskans": "sjuksköterska",
    "sjuksköterskas": "sjuksköterska",
    "sjuksköterske": "sjuksköterska",
    "sjuksköterskeexamens": "sjuksköterskeexamen",
    "sjuksköterskeexamina": "sjuksköterskeexamen",
    "sjuksköterskeexaminas": "sjuksköterskeexamen",
    "sjuksköterskeutbildningar": "sjuksköterskeutbildning",
    "sjuksköterskeutbildningarna": "sjuksköterskeutbildning",
    "sjuksköterskeutbildningarnas": "sjuksköterskeutbildning",
    "sjuksköterskeutbildningars": "sjuksköterskeutbildning",
    "sjuksköterskeutbildningen": "sjuksköterskeutbildning",
    "sjuksköterskeutbildningens": "sjuksköterskeutbildning",
    "sjuksköterskeutbildnings": "sjuksköterskeutbildning",
    "sjuksköterskor": "sjuksköterska",
    "sjuksköterskorna": "sjuksköterska",
    "sjuksköterskornas": "sjuksköterska",
    "sjuksköterskors": "sjuksköterska",
    "sjukstugan": "sjukstuga",
    "sjukstugans": "sjukstuga",
    "sjukstugas": "sjukstuga",
    "sjukstuge": "sjukstuga",
    "sjukstugor": "sjukstuga",
    "sjukstugorna": "sjukstuga",
    "sjukstugornas": "sjukstuga",
    "sjukstugors": "sjukstuga",
    "sjukstugu": "sjukstuga",
    "sjuksystern": "sjuksyster",
    "sjuksysterns": "sjuksyster",
    "sjuksysters": "sjuksyster",
    "sjuksystrar": "sjuksyster",
    "sjuksystrarna": "sjuksyster",
    "sjuksystrarnas": "sjuksyster",
    "sjuksystrars": "sjuksyster",
    "sjukt": "sjuk",
    "sjuktransporten": "sjuktransport",
    "sjuktransportens": "sjuktransport",
    "sjuktransporter": "sjuktransport",
    "sjuktransporterna": "sjuktransport",
    "sjuktransporternas": "sjuktransport",
    "sjuktransporters": "sjuktransport",
    "sjuktransports": "sjuktransport",
    "sjukts": "sjuk",
    "sjukvikarien": "sjukvikarie",
    "sjukvikariens": "sjukvikarie",
    "sjukvikarier": "sjukvikarie",
    "sjukvikarierna": "sjukvikarie",
    "sjukvikariernas": "sjukvikarie",
    "sjukvikariers": "sjukvikarie",
    "sjukvikaries": "sjukvikarie",
    "sjukvårdar": "sjukvårdare",
    "sjukvårdaren": "sjukvårdare",
    "sjukvårdarens": "sjukvårdare",
    "sjukvårdares": "sjukvårdare",
    "sjukvårdarna": "sjukvårdare",
    "sjukvårdarnas": "sjukvårdare",
    "sjukvården": "sjukvård",
    "sjukvårdens": "sjukvård",
    "sjukvårds": "sjukvård",
    "sjukvårdsaffären": "sjukvårdsaffär",
    "sjukvårdsaffärens": "sjukvårdsaffär",
    "sjukvårdsaffärer": "sjukvårdsaffär",
    "sjukvårdsaffärerna": "sjukvårdsaffär",
    "sjukvårdsaffärernas": "sjukvårdsaffär",
    "sjukvårdsaffärers": "sjukvårdsaffär",
    "sjukvårdsaffärs": "sjukvårdsaffär",
    "sjukvårdsartikeln": "sjukvårdsartikel",
    "sjukvårdsartikelns": "sjukvårdsartikel",
    "sjukvårdsartikels": "sjukvårdsartikel",
    "sjukvårdsartiklar": "sjukvårdsartikel",
    "sjukvårdsartiklarna": "sjukvårdsartikel",
    "sjukvårdsartiklarnas": "sjukvårdsartikel",
    "sjukvårdsartiklars": "sjukvårdsartikel",
    "sjukvårdsbiträden": "sjukvårdsbiträde",
    "sjukvårdsbiträdena": "sjukvårdsbiträde",
    "sjukvårdsbiträdenas": "sjukvårdsbiträde",
    "sjukvårdsbiträdens": "sjukvårdsbiträde",
    "sjukvårdsbiträdes": "sjukvårdsbiträde",
    "sjukvårdsbiträdet": "sjukvårdsbiträde",
    "sjukvårdsbiträdets": "sjukvårdsbiträde",
    "sjukvårdsförsäkringar": "sjukvårdsförsäkring",
    "sjukvårdsförsäkringarna": "sjukvårdsförsäkring",
    "sjukvårdsförsäkringarnas": "sjukvårdsförsäkring",
    "sjukvårdsförsäkringars": "sjukvårdsförsäkring",
    "sjukvårdsförsäkringen": "sjukvårdsförsäkring",
    "sjukvårdsförsäkringens": "sjukvårdsförsäkring",
    "sjukvårdsförsäkrings": "sjukvårdsförsäkring",
    "sjukvårdsmässiga": "sjukvårdsmässig",
    "sjukvårdsmässigare": "sjukvårdsmässig",
    "sjukvårdsmässigares": "sjukvårdsmässig",
    "sjukvårdsmässigas": "sjukvårdsmässig",
    "sjukvårdsmässigast": "sjukvårdsmässig",
    "sjukvårdsmässigaste": "sjukvårdsmässig",
    "sjukvårdsmässigastes": "sjukvårdsmässig",
    "sjukvårdsmässigasts": "sjukvårdsmässig",
    "sjukvårdsmässige": "sjukvårdsmässig",
    "sjukvårdsmässiges": "sjukvårdsmässig",
    "sjukvårdsmässigs": "sjukvårdsmässig",
    "sjukvårdsmässigt": "sjukvårdsmässig",
    "sjukvårdsmässigts": "sjukvårdsmässig",
    "sjukvårdspolitiken": "sjukvårdspolitik",
    "sjukvårdspolitikens": "sjukvårdspolitik",
    "sjukvårdspolitiks": "sjukvårdspolitik",
    "sjukvårdspolitiska": "sjukvårdspolitisk",
    "sjukvårdspolitiskas": "sjukvårdspolitisk",
    "sjukvårdspolitiske": "sjukvårdspolitisk",
    "sjukvårdspolitiskes": "sjukvårdspolitisk",
    "sjukvårdspolitisks": "sjukvårdspolitisk",
    "sjukvårdspolitiskt": "sjukvårdspolitisk",
    "sjukvårdspolitiskts": "sjukvårdspolitisk",
    "sjukvårdsreformen": "sjukvårdsreform",
    "sjukvårdsreformens": "sjukvårdsreform",
    "sjukvårdsreformer": "sjukvårdsreform",
    "sjukvårdsreformerna": "sjukvårdsreform",
    "sjukvårdsreformernas": "sjukvårdsreform",
    "sjukvårdsreformers": "sjukvårdsreform",
    "sjukvårdsreforms": "sjukvårdsreform",
    "sjukvårdsregionen": "sjukvårdsregion",
    "sjukvårdsregionens": "sjukvårdsregion",
    "sjukvårdsregioner": "sjukvårdsregion",
    "sjukvårdsregionerna": "sjukvårdsregion",
    "sjukvårdsregionernas": "sjukvårdsregion",
    "sjukvårdsregioners": "sjukvårdsregion",
    "sjukvårdsregions": "sjukvårdsregion",
    "sjukvårdsutbildningar": "sjukvårdsutbildning",
    "sjukvårdsutbildningarna": "sjukvårdsutbildning",
    "sjukvårdsutbildningarnas": "sjukvårdsutbildning",
    "sjukvårdsutbildningars": "sjukvårdsutbildning",
    "sjukvårdsutbildningen": "sjukvårdsutbildning",
    "sjukvårdsutbildningens": "sjukvårdsutbildning",
    "sjukvårdsutbildnings": "sjukvårdsutbildning",
    "sjukvårdsutrustningar": "sjukvårdsutrustning",
    "sjukvårdsutrustningarna": "sjukvårdsutrustning",
    "sjukvårdsutrustningarnas": "sjukvårdsutrustning",
    "sjukvårdsutrustningars": "sjukvårdsutrustning",
    "sjukvårdsutrustningen": "sjukvårdsutrustning",
    "sjukvårdsutrustningens": "sjukvårdsutrustning",
    "sjukvårdsutrustnings": "sjukvårdsutrustning",
    "sjulingar": "sjuling",
    "sjulingarna": "sjuling",
    "sjulingarnas": "sjuling",
    "sjulingars": "sjuling",
    "sjulingen": "sjuling",
    "sjulingens": "sjuling",
    "sjulings": "sjuling",
    "sjumilakliven": "sjumilakliv",
    "sjumilaklivens": "sjumilakliv",
    "sjumilaklivet": "sjumilakliv",
    "sjumilaklivets": "sjumilakliv",
    "sjumilaklivs": "sjumilakliv",
    "sjumilastövel": "sjumilastövlar",
    "sjumilastövels": "sjumilastövlar",
    "sjumilastövlarna": "sjumilastövlar",
    "sjumilastövlarnas": "sjumilastövlar",
    "sjumilastövlars": "sjumilastövlar",
    "sjunde": "sju",
    "sjundedagsadventisten": "sjundedagsadventist",
    "sjundedagsadventistens": "sjundedagsadventist",
    "sjundedagsadventister": "sjundedagsadventist",
    "sjundedagsadventisterna": "sjundedagsadventist",
    "sjundedagsadventisternas": "sjundedagsadventist",
    "sjundedagsadventisters": "sjundedagsadventist",
    "sjundedagsadventists": "sjundedagsadventist",
    "sjundedelar": "sjundedel",
    "sjundedelarna": "sjundedel",
    "sjundedelarnas": "sjundedel",
    "sjundedelars": "sjundedel",
    "sjundedelen": "sjundedel",
    "sjundedelens": "sjundedel",
    "sjundedels": "sjundedel",
    "sjundes": "sju",
    "sjung": "sjunga",
    "sjungande": "sjunga",
    "sjungandes": "sjungande",
    "sjungandet": "sjungande",
    "sjungandets": "sjungande",
    "sjungas": "sjunga",
    "sjunge": "sjunga",
    "sjungen": "sjunga",
    "sjungens": "sjunga",
    "sjunger": "sjunga",
    "sjunges": "sjunga",
    "sjunget": "sjunga",
    "sjungets": "sjunga",
    "sjungit": "sjunga",
    "sjungits": "sjunga",
    "sjungna": "sjunga",
    "sjungnas": "sjunga",
    "sjungne": "sjunga",
    "sjungnes": "sjunga",
    "sjungs": "sjunga",
    "sjunk": "sjunka",
    "sjunkande": "sjunka",
    "sjunkanden": "sjunkande",
    "sjunkandena": "sjunkande",
    "sjunkandenas": "sjunkande",
    "sjunkandens": "sjunkande",
    "sjunkandes": "sjunkande",
    "sjunkandet": "sjunkande",
    "sjunkandets": "sjunkande",
    "sjunkas": "sjunka",
    "sjunkbomben": "sjunkbomb",
    "sjunkbombens": "sjunkbomb",
    "sjunkbomber": "sjunkbomb",
    "sjunkbomberna": "sjunkbomb",
    "sjunkbombernas": "sjunkbomb",
    "sjunkbombers": "sjunkbomb",
    "sjunkbombs": "sjunkbomb",
    "sjunke": "sjunka",
    "sjunken": "sjunka",
    "sjunkens": "sjunka",
    "sjunker": "sjunka",
    "sjunkes": "sjunka",
    "sjunket": "sjunka",
    "sjunkets": "sjunka",
    "sjunkit": "sjunka",
    "sjunkits": "sjunka",
    "sjunkna": "sjunka",
    "sjunknas": "sjunka",
    "sjunkne": "sjunka",
    "sjunknes": "sjunka",
    "sjunks": "sjunka",
    "sjuor": "sjua",
    "sjuorna": "sjua",
    "sjuornas": "sjua",
    "sjuors": "sjua",
    "sjuryggar": "sjurygg",
    "sjuryggarna": "sjurygg",
    "sjuryggarnas": "sjurygg",
    "sjuryggars": "sjurygg",
    "sjuryggen": "sjurygg",
    "sjuryggens": "sjurygg",
    "sjuryggs": "sjurygg",
    "sjus": "sju",
    "sjusnårets": "sjusnåret",
    "sjusovar": "sjusovare",
    "sjusovaren": "sjusovare",
    "sjusovarens": "sjusovare",
    "sjusovares": "sjusovare",
    "sjusovarna": "sjusovare",
    "sjusovarnas": "sjusovare",
    "sjustjärnan": "sjustjärna",
    "sjustjärnans": "sjustjärna",
    "sjustjärnas": "sjustjärna",
    "sjustjärne": "sjustjärna",
    "sjustjärnor": "sjustjärna",
    "sjustjärnorna": "sjustjärna",
    "sjustjärnornas": "sjustjärna",
    "sjustjärnors": "sjustjärna",
    "sjutillhållarlåsen": "sjutillhållarlås",
    "sjutillhållarlåsens": "sjutillhållarlås",
    "sjutillhållarlåset": "sjutillhållarlås",
    "sjutillhållarlåsets": "sjutillhållarlås",
    "sjuttionde": "sjuttio",
    "sjuttiondes": "sjuttio",
    "sjuttios": "sjuttio",
    "sjuttiotalet": "sjuttiotal",
    "sjuttiotalets": "sjuttiotal",
    "sjuttiotals": "sjuttiotal",
    "sjuttis": "sjutti",
    "sjuttitalet": "sjuttital",
    "sjuttitalets": "sjuttital",
    "sjuttitals": "sjuttital",
    "sjuttonde": "sjutton",
    "sjuttondes": "sjutton",
    "sjuttonhundratalet": "sjuttonhundratal",
    "sjuttonhundratalets": "sjuttonhundratal",
    "sjuttonhundratals": "sjuttonhundratal",
    "sjuttons": "sjutton",
    "sjuttonsnårets": "sjuttonsnåret",
    "sjuttonåriga": "sjuttonårig",
    "sjuttonårigas": "sjuttonårig",
    "sjuttonårige": "sjuttonårig",
    "sjuttonåriges": "sjuttonårig",
    "sjuttonårigs": "sjuttonårig",
    "sjuttonårigt": "sjuttonårig",
    "sjuttonårigts": "sjuttonårig",
    "sjuttonåringar": "sjuttonåring",
    "sjuttonåringarna": "sjuttonåring",
    "sjuttonåringarnas": "sjuttonåring",
    "sjuttonåringars": "sjuttonåring",
    "sjuttonåringen": "sjuttonåring",
    "sjuttonåringens": "sjuttonåring",
    "sjuttonårings": "sjuttonåring",
    "sjutumsspikar": "sjutumsspik",
    "sjutumsspikarna": "sjutumsspik",
    "sjutumsspikarnas": "sjutumsspik",
    "sjutumsspikars": "sjutumsspik",
    "sjutumsspiken": "sjutumsspik",
    "sjutumsspikens": "sjutumsspik",
    "sjutumsspiks": "sjutumsspik",
    "sjutusans": "sjutusan",
    "sjuåriga": "sjuårig",
    "sjuårigas": "sjuårig",
    "sjuårige": "sjuårig",
    "sjuåriges": "sjuårig",
    "sjuårigs": "sjuårig",
    "sjuårigt": "sjuårig",
    "sjuårigts": "sjuårig",
    "sjuåringar": "sjuåring",
    "sjuåringarna": "sjuåring",
    "sjuåringarnas": "sjuåring",
    "sjuåringars": "sjuåring",
    "sjuåringen": "sjuåring",
    "sjuåringens": "sjuåring",
    "sjuårings": "sjuåring",
    "sjysta": "sjyst",
    "sjystare": "sjyst",
    "sjystares": "sjyst",
    "sjystas": "sjyst",
    "sjystast": "sjyst",
    "sjystaste": "sjyst",
    "sjystastes": "sjyst",
    "sjystasts": "sjyst",
    "sjyste": "sjyst",
    "sjystes": "sjyst",
    "sjystheten": "sjysthet",
    "sjysthetens": "sjysthet",
    "sjysthets": "sjysthet",
    "sjysts": "sjyst",
    "själaglada": "själaglad",
    "själagladare": "själaglad",
    "själagladares": "själaglad",
    "själagladas": "själaglad",
    "själagladast": "själaglad",
    "själagladaste": "själaglad",
    "själagladastes": "själaglad",
    "själagladasts": "själaglad",
    "själaglade": "själaglad",
    "själaglades": "själaglad",
    "själaglads": "själaglad",
    "själaglatt": "själaglad",
    "själaglatts": "själaglad",
    "själamäss": "själamässa",
    "själamässan": "själamässa",
    "själamässans": "själamässa",
    "själamässas": "själamässa",
    "själamässe": "själamässa",
    "själamässor": "själamässa",
    "själamässorna": "själamässa",
    "själamässornas": "själamässa",
    "själamässors": "själamässa",
    "själanöden": "själanöd",
    "själanödens": "själanöd",
    "själanöds": "själanöd",
    "själar": "själ",
    "själaringningar": "själaringning",
    "själaringningarna": "själaringning",
    "själaringningarnas": "själaringning",
    "själaringningars": "själaringning",
    "själaringningen": "själaringning",
    "själaringningens": "själaringning",
    "själaringnings": "själaringning",
    "själarna": "själ",
    "själarnas": "själ",
    "själars": "själ",
    "själasörjar": "själasörjare",
    "själasörjaren": "själasörjare",
    "själasörjarens": "själasörjare",
    "själasörjares": "själasörjare",
    "själasörjarna": "själasörjare",
    "själasörjarnas": "själasörjare",
    "själatåget": "själatåg",
    "själatågets": "själatåg",
    "själatågs": "själatåg",
    "själavandringar": "själavandring",
    "själavandringarna": "själavandring",
    "själavandringarnas": "själavandring",
    "själavandringars": "själavandring",
    "själavandringen": "själavandring",
    "själavandringens": "själavandring",
    "själavandrings": "själavandring",
    "själavården": "själavård",
    "själavårdens": "själavård",
    "själavårds": "själavård",
    "själavårdsmässiga": "själavårdsmässig",
    "själavårdsmässigare": "själavårdsmässig",
    "själavårdsmässigares": "själavårdsmässig",
    "själavårdsmässigas": "själavårdsmässig",
    "själavårdsmässigast": "själavårdsmässig",
    "själavårdsmässigaste": "själavårdsmässig",
    "själavårdsmässigastes": "själavårdsmässig",
    "själavårdsmässigasts": "själavårdsmässig",
    "själavårdsmässige": "själavårdsmässig",
    "själavårdsmässiges": "själavårdsmässig",
    "själavårdsmässigs": "själavårdsmässig",
    "själavårdsmässigt": "själavårdsmässig",
    "själavårdsmässigts": "själavårdsmässig",
    "själen": "själ",
    "själens": "själ",
    "själfulla": "själfull",
    "själfullare": "själfull",
    "själfullares": "själfull",
    "själfullas": "själfull",
    "själfullast": "själfull",
    "själfullaste": "själfull",
    "själfullastes": "själfull",
    "själfullasts": "själfull",
    "själfulle": "själfull",
    "själfulles": "själfull",
    "själfullheten": "själfullhet",
    "själfullhetens": "själfullhet",
    "själfullhets": "själfullhet",
    "själfulls": "själfull",
    "själfullt": "själfull",
    "själfullts": "själfull",
    "själiska": "själisk",
    "själiskare": "själisk",
    "själiskares": "själisk",
    "själiskas": "själisk",
    "själiskast": "själisk",
    "själiskaste": "själisk",
    "själiskastes": "själisk",
    "själiskasts": "själisk",
    "själiske": "själisk",
    "själiskes": "själisk",
    "själisks": "själisk",
    "själiskt": "själisk",
    "själiskts": "själisk",
    "själlösa": "själlös",
    "själlösare": "själlös",
    "själlösares": "själlös",
    "själlösas": "själlös",
    "själlösast": "själlös",
    "själlösaste": "själlös",
    "själlösastes": "själlös",
    "själlösasts": "själlös",
    "själlöse": "själlös",
    "själlöses": "själlös",
    "själlösheten": "själlöshet",
    "själlöshetens": "själlöshet",
    "själlösheter": "själlöshet",
    "själlösheterna": "själlöshet",
    "själlösheternas": "själlöshet",
    "själlösheters": "själlöshet",
    "själlöshets": "själlöshet",
    "själlöst": "själlös",
    "själlösts": "själlös",
    "själs": "själ",
    "själsadeln": "själsadel",
    "själsadelns": "själsadel",
    "själsadels": "själsadel",
    "själsbesläktade": "själsbesläktad",
    "själsbesläktades": "själsbesläktad",
    "själsbesläktads": "själsbesläktad",
    "själsbesläktat": "själsbesläktad",
    "själsbesläktats": "själsbesläktad",
    "själsegenskapen": "själsegenskap",
    "själsegenskapens": "själsegenskap",
    "själsegenskaper": "själsegenskap",
    "själsegenskaperna": "själsegenskap",
    "själsegenskapernas": "själsegenskap",
    "själsegenskapers": "själsegenskap",
    "själsegenskaps": "själsegenskap",
    "själsfinheten": "själsfinhet",
    "själsfinhetens": "själsfinhet",
    "själsfinhets": "själsfinhet",
    "själsfränden": "själsfrände",
    "själsfrändens": "själsfrände",
    "själsfränder": "själsfrände",
    "själsfränderna": "själsfrände",
    "själsfrändernas": "själsfrände",
    "själsfränders": "själsfrände",
    "själsfrändes": "själsfrände",
    "själsfrånvaron": "själsfrånvaro",
    "själsfrånvarons": "själsfrånvaro",
    "själsfrånvaros": "själsfrånvaro",
    "själsförmögenheten": "själsförmögenhet",
    "själsförmögenhetens": "själsförmögenhet",
    "själsförmögenheter": "själsförmögenhet",
    "själsförmögenheterna": "själsförmögenhet",
    "själsförmögenheternas": "själsförmögenhet",
    "själsförmögenheters": "själsförmögenhet",
    "själsförmögenhets": "själsförmögenhet",
    "själskonflikten": "själskonflikt",
    "själskonfliktens": "själskonflikt",
    "själskonflikter": "själskonflikt",
    "själskonflikterna": "själskonflikt",
    "själskonflikternas": "själskonflikt",
    "själskonflikters": "själskonflikt",
    "själskonflikts": "själskonflikt",
    "själsliga": "själslig",
    "själsligare": "själslig",
    "själsligares": "själslig",
    "själsligas": "själslig",
    "själsligast": "själslig",
    "själsligaste": "själslig",
    "själsligastes": "själslig",
    "själsligasts": "själslig",
    "själslige": "själslig",
    "själsliges": "själslig",
    "själsligheten": "själslighet",
    "själslighetens": "själslighet",
    "själslighets": "själslighet",
    "själsligs": "själslig",
    "själsligt": "själslig",
    "själsligts": "själslig",
    "själslivet": "själsliv",
    "själslivets": "själsliv",
    "själslivs": "själsliv",
    "själsnärvaron": "själsnärvaro",
    "själsnärvarons": "själsnärvaro",
    "själsnärvaros": "själsnärvaro",
    "själsnöden": "själsnöd",
    "själsnödens": "själsnöd",
    "själsnöds": "själsnöd",
    "själsron": "själsro",
    "själsrons": "själsro",
    "själsros": "själsro",
    "själssjuka": "själssjuk",
    "själssjukare": "själssjuk",
    "själssjukares": "själssjuk",
    "själssjukas": "själssjuk",
    "själssjukast": "själssjuk",
    "själssjukaste": "själssjuk",
    "själssjukastes": "själssjuk",
    "själssjukasts": "själssjuk",
    "själssjuke": "själssjuk",
    "själssjukes": "själssjuk",
    "själssjukheten": "själssjukhet",
    "själssjukhetens": "själssjukhet",
    "själssjukhets": "själssjukhet",
    "själssjuks": "själssjuk",
    "själssjukt": "själssjuk",
    "själssjukts": "själssjuk",
    "själsstriden": "själsstrid",
    "själsstridens": "själsstrid",
    "själsstrider": "själsstrid",
    "själsstriderna": "själsstrid",
    "själsstridernas": "själsstrid",
    "själsstriders": "själsstrid",
    "själsstrids": "själsstrid",
    "själsvånd": "själsvånda",
    "själsvåndan": "själsvånda",
    "själsvåndans": "själsvånda",
    "själsvåndas": "själsvånda",
    "själsvånde": "själsvånda",
    "själsvåndor": "själsvånda",
    "själsvåndorna": "själsvånda",
    "själsvåndornas": "själsvånda",
    "själsvåndors": "själsvånda",
    "själsvånds": "själsvånda",
    "själva": "själv",
    "självaktningar": "självaktning",
    "självaktningarna": "självaktning",
    "självaktningarnas": "självaktning",
    "självaktningars": "självaktning",
    "självaktningen": "självaktning",
    "självaktningens": "självaktning",
    "självaktnings": "självaktning",
    "självalstringar": "självalstring",
    "självalstringarna": "självalstring",
    "självalstringarnas": "självalstring",
    "självalstringars": "självalstring",
    "självalstringen": "självalstring",
    "självalstringens": "självalstring",
    "självalstrings": "självalstring",
    "självanalysen": "självanalys",
    "självanalysens": "självanalys",
    "självanalyser": "självanalys",
    "självanalyserna": "självanalys",
    "självanalysernas": "självanalys",
    "självanalysers": "självanalys",
    "självanklagelsen": "självanklagelse",
    "självanklagelsens": "självanklagelse",
    "självanklagelser": "självanklagelse",
    "självanklagelserna": "självanklagelse",
    "självanklagelsernas": "självanklagelse",
    "självanklagelsers": "självanklagelse",
    "självanklagelses": "självanklagelse",
    "självantänd": "självantända",
    "självantändande": "självantända",
    "självantändandes": "självantända",
    "självantändas": "självantända",
    "självantände": "självantända",
    "självantänder": "självantända",
    "självantändes": "självantända",
    "självantändningar": "självantändning",
    "självantändningarna": "självantändning",
    "självantändningarnas": "självantändning",
    "självantändningars": "självantändning",
    "självantändningen": "självantändning",
    "självantändningens": "självantändning",
    "självantändnings": "självantändning",
    "självantänds": "självantända",
    "självantänt": "självantända",
    "självantänts": "självantända",
    "självas": "själva",
    "självbedrägerier": "självbedrägeri",
    "självbedrägerierna": "självbedrägeri",
    "självbedrägeriernas": "självbedrägeri",
    "självbedrägeriers": "självbedrägeri",
    "självbedrägeriet": "självbedrägeri",
    "självbedrägeriets": "självbedrägeri",
    "självbedrägeris": "självbedrägeri",
    "självbedrägerit": "självbedrägeri",
    "självbedrägerits": "självbedrägeri",
    "självbefruktningar": "självbefruktning",
    "självbefruktningarna": "självbefruktning",
    "självbefruktningarnas": "självbefruktning",
    "självbefruktningars": "självbefruktning",
    "självbefruktningen": "självbefruktning",
    "självbefruktningens": "självbefruktning",
    "självbefruktnings": "självbefruktning",
    "självbehärskningar": "självbehärskning",
    "självbehärskningarna": "självbehärskning",
    "självbehärskningarnas": "självbehärskning",
    "självbehärskningars": "självbehärskning",
    "självbehärskningen": "självbehärskning",
    "självbehärskningens": "självbehärskning",
    "självbehärsknings": "självbehärskning",
    "självbekännelsen": "självbekännelse",
    "självbekännelsens": "självbekännelse",
    "självbekännelser": "självbekännelse",
    "självbekännelserna": "självbekännelse",
    "självbekännelsernas": "självbekännelse",
    "självbekännelsers": "självbekännelse",
    "självbekännelses": "självbekännelse",
    "självbelåtenheten": "självbelåtenhet",
    "självbelåtenhetens": "självbelåtenhet",
    "självbelåtenheter": "självbelåtenhet",
    "självbelåtenheterna": "självbelåtenhet",
    "självbelåtenheternas": "självbelåtenhet",
    "självbelåtenheters": "självbelåtenhet",
    "självbelåtenhets": "självbelåtenhet",
    "självbelåtens": "självbelåten",
    "självbelåtet": "självbelåten",
    "självbelåtets": "självbelåten",
    "självbelåtna": "självbelåten",
    "självbelåtnare": "självbelåten",
    "självbelåtnares": "självbelåten",
    "självbelåtnas": "självbelåten",
    "självbelåtnast": "självbelåten",
    "självbelåtnaste": "självbelåten",
    "självbelåtnastes": "självbelåten",
    "självbelåtnasts": "självbelåten",
    "självbelåtne": "självbelåten",
    "självbelåtnes": "självbelåten",
    "självbespeglanden": "självbespeglande",
    "självbespeglandena": "självbespeglande",
    "självbespeglandenas": "självbespeglande",
    "självbespeglandens": "självbespeglande",
    "självbespeglandes": "självbespeglande",
    "självbespeglandet": "självbespeglande",
    "självbespeglandets": "självbespeglande",
    "självbespeglingar": "självbespegling",
    "självbespeglingarna": "självbespegling",
    "självbespeglingarnas": "självbespegling",
    "självbespeglingars": "självbespegling",
    "självbespeglingen": "självbespegling",
    "självbespeglingens": "självbespegling",
    "självbespeglings": "självbespegling",
    "självbestämmandes": "självbestämmande",
    "självbestämmandet": "självbestämmande",
    "självbestämmandets": "självbestämmande",
    "självbetjäningar": "självbetjäning",
    "självbetjäningarna": "självbetjäning",
    "självbetjäningarnas": "självbetjäning",
    "självbetjäningars": "självbetjäning",
    "självbetjäningen": "självbetjäning",
    "självbetjäningens": "självbetjäning",
    "självbetjänings": "självbetjäning",
    "självbevaranden": "självbevarande",
    "självbevarandena": "självbevarande",
    "självbevarandenas": "självbevarande",
    "självbevarandens": "självbevarande",
    "självbevarandes": "självbevarande",
    "självbevarandet": "självbevarande",
    "självbevarandets": "självbevarande",
    "självbevarelsedriften": "självbevarelsedrift",
    "självbevarelsedriftens": "självbevarelsedrift",
    "självbevarelsedrifts": "självbevarelsedrift",
    "självbildningar": "självbildning",
    "självbildningarna": "självbildning",
    "självbildningarnas": "självbildning",
    "självbildningars": "självbildning",
    "självbildningen": "självbildning",
    "självbildningens": "självbildning",
    "självbildnings": "självbildning",
    "självbindar": "självbindare",
    "självbindaren": "självbindare",
    "självbindarens": "självbindare",
    "självbindares": "självbindare",
    "självbindarna": "självbindare",
    "självbindarnas": "självbindare",
    "självbiografien": "självbiografi",
    "självbiografiens": "självbiografi",
    "självbiografier": "självbiografi",
    "självbiografierna": "självbiografi",
    "självbiografiernas": "självbiografi",
    "självbiografiers": "självbiografi",
    "självbiografin": "självbiografi",
    "självbiografins": "självbiografi",
    "självbiografis": "självbiografi",
    "självbiografiska": "självbiografisk",
    "självbiografiskare": "självbiografisk",
    "självbiografiskares": "självbiografisk",
    "självbiografiskas": "självbiografisk",
    "självbiografiskast": "självbiografisk",
    "självbiografiskaste": "självbiografisk",
    "självbiografiskastes": "självbiografisk",
    "självbiografiskasts": "självbiografisk",
    "självbiografiske": "självbiografisk",
    "självbiografiskes": "självbiografisk",
    "självbiografisks": "självbiografisk",
    "självbiografiskt": "självbiografisk",
    "självbiografiskts": "självbiografisk",
    "självbon": "självbo",
    "självbons": "självbo",
    "självbor": "självbo",
    "självborna": "självbo",
    "självbornas": "självbo",
    "självbors": "självbo",
    "självbos": "självbo",
    "självcentrerade": "självcentrerad",
    "självcentrerades": "självcentrerad",
    "självcentrerads": "självcentrerad",
    "självcentrerat": "självcentrerad",
    "självcentrerats": "självcentrerad",
    "självdeklarationen": "självdeklaration",
    "självdeklarationens": "självdeklaration",
    "självdeklarationer": "självdeklaration",
    "självdeklarationerna": "självdeklaration",
    "självdeklarationernas": "självdeklaration",
    "självdeklarationers": "självdeklaration",
    "självdeklarations": "självdeklaration",
    "självdisciplinen": "självdisciplin",
    "självdisciplinens": "självdisciplin",
    "självdisciplins": "självdisciplin",
    "självdistanserade": "självdistanserad",
    "självdistanserades": "självdistanserad",
    "självdistanserads": "självdistanserad",
    "självdistanserat": "självdistanserad",
    "självdistanserats": "självdistanserad",
    "självdog": "självdö",
    "självdoge": "självdö",
    "självdoges": "självdö",
    "självdogs": "självdö",
    "självdöende": "självdö",
    "självdöenden": "självdöende",
    "självdöendena": "självdöende",
    "självdöendenas": "självdöende",
    "självdöendens": "självdöende",
    "självdöendes": "självdöende",
    "självdöendet": "självdöende",
    "självdöendets": "självdöende",
    "självdör": "självdö",
    "självdös": "självdö",
    "självdött": "självdö",
    "självdötts": "självdö",
    "själve": "själva",
    "själves": "själva",
    "självfallens": "självfallen",
    "självfallet": "självfallen",
    "självfallets": "självfallen",
    "självfallna": "självfallen",
    "självfallnare": "självfallen",
    "självfallnares": "självfallen",
    "självfallnas": "självfallen",
    "självfallnast": "självfallen",
    "självfallnaste": "självfallen",
    "självfallnastes": "självfallen",
    "självfallnasts": "självfallen",
    "självfallne": "självfallen",
    "självfallnes": "självfallen",
    "självfinansierad": "självfinansiera",
    "självfinansierade": "självfinansiera",
    "självfinansierades": "självfinansiera",
    "självfinansierads": "självfinansiera",
    "självfinansierande": "självfinansiera",
    "självfinansieranden": "självfinansierande",
    "självfinansierandena": "självfinansierande",
    "självfinansierandenas": "självfinansierande",
    "självfinansierandens": "självfinansierande",
    "självfinansierandes": "självfinansierande",
    "självfinansierandet": "självfinansierande",
    "självfinansierandets": "självfinansierande",
    "självfinansierar": "självfinansiera",
    "självfinansieras": "självfinansiera",
    "självfinansierat": "självfinansiera",
    "självfinansierats": "självfinansiera",
    "självfinansierbara": "självfinansierbar",
    "självfinansierbarare": "självfinansierbar",
    "självfinansierbarares": "självfinansierbar",
    "självfinansierbaras": "självfinansierbar",
    "självfinansierbarast": "självfinansierbar",
    "självfinansierbaraste": "självfinansierbar",
    "självfinansierbarastes": "självfinansierbar",
    "självfinansierbarasts": "självfinansierbar",
    "självfinansierbare": "självfinansierbar",
    "självfinansierbares": "självfinansierbar",
    "självfinansierbarheten": "självfinansierbarhet",
    "självfinansierbarhetens": "självfinansierbarhet",
    "självfinansierbarhets": "självfinansierbarhet",
    "självfinansierbars": "självfinansierbar",
    "självfinansierbart": "självfinansierbar",
    "självfinansierbarts": "självfinansierbar",
    "självfinansieringar": "självfinansiering",
    "självfinansieringarna": "självfinansiering",
    "självfinansieringarnas": "självfinansiering",
    "självfinansieringars": "självfinansiering",
    "självfinansieringen": "självfinansiering",
    "självfinansieringens": "självfinansiering",
    "självfinansierings": "självfinansiering",
    "självföraktet": "självförakt",
    "självföraktets": "självförakt",
    "självförakts": "självförakt",
    "självförebråelsen": "självförebråelse",
    "självförebråelsens": "självförebråelse",
    "självförebråelser": "självförebråelse",
    "självförebråelserna": "självförebråelse",
    "självförebråelsernas": "självförebråelse",
    "självförebråelsers": "självförebråelse",
    "självförebråelses": "självförebråelse",
    "självförhärliganden": "självförhärligande",
    "självförhärligandena": "självförhärligande",
    "självförhärligandenas": "självförhärligande",
    "självförhärligandens": "självförhärligande",
    "självförhärligandes": "självförhärligande",
    "självförhärligandet": "självförhärligande",
    "självförhärligandets": "självförhärligande",
    "självförhävelsen": "självförhävelse",
    "självförhävelsens": "självförhävelse",
    "självförhävelser": "självförhävelse",
    "självförhävelserna": "självförhävelse",
    "självförhävelsernas": "självförhävelse",
    "självförhävelsers": "självförhävelse",
    "självförhävelses": "självförhävelse",
    "självförnekar": "självförnekare",
    "självförnekaren": "självförnekare",
    "självförnekarens": "självförnekare",
    "självförnekares": "självförnekare",
    "självförnekarna": "självförnekare",
    "självförnekarnas": "självförnekare",
    "självförnekelsen": "självförnekelse",
    "självförnekelsens": "självförnekelse",
    "självförnekelser": "självförnekelse",
    "självförnekelserna": "självförnekelse",
    "självförnekelsernas": "självförnekelse",
    "självförnekelsers": "självförnekelse",
    "självförnekelses": "självförnekelse",
    "självförsvaret": "självförsvar",
    "självförsvarets": "självförsvar",
    "självförsvars": "självförsvar",
    "självförsörjningen": "självförsörjning",
    "självförsörjningens": "självförsörjning",
    "självförsörjnings": "självförsörjning",
    "självförtroendes": "självförtroende",
    "självförtroendet": "självförtroende",
    "självförtroendets": "självförtroende",
    "självförverkligandes": "självförverkligande",
    "självförverkligandet": "självförverkligande",
    "självförverkligandets": "självförverkligande",
    "självförvållade": "självförvållad",
    "självförvållades": "självförvållad",
    "självförvållads": "självförvållad",
    "självförvållat": "självförvållad",
    "självförvållats": "självförvållad",
    "självföryngringar": "självföryngring",
    "självföryngringarna": "självföryngring",
    "självföryngringarnas": "självföryngring",
    "självföryngringars": "självföryngring",
    "självföryngringen": "självföryngring",
    "självföryngringens": "självföryngring",
    "självföryngrings": "självföryngring",
    "självgoda": "självgod",
    "självgodare": "självgod",
    "självgodares": "självgod",
    "självgodas": "självgod",
    "självgodast": "självgod",
    "självgodaste": "självgod",
    "självgodastes": "självgod",
    "självgodasts": "självgod",
    "självgode": "självgod",
    "självgodes": "självgod",
    "självgodheten": "självgodhet",
    "självgodhetens": "självgodhet",
    "självgodheter": "självgodhet",
    "självgodheterna": "självgodhet",
    "självgodheternas": "självgodhet",
    "självgodheters": "självgodhet",
    "självgodhets": "självgodhet",
    "självgods": "självgod",
    "självgott": "självgod",
    "självgotts": "självgod",
    "självhjälpen": "självhjälp",
    "självhjälpens": "självhjälp",
    "självhjälps": "självhjälp",
    "självhjälpsboken": "självhjälpsbok",
    "självhjälpsbokens": "självhjälpsbok",
    "självhjälpsboks": "självhjälpsbok",
    "självhjälpsböcker": "självhjälpsbok",
    "självhjälpsböckerna": "självhjälpsbok",
    "självhjälpsböckernas": "självhjälpsbok",
    "självhjälpsböckers": "självhjälpsbok",
    "självhjälpsråden": "självhjälpsråd",
    "självhjälpsrådens": "självhjälpsråd",
    "självhjälpsrådet": "självhjälpsråd",
    "självhjälpsrådets": "självhjälpsråd",
    "självhjälpsråds": "självhjälpsråd",
    "självhushållandes": "självhushållande",
    "självhushållandet": "självhushållande",
    "självhushållandets": "självhushållande",
    "självhushållet": "självhushåll",
    "självhushållets": "självhushåll",
    "självhushållningar": "självhushållning",
    "självhushållningarna": "självhushållning",
    "självhushållningarnas": "självhushållning",
    "självhushållningars": "självhushållning",
    "självhushållningen": "självhushållning",
    "självhushållningens": "självhushållning",
    "självhushållnings": "självhushållning",
    "självhushålls": "självhushåll",
    "självhärliga": "självhärlig",
    "självhärligare": "självhärlig",
    "självhärligares": "självhärlig",
    "självhärligas": "självhärlig",
    "självhärligast": "självhärlig",
    "självhärligaste": "självhärlig",
    "självhärligastes": "självhärlig",
    "självhärligasts": "självhärlig",
    "självhärlige": "självhärlig",
    "självhärliges": "självhärlig",
    "självhärligheten": "självhärlighet",
    "självhärlighetens": "självhärlighet",
    "självhärlighets": "självhärlighet",
    "självhärligs": "självhärlig",
    "självhärligt": "självhärlig",
    "självhärligts": "självhärlig",
    "självhärskar": "självhärskare",
    "självhärskaren": "självhärskare",
    "självhärskarens": "självhärskare",
    "självhärskares": "självhärskare",
    "självhärskarna": "självhärskare",
    "självhärskarnas": "självhärskare",
    "självhävdelsen": "självhävdelse",
    "självhävdelsens": "självhävdelse",
    "självhävdelses": "självhävdelse",
    "själviakttagelsen": "själviakttagelse",
    "själviakttagelsens": "själviakttagelse",
    "själviakttagelser": "själviakttagelse",
    "själviakttagelserna": "själviakttagelse",
    "själviakttagelsernas": "själviakttagelse",
    "själviakttagelsers": "själviakttagelse",
    "själviakttagelses": "själviakttagelse",
    "självironien": "självironi",
    "självironiens": "självironi",
    "självironin": "självironi",
    "självironins": "självironi",
    "självironis": "självironi",
    "självironiska": "självironisk",
    "självironiskare": "självironisk",
    "självironiskares": "självironisk",
    "självironiskas": "självironisk",
    "självironiskast": "självironisk",
    "självironiskaste": "självironisk",
    "självironiskastes": "självironisk",
    "självironiskasts": "självironisk",
    "självironiske": "självironisk",
    "självironiskes": "självironisk",
    "självironisks": "självironisk",
    "självironiskt": "självironisk",
    "självironiskts": "självironisk",
    "själviska": "självisk",
    "själviskare": "självisk",
    "själviskares": "självisk",
    "själviskas": "självisk",
    "själviskast": "självisk",
    "själviskaste": "självisk",
    "själviskastes": "självisk",
    "själviskasts": "självisk",
    "själviske": "självisk",
    "själviskes": "självisk",
    "självisks": "självisk",
    "själviskt": "självisk",
    "själviskts": "självisk",
    "självkemar": "självkem",
    "självkemarna": "självkem",
    "självkemarnas": "självkem",
    "självkemars": "självkem",
    "självkemen": "självkem",
    "självkemens": "självkem",
    "självkems": "självkem",
    "självklara": "självklar",
    "självklarare": "självklar",
    "självklarares": "självklar",
    "självklaras": "självklar",
    "självklarast": "självklar",
    "självklaraste": "självklar",
    "självklarastes": "självklar",
    "självklarasts": "självklar",
    "självklare": "självklar",
    "självklares": "självklar",
    "självklarheten": "självklarhet",
    "självklarhetens": "självklarhet",
    "självklarheter": "självklarhet",
    "självklarheterna": "självklarhet",
    "självklarheternas": "självklarhet",
    "självklarheters": "självklarhet",
    "självklarhets": "självklarhet",
    "självklars": "självklar",
    "självklart": "självklar",
    "självklarts": "självklar",
    "självkontrollen": "självkontroll",
    "självkontrollens": "självkontroll",
    "självkontrolls": "självkontroll",
    "självkostnadspriset": "självkostnadspris",
    "självkostnadsprisets": "självkostnadspris",
    "självkritiken": "självkritik",
    "självkritikens": "självkritik",
    "självkritiks": "självkritik",
    "självkritiska": "självkritisk",
    "självkritiskare": "självkritisk",
    "självkritiskares": "självkritisk",
    "självkritiskas": "självkritisk",
    "självkritiskast": "självkritisk",
    "självkritiskaste": "självkritisk",
    "självkritiskastes": "självkritisk",
    "självkritiskasts": "självkritisk",
    "självkritiske": "självkritisk",
    "självkritiskes": "självkritisk",
    "självkritisks": "självkritisk",
    "självkritiskt": "självkritisk",
    "självkritiskts": "självkritisk",
    "självkännedomar": "självkännedom",
    "självkännedomarna": "självkännedom",
    "självkännedomarnas": "självkännedom",
    "självkännedomars": "självkännedom",
    "självkännedomen": "självkännedom",
    "självkännedomens": "självkännedom",
    "självkännedoms": "självkännedom",
    "självkänslan": "självkänsla",
    "självkänslans": "självkänsla",
    "självkänslas": "självkänsla",
    "självkänsle": "självkänsla",
    "självkänslo": "självkänsla",
    "självljuden": "självljud",
    "självljudens": "självljud",
    "självljudet": "självljud",
    "självljudets": "självljud",
    "självljuds": "självljud",
    "självläk": "självläka",
    "självläkande": "självläka",
    "självläkanden": "självläkande",
    "självläkandena": "självläkande",
    "självläkandenas": "självläkande",
    "självläkandens": "självläkande",
    "självläkandes": "självläkande",
    "självläkandet": "självläkande",
    "självläkandets": "självläkande",
    "självläkas": "självläka",
    "självläker": "självläka",
    "självläkes": "självläka",
    "självläkningar": "självläkning",
    "självläkningarna": "självläkning",
    "självläkningarnas": "självläkning",
    "självläkningars": "självläkning",
    "självläkningen": "självläkning",
    "självläkningens": "självläkning",
    "självläknings": "självläkning",
    "självläks": "självläka",
    "självläkt": "självläka",
    "självläkta": "självläka",
    "självläktas": "självläka",
    "självläkte": "självläka",
    "självläktes": "självläka",
    "självläkts": "självläka",
    "självlänsar": "självläns",
    "självlänsarna": "självläns",
    "självlänsarnas": "självläns",
    "självlänsars": "självläns",
    "självlänsen": "självläns",
    "självlänsens": "självläns",
    "självlärda": "självlärd",
    "självlärdare": "självlärd",
    "självlärdares": "självlärd",
    "självlärdas": "självlärd",
    "självlärdast": "självlärd",
    "självlärdaste": "självlärd",
    "självlärdastes": "självlärd",
    "självlärdasts": "självlärd",
    "självlärde": "självlärd",
    "självlärdes": "självlärd",
    "självlärdheten": "självlärdhet",
    "självlärdhetens": "självlärdhet",
    "självlärdhets": "självlärdhet",
    "självlärds": "självlärd",
    "självlärt": "självlärd",
    "självlärts": "självlärd",
    "självmedvetanden": "självmedvetande",
    "självmedvetandena": "självmedvetande",
    "självmedvetandenas": "självmedvetande",
    "självmedvetandens": "självmedvetande",
    "självmedvetandes": "självmedvetande",
    "självmedvetandet": "självmedvetande",
    "självmedvetandets": "självmedvetande",
    "självmedvetens": "självmedveten",
    "självmedvetet": "självmedveten",
    "självmedvetets": "självmedveten",
    "självmedvetna": "självmedveten",
    "självmedvetnare": "självmedveten",
    "självmedvetnares": "självmedveten",
    "självmedvetnas": "självmedveten",
    "självmedvetnast": "självmedveten",
    "självmedvetnaste": "självmedveten",
    "självmedvetnastes": "självmedveten",
    "självmedvetnasts": "självmedveten",
    "självmedvetne": "självmedveten",
    "självmedvetnes": "självmedveten",
    "självmorden": "självmord",
    "självmordens": "självmord",
    "självmordet": "självmord",
    "självmordets": "självmord",
    "självmords": "självmord",
    "självmordsattacken": "självmordsattack",
    "självmordsattackens": "självmordsattack",
    "självmordsattacker": "självmordsattack",
    "självmordsattackerna": "självmordsattack",
    "självmordsattackernas": "självmordsattack",
    "självmordsattackers": "självmordsattack",
    "självmordsattacks": "självmordsattack",
    "självmordsbenägens": "självmordsbenägen",
    "självmordsbenäget": "självmordsbenägen",
    "självmordsbenägets": "självmordsbenägen",
    "självmordsbenägna": "självmordsbenägen",
    "självmordsbenägnare": "självmordsbenägen",
    "självmordsbenägnares": "självmordsbenägen",
    "självmordsbenägnas": "självmordsbenägen",
    "självmordsbenägnast": "självmordsbenägen",
    "självmordsbenägnaste": "självmordsbenägen",
    "självmordsbenägnastes": "självmordsbenägen",
    "självmordsbenägnasts": "självmordsbenägen",
    "självmordsbenägne": "självmordsbenägen",
    "självmordsbenägnes": "självmordsbenägen",
    "självmordsbombar": "självmordsbombare",
    "självmordsbombaren": "självmordsbombare",
    "självmordsbombarens": "självmordsbombare",
    "självmordsbombares": "självmordsbombare",
    "självmordsbombarna": "självmordsbombare",
    "självmordsbombarnas": "självmordsbombare",
    "självmordsbomben": "självmordsbomb",
    "självmordsbombens": "självmordsbomb",
    "självmordsbomber": "självmordsbomb",
    "självmordsbomberna": "självmordsbomb",
    "självmordsbombernas": "självmordsbomb",
    "självmordsbombers": "självmordsbomb",
    "självmordsbombs": "självmordsbomb",
    "självmordsförsöken": "självmordsförsök",
    "självmordsförsökens": "självmordsförsök",
    "självmordsförsöket": "självmordsförsök",
    "självmordsförsökets": "självmordsförsök",
    "självmordsförsöks": "självmordsförsök",
    "självmordskandidaten": "självmordskandidat",
    "självmordskandidatens": "självmordskandidat",
    "självmordskandidater": "självmordskandidat",
    "självmordskandidaterna": "självmordskandidat",
    "självmordskandidaternas": "självmordskandidat",
    "självmordskandidaters": "självmordskandidat",
    "självmordskandidats": "självmordskandidat",
    "självmordsmässiga": "självmordsmässig",
    "självmordsmässigare": "självmordsmässig",
    "självmordsmässigares": "självmordsmässig",
    "självmordsmässigas": "självmordsmässig",
    "självmordsmässigast": "självmordsmässig",
    "självmordsmässigaste": "självmordsmässig",
    "självmordsmässigastes": "självmordsmässig",
    "självmordsmässigasts": "självmordsmässig",
    "självmordsmässige": "självmordsmässig",
    "självmordsmässiges": "självmordsmässig",
    "självmordsmässigs": "självmordsmässig",
    "självmordsmässigt": "självmordsmässig",
    "självmordsmässigts": "självmordsmässig",
    "självmordsrisken": "självmordsrisk",
    "självmordsriskens": "självmordsrisk",
    "självmordsrisker": "självmordsrisk",
    "självmordsriskerna": "självmordsrisk",
    "självmordsriskernas": "självmordsrisk",
    "självmordsriskers": "självmordsrisk",
    "självmordsrisks": "självmordsrisk",
    "självmordsuppdragen": "självmordsuppdrag",
    "självmordsuppdragens": "självmordsuppdrag",
    "självmordsuppdraget": "självmordsuppdrag",
    "självmordsuppdragets": "självmordsuppdrag",
    "självmordsuppdrags": "självmordsuppdrag",
    "självmotsägelsen": "självmotsägelse",
    "självmotsägelsens": "självmotsägelse",
    "självmotsägelser": "självmotsägelse",
    "självmotsägelserna": "självmotsägelse",
    "självmotsägelsernas": "självmotsägelse",
    "självmotsägelsers": "självmotsägelse",
    "självmotsägelses": "självmotsägelse",
    "självmålen": "självmål",
    "självmålens": "självmål",
    "självmålet": "självmål",
    "självmålets": "självmål",
    "självmåls": "självmål",
    "självmördar": "självmördare",
    "självmördaren": "självmördare",
    "självmördarens": "självmördare",
    "självmördares": "självmördare",
    "självmördarna": "självmördare",
    "självmördarnas": "självmördare",
    "självplågar": "självplågare",
    "självplågaren": "självplågare",
    "självplågarens": "självplågare",
    "självplågares": "självplågare",
    "självplågarna": "självplågare",
    "självplågarnas": "självplågare",
    "självporträtten": "självporträtt",
    "självporträttens": "självporträtt",
    "självporträttet": "självporträtt",
    "självporträttets": "självporträtt",
    "självporträtts": "självporträtt",
    "självpåhittade": "självpåhittad",
    "självpåhittades": "självpåhittad",
    "självpåhittads": "självpåhittad",
    "självpåhittat": "självpåhittad",
    "självpåhittats": "självpåhittad",
    "självpåtagens": "självpåtagen",
    "självpåtaget": "självpåtagen",
    "självpåtagets": "självpåtagen",
    "självpåtagna": "självpåtagen",
    "självpåtagnare": "självpåtagen",
    "självpåtagnares": "självpåtagen",
    "självpåtagnas": "självpåtagen",
    "självpåtagnast": "självpåtagen",
    "självpåtagnaste": "självpåtagen",
    "självpåtagnastes": "självpåtagen",
    "självpåtagnasts": "självpåtagen",
    "självpåtagne": "självpåtagen",
    "självpåtagnes": "självpåtagen",
    "självrisken": "självrisk",
    "självriskens": "självrisk",
    "självrisker": "självrisk",
    "självriskerna": "självrisk",
    "självriskernas": "självrisk",
    "självriskers": "självrisk",
    "självrisks": "självrisk",
    "självrättfärdiga": "självrättfärdig",
    "självrättfärdigare": "självrättfärdig",
    "självrättfärdigares": "självrättfärdig",
    "självrättfärdigas": "självrättfärdig",
    "självrättfärdigast": "självrättfärdig",
    "självrättfärdigaste": "självrättfärdig",
    "självrättfärdigastes": "självrättfärdig",
    "självrättfärdigasts": "självrättfärdig",
    "självrättfärdige": "självrättfärdig",
    "självrättfärdiges": "självrättfärdig",
    "självrättfärdigheten": "självrättfärdighet",
    "självrättfärdighetens": "självrättfärdighet",
    "självrättfärdighets": "självrättfärdighet",
    "självrättfärdigs": "självrättfärdig",
    "självrättfärdigt": "självrättfärdig",
    "självrättfärdigts": "självrättfärdig",
    "självrådiga": "självrådig",
    "självrådigare": "självrådig",
    "självrådigares": "självrådig",
    "självrådigas": "självrådig",
    "självrådigast": "självrådig",
    "självrådigaste": "självrådig",
    "självrådigastes": "självrådig",
    "självrådigasts": "självrådig",
    "självrådige": "självrådig",
    "självrådiges": "självrådig",
    "självrådigheten": "självrådighet",
    "självrådighetens": "självrådighet",
    "självrådighets": "självrådighet",
    "självrådigs": "självrådig",
    "självrådigt": "självrådig",
    "självrådigts": "självrådig",
    "självs": "själv",
    "självserveringar": "självservering",
    "självserveringarna": "självservering",
    "självserveringarnas": "självservering",
    "självserveringars": "självservering",
    "självserveringen": "självservering",
    "självserveringens": "självservering",
    "självserverings": "självservering",
    "självskrivens": "självskriven",
    "självskrivet": "självskriven",
    "självskrivets": "självskriven",
    "självskrivna": "självskriven",
    "självskrivnare": "självskriven",
    "självskrivnares": "självskriven",
    "självskrivnas": "självskriven",
    "självskrivnast": "självskriven",
    "självskrivnaste": "självskriven",
    "självskrivnastes": "självskriven",
    "självskrivnasts": "självskriven",
    "självskrivne": "självskriven",
    "självskrivnes": "självskriven",
    "självskrytet": "självskryt",
    "självskrytets": "självskryt",
    "självskryts": "självskryt",
    "självspillingar": "självspilling",
    "självspillingarna": "självspilling",
    "självspillingarnas": "självspilling",
    "självspillingars": "självspilling",
    "självspillingen": "självspilling",
    "självspillingens": "självspilling",
    "självspillings": "självspilling",
    "självsprick": "självspricka",
    "självsprickan": "självspricka",
    "självsprickans": "självspricka",
    "självsprickas": "självspricka",
    "självspricke": "självspricka",
    "självsprickor": "självspricka",
    "självsprickorna": "självspricka",
    "självsprickornas": "självspricka",
    "självsprickors": "självspricka",
    "självspricks": "självspricka",
    "självstarten": "självstart",
    "självstartens": "självstart",
    "självstarts": "självstart",
    "självstudie": "självstudium",
    "självstudier": "självstudium",
    "självstudierna": "självstudium",
    "självstudiernas": "självstudium",
    "självstudiers": "självstudium",
    "självstudiet": "självstudium",
    "självstudiets": "självstudium",
    "självstudiums": "självstudium",
    "självstyren": "självstyre",
    "självstyrena": "självstyre",
    "självstyrenas": "självstyre",
    "självstyrens": "självstyre",
    "självstyres": "självstyre",
    "självstyret": "självstyre",
    "självstyrets": "självstyre",
    "självständiga": "självständig",
    "självständigare": "självständig",
    "självständigares": "självständig",
    "självständigas": "självständig",
    "självständigast": "självständig",
    "självständigaste": "självständig",
    "självständigastes": "självständig",
    "självständigasts": "självständig",
    "självständige": "självständig",
    "självständiges": "självständig",
    "självständigheten": "självständighet",
    "självständighetens": "självständighet",
    "självständigheter": "självständighet",
    "självständigheterna": "självständighet",
    "självständigheternas": "självständighet",
    "självständigheters": "självständighet",
    "självständighets": "självständighet",
    "självständighetsförklaringar": "självständighetsförklaring",
    "självständighetsförklaringarna": "självständighetsförklaring",
    "självständighetsförklaringarnas": "självständighetsförklaring",
    "självständighetsförklaringars": "självständighetsförklaring",
    "självständighetsförklaringen": "självständighetsförklaring",
    "självständighetsförklaringens": "självständighetsförklaring",
    "självständighetsförklarings": "självständighetsförklaring",
    "självständigs": "självständig",
    "självständigt": "självständig",
    "självständigts": "självständig",
    "självsvåldet": "självsvåld",
    "självsvåldets": "självsvåld",
    "självsvåldiga": "självsvåldig",
    "självsvåldigare": "självsvåldig",
    "självsvåldigares": "självsvåldig",
    "självsvåldigas": "självsvåldig",
    "självsvåldigast": "självsvåldig",
    "självsvåldigaste": "självsvåldig",
    "självsvåldigastes": "självsvåldig",
    "självsvåldigasts": "självsvåldig",
    "självsvåldige": "självsvåldig",
    "självsvåldiges": "självsvåldig",
    "självsvåldigheten": "självsvåldighet",
    "självsvåldighetens": "självsvåldighet",
    "självsvåldighets": "självsvåldighet",
    "självsvåldigs": "självsvåldig",
    "självsvåldigt": "självsvåldig",
    "självsvåldigts": "självsvåldig",
    "självsvålds": "självsvåld",
    "självsäkerheten": "självsäkerhet",
    "självsäkerhetens": "självsäkerhet",
    "självsäkerheter": "självsäkerhet",
    "självsäkerheterna": "självsäkerhet",
    "självsäkerheternas": "självsäkerhet",
    "självsäkerheters": "självsäkerhet",
    "självsäkerhets": "självsäkerhet",
    "självsäkers": "självsäker",
    "självsäkert": "självsäker",
    "självsäkerts": "självsäker",
    "självsäkra": "självsäker",
    "självsäkrare": "självsäker",
    "självsäkrares": "självsäker",
    "självsäkras": "självsäker",
    "självsäkrast": "självsäker",
    "självsäkraste": "självsäker",
    "självsäkrastes": "självsäker",
    "självsäkrasts": "självsäker",
    "självsäkre": "självsäker",
    "självsäkres": "självsäker",
    "självsådden": "självsådd",
    "självsåddens": "självsådd",
    "självsådds": "självsådd",
    "självt": "själv",
    "självtillräckliga": "självtillräcklig",
    "självtillräckligare": "självtillräcklig",
    "självtillräckligares": "självtillräcklig",
    "självtillräckligas": "självtillräcklig",
    "självtillräckligast": "självtillräcklig",
    "självtillräckligaste": "självtillräcklig",
    "självtillräckligastes": "självtillräcklig",
    "självtillräckligasts": "självtillräcklig",
    "självtillräcklige": "självtillräcklig",
    "självtillräckliges": "självtillräcklig",
    "självtillräckligheten": "självtillräcklighet",
    "självtillräcklighetens": "självtillräcklighet",
    "självtillräcklighets": "självtillräcklighet",
    "självtillräckligs": "självtillräcklig",
    "självtillräckligt": "självtillräcklig",
    "självtillräckligts": "självtillräcklig",
    "självts": "själv",
    "självtäkten": "självtäkt",
    "självtäktens": "självtäkt",
    "självtäkts": "självtäkt",
    "självtänd": "självtända",
    "självtändande": "självtända",
    "självtändanden": "självtändande",
    "självtändandena": "självtändande",
    "självtändandenas": "självtändande",
    "självtändandens": "självtändande",
    "självtändandes": "självtändande",
    "självtändandet": "självtändande",
    "självtändandets": "självtändande",
    "självtändas": "självtända",
    "självtände": "självtända",
    "självtänder": "självtända",
    "självtändes": "självtända",
    "självtändningar": "självtändning",
    "självtändningarna": "självtändning",
    "självtändningarnas": "självtändning",
    "självtändningars": "självtändning",
    "självtändningen": "självtändning",
    "självtändningens": "självtändning",
    "självtändnings": "självtändning",
    "självtänds": "självtända",
    "självtänt": "självtända",
    "självtänts": "självtända",
    "självuppfattningar": "självuppfattning",
    "självuppfattningarna": "självuppfattning",
    "självuppfattningarnas": "självuppfattning",
    "självuppfattningars": "självuppfattning",
    "självuppfattningen": "självuppfattning",
    "självuppfattningens": "självuppfattning",
    "självuppfattnings": "självuppfattning",
    "självupplevda": "självupplevd",
    "självupplevdare": "självupplevd",
    "självupplevdares": "självupplevd",
    "självupplevdas": "självupplevd",
    "självupplevdast": "självupplevd",
    "självupplevdaste": "självupplevd",
    "självupplevdastes": "självupplevd",
    "självupplevdasts": "självupplevd",
    "självupplevde": "självupplevd",
    "självupplevdes": "självupplevd",
    "självupplevdheten": "självupplevdhet",
    "självupplevdhetens": "självupplevdhet",
    "självupplevdhets": "självupplevdhet",
    "självupplevds": "självupplevd",
    "självupplevt": "självupplevd",
    "självupplevts": "självupplevd",
    "självuppoffringar": "självuppoffring",
    "självuppoffringarna": "självuppoffring",
    "självuppoffringarnas": "självuppoffring",
    "självuppoffringars": "självuppoffring",
    "självuppoffringen": "självuppoffring",
    "självuppoffringens": "självuppoffring",
    "självuppoffrings": "självuppoffring",
    "självupptagens": "självupptagen",
    "självupptaget": "självupptagen",
    "självupptagets": "självupptagen",
    "självupptagna": "självupptagen",
    "självupptagnare": "självupptagen",
    "självupptagnares": "självupptagen",
    "självupptagnas": "självupptagen",
    "självupptagnast": "självupptagen",
    "självupptagnaste": "självupptagen",
    "självupptagnastes": "självupptagen",
    "självupptagnasts": "självupptagen",
    "självupptagne": "självupptagen",
    "självupptagnes": "självupptagen",
    "självurladdningar": "självurladdning",
    "självurladdningarna": "självurladdning",
    "självurladdningarnas": "självurladdning",
    "självurladdningars": "självurladdning",
    "självurladdningen": "självurladdning",
    "självurladdningens": "självurladdning",
    "självurladdnings": "självurladdning",
    "självutlösar": "självutlösare",
    "självutlösaren": "självutlösare",
    "självutlösarens": "självutlösare",
    "självutlösares": "självutlösare",
    "självutlösarna": "självutlösare",
    "självutlösarnas": "självutlösare",
    "självutnämnda": "självutnämnd",
    "självutnämndare": "självutnämnd",
    "självutnämndares": "självutnämnd",
    "självutnämndas": "självutnämnd",
    "självutnämndast": "självutnämnd",
    "självutnämndaste": "självutnämnd",
    "självutnämndastes": "självutnämnd",
    "självutnämndasts": "självutnämnd",
    "självutnämnde": "självutnämnd",
    "självutnämndes": "självutnämnd",
    "självutnämnds": "självutnämnd",
    "självutnämnt": "självutnämnd",
    "självutnämnts": "självutnämnd",
    "självutplåningar": "självutplåning",
    "självutplåningarna": "självutplåning",
    "självutplåningarnas": "självutplåning",
    "självutplåningars": "självutplåning",
    "självutplåningen": "självutplåning",
    "självutplåningens": "självutplåning",
    "självutplånings": "självutplåning",
    "självvalda": "självvald",
    "självvaldare": "självvald",
    "självvaldares": "självvald",
    "självvaldas": "självvald",
    "självvaldast": "självvald",
    "självvaldaste": "självvald",
    "självvaldastes": "självvald",
    "självvaldasts": "självvald",
    "självvalde": "självvald",
    "självvaldes": "självvald",
    "självvalds": "självvald",
    "självvalt": "självvald",
    "självvalts": "självvald",
    "självändamålet": "självändamål",
    "självändamålets": "självändamål",
    "självändamåls": "självändamål",
    "självövervinnelsen": "självövervinnelse",
    "självövervinnelsens": "självövervinnelse",
    "självövervinnelses": "självövervinnelse",
    "sjätte": "sex",
    "sjättedelar": "sjättedel",
    "sjättedelarna": "sjättedel",
    "sjättedelarnas": "sjättedel",
    "sjättedelars": "sjättedel",
    "sjättedelen": "sjättedel",
    "sjättedelens": "sjättedel",
    "sjättedels": "sjättedel",
    "sjättes": "sex",
    "sjåade": "sjåa",
    "sjåades": "sjåa",
    "sjåande": "sjåa",
    "sjåanden": "sjåande",
    "sjåandena": "sjåande",
    "sjåandenas": "sjåande",
    "sjåandens": "sjåande",
    "sjåandes": "sjåande",
    "sjåandet": "sjåande",
    "sjåandets": "sjåande",
    "sjåar": "sjåare",
    "sjåaren": "sjåare",
    "sjåarens": "sjåare",
    "sjåares": "sjåare",
    "sjåarna": "sjåare",
    "sjåarnas": "sjåare",
    "sjåas": "sjåa",
    "sjåat": "sjåa",
    "sjåats": "sjåa",
    "sjået": "sjå",
    "sjåets": "sjå",
    "sjåpen": "sjåp",
    "sjåpens": "sjåp",
    "sjåperier": "sjåperi",
    "sjåperierna": "sjåperi",
    "sjåperiernas": "sjåperi",
    "sjåperiers": "sjåperi",
    "sjåperiet": "sjåperi",
    "sjåperiets": "sjåperi",
    "sjåperis": "sjåperi",
    "sjåperit": "sjåperi",
    "sjåperits": "sjåperi",
    "sjåpet": "sjåp",
    "sjåpets": "sjåp",
    "sjåpiga": "sjåpig",
    "sjåpigare": "sjåpig",
    "sjåpigares": "sjåpig",
    "sjåpigas": "sjåpig",
    "sjåpigast": "sjåpig",
    "sjåpigaste": "sjåpig",
    "sjåpigastes": "sjåpig",
    "sjåpigasts": "sjåpig",
    "sjåpige": "sjåpig",
    "sjåpiges": "sjåpig",
    "sjåpigs": "sjåpig",
    "sjåpigt": "sjåpig",
    "sjåpigts": "sjåpig",
    "sjåps": "sjåp",
    "sjås": "sjå",
    "sjåt": "sjå",
    "sjåts": "sjå",
    "sjöar": "sjö",
    "sjöarna": "sjö",
    "sjöarnas": "sjö",
    "sjöars": "sjö",
    "sjöartilleriet": "sjöartilleri",
    "sjöartilleriets": "sjöartilleri",
    "sjöartilleris": "sjöartilleri",
    "sjöartillerit": "sjöartilleri",
    "sjöartillerits": "sjöartilleri",
    "sjöavlagringar": "sjöavlagring",
    "sjöavlagringarna": "sjöavlagring",
    "sjöavlagringarnas": "sjöavlagring",
    "sjöavlagringars": "sjöavlagring",
    "sjöavlagringen": "sjöavlagring",
    "sjöavlagringens": "sjöavlagring",
    "sjöavlagrings": "sjöavlagring",
    "sjöbefälet": "sjöbefäl",
    "sjöbefälets": "sjöbefäl",
    "sjöbefäls": "sjöbefäl",
    "sjöbjörnar": "sjöbjörn",
    "sjöbjörnarna": "sjöbjörn",
    "sjöbjörnarnas": "sjöbjörn",
    "sjöbjörnars": "sjöbjörn",
    "sjöbjörnen": "sjöbjörn",
    "sjöbjörnens": "sjöbjörn",
    "sjöbjörns": "sjöbjörn",
    "sjöblöta": "sjöblöt",
    "sjöblötare": "sjöblöt",
    "sjöblötares": "sjöblöt",
    "sjöblötas": "sjöblöt",
    "sjöblötast": "sjöblöt",
    "sjöblötaste": "sjöblöt",
    "sjöblötastes": "sjöblöt",
    "sjöblötasts": "sjöblöt",
    "sjöblöte": "sjöblöt",
    "sjöblötes": "sjöblöt",
    "sjöblöts": "sjöblöt",
    "sjöblött": "sjöblöt",
    "sjöblötts": "sjöblöt",
    "sjöbodar": "sjöbod",
    "sjöbodarna": "sjöbod",
    "sjöbodarnas": "sjöbod",
    "sjöbodars": "sjöbod",
    "sjöboden": "sjöbod",
    "sjöbodens": "sjöbod",
    "sjöbods": "sjöbod",
    "sjöborr": "sjöborre",
    "sjöborrar": "sjöborre",
    "sjöborrarna": "sjöborre",
    "sjöborrarnas": "sjöborre",
    "sjöborrars": "sjöborre",
    "sjöborren": "sjöborre",
    "sjöborrens": "sjöborre",
    "sjöborres": "sjöborre",
    "sjöborrs": "sjöborre",
    "sjöbottens": "sjöbotten",
    "sjöbottnar": "sjöbotten",
    "sjöbottnarna": "sjöbotten",
    "sjöbottnarnas": "sjöbotten",
    "sjöbottnars": "sjöbotten",
    "sjöbottnen": "sjöbotten",
    "sjöbottnens": "sjöbotten",
    "sjöbrisen": "sjöbris",
    "sjöbrisens": "sjöbris",
    "sjöbussar": "sjöbuss",
    "sjöbussarna": "sjöbuss",
    "sjöbussarnas": "sjöbuss",
    "sjöbussars": "sjöbuss",
    "sjöbussen": "sjöbuss",
    "sjöbussens": "sjöbuss",
    "sjöd": "sjuda",
    "sjöde": "sjuda",
    "sjödes": "sjuda",
    "sjödränkta": "sjödränkt",
    "sjödränktare": "sjödränkt",
    "sjödränktares": "sjödränkt",
    "sjödränktas": "sjödränkt",
    "sjödränktast": "sjödränkt",
    "sjödränktaste": "sjödränkt",
    "sjödränktastes": "sjödränkt",
    "sjödränktasts": "sjödränkt",
    "sjödränkte": "sjödränkt",
    "sjödränktes": "sjödränkt",
    "sjödränkts": "sjödränkt",
    "sjöds": "sjuda",
    "sjödugliga": "sjöduglig",
    "sjödugligare": "sjöduglig",
    "sjödugligares": "sjöduglig",
    "sjödugligas": "sjöduglig",
    "sjödugligast": "sjöduglig",
    "sjödugligaste": "sjöduglig",
    "sjödugligastes": "sjöduglig",
    "sjödugligasts": "sjöduglig",
    "sjöduglige": "sjöduglig",
    "sjödugliges": "sjöduglig",
    "sjödugligheten": "sjöduglighet",
    "sjöduglighetens": "sjöduglighet",
    "sjöduglighets": "sjöduglighet",
    "sjödugligs": "sjöduglig",
    "sjödugligt": "sjöduglig",
    "sjödugligts": "sjöduglig",
    "sjöelefanten": "sjöelefant",
    "sjöelefantens": "sjöelefant",
    "sjöelefanter": "sjöelefant",
    "sjöelefanterna": "sjöelefant",
    "sjöelefanternas": "sjöelefant",
    "sjöelefanters": "sjöelefant",
    "sjöelefants": "sjöelefant",
    "sjöfarar": "sjöfarare",
    "sjöfararen": "sjöfarare",
    "sjöfararens": "sjöfarare",
    "sjöfarares": "sjöfarare",
    "sjöfararna": "sjöfarare",
    "sjöfararnas": "sjöfarare",
    "sjöfarten": "sjöfart",
    "sjöfartens": "sjöfart",
    "sjöfarts": "sjöfart",
    "sjöfartspolitiken": "sjöfartspolitik",
    "sjöfartspolitikens": "sjöfartspolitik",
    "sjöfartspolitiks": "sjöfartspolitik",
    "sjöfartspolitiska": "sjöfartspolitisk",
    "sjöfartspolitiskas": "sjöfartspolitisk",
    "sjöfartspolitiske": "sjöfartspolitisk",
    "sjöfartspolitiskes": "sjöfartspolitisk",
    "sjöfartspolitisks": "sjöfartspolitisk",
    "sjöfartspolitiskt": "sjöfartspolitisk",
    "sjöfartspolitiskts": "sjöfartspolitisk",
    "sjöfartsregeln": "sjöfartsregel",
    "sjöfartsregelns": "sjöfartsregel",
    "sjöfartsregels": "sjöfartsregel",
    "sjöfartsregler": "sjöfartsregel",
    "sjöfartsreglerna": "sjöfartsregel",
    "sjöfartsreglernas": "sjöfartsregel",
    "sjöfartsreglers": "sjöfartsregel",
    "sjöflygplanen": "sjöflygplan",
    "sjöflygplanens": "sjöflygplan",
    "sjöflygplanet": "sjöflygplan",
    "sjöflygplanets": "sjöflygplan",
    "sjöflygplans": "sjöflygplan",
    "sjöfolket": "sjöfolk",
    "sjöfolkets": "sjöfolk",
    "sjöfolks": "sjöfolk",
    "sjöfrakten": "sjöfrakt",
    "sjöfraktens": "sjöfrakt",
    "sjöfrakter": "sjöfrakt",
    "sjöfrakterna": "sjöfrakt",
    "sjöfrakternas": "sjöfrakt",
    "sjöfrakters": "sjöfrakt",
    "sjöfrakts": "sjöfrakt",
    "sjöfylleristen": "sjöfyllerist",
    "sjöfylleristens": "sjöfyllerist",
    "sjöfyllerister": "sjöfyllerist",
    "sjöfylleristerna": "sjöfyllerist",
    "sjöfylleristernas": "sjöfyllerist",
    "sjöfylleristers": "sjöfyllerist",
    "sjöfyllerists": "sjöfyllerist",
    "sjöfynden": "sjöfynd",
    "sjöfyndens": "sjöfynd",
    "sjöfyndet": "sjöfynd",
    "sjöfyndets": "sjöfynd",
    "sjöfynds": "sjöfynd",
    "sjöfärden": "sjöfärd",
    "sjöfärdens": "sjöfärd",
    "sjöfärder": "sjöfärd",
    "sjöfärderna": "sjöfärd",
    "sjöfärdernas": "sjöfärd",
    "sjöfärders": "sjöfärd",
    "sjöfärds": "sjöfärd",
    "sjöfågeln": "sjöfågel",
    "sjöfågelns": "sjöfågel",
    "sjöfågels": "sjöfågel",
    "sjöfågelsjakten": "sjöfågelsjakt",
    "sjöfågelsjaktens": "sjöfågelsjakt",
    "sjöfågelsjakter": "sjöfågelsjakt",
    "sjöfågelsjakterna": "sjöfågelsjakt",
    "sjöfågelsjakternas": "sjöfågelsjakt",
    "sjöfågelsjakters": "sjöfågelsjakt",
    "sjöfågelsjakts": "sjöfågelsjakt",
    "sjöfåglar": "sjöfågel",
    "sjöfåglarna": "sjöfågel",
    "sjöfåglarnas": "sjöfågel",
    "sjöfåglars": "sjöfågel",
    "sjöförhören": "sjöförhör",
    "sjöförhörens": "sjöförhör",
    "sjöförhöret": "sjöförhör",
    "sjöförhörets": "sjöförhör",
    "sjöförhörs": "sjöförhör",
    "sjöförklaringar": "sjöförklaring",
    "sjöförklaringarna": "sjöförklaring",
    "sjöförklaringarnas": "sjöförklaring",
    "sjöförklaringars": "sjöförklaring",
    "sjöförklaringen": "sjöförklaring",
    "sjöförklaringens": "sjöförklaring",
    "sjöförklarings": "sjöförklaring",
    "sjögräset": "sjögräs",
    "sjögräsets": "sjögräs",
    "sjögurk": "sjögurka",
    "sjögurkan": "sjögurka",
    "sjögurkans": "sjögurka",
    "sjögurkas": "sjögurka",
    "sjögurke": "sjögurka",
    "sjögurkor": "sjögurka",
    "sjögurkorna": "sjögurka",
    "sjögurkornas": "sjögurka",
    "sjögurkors": "sjögurka",
    "sjögurks": "sjögurka",
    "sjögången": "sjögång",
    "sjögångens": "sjögång",
    "sjögångs": "sjögång",
    "sjöhästar": "sjöhäst",
    "sjöhästarna": "sjöhäst",
    "sjöhästarnas": "sjöhäst",
    "sjöhästars": "sjöhäst",
    "sjöhästen": "sjöhäst",
    "sjöhästens": "sjöhäst",
    "sjöhästs": "sjöhäst",
    "sjöhävningar": "sjöhävning",
    "sjöhävningarna": "sjöhävning",
    "sjöhävningarnas": "sjöhävning",
    "sjöhävningars": "sjöhävning",
    "sjöhävningen": "sjöhävning",
    "sjöhävningens": "sjöhävning",
    "sjöhävnings": "sjöhävning",
    "sjöjungfrun": "sjöjungfru",
    "sjöjungfruns": "sjöjungfru",
    "sjöjungfrur": "sjöjungfru",
    "sjöjungfrurna": "sjöjungfru",
    "sjöjungfrurnas": "sjöjungfru",
    "sjöjungfrurs": "sjöjungfru",
    "sjöjungfrus": "sjöjungfru",
    "sjökaptenen": "sjökapten",
    "sjökaptenens": "sjökapten",
    "sjökaptener": "sjökapten",
    "sjökaptenerna": "sjökapten",
    "sjökaptenernas": "sjökapten",
    "sjökapteners": "sjökapten",
    "sjökaptens": "sjökapten",
    "sjökaptensbreven": "sjökaptensbrev",
    "sjökaptensbrevens": "sjökaptensbrev",
    "sjökaptensbrevet": "sjökaptensbrev",
    "sjökaptensbrevets": "sjökaptensbrev",
    "sjökaptensbrevs": "sjökaptensbrev",
    "sjökon": "sjöko",
    "sjökons": "sjöko",
    "sjökor": "sjöko",
    "sjökorna": "sjöko",
    "sjökornas": "sjöko",
    "sjökors": "sjöko",
    "sjökorten": "sjökort",
    "sjökortens": "sjökort",
    "sjökortet": "sjökort",
    "sjökortets": "sjökort",
    "sjökorts": "sjökort",
    "sjökos": "sjöko",
    "sjölejonen": "sjölejon",
    "sjölejonens": "sjölejon",
    "sjölejonet": "sjölejon",
    "sjölejonets": "sjölejon",
    "sjölejons": "sjölejon",
    "sjöluften": "sjöluft",
    "sjöluftens": "sjöluft",
    "sjölufts": "sjöluft",
    "sjölägenheten": "sjölägenhet",
    "sjölägenhetens": "sjölägenhet",
    "sjölägenheter": "sjölägenhet",
    "sjölägenheterna": "sjölägenhet",
    "sjölägenheternas": "sjölägenhet",
    "sjölägenheters": "sjölägenhet",
    "sjölägenhets": "sjölägenhet",
    "sjömalmen": "sjömalm",
    "sjömalmens": "sjömalm",
    "sjömalms": "sjömalm",
    "sjömaningar": "sjömaning",
    "sjömaningarna": "sjömaning",
    "sjömaningarnas": "sjömaning",
    "sjömaningars": "sjömaning",
    "sjömaningen": "sjömaning",
    "sjömaningens": "sjömaning",
    "sjömanings": "sjömaning",
    "sjömannen": "sjöman",
    "sjömannens": "sjöman",
    "sjömans": "sjöman",
    "sjömansbiffen": "sjömansbiff",
    "sjömansbiffens": "sjömansbiff",
    "sjömansbiffs": "sjömansbiff",
    "sjömansblusar": "sjömansblus",
    "sjömansblusarna": "sjömansblus",
    "sjömansblusarnas": "sjömansblus",
    "sjömansblusars": "sjömansblus",
    "sjömansblusen": "sjömansblus",
    "sjömansblusens": "sjömansblus",
    "sjömansbyx": "sjömansbyxa",
    "sjömansbyxan": "sjömansbyxa",
    "sjömansbyxans": "sjömansbyxa",
    "sjömansbyxas": "sjömansbyxa",
    "sjömansbyxe": "sjömansbyxa",
    "sjömansbyxor": "sjömansbyxa",
    "sjömansbyxorna": "sjömansbyxa",
    "sjömansbyxornas": "sjömansbyxa",
    "sjömansbyxors": "sjömansbyxa",
    "sjömansförmedlingar": "sjömansförmedling",
    "sjömansförmedlingarna": "sjömansförmedling",
    "sjömansförmedlingarnas": "sjömansförmedling",
    "sjömansförmedlingars": "sjömansförmedling",
    "sjömansförmedlingen": "sjömansförmedling",
    "sjömansförmedlingens": "sjömansförmedling",
    "sjömansförmedlings": "sjömansförmedling",
    "sjömanshusen": "sjömanshus",
    "sjömanshusens": "sjömanshus",
    "sjömanshuset": "sjömanshus",
    "sjömanshusets": "sjömanshus",
    "sjömanskapet": "sjömanskap",
    "sjömanskapets": "sjömanskap",
    "sjömanskaps": "sjömanskap",
    "sjömanskist": "sjömanskista",
    "sjömanskistan": "sjömanskista",
    "sjömanskistans": "sjömanskista",
    "sjömanskistas": "sjömanskista",
    "sjömanskiste": "sjömanskista",
    "sjömanskistor": "sjömanskista",
    "sjömanskistorna": "sjömanskista",
    "sjömanskistornas": "sjömanskista",
    "sjömanskistors": "sjömanskista",
    "sjömansklänningar": "sjömansklänning",
    "sjömansklänningarna": "sjömansklänning",
    "sjömansklänningarnas": "sjömansklänning",
    "sjömansklänningars": "sjömansklänning",
    "sjömansklänningen": "sjömansklänning",
    "sjömansklänningens": "sjömansklänning",
    "sjömansklännings": "sjömansklänning",
    "sjömansknopar": "sjömansknop",
    "sjömansknoparna": "sjömansknop",
    "sjömansknoparnas": "sjömansknop",
    "sjömansknopars": "sjömansknop",
    "sjömansknopen": "sjömansknop",
    "sjömansknopens": "sjömansknop",
    "sjömansknops": "sjömansknop",
    "sjömanskrag": "sjömanskrage",
    "sjömanskragar": "sjömanskrage",
    "sjömanskragarna": "sjömanskrage",
    "sjömanskragarnas": "sjömanskrage",
    "sjömanskragars": "sjömanskrage",
    "sjömanskragen": "sjömanskrage",
    "sjömanskragens": "sjömanskrage",
    "sjömanskrages": "sjömanskrage",
    "sjömanskrags": "sjömanskrage",
    "sjömansmässiga": "sjömansmässig",
    "sjömansmässigare": "sjömansmässig",
    "sjömansmässigares": "sjömansmässig",
    "sjömansmässigas": "sjömansmässig",
    "sjömansmässigast": "sjömansmässig",
    "sjömansmässigaste": "sjömansmässig",
    "sjömansmässigastes": "sjömansmässig",
    "sjömansmässigasts": "sjömansmässig",
    "sjömansmässige": "sjömansmässig",
    "sjömansmässiges": "sjömansmässig",
    "sjömansmässigs": "sjömansmässig",
    "sjömansmässigt": "sjömansmässig",
    "sjömansmässigts": "sjömansmässig",
    "sjömanssäckar": "sjömanssäck",
    "sjömanssäckarna": "sjömanssäck",
    "sjömanssäckarnas": "sjömanssäck",
    "sjömanssäckars": "sjömanssäck",
    "sjömanssäcken": "sjömanssäck",
    "sjömanssäckens": "sjömanssäck",
    "sjömanssäcks": "sjömanssäck",
    "sjömansutbildningar": "sjömansutbildning",
    "sjömansutbildningarna": "sjömansutbildning",
    "sjömansutbildningarnas": "sjömansutbildning",
    "sjömansutbildningars": "sjömansutbildning",
    "sjömansutbildningen": "sjömansutbildning",
    "sjömansutbildningens": "sjömansutbildning",
    "sjömansutbildnings": "sjömansutbildning",
    "sjömansvis": "sjömansvisa",
    "sjömansvisan": "sjömansvisa",
    "sjömansvisans": "sjömansvisa",
    "sjömansvisas": "sjömansvisa",
    "sjömansvise": "sjömansvisa",
    "sjömansvisor": "sjömansvisa",
    "sjömansvisorna": "sjömansvisa",
    "sjömansvisornas": "sjömansvisa",
    "sjömansvisors": "sjömansvisa",
    "sjömilen": "sjömil",
    "sjömilens": "sjömil",
    "sjömils": "sjömil",
    "sjömin": "sjömina",
    "sjöminan": "sjömina",
    "sjöminans": "sjömina",
    "sjöminas": "sjömina",
    "sjömine": "sjömina",
    "sjöminor": "sjömina",
    "sjöminorna": "sjömina",
    "sjöminornas": "sjömina",
    "sjöminors": "sjömina",
    "sjömins": "sjömina",
    "sjömän": "sjöman",
    "sjömännen": "sjöman",
    "sjömännens": "sjöman",
    "sjömäns": "sjöman",
    "sjömärken": "sjömärke",
    "sjömärkena": "sjömärke",
    "sjömärkenas": "sjömärke",
    "sjömärkens": "sjömärke",
    "sjömärkes": "sjömärke",
    "sjömärket": "sjömärke",
    "sjömärkets": "sjömärke",
    "sjömätningar": "sjömätning",
    "sjömätningarna": "sjömätning",
    "sjömätningarnas": "sjömätning",
    "sjömätningars": "sjömätning",
    "sjömätningen": "sjömätning",
    "sjömätningens": "sjömätning",
    "sjömätnings": "sjömätning",
    "sjön": "sjö",
    "sjöng": "sjunga",
    "sjönge": "sjunga",
    "sjönges": "sjunga",
    "sjöngs": "sjunga",
    "sjönk": "sjunka",
    "sjönke": "sjunka",
    "sjönkes": "sjunka",
    "sjönks": "sjunka",
    "sjöns": "sjö",
    "sjönöden": "sjönöd",
    "sjönödens": "sjönöd",
    "sjönöds": "sjönöd",
    "sjönöten": "sjönöt",
    "sjönötens": "sjönöt",
    "sjönöts": "sjönöt",
    "sjöodjuren": "sjöodjur",
    "sjöodjurens": "sjöodjur",
    "sjöodjuret": "sjöodjur",
    "sjöodjurets": "sjöodjur",
    "sjöodjurs": "sjöodjur",
    "sjöofficerare": "sjöofficer",
    "sjöofficerares": "sjöofficer",
    "sjöofficerarna": "sjöofficer",
    "sjöofficerarnas": "sjöofficer",
    "sjöofficeren": "sjöofficer",
    "sjöofficerens": "sjöofficer",
    "sjöofficern": "sjöofficer",
    "sjöofficerns": "sjöofficer",
    "sjöofficers": "sjöofficer",
    "sjöolyck": "sjöolycka",
    "sjöolyckan": "sjöolycka",
    "sjöolyckans": "sjöolycka",
    "sjöolyckas": "sjöolycka",
    "sjöolycke": "sjöolycka",
    "sjöolyckor": "sjöolycka",
    "sjöolyckorna": "sjöolycka",
    "sjöolyckornas": "sjöolycka",
    "sjöolyckors": "sjöolycka",
    "sjöolycks": "sjöolycka",
    "sjöormar": "sjöorm",
    "sjöormarna": "sjöorm",
    "sjöormarnas": "sjöorm",
    "sjöormars": "sjöorm",
    "sjöormen": "sjöorm",
    "sjöormens": "sjöorm",
    "sjöorms": "sjöorm",
    "sjöorr": "sjöorre",
    "sjöorrar": "sjöorre",
    "sjöorrarna": "sjöorre",
    "sjöorrarnas": "sjöorre",
    "sjöorrars": "sjöorre",
    "sjöorren": "sjöorre",
    "sjöorrens": "sjöorre",
    "sjöorres": "sjöorre",
    "sjöorrs": "sjöorre",
    "sjöpenn": "sjöpenna",
    "sjöpennan": "sjöpenna",
    "sjöpennans": "sjöpenna",
    "sjöpennas": "sjöpenna",
    "sjöpenne": "sjöpenna",
    "sjöpennor": "sjöpenna",
    "sjöpennorna": "sjöpenna",
    "sjöpennornas": "sjöpenna",
    "sjöpennors": "sjöpenna",
    "sjöpenns": "sjöpenna",
    "sjöpungar": "sjöpung",
    "sjöpungarna": "sjöpung",
    "sjöpungarnas": "sjöpung",
    "sjöpungars": "sjöpung",
    "sjöpungen": "sjöpung",
    "sjöpungens": "sjöpung",
    "sjöpungs": "sjöpung",
    "sjörapporten": "sjörapport",
    "sjörapportens": "sjörapport",
    "sjörapporter": "sjörapport",
    "sjörapporterna": "sjörapport",
    "sjörapporternas": "sjörapport",
    "sjörapporters": "sjörapport",
    "sjörapports": "sjörapport",
    "sjöregleringar": "sjöreglering",
    "sjöregleringarna": "sjöreglering",
    "sjöregleringarnas": "sjöreglering",
    "sjöregleringars": "sjöreglering",
    "sjöregleringen": "sjöreglering",
    "sjöregleringens": "sjöreglering",
    "sjöreglerings": "sjöreglering",
    "sjöräddningar": "sjöräddning",
    "sjöräddningarna": "sjöräddning",
    "sjöräddningarnas": "sjöräddning",
    "sjöräddningars": "sjöräddning",
    "sjöräddningen": "sjöräddning",
    "sjöräddningens": "sjöräddning",
    "sjöräddnings": "sjöräddning",
    "sjörået": "sjörå",
    "sjöråets": "sjörå",
    "sjörån": "sjörå",
    "sjöråna": "sjörå",
    "sjörånas": "sjörå",
    "sjöråns": "sjörå",
    "sjörår": "sjörå",
    "sjörårna": "sjörå",
    "sjörårnas": "sjörå",
    "sjörårs": "sjörå",
    "sjörås": "sjörå",
    "sjöråt": "sjörå",
    "sjöråts": "sjörå",
    "sjöröken": "sjörök",
    "sjörökens": "sjörök",
    "sjöröks": "sjörök",
    "sjörövar": "sjörövare",
    "sjörövaren": "sjörövare",
    "sjörövarens": "sjörövare",
    "sjörövares": "sjörövare",
    "sjörövarna": "sjörövare",
    "sjörövarnas": "sjörövare",
    "sjöröverier": "sjöröveri",
    "sjöröverierna": "sjöröveri",
    "sjöröveriernas": "sjöröveri",
    "sjöröveriers": "sjöröveri",
    "sjöröveriet": "sjöröveri",
    "sjöröveriets": "sjöröveri",
    "sjöröveris": "sjöröveri",
    "sjöröverit": "sjöröveri",
    "sjöröverits": "sjöröveri",
    "sjös": "sjö",
    "sjösatt": "sjösätta",
    "sjösatta": "sjösätta",
    "sjösattas": "sjösätta",
    "sjösatte": "sjösätta",
    "sjösattes": "sjösätta",
    "sjösatts": "sjösätta",
    "sjösedimenten": "sjösediment",
    "sjösedimentens": "sjösediment",
    "sjösedimentet": "sjösediment",
    "sjösedimentets": "sjösediment",
    "sjösediments": "sjösediment",
    "sjösjuka": "sjösjuk",
    "sjösjukan": "sjösjuka",
    "sjösjukans": "sjösjuka",
    "sjösjukare": "sjösjuk",
    "sjösjukares": "sjösjuk",
    "sjösjukas": "sjösjuka",
    "sjösjukast": "sjösjuk",
    "sjösjukaste": "sjösjuk",
    "sjösjukastes": "sjösjuk",
    "sjösjukasts": "sjösjuk",
    "sjösjuke": "sjösjuka",
    "sjösjukes": "sjösjuk",
    "sjösjukheten": "sjösjukhet",
    "sjösjukhetens": "sjösjukhet",
    "sjösjukhets": "sjösjukhet",
    "sjösjuks": "sjösjuka",
    "sjösjukt": "sjösjuk",
    "sjösjukts": "sjösjuk",
    "sjöskummet": "sjöskum",
    "sjöskummets": "sjöskum",
    "sjöskums": "sjöskum",
    "sjöslagen": "sjöslag",
    "sjöslagens": "sjöslag",
    "sjöslaget": "sjöslag",
    "sjöslagets": "sjöslag",
    "sjöslags": "sjöslag",
    "sjöstjärnan": "sjöstjärna",
    "sjöstjärnans": "sjöstjärna",
    "sjöstjärnas": "sjöstjärna",
    "sjöstjärne": "sjöstjärna",
    "sjöstjärnor": "sjöstjärna",
    "sjöstjärnorna": "sjöstjärna",
    "sjöstjärnornas": "sjöstjärna",
    "sjöstjärnors": "sjöstjärna",
    "sjöstriden": "sjöstrid",
    "sjöstridens": "sjöstrid",
    "sjöstrider": "sjöstrid",
    "sjöstriderna": "sjöstrid",
    "sjöstridernas": "sjöstrid",
    "sjöstriders": "sjöstrid",
    "sjöstrids": "sjöstrid",
    "sjöstöveln": "sjöstövel",
    "sjöstövelns": "sjöstövel",
    "sjöstövels": "sjöstövel",
    "sjöstövlar": "sjöstövel",
    "sjöstövlarna": "sjöstövel",
    "sjöstövlarnas": "sjöstövel",
    "sjöstövlars": "sjöstövel",
    "sjösäkerheten": "sjösäkerhet",
    "sjösäkerhetens": "sjösäkerhet",
    "sjösäkerhets": "sjösäkerhet",
    "sjösäkerhetsmässiga": "sjösäkerhetsmässig",
    "sjösäkerhetsmässigare": "sjösäkerhetsmässig",
    "sjösäkerhetsmässigares": "sjösäkerhetsmässig",
    "sjösäkerhetsmässigas": "sjösäkerhetsmässig",
    "sjösäkerhetsmässigast": "sjösäkerhetsmässig",
    "sjösäkerhetsmässigaste": "sjösäkerhetsmässig",
    "sjösäkerhetsmässigastes": "sjösäkerhetsmässig",
    "sjösäkerhetsmässigasts": "sjösäkerhetsmässig",
    "sjösäkerhetsmässige": "sjösäkerhetsmässig",
    "sjösäkerhetsmässiges": "sjösäkerhetsmässig",
    "sjösäkerhetsmässigs": "sjösäkerhetsmässig",
    "sjösäkerhetsmässigt": "sjösäkerhetsmässig",
    "sjösäkerhetsmässigts": "sjösäkerhetsmässig",
    "sjösäkers": "sjösäker",
    "sjösäkert": "sjösäker",
    "sjösäkerts": "sjösäker",
    "sjösäkra": "sjösäker",
    "sjösäkrare": "sjösäker",
    "sjösäkrares": "sjösäker",
    "sjösäkras": "sjösäker",
    "sjösäkrast": "sjösäker",
    "sjösäkraste": "sjösäker",
    "sjösäkrastes": "sjösäker",
    "sjösäkrasts": "sjösäker",
    "sjösäkre": "sjösäker",
    "sjösäkres": "sjösäker",
    "sjösätt": "sjösätta",
    "sjösättande": "sjösätta",
    "sjösättanden": "sjösättande",
    "sjösättandena": "sjösättande",
    "sjösättandenas": "sjösättande",
    "sjösättandens": "sjösättande",
    "sjösättandes": "sjösättande",
    "sjösättandet": "sjösättande",
    "sjösättandets": "sjösättande",
    "sjösättas": "sjösätta",
    "sjösätter": "sjösätta",
    "sjösättes": "sjösätta",
    "sjösättningar": "sjösättning",
    "sjösättningarna": "sjösättning",
    "sjösättningarnas": "sjösättning",
    "sjösättningars": "sjösättning",
    "sjösättningen": "sjösättning",
    "sjösättningens": "sjösättning",
    "sjösättnings": "sjösättning",
    "sjösätts": "sjösätta",
    "sjötomten": "sjötomt",
    "sjötomtens": "sjötomt",
    "sjötomter": "sjötomt",
    "sjötomterna": "sjötomt",
    "sjötomternas": "sjötomt",
    "sjötomters": "sjötomt",
    "sjötomts": "sjötomt",
    "sjötungan": "sjötunga",
    "sjötungans": "sjötunga",
    "sjötungas": "sjötunga",
    "sjötunge": "sjötunga",
    "sjötungo": "sjötunga",
    "sjötungor": "sjötunga",
    "sjötungorna": "sjötunga",
    "sjötungornas": "sjötunga",
    "sjötungors": "sjötunga",
    "sjöutsikten": "sjöutsikt",
    "sjöutsiktens": "sjöutsikt",
    "sjöutsikts": "sjöutsikt",
    "sjövanan": "sjövana",
    "sjövanans": "sjövana",
    "sjövanas": "sjövana",
    "sjövane": "sjövana",
    "sjövanor": "sjövana",
    "sjövanorna": "sjövana",
    "sjövanornas": "sjövana",
    "sjövanors": "sjövana",
    "sjövattens": "sjövatten",
    "sjövattnen": "sjövatten",
    "sjövattnens": "sjövatten",
    "sjövattnet": "sjövatten",
    "sjövattnets": "sjövatten",
    "sjövilda": "sjövild",
    "sjövildare": "sjövild",
    "sjövildares": "sjövild",
    "sjövildas": "sjövild",
    "sjövildast": "sjövild",
    "sjövildaste": "sjövild",
    "sjövildastes": "sjövild",
    "sjövildasts": "sjövild",
    "sjövilde": "sjövild",
    "sjövildes": "sjövild",
    "sjövildheten": "sjövildhet",
    "sjövildhetens": "sjövildhet",
    "sjövildhets": "sjövildhet",
    "sjövilds": "sjövild",
    "sjövilt": "sjövild",
    "sjövilts": "sjövild",
    "sjövägen": "sjöväg",
    "sjövägens": "sjöväg",
    "sjövägs": "sjöväg",
    "sjövägsregeln": "sjövägsregel",
    "sjövägsregelns": "sjövägsregel",
    "sjövägsregels": "sjövägsregel",
    "sjövägsregler": "sjövägsregel",
    "sjövägsreglerna": "sjövägsregel",
    "sjövägsreglernas": "sjövägsregel",
    "sjövägsreglers": "sjövägsregel",
    "sjövärdiga": "sjövärdig",
    "sjövärdigare": "sjövärdig",
    "sjövärdigares": "sjövärdig",
    "sjövärdigas": "sjövärdig",
    "sjövärdigast": "sjövärdig",
    "sjövärdigaste": "sjövärdig",
    "sjövärdigastes": "sjövärdig",
    "sjövärdigasts": "sjövärdig",
    "sjövärdige": "sjövärdig",
    "sjövärdiges": "sjövärdig",
    "sjövärdigheten": "sjövärdighet",
    "sjövärdighetens": "sjövärdighet",
    "sjövärdigheter": "sjövärdighet",
    "sjövärdigheterna": "sjövärdighet",
    "sjövärdigheternas": "sjövärdighet",
    "sjövärdigheters": "sjövärdighet",
    "sjövärdighets": "sjövärdighet",
    "sjövärdigs": "sjövärdig",
    "sjövärdigt": "sjövärdig",
    "sjövärdigts": "sjövärdig",
    "sjöytan": "sjöyta",
    "sjöytans": "sjöyta",
    "sjöytas": "sjöyta",
    "sjöyte": "sjöyta",
    "sjöytor": "sjöyta",
    "sjöytorna": "sjöyta",
    "sjöytornas": "sjöyta",
    "sjöytors": "sjöyta",
    "ska": "skola",
    "skabbdjuren": "skabbdjur",
    "skabbdjurens": "skabbdjur",
    "skabbdjuret": "skabbdjur",
    "skabbdjurets": "skabbdjur",
    "skabbdjurs": "skabbdjur",
    "skabben": "skabb",
    "skabbens": "skabb",
    "skabbiga": "skabbig",
    "skabbigare": "skabbig",
    "skabbigares": "skabbig",
    "skabbigas": "skabbig",
    "skabbigast": "skabbig",
    "skabbigaste": "skabbig",
    "skabbigastes": "skabbig",
    "skabbigasts": "skabbig",
    "skabbige": "skabbig",
    "skabbiges": "skabbig",
    "skabbigheten": "skabbighet",
    "skabbighetens": "skabbighet",
    "skabbighets": "skabbighet",
    "skabbigs": "skabbig",
    "skabbigt": "skabbig",
    "skabbigts": "skabbig",
    "skabbs": "skabb",
    "skabrösa": "skabrös",
    "skabrösare": "skabrös",
    "skabrösares": "skabrös",
    "skabrösas": "skabrös",
    "skabrösast": "skabrös",
    "skabrösaste": "skabrös",
    "skabrösastes": "skabrös",
    "skabrösasts": "skabrös",
    "skabröse": "skabrös",
    "skabröses": "skabrös",
    "skabröst": "skabrös",
    "skabrösts": "skabrös",
    "skackeln": "skackel",
    "skackelns": "skackel",
    "skackels": "skackel",
    "skacklar": "skackel",
    "skacklarna": "skackel",
    "skacklarnas": "skackel",
    "skacklars": "skackel",
    "skadad": "skada",
    "skadade": "skada",
    "skadades": "skada",
    "skadads": "skada",
    "skadan": "skada",
    "skadande": "skada",
    "skadanden": "skadande",
    "skadandena": "skadande",
    "skadandenas": "skadande",
    "skadandens": "skadande",
    "skadandes": "skadande",
    "skadandet": "skadande",
    "skadandets": "skadande",
    "skadans": "skada",
    "skadar": "skada",
    "skadas": "skada",
    "skadat": "skada",
    "skadats": "skada",
    "skade": "skada",
    "skadedjuren": "skadedjur",
    "skadedjurens": "skadedjur",
    "skadedjuret": "skadedjur",
    "skadedjurets": "skadedjur",
    "skadedjurs": "skadedjur",
    "skadedjursbekämpningen": "skadedjursbekämpning",
    "skadedjursbekämpningens": "skadedjursbekämpning",
    "skadedjursbekämpnings": "skadedjursbekämpning",
    "skadeersättningar": "skadeersättning",
    "skadeersättningarna": "skadeersättning",
    "skadeersättningarnas": "skadeersättning",
    "skadeersättningars": "skadeersättning",
    "skadeersättningen": "skadeersättning",
    "skadeersättningens": "skadeersättning",
    "skadeersättnings": "skadeersättning",
    "skadeglada": "skadeglad",
    "skadegladare": "skadeglad",
    "skadegladares": "skadeglad",
    "skadegladas": "skadeglad",
    "skadegladast": "skadeglad",
    "skadegladaste": "skadeglad",
    "skadegladastes": "skadeglad",
    "skadegladasts": "skadeglad",
    "skadeglade": "skadeglad",
    "skadeglades": "skadeglad",
    "skadeglads": "skadeglad",
    "skadeglatt": "skadeglad",
    "skadeglatts": "skadeglad",
    "skadeglädjen": "skadeglädje",
    "skadeglädjens": "skadeglädje",
    "skadeglädjes": "skadeglädje",
    "skadegörar": "skadegörare",
    "skadegöraren": "skadegörare",
    "skadegörarens": "skadegörare",
    "skadegörares": "skadegörare",
    "skadegörarna": "skadegörare",
    "skadegörarnas": "skadegörare",
    "skadegörelsen": "skadegörelse",
    "skadegörelsens": "skadegörelse",
    "skadegörelser": "skadegörelse",
    "skadegörelserna": "skadegörelse",
    "skadegörelsernas": "skadegörelse",
    "skadegörelsers": "skadegörelse",
    "skadegörelses": "skadegörelse",
    "skadeinsekten": "skadeinsekt",
    "skadeinsektens": "skadeinsekt",
    "skadeinsekter": "skadeinsekt",
    "skadeinsekterna": "skadeinsekt",
    "skadeinsekternas": "skadeinsekt",
    "skadeinsekters": "skadeinsekt",
    "skadeinsekts": "skadeinsekt",
    "skadereglerad": "skadereglera",
    "skadereglerade": "skadereglera",
    "skadereglerades": "skadereglera",
    "skadereglerads": "skadereglera",
    "skadereglerande": "skadereglera",
    "skaderegleranden": "skadereglerande",
    "skadereglerandena": "skadereglerande",
    "skadereglerandenas": "skadereglerande",
    "skadereglerandens": "skadereglerande",
    "skadereglerandes": "skadereglerande",
    "skadereglerandet": "skadereglerande",
    "skadereglerandets": "skadereglerande",
    "skadereglerar": "skadereglera",
    "skaderegleras": "skadereglera",
    "skadereglerat": "skadereglera",
    "skadereglerats": "skadereglera",
    "skadereglerbara": "skadereglerbar",
    "skadereglerbarare": "skadereglerbar",
    "skadereglerbarares": "skadereglerbar",
    "skadereglerbaras": "skadereglerbar",
    "skadereglerbarast": "skadereglerbar",
    "skadereglerbaraste": "skadereglerbar",
    "skadereglerbarastes": "skadereglerbar",
    "skadereglerbarasts": "skadereglerbar",
    "skadereglerbare": "skadereglerbar",
    "skadereglerbares": "skadereglerbar",
    "skadereglerbarheten": "skadereglerbarhet",
    "skadereglerbarhetens": "skadereglerbarhet",
    "skadereglerbarhets": "skadereglerbarhet",
    "skadereglerbars": "skadereglerbar",
    "skadereglerbart": "skadereglerbar",
    "skadereglerbarts": "skadereglerbar",
    "skaderegleringar": "skadereglering",
    "skaderegleringarna": "skadereglering",
    "skaderegleringarnas": "skadereglering",
    "skaderegleringars": "skadereglering",
    "skaderegleringen": "skadereglering",
    "skaderegleringens": "skadereglering",
    "skadereglerings": "skadereglering",
    "skadeslösa": "skadeslös",
    "skadeslösare": "skadeslös",
    "skadeslösares": "skadeslös",
    "skadeslösas": "skadeslös",
    "skadeslösast": "skadeslös",
    "skadeslösaste": "skadeslös",
    "skadeslösastes": "skadeslös",
    "skadeslösasts": "skadeslös",
    "skadeslöse": "skadeslös",
    "skadeslöses": "skadeslös",
    "skadeslösheten": "skadeslöshet",
    "skadeslöshetens": "skadeslöshet",
    "skadeslöshets": "skadeslöshet",
    "skadeslöst": "skadeslös",
    "skadeslösts": "skadeslös",
    "skadestånden": "skadestånd",
    "skadeståndens": "skadestånd",
    "skadeståndet": "skadestånd",
    "skadeståndets": "skadestånd",
    "skadestånds": "skadestånd",
    "skadeståndsansvaret": "skadeståndsansvar",
    "skadeståndsansvarets": "skadeståndsansvar",
    "skadeståndsansvars": "skadeståndsansvar",
    "skadeståndsrättsliga": "skadeståndsrättslig",
    "skadeståndsrättsligas": "skadeståndsrättslig",
    "skadeståndsrättslige": "skadeståndsrättslig",
    "skadeståndsrättsliges": "skadeståndsrättslig",
    "skadeståndsrättsligs": "skadeståndsrättslig",
    "skadeståndsrättsligt": "skadeståndsrättslig",
    "skadeståndsrättsligts": "skadeståndsrättslig",
    "skadeståndsskyldiga": "skadeståndsskyldig",
    "skadeståndsskyldigas": "skadeståndsskyldig",
    "skadeståndsskyldige": "skadeståndsskyldig",
    "skadeståndsskyldiges": "skadeståndsskyldig",
    "skadeståndsskyldigheten": "skadeståndsskyldighet",
    "skadeståndsskyldighetens": "skadeståndsskyldighet",
    "skadeståndsskyldighets": "skadeståndsskyldighet",
    "skadeståndsskyldigs": "skadeståndsskyldig",
    "skadeståndsskyldigt": "skadeståndsskyldig",
    "skadeståndsskyldigts": "skadeståndsskyldig",
    "skadeverkans": "skadeverkan",
    "skadeverkningar": "skadeverkning",
    "skadeverkningarna": "skadeverkning",
    "skadeverkningarnas": "skadeverkning",
    "skadeverkningars": "skadeverkning",
    "skadeverkningen": "skadeverkning",
    "skadeverkningens": "skadeverkning",
    "skadeverknings": "skadeverkning",
    "skadevärderingar": "skadevärdering",
    "skadevärderingarna": "skadevärdering",
    "skadevärderingarnas": "skadevärdering",
    "skadevärderingars": "skadevärdering",
    "skadevärderingen": "skadevärdering",
    "skadevärderingens": "skadevärdering",
    "skadevärderings": "skadevärdering",
    "skadliga": "skadlig",
    "skadligare": "skadlig",
    "skadligares": "skadlig",
    "skadligas": "skadlig",
    "skadligast": "skadlig",
    "skadligaste": "skadlig",
    "skadligastes": "skadlig",
    "skadligasts": "skadlig",
    "skadlige": "skadlig",
    "skadliges": "skadlig",
    "skadligheten": "skadlighet",
    "skadlighetens": "skadlighet",
    "skadligheter": "skadlighet",
    "skadligheterna": "skadlighet",
    "skadligheternas": "skadlighet",
    "skadligheters": "skadlighet",
    "skadlighets": "skadlighet",
    "skadligs": "skadlig",
    "skadligt": "skadlig",
    "skadligts": "skadlig",
    "skador": "skada",
    "skadorna": "skada",
    "skadornas": "skada",
    "skadors": "skada",
    "skadskjut": "skadskjuta",
    "skadskjutande": "skadskjuta",
    "skadskjutanden": "skadskjutande",
    "skadskjutandena": "skadskjutande",
    "skadskjutandenas": "skadskjutande",
    "skadskjutandens": "skadskjutande",
    "skadskjutandes": "skadskjutande",
    "skadskjutandet": "skadskjutande",
    "skadskjutandets": "skadskjutande",
    "skadskjutas": "skadskjuta",
    "skadskjute": "skadskjuta",
    "skadskjuten": "skadskjuta",
    "skadskjutens": "skadskjuta",
    "skadskjuter": "skadskjuta",
    "skadskjutes": "skadskjuta",
    "skadskjutet": "skadskjuta",
    "skadskjutets": "skadskjuta",
    "skadskjutit": "skadskjuta",
    "skadskjutits": "skadskjuta",
    "skadskjutna": "skadskjuta",
    "skadskjutnas": "skadskjuta",
    "skadskjutne": "skadskjuta",
    "skadskjutnes": "skadskjuta",
    "skadskjuts": "skadskjuta",
    "skadsköt": "skadskjuta",
    "skadsköte": "skadskjuta",
    "skadskötes": "skadskjuta",
    "skadsköts": "skadskjuta",
    "skaff": "skaffa",
    "skaffad": "skaffa",
    "skaffade": "skaffa",
    "skaffades": "skaffa",
    "skaffads": "skaffa",
    "skaffande": "skaffa",
    "skaffanden": "skaffande",
    "skaffandena": "skaffande",
    "skaffandenas": "skaffande",
    "skaffandens": "skaffande",
    "skaffandes": "skaffande",
    "skaffandet": "skaffande",
    "skaffandets": "skaffande",
    "skaffar": "skaffa",
    "skaffas": "skaffa",
    "skaffat": "skaffa",
    "skaffats": "skaffa",
    "skafferier": "skafferi",
    "skafferierna": "skafferi",
    "skafferiernas": "skafferi",
    "skafferiers": "skafferi",
    "skafferiet": "skafferi",
    "skafferiets": "skafferi",
    "skafferihyll": "skafferihylla",
    "skafferihyllan": "skafferihylla",
    "skafferihyllans": "skafferihylla",
    "skafferihyllas": "skafferihylla",
    "skafferihylle": "skafferihylla",
    "skafferihyllor": "skafferihylla",
    "skafferihyllorna": "skafferihylla",
    "skafferihyllornas": "skafferihylla",
    "skafferihyllors": "skafferihylla",
    "skafferihylls": "skafferihylla",
    "skafferis": "skafferi",
    "skafferit": "skafferi",
    "skafferits": "skafferi",
    "skaffningar": "skaffning",
    "skaffningarna": "skaffning",
    "skaffningarnas": "skaffning",
    "skaffningars": "skaffning",
    "skaffningen": "skaffning",
    "skaffningens": "skaffning",
    "skaffnings": "skaffning",
    "skaft": "skafta",
    "skaftad": "skafta",
    "skaftade": "skafta",
    "skaftades": "skafta",
    "skaftads": "skafta",
    "skaftande": "skafta",
    "skaftanden": "skaftande",
    "skaftandena": "skaftande",
    "skaftandenas": "skaftande",
    "skaftandens": "skaftande",
    "skaftandes": "skaftande",
    "skaftandet": "skaftande",
    "skaftandets": "skaftande",
    "skaftar": "skafta",
    "skaftas": "skafta",
    "skaftat": "skafta",
    "skaftats": "skafta",
    "skaften": "skaft",
    "skaftens": "skaft",
    "skaftet": "skaft",
    "skaftets": "skaft",
    "skafts": "skaft",
    "skak": "skaka",
    "skakad": "skaka",
    "skakade": "skakad",
    "skakades": "skakad",
    "skakads": "skakad",
    "skakande": "skaka",
    "skakanden": "skakande",
    "skakandena": "skakande",
    "skakandenas": "skakande",
    "skakandens": "skakande",
    "skakandes": "skakande",
    "skakandet": "skakande",
    "skakandets": "skakande",
    "skakar": "skaka",
    "skakas": "skaka",
    "skakat": "skakad",
    "skakats": "skakad",
    "skakeln": "skakel",
    "skakelns": "skakel",
    "skakels": "skakel",
    "skaken": "skak",
    "skakens": "skak",
    "skaket": "skak",
    "skakets": "skak",
    "skakiga": "skakig",
    "skakigare": "skakig",
    "skakigares": "skakig",
    "skakigas": "skakig",
    "skakigast": "skakig",
    "skakigaste": "skakig",
    "skakigastes": "skakig",
    "skakigasts": "skakig",
    "skakige": "skakig",
    "skakiges": "skakig",
    "skakigs": "skakig",
    "skakigt": "skakig",
    "skakigts": "skakig",
    "skaklar": "skakel",
    "skaklarna": "skakel",
    "skaklarnas": "skakel",
    "skaklars": "skakel",
    "skakningar": "skakning",
    "skakningarna": "skakning",
    "skakningarnas": "skakning",
    "skakningars": "skakning",
    "skakningen": "skakning",
    "skakningens": "skakning",
    "skaknings": "skakning",
    "skaks": "skak",
    "skaktåliga": "skaktålig",
    "skaktåligare": "skaktålig",
    "skaktåligares": "skaktålig",
    "skaktåligas": "skaktålig",
    "skaktåligast": "skaktålig",
    "skaktåligaste": "skaktålig",
    "skaktåligastes": "skaktålig",
    "skaktåligasts": "skaktålig",
    "skaktålige": "skaktålig",
    "skaktåliges": "skaktålig",
    "skaktåligheten": "skaktålighet",
    "skaktålighetens": "skaktålighet",
    "skaktålighets": "skaktålighet",
    "skaktåligs": "skaktålig",
    "skaktåligt": "skaktålig",
    "skaktåligts": "skaktålig",
    "skal": "skala",
    "skalad": "skala",
    "skalade": "skala",
    "skalades": "skala",
    "skalads": "skala",
    "skalan": "skala",
    "skalande": "skala",
    "skalanden": "skalande",
    "skalandena": "skalande",
    "skalandenas": "skalande",
    "skalandens": "skalande",
    "skalandes": "skalande",
    "skalandet": "skalande",
    "skalandets": "skalande",
    "skalans": "skala",
    "skalar": "skala",
    "skalas": "skala",
    "skalat": "skala",
    "skalats": "skala",
    "skalbagg": "skalbagge",
    "skalbaggar": "skalbagge",
    "skalbaggarna": "skalbagge",
    "skalbaggarnas": "skalbagge",
    "skalbaggars": "skalbagge",
    "skalbaggen": "skalbagge",
    "skalbaggens": "skalbagge",
    "skalbagges": "skalbagge",
    "skalbaggs": "skalbagge",
    "skald": "skalda",
    "skaldad": "skalda",
    "skaldade": "skalda",
    "skaldades": "skalda",
    "skaldads": "skalda",
    "skaldande": "skalda",
    "skaldanden": "skaldande",
    "skaldandena": "skaldande",
    "skaldandenas": "skaldande",
    "skaldandens": "skaldande",
    "skaldandes": "skaldande",
    "skaldandet": "skaldande",
    "skaldandets": "skaldande",
    "skaldar": "skalda",
    "skaldas": "skalda",
    "skaldat": "skalda",
    "skaldats": "skalda",
    "skalde": "skald",
    "skaldegåvan": "skaldegåva",
    "skaldegåvans": "skaldegåva",
    "skaldegåvas": "skaldegåva",
    "skaldegåve": "skaldegåva",
    "skaldegåvo": "skaldegåva",
    "skaldekonsten": "skaldekonst",
    "skaldekonstens": "skaldekonst",
    "skaldekonster": "skaldekonst",
    "skaldekonsterna": "skaldekonst",
    "skaldekonsternas": "skaldekonst",
    "skaldekonsters": "skaldekonst",
    "skaldekonsts": "skaldekonst",
    "skalden": "skald",
    "skaldens": "skald",
    "skalder": "skald",
    "skalderna": "skald",
    "skaldernas": "skald",
    "skalders": "skald",
    "skaldiska": "skaldisk",
    "skaldiskare": "skaldisk",
    "skaldiskares": "skaldisk",
    "skaldiskas": "skaldisk",
    "skaldiskast": "skaldisk",
    "skaldiskaste": "skaldisk",
    "skaldiskastes": "skaldisk",
    "skaldiskasts": "skaldisk",
    "skaldiske": "skaldisk",
    "skaldiskes": "skaldisk",
    "skaldisks": "skaldisk",
    "skaldiskt": "skaldisk",
    "skaldiskts": "skaldisk",
    "skaldjuren": "skaldjur",
    "skaldjurens": "skaldjur",
    "skaldjuret": "skaldjur",
    "skaldjurets": "skaldjur",
    "skaldjurs": "skaldjur",
    "skalds": "skald",
    "skale": "skala",
    "skalen": "skal",
    "skalenliga": "skalenlig",
    "skalenligare": "skalenlig",
    "skalenligares": "skalenlig",
    "skalenligas": "skalenlig",
    "skalenligast": "skalenlig",
    "skalenligaste": "skalenlig",
    "skalenligastes": "skalenlig",
    "skalenligasts": "skalenlig",
    "skalenlige": "skalenlig",
    "skalenliges": "skalenlig",
    "skalenligheten": "skalenlighet",
    "skalenlighetens": "skalenlighet",
    "skalenlighets": "skalenlighet",
    "skalenligs": "skalenlig",
    "skalenligt": "skalenlig",
    "skalenligts": "skalenlig",
    "skalens": "skal",
    "skalet": "skal",
    "skalets": "skal",
    "skalhusen": "skalhus",
    "skalhusens": "skalhus",
    "skalhuset": "skalhus",
    "skalhusets": "skalhus",
    "skalk": "skalka",
    "skalkad": "skalka",
    "skalkade": "skalka",
    "skalkades": "skalkas",
    "skalkads": "skalka",
    "skalkaktiga": "skalkaktig",
    "skalkaktigare": "skalkaktig",
    "skalkaktigares": "skalkaktig",
    "skalkaktigas": "skalkaktig",
    "skalkaktigast": "skalkaktig",
    "skalkaktigaste": "skalkaktig",
    "skalkaktigastes": "skalkaktig",
    "skalkaktigasts": "skalkaktig",
    "skalkaktige": "skalkaktig",
    "skalkaktiges": "skalkaktig",
    "skalkaktigheten": "skalkaktighet",
    "skalkaktighetens": "skalkaktighet",
    "skalkaktighets": "skalkaktighet",
    "skalkaktigs": "skalkaktig",
    "skalkaktigt": "skalkaktig",
    "skalkaktigts": "skalkaktig",
    "skalkande": "skalka",
    "skalkanden": "skalkande",
    "skalkandena": "skalkande",
    "skalkandenas": "skalkande",
    "skalkandens": "skalkande",
    "skalkandes": "skalkande",
    "skalkandet": "skalkande",
    "skalkandets": "skalkande",
    "skalkar": "skalka",
    "skalkarna": "skalk",
    "skalkarnas": "skalk",
    "skalkars": "skalk",
    "skalkas": "skalka",
    "skalkat": "skalka",
    "skalkats": "skalkas",
    "skalken": "skalk",
    "skalkens": "skalk",
    "skalkeskjulen": "skalkeskjul",
    "skalkeskjulens": "skalkeskjul",
    "skalkeskjulet": "skalkeskjul",
    "skalkeskjulets": "skalkeskjul",
    "skalkeskjuls": "skalkeskjul",
    "skalkornen": "skalkorn",
    "skalkornens": "skalkorn",
    "skalkornet": "skalkorn",
    "skalkornets": "skalkorn",
    "skalkorns": "skalkorn",
    "skalks": "skalk",
    "skall": "skola",
    "skallad": "skalla",
    "skallade": "skalla",
    "skallades": "skalla",
    "skallads": "skalla",
    "skallande": "skalla",
    "skallanden": "skallande",
    "skallandena": "skallande",
    "skallandenas": "skallande",
    "skallandens": "skallande",
    "skallandes": "skallande",
    "skallandet": "skallande",
    "skallandets": "skallande",
    "skallar": "skalle",
    "skallarna": "skalle",
    "skallarnas": "skalle",
    "skallars": "skalle",
    "skallas": "skalla",
    "skallat": "skalla",
    "skallats": "skalla",
    "skallbasen": "skallbas",
    "skallbasens": "skallbas",
    "skallbaser": "skallbas",
    "skallbaserna": "skallbas",
    "skallbasernas": "skallbas",
    "skallbasers": "skallbas",
    "skallbenen": "skallben",
    "skallbenens": "skallben",
    "skallbenet": "skallben",
    "skallbenets": "skallben",
    "skallbens": "skallben",
    "skallblödningar": "skallblödning",
    "skallblödningarna": "skallblödning",
    "skallblödningarnas": "skallblödning",
    "skallblödningars": "skallblödning",
    "skallblödningen": "skallblödning",
    "skallblödningens": "skallblödning",
    "skallblödnings": "skallblödning",
    "skallen": "skalle",
    "skallens": "skalle",
    "skaller": "skallra",
    "skallerormar": "skallerorm",
    "skallerormarna": "skallerorm",
    "skallerormarnas": "skallerorm",
    "skallerormars": "skallerorm",
    "skallerormen": "skallerorm",
    "skallerormens": "skallerorm",
    "skallerorms": "skallerorm",
    "skallers": "skaller",
    "skalles": "skalle",
    "skallet": "skall",
    "skallets": "skall",
    "skallformen": "skallform",
    "skallformens": "skallform",
    "skallformer": "skallform",
    "skallformerna": "skallform",
    "skallformernas": "skallform",
    "skallformers": "skallform",
    "skallforms": "skallform",
    "skallgångar": "skallgång",
    "skallgångarna": "skallgång",
    "skallgångarnas": "skallgång",
    "skallgångars": "skallgång",
    "skallgången": "skallgång",
    "skallgångens": "skallgång",
    "skallgångs": "skallgång",
    "skalliga": "skallig",
    "skalligare": "skallig",
    "skalligares": "skallig",
    "skalligas": "skallig",
    "skalligast": "skallig",
    "skalligaste": "skallig",
    "skalligastes": "skallig",
    "skalligasts": "skallig",
    "skallige": "skallig",
    "skalliges": "skallig",
    "skalligheten": "skallighet",
    "skallighetens": "skallighet",
    "skallighets": "skallighet",
    "skalligs": "skallig",
    "skalligt": "skallig",
    "skalligts": "skallig",
    "skallrade": "skallra",
    "skallrades": "skallra",
    "skallran": "skallra",
    "skallrande": "skallra",
    "skallranden": "skallrande",
    "skallrandena": "skallrande",
    "skallrandenas": "skallrande",
    "skallrandens": "skallrande",
    "skallrandes": "skallrande",
    "skallrandet": "skallrande",
    "skallrandets": "skallrande",
    "skallrans": "skallra",
    "skallrar": "skallra",
    "skallras": "skallra",
    "skallrat": "skallra",
    "skallrats": "skallra",
    "skallre": "skallra",
    "skallret": "skaller",
    "skallrets": "skaller",
    "skallror": "skallra",
    "skallrorna": "skallra",
    "skallrornas": "skallra",
    "skallrors": "skallra",
    "skalls": "skalle",
    "skallskadan": "skallskada",
    "skallskadans": "skallskada",
    "skallskadas": "skallskada",
    "skallskade": "skallskada",
    "skallskador": "skallskada",
    "skallskadorna": "skallskada",
    "skallskadornas": "skallskada",
    "skallskadors": "skallskada",
    "skallösa": "skallös",
    "skallösare": "skallös",
    "skallösares": "skallös",
    "skallösas": "skallös",
    "skallösast": "skallös",
    "skallösaste": "skallös",
    "skallösastes": "skallös",
    "skallösasts": "skallös",
    "skallöse": "skallös",
    "skallöses": "skallös",
    "skallösheten": "skallöshet",
    "skallöshetens": "skallöshet",
    "skallöshets": "skallöshet",
    "skallöst": "skallös",
    "skallösts": "skallös",
    "skalmar": "skalm",
    "skalmarna": "skalm",
    "skalmarnas": "skalm",
    "skalmars": "skalm",
    "skalmej": "skalmeja",
    "skalmejan": "skalmeja",
    "skalmejans": "skalmeja",
    "skalmejas": "skalmeja",
    "skalmeje": "skalmeja",
    "skalmejor": "skalmeja",
    "skalmejorna": "skalmeja",
    "skalmejornas": "skalmeja",
    "skalmejors": "skalmeja",
    "skalmejs": "skalmeja",
    "skalmen": "skalm",
    "skalmens": "skalm",
    "skalms": "skalm",
    "skalor": "skala",
    "skalorna": "skala",
    "skalornas": "skala",
    "skalors": "skala",
    "skalpellen": "skalpell",
    "skalpellens": "skalpell",
    "skalpeller": "skalpell",
    "skalpellerna": "skalpell",
    "skalpellernas": "skalpell",
    "skalpellers": "skalpell",
    "skalpells": "skalpell",
    "skalpen": "skalp",
    "skalpens": "skalp",
    "skalper": "skalp",
    "skalperad": "skalpera",
    "skalperade": "skalpera",
    "skalperades": "skalpera",
    "skalperads": "skalpera",
    "skalperande": "skalpera",
    "skalperanden": "skalperande",
    "skalperandena": "skalperande",
    "skalperandenas": "skalperande",
    "skalperandens": "skalperande",
    "skalperandes": "skalperande",
    "skalperandet": "skalperande",
    "skalperandets": "skalperande",
    "skalperar": "skalpera",
    "skalperas": "skalpera",
    "skalperat": "skalpera",
    "skalperats": "skalpera",
    "skalperbara": "skalperbar",
    "skalperbarare": "skalperbar",
    "skalperbarares": "skalperbar",
    "skalperbaras": "skalperbar",
    "skalperbarast": "skalperbar",
    "skalperbaraste": "skalperbar",
    "skalperbarastes": "skalperbar",
    "skalperbarasts": "skalperbar",
    "skalperbare": "skalperbar",
    "skalperbares": "skalperbar",
    "skalperbarheten": "skalperbarhet",
    "skalperbarhetens": "skalperbarhet",
    "skalperbarhets": "skalperbarhet",
    "skalperbars": "skalperbar",
    "skalperbart": "skalperbar",
    "skalperbarts": "skalperbar",
    "skalperingar": "skalpering",
    "skalperingarna": "skalpering",
    "skalperingarnas": "skalpering",
    "skalperingars": "skalpering",
    "skalperingen": "skalpering",
    "skalperingens": "skalpering",
    "skalperings": "skalpering",
    "skalperna": "skalp",
    "skalpernas": "skalp",
    "skalpers": "skalp",
    "skalps": "skalp",
    "skals": "skala",
    "skalstrecken": "skalstreck",
    "skalstreckens": "skalstreck",
    "skalstrecket": "skalstreck",
    "skalstreckets": "skalstreck",
    "skalstrecks": "skalstreck",
    "skalv": "skälva",
    "skalven": "skalv",
    "skalvens": "skalv",
    "skalvet": "skalv",
    "skalvets": "skalv",
    "skalvs": "skalv",
    "skalära": "skalär",
    "skalärare": "skalär",
    "skalärares": "skalär",
    "skaläras": "skalär",
    "skalärast": "skalär",
    "skaläraste": "skalär",
    "skalärastes": "skalär",
    "skalärasts": "skalär",
    "skaläre": "skalär",
    "skalären": "skalär",
    "skalärens": "skalär",
    "skalärer": "skalär",
    "skalärerna": "skalär",
    "skalärernas": "skalär",
    "skalärers": "skalär",
    "skaläres": "skalär",
    "skalärs": "skalär",
    "skalärt": "skalär",
    "skalärts": "skalär",
    "skamfil": "skamfila",
    "skamfilad": "skamfila",
    "skamfilade": "skamfila",
    "skamfilades": "skamfila",
    "skamfilads": "skamfila",
    "skamfilande": "skamfila",
    "skamfilanden": "skamfilande",
    "skamfilandena": "skamfilande",
    "skamfilandenas": "skamfilande",
    "skamfilandens": "skamfilande",
    "skamfilandes": "skamfilande",
    "skamfilandet": "skamfilande",
    "skamfilandets": "skamfilande",
    "skamfilar": "skamfila",
    "skamfilas": "skamfila",
    "skamfilat": "skamfila",
    "skamfilats": "skamfila",
    "skamflata": "skamflat",
    "skamflatare": "skamflat",
    "skamflatares": "skamflat",
    "skamflatas": "skamflat",
    "skamflatast": "skamflat",
    "skamflataste": "skamflat",
    "skamflatastes": "skamflat",
    "skamflatasts": "skamflat",
    "skamflate": "skamflat",
    "skamflates": "skamflat",
    "skamflats": "skamflat",
    "skamfläckar": "skamfläck",
    "skamfläckarna": "skamfläck",
    "skamfläckarnas": "skamfläck",
    "skamfläckars": "skamfläck",
    "skamfläcken": "skamfläck",
    "skamfläckens": "skamfläck",
    "skamfläcks": "skamfläck",
    "skamgreppen": "skamgrepp",
    "skamgreppens": "skamgrepp",
    "skamgreppet": "skamgrepp",
    "skamgreppets": "skamgrepp",
    "skamgrepps": "skamgrepp",
    "skamkänsl": "skamkänsla",
    "skamkänslan": "skamkänsla",
    "skamkänslans": "skamkänsla",
    "skamkänslas": "skamkänsla",
    "skamkänsle": "skamkänsla",
    "skamkänslo": "skamkänsla",
    "skamkänslor": "skamkänsla",
    "skamkänslorna": "skamkänsla",
    "skamkänslornas": "skamkänsla",
    "skamkänslors": "skamkänsla",
    "skamliga": "skamlig",
    "skamligare": "skamlig",
    "skamligares": "skamlig",
    "skamligas": "skamlig",
    "skamligast": "skamlig",
    "skamligaste": "skamlig",
    "skamligastes": "skamlig",
    "skamligasts": "skamlig",
    "skamlige": "skamlig",
    "skamliges": "skamlig",
    "skamligheten": "skamlighet",
    "skamlighetens": "skamlighet",
    "skamligheter": "skamlighet",
    "skamligheterna": "skamlighet",
    "skamligheternas": "skamlighet",
    "skamligheters": "skamlighet",
    "skamlighets": "skamlighet",
    "skamligs": "skamlig",
    "skamligt": "skamlig",
    "skamligts": "skamlig",
    "skamlösa": "skamlös",
    "skamlösare": "skamlös",
    "skamlösares": "skamlös",
    "skamlösas": "skamlös",
    "skamlösast": "skamlös",
    "skamlösaste": "skamlös",
    "skamlösastes": "skamlös",
    "skamlösasts": "skamlös",
    "skamlöse": "skamlös",
    "skamlöses": "skamlös",
    "skamlösheten": "skamlöshet",
    "skamlöshetens": "skamlöshet",
    "skamlösheter": "skamlöshet",
    "skamlösheterna": "skamlöshet",
    "skamlösheternas": "skamlöshet",
    "skamlösheters": "skamlöshet",
    "skamlöshets": "skamlöshet",
    "skamlöst": "skamlös",
    "skamlösts": "skamlös",
    "skammen": "skam",
    "skammens": "skam",
    "skampål": "skampåle",
    "skampålar": "skampåle",
    "skampålarna": "skampåle",
    "skampålarnas": "skampåle",
    "skampålars": "skampåle",
    "skampålen": "skampåle",
    "skampålens": "skampåle",
    "skampåles": "skampåle",
    "skampåls": "skampåle",
    "skams": "skam",
    "skamsens": "skamsen",
    "skamset": "skamsen",
    "skamsets": "skamsen",
    "skamsna": "skamsen",
    "skamsnare": "skamsen",
    "skamsnares": "skamsen",
    "skamsnas": "skamsen",
    "skamsnast": "skamsen",
    "skamsnaste": "skamsen",
    "skamsnastes": "skamsen",
    "skamsnasts": "skamsen",
    "skamsne": "skamsen",
    "skamsnes": "skamsen",
    "skamstockar": "skamstock",
    "skamstockarna": "skamstock",
    "skamstockarnas": "skamstock",
    "skamstockars": "skamstock",
    "skamstocken": "skamstock",
    "skamstockens": "skamstock",
    "skamstocks": "skamstock",
    "skamvrån": "skamvrå",
    "skamvråns": "skamvrå",
    "skamvrås": "skamvrå",
    "skandalavslöjanden": "skandalavslöjande",
    "skandalavslöjandena": "skandalavslöjande",
    "skandalavslöjandenas": "skandalavslöjande",
    "skandalavslöjandens": "skandalavslöjande",
    "skandalavslöjandes": "skandalavslöjande",
    "skandalavslöjandet": "skandalavslöjande",
    "skandalavslöjandets": "skandalavslöjande",
    "skandalbilden": "skandalbild",
    "skandalbildens": "skandalbild",
    "skandalbilder": "skandalbild",
    "skandalbilderna": "skandalbild",
    "skandalbildernas": "skandalbild",
    "skandalbilders": "skandalbild",
    "skandalbilds": "skandalbild",
    "skandalen": "skandal",
    "skandalens": "skandal",
    "skandaler": "skandal",
    "skandalerna": "skandal",
    "skandalernas": "skandal",
    "skandalers": "skandal",
    "skandaliserad": "skandalisera",
    "skandaliserade": "skandalisera",
    "skandaliserades": "skandalisera",
    "skandaliserads": "skandalisera",
    "skandaliserande": "skandalisera",
    "skandaliseranden": "skandaliserande",
    "skandaliserandena": "skandaliserande",
    "skandaliserandenas": "skandaliserande",
    "skandaliserandens": "skandaliserande",
    "skandaliserandes": "skandaliserande",
    "skandaliserandet": "skandaliserande",
    "skandaliserandets": "skandaliserande",
    "skandaliserar": "skandalisera",
    "skandaliseras": "skandalisera",
    "skandaliserat": "skandalisera",
    "skandaliserats": "skandalisera",
    "skandaliserbara": "skandaliserbar",
    "skandaliserbarare": "skandaliserbar",
    "skandaliserbarares": "skandaliserbar",
    "skandaliserbaras": "skandaliserbar",
    "skandaliserbarast": "skandaliserbar",
    "skandaliserbaraste": "skandaliserbar",
    "skandaliserbarastes": "skandaliserbar",
    "skandaliserbarasts": "skandaliserbar",
    "skandaliserbare": "skandaliserbar",
    "skandaliserbares": "skandaliserbar",
    "skandaliserbarheten": "skandaliserbarhet",
    "skandaliserbarhetens": "skandaliserbarhet",
    "skandaliserbarhets": "skandaliserbarhet",
    "skandaliserbars": "skandaliserbar",
    "skandaliserbart": "skandaliserbar",
    "skandaliserbarts": "skandaliserbar",
    "skandaliseringar": "skandalisering",
    "skandaliseringarna": "skandalisering",
    "skandaliseringarnas": "skandalisering",
    "skandaliseringars": "skandalisering",
    "skandaliseringen": "skandalisering",
    "skandaliseringens": "skandalisering",
    "skandaliserings": "skandalisering",
    "skandalmissar": "skandalmiss",
    "skandalmissarna": "skandalmiss",
    "skandalmissarnas": "skandalmiss",
    "skandalmissars": "skandalmiss",
    "skandalmissen": "skandalmiss",
    "skandalmissens": "skandalmiss",
    "skandalmålen": "skandalmål",
    "skandalmålens": "skandalmål",
    "skandalmålet": "skandalmål",
    "skandalmålets": "skandalmål",
    "skandalmåls": "skandalmål",
    "skandalomsusade": "skandalomsusad",
    "skandalomsusades": "skandalomsusad",
    "skandalomsusads": "skandalomsusad",
    "skandalomsusat": "skandalomsusad",
    "skandalomsusats": "skandalomsusad",
    "skandals": "skandal",
    "skandalskriverier": "skandalskriveri",
    "skandalskriverierna": "skandalskriveri",
    "skandalskriveriernas": "skandalskriveri",
    "skandalskriveriers": "skandalskriveri",
    "skandalskriveriet": "skandalskriveri",
    "skandalskriveriets": "skandalskriveri",
    "skandalskriveris": "skandalskriveri",
    "skandalskriverit": "skandalskriveri",
    "skandalskriverits": "skandalskriveri",
    "skandaltidningar": "skandaltidning",
    "skandaltidningarna": "skandaltidning",
    "skandaltidningarnas": "skandaltidning",
    "skandaltidningars": "skandaltidning",
    "skandaltidningen": "skandaltidning",
    "skandaltidningens": "skandaltidning",
    "skandaltidnings": "skandaltidning",
    "skandalungar": "skandalunge",
    "skandalungarna": "skandalunge",
    "skandalungarnas": "skandalunge",
    "skandalungars": "skandalunge",
    "skandalungen": "skandalunge",
    "skandalungens": "skandalunge",
    "skandalunges": "skandalunge",
    "skandalösa": "skandalös",
    "skandalösare": "skandalös",
    "skandalösares": "skandalös",
    "skandalösas": "skandalös",
    "skandalösast": "skandalös",
    "skandalösaste": "skandalös",
    "skandalösastes": "skandalös",
    "skandalösasts": "skandalös",
    "skandalöse": "skandalös",
    "skandalöses": "skandalös",
    "skandalöst": "skandalös",
    "skandalösts": "skandalös",
    "skanderad": "skandera",
    "skanderade": "skandera",
    "skanderades": "skandera",
    "skanderads": "skandera",
    "skanderande": "skandera",
    "skanderanden": "skanderande",
    "skanderandena": "skanderande",
    "skanderandenas": "skanderande",
    "skanderandens": "skanderande",
    "skanderandes": "skanderande",
    "skanderandet": "skanderande",
    "skanderandets": "skanderande",
    "skanderar": "skandera",
    "skanderas": "skandera",
    "skanderat": "skandera",
    "skanderats": "skandera",
    "skanderbara": "skanderbar",
    "skanderbarare": "skanderbar",
    "skanderbarares": "skanderbar",
    "skanderbaras": "skanderbar",
    "skanderbarast": "skanderbar",
    "skanderbaraste": "skanderbar",
    "skanderbarastes": "skanderbar",
    "skanderbarasts": "skanderbar",
    "skanderbare": "skanderbar",
    "skanderbares": "skanderbar",
    "skanderbarheten": "skanderbarhet",
    "skanderbarhetens": "skanderbarhet",
    "skanderbarhets": "skanderbarhet",
    "skanderbars": "skanderbar",
    "skanderbart": "skanderbar",
    "skanderbarts": "skanderbar",
    "skanderingar": "skandering",
    "skanderingarna": "skandering",
    "skanderingarnas": "skandering",
    "skanderingars": "skandering",
    "skanderingen": "skandering",
    "skanderingens": "skandering",
    "skanderings": "skandering",
    "skandiet": "skandium",
    "skandiets": "skandium",
    "skandinaven": "skandinav",
    "skandinavens": "skandinav",
    "skandinaver": "skandinav",
    "skandinaverna": "skandinav",
    "skandinavernas": "skandinav",
    "skandinavers": "skandinav",
    "skandinaviska": "skandinavisk",
    "skandinaviskare": "skandinavisk",
    "skandinaviskares": "skandinavisk",
    "skandinaviskas": "skandinavisk",
    "skandinaviskast": "skandinavisk",
    "skandinaviskaste": "skandinavisk",
    "skandinaviskastes": "skandinavisk",
    "skandinaviskasts": "skandinavisk",
    "skandinaviske": "skandinavisk",
    "skandinaviskes": "skandinavisk",
    "skandinavisks": "skandinavisk",
    "skandinaviskt": "skandinavisk",
    "skandinaviskts": "skandinavisk",
    "skandinavismen": "skandinavism",
    "skandinavismens": "skandinavism",
    "skandinavismer": "skandinavism",
    "skandinavismerna": "skandinavism",
    "skandinavismernas": "skandinavism",
    "skandinavismers": "skandinavism",
    "skandinavisms": "skandinavism",
    "skandinavisten": "skandinavist",
    "skandinavistens": "skandinavist",
    "skandinavister": "skandinavist",
    "skandinavisterna": "skandinavist",
    "skandinavisternas": "skandinavist",
    "skandinavisters": "skandinavist",
    "skandinavistiska": "skandinavistisk",
    "skandinavistiskas": "skandinavistisk",
    "skandinavistiske": "skandinavistisk",
    "skandinavistiskes": "skandinavistisk",
    "skandinavistisks": "skandinavistisk",
    "skandinavistiskt": "skandinavistisk",
    "skandinavistiskts": "skandinavistisk",
    "skandinavists": "skandinavist",
    "skandinavs": "skandinav",
    "skandiumet": "skandium",
    "skandiumets": "skandium",
    "skandiums": "skandium",
    "skanismen": "skanism",
    "skanismens": "skanism",
    "skanismer": "skanism",
    "skanismerna": "skanism",
    "skanismernas": "skanism",
    "skanismers": "skanism",
    "skanisms": "skanism",
    "skankar": "skank",
    "skankarna": "skank",
    "skankarnas": "skank",
    "skankars": "skank",
    "skanken": "skank",
    "skankens": "skank",
    "skankor": "skank",
    "skankorna": "skank",
    "skankornas": "skank",
    "skankors": "skank",
    "skanks": "skank",
    "skannad": "skanna",
    "skannade": "skanna",
    "skannades": "skanna",
    "skannads": "skanna",
    "skannande": "skanna",
    "skannanden": "skannande",
    "skannandena": "skannande",
    "skannandenas": "skannande",
    "skannandens": "skannande",
    "skannandes": "skannande",
    "skannandet": "skannande",
    "skannandets": "skannande",
    "skannar": "skanna",
    "skannas": "skanna",
    "skannat": "skanna",
    "skannats": "skanna",
    "skannern": "skanner",
    "skannerna": "skanner",
    "skannernas": "skanner",
    "skannerns": "skanner",
    "skanners": "skanner",
    "skannersarna": "skanner",
    "skannersarnas": "skanner",
    "skanningar": "skanning",
    "skanningarna": "skanning",
    "skanningarnas": "skanning",
    "skanningars": "skanning",
    "skanningen": "skanning",
    "skanningens": "skanning",
    "skannings": "skanning",
    "skannrar": "skanner",
    "skannrarna": "skanner",
    "skannrarnas": "skanner",
    "skannrars": "skanner",
    "skansar": "skans",
    "skansarna": "skans",
    "skansarnas": "skans",
    "skansars": "skans",
    "skansen": "skans",
    "skansens": "skans",
    "skap": "skapa",
    "skapad": "skapa",
    "skapade": "skapa",
    "skapades": "skapa",
    "skapads": "skapa",
    "skapande": "skapa",
    "skapanden": "skapande",
    "skapandena": "skapande",
    "skapandenas": "skapande",
    "skapandens": "skapande",
    "skapandes": "skapande",
    "skapandet": "skapande",
    "skapandets": "skapande",
    "skapar": "skapare",
    "skaparandan": "skaparanda",
    "skaparandans": "skaparanda",
    "skaparandas": "skaparanda",
    "skaparen": "skapare",
    "skaparens": "skapare",
    "skapares": "skapare",
    "skaparkraften": "skaparkraft",
    "skaparkraftens": "skaparkraft",
    "skaparkrafter": "skaparkraft",
    "skaparkrafterna": "skaparkraft",
    "skaparkrafternas": "skaparkraft",
    "skaparkrafters": "skaparkraft",
    "skaparkrafts": "skaparkraft",
    "skaparna": "skapare",
    "skaparnas": "skapare",
    "skapas": "skapa",
    "skapat": "skapa",
    "skapats": "skapa",
    "skapelseakten": "skapelseakt",
    "skapelseaktens": "skapelseakt",
    "skapelseakter": "skapelseakt",
    "skapelseakterna": "skapelseakt",
    "skapelseakternas": "skapelseakt",
    "skapelseakters": "skapelseakt",
    "skapelseakts": "skapelseakt",
    "skapelseberättelsen": "skapelseberättelse",
    "skapelseberättelsens": "skapelseberättelse",
    "skapelseberättelser": "skapelseberättelse",
    "skapelseberättelserna": "skapelseberättelse",
    "skapelseberättelsernas": "skapelseberättelse",
    "skapelseberättelsers": "skapelseberättelse",
    "skapelseberättelses": "skapelseberättelse",
    "skapelsen": "skapelse",
    "skapelsens": "skapelse",
    "skapelser": "skapelse",
    "skapelserna": "skapelse",
    "skapelsernas": "skapelse",
    "skapelsers": "skapelse",
    "skapelses": "skapelse",
    "skapen": "skap",
    "skapens": "skap",
    "skapet": "skap",
    "skapets": "skap",
    "skapliga": "skaplig",
    "skapligare": "skaplig",
    "skapligares": "skaplig",
    "skapligas": "skaplig",
    "skapligast": "skaplig",
    "skapligaste": "skaplig",
    "skapligastes": "skaplig",
    "skapligasts": "skaplig",
    "skaplige": "skaplig",
    "skapliges": "skaplig",
    "skapligheten": "skaplighet",
    "skaplighetens": "skaplighet",
    "skaplighets": "skaplighet",
    "skapligs": "skaplig",
    "skapligt": "skaplig",
    "skapligts": "skaplig",
    "skaplynnen": "skaplynne",
    "skaplynnena": "skaplynne",
    "skaplynnenas": "skaplynne",
    "skaplynnens": "skaplynne",
    "skaplynnes": "skaplynne",
    "skaplynnet": "skaplynne",
    "skaplynnets": "skaplynne",
    "skaplynns": "skaplynne",
    "skapnaden": "skapnad",
    "skapnadens": "skapnad",
    "skapnader": "skapnad",
    "skapnaderna": "skapnad",
    "skapnadernas": "skapnad",
    "skapnaders": "skapnad",
    "skapnads": "skapnad",
    "skaps": "skap",
    "skapt": "skapa",
    "skapta": "skapa",
    "skaptas": "skapa",
    "skapte": "skapa",
    "skaptes": "skapa",
    "skapts": "skapa",
    "skar": "skära",
    "skarabéer": "skarabé",
    "skarabéerna": "skarabé",
    "skarabéernas": "skarabé",
    "skarabéers": "skarabé",
    "skarabén": "skarabé",
    "skarabéns": "skarabé",
    "skarabés": "skarabé",
    "skaran": "skara",
    "skarans": "skara",
    "skaras": "skara",
    "skare": "skara",
    "skaren": "skare",
    "skarens": "skare",
    "skares": "skare",
    "skarfar": "skarf",
    "skarfarna": "skarf",
    "skarfarnas": "skarf",
    "skarfars": "skarf",
    "skarfen": "skarf",
    "skarfens": "skarf",
    "skarfs": "skarf",
    "skarndäcken": "skarndäck",
    "skarndäckens": "skarndäck",
    "skarndäcket": "skarndäck",
    "skarndäckets": "skarndäck",
    "skarndäcks": "skarndäck",
    "skarnen": "skarn",
    "skarnens": "skarn",
    "skarnet": "skarn",
    "skarnets": "skarn",
    "skarns": "skarn",
    "skaror": "skara",
    "skarorna": "skara",
    "skarornas": "skara",
    "skarors": "skara",
    "skarpa": "skarp",
    "skarpare": "skarp",
    "skarpares": "skarp",
    "skarpas": "skarp",
    "skarpast": "skarp",
    "skarpaste": "skarp",
    "skarpastes": "skarp",
    "skarpasts": "skarp",
    "skarpe": "skarp",
    "skarpes": "skarp",
    "skarpheten": "skarphet",
    "skarphetens": "skarphet",
    "skarpheter": "skarphet",
    "skarpheterna": "skarphet",
    "skarpheternas": "skarphet",
    "skarpheters": "skarphet",
    "skarphets": "skarphet",
    "skarpladdade": "skarpladdad",
    "skarpladdades": "skarpladdad",
    "skarpladdads": "skarpladdad",
    "skarpladdat": "skarpladdad",
    "skarpladdats": "skarpladdad",
    "skarprättar": "skarprättare",
    "skarprättaren": "skarprättare",
    "skarprättarens": "skarprättare",
    "skarprättares": "skarprättare",
    "skarprättarna": "skarprättare",
    "skarprättarnas": "skarprättare",
    "skarps": "skarp",
    "skarpsillar": "skarpsill",
    "skarpsillarna": "skarpsill",
    "skarpsillarnas": "skarpsill",
    "skarpsillars": "skarpsill",
    "skarpsillen": "skarpsill",
    "skarpsillens": "skarpsill",
    "skarpsills": "skarpsill",
    "skarpsinnen": "skarpsinne",
    "skarpsinnena": "skarpsinne",
    "skarpsinnenas": "skarpsinne",
    "skarpsinnens": "skarpsinne",
    "skarpsinnes": "skarpsinne",
    "skarpsinnet": "skarpsinne",
    "skarpsinnets": "skarpsinne",
    "skarpsinniga": "skarpsinnig",
    "skarpsinnigare": "skarpsinnig",
    "skarpsinnigares": "skarpsinnig",
    "skarpsinnigas": "skarpsinnig",
    "skarpsinnigast": "skarpsinnig",
    "skarpsinnigaste": "skarpsinnig",
    "skarpsinnigastes": "skarpsinnig",
    "skarpsinnigasts": "skarpsinnig",
    "skarpsinnige": "skarpsinnig",
    "skarpsinniges": "skarpsinnig",
    "skarpsinnigs": "skarpsinnig",
    "skarpsinnigt": "skarpsinnig",
    "skarpsinnigts": "skarpsinnig",
    "skarpskurens": "skarpskuren",
    "skarpskuret": "skarpskuren",
    "skarpskurets": "skarpskuren",
    "skarpskurna": "skarpskuren",
    "skarpskurnare": "skarpskuren",
    "skarpskurnares": "skarpskuren",
    "skarpskurnas": "skarpskuren",
    "skarpskurnast": "skarpskuren",
    "skarpskurnaste": "skarpskuren",
    "skarpskurnastes": "skarpskuren",
    "skarpskurnasts": "skarpskuren",
    "skarpskurne": "skarpskuren",
    "skarpskurnes": "skarpskuren",
    "skarpskyttar": "skarpskytt",
    "skarpskyttarna": "skarpskytt",
    "skarpskyttarnas": "skarpskytt",
    "skarpskyttars": "skarpskytt",
    "skarpskytten": "skarpskytt",
    "skarpskyttens": "skarpskytt",
    "skarpskytts": "skarpskytt",
    "skarpslipade": "skarpslipad",
    "skarpslipades": "skarpslipad",
    "skarpslipads": "skarpslipad",
    "skarpslipat": "skarpslipad",
    "skarpslipats": "skarpslipad",
    "skarpsynen": "skarpsyn",
    "skarpsynens": "skarpsyn",
    "skarpsyner": "skarpsyn",
    "skarpsynerna": "skarpsyn",
    "skarpsynernas": "skarpsyn",
    "skarpsyners": "skarpsyn",
    "skarpsyns": "skarpsyn",
    "skarpsynta": "skarpsynt",
    "skarpsyntare": "skarpsynt",
    "skarpsyntares": "skarpsynt",
    "skarpsyntas": "skarpsynt",
    "skarpsyntast": "skarpsynt",
    "skarpsyntaste": "skarpsynt",
    "skarpsyntastes": "skarpsynt",
    "skarpsyntasts": "skarpsynt",
    "skarpsynte": "skarpsynt",
    "skarpsyntes": "skarpsynt",
    "skarpsyntheten": "skarpsynthet",
    "skarpsynthetens": "skarpsynthet",
    "skarpsynthets": "skarpsynthet",
    "skarpsynts": "skarpsynt",
    "skarpsåsen": "skarpsås",
    "skarpsåsens": "skarpsås",
    "skarpt": "skarp",
    "skarpts": "skarp",
    "skarpögda": "skarpögd",
    "skarpögdare": "skarpögd",
    "skarpögdares": "skarpögd",
    "skarpögdas": "skarpögd",
    "skarpögdast": "skarpögd",
    "skarpögdaste": "skarpögd",
    "skarpögdastes": "skarpögd",
    "skarpögdasts": "skarpögd",
    "skarpögde": "skarpögd",
    "skarpögdes": "skarpögd",
    "skarpögdheten": "skarpögdhet",
    "skarpögdhetens": "skarpögdhet",
    "skarpögdhets": "skarpögdhet",
    "skarpögds": "skarpögd",
    "skarpögt": "skarpögd",
    "skarpögts": "skarpögd",
    "skars": "skära",
    "skarv": "skarva",
    "skarvad": "skarva",
    "skarvade": "skarva",
    "skarvades": "skarva",
    "skarvads": "skarva",
    "skarvande": "skarva",
    "skarvanden": "skarvande",
    "skarvandena": "skarvande",
    "skarvandenas": "skarvande",
    "skarvandens": "skarvande",
    "skarvandes": "skarvande",
    "skarvandet": "skarvande",
    "skarvandets": "skarvande",
    "skarvar": "skarva",
    "skarvarna": "skarv",
    "skarvarnas": "skarv",
    "skarvars": "skarv",
    "skarvas": "skarva",
    "skarvat": "skarva",
    "skarvats": "skarva",
    "skarven": "skarv",
    "skarvens": "skarv",
    "skarvklämman": "skarvklämma",
    "skarvklämmans": "skarvklämma",
    "skarvklämmas": "skarvklämma",
    "skarvklämme": "skarvklämma",
    "skarvklämmor": "skarvklämma",
    "skarvklämmorna": "skarvklämma",
    "skarvklämmornas": "skarvklämma",
    "skarvklämmors": "skarvklämma",
    "skarvrull": "skarvrulle",
    "skarvrullar": "skarvrulle",
    "skarvrullarna": "skarvrulle",
    "skarvrullarnas": "skarvrulle",
    "skarvrullars": "skarvrulle",
    "skarvrullen": "skarvrulle",
    "skarvrullens": "skarvrulle",
    "skarvrulles": "skarvrulle",
    "skarvrulls": "skarvrulle",
    "skarvs": "skarv",
    "skarvsladdar": "skarvsladd",
    "skarvsladdarna": "skarvsladd",
    "skarvsladdarnas": "skarvsladd",
    "skarvsladdars": "skarvsladd",
    "skarvsladden": "skarvsladd",
    "skarvsladdens": "skarvsladd",
    "skarvsladds": "skarvsladd",
    "skat": "skate",
    "skatade": "skata",
    "skatades": "skata",
    "skatan": "skata",
    "skatande": "skata",
    "skatanden": "skatande",
    "skatandena": "skatande",
    "skatandenas": "skatande",
    "skatandens": "skatande",
    "skatandes": "skatande",
    "skatandet": "skatande",
    "skatandets": "skatande",
    "skatans": "skata",
    "skatar": "skate",
    "skatarna": "skate",
    "skatarnas": "skate",
    "skatars": "skate",
    "skatas": "skata",
    "skatat": "skata",
    "skatats": "skata",
    "skate": "skata",
    "skateboarden": "skateboard",
    "skateboardens": "skateboard",
    "skateboards": "skateboard",
    "skateboardsen": "skateboard",
    "skateboardsens": "skateboard",
    "skaten": "skate",
    "skatens": "skate",
    "skates": "skate",
    "skatnäv": "skatnäva",
    "skatnävan": "skatnäva",
    "skatnävans": "skatnäva",
    "skatnävas": "skatnäva",
    "skatnäve": "skatnäva",
    "skatnävor": "skatnäva",
    "skatnävorna": "skatnäva",
    "skatnävornas": "skatnäva",
    "skatnävors": "skatnäva",
    "skatnävs": "skatnäva",
    "skator": "skata",
    "skatorna": "skata",
    "skatornas": "skata",
    "skators": "skata",
    "skats": "skate",
    "skattad": "skatta",
    "skattade": "skatta",
    "skattades": "skatta",
    "skattads": "skatta",
    "skattande": "skatta",
    "skattanden": "skattande",
    "skattandena": "skattande",
    "skattandenas": "skattande",
    "skattandens": "skattande",
    "skattandes": "skattande",
    "skattandet": "skattande",
    "skattandets": "skattande",
    "skattar": "skatta",
    "skattas": "skatta",
    "skattat": "skatta",
    "skattats": "skatta",
    "skatte": "skatt",
    "skatteallergiska": "skatteallergisk",
    "skatteallergiskas": "skatteallergisk",
    "skatteallergiske": "skatteallergisk",
    "skatteallergiskes": "skatteallergisk",
    "skatteallergisks": "skatteallergisk",
    "skatteallergiskt": "skatteallergisk",
    "skatteallergiskts": "skatteallergisk",
    "skatteavdragen": "skatteavdrag",
    "skatteavdragens": "skatteavdrag",
    "skatteavdraget": "skatteavdrag",
    "skatteavdragets": "skatteavdrag",
    "skatteavdrags": "skatteavdrag",
    "skattebasen": "skattebas",
    "skattebasens": "skattebas",
    "skattebaser": "skattebas",
    "skattebaserna": "skattebas",
    "skattebasernas": "skattebas",
    "skattebasers": "skattebas",
    "skattebeloppen": "skattebelopp",
    "skattebeloppens": "skattebelopp",
    "skattebeloppet": "skattebelopp",
    "skattebeloppets": "skattebelopp",
    "skattebelopps": "skattebelopp",
    "skattebetalar": "skattebetalare",
    "skattebetalaren": "skattebetalare",
    "skattebetalarens": "skattebetalare",
    "skattebetalares": "skattebetalare",
    "skattebetalarna": "skattebetalare",
    "skattebetalarnas": "skattebetalare",
    "skattebetalningar": "skattebetalning",
    "skattebetalningarna": "skattebetalning",
    "skattebetalningarnas": "skattebetalning",
    "skattebetalningars": "skattebetalning",
    "skattebetalningen": "skattebetalning",
    "skattebetalningens": "skattebetalning",
    "skattebetalnings": "skattebetalning",
    "skattebond": "skattebonde",
    "skattebonden": "skattebonde",
    "skattebondens": "skattebonde",
    "skattebondes": "skattebonde",
    "skattebonds": "skattebonde",
    "skattebrotten": "skattebrott",
    "skattebrottens": "skattebrott",
    "skattebrottet": "skattebrott",
    "skattebrottets": "skattebrott",
    "skattebrotts": "skattebrott",
    "skattebönder": "skattebonde",
    "skattebönderna": "skattebonde",
    "skatteböndernas": "skattebonde",
    "skattebönders": "skattebonde",
    "skattefiffels": "skattefiffel",
    "skattefifflade": "skattefiffla",
    "skattefifflades": "skattefiffla",
    "skattefifflande": "skattefiffla",
    "skattefifflanden": "skattefifflande",
    "skattefifflandena": "skattefifflande",
    "skattefifflandenas": "skattefifflande",
    "skattefifflandens": "skattefifflande",
    "skattefifflandes": "skattefifflande",
    "skattefifflandet": "skattefifflande",
    "skattefifflandets": "skattefifflande",
    "skattefifflar": "skattefiffla",
    "skattefifflas": "skattefiffla",
    "skattefifflat": "skattefiffla",
    "skattefifflats": "skattefiffla",
    "skattefifflet": "skattefiffel",
    "skattefifflets": "skattefiffel",
    "skattefinansierade": "skattefinansierad",
    "skattefinansierades": "skattefinansierad",
    "skattefinansierads": "skattefinansierad",
    "skattefinansierat": "skattefinansierad",
    "skattefinansierats": "skattefinansierad",
    "skatteflykten": "skatteflykt",
    "skatteflyktens": "skatteflykt",
    "skatteflykts": "skatteflykt",
    "skattefria": "skattefri",
    "skattefriare": "skattefri",
    "skattefriares": "skattefri",
    "skattefrias": "skattefri",
    "skattefriast": "skattefri",
    "skattefriaste": "skattefri",
    "skattefriastes": "skattefri",
    "skattefriasts": "skattefri",
    "skattefrie": "skattefri",
    "skattefries": "skattefri",
    "skattefriheten": "skattefrihet",
    "skattefrihetens": "skattefrihet",
    "skattefriheter": "skattefrihet",
    "skattefriheterna": "skattefrihet",
    "skattefriheternas": "skattefrihet",
    "skattefriheters": "skattefrihet",
    "skattefrihets": "skattefrihet",
    "skattefris": "skattefri",
    "skattefritt": "skattefri",
    "skattefritts": "skattefri",
    "skattefrågan": "skattefråga",
    "skattefrågans": "skattefråga",
    "skattefrågas": "skattefråga",
    "skattefråge": "skattefråga",
    "skattefrågor": "skattefråga",
    "skattefrågorna": "skattefråga",
    "skattefrågornas": "skattefråga",
    "skattefrågors": "skattefråga",
    "skattefuskar": "skattefuskare",
    "skattefuskaren": "skattefuskare",
    "skattefuskarens": "skattefuskare",
    "skattefuskares": "skattefuskare",
    "skattefuskarna": "skattefuskare",
    "skattefuskarnas": "skattefuskare",
    "skattefusket": "skattefusk",
    "skattefuskets": "skattefusk",
    "skattefusks": "skattefusk",
    "skatteförmågan": "skatteförmåga",
    "skatteförmågans": "skatteförmåga",
    "skatteförmågas": "skatteförmåga",
    "skatteförmåge": "skatteförmåga",
    "skatteförmågor": "skatteförmåga",
    "skatteförmågorna": "skatteförmåga",
    "skatteförmågornas": "skatteförmåga",
    "skatteförmågors": "skatteförmåga",
    "skatteförslagen": "skatteförslag",
    "skatteförslagens": "skatteförslag",
    "skatteförslaget": "skatteförslag",
    "skatteförslagets": "skatteförslag",
    "skatteförslags": "skatteförslag",
    "skattehöjningar": "skattehöjning",
    "skattehöjningarna": "skattehöjning",
    "skattehöjningarnas": "skattehöjning",
    "skattehöjningars": "skattehöjning",
    "skattehöjningen": "skattehöjning",
    "skattehöjningens": "skattehöjning",
    "skattehöjnings": "skattehöjning",
    "skatteinbetalningar": "skatteinbetalning",
    "skatteinbetalningarna": "skatteinbetalning",
    "skatteinbetalningarnas": "skatteinbetalning",
    "skatteinbetalningars": "skatteinbetalning",
    "skatteinbetalningen": "skatteinbetalning",
    "skatteinbetalningens": "skatteinbetalning",
    "skatteinbetalnings": "skatteinbetalning",
    "skatteingenjören": "skatteingenjör",
    "skatteingenjörens": "skatteingenjör",
    "skatteingenjörer": "skatteingenjör",
    "skatteingenjörerna": "skatteingenjör",
    "skatteingenjörernas": "skatteingenjör",
    "skatteingenjörers": "skatteingenjör",
    "skatteingenjörn": "skatteingenjör",
    "skatteingenjörns": "skatteingenjör",
    "skatteingenjörs": "skatteingenjör",
    "skatteinkomsten": "skatteinkomst",
    "skatteinkomstens": "skatteinkomst",
    "skatteinkomster": "skatteinkomst",
    "skatteinkomsterna": "skatteinkomst",
    "skatteinkomsternas": "skatteinkomst",
    "skatteinkomsters": "skatteinkomst",
    "skatteinkomsts": "skatteinkomst",
    "skatteintäkten": "skatteintäkt",
    "skatteintäktens": "skatteintäkt",
    "skatteintäkter": "skatteintäkt",
    "skatteintäkterna": "skatteintäkt",
    "skatteintäkternas": "skatteintäkt",
    "skatteintäkters": "skatteintäkt",
    "skatteintäkts": "skatteintäkt",
    "skattekilar": "skattekil",
    "skattekilarna": "skattekil",
    "skattekilarnas": "skattekil",
    "skattekilars": "skattekil",
    "skattekilen": "skattekil",
    "skattekilens": "skattekil",
    "skattekils": "skattekil",
    "skatteklassen": "skatteklass",
    "skatteklassens": "skatteklass",
    "skatteklasser": "skatteklass",
    "skatteklasserna": "skatteklass",
    "skatteklassernas": "skatteklass",
    "skatteklassers": "skatteklass",
    "skattekorten": "skattekort",
    "skattekortens": "skattekort",
    "skattekortet": "skattekort",
    "skattekortets": "skattekort",
    "skattekorts": "skattekort",
    "skattekraften": "skattekraft",
    "skattekraftens": "skattekraft",
    "skattekrafter": "skattekraft",
    "skattekrafterna": "skattekraft",
    "skattekrafternas": "skattekraft",
    "skattekrafters": "skattekraft",
    "skattekrafts": "skattekraft",
    "skattekron": "skattekrona",
    "skattekronan": "skattekrona",
    "skattekronans": "skattekrona",
    "skattekronas": "skattekrona",
    "skattekrone": "skattekrona",
    "skattekronor": "skattekrona",
    "skattekronorna": "skattekrona",
    "skattekronornas": "skattekrona",
    "skattekronors": "skattekrona",
    "skattekrons": "skattekrona",
    "skattelagar": "skattelag",
    "skattelagarna": "skattelag",
    "skattelagarnas": "skattelag",
    "skattelagars": "skattelag",
    "skattelagen": "skattelag",
    "skattelagens": "skattelag",
    "skattelags": "skattelag",
    "skattelättnaden": "skattelättnad",
    "skattelättnadens": "skattelättnad",
    "skattelättnader": "skattelättnad",
    "skattelättnaderna": "skattelättnad",
    "skattelättnadernas": "skattelättnad",
    "skattelättnaders": "skattelättnad",
    "skattelättnads": "skattelättnad",
    "skattemedels": "skattemedel",
    "skattemedlen": "skattemedel",
    "skattemedlens": "skattemedel",
    "skattemedlet": "skattemedel",
    "skattemedlets": "skattemedel",
    "skattemoralen": "skattemoral",
    "skattemoralens": "skattemoral",
    "skattemoraler": "skattemoral",
    "skattemoralerna": "skattemoral",
    "skattemoralernas": "skattemoral",
    "skattemoralers": "skattemoral",
    "skattemorals": "skattemoral",
    "skattemyndigheten": "skattemyndighet",
    "skattemyndighetens": "skattemyndighet",
    "skattemyndigheter": "skattemyndighet",
    "skattemyndigheterna": "skattemyndighet",
    "skattemyndigheternas": "skattemyndighet",
    "skattemyndigheters": "skattemyndighet",
    "skattemyndighets": "skattemyndighet",
    "skattemärken": "skattemärke",
    "skattemärkena": "skattemärke",
    "skattemärkenas": "skattemärke",
    "skattemärkens": "skattemärke",
    "skattemärkes": "skattemärke",
    "skattemärket": "skattemärke",
    "skattemärkets": "skattemärke",
    "skattemässiga": "skattemässig",
    "skattemässigare": "skattemässig",
    "skattemässigares": "skattemässig",
    "skattemässigas": "skattemässig",
    "skattemässigast": "skattemässig",
    "skattemässigaste": "skattemässig",
    "skattemässigastes": "skattemässig",
    "skattemässigasts": "skattemässig",
    "skattemässige": "skattemässig",
    "skattemässiges": "skattemässig",
    "skattemässigs": "skattemässig",
    "skattemässigt": "skattemässig",
    "skattemässigts": "skattemässig",
    "skatten": "skatt",
    "skattenivåer": "skattenivå",
    "skattenivåerna": "skattenivå",
    "skattenivåernas": "skattenivå",
    "skattenivåers": "skattenivå",
    "skattenivån": "skattenivå",
    "skattenivåns": "skattenivå",
    "skattenivås": "skattenivå",
    "skattens": "skatt",
    "skatteparadisen": "skatteparadis",
    "skatteparadisens": "skatteparadis",
    "skatteparadiset": "skatteparadis",
    "skatteparadisets": "skatteparadis",
    "skattepengar": "skattepeng",
    "skattepengarna": "skattepeng",
    "skattepengarnas": "skattepeng",
    "skattepengars": "skattepeng",
    "skattepengen": "skattepeng",
    "skattepengens": "skattepeng",
    "skattepengs": "skattepeng",
    "skatteplanerad": "skatteplanera",
    "skatteplanerade": "skatteplanera",
    "skatteplanerades": "skatteplanera",
    "skatteplanerads": "skatteplanera",
    "skatteplanerande": "skatteplanera",
    "skatteplaneranden": "skatteplanerande",
    "skatteplanerandena": "skatteplanerande",
    "skatteplanerandenas": "skatteplanerande",
    "skatteplanerandens": "skatteplanerande",
    "skatteplanerandes": "skatteplanerande",
    "skatteplanerandet": "skatteplanerande",
    "skatteplanerandets": "skatteplanerande",
    "skatteplanerar": "skatteplanera",
    "skatteplaneras": "skatteplanera",
    "skatteplanerat": "skatteplanera",
    "skatteplanerats": "skatteplanera",
    "skatteplanerbara": "skatteplanerbar",
    "skatteplanerbarare": "skatteplanerbar",
    "skatteplanerbarares": "skatteplanerbar",
    "skatteplanerbaras": "skatteplanerbar",
    "skatteplanerbarast": "skatteplanerbar",
    "skatteplanerbaraste": "skatteplanerbar",
    "skatteplanerbarastes": "skatteplanerbar",
    "skatteplanerbarasts": "skatteplanerbar",
    "skatteplanerbare": "skatteplanerbar",
    "skatteplanerbares": "skatteplanerbar",
    "skatteplanerbarheten": "skatteplanerbarhet",
    "skatteplanerbarhetens": "skatteplanerbarhet",
    "skatteplanerbarhets": "skatteplanerbarhet",
    "skatteplanerbars": "skatteplanerbar",
    "skatteplanerbart": "skatteplanerbar",
    "skatteplanerbarts": "skatteplanerbar",
    "skatteplaneringar": "skatteplanering",
    "skatteplaneringarna": "skatteplanering",
    "skatteplaneringarnas": "skatteplanering",
    "skatteplaneringars": "skatteplanering",
    "skatteplaneringen": "skatteplanering",
    "skatteplaneringens": "skatteplanering",
    "skatteplanerings": "skatteplanering",
    "skattepliktiga": "skattepliktig",
    "skattepliktigare": "skattepliktig",
    "skattepliktigares": "skattepliktig",
    "skattepliktigas": "skattepliktig",
    "skattepliktigast": "skattepliktig",
    "skattepliktigaste": "skattepliktig",
    "skattepliktigastes": "skattepliktig",
    "skattepliktigasts": "skattepliktig",
    "skattepliktige": "skattepliktig",
    "skattepliktiges": "skattepliktig",
    "skattepliktigheten": "skattepliktighet",
    "skattepliktighetens": "skattepliktighet",
    "skattepliktighets": "skattepliktighet",
    "skattepliktigs": "skattepliktig",
    "skattepliktigt": "skattepliktig",
    "skattepliktigts": "skattepliktig",
    "skattepolitiken": "skattepolitik",
    "skattepolitikens": "skattepolitik",
    "skattepolitiks": "skattepolitik",
    "skattepolitiska": "skattepolitisk",
    "skattepolitiskas": "skattepolitisk",
    "skattepolitiske": "skattepolitisk",
    "skattepolitiskes": "skattepolitisk",
    "skattepolitisks": "skattepolitisk",
    "skattepolitiskt": "skattepolitisk",
    "skattepolitiskts": "skattepolitisk",
    "skattepopulismen": "skattepopulism",
    "skattepopulismens": "skattepopulism",
    "skattepopulisms": "skattepopulism",
    "skatteprincipen": "skatteprincip",
    "skatteprincipens": "skatteprincip",
    "skatteprinciper": "skatteprincip",
    "skatteprinciperna": "skatteprincip",
    "skatteprincipernas": "skatteprincip",
    "skatteprincipers": "skatteprincip",
    "skatteprincips": "skatteprincip",
    "skatteprotesten": "skatteprotest",
    "skatteprotestens": "skatteprotest",
    "skatteprotester": "skatteprotest",
    "skatteprotesterna": "skatteprotest",
    "skatteprotesternas": "skatteprotest",
    "skatteprotesters": "skatteprotest",
    "skatteprotests": "skatteprotest",
    "skatter": "skatt",
    "skattereduktionen": "skattereduktion",
    "skattereduktionens": "skattereduktion",
    "skattereduktioner": "skattereduktion",
    "skattereduktionerna": "skattereduktion",
    "skattereduktionernas": "skattereduktion",
    "skattereduktioners": "skattereduktion",
    "skattereduktions": "skattereduktion",
    "skattereformen": "skattereform",
    "skattereformens": "skattereform",
    "skattereformer": "skattereform",
    "skattereformerna": "skattereform",
    "skattereformernas": "skattereform",
    "skattereformers": "skattereform",
    "skattereforms": "skattereform",
    "skatteregeln": "skatteregel",
    "skatteregelns": "skatteregel",
    "skatteregels": "skatteregel",
    "skatteregler": "skatteregel",
    "skattereglerna": "skatteregel",
    "skattereglernas": "skatteregel",
    "skattereglers": "skatteregel",
    "skatterevolten": "skatterevolt",
    "skatterevoltens": "skatterevolt",
    "skatterevolter": "skatterevolt",
    "skatterevolterna": "skatterevolt",
    "skatterevolternas": "skatterevolt",
    "skatterevolters": "skatterevolt",
    "skatterevolts": "skatterevolt",
    "skatterna": "skatt",
    "skatternas": "skatt",
    "skatters": "skatt",
    "skattesatsen": "skattesats",
    "skattesatsens": "skattesats",
    "skattesatser": "skattesats",
    "skattesatserna": "skattesats",
    "skattesatsernas": "skattesats",
    "skattesatsers": "skattesats",
    "skatteskal": "skatteskala",
    "skatteskalan": "skatteskala",
    "skatteskalans": "skatteskala",
    "skatteskalas": "skatteskala",
    "skatteskale": "skatteskala",
    "skatteskalor": "skatteskala",
    "skatteskalorna": "skatteskala",
    "skatteskalornas": "skatteskala",
    "skatteskalors": "skatteskala",
    "skatteskals": "skatteskala",
    "skattesmitar": "skattesmitare",
    "skattesmitaren": "skattesmitare",
    "skattesmitarens": "skattesmitare",
    "skattesmitares": "skattesmitare",
    "skattesmitarna": "skattesmitare",
    "skattesmitarnas": "skattesmitare",
    "skattesystemen": "skattesystem",
    "skattesystemens": "skattesystem",
    "skattesystemet": "skattesystem",
    "skattesystemets": "skattesystem",
    "skattesystems": "skattesystem",
    "skattesänkningar": "skattesänkning",
    "skattesänkningarna": "skattesänkning",
    "skattesänkningarnas": "skattesänkning",
    "skattesänkningars": "skattesänkning",
    "skattesänkningen": "skattesänkning",
    "skattesänkningens": "skattesänkning",
    "skattesänknings": "skattesänkning",
    "skattetabellen": "skattetabell",
    "skattetabellens": "skattetabell",
    "skattetabeller": "skattetabell",
    "skattetabellerna": "skattetabell",
    "skattetabellernas": "skattetabell",
    "skattetabellers": "skattetabell",
    "skattetabells": "skattetabell",
    "skattetaken": "skattetak",
    "skattetakens": "skattetak",
    "skattetaket": "skattetak",
    "skattetakets": "skattetak",
    "skattetaks": "skattetak",
    "skattetilläggen": "skattetillägg",
    "skattetilläggens": "skattetillägg",
    "skattetillägget": "skattetillägg",
    "skattetilläggets": "skattetillägg",
    "skattetilläggs": "skattetillägg",
    "skattetrycken": "skattetryck",
    "skattetryckens": "skattetryck",
    "skattetrycket": "skattetryck",
    "skattetryckets": "skattetryck",
    "skattetrycks": "skattetryck",
    "skatteunderlagen": "skatteunderlag",
    "skatteunderlagens": "skatteunderlag",
    "skatteunderlaget": "skatteunderlag",
    "skatteunderlagets": "skatteunderlag",
    "skatteunderlags": "skatteunderlag",
    "skatteuppbörden": "skatteuppbörd",
    "skatteuppbördens": "skatteuppbörd",
    "skatteuppbörder": "skatteuppbörd",
    "skatteuppbörderna": "skatteuppbörd",
    "skatteuppbördernas": "skatteuppbörd",
    "skatteuppbörders": "skatteuppbörd",
    "skatteuppbörds": "skatteuppbörd",
    "skatteuppskoven": "skatteuppskov",
    "skatteuppskovens": "skatteuppskov",
    "skatteuppskovet": "skatteuppskov",
    "skatteuppskovets": "skatteuppskov",
    "skatteuppskovs": "skatteuppskov",
    "skatteutjämningar": "skatteutjämning",
    "skatteutjämningarna": "skatteutjämning",
    "skatteutjämningarnas": "skatteutjämning",
    "skatteutjämningars": "skatteutjämning",
    "skatteutjämningen": "skatteutjämning",
    "skatteutjämningens": "skatteutjämning",
    "skatteutjämnings": "skatteutjämning",
    "skatteutjämningssystemen": "skatteutjämningssystem",
    "skatteutjämningssystemens": "skatteutjämningssystem",
    "skatteutjämningssystemet": "skatteutjämningssystem",
    "skatteutjämningssystemets": "skatteutjämningssystem",
    "skatteutjämningssystems": "skatteutjämningssystem",
    "skatteuttagen": "skatteuttag",
    "skatteuttagens": "skatteuttag",
    "skatteuttaget": "skatteuttag",
    "skatteuttagets": "skatteuttag",
    "skatteuttags": "skatteuttag",
    "skatteverken": "skatteverk",
    "skatteverkens": "skatteverk",
    "skatteverket": "skatteverk",
    "skatteverkets": "skatteverk",
    "skatteverks": "skatteverk",
    "skatteväxlingar": "skatteväxling",
    "skatteväxlingarna": "skatteväxling",
    "skatteväxlingarnas": "skatteväxling",
    "skatteväxlingars": "skatteväxling",
    "skatteväxlingen": "skatteväxling",
    "skatteväxlingens": "skatteväxling",
    "skatteväxlings": "skatteväxling",
    "skatteärenden": "skatteärende",
    "skatteärendena": "skatteärende",
    "skatteärendenas": "skatteärende",
    "skatteärendens": "skatteärende",
    "skatteärendes": "skatteärende",
    "skatteärendet": "skatteärende",
    "skatteärendets": "skatteärende",
    "skatteåterbäringar": "skatteåterbäring",
    "skatteåterbäringarna": "skatteåterbäring",
    "skatteåterbäringarnas": "skatteåterbäring",
    "skatteåterbäringars": "skatteåterbäring",
    "skatteåterbäringen": "skatteåterbäring",
    "skatteåterbäringens": "skatteåterbäring",
    "skatteåterbärings": "skatteåterbäring",
    "skattgöm": "skattgömma",
    "skattgömman": "skattgömma",
    "skattgömmans": "skattgömma",
    "skattgömmas": "skattgömma",
    "skattgömme": "skattgömma",
    "skattgömmor": "skattgömma",
    "skattgömmorna": "skattgömma",
    "skattgömmornas": "skattgömma",
    "skattgömmors": "skattgömma",
    "skattgöms": "skattgömma",
    "skattkammar": "skattkammare",
    "skattkammaren": "skattkammare",
    "skattkammarens": "skattkammare",
    "skattkammares": "skattkammare",
    "skattkammarväxeln": "skattkammarväxel",
    "skattkammarväxelns": "skattkammarväxel",
    "skattkammarväxels": "skattkammarväxel",
    "skattkammarväxlar": "skattkammarväxel",
    "skattkammarväxlarna": "skattkammarväxel",
    "skattkammarväxlarnas": "skattkammarväxel",
    "skattkammarväxlars": "skattkammarväxel",
    "skattkamrar": "skattkammare",
    "skattkamrarna": "skattkammare",
    "skattkamrarnas": "skattkammare",
    "skattkamrars": "skattkammare",
    "skattla": "skattlägga",
    "skattlade": "skattlägga",
    "skattlades": "skattlägga",
    "skattlagd": "skattlägga",
    "skattlagda": "skattlägga",
    "skattlagdas": "skattlägga",
    "skattlagde": "skattlägga",
    "skattlagdes": "skattlägga",
    "skattlagds": "skattlägga",
    "skattlagt": "skattlägga",
    "skattlagts": "skattlägga",
    "skattlas": "skattlägga",
    "skattlägg": "skattlägga",
    "skattläggande": "skattlägga",
    "skattlägganden": "skattläggande",
    "skattläggandena": "skattläggande",
    "skattläggandenas": "skattläggande",
    "skattläggandens": "skattläggande",
    "skattläggandes": "skattläggande",
    "skattläggandet": "skattläggande",
    "skattläggandets": "skattläggande",
    "skattläggas": "skattlägga",
    "skattlägger": "skattlägga",
    "skattlägges": "skattlägga",
    "skattläggs": "skattlägga",
    "skattmasar": "skattmas",
    "skattmasarna": "skattmas",
    "skattmasarnas": "skattmas",
    "skattmasars": "skattmas",
    "skattmasen": "skattmas",
    "skattmasens": "skattmas",
    "skattmästar": "skattmästare",
    "skattmästaren": "skattmästare",
    "skattmästarens": "skattmästare",
    "skattmästares": "skattmästare",
    "skattmästarna": "skattmästare",
    "skattmästarnas": "skattmästare",
    "skatts": "skatt",
    "skattsedeln": "skattsedel",
    "skattsedelns": "skattsedel",
    "skattsedels": "skattsedel",
    "skattsedlar": "skattsedel",
    "skattsedlarna": "skattsedel",
    "skattsedlarnas": "skattsedel",
    "skattsedlars": "skattsedel",
    "skattskrev": "skattskriva",
    "skattskrevs": "skattskriva",
    "skattskriv": "skattskriva",
    "skattskrivande": "skattskriva",
    "skattskrivanden": "skattskrivande",
    "skattskrivandena": "skattskrivande",
    "skattskrivandenas": "skattskrivande",
    "skattskrivandens": "skattskrivande",
    "skattskrivandes": "skattskrivande",
    "skattskrivandet": "skattskrivande",
    "skattskrivandets": "skattskrivande",
    "skattskrivas": "skattskriva",
    "skattskrive": "skattskriva",
    "skattskriven": "skattskriva",
    "skattskrivens": "skattskriva",
    "skattskriver": "skattskriva",
    "skattskrives": "skattskriva",
    "skattskrivet": "skattskriva",
    "skattskrivets": "skattskriva",
    "skattskrivit": "skattskriva",
    "skattskrivits": "skattskriva",
    "skattskrivna": "skattskriva",
    "skattskrivnas": "skattskriva",
    "skattskrivne": "skattskriva",
    "skattskrivnes": "skattskriva",
    "skattskrivs": "skattskriva",
    "skattskyldiga": "skattskyldig",
    "skattskyldigare": "skattskyldig",
    "skattskyldigares": "skattskyldig",
    "skattskyldigas": "skattskyldig",
    "skattskyldigast": "skattskyldig",
    "skattskyldigaste": "skattskyldig",
    "skattskyldigastes": "skattskyldig",
    "skattskyldigasts": "skattskyldig",
    "skattskyldige": "skattskyldig",
    "skattskyldiges": "skattskyldig",
    "skattskyldigheten": "skattskyldighet",
    "skattskyldighetens": "skattskyldighet",
    "skattskyldighets": "skattskyldighet",
    "skattskyldigs": "skattskyldig",
    "skattskyldigt": "skattskyldig",
    "skattskyldigts": "skattskyldig",
    "skattsökar": "skattsökare",
    "skattsökaren": "skattsökare",
    "skattsökarens": "skattsökare",
    "skattsökares": "skattsökare",
    "skattsökarna": "skattsökare",
    "skattsökarnas": "skattsökare",
    "skav": "skava",
    "skavande": "skava",
    "skavanden": "skavande",
    "skavandena": "skavande",
    "skavandenas": "skavande",
    "skavandens": "skavande",
    "skavandes": "skavande",
    "skavandet": "skavande",
    "skavandets": "skavande",
    "skavanken": "skavank",
    "skavankens": "skavank",
    "skavanker": "skavank",
    "skavankerna": "skavank",
    "skavankernas": "skavank",
    "skavankers": "skavank",
    "skavanks": "skavank",
    "skavas": "skava",
    "skavd": "skava",
    "skavda": "skava",
    "skavdas": "skava",
    "skavde": "skava",
    "skavdes": "skava",
    "skavds": "skava",
    "skaver": "skava",
    "skaves": "skava",
    "skavllerpressen": "skavllerpress",
    "skavllerpressens": "skavllerpress",
    "skavs": "skava",
    "skavskydden": "skavskydd",
    "skavskyddens": "skavskydd",
    "skavskyddet": "skavskydd",
    "skavskyddets": "skavskydd",
    "skavskydds": "skavskydd",
    "skavsåren": "skavsår",
    "skavsårens": "skavsår",
    "skavsåret": "skavsår",
    "skavsårets": "skavsår",
    "skavsårs": "skavsår",
    "skavt": "skava",
    "skavts": "skava",
    "skedad": "skeda",
    "skedade": "skeda",
    "skedades": "skeda",
    "skedads": "skeda",
    "skedande": "skeda",
    "skedanden": "skedande",
    "skedandena": "skedande",
    "skedandenas": "skedande",
    "skedandens": "skedande",
    "skedandes": "skedande",
    "skedandet": "skedande",
    "skedandets": "skedande",
    "skedands": "skedand",
    "skedar": "skeda",
    "skedarna": "sked",
    "skedarnas": "sked",
    "skedars": "sked",
    "skedas": "skeda",
    "skedat": "skeda",
    "skedats": "skeda",
    "skedd": "ske",
    "skedda": "ske",
    "skeddas": "ske",
    "skedde": "ske",
    "skeddes": "ske",
    "skeddragen": "skeddrag",
    "skeddragens": "skeddrag",
    "skeddraget": "skeddrag",
    "skeddragets": "skeddrag",
    "skeddrags": "skeddrag",
    "skedds": "ske",
    "skeden": "skede",
    "skedena": "skede",
    "skedenas": "skede",
    "skedens": "skede",
    "skedes": "skede",
    "skedet": "skede",
    "skedets": "skede",
    "skeds": "skede",
    "skedstorkar": "skedstork",
    "skedstorkarna": "skedstork",
    "skedstorkarnas": "skedstork",
    "skedstorkars": "skedstork",
    "skedstorken": "skedstork",
    "skedstorkens": "skedstork",
    "skedstorks": "skedstork",
    "skedänder": "skedand",
    "skedänderna": "skedand",
    "skedändernas": "skedand",
    "skedänders": "skedand",
    "skeende": "ske",
    "skeenden": "skeende",
    "skeendena": "skeende",
    "skeendenas": "skeende",
    "skeendens": "skeende",
    "skeendes": "skeende",
    "skeendet": "skeende",
    "skeendets": "skeende",
    "skejt": "skejta",
    "skejtade": "skejta",
    "skejtades": "skejta",
    "skejtande": "skejta",
    "skejtanden": "skejtande",
    "skejtandena": "skejtande",
    "skejtandenas": "skejtande",
    "skejtandens": "skejtande",
    "skejtandes": "skejtande",
    "skejtandet": "skejtande",
    "skejtandets": "skejtande",
    "skejtar": "skejta",
    "skejtas": "skejta",
    "skejtat": "skejta",
    "skejtats": "skejta",
    "skel": "skela",
    "skelade": "skela",
    "skelades": "skela",
    "skelande": "skela",
    "skelanden": "skelande",
    "skelandena": "skelande",
    "skelandenas": "skelande",
    "skelandens": "skelande",
    "skelandes": "skelande",
    "skelandet": "skelande",
    "skelandets": "skelande",
    "skelar": "skela",
    "skelas": "skela",
    "skelat": "skela",
    "skelats": "skela",
    "skeletons": "skeleton",
    "skeletten": "skelett",
    "skelettens": "skelett",
    "skelettet": "skelett",
    "skelettets": "skelett",
    "skelettmuskeln": "skelettmuskel",
    "skelettmuskelns": "skelettmuskel",
    "skelettmuskels": "skelettmuskel",
    "skelettmuskler": "skelettmuskel",
    "skelettmusklerna": "skelettmuskel",
    "skelettmusklernas": "skelettmuskel",
    "skelettmusklers": "skelettmuskel",
    "skelettmuskulaturen": "skelettmuskulatur",
    "skelettmuskulaturens": "skelettmuskulatur",
    "skelettmuskulaturs": "skelettmuskulatur",
    "skeletts": "skelett",
    "skelögda": "skelögd",
    "skelögdare": "skelögd",
    "skelögdares": "skelögd",
    "skelögdas": "skelögd",
    "skelögdast": "skelögd",
    "skelögdaste": "skelögd",
    "skelögdastes": "skelögd",
    "skelögdasts": "skelögd",
    "skelögde": "skelögd",
    "skelögdes": "skelögd",
    "skelögdheten": "skelögdhet",
    "skelögdhetens": "skelögdhet",
    "skelögdheter": "skelögdhet",
    "skelögdheterna": "skelögdhet",
    "skelögdheternas": "skelögdhet",
    "skelögdheters": "skelögdhet",
    "skelögdhets": "skelögdhet",
    "skelögds": "skelögd",
    "skelögt": "skelögd",
    "skelögts": "skelögd",
    "skelörten": "skelört",
    "skelörtens": "skelört",
    "skelörts": "skelört",
    "sken": "skina",
    "skenad": "skena",
    "skenade": "skena",
    "skenades": "skena",
    "skenads": "skena",
    "skenan": "skena",
    "skenande": "skena",
    "skenanden": "skenande",
    "skenandena": "skenande",
    "skenandenas": "skenande",
    "skenandens": "skenande",
    "skenandes": "skenande",
    "skenandet": "skenande",
    "skenandets": "skenande",
    "skenans": "skena",
    "skenar": "skena",
    "skenas": "skena",
    "skenat": "skena",
    "skenats": "skena",
    "skenavrättningar": "skenavrättning",
    "skenavrättningarna": "skenavrättning",
    "skenavrättningarnas": "skenavrättning",
    "skenavrättningars": "skenavrättning",
    "skenavrättningen": "skenavrättning",
    "skenavrättningens": "skenavrättning",
    "skenavrättnings": "skenavrättning",
    "skenbara": "skenbar",
    "skenbarare": "skenbar",
    "skenbarares": "skenbar",
    "skenbaras": "skenbar",
    "skenbarast": "skenbar",
    "skenbaraste": "skenbar",
    "skenbarastes": "skenbar",
    "skenbarasts": "skenbar",
    "skenbare": "skenbar",
    "skenbares": "skenbar",
    "skenbarheten": "skenbarhet",
    "skenbarhetens": "skenbarhet",
    "skenbarhets": "skenbarhet",
    "skenbars": "skenbar",
    "skenbart": "skenbar",
    "skenbarts": "skenbar",
    "skenbenen": "skenben",
    "skenbenens": "skenben",
    "skenbenet": "skenben",
    "skenbenets": "skenben",
    "skenbens": "skenben",
    "skenbilden": "skenbild",
    "skenbildens": "skenbild",
    "skenbilder": "skenbild",
    "skenbilderna": "skenbild",
    "skenbildernas": "skenbild",
    "skenbilders": "skenbild",
    "skenbilds": "skenbild",
    "skendränkningar": "skendränkning",
    "skendränkningarna": "skendränkning",
    "skendränkningarnas": "skendränkning",
    "skendränkningars": "skendränkning",
    "skendränkningen": "skendränkning",
    "skendränkningens": "skendränkning",
    "skendränknings": "skendränkning",
    "skendöda": "skendöd",
    "skendödare": "skendöd",
    "skendödares": "skendöd",
    "skendödas": "skendöd",
    "skendödast": "skendöd",
    "skendödaste": "skendöd",
    "skendödastes": "skendöd",
    "skendödasts": "skendöd",
    "skendöde": "skendöd",
    "skendödes": "skendöd",
    "skendödheten": "skendödhet",
    "skendödhetens": "skendödhet",
    "skendödhets": "skendödhet",
    "skendöds": "skendöd",
    "skendött": "skendöd",
    "skendötts": "skendöd",
    "skene": "skena",
    "skenen": "sken",
    "skenens": "sken",
    "skenet": "sken",
    "skenets": "sken",
    "skenfrukten": "skenfrukt",
    "skenfruktens": "skenfrukt",
    "skenfrukter": "skenfrukt",
    "skenfrukterna": "skenfrukt",
    "skenfrukternas": "skenfrukt",
    "skenfrukters": "skenfrukt",
    "skenfrukts": "skenfrukt",
    "skenfäktningar": "skenfäktning",
    "skenfäktningarna": "skenfäktning",
    "skenfäktningarnas": "skenfäktning",
    "skenfäktningars": "skenfäktning",
    "skenfäktningen": "skenfäktning",
    "skenfäktningens": "skenfäktning",
    "skenfäktnings": "skenfäktning",
    "skengestalten": "skengestalt",
    "skengestaltens": "skengestalt",
    "skengestalter": "skengestalt",
    "skengestalterna": "skengestalt",
    "skengestalternas": "skengestalt",
    "skengestalters": "skengestalt",
    "skengestalts": "skengestalt",
    "skenheliga": "skenhelig",
    "skenheligare": "skenhelig",
    "skenheligares": "skenhelig",
    "skenheligas": "skenhelig",
    "skenheligast": "skenhelig",
    "skenheligaste": "skenhelig",
    "skenheligastes": "skenhelig",
    "skenheligasts": "skenhelig",
    "skenhelige": "skenhelig",
    "skenheliges": "skenhelig",
    "skenheligheten": "skenhelighet",
    "skenhelighetens": "skenhelighet",
    "skenheligheter": "skenhelighet",
    "skenheligheterna": "skenhelighet",
    "skenheligheternas": "skenhelighet",
    "skenheligheters": "skenhelighet",
    "skenhelighets": "skenhelighet",
    "skenheligs": "skenhelig",
    "skenheligt": "skenhelig",
    "skenheligts": "skenhelig",
    "skenhändelsen": "skenhändelse",
    "skenhändelsens": "skenhändelse",
    "skenhändelser": "skenhändelse",
    "skenhändelserna": "skenhändelse",
    "skenhändelsernas": "skenhändelse",
    "skenhändelsers": "skenhändelse",
    "skenhändelses": "skenhändelse",
    "skenor": "skena",
    "skenorna": "skena",
    "skenornas": "skena",
    "skenors": "skena",
    "skenrättegångar": "skenrättegång",
    "skenrättegångarna": "skenrättegång",
    "skenrättegångarnas": "skenrättegång",
    "skenrättegångars": "skenrättegång",
    "skenrättegången": "skenrättegång",
    "skenrättegångens": "skenrättegång",
    "skenrättegångs": "skenrättegång",
    "skens": "skina",
    "skenvärldar": "skenvärld",
    "skenvärldarna": "skenvärld",
    "skenvärldarnas": "skenvärld",
    "skenvärldars": "skenvärld",
    "skenvärlden": "skenvärld",
    "skenvärldens": "skenvärld",
    "skenvärlds": "skenvärld",
    "skenäktenskapen": "skenäktenskap",
    "skenäktenskapens": "skenäktenskap",
    "skenäktenskapet": "skenäktenskap",
    "skenäktenskapets": "skenäktenskap",
    "skenäktenskaps": "skenäktenskap",
    "skepnaden": "skepnad",
    "skepnadens": "skepnad",
    "skepnader": "skepnad",
    "skepnaderna": "skepnad",
    "skepnadernas": "skepnad",
    "skepnaders": "skepnad",
    "skepnads": "skepnad",
    "skepp": "skeppa",
    "skeppad": "skeppa",
    "skeppade": "skeppa",
    "skeppades": "skeppa",
    "skeppads": "skeppa",
    "skeppande": "skeppa",
    "skeppanden": "skeppande",
    "skeppandena": "skeppande",
    "skeppandenas": "skeppande",
    "skeppandens": "skeppande",
    "skeppandes": "skeppande",
    "skeppandet": "skeppande",
    "skeppandets": "skeppande",
    "skeppar": "skeppare",
    "skepparbreven": "skepparbrev",
    "skepparbrevens": "skepparbrev",
    "skepparbrevet": "skepparbrev",
    "skepparbrevets": "skepparbrev",
    "skepparbrevs": "skepparbrev",
    "skepparen": "skeppare",
    "skepparens": "skeppare",
    "skeppares": "skeppare",
    "skepparexamens": "skepparexamen",
    "skepparexamina": "skepparexamen",
    "skepparexaminas": "skepparexamen",
    "skepparhistorian": "skepparhistoria",
    "skepparhistorians": "skepparhistoria",
    "skepparhistorias": "skepparhistoria",
    "skepparhistorien": "skepparhistoria",
    "skepparhistoriens": "skepparhistoria",
    "skepparhistorier": "skepparhistoria",
    "skepparhistorierna": "skepparhistoria",
    "skepparhistoriernas": "skepparhistoria",
    "skepparhistoriers": "skepparhistoria",
    "skepparkransar": "skepparkrans",
    "skepparkransarna": "skepparkrans",
    "skepparkransarnas": "skepparkrans",
    "skepparkransars": "skepparkrans",
    "skepparkransen": "skepparkrans",
    "skepparkransens": "skepparkrans",
    "skepparna": "skeppare",
    "skepparnas": "skeppare",
    "skeppas": "skeppa",
    "skeppat": "skeppa",
    "skeppats": "skeppa",
    "skeppen": "skepp",
    "skeppens": "skepp",
    "skeppet": "skepp",
    "skeppets": "skepp",
    "skepplistan": "skepplista",
    "skepplistans": "skepplista",
    "skepplistas": "skepplista",
    "skeppliste": "skepplista",
    "skepplistor": "skepplista",
    "skepplistorna": "skepplista",
    "skepplistornas": "skepplista",
    "skepplistors": "skepplista",
    "skepps": "skepp",
    "skeppsapoteken": "skeppsapotek",
    "skeppsapotekens": "skeppsapotek",
    "skeppsapoteket": "skeppsapotek",
    "skeppsapotekets": "skeppsapotek",
    "skeppsapoteks": "skeppsapotek",
    "skeppsbroar": "skeppsbro",
    "skeppsbroarna": "skeppsbro",
    "skeppsbroarnas": "skeppsbro",
    "skeppsbroars": "skeppsbro",
    "skeppsbron": "skeppsbro",
    "skeppsbrons": "skeppsbro",
    "skeppsbros": "skeppsbro",
    "skeppsbrotten": "skeppsbrott",
    "skeppsbrottens": "skeppsbrott",
    "skeppsbrottet": "skeppsbrott",
    "skeppsbrottets": "skeppsbrott",
    "skeppsbrotts": "skeppsbrott",
    "skeppsbrutens": "skeppsbruten",
    "skeppsbrutet": "skeppsbruten",
    "skeppsbrutets": "skeppsbruten",
    "skeppsbrutna": "skeppsbruten",
    "skeppsbrutnare": "skeppsbruten",
    "skeppsbrutnares": "skeppsbruten",
    "skeppsbrutnas": "skeppsbruten",
    "skeppsbrutnast": "skeppsbruten",
    "skeppsbrutnaste": "skeppsbruten",
    "skeppsbrutnastes": "skeppsbruten",
    "skeppsbrutnasts": "skeppsbruten",
    "skeppsbrutne": "skeppsbruten",
    "skeppsbrutnes": "skeppsbruten",
    "skeppsbyggerier": "skeppsbyggeri",
    "skeppsbyggerierna": "skeppsbyggeri",
    "skeppsbyggeriernas": "skeppsbyggeri",
    "skeppsbyggeriers": "skeppsbyggeri",
    "skeppsbyggeriet": "skeppsbyggeri",
    "skeppsbyggeriets": "skeppsbyggeri",
    "skeppsbyggeris": "skeppsbyggeri",
    "skeppsbyggerit": "skeppsbyggeri",
    "skeppsbyggerits": "skeppsbyggeri",
    "skeppsbåtar": "skeppsbåt",
    "skeppsbåtarna": "skeppsbåt",
    "skeppsbåtarnas": "skeppsbåt",
    "skeppsbåtars": "skeppsbåt",
    "skeppsbåten": "skeppsbåt",
    "skeppsbåtens": "skeppsbåt",
    "skeppsbåts": "skeppsbåt",
    "skeppsgoss": "skeppsgosse",
    "skeppsgossar": "skeppsgosse",
    "skeppsgossarna": "skeppsgosse",
    "skeppsgossarnas": "skeppsgosse",
    "skeppsgossars": "skeppsgosse",
    "skeppsgossen": "skeppsgosse",
    "skeppsgossens": "skeppsgosse",
    "skeppsgosses": "skeppsgosse",
    "skeppshandeln": "skeppshandel",
    "skeppshandelns": "skeppshandel",
    "skeppshandels": "skeppshandel",
    "skeppsklarerar": "skeppsklarerare",
    "skeppsklareraren": "skeppsklarerare",
    "skeppsklarerarens": "skeppsklarerare",
    "skeppsklarerares": "skeppsklarerare",
    "skeppsklarerarna": "skeppsklarerare",
    "skeppsklarerarnas": "skeppsklarerare",
    "skeppsklock": "skeppsklocka",
    "skeppsklockan": "skeppsklocka",
    "skeppsklockans": "skeppsklocka",
    "skeppsklockas": "skeppsklocka",
    "skeppsklocke": "skeppsklocka",
    "skeppsklockor": "skeppsklocka",
    "skeppsklockorna": "skeppsklocka",
    "skeppsklockornas": "skeppsklocka",
    "skeppsklockors": "skeppsklocka",
    "skeppsklocks": "skeppsklocka",
    "skeppslagen": "skeppslag",
    "skeppslagens": "skeppslag",
    "skeppslaget": "skeppslag",
    "skeppslagets": "skeppslag",
    "skeppslags": "skeppslag",
    "skeppsljusen": "skeppsljus",
    "skeppsljusens": "skeppsljus",
    "skeppsljuset": "skeppsljus",
    "skeppsljusets": "skeppsljus",
    "skeppsmaskar": "skeppsmask",
    "skeppsmaskarna": "skeppsmask",
    "skeppsmaskarnas": "skeppsmask",
    "skeppsmaskars": "skeppsmask",
    "skeppsmasken": "skeppsmask",
    "skeppsmaskens": "skeppsmask",
    "skeppsmasks": "skeppsmask",
    "skeppsmäklar": "skeppsmäklare",
    "skeppsmäklaren": "skeppsmäklare",
    "skeppsmäklarens": "skeppsmäklare",
    "skeppsmäklares": "skeppsmäklare",
    "skeppsmäklarna": "skeppsmäklare",
    "skeppsmäklarnas": "skeppsmäklare",
    "skeppsmätningar": "skeppsmätning",
    "skeppsmätningarna": "skeppsmätning",
    "skeppsmätningarnas": "skeppsmätning",
    "skeppsmätningars": "skeppsmätning",
    "skeppsmätningen": "skeppsmätning",
    "skeppsmätningens": "skeppsmätning",
    "skeppsmätnings": "skeppsmätning",
    "skeppspojk": "skeppspojke",
    "skeppspojkar": "skeppspojke",
    "skeppspojkarna": "skeppspojke",
    "skeppspojkarnas": "skeppspojke",
    "skeppspojkars": "skeppspojke",
    "skeppspojken": "skeppspojke",
    "skeppspojkens": "skeppspojke",
    "skeppspojkes": "skeppspojke",
    "skeppspojks": "skeppspojke",
    "skeppsprovianten": "skeppsproviant",
    "skeppsproviantens": "skeppsproviant",
    "skeppsproviants": "skeppsproviant",
    "skeppsredar": "skeppsredare",
    "skeppsredaren": "skeppsredare",
    "skeppsredarens": "skeppsredare",
    "skeppsredares": "skeppsredare",
    "skeppsredarna": "skeppsredare",
    "skeppsredarnas": "skeppsredare",
    "skeppsskorp": "skeppsskorpa",
    "skeppsskorpan": "skeppsskorpa",
    "skeppsskorpans": "skeppsskorpa",
    "skeppsskorpas": "skeppsskorpa",
    "skeppsskorpe": "skeppsskorpa",
    "skeppsskorpor": "skeppsskorpa",
    "skeppsskorporna": "skeppsskorpa",
    "skeppsskorpornas": "skeppsskorpa",
    "skeppsskorpors": "skeppsskorpa",
    "skeppsskorps": "skeppsskorpa",
    "skeppssättningar": "skeppssättning",
    "skeppssättningarna": "skeppssättning",
    "skeppssättningarnas": "skeppssättning",
    "skeppssättningars": "skeppssättning",
    "skeppssättningen": "skeppssättning",
    "skeppssättningens": "skeppssättning",
    "skeppssättnings": "skeppssättning",
    "skeppsvarven": "skeppsvarv",
    "skeppsvarvens": "skeppsvarv",
    "skeppsvarvet": "skeppsvarv",
    "skeppsvarvets": "skeppsvarv",
    "skeppsvarvs": "skeppsvarv",
    "skeppunden": "skeppund",
    "skeppundens": "skeppund",
    "skeppundet": "skeppund",
    "skeppundets": "skeppund",
    "skeppunds": "skeppund",
    "skepsisen": "skepsis",
    "skepsisens": "skepsis",
    "skepticismen": "skepticism",
    "skepticismens": "skepticism",
    "skepticismer": "skepticism",
    "skepticismerna": "skepticism",
    "skepticismernas": "skepticism",
    "skepticismers": "skepticism",
    "skepticisms": "skepticism",
    "skeptikern": "skeptiker",
    "skeptikerna": "skeptiker",
    "skeptikernas": "skeptiker",
    "skeptikerns": "skeptiker",
    "skeptikers": "skeptiker",
    "skeptiska": "skeptisk",
    "skeptiskare": "skeptisk",
    "skeptiskares": "skeptisk",
    "skeptiskas": "skeptisk",
    "skeptiskast": "skeptisk",
    "skeptiskaste": "skeptisk",
    "skeptiskastes": "skeptisk",
    "skeptiskasts": "skeptisk",
    "skeptiske": "skeptisk",
    "skeptiskes": "skeptisk",
    "skeptisks": "skeptisk",
    "skeptiskt": "skeptisk",
    "skeptiskts": "skeptisk",
    "sker": "ske",
    "skes": "ske",
    "sket": "skita",
    "sketchen": "sketch",
    "sketchens": "sketch",
    "sketcher": "sketch",
    "sketcherna": "sketch",
    "sketchernas": "sketch",
    "sketchers": "sketch",
    "sketchs": "sketch",
    "sketens": "sketen",
    "sketet": "sketen",
    "sketets": "sketen",
    "sketna": "sketen",
    "sketnare": "sketen",
    "sketnares": "sketen",
    "sketnas": "sketen",
    "sketnast": "sketen",
    "sketnaste": "sketen",
    "sketnastes": "sketen",
    "sketnasts": "sketen",
    "sketne": "sketen",
    "sketnes": "sketen",
    "skets": "skita",
    "skett": "ske",
    "sketts": "ske",
    "skeva": "skev",
    "skevad": "skeva",
    "skevade": "skeva",
    "skevades": "skeva",
    "skevads": "skeva",
    "skevande": "skeva",
    "skevanden": "skevande",
    "skevandena": "skevande",
    "skevandenas": "skevande",
    "skevandens": "skevande",
    "skevandes": "skevande",
    "skevandet": "skevande",
    "skevandets": "skevande",
    "skevar": "skeva",
    "skevare": "skev",
    "skevares": "skev",
    "skevas": "skeva",
    "skevast": "skev",
    "skevaste": "skev",
    "skevastes": "skev",
    "skevasts": "skev",
    "skevat": "skeva",
    "skevats": "skeva",
    "skeve": "skev",
    "skeves": "skev",
    "skevheten": "skevhet",
    "skevhetens": "skevhet",
    "skevheter": "skevhet",
    "skevheterna": "skevhet",
    "skevheternas": "skevhet",
    "skevheters": "skevhet",
    "skevhets": "skevhet",
    "skevningsroderna": "skevningsroder",
    "skevningsrodernas": "skevningsroder",
    "skevningsroders": "skevningsroder",
    "skevningsrodren": "skevningsroder",
    "skevningsrodrens": "skevningsroder",
    "skevningsrodret": "skevningsroder",
    "skevningsrodrets": "skevningsroder",
    "skevrad": "skevra",
    "skevrade": "skevra",
    "skevrades": "skevra",
    "skevrads": "skevra",
    "skevrande": "skevra",
    "skevranden": "skevrande",
    "skevrandena": "skevrande",
    "skevrandenas": "skevrande",
    "skevrandens": "skevrande",
    "skevrandes": "skevrande",
    "skevrandet": "skevrande",
    "skevrandets": "skevrande",
    "skevrar": "skevra",
    "skevras": "skevra",
    "skevrat": "skevra",
    "skevrats": "skevra",
    "skevroderna": "skevroder",
    "skevrodernas": "skevroder",
    "skevroders": "skevroder",
    "skevrodren": "skevroder",
    "skevrodrens": "skevroder",
    "skevrodret": "skevroder",
    "skevrodrets": "skevroder",
    "skevs": "skev",
    "skevt": "skev",
    "skevts": "skev",
    "skick": "skicka",
    "skickad": "skicka",
    "skickade": "skickad",
    "skickades": "skickad",
    "skickads": "skickad",
    "skickande": "skicka",
    "skickanden": "skickande",
    "skickandena": "skickande",
    "skickandenas": "skickande",
    "skickandens": "skickande",
    "skickandes": "skickande",
    "skickandet": "skickande",
    "skickandets": "skickande",
    "skickar": "skicka",
    "skickas": "skicka",
    "skickat": "skickad",
    "skickats": "skickad",
    "skicke": "skicka",
    "skickebuden": "skickebud",
    "skickebudens": "skickebud",
    "skickebudet": "skickebud",
    "skickebudets": "skickebud",
    "skickebuds": "skickebud",
    "skickelsedigers": "skickelsediger",
    "skickelsedigert": "skickelsediger",
    "skickelsedigerts": "skickelsediger",
    "skickelsedigra": "skickelsediger",
    "skickelsedigrare": "skickelsediger",
    "skickelsedigrares": "skickelsediger",
    "skickelsedigras": "skickelsediger",
    "skickelsedigrast": "skickelsediger",
    "skickelsedigraste": "skickelsediger",
    "skickelsedigrastes": "skickelsediger",
    "skickelsedigrasts": "skickelsediger",
    "skickelsedigre": "skickelsediger",
    "skickelsedigres": "skickelsediger",
    "skickelsen": "skickelse",
    "skickelsens": "skickelse",
    "skickelser": "skickelse",
    "skickelserna": "skickelse",
    "skickelsernas": "skickelse",
    "skickelsers": "skickelse",
    "skickelses": "skickelse",
    "skicken": "skick",
    "skickens": "skick",
    "skicket": "skick",
    "skickets": "skick",
    "skickliga": "skicklig",
    "skickligare": "skicklig",
    "skickligares": "skicklig",
    "skickligas": "skicklig",
    "skickligast": "skicklig",
    "skickligaste": "skicklig",
    "skickligastes": "skicklig",
    "skickligasts": "skicklig",
    "skicklige": "skicklig",
    "skickliges": "skicklig",
    "skickligheten": "skicklighet",
    "skicklighetens": "skicklighet",
    "skickligheter": "skicklighet",
    "skickligheterna": "skicklighet",
    "skickligheternas": "skicklighet",
    "skickligheters": "skicklighet",
    "skicklighets": "skicklighet",
    "skickligs": "skicklig",
    "skickligt": "skicklig",
    "skickligts": "skicklig",
    "skicks": "skick",
    "skid": "skida",
    "skidade": "skida",
    "skidades": "skida",
    "skidan": "skida",
    "skidande": "skida",
    "skidanden": "skidande",
    "skidandena": "skidande",
    "skidandenas": "skidande",
    "skidandens": "skidande",
    "skidandes": "skidande",
    "skidandet": "skidande",
    "skidandets": "skidande",
    "skidanläggningar": "skidanläggning",
    "skidanläggningarna": "skidanläggning",
    "skidanläggningarnas": "skidanläggning",
    "skidanläggningars": "skidanläggning",
    "skidanläggningen": "skidanläggning",
    "skidanläggningens": "skidanläggning",
    "skidanläggnings": "skidanläggning",
    "skidans": "skida",
    "skidar": "skida",
    "skidas": "skida",
    "skidat": "skida",
    "skidats": "skida",
    "skidback": "skidbacke",
    "skidbackar": "skidbacke",
    "skidbackarna": "skidbacke",
    "skidbackarnas": "skidbacke",
    "skidbackars": "skidbacke",
    "skidbacken": "skidbacke",
    "skidbackens": "skidbacke",
    "skidbackes": "skidbacke",
    "skidbacks": "skidbacke",
    "skide": "skida",
    "skidfynden": "skidfynd",
    "skidfyndens": "skidfynd",
    "skidfyndet": "skidfynd",
    "skidfyndets": "skidfynd",
    "skidfynds": "skidfynd",
    "skidhandsk": "skidhandske",
    "skidhandskar": "skidhandske",
    "skidhandskarna": "skidhandske",
    "skidhandskarnas": "skidhandske",
    "skidhandskars": "skidhandske",
    "skidhandsken": "skidhandske",
    "skidhandskens": "skidhandske",
    "skidhandskes": "skidhandske",
    "skidhjälmar": "skidhjälm",
    "skidhjälmarna": "skidhjälm",
    "skidhjälmarnas": "skidhjälm",
    "skidhjälmars": "skidhjälm",
    "skidhjälmen": "skidhjälm",
    "skidhjälmens": "skidhjälm",
    "skidhjälms": "skidhjälm",
    "skidhoppningar": "skidhoppning",
    "skidhoppningarna": "skidhoppning",
    "skidhoppningarnas": "skidhoppning",
    "skidhoppningars": "skidhoppning",
    "skidhoppningen": "skidhoppning",
    "skidhoppningens": "skidhoppning",
    "skidhoppnings": "skidhoppning",
    "skidliftar": "skidlift",
    "skidliftarna": "skidlift",
    "skidliftarnas": "skidlift",
    "skidliftars": "skidlift",
    "skidliften": "skidlift",
    "skidliftens": "skidlift",
    "skidlifter": "skidlift",
    "skidlifterna": "skidlift",
    "skidlifternas": "skidlift",
    "skidlifters": "skidlift",
    "skidlifts": "skidlift",
    "skidlöpningar": "skidlöpning",
    "skidlöpningarna": "skidlöpning",
    "skidlöpningarnas": "skidlöpning",
    "skidlöpningars": "skidlöpning",
    "skidlöpningen": "skidlöpning",
    "skidlöpningens": "skidlöpning",
    "skidlöpnings": "skidlöpning",
    "skidor": "skida",
    "skidorna": "skida",
    "skidornas": "skida",
    "skidors": "skida",
    "skidorten": "skidort",
    "skidortens": "skidort",
    "skidorter": "skidort",
    "skidorterna": "skidort",
    "skidorternas": "skidort",
    "skidorters": "skidort",
    "skidorts": "skidort",
    "skidrade": "skidra",
    "skidrades": "skidra",
    "skidrande": "skidra",
    "skidrandes": "skidra",
    "skidrar": "skidra",
    "skidras": "skidra",
    "skidrat": "skidra",
    "skidrats": "skidra",
    "skidresan": "skidresa",
    "skidresans": "skidresa",
    "skidresas": "skidresa",
    "skidrese": "skidresa",
    "skidresor": "skidresa",
    "skidresorna": "skidresa",
    "skidresornas": "skidresa",
    "skidresors": "skidresa",
    "skids": "skida",
    "skidsemestern": "skidsemester",
    "skidsemesterns": "skidsemester",
    "skidsemesters": "skidsemester",
    "skidsemestrar": "skidsemester",
    "skidsemestrarna": "skidsemester",
    "skidsemestrarnas": "skidsemester",
    "skidsemestrars": "skidsemester",
    "skidskyttes": "skidskytte",
    "skidskyttestafetten": "skidskyttestafett",
    "skidskyttestafettens": "skidskyttestafett",
    "skidskyttestafetter": "skidskyttestafett",
    "skidskyttestafetterna": "skidskyttestafett",
    "skidskyttestafetternas": "skidskyttestafett",
    "skidskyttestafetters": "skidskyttestafett",
    "skidskyttestafetts": "skidskyttestafett",
    "skidskyttet": "skidskytte",
    "skidskyttets": "skidskytte",
    "skidspåren": "skidspår",
    "skidspårens": "skidspår",
    "skidspåret": "skidspår",
    "skidspårets": "skidspår",
    "skidspårs": "skidspår",
    "skidstavar": "skidstav",
    "skidstavarna": "skidstav",
    "skidstavarnas": "skidstav",
    "skidstavars": "skidstav",
    "skidstaven": "skidstav",
    "skidstavens": "skidstav",
    "skidstavs": "skidstav",
    "skidturen": "skidtur",
    "skidturens": "skidtur",
    "skidturer": "skidtur",
    "skidturerna": "skidtur",
    "skidturernas": "skidtur",
    "skidturers": "skidtur",
    "skidturs": "skidtur",
    "skidtypen": "skidtyp",
    "skidtypens": "skidtyp",
    "skidtyper": "skidtyp",
    "skidtyperna": "skidtyp",
    "skidtypernas": "skidtyp",
    "skidtypers": "skidtyp",
    "skidtyps": "skidtyp",
    "skidtävlingar": "skidtävling",
    "skidtävlingarna": "skidtävling",
    "skidtävlingarnas": "skidtävling",
    "skidtävlingars": "skidtävling",
    "skidtävlingen": "skidtävling",
    "skidtävlingens": "skidtävling",
    "skidtävlings": "skidtävling",
    "skidåkar": "skidåkare",
    "skidåkaren": "skidåkare",
    "skidåkarens": "skidåkare",
    "skidåkares": "skidåkare",
    "skidåkarna": "skidåkare",
    "skidåkarnas": "skidåkare",
    "skidåkningar": "skidåkning",
    "skidåkningarna": "skidåkning",
    "skidåkningarnas": "skidåkning",
    "skidåkningars": "skidåkning",
    "skidåkningen": "skidåkning",
    "skidåkningens": "skidåkning",
    "skidåknings": "skidåkning",
    "skiffergråa": "skiffergrå",
    "skiffergråare": "skiffergrå",
    "skiffergråares": "skiffergrå",
    "skiffergråas": "skiffergrå",
    "skiffergråast": "skiffergrå",
    "skiffergråaste": "skiffergrå",
    "skiffergråastes": "skiffergrå",
    "skiffergråasts": "skiffergrå",
    "skiffergråe": "skiffergrå",
    "skiffergråes": "skiffergrå",
    "skiffergrås": "skiffergrå",
    "skiffergrått": "skiffergrå",
    "skiffergråtts": "skiffergrå",
    "skiffern": "skiffer",
    "skifferns": "skiffer",
    "skifferoljan": "skifferolja",
    "skifferoljans": "skifferolja",
    "skifferoljas": "skifferolja",
    "skifferolje": "skifferolja",
    "skifferplatt": "skifferplatta",
    "skifferplattan": "skifferplatta",
    "skifferplattans": "skifferplatta",
    "skifferplattas": "skifferplatta",
    "skifferplatte": "skifferplatta",
    "skifferplattor": "skifferplatta",
    "skifferplattorna": "skifferplatta",
    "skifferplattornas": "skifferplatta",
    "skifferplattors": "skifferplatta",
    "skifferplatts": "skifferplatta",
    "skiffers": "skiffer",
    "skiffertaken": "skiffertak",
    "skiffertakens": "skiffertak",
    "skiffertaket": "skiffertak",
    "skiffertakets": "skiffertak",
    "skiffertaks": "skiffertak",
    "skifflen": "skiffle",
    "skifflens": "skiffle",
    "skiffles": "skiffle",
    "skiffrar": "skiffer",
    "skiffrarna": "skiffer",
    "skiffrarnas": "skiffer",
    "skiffrars": "skiffer",
    "skiffriga": "skiffrig",
    "skiffrigare": "skiffrig",
    "skiffrigares": "skiffrig",
    "skiffrigas": "skiffrig",
    "skiffrigast": "skiffrig",
    "skiffrigaste": "skiffrig",
    "skiffrigastes": "skiffrig",
    "skiffrigasts": "skiffrig",
    "skiffrige": "skiffrig",
    "skiffriges": "skiffrig",
    "skiffrigheten": "skiffrighet",
    "skiffrighetens": "skiffrighet",
    "skiffrighets": "skiffrighet",
    "skiffrigs": "skiffrig",
    "skiffrigt": "skiffrig",
    "skiffrigts": "skiffrig",
    "skift": "skifta",
    "skiftad": "skifta",
    "skiftade": "skifta",
    "skiftades": "skifta",
    "skiftads": "skifta",
    "skiftande": "skifta",
    "skiftanden": "skiftande",
    "skiftandena": "skiftande",
    "skiftandenas": "skiftande",
    "skiftandens": "skiftande",
    "skiftandes": "skiftande",
    "skiftandet": "skiftande",
    "skiftandets": "skiftande",
    "skiftar": "skifta",
    "skiftarbeten": "skiftarbete",
    "skiftarbetena": "skiftarbete",
    "skiftarbetenas": "skiftarbete",
    "skiftarbetens": "skiftarbete",
    "skiftarbetes": "skiftarbete",
    "skiftarbetet": "skiftarbete",
    "skiftarbetets": "skiftarbete",
    "skiftarbets": "skiftarbete",
    "skiftas": "skifta",
    "skiftat": "skifta",
    "skiftats": "skifta",
    "skiften": "skifte",
    "skiftena": "skifte",
    "skiftenas": "skifte",
    "skiftens": "skifte",
    "skiftes": "skifte",
    "skiftesbruket": "skiftesbruk",
    "skiftesbrukets": "skiftesbruk",
    "skiftesbruks": "skiftesbruk",
    "skiftet": "skifte",
    "skiftets": "skifte",
    "skiftningar": "skiftning",
    "skiftningarna": "skiftning",
    "skiftningarnas": "skiftning",
    "skiftningars": "skiftning",
    "skiftningen": "skiftning",
    "skiftningens": "skiftning",
    "skiftnings": "skiftning",
    "skiftnyckeln": "skiftnyckel",
    "skiftnyckelns": "skiftnyckel",
    "skiftnyckels": "skiftnyckel",
    "skiftnycklar": "skiftnyckel",
    "skiftnycklarna": "skiftnyckel",
    "skiftnycklarnas": "skiftnyckel",
    "skiftnycklars": "skiftnyckel",
    "skifts": "skift",
    "skiktad": "skikta",
    "skiktade": "skiktad",
    "skiktades": "skiktad",
    "skiktads": "skiktad",
    "skiktande": "skikta",
    "skiktanden": "skiktande",
    "skiktandena": "skiktande",
    "skiktandenas": "skiktande",
    "skiktandens": "skiktande",
    "skiktandes": "skiktande",
    "skiktandet": "skiktande",
    "skiktandets": "skiktande",
    "skiktar": "skikta",
    "skiktas": "skikta",
    "skiktat": "skiktad",
    "skiktats": "skiktad",
    "skikten": "skikt",
    "skiktens": "skikt",
    "skiktet": "skikt",
    "skiktets": "skikt",
    "skiktmolnen": "skiktmoln",
    "skiktmolnens": "skiktmoln",
    "skiktmolnet": "skiktmoln",
    "skiktmolnets": "skiktmoln",
    "skiktmolns": "skiktmoln",
    "skiktröntgens": "skiktröntgen",
    "skikts": "skikt",
    "skild": "skilja",
    "skilda": "skilja",
    "skildare": "skild",
    "skildares": "skild",
    "skildas": "skilja",
    "skildast": "skild",
    "skildaste": "skild",
    "skildastes": "skild",
    "skildasts": "skild",
    "skilde": "skilja",
    "skildes": "skiljas",
    "skildkönade": "skildkönad",
    "skildkönades": "skildkönad",
    "skildkönads": "skildkönad",
    "skildkönat": "skildkönad",
    "skildkönats": "skildkönad",
    "skildrad": "skildra",
    "skildrade": "skildra",
    "skildrades": "skildra",
    "skildrads": "skildra",
    "skildrande": "skildra",
    "skildranden": "skildrande",
    "skildrandena": "skildrande",
    "skildrandenas": "skildrande",
    "skildrandens": "skildrande",
    "skildrandes": "skildrande",
    "skildrandet": "skildrande",
    "skildrandets": "skildrande",
    "skildrar": "skildra",
    "skildras": "skildra",
    "skildrat": "skildra",
    "skildrats": "skildra",
    "skildringar": "skildring",
    "skildringarna": "skildring",
    "skildringarnas": "skildring",
    "skildringars": "skildring",
    "skildringen": "skildring",
    "skildringens": "skildring",
    "skildrings": "skildring",
    "skilds": "skilja",
    "skilj": "skilja",
    "skiljaktiga": "skiljaktig",
    "skiljaktigare": "skiljaktig",
    "skiljaktigares": "skiljaktig",
    "skiljaktigas": "skiljaktig",
    "skiljaktigast": "skiljaktig",
    "skiljaktigaste": "skiljaktig",
    "skiljaktigastes": "skiljaktig",
    "skiljaktigasts": "skiljaktig",
    "skiljaktige": "skiljaktig",
    "skiljaktiges": "skiljaktig",
    "skiljaktigheten": "skiljaktighet",
    "skiljaktighetens": "skiljaktighet",
    "skiljaktigheter": "skiljaktighet",
    "skiljaktigheterna": "skiljaktighet",
    "skiljaktigheternas": "skiljaktighet",
    "skiljaktigheters": "skiljaktighet",
    "skiljaktighets": "skiljaktighet",
    "skiljaktigs": "skiljaktig",
    "skiljaktigt": "skiljaktig",
    "skiljaktigts": "skiljaktig",
    "skiljande": "skilja",
    "skiljanden": "skiljande",
    "skiljandena": "skiljande",
    "skiljandenas": "skiljande",
    "skiljandens": "skiljande",
    "skiljandes": "skiljande",
    "skiljandet": "skiljande",
    "skiljandets": "skiljande",
    "skiljas": "skilja",
    "skiljbara": "skiljbar",
    "skiljbarare": "skiljbar",
    "skiljbarares": "skiljbar",
    "skiljbaras": "skiljbar",
    "skiljbarast": "skiljbar",
    "skiljbaraste": "skiljbar",
    "skiljbarastes": "skiljbar",
    "skiljbarasts": "skiljbar",
    "skiljbare": "skiljbar",
    "skiljbares": "skiljbar",
    "skiljbarheten": "skiljbarhet",
    "skiljbarhetens": "skiljbarhet",
    "skiljbarhets": "skiljbarhet",
    "skiljbars": "skiljbar",
    "skiljbart": "skiljbar",
    "skiljbarts": "skiljbar",
    "skiljedomar": "skiljedom",
    "skiljedomarna": "skiljedom",
    "skiljedomarnas": "skiljedom",
    "skiljedomars": "skiljedom",
    "skiljedomen": "skiljedom",
    "skiljedomens": "skiljedom",
    "skiljedoms": "skiljedom",
    "skiljedomstolar": "skiljedomstol",
    "skiljedomstolarna": "skiljedomstol",
    "skiljedomstolarnas": "skiljedomstol",
    "skiljedomstolars": "skiljedomstol",
    "skiljedomstolen": "skiljedomstol",
    "skiljedomstolens": "skiljedomstol",
    "skiljedomstols": "skiljedomstol",
    "skiljeförfaranden": "skiljeförfarande",
    "skiljeförfarandena": "skiljeförfarande",
    "skiljeförfarandenas": "skiljeförfarande",
    "skiljeförfarandens": "skiljeförfarande",
    "skiljeförfarandes": "skiljeförfarande",
    "skiljeförfarandet": "skiljeförfarande",
    "skiljeförfarandets": "skiljeförfarande",
    "skiljelinjen": "skiljelinje",
    "skiljelinjens": "skiljelinje",
    "skiljelinjer": "skiljelinje",
    "skiljelinjerna": "skiljelinje",
    "skiljelinjernas": "skiljelinje",
    "skiljelinjers": "skiljelinje",
    "skiljelinjes": "skiljelinje",
    "skiljemannen": "skiljeman",
    "skiljemannens": "skiljeman",
    "skiljemans": "skiljeman",
    "skiljemurar": "skiljemur",
    "skiljemurarna": "skiljemur",
    "skiljemurarnas": "skiljemur",
    "skiljemurars": "skiljemur",
    "skiljemuren": "skiljemur",
    "skiljemurens": "skiljemur",
    "skiljemurs": "skiljemur",
    "skiljemynten": "skiljemynt",
    "skiljemyntens": "skiljemynt",
    "skiljemyntet": "skiljemynt",
    "skiljemyntets": "skiljemynt",
    "skiljemynts": "skiljemynt",
    "skiljemän": "skiljeman",
    "skiljemännen": "skiljeman",
    "skiljemännens": "skiljeman",
    "skiljemäns": "skiljeman",
    "skiljen": "skilje",
    "skiljena": "skilje",
    "skiljenas": "skilje",
    "skiljens": "skilje",
    "skiljenämnden": "skiljenämnd",
    "skiljenämndens": "skiljenämnd",
    "skiljenämnder": "skiljenämnd",
    "skiljenämnderna": "skiljenämnd",
    "skiljenämndernas": "skiljenämnd",
    "skiljenämnders": "skiljenämnd",
    "skiljenämnds": "skiljenämnd",
    "skiljer": "skilja",
    "skiljes": "skilje",
    "skiljeseten": "skiljeset",
    "skiljesetens": "skiljeset",
    "skiljesetet": "skiljeset",
    "skiljesetets": "skiljeset",
    "skiljesets": "skiljeset",
    "skiljet": "skilje",
    "skiljeteckens": "skiljetecken",
    "skiljetecknen": "skiljetecken",
    "skiljetecknens": "skiljetecken",
    "skiljetecknet": "skiljetecken",
    "skiljetecknets": "skiljetecken",
    "skiljets": "skilje",
    "skiljevägar": "skiljeväg",
    "skiljevägarna": "skiljeväg",
    "skiljevägarnas": "skiljeväg",
    "skiljevägars": "skiljeväg",
    "skiljevägen": "skiljeväg",
    "skiljevägens": "skiljeväg",
    "skiljeväggar": "skiljevägg",
    "skiljeväggarna": "skiljevägg",
    "skiljeväggarnas": "skiljevägg",
    "skiljeväggars": "skiljevägg",
    "skiljeväggen": "skiljevägg",
    "skiljeväggens": "skiljevägg",
    "skiljeväggs": "skiljevägg",
    "skiljevägs": "skiljeväg",
    "skiljs": "skilje",
    "skillingar": "skilling",
    "skillingarna": "skilling",
    "skillingarnas": "skilling",
    "skillingars": "skilling",
    "skillingen": "skilling",
    "skillingens": "skilling",
    "skillings": "skilling",
    "skillingtrycken": "skillingtryck",
    "skillingtryckens": "skillingtryck",
    "skillingtrycket": "skillingtryck",
    "skillingtryckets": "skillingtryck",
    "skillingtrycks": "skillingtryck",
    "skillnaden": "skillnad",
    "skillnadens": "skillnad",
    "skillnader": "skillnad",
    "skillnaderna": "skillnad",
    "skillnadernas": "skillnad",
    "skillnaders": "skillnad",
    "skillnads": "skillnad",
    "skils": "skiljas",
    "skilsmässan": "skilsmässa",
    "skilsmässans": "skilsmässa",
    "skilsmässas": "skilsmässa",
    "skilsmässo": "skilsmässa",
    "skilsmässobarnen": "skilsmässobarn",
    "skilsmässobarnens": "skilsmässobarn",
    "skilsmässobarnet": "skilsmässobarn",
    "skilsmässobarnets": "skilsmässobarn",
    "skilsmässobarns": "skilsmässobarn",
    "skilsmässor": "skilsmässa",
    "skilsmässorna": "skilsmässa",
    "skilsmässornas": "skilsmässa",
    "skilsmässors": "skilsmässa",
    "skilt": "skilja",
    "skilts": "skiljas",
    "skiltvakten": "skiltvakt",
    "skiltvaktens": "skiltvakt",
    "skiltvakter": "skiltvakt",
    "skiltvakterna": "skiltvakt",
    "skiltvakternas": "skiltvakt",
    "skiltvakters": "skiltvakt",
    "skiltvakts": "skiltvakt",
    "skimlar": "skimmel",
    "skimlarna": "skimmel",
    "skimlarnas": "skimmel",
    "skimlars": "skimmel",
    "skimmeln": "skimmel",
    "skimmelns": "skimmel",
    "skimmels": "skimmel",
    "skimmers": "skimmer",
    "skimmlar": "skimmel",
    "skimmlarna": "skimmel",
    "skimmlarnas": "skimmel",
    "skimmlars": "skimmel",
    "skimrade": "skimra",
    "skimrades": "skimra",
    "skimrande": "skimra",
    "skimranden": "skimrande",
    "skimrandena": "skimrande",
    "skimrandenas": "skimrande",
    "skimrandens": "skimrande",
    "skimrandes": "skimrande",
    "skimrandet": "skimrande",
    "skimrandets": "skimrande",
    "skimrar": "skimra",
    "skimras": "skimra",
    "skimrat": "skimra",
    "skimrats": "skimra",
    "skimret": "skimmer",
    "skimrets": "skimmer",
    "skin": "skina",
    "skinande": "skina",
    "skinanden": "skinande",
    "skinandena": "skinande",
    "skinandenas": "skinande",
    "skinandens": "skinande",
    "skinandes": "skinande",
    "skinandet": "skinande",
    "skinandets": "skinande",
    "skinas": "skina",
    "skine": "skina",
    "skineffekten": "skineffekt",
    "skineffektens": "skineffekt",
    "skineffekts": "skineffekt",
    "skiner": "skina",
    "skines": "skina",
    "skingrad": "skingra",
    "skingrade": "skingra",
    "skingrades": "skingras",
    "skingrads": "skingra",
    "skingrande": "skingra",
    "skingranden": "skingrande",
    "skingrandena": "skingrande",
    "skingrandenas": "skingrande",
    "skingrandens": "skingrande",
    "skingrandes": "skingrande",
    "skingrandet": "skingrande",
    "skingrandets": "skingrande",
    "skingrar": "skingra",
    "skingras": "skingra",
    "skingrat": "skingra",
    "skingrats": "skingras",
    "skingringsförbuden": "skingringsförbud",
    "skingringsförbudens": "skingringsförbud",
    "skingringsförbudet": "skingringsförbud",
    "skingringsförbudets": "skingringsförbud",
    "skingringsförbuds": "skingringsförbud",
    "skinheadet": "skinhead",
    "skinheadets": "skinhead",
    "skinheads": "skinhead",
    "skinheadsen": "skinhead",
    "skinheadsens": "skinhead",
    "skinit": "skina",
    "skinits": "skina",
    "skink": "skinka",
    "skinkan": "skinka",
    "skinkans": "skinka",
    "skinkas": "skinka",
    "skinke": "skinka",
    "skinkor": "skinka",
    "skinkorna": "skinka",
    "skinkornas": "skinka",
    "skinkors": "skinka",
    "skinks": "skinka",
    "skinn": "skinna",
    "skinnad": "skinna",
    "skinnade": "skinna",
    "skinnades": "skinna",
    "skinnads": "skinna",
    "skinnande": "skinna",
    "skinnanden": "skinnande",
    "skinnandena": "skinnande",
    "skinnandenas": "skinnande",
    "skinnandens": "skinnande",
    "skinnandes": "skinnande",
    "skinnandet": "skinnande",
    "skinnandets": "skinnande",
    "skinnar": "skinnare",
    "skinnaren": "skinnare",
    "skinnarens": "skinnare",
    "skinnares": "skinnare",
    "skinnarna": "skinnare",
    "skinnarnas": "skinnare",
    "skinnas": "skinna",
    "skinnat": "skinna",
    "skinnats": "skinna",
    "skinnbagg": "skinnbagge",
    "skinnbaggar": "skinnbagge",
    "skinnbaggarna": "skinnbagge",
    "skinnbaggarnas": "skinnbagge",
    "skinnbaggars": "skinnbagge",
    "skinnbaggen": "skinnbagge",
    "skinnbaggens": "skinnbagge",
    "skinnbagges": "skinnbagge",
    "skinnbaggs": "skinnbagge",
    "skinnbanden": "skinnband",
    "skinnbandens": "skinnband",
    "skinnbandet": "skinnband",
    "skinnbandets": "skinnband",
    "skinnbands": "skinnband",
    "skinnbitar": "skinnbit",
    "skinnbitarna": "skinnbit",
    "skinnbitarnas": "skinnbit",
    "skinnbitars": "skinnbit",
    "skinnbiten": "skinnbit",
    "skinnbitens": "skinnbit",
    "skinnbits": "skinnbit",
    "skinnen": "skinn",
    "skinnens": "skinn",
    "skinnerburar": "skinnerbur",
    "skinnerburarna": "skinnerbur",
    "skinnerburarnas": "skinnerbur",
    "skinnerburars": "skinnerbur",
    "skinnerburen": "skinnerbur",
    "skinnerburens": "skinnerbur",
    "skinnerburs": "skinnerbur",
    "skinnet": "skinn",
    "skinnets": "skinn",
    "skinnflådda": "skinnflådd",
    "skinnflåddare": "skinnflådd",
    "skinnflåddares": "skinnflådd",
    "skinnflåddas": "skinnflådd",
    "skinnflåddast": "skinnflådd",
    "skinnflåddaste": "skinnflådd",
    "skinnflåddastes": "skinnflådd",
    "skinnflåddasts": "skinnflådd",
    "skinnflådde": "skinnflådd",
    "skinnflåddes": "skinnflådd",
    "skinnflådds": "skinnflådd",
    "skinnflått": "skinnflådd",
    "skinnflåtts": "skinnflådd",
    "skinnfällar": "skinnfäll",
    "skinnfällarna": "skinnfäll",
    "skinnfällarnas": "skinnfäll",
    "skinnfällars": "skinnfäll",
    "skinnfällen": "skinnfäll",
    "skinnfällens": "skinnfäll",
    "skinnfälls": "skinnfäll",
    "skinnfåtöljen": "skinnfåtölj",
    "skinnfåtöljens": "skinnfåtölj",
    "skinnfåtöljer": "skinnfåtölj",
    "skinnfåtöljerna": "skinnfåtölj",
    "skinnfåtöljernas": "skinnfåtölj",
    "skinnfåtöljers": "skinnfåtölj",
    "skinnfåtöljs": "skinnfåtölj",
    "skinnimitationen": "skinnimitation",
    "skinnimitationens": "skinnimitation",
    "skinnimitationer": "skinnimitation",
    "skinnimitationerna": "skinnimitation",
    "skinnimitationernas": "skinnimitation",
    "skinnimitationers": "skinnimitation",
    "skinnimitations": "skinnimitation",
    "skinnjack": "skinnjacka",
    "skinnjackan": "skinnjacka",
    "skinnjackans": "skinnjacka",
    "skinnjackas": "skinnjacka",
    "skinnjacke": "skinnjacka",
    "skinnjackor": "skinnjacka",
    "skinnjackorna": "skinnjacka",
    "skinnjackornas": "skinnjacka",
    "skinnjackors": "skinnjacka",
    "skinnjacks": "skinnjacka",
    "skinnkavajen": "skinnkavaj",
    "skinnkavajens": "skinnkavaj",
    "skinnkavajer": "skinnkavaj",
    "skinnkavajerna": "skinnkavaj",
    "skinnkavajernas": "skinnkavaj",
    "skinnkavajers": "skinnkavaj",
    "skinnkavajs": "skinnkavaj",
    "skinnklädda": "skinnklädd",
    "skinnkläddare": "skinnklädd",
    "skinnkläddares": "skinnklädd",
    "skinnkläddas": "skinnklädd",
    "skinnkläddast": "skinnklädd",
    "skinnkläddaste": "skinnklädd",
    "skinnkläddastes": "skinnklädd",
    "skinnkläddasts": "skinnklädd",
    "skinnklädde": "skinnklädd",
    "skinnkläddes": "skinnklädd",
    "skinnklädds": "skinnklädd",
    "skinnklädseln": "skinnklädsel",
    "skinnklädselns": "skinnklädsel",
    "skinnklädsels": "skinnklädsel",
    "skinnklädslar": "skinnklädsel",
    "skinnklädslarna": "skinnklädsel",
    "skinnklädslarnas": "skinnklädsel",
    "skinnklädslars": "skinnklädsel",
    "skinnklätt": "skinnklädd",
    "skinnklätts": "skinnklädd",
    "skinnknuttar": "skinnknutte",
    "skinnknuttarna": "skinnknutte",
    "skinnknuttarnas": "skinnknutte",
    "skinnknuttars": "skinnknutte",
    "skinnknutten": "skinnknutte",
    "skinnknuttens": "skinnknutte",
    "skinnknuttes": "skinnknutte",
    "skinnkälk": "skinnkälke",
    "skinnkälkar": "skinnkälke",
    "skinnkälkarna": "skinnkälke",
    "skinnkälkarnas": "skinnkälke",
    "skinnkälkars": "skinnkälke",
    "skinnkälken": "skinnkälke",
    "skinnkälkens": "skinnkälke",
    "skinnkälkes": "skinnkälke",
    "skinnkälks": "skinnkälke",
    "skinnpajar": "skinnpaj",
    "skinnpajarna": "skinnpaj",
    "skinnpajarnas": "skinnpaj",
    "skinnpajars": "skinnpaj",
    "skinnpajen": "skinnpaj",
    "skinnpajens": "skinnpaj",
    "skinnpajs": "skinnpaj",
    "skinns": "skinn",
    "skinnskallar": "skinnskalle",
    "skinnskallarna": "skinnskalle",
    "skinnskallarnas": "skinnskalle",
    "skinnskallars": "skinnskalle",
    "skinnskallen": "skinnskalle",
    "skinnskallens": "skinnskalle",
    "skinnskalles": "skinnskalle",
    "skinnsoff": "skinnsoffa",
    "skinnsoffan": "skinnsoffa",
    "skinnsoffans": "skinnsoffa",
    "skinnsoffas": "skinnsoffa",
    "skinnsoffe": "skinnsoffa",
    "skinnsoffor": "skinnsoffa",
    "skinnsofforna": "skinnsoffa",
    "skinnsoffornas": "skinnsoffa",
    "skinnsoffors": "skinnsoffa",
    "skinnsoffs": "skinnsoffa",
    "skinntorra": "skinntorr",
    "skinntorrare": "skinntorr",
    "skinntorrares": "skinntorr",
    "skinntorras": "skinntorr",
    "skinntorrast": "skinntorr",
    "skinntorraste": "skinntorr",
    "skinntorrastes": "skinntorr",
    "skinntorrasts": "skinntorr",
    "skinntorre": "skinntorr",
    "skinntorres": "skinntorr",
    "skinntorrheten": "skinntorrhet",
    "skinntorrhetens": "skinntorrhet",
    "skinntorrhets": "skinntorrhet",
    "skinntorrs": "skinntorr",
    "skinntorrt": "skinntorr",
    "skinntorrts": "skinntorr",
    "skinnvästar": "skinnväst",
    "skinnvästarna": "skinnväst",
    "skinnvästarnas": "skinnväst",
    "skinnvästars": "skinnväst",
    "skinnvästen": "skinnväst",
    "skinnvästens": "skinnväst",
    "skinnvästs": "skinnväst",
    "skins": "skina",
    "skioptikonen": "skioptikon",
    "skioptikonens": "skioptikon",
    "skioptikonet": "skioptikon",
    "skioptikonets": "skioptikon",
    "skioptikons": "skioptikon",
    "skip": "skipa",
    "skipad": "skipa",
    "skipade": "skipa",
    "skipades": "skipa",
    "skipads": "skipa",
    "skipande": "skipa",
    "skipanden": "skipande",
    "skipandena": "skipande",
    "skipandenas": "skipande",
    "skipandens": "skipande",
    "skipandes": "skipande",
    "skipandet": "skipande",
    "skipandets": "skipande",
    "skipar": "skipa",
    "skipas": "skipa",
    "skipat": "skipa",
    "skipats": "skipa",
    "skipp": "skippa",
    "skippad": "skippa",
    "skippade": "skippa",
    "skippades": "skippa",
    "skippads": "skippa",
    "skippande": "skippa",
    "skippanden": "skippande",
    "skippandena": "skippande",
    "skippandenas": "skippande",
    "skippandens": "skippande",
    "skippandes": "skippande",
    "skippandet": "skippande",
    "skippandets": "skippande",
    "skippar": "skippa",
    "skippas": "skippa",
    "skippat": "skippa",
    "skippats": "skippa",
    "skir": "skira",
    "skira": "skir",
    "skirad": "skira",
    "skirade": "skira",
    "skirades": "skira",
    "skirads": "skira",
    "skirande": "skira",
    "skiranden": "skirande",
    "skirandena": "skirande",
    "skirandenas": "skirande",
    "skirandens": "skirande",
    "skirandes": "skirande",
    "skirandet": "skirande",
    "skirandets": "skirande",
    "skirar": "skira",
    "skirare": "skir",
    "skirares": "skir",
    "skiras": "skira",
    "skirast": "skir",
    "skiraste": "skir",
    "skirastes": "skir",
    "skirasts": "skir",
    "skirat": "skira",
    "skirats": "skira",
    "skire": "skir",
    "skires": "skir",
    "skirheten": "skirhet",
    "skirhetens": "skirhet",
    "skirhets": "skirhet",
    "skirs": "skir",
    "skirt": "skir",
    "skirts": "skir",
    "skiss": "skissa",
    "skissad": "skissa",
    "skissade": "skissa",
    "skissades": "skissa",
    "skissads": "skissa",
    "skissande": "skissa",
    "skissanden": "skissande",
    "skissandena": "skissande",
    "skissandenas": "skissande",
    "skissandens": "skissande",
    "skissandes": "skissande",
    "skissandet": "skissande",
    "skissandets": "skissande",
    "skissar": "skissa",
    "skissas": "skissa",
    "skissat": "skissa",
    "skissats": "skissa",
    "skissblocken": "skissblock",
    "skissblockens": "skissblock",
    "skissblocket": "skissblock",
    "skissblockets": "skissblock",
    "skissblocks": "skissblock",
    "skissen": "skiss",
    "skissens": "skiss",
    "skisser": "skiss",
    "skisserad": "skissera",
    "skisserade": "skissera",
    "skisserades": "skissera",
    "skisserads": "skissera",
    "skisserande": "skissera",
    "skisseranden": "skisserande",
    "skisserandena": "skisserande",
    "skisserandenas": "skisserande",
    "skisserandens": "skisserande",
    "skisserandes": "skisserande",
    "skisserandet": "skisserande",
    "skisserandets": "skisserande",
    "skisserar": "skissera",
    "skisseras": "skissera",
    "skisserat": "skissera",
    "skisserats": "skissera",
    "skisserbara": "skisserbar",
    "skisserbarare": "skisserbar",
    "skisserbarares": "skisserbar",
    "skisserbaras": "skisserbar",
    "skisserbarast": "skisserbar",
    "skisserbaraste": "skisserbar",
    "skisserbarastes": "skisserbar",
    "skisserbarasts": "skisserbar",
    "skisserbare": "skisserbar",
    "skisserbares": "skisserbar",
    "skisserbarheten": "skisserbarhet",
    "skisserbarhetens": "skisserbarhet",
    "skisserbarhets": "skisserbarhet",
    "skisserbars": "skisserbar",
    "skisserbart": "skisserbar",
    "skisserbarts": "skisserbar",
    "skisseringar": "skissering",
    "skisseringarna": "skissering",
    "skisseringarnas": "skissering",
    "skisseringars": "skissering",
    "skisseringen": "skissering",
    "skisseringens": "skissering",
    "skisserings": "skissering",
    "skisserna": "skiss",
    "skissernas": "skiss",
    "skissers": "skiss",
    "skit": "skita",
    "skitande": "skita",
    "skitanden": "skitande",
    "skitandena": "skitande",
    "skitandenas": "skitande",
    "skitandens": "skitande",
    "skitandes": "skitande",
    "skitandet": "skitande",
    "skitandets": "skitande",
    "skitar": "skit",
    "skitarna": "skit",
    "skitarnas": "skit",
    "skitars": "skit",
    "skitas": "skita",
    "skitbesvärliga": "skitbesvärlig",
    "skitbesvärligare": "skitbesvärlig",
    "skitbesvärligares": "skitbesvärlig",
    "skitbesvärligas": "skitbesvärlig",
    "skitbesvärligast": "skitbesvärlig",
    "skitbesvärligaste": "skitbesvärlig",
    "skitbesvärligastes": "skitbesvärlig",
    "skitbesvärligasts": "skitbesvärlig",
    "skitbesvärlige": "skitbesvärlig",
    "skitbesvärliges": "skitbesvärlig",
    "skitbesvärligs": "skitbesvärlig",
    "skitbesvärligt": "skitbesvärlig",
    "skitbesvärligts": "skitbesvärlig",
    "skitdåliga": "skitdålig",
    "skitdåligare": "skitdålig",
    "skitdåligares": "skitdålig",
    "skitdåligas": "skitdålig",
    "skitdåligast": "skitdålig",
    "skitdåligaste": "skitdålig",
    "skitdåligastes": "skitdålig",
    "skitdåligasts": "skitdålig",
    "skitdålige": "skitdålig",
    "skitdåliges": "skitdålig",
    "skitdåligs": "skitdålig",
    "skitdåligt": "skitdålig",
    "skitdåligts": "skitdålig",
    "skite": "skita",
    "skiten": "skit",
    "skitens": "skit",
    "skiter": "skita",
    "skites": "skita",
    "skitet": "skit",
    "skitets": "skit",
    "skitförnäma": "skitförnäm",
    "skitförnämare": "skitförnäm",
    "skitförnämares": "skitförnäm",
    "skitförnämas": "skitförnäm",
    "skitförnämast": "skitförnäm",
    "skitförnämaste": "skitförnäm",
    "skitförnämastes": "skitförnäm",
    "skitförnämasts": "skitförnäm",
    "skitförnäme": "skitförnäm",
    "skitförnämes": "skitförnäm",
    "skitförnämheten": "skitförnämhet",
    "skitförnämhetens": "skitförnämhet",
    "skitförnämhets": "skitförnämhet",
    "skitförnäms": "skitförnäm",
    "skitförnämt": "skitförnäm",
    "skitförnämts": "skitförnäm",
    "skitgubb": "skitgubbe",
    "skitgubbar": "skitgubbe",
    "skitgubbarna": "skitgubbe",
    "skitgubbarnas": "skitgubbe",
    "skitgubbars": "skitgubbe",
    "skitgubben": "skitgubbe",
    "skitgubbens": "skitgubbe",
    "skitgubbes": "skitgubbe",
    "skitgubbs": "skitgubbe",
    "skitiga": "skitig",
    "skitigare": "skitig",
    "skitigares": "skitig",
    "skitigas": "skitig",
    "skitigast": "skitig",
    "skitigaste": "skitig",
    "skitigastes": "skitig",
    "skitigasts": "skitig",
    "skitige": "skitig",
    "skitiges": "skitig",
    "skitigs": "skitig",
    "skitigt": "skitig",
    "skitigts": "skitig",
    "skitit": "skita",
    "skitits": "skita",
    "skitnödiga": "skitnödig",
    "skitnödigare": "skitnödig",
    "skitnödigares": "skitnödig",
    "skitnödigas": "skitnödig",
    "skitnödigast": "skitnödig",
    "skitnödigaste": "skitnödig",
    "skitnödigastes": "skitnödig",
    "skitnödigasts": "skitnödig",
    "skitnödige": "skitnödig",
    "skitnödiges": "skitnödig",
    "skitnödigheten": "skitnödighet",
    "skitnödighetens": "skitnödighet",
    "skitnödighets": "skitnödighet",
    "skitnödigs": "skitnödig",
    "skitnödigt": "skitnödig",
    "skitnödigts": "skitnödig",
    "skitpratet": "skitprat",
    "skitpratets": "skitprat",
    "skitprats": "skitprat",
    "skiträdda": "skiträdd",
    "skiträddare": "skiträdd",
    "skiträddares": "skiträdd",
    "skiträddas": "skiträdd",
    "skiträddast": "skiträdd",
    "skiträddaste": "skiträdd",
    "skiträddastes": "skiträdd",
    "skiträddasts": "skiträdd",
    "skiträdde": "skiträdd",
    "skiträddes": "skiträdd",
    "skiträdds": "skiträdd",
    "skits": "skita",
    "skitsnacket": "skitsnack",
    "skitsnackets": "skitsnack",
    "skitsnacks": "skitsnack",
    "skitsnygga": "skitsnygg",
    "skitsnyggare": "skitsnygg",
    "skitsnyggares": "skitsnygg",
    "skitsnyggas": "skitsnygg",
    "skitsnyggast": "skitsnygg",
    "skitsnyggaste": "skitsnygg",
    "skitsnyggastes": "skitsnygg",
    "skitsnyggasts": "skitsnygg",
    "skitsnygge": "skitsnygg",
    "skitsnygges": "skitsnygg",
    "skitsnyggheten": "skitsnygghet",
    "skitsnygghetens": "skitsnygghet",
    "skitsnygghets": "skitsnygghet",
    "skitsnyggs": "skitsnygg",
    "skitsnyggt": "skitsnygg",
    "skitsnyggts": "skitsnygg",
    "skitställen": "skitställe",
    "skitställena": "skitställe",
    "skitställenas": "skitställe",
    "skitställens": "skitställe",
    "skitställes": "skitställe",
    "skitstället": "skitställe",
    "skitställets": "skitställe",
    "skitstöveln": "skitstövel",
    "skitstövelns": "skitstövel",
    "skitstövels": "skitstövel",
    "skitstövlar": "skitstövel",
    "skitstövlarna": "skitstövel",
    "skitstövlarnas": "skitstövel",
    "skitstövlars": "skitstövel",
    "skittråkiga": "skittråkig",
    "skittråkigare": "skittråkig",
    "skittråkigares": "skittråkig",
    "skittråkigas": "skittråkig",
    "skittråkigast": "skittråkig",
    "skittråkigaste": "skittråkig",
    "skittråkigastes": "skittråkig",
    "skittråkigasts": "skittråkig",
    "skittråkige": "skittråkig",
    "skittråkiges": "skittråkig",
    "skittråkigheten": "skittråkighet",
    "skittråkighetens": "skittråkighet",
    "skittråkighets": "skittråkighet",
    "skittråkigs": "skittråkig",
    "skittråkigt": "skittråkig",
    "skittråkigts": "skittråkig",
    "skitviktiga": "skitviktig",
    "skitviktigare": "skitviktig",
    "skitviktigares": "skitviktig",
    "skitviktigas": "skitviktig",
    "skitviktigast": "skitviktig",
    "skitviktigaste": "skitviktig",
    "skitviktigastes": "skitviktig",
    "skitviktigasts": "skitviktig",
    "skitviktige": "skitviktig",
    "skitviktiges": "skitviktig",
    "skitviktigheten": "skitviktighet",
    "skitviktighetens": "skitviktighet",
    "skitviktighets": "skitviktighet",
    "skitviktigs": "skitviktig",
    "skitviktigt": "skitviktig",
    "skitviktigts": "skitviktig",
    "skitåren": "skitår",
    "skitårens": "skitår",
    "skitåret": "skitår",
    "skitårets": "skitår",
    "skitårs": "skitår",
    "skiv": "skiva",
    "skivad": "skiva",
    "skivade": "skiva",
    "skivades": "skiva",
    "skivads": "skiva",
    "skivaffären": "skivaffär",
    "skivaffärens": "skivaffär",
    "skivaffärer": "skivaffär",
    "skivaffärerna": "skivaffär",
    "skivaffärernas": "skivaffär",
    "skivaffärers": "skivaffär",
    "skivaffärs": "skivaffär",
    "skivan": "skiva",
    "skivande": "skiva",
    "skivanden": "skivande",
    "skivandena": "skivande",
    "skivandenas": "skivande",
    "skivandens": "skivande",
    "skivandes": "skivande",
    "skivandet": "skivande",
    "skivandets": "skivande",
    "skivans": "skiva",
    "skivar": "skiva",
    "skivas": "skiva",
    "skivat": "skiva",
    "skivats": "skiva",
    "skivbaren": "skivbar",
    "skivbarens": "skivbar",
    "skivbarer": "skivbar",
    "skivbarerna": "skivbar",
    "skivbarernas": "skivbar",
    "skivbarers": "skivbar",
    "skivbars": "skivbar",
    "skivbolagen": "skivbolag",
    "skivbolagens": "skivbolag",
    "skivbolaget": "skivbolag",
    "skivbolagets": "skivbolag",
    "skivbolags": "skivbolag",
    "skivbolagsdirektören": "skivbolagsdirektör",
    "skivbolagsdirektörens": "skivbolagsdirektör",
    "skivbolagsdirektörer": "skivbolagsdirektör",
    "skivbolagsdirektörerna": "skivbolagsdirektör",
    "skivbolagsdirektörernas": "skivbolagsdirektör",
    "skivbolagsdirektörers": "skivbolagsdirektör",
    "skivbolagsdirektörn": "skivbolagsdirektör",
    "skivbolagsdirektörns": "skivbolagsdirektör",
    "skivbolagsdirektörs": "skivbolagsdirektör",
    "skivbromsar": "skivbroms",
    "skivbromsarna": "skivbroms",
    "skivbromsarnas": "skivbroms",
    "skivbromsars": "skivbroms",
    "skivbromsen": "skivbroms",
    "skivbromsens": "skivbroms",
    "skive": "skiva",
    "skivhusen": "skivhus",
    "skivhusens": "skivhus",
    "skivhuset": "skivhus",
    "skivhusets": "skivhus",
    "skiviga": "skivig",
    "skivigare": "skivig",
    "skivigares": "skivig",
    "skivigas": "skivig",
    "skivigast": "skivig",
    "skivigaste": "skivig",
    "skivigastes": "skivig",
    "skivigasts": "skivig",
    "skivige": "skivig",
    "skiviges": "skivig",
    "skivigs": "skivig",
    "skivigt": "skivig",
    "skivigts": "skivig",
    "skivinspelningar": "skivinspelning",
    "skivinspelningarna": "skivinspelning",
    "skivinspelningarnas": "skivinspelning",
    "skivinspelningars": "skivinspelning",
    "skivinspelningen": "skivinspelning",
    "skivinspelningens": "skivinspelning",
    "skivinspelnings": "skivinspelning",
    "skivkontrakten": "skivkontrakt",
    "skivkontraktens": "skivkontrakt",
    "skivkontraktet": "skivkontrakt",
    "skivkontraktets": "skivkontrakt",
    "skivkontrakts": "skivkontrakt",
    "skivlingar": "skivling",
    "skivlingarna": "skivling",
    "skivlingarnas": "skivling",
    "skivlingars": "skivling",
    "skivlingen": "skivling",
    "skivlingens": "skivling",
    "skivlings": "skivling",
    "skivminnen": "skivminne",
    "skivminnena": "skivminne",
    "skivminnenas": "skivminne",
    "skivminnens": "skivminne",
    "skivminnes": "skivminne",
    "skivminnet": "skivminne",
    "skivminnets": "skivminne",
    "skivomslagen": "skivomslag",
    "skivomslagens": "skivomslag",
    "skivomslaget": "skivomslag",
    "skivomslagets": "skivomslag",
    "skivomslags": "skivomslag",
    "skivor": "skiva",
    "skivorna": "skiva",
    "skivornas": "skiva",
    "skivors": "skiva",
    "skivpratar": "skivpratare",
    "skivprataren": "skivpratare",
    "skivpratarens": "skivpratare",
    "skivpratares": "skivpratare",
    "skivpratarna": "skivpratare",
    "skivpratarnas": "skivpratare",
    "skivs": "skiva",
    "skivsamlingar": "skivsamling",
    "skivsamlingarna": "skivsamling",
    "skivsamlingarnas": "skivsamling",
    "skivsamlingars": "skivsamling",
    "skivsamlingen": "skivsamling",
    "skivsamlingens": "skivsamling",
    "skivsamlings": "skivsamling",
    "skivspelar": "skivspelare",
    "skivspelaren": "skivspelare",
    "skivspelarens": "skivspelare",
    "skivspelares": "skivspelare",
    "skivspelarna": "skivspelare",
    "skivspelarnas": "skivspelare",
    "skivstänger": "skivstång",
    "skivstängerna": "skivstång",
    "skivstängernas": "skivstång",
    "skivstängers": "skivstång",
    "skivstången": "skivstång",
    "skivstångens": "skivstång",
    "skivstångs": "skivstång",
    "skivsvampar": "skivsvamp",
    "skivsvamparna": "skivsvamp",
    "skivsvamparnas": "skivsvamp",
    "skivsvampars": "skivsvamp",
    "skivsvampen": "skivsvamp",
    "skivsvampens": "skivsvamp",
    "skivsvamps": "skivsvamp",
    "skivtallrikar": "skivtallrik",
    "skivtallrikarna": "skivtallrik",
    "skivtallrikarnas": "skivtallrik",
    "skivtallrikars": "skivtallrik",
    "skivtallriken": "skivtallrik",
    "skivtallrikens": "skivtallrik",
    "skivtallriks": "skivtallrik",
    "skjort": "skjorta",
    "skjortan": "skjorta",
    "skjortans": "skjorta",
    "skjortas": "skjorta",
    "skjortblusar": "skjortblus",
    "skjortblusarna": "skjortblus",
    "skjortblusarnas": "skjortblus",
    "skjortblusars": "skjortblus",
    "skjortblusen": "skjortblus",
    "skjortblusens": "skjortblus",
    "skjortbrösten": "skjortbröst",
    "skjortbröstens": "skjortbröst",
    "skjortbröstet": "skjortbröst",
    "skjortbröstets": "skjortbröst",
    "skjortbrösts": "skjortbröst",
    "skjorte": "skjorta",
    "skjortkrag": "skjortkrage",
    "skjortkragar": "skjortkrage",
    "skjortkragarna": "skjortkrage",
    "skjortkragarnas": "skjortkrage",
    "skjortkragars": "skjortkrage",
    "skjortkragen": "skjortkrage",
    "skjortkragens": "skjortkrage",
    "skjortkrages": "skjortkrage",
    "skjortkrags": "skjortkrage",
    "skjortor": "skjorta",
    "skjortorna": "skjorta",
    "skjortornas": "skjorta",
    "skjortors": "skjorta",
    "skjorts": "skjorta",
    "skjortärmar": "skjortärm",
    "skjortärmarna": "skjortärm",
    "skjortärmarnas": "skjortärm",
    "skjortärmars": "skjortärm",
    "skjortärmen": "skjortärm",
    "skjortärmens": "skjortärm",
    "skjortärms": "skjortärm",
    "skjulen": "skjul",
    "skjulens": "skjul",
    "skjulet": "skjul",
    "skjulets": "skjul",
    "skjuls": "skjul",
    "skjut": "skjuta",
    "skjutande": "skjuta",
    "skjutanden": "skjutande",
    "skjutandena": "skjutande",
    "skjutandenas": "skjutande",
    "skjutandens": "skjutande",
    "skjutandes": "skjutande",
    "skjutandet": "skjutande",
    "skjutandets": "skjutande",
    "skjutas": "skjuta",
    "skjutbanan": "skjutbana",
    "skjutbanans": "skjutbana",
    "skjutbanas": "skjutbana",
    "skjutbane": "skjutbana",
    "skjutbanor": "skjutbana",
    "skjutbanorna": "skjutbana",
    "skjutbanornas": "skjutbana",
    "skjutbanors": "skjutbana",
    "skjutdörrar": "skjutdörr",
    "skjutdörrarna": "skjutdörr",
    "skjutdörrarnas": "skjutdörr",
    "skjutdörrars": "skjutdörr",
    "skjutdörren": "skjutdörr",
    "skjutdörrens": "skjutdörr",
    "skjutdörrs": "skjutdörr",
    "skjute": "skjuta",
    "skjuten": "skjuta",
    "skjutens": "skjuta",
    "skjuter": "skjuta",
    "skjutes": "skjuta",
    "skjutet": "skjuta",
    "skjutets": "skjuta",
    "skjutfälten": "skjutfält",
    "skjutfältens": "skjutfält",
    "skjutfältet": "skjutfält",
    "skjutfältets": "skjutfält",
    "skjutfälts": "skjutfält",
    "skjutfärdiga": "skjutfärdig",
    "skjutfärdigare": "skjutfärdig",
    "skjutfärdigares": "skjutfärdig",
    "skjutfärdigas": "skjutfärdig",
    "skjutfärdigast": "skjutfärdig",
    "skjutfärdigaste": "skjutfärdig",
    "skjutfärdigastes": "skjutfärdig",
    "skjutfärdigasts": "skjutfärdig",
    "skjutfärdige": "skjutfärdig",
    "skjutfärdiges": "skjutfärdig",
    "skjutfärdigs": "skjutfärdig",
    "skjutfärdigt": "skjutfärdig",
    "skjutfärdigts": "skjutfärdig",
    "skjutfönsterna": "skjutfönster",
    "skjutfönsternas": "skjutfönster",
    "skjutfönsters": "skjutfönster",
    "skjutfönstren": "skjutfönster",
    "skjutfönstrens": "skjutfönster",
    "skjutfönstret": "skjutfönster",
    "skjutfönstrets": "skjutfönster",
    "skjutit": "skjuta",
    "skjutits": "skjuta",
    "skjutjärnen": "skjutjärn",
    "skjutjärnens": "skjutjärn",
    "skjutjärnet": "skjutjärn",
    "skjutjärnets": "skjutjärn",
    "skjutjärns": "skjutjärn",
    "skjutjärnsintervjuer": "skjutjärnsintervju",
    "skjutjärnsintervjuerna": "skjutjärnsintervju",
    "skjutjärnsintervjuernas": "skjutjärnsintervju",
    "skjutjärnsintervjuers": "skjutjärnsintervju",
    "skjutjärnsintervjun": "skjutjärnsintervju",
    "skjutjärnsintervjuns": "skjutjärnsintervju",
    "skjutjärnsintervjus": "skjutjärnsintervju",
    "skjutjärnsjournalisten": "skjutjärnsjournalist",
    "skjutjärnsjournalistens": "skjutjärnsjournalist",
    "skjutjärnsjournalister": "skjutjärnsjournalist",
    "skjutjärnsjournalisterna": "skjutjärnsjournalist",
    "skjutjärnsjournalisternas": "skjutjärnsjournalist",
    "skjutjärnsjournalisters": "skjutjärnsjournalist",
    "skjutjärnsjournalists": "skjutjärnsjournalist",
    "skjutklara": "skjutklar",
    "skjutklarare": "skjutklar",
    "skjutklarares": "skjutklar",
    "skjutklaras": "skjutklar",
    "skjutklarast": "skjutklar",
    "skjutklaraste": "skjutklar",
    "skjutklarastes": "skjutklar",
    "skjutklarasts": "skjutklar",
    "skjutklare": "skjutklar",
    "skjutklares": "skjutklar",
    "skjutklars": "skjutklar",
    "skjutklart": "skjutklar",
    "skjutklarts": "skjutklar",
    "skjutmåtten": "skjutmått",
    "skjutmåttens": "skjutmått",
    "skjutmåttet": "skjutmått",
    "skjutmåttets": "skjutmått",
    "skjutmåtts": "skjutmått",
    "skjutmåttseten": "skjutmåttset",
    "skjutmåttsetens": "skjutmåttset",
    "skjutmåttsetet": "skjutmåttset",
    "skjutmåttsetets": "skjutmåttset",
    "skjutmåttsets": "skjutmåttset",
    "skjutna": "skjuta",
    "skjutnas": "skjuta",
    "skjutne": "skjuta",
    "skjutnes": "skjuta",
    "skjutningar": "skjutning",
    "skjutningarna": "skjutning",
    "skjutningarnas": "skjutning",
    "skjutningars": "skjutning",
    "skjutningen": "skjutning",
    "skjutningens": "skjutning",
    "skjutnings": "skjutning",
    "skjutriktningar": "skjutriktning",
    "skjutriktningarna": "skjutriktning",
    "skjutriktningarnas": "skjutriktning",
    "skjutriktningars": "skjutriktning",
    "skjutriktningen": "skjutriktning",
    "skjutriktningens": "skjutriktning",
    "skjutriktnings": "skjutriktning",
    "skjuts": "skjutsa",
    "skjutsad": "skjutsa",
    "skjutsade": "skjutsa",
    "skjutsades": "skjutsa",
    "skjutsads": "skjutsa",
    "skjutsande": "skjutsa",
    "skjutsanden": "skjutsande",
    "skjutsandena": "skjutsande",
    "skjutsandenas": "skjutsande",
    "skjutsandens": "skjutsande",
    "skjutsandes": "skjutsande",
    "skjutsandet": "skjutsande",
    "skjutsandets": "skjutsande",
    "skjutsar": "skjutsa",
    "skjutsarna": "skjuts",
    "skjutsarnas": "skjuts",
    "skjutsars": "skjuts",
    "skjutsas": "skjutsa",
    "skjutsat": "skjutsa",
    "skjutsats": "skjutsa",
    "skjutsen": "skjuts",
    "skjutsens": "skjuts",
    "skjutshållen": "skjutshåll",
    "skjutshållens": "skjutshåll",
    "skjutshållet": "skjutshåll",
    "skjutshållets": "skjutshåll",
    "skjutshålls": "skjutshåll",
    "skjutskår": "skjutskåre",
    "skjutskårar": "skjutskåre",
    "skjutskårarna": "skjutskåre",
    "skjutskårarnas": "skjutskåre",
    "skjutskårars": "skjutskåre",
    "skjutskåren": "skjutskåre",
    "skjutskårens": "skjutskåre",
    "skjutskåres": "skjutskåre",
    "skjutskårs": "skjutskåre",
    "skjututbildningar": "skjututbildning",
    "skjututbildningarna": "skjututbildning",
    "skjututbildningarnas": "skjututbildning",
    "skjututbildningars": "skjututbildning",
    "skjututbildningen": "skjututbildning",
    "skjututbildningens": "skjututbildning",
    "skjututbildnings": "skjututbildning",
    "skjutvapens": "skjutvapen",
    "skjutvapnen": "skjutvapen",
    "skjutvapnens": "skjutvapen",
    "skjutvapnet": "skjutvapen",
    "skjutvapnets": "skjutvapen",
    "skjutvinkeln": "skjutvinkel",
    "skjutvinkelns": "skjutvinkel",
    "skjutvinkels": "skjutvinkel",
    "skjutvinklar": "skjutvinkel",
    "skjutvinklarna": "skjutvinkel",
    "skjutvinklarnas": "skjutvinkel",
    "skjutvinklars": "skjutvinkel",
    "skjuv": "skjuva",
    "skjuvad": "skjuva",
    "skjuvade": "skjuva",
    "skjuvades": "skjuva",
    "skjuvads": "skjuva",
    "skjuvande": "skjuva",
    "skjuvanden": "skjuvande",
    "skjuvandena": "skjuvande",
    "skjuvandenas": "skjuvande",
    "skjuvandens": "skjuvande",
    "skjuvandes": "skjuvande",
    "skjuvandet": "skjuvande",
    "skjuvandets": "skjuvande",
    "skjuvar": "skjuva",
    "skjuvas": "skjuva",
    "skjuvat": "skjuva",
    "skjuvats": "skjuva",
    "sklerosen": "skleros",
    "sklerosens": "skleros",
    "skleroser": "skleros",
    "skleroserna": "skleros",
    "sklerosernas": "skleros",
    "sklerosers": "skleros",
    "sklerotiska": "sklerotisk",
    "sklerotiskare": "sklerotisk",
    "sklerotiskares": "sklerotisk",
    "sklerotiskas": "sklerotisk",
    "sklerotiskast": "sklerotisk",
    "sklerotiskaste": "sklerotisk",
    "sklerotiskastes": "sklerotisk",
    "sklerotiskasts": "sklerotisk",
    "sklerotiske": "sklerotisk",
    "sklerotiskes": "sklerotisk",
    "sklerotisks": "sklerotisk",
    "sklerotiskt": "sklerotisk",
    "sklerotiskts": "sklerotisk",
    "skoblocken": "skoblock",
    "skoblockens": "skoblock",
    "skoblocket": "skoblock",
    "skoblockets": "skoblock",
    "skoblocks": "skoblock",
    "skoborst": "skoborste",
    "skoborstar": "skoborste",
    "skoborstarna": "skoborste",
    "skoborstarnas": "skoborste",
    "skoborstars": "skoborste",
    "skoborsten": "skoborste",
    "skoborstens": "skoborste",
    "skoborstes": "skoborste",
    "skoborstningar": "skoborstning",
    "skoborstningarna": "skoborstning",
    "skoborstningarnas": "skoborstning",
    "skoborstningars": "skoborstning",
    "skoborstningen": "skoborstning",
    "skoborstningens": "skoborstning",
    "skoborstnings": "skoborstning",
    "skock": "skocka",
    "skockades": "skockas",
    "skockan": "skocka",
    "skockans": "skocka",
    "skockar": "skock",
    "skockarna": "skock",
    "skockarnas": "skock",
    "skockars": "skock",
    "skockas": "skocka",
    "skockats": "skockas",
    "skocke": "skocka",
    "skocken": "skock",
    "skockens": "skock",
    "skockor": "skocka",
    "skockorna": "skocka",
    "skockornas": "skocka",
    "skockors": "skocka",
    "skocks": "skocka",
    "skodd": "sko",
    "skodda": "sko",
    "skoddas": "sko",
    "skodde": "sko",
    "skoddes": "sko",
    "skodds": "sko",
    "skodonen": "skodon",
    "skodonens": "skodon",
    "skodonet": "skodon",
    "skodonets": "skodon",
    "skodons": "skodon",
    "skoende": "sko",
    "skoenden": "skoende",
    "skoendena": "skoende",
    "skoendenas": "skoende",
    "skoendens": "skoende",
    "skoendes": "skoende",
    "skoendet": "skoende",
    "skoendets": "skoende",
    "skoflickar": "skoflickare",
    "skoflickaren": "skoflickare",
    "skoflickarens": "skoflickare",
    "skoflickares": "skoflickare",
    "skoflickarna": "skoflickare",
    "skoflickarnas": "skoflickare",
    "skogar": "skog",
    "skogarna": "skog",
    "skogarnas": "skog",
    "skogars": "skog",
    "skogbevuxens": "skogbevuxen",
    "skogbevuxet": "skogbevuxen",
    "skogbevuxets": "skogbevuxen",
    "skogbevuxna": "skogbevuxen",
    "skogbevuxnare": "skogbevuxen",
    "skogbevuxnares": "skogbevuxen",
    "skogbevuxnas": "skogbevuxen",
    "skogbevuxnast": "skogbevuxen",
    "skogbevuxnaste": "skogbevuxen",
    "skogbevuxnastes": "skogbevuxen",
    "skogbevuxnasts": "skogbevuxen",
    "skogbevuxne": "skogbevuxen",
    "skogbevuxnes": "skogbevuxen",
    "skogbitar": "skogbit",
    "skogbitarna": "skogbit",
    "skogbitarnas": "skogbit",
    "skogbitars": "skogbit",
    "skogbiten": "skogbit",
    "skogbitens": "skogbit",
    "skogbits": "skogbit",
    "skogen": "skog",
    "skogens": "skog",
    "skogfattiga": "skogfattig",
    "skogfattigare": "skogfattig",
    "skogfattigares": "skogfattig",
    "skogfattigas": "skogfattig",
    "skogfattigast": "skogfattig",
    "skogfattigaste": "skogfattig",
    "skogfattigastes": "skogfattig",
    "skogfattigasts": "skogfattig",
    "skogfattige": "skogfattig",
    "skogfattiges": "skogfattig",
    "skogfattigheten": "skogfattighet",
    "skogfattighetens": "skogfattighet",
    "skogfattighets": "skogfattighet",
    "skogfattigs": "skogfattig",
    "skogfattigt": "skogfattig",
    "skogfattigts": "skogfattig",
    "skogiga": "skogig",
    "skogigare": "skogig",
    "skogigares": "skogig",
    "skogigas": "skogig",
    "skogigast": "skogig",
    "skogigaste": "skogig",
    "skogigastes": "skogig",
    "skogigasts": "skogig",
    "skogige": "skogig",
    "skogiges": "skogig",
    "skogigs": "skogig",
    "skogigt": "skogig",
    "skogigts": "skogig",
    "skogklädda": "skogklädd",
    "skogkläddare": "skogklädd",
    "skogkläddares": "skogklädd",
    "skogkläddas": "skogklädd",
    "skogkläddast": "skogklädd",
    "skogkläddaste": "skogklädd",
    "skogkläddastes": "skogklädd",
    "skogkläddasts": "skogklädd",
    "skogklädde": "skogklädd",
    "skogkläddes": "skogklädd",
    "skogkläddheten": "skogkläddhet",
    "skogkläddhetens": "skogkläddhet",
    "skogkläddhets": "skogkläddhet",
    "skogklädds": "skogklädd",
    "skogklätt": "skogklädd",
    "skogklätts": "skogklädd",
    "skogliga": "skoglig",
    "skogligare": "skoglig",
    "skogligares": "skoglig",
    "skogligas": "skoglig",
    "skogligast": "skoglig",
    "skogligaste": "skoglig",
    "skogligastes": "skoglig",
    "skogligasts": "skoglig",
    "skoglige": "skoglig",
    "skogliges": "skoglig",
    "skogligs": "skoglig",
    "skogligt": "skoglig",
    "skogligts": "skoglig",
    "skogs": "skog",
    "skogsarbetar": "skogsarbetare",
    "skogsarbetaren": "skogsarbetare",
    "skogsarbetarens": "skogsarbetare",
    "skogsarbetares": "skogsarbetare",
    "skogsarbetarna": "skogsarbetare",
    "skogsarbetarnas": "skogsarbetare",
    "skogsarbeten": "skogsarbete",
    "skogsarbetena": "skogsarbete",
    "skogsarbetenas": "skogsarbete",
    "skogsarbetens": "skogsarbete",
    "skogsarbetes": "skogsarbete",
    "skogsarbetet": "skogsarbete",
    "skogsarbetets": "skogsarbete",
    "skogsarbets": "skogsarbete",
    "skogsavverkningar": "skogsavverkning",
    "skogsavverkningarna": "skogsavverkning",
    "skogsavverkningarnas": "skogsavverkning",
    "skogsavverkningars": "skogsavverkning",
    "skogsavverkningen": "skogsavverkning",
    "skogsavverkningens": "skogsavverkning",
    "skogsavverknings": "skogsavverkning",
    "skogsback": "skogsbacke",
    "skogsbackar": "skogsbacke",
    "skogsbackarna": "skogsbacke",
    "skogsbackarnas": "skogsbacke",
    "skogsbackars": "skogsbacke",
    "skogsbacken": "skogsbacke",
    "skogsbackens": "skogsbacke",
    "skogsbackes": "skogsbacke",
    "skogsbacks": "skogsbacke",
    "skogsbagg": "skogsbagge",
    "skogsbaggar": "skogsbagge",
    "skogsbaggarna": "skogsbagge",
    "skogsbaggarnas": "skogsbagge",
    "skogsbaggars": "skogsbagge",
    "skogsbaggen": "skogsbagge",
    "skogsbaggens": "skogsbagge",
    "skogsbagges": "skogsbagge",
    "skogsbaggs": "skogsbagge",
    "skogsbeten": "skogsbete",
    "skogsbetena": "skogsbete",
    "skogsbetenas": "skogsbete",
    "skogsbetens": "skogsbete",
    "skogsbetes": "skogsbete",
    "skogsbetet": "skogsbete",
    "skogsbetets": "skogsbete",
    "skogsblom": "skogsblomma",
    "skogsblomman": "skogsblomma",
    "skogsblommans": "skogsblomma",
    "skogsblommas": "skogsblomma",
    "skogsblomme": "skogsblomma",
    "skogsblommor": "skogsblomma",
    "skogsblommorna": "skogsblomma",
    "skogsblommornas": "skogsblomma",
    "skogsblommors": "skogsblomma",
    "skogsbloms": "skogsblomma",
    "skogsbolagen": "skogsbolag",
    "skogsbolagens": "skogsbolag",
    "skogsbolaget": "skogsbolag",
    "skogsbolagets": "skogsbolag",
    "skogsbolags": "skogsbolag",
    "skogsbranden": "skogsbrand",
    "skogsbrandens": "skogsbrand",
    "skogsbrands": "skogsbrand",
    "skogsbruket": "skogsbruk",
    "skogsbrukets": "skogsbruk",
    "skogsbruks": "skogsbruk",
    "skogsbrynet": "skogsbryn",
    "skogsbrynets": "skogsbryn",
    "skogsbryns": "skogsbryn",
    "skogsbränder": "skogsbrand",
    "skogsbränderna": "skogsbrand",
    "skogsbrändernas": "skogsbrand",
    "skogsbränders": "skogsbrand",
    "skogsbäckar": "skogsbäck",
    "skogsbäckarna": "skogsbäck",
    "skogsbäckarnas": "skogsbäck",
    "skogsbäckars": "skogsbäck",
    "skogsbäcken": "skogsbäck",
    "skogsbäckens": "skogsbäck",
    "skogsbäcks": "skogsbäck",
    "skogsdungar": "skogsdunge",
    "skogsdungarna": "skogsdunge",
    "skogsdungarnas": "skogsdunge",
    "skogsdungars": "skogsdunge",
    "skogsdungen": "skogsdunge",
    "skogsdungens": "skogsdunge",
    "skogsdunges": "skogsdunge",
    "skogsduv": "skogsduva",
    "skogsduvan": "skogsduva",
    "skogsduvans": "skogsduva",
    "skogsduvas": "skogsduva",
    "skogsduve": "skogsduva",
    "skogsduvor": "skogsduva",
    "skogsduvorna": "skogsduva",
    "skogsduvornas": "skogsduva",
    "skogsduvors": "skogsduva",
    "skogsduvs": "skogsduva",
    "skogsdöden": "skogsdöd",
    "skogsdödens": "skogsdöd",
    "skogsdöds": "skogsdöd",
    "skogsfruar": "skogsfru",
    "skogsfruarna": "skogsfru",
    "skogsfruarnas": "skogsfru",
    "skogsfruars": "skogsfru",
    "skogsfrun": "skogsfru",
    "skogsfruns": "skogsfru",
    "skogsfrus": "skogsfru",
    "skogsfågeln": "skogsfågel",
    "skogsfågelns": "skogsfågel",
    "skogsfågels": "skogsfågel",
    "skogsfåglar": "skogsfågel",
    "skogsfåglarna": "skogsfågel",
    "skogsfåglarnas": "skogsfågel",
    "skogsfåglars": "skogsfågel",
    "skogsförbättringar": "skogsförbättring",
    "skogsförbättringarna": "skogsförbättring",
    "skogsförbättringarnas": "skogsförbättring",
    "skogsförbättringars": "skogsförbättring",
    "skogsförbättringen": "skogsförbättring",
    "skogsförbättringens": "skogsförbättring",
    "skogsförbättrings": "skogsförbättring",
    "skogsförvaltningar": "skogsförvaltning",
    "skogsförvaltningarna": "skogsförvaltning",
    "skogsförvaltningarnas": "skogsförvaltning",
    "skogsförvaltningars": "skogsförvaltning",
    "skogsförvaltningen": "skogsförvaltning",
    "skogsförvaltningens": "skogsförvaltning",
    "skogsförvaltnings": "skogsförvaltning",
    "skogsgenetiken": "skogsgenetik",
    "skogsgenetikens": "skogsgenetik",
    "skogsgenetikern": "skogsgenetiker",
    "skogsgenetikerna": "skogsgenetiker",
    "skogsgenetikernas": "skogsgenetiker",
    "skogsgenetikerns": "skogsgenetiker",
    "skogsgenetikers": "skogsgenetiker",
    "skogsgenetiks": "skogsgenetik",
    "skogsgenetiska": "skogsgenetisk",
    "skogsgenetiskare": "skogsgenetisk",
    "skogsgenetiskares": "skogsgenetisk",
    "skogsgenetiskas": "skogsgenetisk",
    "skogsgenetiskast": "skogsgenetisk",
    "skogsgenetiskaste": "skogsgenetisk",
    "skogsgenetiskastes": "skogsgenetisk",
    "skogsgenetiskasts": "skogsgenetisk",
    "skogsgenetiske": "skogsgenetisk",
    "skogsgenetiskes": "skogsgenetisk",
    "skogsgenetisks": "skogsgenetisk",
    "skogsgenetiskt": "skogsgenetisk",
    "skogsgenetiskts": "skogsgenetisk",
    "skogsgränsen": "skogsgräns",
    "skogsgränsens": "skogsgräns",
    "skogsgudar": "skogsgud",
    "skogsgudarna": "skogsgud",
    "skogsgudarnas": "skogsgud",
    "skogsgudars": "skogsgud",
    "skogsguden": "skogsgud",
    "skogsgudens": "skogsgud",
    "skogsguds": "skogsgud",
    "skogshuggar": "skogshuggare",
    "skogshuggaren": "skogshuggare",
    "skogshuggarens": "skogshuggare",
    "skogshuggares": "skogshuggare",
    "skogshuggarna": "skogshuggare",
    "skogshuggarnas": "skogshuggare",
    "skogshögskolan": "skogshögskola",
    "skogshögskolans": "skogshögskola",
    "skogshögskolas": "skogshögskola",
    "skogshögskole": "skogshögskola",
    "skogshögskolor": "skogshögskola",
    "skogshögskolorna": "skogshögskola",
    "skogshögskolornas": "skogshögskola",
    "skogshögskolors": "skogshögskola",
    "skogshönsen": "skogshöns",
    "skogshönsens": "skogshöns",
    "skogshönset": "skogshöns",
    "skogshönsets": "skogshöns",
    "skogsindustrien": "skogsindustri",
    "skogsindustriens": "skogsindustri",
    "skogsindustrier": "skogsindustri",
    "skogsindustrierna": "skogsindustri",
    "skogsindustriernas": "skogsindustri",
    "skogsindustriers": "skogsindustri",
    "skogsindustrin": "skogsindustri",
    "skogsindustrins": "skogsindustri",
    "skogsindustris": "skogsindustri",
    "skogsjack": "skogsjacka",
    "skogsjackan": "skogsjacka",
    "skogsjackans": "skogsjacka",
    "skogsjackas": "skogsjacka",
    "skogsjacke": "skogsjacka",
    "skogsjackor": "skogsjacka",
    "skogsjackorna": "skogsjacka",
    "skogsjackornas": "skogsjacka",
    "skogsjackors": "skogsjacka",
    "skogsjacks": "skogsjacka",
    "skogskovallen": "skogskovall",
    "skogskovallens": "skogskovall",
    "skogskovaller": "skogskovall",
    "skogskovallerna": "skogskovall",
    "skogskovallernas": "skogskovall",
    "skogskovallers": "skogskovall",
    "skogskovalls": "skogskovall",
    "skogslandet": "skogsland",
    "skogslandets": "skogsland",
    "skogslands": "skogsland",
    "skogslandskapen": "skogslandskap",
    "skogslandskapens": "skogslandskap",
    "skogslandskapet": "skogslandskap",
    "skogslandskapets": "skogslandskap",
    "skogslandskaps": "skogslandskap",
    "skogsmarken": "skogsmark",
    "skogsmarkens": "skogsmark",
    "skogsmarker": "skogsmark",
    "skogsmarkerna": "skogsmark",
    "skogsmarkernas": "skogsmark",
    "skogsmarkers": "skogsmark",
    "skogsmarks": "skogsmark",
    "skogsmulleskolan": "skogsmulleskola",
    "skogsmulleskolans": "skogsmulleskola",
    "skogsmulleskolas": "skogsmulleskola",
    "skogsmulleskole": "skogsmulleskola",
    "skogsmulleskolor": "skogsmulleskola",
    "skogsmulleskolorna": "skogsmulleskola",
    "skogsmulleskolornas": "skogsmulleskola",
    "skogsmulleskolors": "skogsmulleskola",
    "skogsmusen": "skogsmus",
    "skogsmusens": "skogsmus",
    "skogsmästar": "skogsmästare",
    "skogsmästaren": "skogsmästare",
    "skogsmästarens": "skogsmästare",
    "skogsmästares": "skogsmästare",
    "skogsmästarna": "skogsmästare",
    "skogsmästarnas": "skogsmästare",
    "skogsmöss": "skogsmus",
    "skogsmössen": "skogsmus",
    "skogsmössens": "skogsmus",
    "skogsnäv": "skogsnäva",
    "skogsnävan": "skogsnäva",
    "skogsnävans": "skogsnäva",
    "skogsnävas": "skogsnäva",
    "skogsnäve": "skogsnäva",
    "skogsnävor": "skogsnäva",
    "skogsnävorna": "skogsnäva",
    "skogsnävornas": "skogsnäva",
    "skogsnävors": "skogsnäva",
    "skogsnävs": "skogsnäva",
    "skogsområden": "skogsområde",
    "skogsområdena": "skogsområde",
    "skogsområdenas": "skogsområde",
    "skogsområdens": "skogsområde",
    "skogsområdes": "skogsområde",
    "skogsområdet": "skogsområde",
    "skogsområdets": "skogsområde",
    "skogsrået": "skogsrå",
    "skogsråets": "skogsrå",
    "skogsrån": "skogsrå",
    "skogsråna": "skogsrå",
    "skogsrånas": "skogsrå",
    "skogsråns": "skogsrå",
    "skogsrår": "skogsrå",
    "skogsrårna": "skogsrå",
    "skogsrårnas": "skogsrå",
    "skogsrårs": "skogsrå",
    "skogsrås": "skogsrå",
    "skogsråt": "skogsrå",
    "skogsråts": "skogsrå",
    "skogsskötseln": "skogsskötsel",
    "skogsskötselns": "skogsskötsel",
    "skogsskötsels": "skogsskötsel",
    "skogssnuv": "skogssnuva",
    "skogssnuvan": "skogssnuva",
    "skogssnuvans": "skogssnuva",
    "skogssnuvas": "skogssnuva",
    "skogssnuve": "skogssnuva",
    "skogssnuvor": "skogssnuva",
    "skogssnuvorna": "skogssnuva",
    "skogssnuvornas": "skogssnuva",
    "skogssnuvors": "skogssnuva",
    "skogssnuvs": "skogssnuva",
    "skogsstjärnan": "skogsstjärna",
    "skogsstjärnans": "skogsstjärna",
    "skogsstjärnas": "skogsstjärna",
    "skogsstjärne": "skogsstjärna",
    "skogsstjärnor": "skogsstjärna",
    "skogsstjärnorna": "skogsstjärna",
    "skogsstjärnornas": "skogsstjärna",
    "skogsstjärnors": "skogsstjärna",
    "skogsterrängen": "skogsterräng",
    "skogsterrängens": "skogsterräng",
    "skogsterrängs": "skogsterräng",
    "skogstomten": "skogstomt",
    "skogstomtens": "skogstomt",
    "skogstomter": "skogstomt",
    "skogstomterna": "skogstomt",
    "skogstomternas": "skogstomt",
    "skogstomters": "skogstomt",
    "skogstomts": "skogstomt",
    "skogsträden": "skogsträd",
    "skogsträdens": "skogsträd",
    "skogsträdet": "skogsträd",
    "skogsträdets": "skogsträd",
    "skogsträds": "skogsträd",
    "skogsträdsförädlar": "skogsträdsförädlare",
    "skogsträdsförädlaren": "skogsträdsförädlare",
    "skogsträdsförädlarens": "skogsträdsförädlare",
    "skogsträdsförädlares": "skogsträdsförädlare",
    "skogsträdsförädlarna": "skogsträdsförädlare",
    "skogsträdsförädlarnas": "skogsträdsförädlare",
    "skogsträn": "skogsträd",
    "skogsträna": "skogsträd",
    "skogstränas": "skogsträd",
    "skogsträns": "skogsträd",
    "skogsvandringar": "skogsvandring",
    "skogsvandringarna": "skogsvandring",
    "skogsvandringarnas": "skogsvandring",
    "skogsvandringars": "skogsvandring",
    "skogsvandringen": "skogsvandring",
    "skogsvandringens": "skogsvandring",
    "skogsvandrings": "skogsvandring",
    "skogsvägar": "skogsväg",
    "skogsvägarna": "skogsväg",
    "skogsvägarnas": "skogsväg",
    "skogsvägars": "skogsväg",
    "skogsvägen": "skogsväg",
    "skogsvägens": "skogsväg",
    "skogsvägs": "skogsväg",
    "skogsvårdar": "skogsvård",
    "skogsvårdarna": "skogsvård",
    "skogsvårdarnas": "skogsvård",
    "skogsvårdars": "skogsvård",
    "skogsvården": "skogsvård",
    "skogsvårdens": "skogsvård",
    "skogsvårds": "skogsvård",
    "skogvaktar": "skogvaktare",
    "skogvaktaren": "skogvaktare",
    "skogvaktarens": "skogvaktare",
    "skogvaktares": "skogvaktare",
    "skogvaktarna": "skogvaktare",
    "skogvaktarnas": "skogvaktare",
    "skohornen": "skohorn",
    "skohornens": "skohorn",
    "skohornet": "skohorn",
    "skohornets": "skohorn",
    "skohorns": "skohorn",
    "skojad": "skoja",
    "skojade": "skoja",
    "skojades": "skoja",
    "skojads": "skoja",
    "skojande": "skoja",
    "skojanden": "skojande",
    "skojandena": "skojande",
    "skojandenas": "skojande",
    "skojandens": "skojande",
    "skojandes": "skojande",
    "skojandet": "skojande",
    "skojandets": "skojande",
    "skojar": "skojare",
    "skojaren": "skojare",
    "skojarens": "skojare",
    "skojares": "skojare",
    "skojarna": "skojare",
    "skojarnas": "skojare",
    "skojas": "skoja",
    "skojat": "skoja",
    "skojats": "skoja",
    "skojen": "skoj",
    "skojens": "skoj",
    "skojerier": "skojeri",
    "skojerierna": "skojeri",
    "skojeriernas": "skojeri",
    "skojeriers": "skojeri",
    "skojeriet": "skojeri",
    "skojeriets": "skojeri",
    "skojeris": "skojeri",
    "skojerit": "skojeri",
    "skojerits": "skojeri",
    "skojet": "skoj",
    "skojets": "skoj",
    "skojfriska": "skojfrisk",
    "skojfriskare": "skojfrisk",
    "skojfriskares": "skojfrisk",
    "skojfriskas": "skojfrisk",
    "skojfriskast": "skojfrisk",
    "skojfriskaste": "skojfrisk",
    "skojfriskastes": "skojfrisk",
    "skojfriskasts": "skojfrisk",
    "skojfriske": "skojfrisk",
    "skojfriskes": "skojfrisk",
    "skojfrisks": "skojfrisk",
    "skojfriskt": "skojfrisk",
    "skojfriskts": "skojfrisk",
    "skojiga": "skojig",
    "skojigare": "skojig",
    "skojigares": "skojig",
    "skojigas": "skojig",
    "skojigast": "skojig",
    "skojigaste": "skojig",
    "skojigastes": "skojig",
    "skojigasts": "skojig",
    "skojige": "skojig",
    "skojiges": "skojig",
    "skojigheten": "skojighet",
    "skojighetens": "skojighet",
    "skojigheter": "skojighet",
    "skojigheterna": "skojighet",
    "skojigheternas": "skojighet",
    "skojigheters": "skojighet",
    "skojighets": "skojighet",
    "skojigs": "skojig",
    "skojigt": "skojig",
    "skojigts": "skojig",
    "skojs": "skoj",
    "skokartongen": "skokartong",
    "skokartongens": "skokartong",
    "skokartonger": "skokartong",
    "skokartongerna": "skokartong",
    "skokartongernas": "skokartong",
    "skokartongers": "skokartong",
    "skokartongs": "skokartong",
    "skoklädda": "skoklädd",
    "skokläddare": "skoklädd",
    "skokläddares": "skoklädd",
    "skokläddas": "skoklädd",
    "skokläddast": "skoklädd",
    "skokläddaste": "skoklädd",
    "skokläddastes": "skoklädd",
    "skokläddasts": "skoklädd",
    "skoklädde": "skoklädd",
    "skokläddes": "skoklädd",
    "skoklädds": "skoklädd",
    "skoklätt": "skoklädd",
    "skoklätts": "skoklädd",
    "skokrämen": "skokräm",
    "skokrämens": "skokräm",
    "skokrämer": "skokräm",
    "skokrämerna": "skokräm",
    "skokrämernas": "skokräm",
    "skokrämers": "skokräm",
    "skokräms": "skokräm",
    "skol": "skola",
    "skol-TV-n": "skol-TV",
    "skol-TV-na": "skol-TV",
    "skol-TV-nas": "skol-TV",
    "skol-TV-ns": "skol-TV",
    "skol-TV-s": "skol-TV",
    "skol-TV:n": "skol-TV",
    "skol-TV:na": "skol-TV",
    "skol-TV:nas": "skol-TV",
    "skol-TV:ns": "skol-TV",
    "skol-TV:s": "skol-TV",
    "skol-TVn": "skol-TV",
    "skol-TVna": "skol-TV",
    "skol-TVnas": "skol-TV",
    "skol-TVns": "skol-TV",
    "skol-TVs": "skol-TV",
    "skolad": "skola",
    "skolade": "skola",
    "skolades": "skola",
    "skolads": "skola",
    "skolan": "skola",
    "skolande": "skola",
    "skolanden": "skolande",
    "skolandena": "skolande",
    "skolandenas": "skolande",
    "skolandens": "skolande",
    "skolandes": "skolande",
    "skolandet": "skolande",
    "skolandets": "skolande",
    "skolans": "skola",
    "skolar": "skola",
    "skolarbeten": "skolarbete",
    "skolarbetena": "skolarbete",
    "skolarbetenas": "skolarbete",
    "skolarbetens": "skolarbete",
    "skolarbetes": "skolarbete",
    "skolarbetet": "skolarbete",
    "skolarbetets": "skolarbete",
    "skolarbets": "skolarbete",
    "skolas": "skola",
    "skolastiken": "skolastik",
    "skolastikens": "skolastik",
    "skolastikern": "skolastiker",
    "skolastikerna": "skolastiker",
    "skolastikernas": "skolastiker",
    "skolastikerns": "skolastiker",
    "skolastikers": "skolastiker",
    "skolastiks": "skolastik",
    "skolastiska": "skolastisk",
    "skolastiskare": "skolastisk",
    "skolastiskares": "skolastisk",
    "skolastiskas": "skolastisk",
    "skolastiskast": "skolastisk",
    "skolastiskaste": "skolastisk",
    "skolastiskastes": "skolastisk",
    "skolastiskasts": "skolastisk",
    "skolastiske": "skolastisk",
    "skolastiskes": "skolastisk",
    "skolastisks": "skolastisk",
    "skolastiskt": "skolastisk",
    "skolastiskts": "skolastisk",
    "skolat": "skola",
    "skolats": "skola",
    "skolavgiften": "skolavgift",
    "skolavgiftens": "skolavgift",
    "skolavgifter": "skolavgift",
    "skolavgifterna": "skolavgift",
    "skolavgifternas": "skolavgift",
    "skolavgifters": "skolavgift",
    "skolavgifts": "skolavgift",
    "skolavslutningar": "skolavslutning",
    "skolavslutningarna": "skolavslutning",
    "skolavslutningarnas": "skolavslutning",
    "skolavslutningars": "skolavslutning",
    "skolavslutningen": "skolavslutning",
    "skolavslutningens": "skolavslutning",
    "skolavslutnings": "skolavslutning",
    "skolbarnen": "skolbarn",
    "skolbarnens": "skolbarn",
    "skolbarnet": "skolbarn",
    "skolbarnets": "skolbarn",
    "skolbarns": "skolbarn",
    "skolbildningar": "skolbildning",
    "skolbildningarna": "skolbildning",
    "skolbildningarnas": "skolbildning",
    "skolbildningars": "skolbildning",
    "skolbildningen": "skolbildning",
    "skolbildningens": "skolbildning",
    "skolbildnings": "skolbildning",
    "skolboken": "skolbok",
    "skolbokens": "skolbok",
    "skolboks": "skolbok",
    "skolboksmässiga": "skolboksmässig",
    "skolboksmässigare": "skolboksmässig",
    "skolboksmässigares": "skolboksmässig",
    "skolboksmässigas": "skolboksmässig",
    "skolboksmässigast": "skolboksmässig",
    "skolboksmässigaste": "skolboksmässig",
    "skolboksmässigastes": "skolboksmässig",
    "skolboksmässigasts": "skolboksmässig",
    "skolboksmässige": "skolboksmässig",
    "skolboksmässiges": "skolboksmässig",
    "skolboksmässigs": "skolboksmässig",
    "skolboksmässigt": "skolboksmässig",
    "skolboksmässigts": "skolboksmässig",
    "skolbranden": "skolbrand",
    "skolbrandens": "skolbrand",
    "skolbrands": "skolbrand",
    "skolbränder": "skolbrand",
    "skolbränderna": "skolbrand",
    "skolbrändernas": "skolbrand",
    "skolbränders": "skolbrand",
    "skolbussar": "skolbuss",
    "skolbussarna": "skolbuss",
    "skolbussarnas": "skolbuss",
    "skolbussars": "skolbuss",
    "skolbussen": "skolbuss",
    "skolbussens": "skolbuss",
    "skolbyggnaden": "skolbyggnad",
    "skolbyggnadens": "skolbyggnad",
    "skolbyggnader": "skolbyggnad",
    "skolbyggnaderna": "skolbyggnad",
    "skolbyggnadernas": "skolbyggnad",
    "skolbyggnaders": "skolbyggnad",
    "skolbyggnads": "skolbyggnad",
    "skolbänkar": "skolbänk",
    "skolbänkarna": "skolbänk",
    "skolbänkarnas": "skolbänk",
    "skolbänkars": "skolbänk",
    "skolbänken": "skolbänk",
    "skolbänkens": "skolbänk",
    "skolbänks": "skolbänk",
    "skolböcker": "skolbok",
    "skolböckerna": "skolbok",
    "skolböckernas": "skolbok",
    "skolböckers": "skolbok",
    "skolchefen": "skolchef",
    "skolchefens": "skolchef",
    "skolchefer": "skolchef",
    "skolcheferna": "skolchef",
    "skolchefernas": "skolchef",
    "skolchefers": "skolchef",
    "skolchefs": "skolchef",
    "skoldagar": "skoldag",
    "skoldagarna": "skoldag",
    "skoldagarnas": "skoldag",
    "skoldagars": "skoldag",
    "skoldagen": "skoldag",
    "skoldagens": "skoldag",
    "skoldags": "skoldag",
    "skoldansen": "skoldans",
    "skoldansens": "skoldans",
    "skoldanser": "skoldans",
    "skoldanserna": "skoldans",
    "skoldansernas": "skoldans",
    "skoldansers": "skoldans",
    "skoldirektören": "skoldirektör",
    "skoldirektörens": "skoldirektör",
    "skoldirektörer": "skoldirektör",
    "skoldirektörerna": "skoldirektör",
    "skoldirektörernas": "skoldirektör",
    "skoldirektörers": "skoldirektör",
    "skoldirektörn": "skoldirektör",
    "skoldirektörns": "skoldirektör",
    "skoldirektörs": "skoldirektör",
    "skoldistrikten": "skoldistrikt",
    "skoldistriktens": "skoldistrikt",
    "skoldistriktet": "skoldistrikt",
    "skoldistriktets": "skoldistrikt",
    "skoldistrikts": "skoldistrikt",
    "skole": "skola",
    "skoleleven": "skolelev",
    "skolelevens": "skolelev",
    "skolelever": "skolelev",
    "skoleleverna": "skolelev",
    "skolelevernas": "skolelev",
    "skolelevers": "skolelev",
    "skolelevs": "skolelev",
    "skolexempels": "skolexempel",
    "skolexemplen": "skolexempel",
    "skolexemplens": "skolexempel",
    "skolexemplet": "skolexempel",
    "skolexemplets": "skolexempel",
    "skolfartygen": "skolfartyg",
    "skolfartygens": "skolfartyg",
    "skolfartyget": "skolfartyg",
    "skolfartygets": "skolfartyg",
    "skolfartygs": "skolfartyg",
    "skolflick": "skolflicka",
    "skolflickan": "skolflicka",
    "skolflickans": "skolflicka",
    "skolflickas": "skolflicka",
    "skolflicke": "skolflicka",
    "skolflickor": "skolflicka",
    "skolflickorna": "skolflicka",
    "skolflickornas": "skolflicka",
    "skolflickors": "skolflicka",
    "skolflicks": "skolflicka",
    "skolflygplanen": "skolflygplan",
    "skolflygplanens": "skolflygplan",
    "skolflygplanet": "skolflygplan",
    "skolflygplanets": "skolflygplan",
    "skolflygplans": "skolflygplan",
    "skolformen": "skolform",
    "skolformens": "skolform",
    "skolformer": "skolform",
    "skolformerna": "skolform",
    "skolformernas": "skolform",
    "skolformers": "skolform",
    "skolforms": "skolform",
    "skolfransk": "skolfranska",
    "skolfranskan": "skolfranska",
    "skolfranskans": "skolfranska",
    "skolfranskas": "skolfranska",
    "skolfrökens": "skolfröken",
    "skolfröknar": "skolfröken",
    "skolfröknarna": "skolfröken",
    "skolfröknarnas": "skolfröken",
    "skolfröknars": "skolfröken",
    "skolfröknen": "skolfröken",
    "skolfröknens": "skolfröken",
    "skolfuxar": "skolfux",
    "skolfuxarna": "skolfux",
    "skolfuxarnas": "skolfux",
    "skolfuxars": "skolfux",
    "skolfuxen": "skolfux",
    "skolfuxens": "skolfux",
    "skolförvaltningar": "skolförvaltning",
    "skolförvaltningarna": "skolförvaltning",
    "skolförvaltningarnas": "skolförvaltning",
    "skolförvaltningars": "skolförvaltning",
    "skolförvaltningen": "skolförvaltning",
    "skolförvaltningens": "skolförvaltning",
    "skolförvaltnings": "skolförvaltning",
    "skolgrammatiken": "skolgrammatik",
    "skolgrammatikens": "skolgrammatik",
    "skolgrammatiker": "skolgrammatik",
    "skolgrammatikerna": "skolgrammatik",
    "skolgrammatikernas": "skolgrammatik",
    "skolgrammatikers": "skolgrammatik",
    "skolgrammatiks": "skolgrammatik",
    "skolgången": "skolgång",
    "skolgångens": "skolgång",
    "skolgångs": "skolgång",
    "skolgårdar": "skolgård",
    "skolgårdarna": "skolgård",
    "skolgårdarnas": "skolgård",
    "skolgårdars": "skolgård",
    "skolgården": "skolgård",
    "skolgårdens": "skolgård",
    "skolgårds": "skolgård",
    "skolhemmen": "skolhem",
    "skolhemmens": "skolhem",
    "skolhemmet": "skolhem",
    "skolhemmets": "skolhem",
    "skolhems": "skolhem",
    "skolhusen": "skolhus",
    "skolhusens": "skolhus",
    "skolhuset": "skolhus",
    "skolhusets": "skolhus",
    "skolhälsovården": "skolhälsovård",
    "skolhälsovårdens": "skolhälsovård",
    "skolhälsovårds": "skolhälsovård",
    "skolinspektören": "skolinspektör",
    "skolinspektörens": "skolinspektör",
    "skolinspektörer": "skolinspektör",
    "skolinspektörerna": "skolinspektör",
    "skolinspektörernas": "skolinspektör",
    "skolinspektörers": "skolinspektör",
    "skolinspektörn": "skolinspektör",
    "skolinspektörns": "skolinspektör",
    "skolinspektörs": "skolinspektör",
    "skoliosen": "skolios",
    "skoliosens": "skolios",
    "skoljazzen": "skoljazz",
    "skoljazzens": "skoljazz",
    "skoljazztävlingar": "skoljazztävling",
    "skoljazztävlingarna": "skoljazztävling",
    "skoljazztävlingarnas": "skoljazztävling",
    "skoljazztävlingars": "skoljazztävling",
    "skoljazztävlingen": "skoljazztävling",
    "skoljazztävlingens": "skoljazztävling",
    "skoljazztävlings": "skoljazztävling",
    "skoljournalen": "skoljournal",
    "skoljournalens": "skoljournal",
    "skoljournaler": "skoljournal",
    "skoljournalerna": "skoljournal",
    "skoljournalernas": "skoljournal",
    "skoljournalers": "skoljournal",
    "skoljournals": "skoljournal",
    "skolkade": "skolka",
    "skolkades": "skolka",
    "skolkande": "skolka",
    "skolkanden": "skolkande",
    "skolkandena": "skolkande",
    "skolkandenas": "skolkande",
    "skolkandens": "skolkande",
    "skolkandes": "skolkande",
    "skolkandet": "skolkande",
    "skolkandets": "skolkande",
    "skolkar": "skolkare",
    "skolkaren": "skolkare",
    "skolkarens": "skolkare",
    "skolkares": "skolkare",
    "skolkarna": "skolkare",
    "skolkarnas": "skolkare",
    "skolkas": "skolka",
    "skolkat": "skolka",
    "skolkats": "skolka",
    "skolket": "skolk",
    "skolkets": "skolk",
    "skolklassen": "skolklass",
    "skolklassens": "skolklass",
    "skolklasser": "skolklass",
    "skolklasserna": "skolklass",
    "skolklassernas": "skolklass",
    "skolklassers": "skolklass",
    "skolkorridoren": "skolkorridor",
    "skolkorridorens": "skolkorridor",
    "skolkorridorer": "skolkorridor",
    "skolkorridorerna": "skolkorridor",
    "skolkorridorernas": "skolkorridor",
    "skolkorridorers": "skolkorridor",
    "skolkorridors": "skolkorridor",
    "skolkorten": "skolkort",
    "skolkortens": "skolkort",
    "skolkortet": "skolkort",
    "skolkortets": "skolkort",
    "skolkorts": "skolkort",
    "skolks": "skolk",
    "skolköken": "skolkök",
    "skolkökens": "skolkök",
    "skolköket": "skolkök",
    "skolkökets": "skolkök",
    "skolköks": "skolkök",
    "skolledar": "skolledare",
    "skolledaren": "skolledare",
    "skolledarens": "skolledare",
    "skolledares": "skolledare",
    "skolledarna": "skolledare",
    "skolledarnas": "skolledare",
    "skolljusen": "skolljus",
    "skolljusens": "skolljus",
    "skolljuset": "skolljus",
    "skolljusets": "skolljus",
    "skolloven": "skollov",
    "skollovens": "skollov",
    "skollovet": "skollov",
    "skollovets": "skollov",
    "skollovs": "skollov",
    "skollunchen": "skollunch",
    "skollunchens": "skollunch",
    "skolluncher": "skollunch",
    "skolluncherna": "skollunch",
    "skollunchernas": "skollunch",
    "skollunchers": "skollunch",
    "skollunchs": "skollunch",
    "skolmagistern": "skolmagister",
    "skolmagisterns": "skolmagister",
    "skolmagisters": "skolmagister",
    "skolmagistrar": "skolmagister",
    "skolmagistrarna": "skolmagister",
    "skolmagistrarnas": "skolmagister",
    "skolmagistrars": "skolmagister",
    "skolmassakern": "skolmassaker",
    "skolmassakerns": "skolmassaker",
    "skolmassakers": "skolmassaker",
    "skolmassakrer": "skolmassaker",
    "skolmassakrerna": "skolmassaker",
    "skolmassakrernas": "skolmassaker",
    "skolmassakrers": "skolmassaker",
    "skolmatematiken": "skolmatematik",
    "skolmatematikens": "skolmatematik",
    "skolmatematiks": "skolmatematik",
    "skolmaten": "skolmat",
    "skolmatens": "skolmat",
    "skolmats": "skolmat",
    "skolmogens": "skolmogen",
    "skolmoget": "skolmogen",
    "skolmogets": "skolmogen",
    "skolmogna": "skolmogen",
    "skolmognaden": "skolmognad",
    "skolmognadens": "skolmognad",
    "skolmognader": "skolmognad",
    "skolmognaderna": "skolmognad",
    "skolmognadernas": "skolmognad",
    "skolmognaders": "skolmognad",
    "skolmognads": "skolmognad",
    "skolmognadsklassen": "skolmognadsklass",
    "skolmognadsklassens": "skolmognadsklass",
    "skolmognadsklasser": "skolmognadsklass",
    "skolmognadsklasserna": "skolmognadsklass",
    "skolmognadsklassernas": "skolmognadsklass",
    "skolmognadsklassers": "skolmognadsklass",
    "skolmognadsproven": "skolmognadsprov",
    "skolmognadsprovens": "skolmognadsprov",
    "skolmognadsprovet": "skolmognadsprov",
    "skolmognadsprovets": "skolmognadsprov",
    "skolmognadsprovs": "skolmognadsprov",
    "skolmognare": "skolmogen",
    "skolmognares": "skolmogen",
    "skolmognas": "skolmogen",
    "skolmognast": "skolmogen",
    "skolmognaste": "skolmogen",
    "skolmognastes": "skolmogen",
    "skolmognasts": "skolmogen",
    "skolmogne": "skolmogen",
    "skolmognes": "skolmogen",
    "skolmyndigheten": "skolmyndighet",
    "skolmyndighetens": "skolmyndighet",
    "skolmyndigheter": "skolmyndighet",
    "skolmyndigheterna": "skolmyndighet",
    "skolmyndigheternas": "skolmyndighet",
    "skolmyndigheters": "skolmyndighet",
    "skolmyndighets": "skolmyndighet",
    "skolmässiga": "skolmässig",
    "skolmässigare": "skolmässig",
    "skolmässigares": "skolmässig",
    "skolmässigas": "skolmässig",
    "skolmässigast": "skolmässig",
    "skolmässigaste": "skolmässig",
    "skolmässigastes": "skolmässig",
    "skolmässigasts": "skolmässig",
    "skolmässige": "skolmässig",
    "skolmässiges": "skolmässig",
    "skolmässigs": "skolmässig",
    "skolmässigt": "skolmässig",
    "skolmässigts": "skolmässig",
    "skolmästar": "skolmästare",
    "skolmästaraktiga": "skolmästaraktig",
    "skolmästaraktigare": "skolmästaraktig",
    "skolmästaraktigares": "skolmästaraktig",
    "skolmästaraktigas": "skolmästaraktig",
    "skolmästaraktigast": "skolmästaraktig",
    "skolmästaraktigaste": "skolmästaraktig",
    "skolmästaraktigastes": "skolmästaraktig",
    "skolmästaraktigasts": "skolmästaraktig",
    "skolmästaraktige": "skolmästaraktig",
    "skolmästaraktiges": "skolmästaraktig",
    "skolmästaraktigheten": "skolmästaraktighet",
    "skolmästaraktighetens": "skolmästaraktighet",
    "skolmästaraktighets": "skolmästaraktighet",
    "skolmästaraktigs": "skolmästaraktig",
    "skolmästaraktigt": "skolmästaraktig",
    "skolmästaraktigts": "skolmästaraktig",
    "skolmästaren": "skolmästare",
    "skolmästarens": "skolmästare",
    "skolmästares": "skolmästare",
    "skolmästarna": "skolmästare",
    "skolmästarnas": "skolmästare",
    "skolmåltiden": "skolmåltid",
    "skolmåltidens": "skolmåltid",
    "skolmåltider": "skolmåltid",
    "skolmåltiderna": "skolmåltid",
    "skolmåltidernas": "skolmåltid",
    "skolmåltiders": "skolmåltid",
    "skolmåltids": "skolmåltid",
    "skolmöss": "skolmössa",
    "skolmössan": "skolmössa",
    "skolmössans": "skolmössa",
    "skolmössas": "skolmössa",
    "skolmösse": "skolmössa",
    "skolmössor": "skolmössa",
    "skolmössorna": "skolmössa",
    "skolmössornas": "skolmössa",
    "skolmössors": "skolmössa",
    "skolningar": "skolning",
    "skolningarna": "skolning",
    "skolningarnas": "skolning",
    "skolningars": "skolning",
    "skolningen": "skolning",
    "skolningens": "skolning",
    "skolnings": "skolning",
    "skolnämnden": "skolnämnd",
    "skolnämndens": "skolnämnd",
    "skolnämnder": "skolnämnd",
    "skolnämnderna": "skolnämnd",
    "skolnämndernas": "skolnämnd",
    "skolnämnders": "skolnämnd",
    "skolnämnds": "skolnämnd",
    "skolor": "skola",
    "skolorna": "skola",
    "skolornas": "skola",
    "skolors": "skola",
    "skolpersonalen": "skolpersonal",
    "skolpersonalens": "skolpersonal",
    "skolpersonals": "skolpersonal",
    "skolpolisen": "skolpolis",
    "skolpolisens": "skolpolis",
    "skolpoliser": "skolpolis",
    "skolpoliserna": "skolpolis",
    "skolpolisernas": "skolpolis",
    "skolpolisers": "skolpolis",
    "skolpolitiken": "skolpolitik",
    "skolpolitikens": "skolpolitik",
    "skolpolitiks": "skolpolitik",
    "skolpolitiska": "skolpolitisk",
    "skolpolitiskas": "skolpolitisk",
    "skolpolitiske": "skolpolitisk",
    "skolpolitiskes": "skolpolitisk",
    "skolpolitisks": "skolpolitisk",
    "skolpolitiskt": "skolpolitisk",
    "skolpolitiskts": "skolpolitisk",
    "skolproven": "skolprov",
    "skolprovens": "skolprov",
    "skolprovet": "skolprov",
    "skolprovets": "skolprov",
    "skolprovs": "skolprov",
    "skolradion": "skolradio",
    "skolradions": "skolradio",
    "skolradios": "skolradio",
    "skolresan": "skolresa",
    "skolresans": "skolresa",
    "skolresas": "skolresa",
    "skolrese": "skolresa",
    "skolresor": "skolresa",
    "skolresorna": "skolresa",
    "skolresornas": "skolresa",
    "skolresors": "skolresa",
    "skolridningar": "skolridning",
    "skolridningarna": "skolridning",
    "skolridningarnas": "skolridning",
    "skolridningars": "skolridning",
    "skolridningen": "skolridning",
    "skolridningens": "skolridning",
    "skolridnings": "skolridning",
    "skolråden": "skolråd",
    "skolrådens": "skolråd",
    "skolrådet": "skolråd",
    "skolrådets": "skolråd",
    "skolråds": "skolråd",
    "skols": "skola",
    "skolsalar": "skolsal",
    "skolsalarna": "skolsal",
    "skolsalarnas": "skolsal",
    "skolsalars": "skolsal",
    "skolsalen": "skolsal",
    "skolsalens": "skolsal",
    "skolsals": "skolsal",
    "skolsituationen": "skolsituation",
    "skolsituationens": "skolsituation",
    "skolsituationer": "skolsituation",
    "skolsituationerna": "skolsituation",
    "skolsituationernas": "skolsituation",
    "skolsituationers": "skolsituation",
    "skolsituations": "skolsituation",
    "skolsjuka": "skolsjuk",
    "skolsjukare": "skolsjuk",
    "skolsjukares": "skolsjuk",
    "skolsjukas": "skolsjuk",
    "skolsjukast": "skolsjuk",
    "skolsjukaste": "skolsjuk",
    "skolsjukastes": "skolsjuk",
    "skolsjukasts": "skolsjuk",
    "skolsjuke": "skolsjuk",
    "skolsjukes": "skolsjuk",
    "skolsjukheten": "skolsjukhet",
    "skolsjukhetens": "skolsjukhet",
    "skolsjukhets": "skolsjukhet",
    "skolsjuks": "skolsjuk",
    "skolsjukt": "skolsjuk",
    "skolsjukts": "skolsjuk",
    "skolskeppen": "skolskepp",
    "skolskeppens": "skolskepp",
    "skolskeppet": "skolskepp",
    "skolskeppets": "skolskepp",
    "skolskepps": "skolskepp",
    "skolskjutningar": "skolskjutning",
    "skolskjutningarna": "skolskjutning",
    "skolskjutningarnas": "skolskjutning",
    "skolskjutningars": "skolskjutning",
    "skolskjutningen": "skolskjutning",
    "skolskjutningens": "skolskjutning",
    "skolskjutnings": "skolskjutning",
    "skolskjutsar": "skolskjuts",
    "skolskjutsarna": "skolskjuts",
    "skolskjutsarnas": "skolskjuts",
    "skolskjutsars": "skolskjuts",
    "skolskjutsen": "skolskjuts",
    "skolskjutsens": "skolskjuts",
    "skolsköterskan": "skolsköterska",
    "skolsköterskans": "skolsköterska",
    "skolsköterskas": "skolsköterska",
    "skolsköterske": "skolsköterska",
    "skolsköterskor": "skolsköterska",
    "skolsköterskorna": "skolsköterska",
    "skolsköterskornas": "skolsköterska",
    "skolsköterskors": "skolsköterska",
    "skolstyrelsen": "skolstyrelse",
    "skolstyrelsens": "skolstyrelse",
    "skolstyrelser": "skolstyrelse",
    "skolstyrelserna": "skolstyrelse",
    "skolstyrelsernas": "skolstyrelse",
    "skolstyrelsers": "skolstyrelse",
    "skolstyrelses": "skolstyrelse",
    "skolsystemen": "skolsystem",
    "skolsystemens": "skolsystem",
    "skolsystemet": "skolsystem",
    "skolsystemets": "skolsystem",
    "skolsystems": "skolsystem",
    "skolsystern": "skolsyster",
    "skolsysterns": "skolsyster",
    "skolsysters": "skolsyster",
    "skolsystrar": "skolsyster",
    "skolsystrarna": "skolsyster",
    "skolsystrarnas": "skolsyster",
    "skolsystrars": "skolsyster",
    "skolten": "skolt",
    "skoltens": "skolt",
    "skolter": "skolt",
    "skolterna": "skolt",
    "skolternas": "skolt",
    "skolters": "skolt",
    "skoltrötta": "skoltrött",
    "skoltröttare": "skoltrött",
    "skoltröttares": "skoltrött",
    "skoltröttas": "skoltrött",
    "skoltröttast": "skoltrött",
    "skoltröttaste": "skoltrött",
    "skoltröttastes": "skoltrött",
    "skoltröttasts": "skoltrött",
    "skoltrötte": "skoltrött",
    "skoltröttes": "skoltrött",
    "skoltröttheten": "skoltrötthet",
    "skoltrötthetens": "skoltrötthet",
    "skoltrötthets": "skoltrötthet",
    "skoltrötts": "skoltrött",
    "skolts": "skolt",
    "skolunderbyggnaden": "skolunderbyggnad",
    "skolunderbyggnadens": "skolunderbyggnad",
    "skolunderbyggnader": "skolunderbyggnad",
    "skolunderbyggnaderna": "skolunderbyggnad",
    "skolunderbyggnadernas": "skolunderbyggnad",
    "skolunderbyggnaders": "skolunderbyggnad",
    "skolunderbyggnads": "skolunderbyggnad",
    "skolundervisningar": "skolundervisning",
    "skolundervisningarna": "skolundervisning",
    "skolundervisningarnas": "skolundervisning",
    "skolundervisningars": "skolundervisning",
    "skolundervisningen": "skolundervisning",
    "skolundervisningens": "skolundervisning",
    "skolundervisnings": "skolundervisning",
    "skolungdomar": "skolungdom",
    "skolungdomarna": "skolungdom",
    "skolungdomarnas": "skolungdom",
    "skolungdomars": "skolungdom",
    "skolungdomen": "skolungdom",
    "skolungdomens": "skolungdom",
    "skolungdoms": "skolungdom",
    "skolungdomsidrotten": "skolungdomsidrott",
    "skolungdomsidrottens": "skolungdomsidrott",
    "skolungdomsidrotter": "skolungdomsidrott",
    "skolungdomsidrotterna": "skolungdomsidrott",
    "skolungdomsidrotternas": "skolungdomsidrott",
    "skolungdomsidrotters": "skolungdomsidrott",
    "skolungdomsidrotts": "skolungdomsidrott",
    "skoluppsatsen": "skoluppsats",
    "skoluppsatsens": "skoluppsats",
    "skoluppsatser": "skoluppsats",
    "skoluppsatserna": "skoluppsats",
    "skoluppsatsernas": "skoluppsats",
    "skoluppsatsers": "skoluppsats",
    "skolutbildningar": "skolutbildning",
    "skolutbildningarna": "skolutbildning",
    "skolutbildningarnas": "skolutbildning",
    "skolutbildningars": "skolutbildning",
    "skolutbildningen": "skolutbildning",
    "skolutbildningens": "skolutbildning",
    "skolutbildnings": "skolutbildning",
    "skolvaktmästar": "skolvaktmästare",
    "skolvaktmästaren": "skolvaktmästare",
    "skolvaktmästarens": "skolvaktmästare",
    "skolvaktmästares": "skolvaktmästare",
    "skolvaktmästarna": "skolvaktmästare",
    "skolvaktmästarnas": "skolvaktmästare",
    "skolvägar": "skolväg",
    "skolvägarna": "skolväg",
    "skolvägarnas": "skolväg",
    "skolvägars": "skolväg",
    "skolvägen": "skolväg",
    "skolvägens": "skolväg",
    "skolvägs": "skolväg",
    "skolväsenden": "skolväsende",
    "skolväsendena": "skolväsende",
    "skolväsendenas": "skolväsende",
    "skolväsendens": "skolväsende",
    "skolväsendes": "skolväsende",
    "skolväsendet": "skolväsende",
    "skolväsendets": "skolväsende",
    "skolväsenet": "skolväsen",
    "skolväsenets": "skolväsen",
    "skolväsens": "skolväsen",
    "skolämnen": "skolämne",
    "skolämnena": "skolämne",
    "skolämnenas": "skolämne",
    "skolämnens": "skolämne",
    "skolämnes": "skolämne",
    "skolämnet": "skolämne",
    "skolämnets": "skolämne",
    "skolästar": "skoläst",
    "skolästarna": "skoläst",
    "skolästarnas": "skoläst",
    "skolästars": "skoläst",
    "skolästen": "skoläst",
    "skolästens": "skoläst",
    "skoläster": "skoläst",
    "skolästerna": "skoläst",
    "skolästernas": "skoläst",
    "skolästers": "skoläst",
    "skolästs": "skoläst",
    "skolåren": "skolår",
    "skolårens": "skolår",
    "skolåret": "skolår",
    "skolårets": "skolår",
    "skolårs": "skolår",
    "skolövningar": "skolövning",
    "skolövningarna": "skolövning",
    "skolövningarnas": "skolövning",
    "skolövningars": "skolövning",
    "skolövningen": "skolövning",
    "skolövningens": "skolövning",
    "skolövnings": "skolövning",
    "skomakar": "skomakare",
    "skomakaren": "skomakare",
    "skomakarens": "skomakare",
    "skomakares": "skomakare",
    "skomakarna": "skomakare",
    "skomakarnas": "skomakare",
    "skomakarrealismen": "skomakarrealism",
    "skomakarrealismens": "skomakarrealism",
    "skomakarrealismer": "skomakarrealism",
    "skomakarrealismerna": "skomakarrealism",
    "skomakarrealismernas": "skomakarrealism",
    "skomakarrealismers": "skomakarrealism",
    "skomakarrealisms": "skomakarrealism",
    "skomakarverkstaden": "skomakarverkstad",
    "skomakarverkstadens": "skomakarverkstad",
    "skomakarverkstads": "skomakarverkstad",
    "skomakarverkstan": "skomakarverkstad",
    "skomakarverkstans": "skomakarverkstad",
    "skomakarverkstäder": "skomakarverkstad",
    "skomakarverkstäderna": "skomakarverkstad",
    "skomakarverkstädernas": "skomakarverkstad",
    "skomakarverkstäders": "skomakarverkstad",
    "skomakerier": "skomakeri",
    "skomakerierna": "skomakeri",
    "skomakeriernas": "skomakeri",
    "skomakeriers": "skomakeri",
    "skomakeriet": "skomakeri",
    "skomakeriets": "skomakeri",
    "skomakeris": "skomakeri",
    "skomakerit": "skomakeri",
    "skomakerits": "skomakeri",
    "skon": "skona",
    "skonad": "skona",
    "skonade": "skona",
    "skonades": "skona",
    "skonads": "skona",
    "skonande": "skona",
    "skonanden": "skonande",
    "skonandena": "skonande",
    "skonandenas": "skonande",
    "skonandens": "skonande",
    "skonandes": "skonande",
    "skonandet": "skonande",
    "skonandets": "skonande",
    "skonar": "skonare",
    "skonaren": "skonare",
    "skonarens": "skonare",
    "skonares": "skonare",
    "skonarna": "skonare",
    "skonarnas": "skonare",
    "skonas": "skona",
    "skonat": "skona",
    "skonats": "skona",
    "skonerten": "skonert",
    "skonertens": "skonert",
    "skonerter": "skonert",
    "skonerterna": "skonert",
    "skonerternas": "skonert",
    "skonerters": "skonert",
    "skonerts": "skonert",
    "skonertskeppen": "skonertskepp",
    "skonertskeppens": "skonertskepp",
    "skonertskeppet": "skonertskepp",
    "skonertskeppets": "skonertskepp",
    "skonertskepps": "skonertskepp",
    "skongången": "skongång",
    "skongångens": "skongång",
    "skongångs": "skongång",
    "skoningar": "skoning",
    "skoningarna": "skoning",
    "skoningarnas": "skoning",
    "skoningars": "skoning",
    "skoningen": "skoning",
    "skoningens": "skoning",
    "skonings": "skoning",
    "skoningslösa": "skoningslös",
    "skoningslösare": "skoningslös",
    "skoningslösares": "skoningslös",
    "skoningslösas": "skoningslös",
    "skoningslösast": "skoningslös",
    "skoningslösaste": "skoningslös",
    "skoningslösastes": "skoningslös",
    "skoningslösasts": "skoningslös",
    "skoningslöse": "skoningslös",
    "skoningslöses": "skoningslös",
    "skoningslösheten": "skoningslöshet",
    "skoningslöshetens": "skoningslöshet",
    "skoningslösheter": "skoningslöshet",
    "skoningslösheterna": "skoningslöshet",
    "skoningslösheternas": "skoningslöshet",
    "skoningslösheters": "skoningslöshet",
    "skoningslöshets": "skoningslöshet",
    "skoningslöst": "skoningslös",
    "skoningslösts": "skoningslös",
    "skons": "sko",
    "skonsamheten": "skonsamhet",
    "skonsamhetens": "skonsamhet",
    "skonsamhets": "skonsamhet",
    "skonsamma": "skonsam",
    "skonsammare": "skonsam",
    "skonsammares": "skonsam",
    "skonsammas": "skonsam",
    "skonsammast": "skonsam",
    "skonsammaste": "skonsam",
    "skonsammastes": "skonsam",
    "skonsammasts": "skonsam",
    "skonsamme": "skonsam",
    "skonsammes": "skonsam",
    "skonsams": "skonsam",
    "skonsamt": "skonsam",
    "skonsamts": "skonsam",
    "skonummerna": "skonummer",
    "skonummernas": "skonummer",
    "skonummers": "skonummer",
    "skonumren": "skonummer",
    "skonumrens": "skonummer",
    "skonumret": "skonummer",
    "skonumrets": "skonummer",
    "skop": "skopa",
    "skopad": "skopa",
    "skopade": "skopa",
    "skopades": "skopa",
    "skopads": "skopa",
    "skopan": "skopa",
    "skopande": "skopa",
    "skopanden": "skopande",
    "skopandena": "skopande",
    "skopandenas": "skopande",
    "skopandens": "skopande",
    "skopandes": "skopande",
    "skopandet": "skopande",
    "skopandets": "skopande",
    "skopans": "skopa",
    "skopar": "skopa",
    "skopas": "skopa",
    "skopat": "skopa",
    "skopats": "skopa",
    "skope": "skopa",
    "skopofila": "skopofil",
    "skopofilare": "skopofil",
    "skopofilares": "skopofil",
    "skopofilas": "skopofil",
    "skopofilast": "skopofil",
    "skopofilaste": "skopofil",
    "skopofilastes": "skopofil",
    "skopofilasts": "skopofil",
    "skopofile": "skopofil",
    "skopofilen": "skopofil",
    "skopofilens": "skopofil",
    "skopofiler": "skopofil",
    "skopofilerna": "skopofil",
    "skopofilernas": "skopofil",
    "skopofilers": "skopofil",
    "skopofiles": "skopofil",
    "skopofilien": "skopofili",
    "skopofiliens": "skopofili",
    "skopofilin": "skopofili",
    "skopofilins": "skopofili",
    "skopofilis": "skopofili",
    "skopofils": "skopofil",
    "skopofilt": "skopofil",
    "skopofilts": "skopofil",
    "skopolaminen": "skopolamin",
    "skopolaminens": "skopolamin",
    "skopolaminer": "skopolamin",
    "skopolaminerna": "skopolamin",
    "skopolaminernas": "skopolamin",
    "skopolaminers": "skopolamin",
    "skopolaminet": "skopolamin",
    "skopolaminets": "skopolamin",
    "skopolamins": "skopolamin",
    "skopor": "skopa",
    "skoporna": "skopa",
    "skopornas": "skopa",
    "skopors": "skopa",
    "skops": "skopa",
    "skoptofilien": "skoptofili",
    "skoptofiliens": "skoptofili",
    "skoptofilin": "skoptofili",
    "skoptofilins": "skoptofili",
    "skoptofilis": "skoptofili",
    "skoputsar": "skoputsare",
    "skoputsaren": "skoputsare",
    "skoputsarens": "skoputsare",
    "skoputsares": "skoputsare",
    "skoputsarna": "skoputsare",
    "skoputsarnas": "skoputsare",
    "skor": "sko",
    "skorbuten": "skorbut",
    "skorbutens": "skorbut",
    "skorbuts": "skorbut",
    "skorna": "sko",
    "skornas": "sko",
    "skorp": "skorpa",
    "skorpan": "skorpa",
    "skorpans": "skorpa",
    "skorpas": "skorpa",
    "skorpe": "skorpa",
    "skorpionen": "skorpion",
    "skorpionens": "skorpion",
    "skorpioner": "skorpion",
    "skorpionerna": "skorpion",
    "skorpionernas": "skorpion",
    "skorpioners": "skorpion",
    "skorpions": "skorpion",
    "skorpmjölet": "skorpmjöl",
    "skorpmjölets": "skorpmjöl",
    "skorpmjöls": "skorpmjöl",
    "skorpor": "skorpa",
    "skorporna": "skorpa",
    "skorpornas": "skorpa",
    "skorpors": "skorpa",
    "skorps": "skorpa",
    "skorr": "skorra",
    "skorrade": "skorra",
    "skorrades": "skorra",
    "skorrande": "skorra",
    "skorranden": "skorrande",
    "skorrandena": "skorrande",
    "skorrandenas": "skorrande",
    "skorrandens": "skorrande",
    "skorrandes": "skorrande",
    "skorrandet": "skorrande",
    "skorrandets": "skorrande",
    "skorrar": "skorra",
    "skorras": "skorra",
    "skorrat": "skorra",
    "skorrats": "skorra",
    "skorret": "skorr",
    "skorrets": "skorr",
    "skorrs": "skorr",
    "skors": "sko",
    "skorstenar": "skorsten",
    "skorstenarna": "skorsten",
    "skorstenarnas": "skorsten",
    "skorstenars": "skorsten",
    "skorstenen": "skorsten",
    "skorstenens": "skorsten",
    "skorstens": "skorsten",
    "skorstensfejar": "skorstensfejare",
    "skorstensfejaren": "skorstensfejare",
    "skorstensfejarens": "skorstensfejare",
    "skorstensfejares": "skorstensfejare",
    "skorstensfejarna": "skorstensfejare",
    "skorstensfejarnas": "skorstensfejare",
    "skorvar": "skorv",
    "skorvarna": "skorv",
    "skorvarnas": "skorv",
    "skorvars": "skorv",
    "skorven": "skorv",
    "skorvens": "skorv",
    "skorviga": "skorvig",
    "skorvigare": "skorvig",
    "skorvigares": "skorvig",
    "skorvigas": "skorvig",
    "skorvigast": "skorvig",
    "skorvigaste": "skorvig",
    "skorvigastes": "skorvig",
    "skorvigasts": "skorvig",
    "skorvige": "skorvig",
    "skorviges": "skorvig",
    "skorvigheten": "skorvighet",
    "skorvighetens": "skorvighet",
    "skorvighets": "skorvighet",
    "skorvigs": "skorvig",
    "skorvigt": "skorvig",
    "skorvigts": "skorvig",
    "skorvs": "skorv",
    "skos": "sko",
    "skoskavet": "skoskav",
    "skoskavets": "skoskav",
    "skoskavs": "skoskav",
    "skosmörjan": "skosmörja",
    "skosmörjans": "skosmörja",
    "skosmörjas": "skosmörja",
    "skosmörje": "skosmörja",
    "skosmörjor": "skosmörja",
    "skosmörjorna": "skosmörja",
    "skosmörjornas": "skosmörja",
    "skosmörjors": "skosmörja",
    "skosnör": "skosnöre",
    "skosnören": "skosnöre",
    "skosnörena": "skosnöre",
    "skosnörenas": "skosnöre",
    "skosnörens": "skosnöre",
    "skosnöres": "skosnöre",
    "skosnöret": "skosnöre",
    "skosnörets": "skosnöre",
    "skosnörs": "skosnöre",
    "skosul": "skosula",
    "skosulan": "skosula",
    "skosulans": "skosula",
    "skosulas": "skosula",
    "skosule": "skosula",
    "skosulor": "skosula",
    "skosulorna": "skosula",
    "skosulornas": "skosula",
    "skosulors": "skosula",
    "skosuls": "skosula",
    "skot": "skota",
    "skotad": "skota",
    "skotade": "skota",
    "skotades": "skota",
    "skotads": "skota",
    "skotande": "skota",
    "skotanden": "skotande",
    "skotandena": "skotande",
    "skotandenas": "skotande",
    "skotandens": "skotande",
    "skotandes": "skotande",
    "skotandet": "skotande",
    "skotandets": "skotande",
    "skotar": "skota",
    "skotas": "skota",
    "skotat": "skota",
    "skotats": "skota",
    "skoten": "skot",
    "skotens": "skot",
    "skoterkäng": "skoterkänga",
    "skoterkängan": "skoterkänga",
    "skoterkängans": "skoterkänga",
    "skoterkängas": "skoterkänga",
    "skoterkänge": "skoterkänga",
    "skoterkängor": "skoterkänga",
    "skoterkängorna": "skoterkänga",
    "skoterkängornas": "skoterkänga",
    "skoterkängors": "skoterkänga",
    "skoterkängs": "skoterkänga",
    "skotern": "skoter",
    "skoterns": "skoter",
    "skoters": "skoter",
    "skotet": "skot",
    "skotets": "skot",
    "skothornen": "skothorn",
    "skothornens": "skothorn",
    "skothornet": "skothorn",
    "skothornets": "skothorn",
    "skothorns": "skothorn",
    "skotrar": "skoter",
    "skotrarna": "skoter",
    "skotrarnas": "skoter",
    "skotrars": "skoter",
    "skots": "skot",
    "skotsk": "skotska",
    "skotska": "skotsk",
    "skotskan": "skotska",
    "skotskans": "skotska",
    "skotskare": "skotsk",
    "skotskares": "skotsk",
    "skotskas": "skotska",
    "skotskast": "skotsk",
    "skotskaste": "skotsk",
    "skotskastes": "skotsk",
    "skotskasts": "skotsk",
    "skotske": "skotska",
    "skotskes": "skotsk",
    "skotskheten": "skotskhet",
    "skotskhetens": "skotskhet",
    "skotskhets": "skotskhet",
    "skotskor": "skotska",
    "skotskorna": "skotska",
    "skotskornas": "skotska",
    "skotskors": "skotska",
    "skotskrutiga": "skotskrutig",
    "skotskrutigare": "skotskrutig",
    "skotskrutigares": "skotskrutig",
    "skotskrutigas": "skotskrutig",
    "skotskrutigast": "skotskrutig",
    "skotskrutigaste": "skotskrutig",
    "skotskrutigastes": "skotskrutig",
    "skotskrutigasts": "skotskrutig",
    "skotskrutige": "skotskrutig",
    "skotskrutiges": "skotskrutig",
    "skotskrutigs": "skotskrutig",
    "skotskrutigt": "skotskrutig",
    "skotskrutigts": "skotskrutig",
    "skotsks": "skotsk",
    "skotskt": "skotsk",
    "skotskts": "skotsk",
    "skotsteken": "skotstek",
    "skotstekens": "skotstek",
    "skotsteket": "skotstek",
    "skotstekets": "skotstek",
    "skotsteks": "skotstek",
    "skott": "skotte",
    "skottad": "skotta",
    "skottade": "skotta",
    "skottades": "skotta",
    "skottads": "skotta",
    "skottande": "skotta",
    "skottanden": "skottande",
    "skottandena": "skottande",
    "skottandenas": "skottande",
    "skottandens": "skottande",
    "skottandes": "skottande",
    "skottandet": "skottande",
    "skottandets": "skottande",
    "skottar": "skotte",
    "skottarna": "skotte",
    "skottarnas": "skotte",
    "skottars": "skotte",
    "skottas": "skotta",
    "skottat": "skotta",
    "skottats": "skotta",
    "skottavel": "skottavla",
    "skottavlan": "skottavla",
    "skottavlans": "skottavla",
    "skottavlas": "skottavla",
    "skottavle": "skottavla",
    "skottavlor": "skottavla",
    "skottavlorna": "skottavla",
    "skottavlornas": "skottavla",
    "skottavlors": "skottavla",
    "skottdagar": "skottdag",
    "skottdagarna": "skottdag",
    "skottdagarnas": "skottdag",
    "skottdagars": "skottdag",
    "skottdagen": "skottdag",
    "skottdagens": "skottdag",
    "skottdags": "skottdag",
    "skottdraman": "skottdrama",
    "skottdramana": "skottdrama",
    "skottdramanas": "skottdrama",
    "skottdramans": "skottdrama",
    "skottdramas": "skottdrama",
    "skottdramat": "skottdrama",
    "skottdramats": "skottdrama",
    "skottdramer": "skottdrama",
    "skottdramerna": "skottdrama",
    "skottdramernas": "skottdrama",
    "skottdramers": "skottdrama",
    "skotten": "skotte",
    "skottens": "skotte",
    "skottes": "skotte",
    "skottet": "skott",
    "skottets": "skott",
    "skottfälten": "skottfält",
    "skottfältens": "skottfält",
    "skottfältet": "skottfält",
    "skottfältets": "skottfält",
    "skottfälts": "skottfält",
    "skottgluggar": "skottglugg",
    "skottgluggarna": "skottglugg",
    "skottgluggarnas": "skottglugg",
    "skottgluggars": "skottglugg",
    "skottgluggen": "skottglugg",
    "skottgluggens": "skottglugg",
    "skottgluggs": "skottglugg",
    "skotthålen": "skotthål",
    "skotthålens": "skotthål",
    "skotthålet": "skotthål",
    "skotthålets": "skotthål",
    "skotthållet": "skotthåll",
    "skotthållets": "skotthåll",
    "skotthålls": "skotthåll",
    "skotthåls": "skotthål",
    "skottkärr": "skottkärra",
    "skottkärran": "skottkärra",
    "skottkärrans": "skottkärra",
    "skottkärras": "skottkärra",
    "skottkärre": "skottkärra",
    "skottkärrehjulen": "skottkärrehjul",
    "skottkärrehjulens": "skottkärrehjul",
    "skottkärrehjulet": "skottkärrehjul",
    "skottkärrehjulets": "skottkärrehjul",
    "skottkärrehjuls": "skottkärrehjul",
    "skottkärror": "skottkärra",
    "skottkärrorna": "skottkärra",
    "skottkärrornas": "skottkärra",
    "skottkärrors": "skottkärra",
    "skottkärrs": "skottkärra",
    "skottlinjen": "skottlinje",
    "skottlinjens": "skottlinje",
    "skottlinjer": "skottlinje",
    "skottlinjerna": "skottlinje",
    "skottlinjernas": "skottlinje",
    "skottlinjers": "skottlinje",
    "skottlinjes": "skottlinje",
    "skottlossningar": "skottlossning",
    "skottlossningarna": "skottlossning",
    "skottlossningarnas": "skottlossning",
    "skottlossningars": "skottlossning",
    "skottlossningen": "skottlossning",
    "skottlossningens": "skottlossning",
    "skottlossnings": "skottlossning",
    "skottningar": "skottning",
    "skottningarna": "skottning",
    "skottningarnas": "skottning",
    "skottningars": "skottning",
    "skottningen": "skottning",
    "skottningens": "skottning",
    "skottnings": "skottning",
    "skottningsolyck": "skottningsolycka",
    "skottningsolyckan": "skottningsolycka",
    "skottningsolyckans": "skottningsolycka",
    "skottningsolyckas": "skottningsolycka",
    "skottningsolycke": "skottningsolycka",
    "skottningsolyckor": "skottningsolycka",
    "skottningsolyckorna": "skottningsolycka",
    "skottningsolyckornas": "skottningsolycka",
    "skottningsolyckors": "skottningsolycka",
    "skottningsolycks": "skottningsolycka",
    "skottpengar": "skottpeng",
    "skottpengarna": "skottpeng",
    "skottpengarnas": "skottpeng",
    "skottpengars": "skottpeng",
    "skottpengen": "skottpeng",
    "skottpengens": "skottpeng",
    "skottpengs": "skottpeng",
    "skotträdda": "skotträdd",
    "skotträddare": "skotträdd",
    "skotträddares": "skotträdd",
    "skotträddas": "skotträdd",
    "skotträddast": "skotträdd",
    "skotträddaste": "skotträdd",
    "skotträddastes": "skotträdd",
    "skotträddasts": "skotträdd",
    "skotträdde": "skotträdd",
    "skotträddes": "skotträdd",
    "skotträddheten": "skotträddhet",
    "skotträddhetens": "skotträddhet",
    "skotträddhets": "skotträddhet",
    "skotträdds": "skotträdd",
    "skotts": "skotte",
    "skottsekunden": "skottsekund",
    "skottsekundens": "skottsekund",
    "skottsekunder": "skottsekund",
    "skottsekunderna": "skottsekund",
    "skottsekundernas": "skottsekund",
    "skottsekunders": "skottsekund",
    "skottsekunds": "skottsekund",
    "skottskadad": "skottskada",
    "skottskadade": "skottskada",
    "skottskadades": "skottskada",
    "skottskadads": "skottskada",
    "skottskadan": "skottskada",
    "skottskadande": "skottskada",
    "skottskadanden": "skottskadande",
    "skottskadandena": "skottskadande",
    "skottskadandenas": "skottskadande",
    "skottskadandens": "skottskadande",
    "skottskadandes": "skottskadande",
    "skottskadandet": "skottskadande",
    "skottskadandets": "skottskadande",
    "skottskadans": "skottskada",
    "skottskadar": "skottskada",
    "skottskadas": "skottskada",
    "skottskadat": "skottskada",
    "skottskadats": "skottskada",
    "skottskade": "skottskada",
    "skottskador": "skottskada",
    "skottskadorna": "skottskada",
    "skottskadornas": "skottskada",
    "skottskadors": "skottskada",
    "skottskogar": "skottskog",
    "skottskogarna": "skottskog",
    "skottskogarnas": "skottskog",
    "skottskogars": "skottskog",
    "skottskogen": "skottskog",
    "skottskogens": "skottskog",
    "skottskogs": "skottskog",
    "skottspol": "skottspole",
    "skottspolar": "skottspole",
    "skottspolarna": "skottspole",
    "skottspolarnas": "skottspole",
    "skottspolars": "skottspole",
    "skottspolen": "skottspole",
    "skottspolens": "skottspole",
    "skottspoles": "skottspole",
    "skottspols": "skottspole",
    "skottsäkerheten": "skottsäkerhet",
    "skottsäkerhetens": "skottsäkerhet",
    "skottsäkerhets": "skottsäkerhet",
    "skottsäkers": "skottsäker",
    "skottsäkert": "skottsäker",
    "skottsäkerts": "skottsäker",
    "skottsäkra": "skottsäker",
    "skottsäkrare": "skottsäker",
    "skottsäkrares": "skottsäker",
    "skottsäkras": "skottsäker",
    "skottsäkrast": "skottsäker",
    "skottsäkraste": "skottsäker",
    "skottsäkrastes": "skottsäker",
    "skottsäkrasts": "skottsäker",
    "skottsäkre": "skottsäker",
    "skottsäkres": "skottsäker",
    "skottåren": "skottår",
    "skottårens": "skottår",
    "skottåret": "skottår",
    "skottårets": "skottår",
    "skottårs": "skottår",
    "skovel": "skovla",
    "skovelhjulen": "skovelhjul",
    "skovelhjulens": "skovelhjul",
    "skovelhjulet": "skovelhjul",
    "skovelhjulets": "skovelhjul",
    "skovelhjuls": "skovelhjul",
    "skoveln": "skovel",
    "skovelns": "skovel",
    "skovels": "skovel",
    "skoven": "skov",
    "skovens": "skov",
    "skovet": "skov",
    "skovets": "skov",
    "skovlad": "skovla",
    "skovlade": "skovla",
    "skovlades": "skovla",
    "skovlads": "skovla",
    "skovlande": "skovla",
    "skovlanden": "skovlande",
    "skovlandena": "skovlande",
    "skovlandenas": "skovlande",
    "skovlandens": "skovlande",
    "skovlandes": "skovlande",
    "skovlandet": "skovlande",
    "skovlandets": "skovlande",
    "skovlar": "skovla",
    "skovlarna": "skovel",
    "skovlarnas": "skovel",
    "skovlars": "skovel",
    "skovlas": "skovla",
    "skovlat": "skovla",
    "skovlats": "skovla",
    "skovorna": "skovor",
    "skovornas": "skovor",
    "skovors": "skovor",
    "skovs": "skov",
    "skrabb": "skrabba",
    "skrabban": "skrabba",
    "skrabbans": "skrabba",
    "skrabbas": "skrabba",
    "skrabbe": "skrabba",
    "skrabbiga": "skrabbig",
    "skrabbigare": "skrabbig",
    "skrabbigares": "skrabbig",
    "skrabbigas": "skrabbig",
    "skrabbigast": "skrabbig",
    "skrabbigaste": "skrabbig",
    "skrabbigastes": "skrabbig",
    "skrabbigasts": "skrabbig",
    "skrabbige": "skrabbig",
    "skrabbiges": "skrabbig",
    "skrabbigheten": "skrabbighet",
    "skrabbighetens": "skrabbighet",
    "skrabbighets": "skrabbighet",
    "skrabbigs": "skrabbig",
    "skrabbigt": "skrabbig",
    "skrabbigts": "skrabbig",
    "skrabbor": "skrabba",
    "skrabborna": "skrabba",
    "skrabbornas": "skrabba",
    "skrabbors": "skrabba",
    "skrabbs": "skrabba",
    "skrafferad": "skraffera",
    "skrafferade": "skraffera",
    "skrafferades": "skraffera",
    "skrafferads": "skraffera",
    "skrafferande": "skraffera",
    "skrafferanden": "skrafferande",
    "skrafferandena": "skrafferande",
    "skrafferandenas": "skrafferande",
    "skrafferandens": "skrafferande",
    "skrafferandes": "skrafferande",
    "skrafferandet": "skrafferande",
    "skrafferandets": "skrafferande",
    "skrafferar": "skraffera",
    "skrafferas": "skraffera",
    "skrafferat": "skraffera",
    "skrafferats": "skraffera",
    "skrafferbara": "skrafferbar",
    "skrafferbarare": "skrafferbar",
    "skrafferbarares": "skrafferbar",
    "skrafferbaras": "skrafferbar",
    "skrafferbarast": "skrafferbar",
    "skrafferbaraste": "skrafferbar",
    "skrafferbarastes": "skrafferbar",
    "skrafferbarasts": "skrafferbar",
    "skrafferbare": "skrafferbar",
    "skrafferbares": "skrafferbar",
    "skrafferbarheten": "skrafferbarhet",
    "skrafferbarhetens": "skrafferbarhet",
    "skrafferbarhets": "skrafferbarhet",
    "skrafferbars": "skrafferbar",
    "skrafferbart": "skrafferbar",
    "skrafferbarts": "skrafferbar",
    "skrafferingar": "skraffering",
    "skrafferingarna": "skraffering",
    "skrafferingarnas": "skraffering",
    "skrafferingars": "skraffering",
    "skrafferingen": "skraffering",
    "skrafferingens": "skraffering",
    "skrafferings": "skraffering",
    "skraja": "skraj",
    "skrajare": "skraj",
    "skrajares": "skraj",
    "skrajas": "skraj",
    "skrajast": "skraj",
    "skrajaste": "skraj",
    "skrajastes": "skraj",
    "skrajasts": "skraj",
    "skraje": "skraj",
    "skrajes": "skraj",
    "skrajheten": "skrajhet",
    "skrajhetens": "skrajhet",
    "skrajhets": "skrajhet",
    "skrajs": "skraj",
    "skrajsens": "skrajsen",
    "skrajset": "skrajsen",
    "skrajsets": "skrajsen",
    "skrajsna": "skrajsen",
    "skrajsnare": "skrajsen",
    "skrajsnares": "skrajsen",
    "skrajsnas": "skrajsen",
    "skrajsnast": "skrajsen",
    "skrajsnaste": "skrajsen",
    "skrajsnastes": "skrajsen",
    "skrajsnasts": "skrajsen",
    "skrajsne": "skrajsen",
    "skrajsnes": "skrajsen",
    "skrajt": "skraj",
    "skrajts": "skraj",
    "skrak": "skrake",
    "skrakar": "skrake",
    "skrakarna": "skrake",
    "skrakarnas": "skrake",
    "skrakars": "skrake",
    "skraken": "skrake",
    "skrakens": "skrake",
    "skrakes": "skrake",
    "skraks": "skrake",
    "skrala": "skral",
    "skralare": "skral",
    "skralares": "skral",
    "skralas": "skral",
    "skralast": "skral",
    "skralaste": "skral",
    "skralastes": "skral",
    "skralasts": "skral",
    "skrale": "skral",
    "skrales": "skral",
    "skralheten": "skralhet",
    "skralhetens": "skralhet",
    "skralhets": "skralhet",
    "skralnade": "skralna",
    "skralnades": "skralna",
    "skralnande": "skralna",
    "skralnanden": "skralnande",
    "skralnandena": "skralnande",
    "skralnandenas": "skralnande",
    "skralnandens": "skralnande",
    "skralnandes": "skralnande",
    "skralnandet": "skralnande",
    "skralnandets": "skralnande",
    "skralnar": "skralna",
    "skralnas": "skralna",
    "skralnat": "skralna",
    "skralnats": "skralna",
    "skrals": "skral",
    "skralt": "skralta",
    "skraltade": "skralta",
    "skraltades": "skralta",
    "skraltande": "skralta",
    "skraltanden": "skraltande",
    "skraltandena": "skraltande",
    "skraltandenas": "skraltande",
    "skraltandens": "skraltande",
    "skraltandes": "skraltande",
    "skraltandet": "skraltande",
    "skraltandets": "skraltande",
    "skraltar": "skralta",
    "skraltas": "skralta",
    "skraltat": "skralta",
    "skraltats": "skralta",
    "skraltiga": "skraltig",
    "skraltigare": "skraltig",
    "skraltigares": "skraltig",
    "skraltigas": "skraltig",
    "skraltigast": "skraltig",
    "skraltigaste": "skraltig",
    "skraltigastes": "skraltig",
    "skraltigasts": "skraltig",
    "skraltige": "skraltig",
    "skraltiges": "skraltig",
    "skraltigheten": "skraltighet",
    "skraltighetens": "skraltighet",
    "skraltighets": "skraltighet",
    "skraltigs": "skraltig",
    "skraltigt": "skraltig",
    "skraltigts": "skraltig",
    "skralts": "skral",
    "skramel": "skramla",
    "skramlad": "skramla",
    "skramlade": "skramla",
    "skramlades": "skramla",
    "skramlads": "skramla",
    "skramlan": "skramla",
    "skramlande": "skramla",
    "skramlanden": "skramlande",
    "skramlandena": "skramlande",
    "skramlandenas": "skramlande",
    "skramlandens": "skramlande",
    "skramlandes": "skramlande",
    "skramlandet": "skramlande",
    "skramlandets": "skramlande",
    "skramlans": "skramla",
    "skramlar": "skramla",
    "skramlas": "skramla",
    "skramlat": "skramla",
    "skramlats": "skramla",
    "skramle": "skramla",
    "skramlet": "skrammel",
    "skramlets": "skrammel",
    "skramliga": "skramlig",
    "skramligare": "skramlig",
    "skramligares": "skramlig",
    "skramligas": "skramlig",
    "skramligast": "skramlig",
    "skramligaste": "skramlig",
    "skramligastes": "skramlig",
    "skramligasts": "skramlig",
    "skramlige": "skramlig",
    "skramliges": "skramlig",
    "skramligheten": "skramlighet",
    "skramlighetens": "skramlighet",
    "skramlighets": "skramlighet",
    "skramligs": "skramlig",
    "skramligt": "skramlig",
    "skramligts": "skramlig",
    "skramlor": "skramla",
    "skramlorna": "skramla",
    "skramlornas": "skramla",
    "skramlors": "skramla",
    "skrammel": "skramla",
    "skrammels": "skrammel",
    "skrangliga": "skranglig",
    "skrangligare": "skranglig",
    "skrangligares": "skranglig",
    "skrangligas": "skranglig",
    "skrangligast": "skranglig",
    "skrangligaste": "skranglig",
    "skrangligastes": "skranglig",
    "skrangligasts": "skranglig",
    "skranglige": "skranglig",
    "skrangliges": "skranglig",
    "skrangligheten": "skranglighet",
    "skranglighetens": "skranglighet",
    "skranglighets": "skranglighet",
    "skrangligs": "skranglig",
    "skrangligt": "skranglig",
    "skrangligts": "skranglig",
    "skrank": "skranka",
    "skrankan": "skranka",
    "skrankans": "skranka",
    "skrankas": "skranka",
    "skranke": "skranka",
    "skranken": "skrank",
    "skrankens": "skrank",
    "skranket": "skrank",
    "skrankets": "skrank",
    "skrankor": "skranka",
    "skrankorna": "skranka",
    "skrankornas": "skranka",
    "skrankors": "skranka",
    "skranks": "skranka",
    "skrap": "skrapa",
    "skrapad": "skrapa",
    "skrapade": "skrapa",
    "skrapades": "skrapa",
    "skrapads": "skrapa",
    "skrapan": "skrapa",
    "skrapande": "skrapa",
    "skrapanden": "skrapande",
    "skrapandena": "skrapande",
    "skrapandenas": "skrapande",
    "skrapandens": "skrapande",
    "skrapandes": "skrapande",
    "skrapandet": "skrapande",
    "skrapandets": "skrapande",
    "skrapans": "skrapa",
    "skrapar": "skrapa",
    "skrapas": "skrapa",
    "skrapat": "skrapa",
    "skrapats": "skrapa",
    "skrape": "skrapa",
    "skrapet": "skrap",
    "skrapets": "skrap",
    "skraplotten": "skraplott",
    "skraplottens": "skraplott",
    "skraplotter": "skraplott",
    "skraplotterna": "skraplott",
    "skraplotternas": "skraplott",
    "skraplotters": "skraplott",
    "skraplotts": "skraplott",
    "skrapningar": "skrapning",
    "skrapningarna": "skrapning",
    "skrapningarnas": "skrapning",
    "skrapningars": "skrapning",
    "skrapningen": "skrapning",
    "skrapningens": "skrapning",
    "skrapnings": "skrapning",
    "skrapor": "skrapa",
    "skraporna": "skrapa",
    "skrapornas": "skrapa",
    "skrapors": "skrapa",
    "skraps": "skrapa",
    "skrapsåren": "skrapsår",
    "skrapsårens": "skrapsår",
    "skrapsåret": "skrapsår",
    "skrapsårets": "skrapsår",
    "skrapsårs": "skrapsår",
    "skrattade": "skratta",
    "skrattades": "skratta",
    "skrattande": "skratta",
    "skrattanden": "skrattande",
    "skrattandena": "skrattande",
    "skrattandenas": "skrattande",
    "skrattandens": "skrattande",
    "skrattandes": "skrattande",
    "skrattandet": "skrattande",
    "skrattandets": "skrattande",
    "skrattar": "skrattare",
    "skrattaren": "skrattare",
    "skrattarens": "skrattare",
    "skrattares": "skrattare",
    "skrattarna": "skrattare",
    "skrattarnas": "skrattare",
    "skrattas": "skratta",
    "skrattat": "skratta",
    "skrattats": "skratta",
    "skratten": "skratt",
    "skrattens": "skratt",
    "skrattet": "skratt",
    "skrattets": "skratt",
    "skrattfesten": "skrattfest",
    "skrattfestens": "skrattfest",
    "skrattfester": "skrattfest",
    "skrattfesterna": "skrattfest",
    "skrattfesternas": "skrattfest",
    "skrattfesters": "skrattfest",
    "skrattfests": "skrattfest",
    "skrattgropar": "skrattgrop",
    "skrattgroparna": "skrattgrop",
    "skrattgroparnas": "skrattgrop",
    "skrattgropars": "skrattgrop",
    "skrattgropen": "skrattgrop",
    "skrattgropens": "skrattgrop",
    "skrattgrops": "skrattgrop",
    "skrattkrampen": "skrattkramp",
    "skrattkrampens": "skrattkramp",
    "skrattkramper": "skrattkramp",
    "skrattkramperna": "skrattkramp",
    "skrattkrampernas": "skrattkramp",
    "skrattkrampers": "skrattkramp",
    "skrattkramps": "skrattkramp",
    "skrattlystens": "skrattlysten",
    "skrattlystet": "skrattlysten",
    "skrattlystets": "skrattlysten",
    "skrattlystna": "skrattlysten",
    "skrattlystnare": "skrattlysten",
    "skrattlystnares": "skrattlysten",
    "skrattlystnas": "skrattlysten",
    "skrattlystnast": "skrattlysten",
    "skrattlystnaste": "skrattlysten",
    "skrattlystnastes": "skrattlysten",
    "skrattlystnasts": "skrattlysten",
    "skrattlystne": "skrattlysten",
    "skrattlystnes": "skrattlysten",
    "skrattmåsar": "skrattmås",
    "skrattmåsarna": "skrattmås",
    "skrattmåsarnas": "skrattmås",
    "skrattmåsars": "skrattmås",
    "skrattmåsen": "skrattmås",
    "skrattmåsens": "skrattmås",
    "skrattparoxysmen": "skrattparoxysm",
    "skrattparoxysmens": "skrattparoxysm",
    "skrattparoxysmer": "skrattparoxysm",
    "skrattparoxysmerna": "skrattparoxysm",
    "skrattparoxysmernas": "skrattparoxysm",
    "skrattparoxysmers": "skrattparoxysm",
    "skrattparoxysms": "skrattparoxysm",
    "skrattrynk": "skrattrynka",
    "skrattrynkan": "skrattrynka",
    "skrattrynkans": "skrattrynka",
    "skrattrynkas": "skrattrynka",
    "skrattrynke": "skrattrynka",
    "skrattrynkor": "skrattrynka",
    "skrattrynkorna": "skrattrynka",
    "skrattrynkornas": "skrattrynka",
    "skrattrynkors": "skrattrynka",
    "skrattrynks": "skrattrynka",
    "skratts": "skratt",
    "skrattsalv": "skrattsalva",
    "skrattsalvan": "skrattsalva",
    "skrattsalvans": "skrattsalva",
    "skrattsalvas": "skrattsalva",
    "skrattsalve": "skrattsalva",
    "skrattsalvor": "skrattsalva",
    "skrattsalvorna": "skrattsalva",
    "skrattsalvornas": "skrattsalva",
    "skrattsalvors": "skrattsalva",
    "skrattsalvs": "skrattsalva",
    "skrattspegeln": "skrattspegel",
    "skrattspegelns": "skrattspegel",
    "skrattspegels": "skrattspegel",
    "skrattspeglar": "skrattspegel",
    "skrattspeglarna": "skrattspegel",
    "skrattspeglarnas": "skrattspegel",
    "skrattspeglars": "skrattspegel",
    "skravels": "skravel",
    "skravlet": "skravel",
    "skravlets": "skravel",
    "skred": "skrida",
    "skreden": "skred",
    "skredens": "skred",
    "skredet": "skred",
    "skredets": "skred",
    "skreds": "skrida",
    "skrek": "skrika",
    "skreks": "skrika",
    "skrev": "skriva",
    "skrevade": "skreva",
    "skrevades": "skreva",
    "skrevan": "skreva",
    "skrevande": "skreva",
    "skrevanden": "skrevande",
    "skrevandena": "skrevande",
    "skrevandenas": "skrevande",
    "skrevandens": "skrevande",
    "skrevandes": "skrevande",
    "skrevandet": "skrevande",
    "skrevandets": "skrevande",
    "skrevans": "skreva",
    "skrevar": "skreva",
    "skrevas": "skreva",
    "skrevat": "skreva",
    "skrevats": "skreva",
    "skreve": "skreva",
    "skreven": "skrev",
    "skrevens": "skrev",
    "skrevet": "skrev",
    "skrevets": "skrev",
    "skrevor": "skreva",
    "skrevorna": "skreva",
    "skrevornas": "skreva",
    "skrevors": "skreva",
    "skrevs": "skriva",
    "skriade": "skria",
    "skriades": "skria",
    "skriande": "skria",
    "skrianden": "skriande",
    "skriandena": "skriande",
    "skriandenas": "skriande",
    "skriandens": "skriande",
    "skriandes": "skriande",
    "skriandet": "skriande",
    "skriandets": "skriande",
    "skriar": "skria",
    "skrias": "skria",
    "skriat": "skria",
    "skriats": "skria",
    "skribenten": "skribent",
    "skribentens": "skribent",
    "skribenter": "skribent",
    "skribenterna": "skribent",
    "skribenternas": "skribent",
    "skribenters": "skribent",
    "skribents": "skribent",
    "skrid": "skrida",
    "skridande": "skrida",
    "skridanden": "skridande",
    "skridandena": "skridande",
    "skridandenas": "skridande",
    "skridandens": "skridande",
    "skridandes": "skridande",
    "skridandet": "skridande",
    "skridandets": "skridande",
    "skridas": "skrida",
    "skride": "skrida",
    "skriden": "skrida",
    "skridens": "skrida",
    "skrider": "skrida",
    "skrides": "skrida",
    "skridet": "skrida",
    "skridets": "skrida",
    "skridit": "skrida",
    "skridits": "skrida",
    "skridna": "skrida",
    "skridnas": "skrida",
    "skridne": "skrida",
    "skridnes": "skrida",
    "skrids": "skrida",
    "skridskobanan": "skridskobana",
    "skridskobanans": "skridskobana",
    "skridskobanas": "skridskobana",
    "skridskobane": "skridskobana",
    "skridskobanor": "skridskobana",
    "skridskobanorna": "skridskobana",
    "skridskobanornas": "skridskobana",
    "skridskobanors": "skridskobana",
    "skridskon": "skridsko",
    "skridskons": "skridsko",
    "skridskoprinsess": "skridskoprinsessa",
    "skridskoprinsessan": "skridskoprinsessa",
    "skridskoprinsessans": "skridskoprinsessa",
    "skridskoprinsessas": "skridskoprinsessa",
    "skridskoprinsesse": "skridskoprinsessa",
    "skridskoprinsessor": "skridskoprinsessa",
    "skridskoprinsessorna": "skridskoprinsessa",
    "skridskoprinsessornas": "skridskoprinsessa",
    "skridskoprinsessors": "skridskoprinsessa",
    "skridskor": "skridsko",
    "skridskorna": "skridsko",
    "skridskornas": "skridsko",
    "skridskors": "skridsko",
    "skridskos": "skridsko",
    "skridskoseglingar": "skridskosegling",
    "skridskoseglingarna": "skridskosegling",
    "skridskoseglingarnas": "skridskosegling",
    "skridskoseglingars": "skridskosegling",
    "skridskoseglingen": "skridskosegling",
    "skridskoseglingens": "skridskosegling",
    "skridskoseglings": "skridskosegling",
    "skridskoåkar": "skridskoåkare",
    "skridskoåkaren": "skridskoåkare",
    "skridskoåkarens": "skridskoåkare",
    "skridskoåkares": "skridskoåkare",
    "skridskoåkarna": "skridskoåkare",
    "skridskoåkarnas": "skridskoåkare",
    "skridskoåkningar": "skridskoåkning",
    "skridskoåkningarna": "skridskoåkning",
    "skridskoåkningarnas": "skridskoåkning",
    "skridskoåkningars": "skridskoåkning",
    "skridskoåkningen": "skridskoåkning",
    "skridskoåkningens": "skridskoåkning",
    "skridskoåknings": "skridskoåkning",
    "skrien": "skri",
    "skriens": "skri",
    "skriet": "skri",
    "skriets": "skri",
    "skriftbilden": "skriftbild",
    "skriftbildens": "skriftbild",
    "skriftbilder": "skriftbild",
    "skriftbilderna": "skriftbild",
    "skriftbildernas": "skriftbild",
    "skriftbilders": "skriftbild",
    "skriftbilds": "skriftbild",
    "skriften": "skrift",
    "skriftens": "skrift",
    "skrifter": "skrift",
    "skriftermålen": "skriftermål",
    "skriftermålens": "skriftermål",
    "skriftermålet": "skriftermål",
    "skriftermålets": "skriftermål",
    "skriftermåls": "skriftermål",
    "skrifterna": "skrift",
    "skrifternas": "skrift",
    "skrifters": "skrift",
    "skriftliga": "skriftlig",
    "skriftligare": "skriftlig",
    "skriftligares": "skriftlig",
    "skriftligas": "skriftlig",
    "skriftligast": "skriftlig",
    "skriftligaste": "skriftlig",
    "skriftligastes": "skriftlig",
    "skriftligasts": "skriftlig",
    "skriftlige": "skriftlig",
    "skriftliges": "skriftlig",
    "skriftligheten": "skriftlighet",
    "skriftlighetens": "skriftlighet",
    "skriftlighets": "skriftlighet",
    "skriftligs": "skriftlig",
    "skriftligt": "skriftlig",
    "skriftligts": "skriftlig",
    "skriftlärde": "skriftlärd",
    "skriftlärdes": "skriftlärd",
    "skriftlärds": "skriftlärd",
    "skriftlärt": "skriftlärd",
    "skriftlärts": "skriftlärd",
    "skrifts": "skrift",
    "skriftspråken": "skriftspråk",
    "skriftspråkens": "skriftspråk",
    "skriftspråket": "skriftspråk",
    "skriftspråkets": "skriftspråk",
    "skriftspråkliga": "skriftspråklig",
    "skriftspråkligare": "skriftspråklig",
    "skriftspråkligares": "skriftspråklig",
    "skriftspråkligas": "skriftspråklig",
    "skriftspråkligast": "skriftspråklig",
    "skriftspråkligaste": "skriftspråklig",
    "skriftspråkligastes": "skriftspråklig",
    "skriftspråkligasts": "skriftspråklig",
    "skriftspråklige": "skriftspråklig",
    "skriftspråkliges": "skriftspråklig",
    "skriftspråkligheten": "skriftspråklighet",
    "skriftspråklighetens": "skriftspråklighet",
    "skriftspråkligheter": "skriftspråklighet",
    "skriftspråkligheterna": "skriftspråklighet",
    "skriftspråkligheternas": "skriftspråklighet",
    "skriftspråkligheters": "skriftspråklighet",
    "skriftspråklighets": "skriftspråklighet",
    "skriftspråkligs": "skriftspråklig",
    "skriftspråkligt": "skriftspråklig",
    "skriftspråkligts": "skriftspråklig",
    "skriftspråks": "skriftspråk",
    "skriftställar": "skriftställare",
    "skriftställaren": "skriftställare",
    "skriftställarens": "skriftställare",
    "skriftställares": "skriftställare",
    "skriftställarna": "skriftställare",
    "skriftställarnas": "skriftställare",
    "skriftställerier": "skriftställeri",
    "skriftställerierna": "skriftställeri",
    "skriftställeriernas": "skriftställeri",
    "skriftställeriers": "skriftställeri",
    "skriftställeriet": "skriftställeri",
    "skriftställeriets": "skriftställeri",
    "skriftställeris": "skriftställeri",
    "skriftställerit": "skriftställeri",
    "skriftställerits": "skriftställeri",
    "skriftsystemen": "skriftsystem",
    "skriftsystemens": "skriftsystem",
    "skriftsystemet": "skriftsystem",
    "skriftsystemets": "skriftsystem",
    "skriftsystems": "skriftsystem",
    "skrik": "skrika",
    "skrikan": "skrika",
    "skrikande": "skrika",
    "skrikanden": "skrikande",
    "skrikandena": "skrikande",
    "skrikandenas": "skrikande",
    "skrikandens": "skrikande",
    "skrikandes": "skrikande",
    "skrikandet": "skrikande",
    "skrikandets": "skrikande",
    "skrikans": "skrika",
    "skrikas": "skrika",
    "skrike": "skrika",
    "skriken": "skrik",
    "skrikens": "skrik",
    "skriker": "skrika",
    "skrikes": "skrika",
    "skriket": "skrik",
    "skrikets": "skrik",
    "skrikhalsar": "skrikhals",
    "skrikhalsarna": "skrikhals",
    "skrikhalsarnas": "skrikhals",
    "skrikhalsars": "skrikhals",
    "skrikhalsen": "skrikhals",
    "skrikhalsens": "skrikhals",
    "skrikiga": "skrikig",
    "skrikigare": "skrikig",
    "skrikigares": "skrikig",
    "skrikigas": "skrikig",
    "skrikigast": "skrikig",
    "skrikigaste": "skrikig",
    "skrikigastes": "skrikig",
    "skrikigasts": "skrikig",
    "skrikige": "skrikig",
    "skrikiges": "skrikig",
    "skrikigs": "skrikig",
    "skrikigt": "skrikig",
    "skrikigts": "skrikig",
    "skrikit": "skrika",
    "skrikits": "skrika",
    "skrikor": "skrika",
    "skrikorna": "skrika",
    "skrikornas": "skrika",
    "skrikors": "skrika",
    "skriks": "skrika",
    "skriksessionen": "skriksession",
    "skriksessionens": "skriksession",
    "skriksessioner": "skriksession",
    "skriksessionerna": "skriksession",
    "skriksessionernas": "skriksession",
    "skriksessioners": "skriksession",
    "skriksessions": "skriksession",
    "skrin": "skri",
    "skrina": "skri",
    "skrinas": "skri",
    "skrind": "skrinda",
    "skrindan": "skrinda",
    "skrindans": "skrinda",
    "skrindas": "skrinda",
    "skrinde": "skrinda",
    "skrindor": "skrinda",
    "skrindorna": "skrinda",
    "skrindornas": "skrinda",
    "skrindors": "skrinda",
    "skrinds": "skrinda",
    "skrinen": "skrin",
    "skrinens": "skrin",
    "skrinet": "skrin",
    "skrinets": "skrin",
    "skrinla": "skrinlägga",
    "skrinlade": "skrinlägga",
    "skrinlades": "skrinlägga",
    "skrinlagd": "skrinlägga",
    "skrinlagda": "skrinlägga",
    "skrinlagdas": "skrinlägga",
    "skrinlagde": "skrinlägga",
    "skrinlagdes": "skrinlägga",
    "skrinlagds": "skrinlägga",
    "skrinlagt": "skrinlägga",
    "skrinlagts": "skrinlägga",
    "skrinlas": "skrinlägga",
    "skrinlägg": "skrinlägga",
    "skrinläggande": "skrinlägga",
    "skrinlägganden": "skrinläggande",
    "skrinläggandena": "skrinläggande",
    "skrinläggandenas": "skrinläggande",
    "skrinläggandens": "skrinläggande",
    "skrinläggandes": "skrinläggande",
    "skrinläggandet": "skrinläggande",
    "skrinläggandets": "skrinläggande",
    "skrinläggas": "skrinlägga",
    "skrinlägger": "skrinlägga",
    "skrinlägges": "skrinlägga",
    "skrinläggs": "skrinlägga",
    "skrinn": "skrinna",
    "skrinnade": "skrinna",
    "skrinnades": "skrinna",
    "skrinnande": "skrinna",
    "skrinnanden": "skrinnande",
    "skrinnandena": "skrinnande",
    "skrinnandenas": "skrinnande",
    "skrinnandens": "skrinnande",
    "skrinnandes": "skrinnande",
    "skrinnandet": "skrinnande",
    "skrinnandets": "skrinnande",
    "skrinnar": "skrinnare",
    "skrinnaren": "skrinnare",
    "skrinnarens": "skrinnare",
    "skrinnares": "skrinnare",
    "skrinnarna": "skrinnare",
    "skrinnarnas": "skrinnare",
    "skrinnas": "skrinna",
    "skrinnat": "skrinna",
    "skrinnats": "skrinna",
    "skrins": "skrin",
    "skripta": "skriptum",
    "skriptan": "skripta",
    "skriptans": "skripta",
    "skriptas": "skriptum",
    "skripte": "skripta",
    "skriptor": "skripta",
    "skriptorna": "skripta",
    "skriptornas": "skripta",
    "skriptors": "skripta",
    "skriptumen": "skriptum",
    "skriptumens": "skriptum",
    "skriptumet": "skriptum",
    "skriptumets": "skriptum",
    "skriptums": "skriptum",
    "skris": "skri",
    "skrit": "skri",
    "skrits": "skri",
    "skrittade": "skritta",
    "skrittades": "skritta",
    "skrittande": "skritta",
    "skrittanden": "skrittande",
    "skrittandena": "skrittande",
    "skrittandenas": "skrittande",
    "skrittandens": "skrittande",
    "skrittandes": "skrittande",
    "skrittandet": "skrittande",
    "skrittandets": "skrittande",
    "skrittar": "skritta",
    "skrittas": "skritta",
    "skrittat": "skritta",
    "skrittats": "skritta",
    "skritten": "skritt",
    "skrittens": "skritt",
    "skritts": "skritt",
    "skriv": "skriva",
    "skrivande": "skriva",
    "skrivanden": "skrivande",
    "skrivandena": "skrivande",
    "skrivandenas": "skrivande",
    "skrivandens": "skrivande",
    "skrivandes": "skrivande",
    "skrivandet": "skrivande",
    "skrivandets": "skrivande",
    "skrivar": "skrivare",
    "skrivaren": "skrivare",
    "skrivarens": "skrivare",
    "skrivares": "skrivare",
    "skrivarna": "skrivare",
    "skrivarnas": "skrivare",
    "skrivarpapperen": "skrivarpapper",
    "skrivarpapperens": "skrivarpapper",
    "skrivarpapperet": "skrivarpapper",
    "skrivarpapperets": "skrivarpapper",
    "skrivarpapperna": "skrivarpapper",
    "skrivarpappernas": "skrivarpapper",
    "skrivarpappers": "skrivarpapper",
    "skrivarpappren": "skrivarpapper",
    "skrivarpapprens": "skrivarpapper",
    "skrivarpappret": "skrivarpapper",
    "skrivarpapprets": "skrivarpapper",
    "skrivas": "skriva",
    "skrivbara": "skrivbar",
    "skrivbaras": "skrivbar",
    "skrivbare": "skrivbar",
    "skrivbares": "skrivbar",
    "skrivbars": "skrivbar",
    "skrivbart": "skrivbar",
    "skrivbarts": "skrivbar",
    "skrivberedda": "skrivberedd",
    "skrivbereddare": "skrivberedd",
    "skrivbereddares": "skrivberedd",
    "skrivbereddas": "skrivberedd",
    "skrivbereddast": "skrivberedd",
    "skrivbereddaste": "skrivberedd",
    "skrivbereddastes": "skrivberedd",
    "skrivbereddasts": "skrivberedd",
    "skrivberedde": "skrivberedd",
    "skrivbereddes": "skrivberedd",
    "skrivberedds": "skrivberedd",
    "skrivberett": "skrivberedd",
    "skrivberetts": "skrivberedd",
    "skrivblocken": "skrivblock",
    "skrivblockens": "skrivblock",
    "skrivblocket": "skrivblock",
    "skrivblockets": "skrivblock",
    "skrivblocks": "skrivblock",
    "skrivboken": "skrivbok",
    "skrivbokens": "skrivbok",
    "skrivboks": "skrivbok",
    "skrivborden": "skrivbord",
    "skrivbordens": "skrivbord",
    "skrivbordet": "skrivbord",
    "skrivbordets": "skrivbord",
    "skrivbords": "skrivbord",
    "skrivbordslamp": "skrivbordslampa",
    "skrivbordslampan": "skrivbordslampa",
    "skrivbordslampans": "skrivbordslampa",
    "skrivbordslampas": "skrivbordslampa",
    "skrivbordslampe": "skrivbordslampa",
    "skrivbordslampor": "skrivbordslampa",
    "skrivbordslamporna": "skrivbordslampa",
    "skrivbordslampornas": "skrivbordslampa",
    "skrivbordslampors": "skrivbordslampa",
    "skrivbordslamps": "skrivbordslampa",
    "skrivbordslåd": "skrivbordslåda",
    "skrivbordslådan": "skrivbordslåda",
    "skrivbordslådans": "skrivbordslåda",
    "skrivbordslådas": "skrivbordslåda",
    "skrivbordslåde": "skrivbordslåda",
    "skrivbordslådor": "skrivbordslåda",
    "skrivbordslådorna": "skrivbordslåda",
    "skrivbordslådornas": "skrivbordslåda",
    "skrivbordslådors": "skrivbordslåda",
    "skrivbordslåds": "skrivbordslåda",
    "skrivbordsstolar": "skrivbordsstol",
    "skrivbordsstolarna": "skrivbordsstol",
    "skrivbordsstolarnas": "skrivbordsstol",
    "skrivbordsstolars": "skrivbordsstol",
    "skrivbordsstolen": "skrivbordsstol",
    "skrivbordsstolens": "skrivbordsstol",
    "skrivbordsstols": "skrivbordsstol",
    "skrivbordsunderläggen": "skrivbordsunderlägg",
    "skrivbordsunderläggens": "skrivbordsunderlägg",
    "skrivbordsunderlägget": "skrivbordsunderlägg",
    "skrivbordsunderläggets": "skrivbordsunderlägg",
    "skrivbordsunderläggs": "skrivbordsunderlägg",
    "skrivbyråer": "skrivbyrå",
    "skrivbyråerna": "skrivbyrå",
    "skrivbyråernas": "skrivbyrå",
    "skrivbyråers": "skrivbyrå",
    "skrivbyrån": "skrivbyrå",
    "skrivbyråns": "skrivbyrå",
    "skrivbyrås": "skrivbyrå",
    "skrivböcker": "skrivbok",
    "skrivböckerna": "skrivbok",
    "skrivböckernas": "skrivbok",
    "skrivböckers": "skrivbok",
    "skrive": "skriva",
    "skrivelsen": "skrivelse",
    "skrivelsens": "skrivelse",
    "skrivelser": "skrivelse",
    "skrivelserna": "skrivelse",
    "skrivelsernas": "skrivelse",
    "skrivelsers": "skrivelse",
    "skrivelses": "skrivelse",
    "skriven": "skriva",
    "skrivens": "skriva",
    "skriver": "skriva",
    "skriverier": "skriveri",
    "skriverierna": "skriveri",
    "skriveriernas": "skriveri",
    "skriveriers": "skriveri",
    "skriveriet": "skriveri",
    "skriveriets": "skriveri",
    "skriveris": "skriveri",
    "skriverit": "skriveri",
    "skriverits": "skriveri",
    "skrives": "skriva",
    "skrivet": "skriva",
    "skrivets": "skriva",
    "skrivhäften": "skrivhäfte",
    "skrivhäftena": "skrivhäfte",
    "skrivhäftenas": "skrivhäfte",
    "skrivhäftens": "skrivhäfte",
    "skrivhäftes": "skrivhäfte",
    "skrivhäftet": "skrivhäfte",
    "skrivhäftets": "skrivhäfte",
    "skrivhörn": "skrivhörna",
    "skrivhörnan": "skrivhörna",
    "skrivhörnans": "skrivhörna",
    "skrivhörnas": "skrivhörna",
    "skrivhörne": "skrivhörna",
    "skrivhörnor": "skrivhörna",
    "skrivhörnorna": "skrivhörna",
    "skrivhörnornas": "skrivhörna",
    "skrivhörnors": "skrivhörna",
    "skrivhörns": "skrivhörna",
    "skrivit": "skriva",
    "skrivits": "skriva",
    "skrivklådan": "skrivklåda",
    "skrivklådans": "skrivklåda",
    "skrivklådas": "skrivklåda",
    "skrivkrampen": "skrivkramp",
    "skrivkrampens": "skrivkramp",
    "skrivkramps": "skrivkramp",
    "skrivkunniga": "skrivkunnig",
    "skrivkunnigare": "skrivkunnig",
    "skrivkunnigares": "skrivkunnig",
    "skrivkunnigas": "skrivkunnig",
    "skrivkunnigast": "skrivkunnig",
    "skrivkunnigaste": "skrivkunnig",
    "skrivkunnigastes": "skrivkunnig",
    "skrivkunnigasts": "skrivkunnig",
    "skrivkunnige": "skrivkunnig",
    "skrivkunniges": "skrivkunnig",
    "skrivkunnigheten": "skrivkunnighet",
    "skrivkunnighetens": "skrivkunnighet",
    "skrivkunnighets": "skrivkunnighet",
    "skrivkunnigs": "skrivkunnig",
    "skrivkunnigt": "skrivkunnig",
    "skrivkunnigts": "skrivkunnig",
    "skrivmaskinen": "skrivmaskin",
    "skrivmaskinens": "skrivmaskin",
    "skrivmaskiner": "skrivmaskin",
    "skrivmaskinerna": "skrivmaskin",
    "skrivmaskinernas": "skrivmaskin",
    "skrivmaskiners": "skrivmaskin",
    "skrivmaskins": "skrivmaskin",
    "skrivmaskinsborden": "skrivmaskinsbord",
    "skrivmaskinsbordens": "skrivmaskinsbord",
    "skrivmaskinsbordet": "skrivmaskinsbord",
    "skrivmaskinsbordets": "skrivmaskinsbord",
    "skrivmaskinsbords": "skrivmaskinsbord",
    "skrivmaskinsstolar": "skrivmaskinsstol",
    "skrivmaskinsstolarna": "skrivmaskinsstol",
    "skrivmaskinsstolarnas": "skrivmaskinsstol",
    "skrivmaskinsstolars": "skrivmaskinsstol",
    "skrivmaskinsstolen": "skrivmaskinsstol",
    "skrivmaskinsstolens": "skrivmaskinsstol",
    "skrivmaskinsstols": "skrivmaskinsstol",
    "skrivmaskinstangenten": "skrivmaskinstangent",
    "skrivmaskinstangentens": "skrivmaskinstangent",
    "skrivmaskinstangenter": "skrivmaskinstangent",
    "skrivmaskinstangenterna": "skrivmaskinstangent",
    "skrivmaskinstangenternas": "skrivmaskinstangent",
    "skrivmaskinstangenters": "skrivmaskinstangent",
    "skrivmaskinstangents": "skrivmaskinstangent",
    "skrivna": "skriva",
    "skrivnas": "skriva",
    "skrivne": "skriva",
    "skrivnes": "skriva",
    "skrivningar": "skrivning",
    "skrivningarna": "skrivning",
    "skrivningarnas": "skrivning",
    "skrivningars": "skrivning",
    "skrivningen": "skrivning",
    "skrivningens": "skrivning",
    "skrivnings": "skrivning",
    "skrivplatsen": "skrivplats",
    "skrivplatsens": "skrivplats",
    "skrivplatser": "skrivplats",
    "skrivplatserna": "skrivplats",
    "skrivplatsernas": "skrivplats",
    "skrivplatsers": "skrivplats",
    "skrivplånen": "skrivplån",
    "skrivplånens": "skrivplån",
    "skrivplånet": "skrivplån",
    "skrivplånets": "skrivplån",
    "skrivplåns": "skrivplån",
    "skrivs": "skriva",
    "skrivstilar": "skrivstil",
    "skrivstilarna": "skrivstil",
    "skrivstilarnas": "skrivstil",
    "skrivstilars": "skrivstil",
    "skrivstilen": "skrivstil",
    "skrivstilens": "skrivstil",
    "skrivstils": "skrivstil",
    "skrivtavel": "skrivtavla",
    "skrivtavlan": "skrivtavla",
    "skrivtavlans": "skrivtavla",
    "skrivtavlas": "skrivtavla",
    "skrivtavle": "skrivtavla",
    "skrivtavlor": "skrivtavla",
    "skrivtavlorna": "skrivtavla",
    "skrivtavlornas": "skrivtavla",
    "skrivtavlors": "skrivtavla",
    "skrivteckens": "skrivtecken",
    "skrivtecknen": "skrivtecken",
    "skrivtecknens": "skrivtecken",
    "skrivtecknet": "skrivtecken",
    "skrivtecknets": "skrivtecken",
    "skrivunderläggen": "skrivunderlägg",
    "skrivunderläggens": "skrivunderlägg",
    "skrivunderlägget": "skrivunderlägg",
    "skrivunderläggets": "skrivunderlägg",
    "skrivunderläggs": "skrivunderlägg",
    "skrivövningar": "skrivövning",
    "skrivövningarna": "skrivövning",
    "skrivövningarnas": "skrivövning",
    "skrivövningars": "skrivövning",
    "skrivövningen": "skrivövning",
    "skrivövningens": "skrivövning",
    "skrivövnings": "skrivövning",
    "skrock": "skrocka",
    "skrockade": "skrocka",
    "skrockades": "skrocka",
    "skrockande": "skrocka",
    "skrockanden": "skrockande",
    "skrockandena": "skrockande",
    "skrockandenas": "skrockande",
    "skrockandens": "skrockande",
    "skrockandes": "skrockande",
    "skrockandet": "skrockande",
    "skrockandets": "skrockande",
    "skrockar": "skrocka",
    "skrockas": "skrocka",
    "skrockat": "skrocka",
    "skrockats": "skrocka",
    "skrocket": "skrock",
    "skrockets": "skrock",
    "skrocks": "skrock",
    "skroderade": "skrodera",
    "skroderades": "skrodera",
    "skroderande": "skrodera",
    "skroderanden": "skroderande",
    "skroderandena": "skroderande",
    "skroderandenas": "skroderande",
    "skroderandens": "skroderande",
    "skroderandes": "skroderande",
    "skroderandet": "skroderande",
    "skroderandets": "skroderande",
    "skroderar": "skrodera",
    "skroderas": "skrodera",
    "skroderat": "skrodera",
    "skroderats": "skrodera",
    "skroderingar": "skrodering",
    "skroderingarna": "skrodering",
    "skroderingarnas": "skrodering",
    "skroderingars": "skrodering",
    "skroderingen": "skrodering",
    "skroderingens": "skrodering",
    "skroderings": "skrodering",
    "skrodören": "skrodör",
    "skrodörens": "skrodör",
    "skrodörer": "skrodör",
    "skrodörerna": "skrodör",
    "skrodörernas": "skrodör",
    "skrodörers": "skrodör",
    "skrodörs": "skrodör",
    "skrofel": "skrofler",
    "skrofels": "skrofler",
    "skroflerna": "skrofler",
    "skroflernas": "skrofler",
    "skroflers": "skrofler",
    "skrofulösa": "skrofulös",
    "skrofulösare": "skrofulös",
    "skrofulösares": "skrofulös",
    "skrofulösas": "skrofulös",
    "skrofulösast": "skrofulös",
    "skrofulösaste": "skrofulös",
    "skrofulösastes": "skrofulös",
    "skrofulösasts": "skrofulös",
    "skrofulöse": "skrofulös",
    "skrofulöses": "skrofulös",
    "skrofulöst": "skrofulös",
    "skrofulösts": "skrofulös",
    "skrotad": "skrota",
    "skrotade": "skrota",
    "skrotades": "skrota",
    "skrotads": "skrota",
    "skrotande": "skrota",
    "skrotanden": "skrotande",
    "skrotandena": "skrotande",
    "skrotandenas": "skrotande",
    "skrotandens": "skrotande",
    "skrotandes": "skrotande",
    "skrotandet": "skrotande",
    "skrotandets": "skrotande",
    "skrotar": "skrota",
    "skrotas": "skrota",
    "skrotat": "skrota",
    "skrotats": "skrota",
    "skrotbilar": "skrotbil",
    "skrotbilarna": "skrotbil",
    "skrotbilarnas": "skrotbil",
    "skrotbilars": "skrotbil",
    "skrotbilen": "skrotbil",
    "skrotbilens": "skrotbil",
    "skrotbils": "skrotbil",
    "skroten": "skrot",
    "skrotens": "skrot",
    "skrotet": "skrot",
    "skrotets": "skrot",
    "skrothögar": "skrothög",
    "skrothögarna": "skrothög",
    "skrothögarnas": "skrothög",
    "skrothögars": "skrothög",
    "skrothögen": "skrothög",
    "skrothögens": "skrothög",
    "skrothögs": "skrothög",
    "skrots": "skrot",
    "skrotskulpturen": "skrotskulptur",
    "skrotskulpturens": "skrotskulptur",
    "skrotskulpturer": "skrotskulptur",
    "skrotskulpturerna": "skrotskulptur",
    "skrotskulpturernas": "skrotskulptur",
    "skrotskulpturers": "skrotskulptur",
    "skrotskulpturs": "skrotskulptur",
    "skrottar": "skrott",
    "skrottarna": "skrott",
    "skrottarnas": "skrott",
    "skrottars": "skrott",
    "skrotten": "skrott",
    "skrottens": "skrott",
    "skrotts": "skrott",
    "skrotupplagen": "skrotupplag",
    "skrotupplagens": "skrotupplag",
    "skrotupplaget": "skrotupplag",
    "skrotupplagets": "skrotupplag",
    "skrotupplags": "skrotupplag",
    "skrotvärdes": "skrotvärde",
    "skrotvärdet": "skrotvärde",
    "skrotvärdets": "skrotvärde",
    "skroven": "skrov",
    "skrovens": "skrov",
    "skrovet": "skrov",
    "skrovets": "skrov",
    "skrovliga": "skrovlig",
    "skrovligare": "skrovlig",
    "skrovligares": "skrovlig",
    "skrovligas": "skrovlig",
    "skrovligast": "skrovlig",
    "skrovligaste": "skrovlig",
    "skrovligastes": "skrovlig",
    "skrovligasts": "skrovlig",
    "skrovlige": "skrovlig",
    "skrovliges": "skrovlig",
    "skrovligheten": "skrovlighet",
    "skrovlighetens": "skrovlighet",
    "skrovligheter": "skrovlighet",
    "skrovligheterna": "skrovlighet",
    "skrovligheternas": "skrovlighet",
    "skrovligheters": "skrovlighet",
    "skrovlighets": "skrovlighet",
    "skrovligs": "skrovlig",
    "skrovligt": "skrovlig",
    "skrovligts": "skrovlig",
    "skrovmålen": "skrovmål",
    "skrovmålens": "skrovmål",
    "skrovmålet": "skrovmål",
    "skrovmålets": "skrovmål",
    "skrovmåls": "skrovmål",
    "skrovs": "skrov",
    "skrubb": "skrubbor",
    "skrubbad": "skrubba",
    "skrubbade": "skrubba",
    "skrubbades": "skrubba",
    "skrubbads": "skrubba",
    "skrubban": "skrubba",
    "skrubbande": "skrubba",
    "skrubbanden": "skrubbande",
    "skrubbandena": "skrubbande",
    "skrubbandenas": "skrubbande",
    "skrubbandens": "skrubbande",
    "skrubbandes": "skrubbande",
    "skrubbandet": "skrubbande",
    "skrubbandets": "skrubbande",
    "skrubbans": "skrubba",
    "skrubbar": "skrubba",
    "skrubbarna": "skrubb",
    "skrubbarnas": "skrubb",
    "skrubbars": "skrubb",
    "skrubbas": "skrubba",
    "skrubbat": "skrubba",
    "skrubbats": "skrubba",
    "skrubbe": "skrubba",
    "skrubben": "skrubb",
    "skrubbens": "skrubb",
    "skrubbor": "skrubba",
    "skrubborna": "skrubbor",
    "skrubbornas": "skrubbor",
    "skrubbors": "skrubbor",
    "skrubbs": "skrubbor",
    "skrubbsåren": "skrubbsår",
    "skrubbsårens": "skrubbsår",
    "skrubbsåret": "skrubbsår",
    "skrubbsårets": "skrubbsår",
    "skrubbsårs": "skrubbsår",
    "skrud": "skruda",
    "skrudad": "skruda",
    "skrudade": "skruda",
    "skrudades": "skruda",
    "skrudads": "skruda",
    "skrudande": "skruda",
    "skrudanden": "skrudande",
    "skrudandena": "skrudande",
    "skrudandenas": "skrudande",
    "skrudandens": "skrudande",
    "skrudandes": "skrudande",
    "skrudandet": "skrudande",
    "skrudandets": "skrudande",
    "skrudar": "skruda",
    "skrudarna": "skrud",
    "skrudarnas": "skrud",
    "skrudars": "skrud",
    "skrudas": "skruda",
    "skrudat": "skruda",
    "skrudats": "skruda",
    "skruden": "skrud",
    "skrudens": "skrud",
    "skruds": "skrud",
    "skrumpens": "skrumpen",
    "skrumpet": "skrumpen",
    "skrumpets": "skrumpen",
    "skrumplevern": "skrumplever",
    "skrumpleverns": "skrumplever",
    "skrumplevers": "skrumplever",
    "skrumpna": "skrumpen",
    "skrumpnade": "skrumpna",
    "skrumpnades": "skrumpna",
    "skrumpnande": "skrumpna",
    "skrumpnanden": "skrumpnande",
    "skrumpnandena": "skrumpnande",
    "skrumpnandenas": "skrumpnande",
    "skrumpnandens": "skrumpnande",
    "skrumpnandes": "skrumpnande",
    "skrumpnandet": "skrumpnande",
    "skrumpnandets": "skrumpnande",
    "skrumpnar": "skrumpna",
    "skrumpnare": "skrumpen",
    "skrumpnares": "skrumpen",
    "skrumpnas": "skrumpna",
    "skrumpnast": "skrumpen",
    "skrumpnaste": "skrumpen",
    "skrumpnastes": "skrumpen",
    "skrumpnasts": "skrumpen",
    "skrumpnat": "skrumpna",
    "skrumpnats": "skrumpna",
    "skrumpne": "skrumpen",
    "skrumpnes": "skrumpen",
    "skrumpnjuren": "skrumpnjure",
    "skrumpnjurens": "skrumpnjure",
    "skrumpnjures": "skrumpnjure",
    "skrupelfria": "skrupelfri",
    "skrupelfriare": "skrupelfri",
    "skrupelfriares": "skrupelfri",
    "skrupelfrias": "skrupelfri",
    "skrupelfriast": "skrupelfri",
    "skrupelfriaste": "skrupelfri",
    "skrupelfriastes": "skrupelfri",
    "skrupelfriasts": "skrupelfri",
    "skrupelfrie": "skrupelfri",
    "skrupelfries": "skrupelfri",
    "skrupelfris": "skrupelfri",
    "skrupelfritt": "skrupelfri",
    "skrupelfritts": "skrupelfri",
    "skrupeln": "skrupel",
    "skrupelns": "skrupel",
    "skrupels": "skrupel",
    "skrupler": "skrupel",
    "skruplerna": "skrupel",
    "skruplernas": "skrupel",
    "skruplers": "skrupel",
    "skrupulösa": "skrupulös",
    "skrupulösare": "skrupulös",
    "skrupulösares": "skrupulös",
    "skrupulösas": "skrupulös",
    "skrupulösast": "skrupulös",
    "skrupulösaste": "skrupulös",
    "skrupulösastes": "skrupulös",
    "skrupulösasts": "skrupulös",
    "skrupulöse": "skrupulös",
    "skrupulöses": "skrupulös",
    "skrupulöst": "skrupulös",
    "skrupulösts": "skrupulös",
    "skrute": "skryta",
    "skrutes": "skryta",
    "skrutit": "skryta",
    "skrutits": "skryta",
    "skruttar": "skrutt",
    "skruttarna": "skrutt",
    "skruttarnas": "skrutt",
    "skruttars": "skrutt",
    "skrutten": "skrutt",
    "skruttens": "skrutt",
    "skruttet": "skrutt",
    "skruttets": "skrutt",
    "skruttiga": "skruttig",
    "skruttigare": "skruttig",
    "skruttigares": "skruttig",
    "skruttigas": "skruttig",
    "skruttigast": "skruttig",
    "skruttigaste": "skruttig",
    "skruttigastes": "skruttig",
    "skruttigasts": "skruttig",
    "skruttige": "skruttig",
    "skruttiges": "skruttig",
    "skruttigheten": "skruttighet",
    "skruttighetens": "skruttighet",
    "skruttighets": "skruttighet",
    "skruttigs": "skruttig",
    "skruttigt": "skruttig",
    "skruttigts": "skruttig",
    "skrutts": "skrutt",
    "skruv": "skruva",
    "skruvad": "skruva",
    "skruvade": "skruvad",
    "skruvades": "skruvad",
    "skruvads": "skruvad",
    "skruvande": "skruva",
    "skruvanden": "skruvande",
    "skruvandena": "skruvande",
    "skruvandenas": "skruvande",
    "skruvandens": "skruvande",
    "skruvandes": "skruvande",
    "skruvandet": "skruvande",
    "skruvandets": "skruvande",
    "skruvar": "skruva",
    "skruvarna": "skruv",
    "skruvarnas": "skruv",
    "skruvars": "skruv",
    "skruvas": "skruva",
    "skruvat": "skruvad",
    "skruvats": "skruvad",
    "skruvavstånden": "skruvavstånd",
    "skruvavståndens": "skruvavstånd",
    "skruvavståndet": "skruvavstånd",
    "skruvavståndets": "skruvavstånd",
    "skruvavstånds": "skruvavstånd",
    "skruvbara": "skruvbar",
    "skruvbaras": "skruvbar",
    "skruvbare": "skruvbar",
    "skruvbares": "skruvbar",
    "skruvbars": "skruvbar",
    "skruvbart": "skruvbar",
    "skruvbarts": "skruvbar",
    "skruvdragar": "skruvdragare",
    "skruvdragaren": "skruvdragare",
    "skruvdragarens": "skruvdragare",
    "skruvdragares": "skruvdragare",
    "skruvdragarna": "skruvdragare",
    "skruvdragarnas": "skruvdragare",
    "skruven": "skruv",
    "skruvens": "skruv",
    "skruvförbanden": "skruvförband",
    "skruvförbandens": "skruvförband",
    "skruvförbandet": "skruvförband",
    "skruvförbandets": "skruvförband",
    "skruvförbands": "skruvförband",
    "skruvhuvuden": "skruvhuvud",
    "skruvhuvudena": "skruvhuvud",
    "skruvhuvudenas": "skruvhuvud",
    "skruvhuvudens": "skruvhuvud",
    "skruvhuvudet": "skruvhuvud",
    "skruvhuvudets": "skruvhuvud",
    "skruvhuvuds": "skruvhuvud",
    "skruvhålen": "skruvhål",
    "skruvhålens": "skruvhål",
    "skruvhålet": "skruvhål",
    "skruvhålets": "skruvhål",
    "skruvhåls": "skruvhål",
    "skruvisen": "skruvis",
    "skruvisens": "skruvis",
    "skruvkrokar": "skruvkrok",
    "skruvkrokarna": "skruvkrok",
    "skruvkrokarnas": "skruvkrok",
    "skruvkrokars": "skruvkrok",
    "skruvkroken": "skruvkrok",
    "skruvkrokens": "skruvkrok",
    "skruvkroks": "skruvkrok",
    "skruvmejseln": "skruvmejsel",
    "skruvmejselns": "skruvmejsel",
    "skruvmejsels": "skruvmejsel",
    "skruvmejslar": "skruvmejsel",
    "skruvmejslarna": "skruvmejsel",
    "skruvmejslarnas": "skruvmejsel",
    "skruvmejslars": "skruvmejsel",
    "skruvnyckeln": "skruvnyckel",
    "skruvnyckelns": "skruvnyckel",
    "skruvnyckels": "skruvnyckel",
    "skruvnycklar": "skruvnyckel",
    "skruvnycklarna": "skruvnyckel",
    "skruvnycklarnas": "skruvnyckel",
    "skruvnycklars": "skruvnyckel",
    "skruvs": "skruv",
    "skruvskall": "skruvskalle",
    "skruvskallar": "skruvskalle",
    "skruvskallarna": "skruvskalle",
    "skruvskallarnas": "skruvskalle",
    "skruvskallars": "skruvskalle",
    "skruvskallen": "skruvskalle",
    "skruvskallens": "skruvskalle",
    "skruvskalles": "skruvskalle",
    "skruvskalls": "skruvskalle",
    "skruvstycken": "skruvstycke",
    "skruvstyckena": "skruvstycke",
    "skruvstyckenas": "skruvstycke",
    "skruvstyckens": "skruvstycke",
    "skruvstyckes": "skruvstycke",
    "skruvstycket": "skruvstycke",
    "skruvstyckets": "skruvstycke",
    "skruvstycks": "skruvstycke",
    "skruvstäden": "skruvstäd",
    "skruvstädens": "skruvstäd",
    "skruvstädet": "skruvstäd",
    "skruvstädets": "skruvstäd",
    "skruvstäds": "skruvstäd",
    "skruvtvingar": "skruvtving",
    "skruvtvingarna": "skruvtving",
    "skruvtvingarnas": "skruvtving",
    "skruvtvingars": "skruvtving",
    "skruvtvingen": "skruvtving",
    "skruvtvingens": "skruvtving",
    "skruvtvings": "skruvtving",
    "skrym": "skrymma",
    "skrymd": "skrymma",
    "skrymda": "skrymma",
    "skrymdas": "skrymma",
    "skrymde": "skrymma",
    "skrymdes": "skrymma",
    "skrymds": "skrymma",
    "skrymmande": "skrymma",
    "skrymmanden": "skrymmande",
    "skrymmandena": "skrymmande",
    "skrymmandenas": "skrymmande",
    "skrymmandens": "skrymmande",
    "skrymmandes": "skrymmande",
    "skrymmandet": "skrymmande",
    "skrymmandets": "skrymmande",
    "skrymmas": "skrymma",
    "skrymmer": "skrymma",
    "skryms": "skrymma",
    "skrymsl": "skrymsle",
    "skrymslan": "skrymsla",
    "skrymslans": "skrymsla",
    "skrymslas": "skrymsla",
    "skrymsle": "skrymsla",
    "skrymslen": "skrymsle",
    "skrymslena": "skrymsle",
    "skrymslenas": "skrymsle",
    "skrymslens": "skrymsle",
    "skrymsles": "skrymsle",
    "skrymslet": "skrymsle",
    "skrymslets": "skrymsle",
    "skrymslor": "skrymsla",
    "skrymslorna": "skrymsla",
    "skrymslornas": "skrymsla",
    "skrymslors": "skrymsla",
    "skrymt": "skrymta",
    "skrymtad": "skrymta",
    "skrymtade": "skrymta",
    "skrymtades": "skrymta",
    "skrymtads": "skrymta",
    "skrymtande": "skrymta",
    "skrymtanden": "skrymtande",
    "skrymtandena": "skrymtande",
    "skrymtandenas": "skrymtande",
    "skrymtandens": "skrymtande",
    "skrymtandes": "skrymtande",
    "skrymtandet": "skrymtande",
    "skrymtandets": "skrymtande",
    "skrymtar": "skrymtare",
    "skrymtaren": "skrymtare",
    "skrymtarens": "skrymtare",
    "skrymtares": "skrymtare",
    "skrymtarna": "skrymtare",
    "skrymtarnas": "skrymtare",
    "skrymtas": "skrymta",
    "skrymtat": "skrymta",
    "skrymtats": "skrymta",
    "skrymten": "skrymt",
    "skrymtens": "skrymt",
    "skrymterier": "skrymteri",
    "skrymterierna": "skrymteri",
    "skrymteriernas": "skrymteri",
    "skrymteriers": "skrymteri",
    "skrymteriet": "skrymteri",
    "skrymteriets": "skrymteri",
    "skrymteris": "skrymteri",
    "skrymterit": "skrymteri",
    "skrymterits": "skrymteri",
    "skrymtet": "skrymt",
    "skrymtets": "skrymt",
    "skrymts": "skrymt",
    "skrynkel": "skrynkla",
    "skrynkelfria": "skrynkelfri",
    "skrynkelfriare": "skrynkelfri",
    "skrynkelfriares": "skrynkelfri",
    "skrynkelfrias": "skrynkelfri",
    "skrynkelfriast": "skrynkelfri",
    "skrynkelfriaste": "skrynkelfri",
    "skrynkelfriastes": "skrynkelfri",
    "skrynkelfriasts": "skrynkelfri",
    "skrynkelfrie": "skrynkelfri",
    "skrynkelfries": "skrynkelfri",
    "skrynkelfris": "skrynkelfri",
    "skrynkelfritt": "skrynkelfri",
    "skrynkelfritts": "skrynkelfri",
    "skrynkelhärdiga": "skrynkelhärdig",
    "skrynkelhärdigare": "skrynkelhärdig",
    "skrynkelhärdigares": "skrynkelhärdig",
    "skrynkelhärdigas": "skrynkelhärdig",
    "skrynkelhärdigast": "skrynkelhärdig",
    "skrynkelhärdigaste": "skrynkelhärdig",
    "skrynkelhärdigastes": "skrynkelhärdig",
    "skrynkelhärdigasts": "skrynkelhärdig",
    "skrynkelhärdige": "skrynkelhärdig",
    "skrynkelhärdiges": "skrynkelhärdig",
    "skrynkelhärdigs": "skrynkelhärdig",
    "skrynkelhärdigt": "skrynkelhärdig",
    "skrynkelhärdigts": "skrynkelhärdig",
    "skrynklad": "skrynkla",
    "skrynklade": "skrynkla",
    "skrynklades": "skrynkla",
    "skrynklads": "skrynkla",
    "skrynklan": "skrynkla",
    "skrynklande": "skrynkla",
    "skrynklanden": "skrynklande",
    "skrynklandena": "skrynklande",
    "skrynklandenas": "skrynklande",
    "skrynklandens": "skrynklande",
    "skrynklandes": "skrynklande",
    "skrynklandet": "skrynklande",
    "skrynklandets": "skrynklande",
    "skrynklans": "skrynkla",
    "skrynklar": "skrynkla",
    "skrynklas": "skrynkla",
    "skrynklat": "skrynkla",
    "skrynklats": "skrynkla",
    "skrynkle": "skrynkla",
    "skrynkliga": "skrynklig",
    "skrynkligare": "skrynklig",
    "skrynkligares": "skrynklig",
    "skrynkligas": "skrynklig",
    "skrynkligast": "skrynklig",
    "skrynkligaste": "skrynklig",
    "skrynkligastes": "skrynklig",
    "skrynkligasts": "skrynklig",
    "skrynklige": "skrynklig",
    "skrynkliges": "skrynklig",
    "skrynkligheten": "skrynklighet",
    "skrynklighetens": "skrynklighet",
    "skrynklighets": "skrynklighet",
    "skrynkligs": "skrynklig",
    "skrynkligt": "skrynklig",
    "skrynkligts": "skrynklig",
    "skrynklor": "skrynkla",
    "skrynklorna": "skrynkla",
    "skrynklornas": "skrynkla",
    "skrynklors": "skrynkla",
    "skryt": "skryta",
    "skrytande": "skryta",
    "skrytanden": "skrytande",
    "skrytandena": "skrytande",
    "skrytandenas": "skrytande",
    "skrytandens": "skrytande",
    "skrytandes": "skrytande",
    "skrytandet": "skrytande",
    "skrytandets": "skrytande",
    "skrytas": "skryta",
    "skrytbyggen": "skrytbygge",
    "skrytbyggena": "skrytbygge",
    "skrytbyggenas": "skrytbygge",
    "skrytbyggens": "skrytbygge",
    "skrytbygges": "skrytbygge",
    "skrytbygget": "skrytbygge",
    "skrytbyggets": "skrytbygge",
    "skryte": "skryta",
    "skryter": "skryta",
    "skrytes": "skryta",
    "skrytet": "skryt",
    "skrytets": "skryt",
    "skrytmånsar": "skrytmåns",
    "skrytmånsarna": "skrytmåns",
    "skrytmånsarnas": "skrytmåns",
    "skrytmånsars": "skrytmåns",
    "skrytmånsen": "skrytmåns",
    "skrytmånsens": "skrytmåns",
    "skryts": "skryta",
    "skrytsamheten": "skrytsamhet",
    "skrytsamhetens": "skrytsamhet",
    "skrytsamhets": "skrytsamhet",
    "skrytsamma": "skrytsam",
    "skrytsammare": "skrytsam",
    "skrytsammares": "skrytsam",
    "skrytsammas": "skrytsam",
    "skrytsammast": "skrytsam",
    "skrytsammaste": "skrytsam",
    "skrytsammastes": "skrytsam",
    "skrytsammasts": "skrytsam",
    "skrytsamme": "skrytsam",
    "skrytsammes": "skrytsam",
    "skrytsams": "skrytsam",
    "skrytsamt": "skrytsam",
    "skrytsamts": "skrytsam",
    "skräckar": "skräck",
    "skräckarna": "skräck",
    "skräckarnas": "skräck",
    "skräckars": "skräck",
    "skräckels": "skräckel",
    "skräcken": "skräck",
    "skräckens": "skräck",
    "skräckexempels": "skräckexempel",
    "skräckexemplen": "skräckexempel",
    "skräckexemplens": "skräckexempel",
    "skräckexemplet": "skräckexempel",
    "skräckexemplets": "skräckexempel",
    "skräckfilmen": "skräckfilm",
    "skräckfilmens": "skräckfilm",
    "skräckfilmer": "skräckfilm",
    "skräckfilmerna": "skräckfilm",
    "skräckfilmernas": "skräckfilm",
    "skräckfilmers": "skräckfilm",
    "skräckfilms": "skräckfilm",
    "skräckhistorian": "skräckhistoria",
    "skräckhistorians": "skräckhistoria",
    "skräckhistorias": "skräckhistoria",
    "skräckhistorien": "skräckhistoria",
    "skräckhistoriens": "skräckhistoria",
    "skräckhistorier": "skräckhistoria",
    "skräckhistorierna": "skräckhistoria",
    "skräckhistoriernas": "skräckhistoria",
    "skräckhistoriers": "skräckhistoria",
    "skräckkabinetten": "skräckkabinett",
    "skräckkabinettens": "skräckkabinett",
    "skräckkabinettet": "skräckkabinett",
    "skräckkabinettets": "skräckkabinett",
    "skräckkabinetts": "skräckkabinett",
    "skräcklet": "skräckel",
    "skräcklets": "skräckel",
    "skräcknatn": "skräcknatt",
    "skräcknatns": "skräcknatt",
    "skräcknatten": "skräcknatt",
    "skräcknattens": "skräcknatt",
    "skräcknatts": "skräcknatt",
    "skräcknovellen": "skräcknovell",
    "skräcknovellens": "skräcknovell",
    "skräcknoveller": "skräcknovell",
    "skräcknovellerna": "skräcknovell",
    "skräcknovellernas": "skräcknovell",
    "skräcknovellers": "skräcknovell",
    "skräcknovells": "skräcknovell",
    "skräcknätter": "skräcknatt",
    "skräcknätterna": "skräcknatt",
    "skräcknätternas": "skräcknatt",
    "skräcknätters": "skräcknatt",
    "skräckpropagandan": "skräckpropaganda",
    "skräckpropagandans": "skräckpropaganda",
    "skräckpropagandas": "skräckpropaganda",
    "skräckregementes": "skräckregemente",
    "skräckregementet": "skräckregemente",
    "skräckregementets": "skräckregemente",
    "skräckrubriken": "skräckrubrik",
    "skräckrubrikens": "skräckrubrik",
    "skräckrubriker": "skräckrubrik",
    "skräckrubrikerna": "skräckrubrik",
    "skräckrubrikernas": "skräckrubrik",
    "skräckrubrikers": "skräckrubrik",
    "skräckrubriks": "skräckrubrik",
    "skräcks": "skräck",
    "skräckskildringar": "skräckskildring",
    "skräckskildringarna": "skräckskildring",
    "skräckskildringarnas": "skräckskildring",
    "skräckskildringars": "skräckskildring",
    "skräckskildringen": "skräckskildring",
    "skräckskildringens": "skräckskildring",
    "skräckskildrings": "skräckskildring",
    "skräckslagens": "skräckslagen",
    "skräckslaget": "skräckslagen",
    "skräckslagets": "skräckslagen",
    "skräckslagna": "skräckslagen",
    "skräckslagnare": "skräckslagen",
    "skräckslagnares": "skräckslagen",
    "skräckslagnas": "skräckslagen",
    "skräckslagnast": "skräckslagen",
    "skräckslagnaste": "skräckslagen",
    "skräckslagnastes": "skräckslagen",
    "skräckslagnasts": "skräckslagen",
    "skräckslagne": "skräckslagen",
    "skräckslagnes": "skräckslagen",
    "skräcksynen": "skräcksyn",
    "skräcksynens": "skräcksyn",
    "skräcksyner": "skräcksyn",
    "skräcksynerna": "skräcksyn",
    "skräcksynernas": "skräcksyn",
    "skräcksyners": "skräcksyn",
    "skräcksyns": "skräcksyn",
    "skräcktacklingar": "skräcktackling",
    "skräcktacklingarna": "skräcktackling",
    "skräcktacklingarnas": "skräcktackling",
    "skräcktacklingars": "skräcktackling",
    "skräcktacklingen": "skräcktackling",
    "skräcktacklingens": "skräcktackling",
    "skräcktacklings": "skräcktackling",
    "skräckvisionen": "skräckvision",
    "skräckvisionens": "skräckvision",
    "skräckvisioner": "skräckvision",
    "skräckvisionerna": "skräckvision",
    "skräckvisionernas": "skräckvision",
    "skräckvisioners": "skräckvision",
    "skräckvisions": "skräckvision",
    "skräckvälden": "skräckvälde",
    "skräckväldena": "skräckvälde",
    "skräckväldenas": "skräckvälde",
    "skräckväldens": "skräckvälde",
    "skräckväldes": "skräckvälde",
    "skräckväldet": "skräckvälde",
    "skräckväldets": "skräckvälde",
    "skräcködlan": "skräcködla",
    "skräcködlans": "skräcködla",
    "skräcködlas": "skräcködla",
    "skräcködle": "skräcködla",
    "skräcködlor": "skräcködla",
    "skräcködlorna": "skräcködla",
    "skräcködlornas": "skräcködla",
    "skräcködlors": "skräcködla",
    "skräd": "skräda",
    "skrädande": "skräda",
    "skrädanden": "skrädande",
    "skrädandena": "skrädande",
    "skrädandenas": "skrädande",
    "skrädandens": "skrädande",
    "skrädandes": "skrädande",
    "skrädandet": "skrädande",
    "skrädandets": "skrädande",
    "skrädas": "skräda",
    "skrädd": "skrädda",
    "skrädda": "skräda",
    "skräddad": "skrädda",
    "skräddade": "skrädda",
    "skräddades": "skrädda",
    "skräddads": "skrädda",
    "skräddande": "skrädda",
    "skräddanden": "skräddande",
    "skräddandena": "skräddande",
    "skräddandenas": "skräddande",
    "skräddandens": "skräddande",
    "skräddandes": "skräddande",
    "skräddandet": "skräddande",
    "skräddandets": "skräddande",
    "skräddar": "skräddare",
    "skräddaren": "skräddare",
    "skräddarens": "skräddare",
    "skräddares": "skräddare",
    "skräddarna": "skräddare",
    "skräddarnas": "skräddare",
    "skräddarsydd": "skräddarsy",
    "skräddarsydda": "skräddarsy",
    "skräddarsyddas": "skräddarsy",
    "skräddarsydde": "skräddarsy",
    "skräddarsyddes": "skräddarsy",
    "skräddarsydds": "skräddarsy",
    "skräddarsyende": "skräddarsy",
    "skräddarsyenden": "skräddarsyende",
    "skräddarsyendena": "skräddarsyende",
    "skräddarsyendenas": "skräddarsyende",
    "skräddarsyendens": "skräddarsyende",
    "skräddarsyendes": "skräddarsyende",
    "skräddarsyendet": "skräddarsyende",
    "skräddarsyendets": "skräddarsyende",
    "skräddarsyr": "skräddarsy",
    "skräddarsys": "skräddarsy",
    "skräddarsytt": "skräddarsy",
    "skräddarsytts": "skräddarsy",
    "skräddas": "skrädda",
    "skräddat": "skrädda",
    "skräddats": "skrädda",
    "skrädde": "skräda",
    "skrädderier": "skrädderi",
    "skrädderierna": "skrädderi",
    "skrädderiernas": "skrädderi",
    "skrädderiers": "skrädderi",
    "skrädderiet": "skrädderi",
    "skrädderiets": "skrädderi",
    "skrädderis": "skrädderi",
    "skrädderit": "skrädderi",
    "skrädderits": "skrädderi",
    "skräddes": "skräda",
    "skrädds": "skräda",
    "skräder": "skräda",
    "skrädes": "skräda",
    "skräds": "skräda",
    "skrädyx": "skrädyxa",
    "skrädyxan": "skrädyxa",
    "skrädyxans": "skrädyxa",
    "skrädyxas": "skrädyxa",
    "skrädyxe": "skrädyxa",
    "skrädyxor": "skrädyxa",
    "skrädyxorna": "skrädyxa",
    "skrädyxornas": "skrädyxa",
    "skrädyxors": "skrädyxa",
    "skräll": "skrälla",
    "skrällande": "skrälla",
    "skrällanden": "skrällande",
    "skrällandena": "skrällande",
    "skrällandenas": "skrällande",
    "skrällandens": "skrällande",
    "skrällandes": "skrällande",
    "skrällandet": "skrällande",
    "skrällandets": "skrällande",
    "skrällar": "skräll",
    "skrällarna": "skräll",
    "skrällarnas": "skräll",
    "skrällars": "skräll",
    "skrällas": "skrälla",
    "skrälld": "skrälla",
    "skrällda": "skrälla",
    "skrälldas": "skrälla",
    "skrällde": "skrälla",
    "skrälldes": "skrälla",
    "skrällds": "skrälla",
    "skrälldusen": "skrälldus",
    "skrälldusens": "skrälldus",
    "skrällduser": "skrälldus",
    "skrällduserna": "skrälldus",
    "skrälldusernas": "skrälldus",
    "skrälldusers": "skrälldus",
    "skrällen": "skrälle",
    "skrällena": "skrälle",
    "skrällenas": "skrälle",
    "skrällens": "skrälle",
    "skräller": "skrälla",
    "skrälles": "skrälle",
    "skrället": "skrälle",
    "skrällets": "skrälle",
    "skrällhost": "skrällhosta",
    "skrällhostan": "skrällhosta",
    "skrällhostans": "skrällhosta",
    "skrällhostas": "skrällhosta",
    "skrällhoste": "skrällhosta",
    "skrälliga": "skrällig",
    "skrälligare": "skrällig",
    "skrälligares": "skrällig",
    "skrälligas": "skrällig",
    "skrälligast": "skrällig",
    "skrälligaste": "skrällig",
    "skrälligastes": "skrällig",
    "skrälligasts": "skrällig",
    "skrällige": "skrällig",
    "skrälliges": "skrällig",
    "skrälligheten": "skrällighet",
    "skrällighetens": "skrällighet",
    "skrällighets": "skrällighet",
    "skrälligs": "skrällig",
    "skrälligt": "skrällig",
    "skrälligts": "skrällig",
    "skrälls": "skrälla",
    "skrällsegern": "skrällseger",
    "skrällsegerns": "skrällseger",
    "skrällsegers": "skrällseger",
    "skrällsegrar": "skrällseger",
    "skrällsegrarna": "skrällseger",
    "skrällsegrarnas": "skrällseger",
    "skrällsegrars": "skrällseger",
    "skrällt": "skrälla",
    "skrällts": "skrälla",
    "skrällvinsten": "skrällvinst",
    "skrällvinstens": "skrällvinst",
    "skrällvinster": "skrällvinst",
    "skrällvinsterna": "skrällvinst",
    "skrällvinsternas": "skrällvinst",
    "skrällvinsters": "skrällvinst",
    "skrällvinsts": "skrällvinst",
    "skräm": "skrämma",
    "skrämd": "skrämma",
    "skrämda": "skrämma",
    "skrämdas": "skrämma",
    "skrämde": "skrämma",
    "skrämdes": "skrämma",
    "skrämds": "skrämma",
    "skrämmande": "skrämma",
    "skrämmanden": "skrämmande",
    "skrämmandena": "skrämmande",
    "skrämmandenas": "skrämmande",
    "skrämmandens": "skrämmande",
    "skrämmandes": "skrämmande",
    "skrämmandet": "skrämmande",
    "skrämmandets": "skrämmande",
    "skrämmas": "skrämma",
    "skrämmer": "skrämma",
    "skräms": "skrämma",
    "skrämselhickan": "skrämselhicka",
    "skrämselhickans": "skrämselhicka",
    "skrämselhickas": "skrämselhicka",
    "skrämselhicke": "skrämselhicka",
    "skrämselhickor": "skrämselhicka",
    "skrämselhickorna": "skrämselhicka",
    "skrämselhickornas": "skrämselhicka",
    "skrämselhickors": "skrämselhicka",
    "skrämseln": "skrämsel",
    "skrämselns": "skrämsel",
    "skrämselpropagandan": "skrämselpropaganda",
    "skrämselpropagandans": "skrämselpropaganda",
    "skrämselpropagandas": "skrämselpropaganda",
    "skrämsels": "skrämsel",
    "skrämskotten": "skrämskott",
    "skrämskottens": "skrämskott",
    "skrämskottet": "skrämskott",
    "skrämskottets": "skrämskott",
    "skrämskotts": "skrämskott",
    "skrämt": "skrämma",
    "skrämts": "skrämma",
    "skrän": "skräna",
    "skränad": "skräna",
    "skränade": "skräna",
    "skränades": "skräna",
    "skränads": "skräna",
    "skränande": "skräna",
    "skränanden": "skränande",
    "skränandena": "skränande",
    "skränandenas": "skränande",
    "skränandens": "skränande",
    "skränandes": "skränande",
    "skränandet": "skränande",
    "skränandets": "skränande",
    "skränar": "skräna",
    "skränas": "skräna",
    "skränat": "skräna",
    "skränats": "skräna",
    "skränen": "skrän",
    "skränens": "skrän",
    "skränet": "skrän",
    "skränets": "skrän",
    "skränfockar": "skränfock",
    "skränfockarna": "skränfock",
    "skränfockarnas": "skränfock",
    "skränfockars": "skränfock",
    "skränfocken": "skränfock",
    "skränfockens": "skränfock",
    "skränfocks": "skränfock",
    "skräniga": "skränig",
    "skränigare": "skränig",
    "skränigares": "skränig",
    "skränigas": "skränig",
    "skränigast": "skränig",
    "skränigaste": "skränig",
    "skränigastes": "skränig",
    "skränigasts": "skränig",
    "skränige": "skränig",
    "skräniges": "skränig",
    "skränigs": "skränig",
    "skränigt": "skränig",
    "skränigts": "skränig",
    "skränk": "skränka",
    "skränkande": "skränka",
    "skränkanden": "skränkande",
    "skränkandena": "skränkande",
    "skränkandenas": "skränkande",
    "skränkandens": "skränkande",
    "skränkandes": "skränkande",
    "skränkandet": "skränkande",
    "skränkandets": "skränkande",
    "skränkas": "skränka",
    "skränker": "skränka",
    "skränkes": "skränka",
    "skränks": "skränka",
    "skränkt": "skränka",
    "skränkta": "skränka",
    "skränktas": "skränka",
    "skränkte": "skränka",
    "skränktes": "skränka",
    "skränkts": "skränka",
    "skräns": "skrän",
    "skräp": "skräpa",
    "skräpad": "skräpa",
    "skräpade": "skräpa",
    "skräpades": "skräpa",
    "skräpads": "skräpa",
    "skräpande": "skräpa",
    "skräpanden": "skräpande",
    "skräpandena": "skräpande",
    "skräpandenas": "skräpande",
    "skräpandens": "skräpande",
    "skräpandes": "skräpande",
    "skräpandet": "skräpande",
    "skräpandets": "skräpande",
    "skräpar": "skräpa",
    "skräpas": "skräpa",
    "skräpat": "skräpa",
    "skräpats": "skräpa",
    "skräpet": "skräp",
    "skräpets": "skräp",
    "skräphögar": "skräphög",
    "skräphögarna": "skräphög",
    "skräphögarnas": "skräphög",
    "skräphögars": "skräphög",
    "skräphögen": "skräphög",
    "skräphögens": "skräphög",
    "skräphögs": "skräphög",
    "skräpiga": "skräpig",
    "skräpigare": "skräpig",
    "skräpigares": "skräpig",
    "skräpigas": "skräpig",
    "skräpigast": "skräpig",
    "skräpigaste": "skräpig",
    "skräpigastes": "skräpig",
    "skräpigasts": "skräpig",
    "skräpige": "skräpig",
    "skräpiges": "skräpig",
    "skräpigs": "skräpig",
    "skräpigt": "skräpig",
    "skräpigts": "skräpig",
    "skräpkammar": "skräpkammare",
    "skräpkammaren": "skräpkammare",
    "skräpkammarens": "skräpkammare",
    "skräpkammares": "skräpkammare",
    "skräpkamrar": "skräpkammare",
    "skräpkamrarna": "skräpkammare",
    "skräpkamrarnas": "skräpkammare",
    "skräpkamrars": "skräpkammare",
    "skräpkulturen": "skräpkultur",
    "skräpkulturens": "skräpkultur",
    "skräpkulturer": "skräpkultur",
    "skräpkulturerna": "skräpkultur",
    "skräpkulturernas": "skräpkultur",
    "skräpkulturers": "skräpkultur",
    "skräpkulturs": "skräpkultur",
    "skräpmaten": "skräpmat",
    "skräpmatens": "skräpmat",
    "skräpmats": "skräpmat",
    "skräpp": "skräppa",
    "skräppan": "skräppa",
    "skräppande": "skräppa",
    "skräppanden": "skräppande",
    "skräppandena": "skräppande",
    "skräppandenas": "skräppande",
    "skräppandens": "skräppande",
    "skräppandes": "skräppande",
    "skräppandet": "skräppande",
    "skräppandets": "skräppande",
    "skräppans": "skräppa",
    "skräppas": "skräppa",
    "skräppe": "skräppa",
    "skräpper": "skräppa",
    "skräppes": "skräppa",
    "skräppor": "skräppa",
    "skräpporna": "skräppa",
    "skräppornas": "skräppa",
    "skräppors": "skräppa",
    "skräpps": "skräppa",
    "skräppt": "skräppa",
    "skräppta": "skräppa",
    "skräpptas": "skräppa",
    "skräppte": "skräppa",
    "skräpptes": "skräppa",
    "skräppts": "skräppa",
    "skräps": "skräp",
    "skrätt": "skräda",
    "skrätts": "skräda",
    "skrävel": "skrävla",
    "skrävels": "skrävel",
    "skrävlade": "skrävla",
    "skrävlades": "skrävla",
    "skrävlande": "skrävla",
    "skrävlanden": "skrävlande",
    "skrävlandena": "skrävlande",
    "skrävlandenas": "skrävlande",
    "skrävlandens": "skrävlande",
    "skrävlandes": "skrävlande",
    "skrävlandet": "skrävlande",
    "skrävlandets": "skrävlande",
    "skrävlar": "skrävlare",
    "skrävlaren": "skrävlare",
    "skrävlarens": "skrävlare",
    "skrävlares": "skrävlare",
    "skrävlarna": "skrävlare",
    "skrävlarnas": "skrävlare",
    "skrävlas": "skrävla",
    "skrävlat": "skrävla",
    "skrävlats": "skrävla",
    "skrävlet": "skrävel",
    "skrävlets": "skrävel",
    "skrävliga": "skrävlig",
    "skrävligare": "skrävlig",
    "skrävligares": "skrävlig",
    "skrävligas": "skrävlig",
    "skrävligast": "skrävlig",
    "skrävligaste": "skrävlig",
    "skrävligastes": "skrävlig",
    "skrävligasts": "skrävlig",
    "skrävlige": "skrävlig",
    "skrävliges": "skrävlig",
    "skrävligheten": "skrävlighet",
    "skrävlighetens": "skrävlighet",
    "skrävlighets": "skrävlighet",
    "skrävligs": "skrävlig",
    "skrävligt": "skrävlig",
    "skrävligts": "skrävlig",
    "skråa": "skrå",
    "skråandan": "skråanda",
    "skråandans": "skråanda",
    "skråandas": "skråanda",
    "skråare": "skrå",
    "skråares": "skrå",
    "skråas": "skrå",
    "skråast": "skrå",
    "skråaste": "skrå",
    "skråastes": "skrå",
    "skråasts": "skrå",
    "skråe": "skrå",
    "skråen": "skrå",
    "skråens": "skrå",
    "skråes": "skrå",
    "skrået": "skrå",
    "skråets": "skrå",
    "skrål": "skråla",
    "skrålad": "skråla",
    "skrålade": "skråla",
    "skrålades": "skråla",
    "skrålads": "skråla",
    "skrålande": "skråla",
    "skrålanden": "skrålande",
    "skrålandena": "skrålande",
    "skrålandenas": "skrålande",
    "skrålandens": "skrålande",
    "skrålandes": "skrålande",
    "skrålandet": "skrålande",
    "skrålandets": "skrålande",
    "skrålar": "skråla",
    "skrålas": "skråla",
    "skrålat": "skråla",
    "skrålats": "skråla",
    "skrålen": "skrål",
    "skrålens": "skrål",
    "skrålet": "skrål",
    "skrålets": "skrål",
    "skråls": "skrål",
    "skråm": "skråma",
    "skråmad": "skråma",
    "skråmade": "skråma",
    "skråmades": "skråma",
    "skråmads": "skråma",
    "skråman": "skråma",
    "skråmande": "skråma",
    "skråmanden": "skråmande",
    "skråmandena": "skråmande",
    "skråmandenas": "skråmande",
    "skråmandens": "skråmande",
    "skråmandes": "skråmande",
    "skråmandet": "skråmande",
    "skråmandets": "skråmande",
    "skråmans": "skråma",
    "skråmar": "skråma",
    "skråmas": "skråma",
    "skråmat": "skråma",
    "skråmats": "skråma",
    "skråme": "skråma",
    "skråmor": "skråma",
    "skråmorna": "skråma",
    "skråmornas": "skråma",
    "skråmors": "skråma",
    "skråms": "skråma",
    "skråmässiga": "skråmässig",
    "skråmässigare": "skråmässig",
    "skråmässigares": "skråmässig",
    "skråmässigas": "skråmässig",
    "skråmässigast": "skråmässig",
    "skråmässigaste": "skråmässig",
    "skråmässigastes": "skråmässig",
    "skråmässigasts": "skråmässig",
    "skråmässige": "skråmässig",
    "skråmässiges": "skråmässig",
    "skråmässigs": "skråmässig",
    "skråmässigt": "skråmässig",
    "skråmässigts": "skråmässig",
    "skrån": "skrå",
    "skråna": "skrå",
    "skrånas": "skrå",
    "skråns": "skrå",
    "skråpukar": "skråpuk",
    "skråpukarna": "skråpuk",
    "skråpukarnas": "skråpuk",
    "skråpukars": "skråpuk",
    "skråpuken": "skråpuk",
    "skråpukens": "skråpuk",
    "skråpuks": "skråpuk",
    "skrås": "skrå",
    "skråt": "skrå",
    "skråts": "skrå",
    "skrått": "skrå",
    "skråtts": "skrå",
    "skråväsendet": "skråväsen",
    "skråväsendets": "skråväsen",
    "skråväsenet": "skråväsen",
    "skråväsenets": "skråväsen",
    "skråväsens": "skråväsen",
    "skrön": "skröna",
    "skrönan": "skröna",
    "skrönans": "skröna",
    "skrönas": "skröna",
    "skröne": "skröna",
    "skrönor": "skröna",
    "skrönorna": "skröna",
    "skrönornas": "skröna",
    "skrönors": "skröna",
    "skröns": "skröna",
    "skröpliga": "skröplig",
    "skröpligare": "skröplig",
    "skröpligares": "skröplig",
    "skröpligas": "skröplig",
    "skröpligast": "skröplig",
    "skröpligaste": "skröplig",
    "skröpligastes": "skröplig",
    "skröpligasts": "skröplig",
    "skröplige": "skröplig",
    "skröpliges": "skröplig",
    "skröpligheten": "skröplighet",
    "skröplighetens": "skröplighet",
    "skröpligheter": "skröplighet",
    "skröpligheterna": "skröplighet",
    "skröpligheternas": "skröplighet",
    "skröpligheters": "skröplighet",
    "skröplighets": "skröplighet",
    "skröpligs": "skröplig",
    "skröpligt": "skröplig",
    "skröpligts": "skröplig",
    "skröt": "skryta",
    "skröts": "skryta",
    "skubb": "skubba",
    "skubbad": "skubba",
    "skubbade": "skubba",
    "skubbades": "skubba",
    "skubbads": "skubba",
    "skubbande": "skubba",
    "skubbanden": "skubbande",
    "skubbandena": "skubbande",
    "skubbandenas": "skubbande",
    "skubbandens": "skubbande",
    "skubbandes": "skubbande",
    "skubbandet": "skubbande",
    "skubbandets": "skubbande",
    "skubbar": "skubba",
    "skubbas": "skubba",
    "skubbat": "skubba",
    "skubbats": "skubba",
    "skubben": "skubb",
    "skubbens": "skubb",
    "skubbet": "skubb",
    "skubbets": "skubb",
    "skubbs": "skubb",
    "skudd": "skudda",
    "skuddad": "skudda",
    "skuddade": "skudda",
    "skuddades": "skudda",
    "skuddads": "skudda",
    "skuddande": "skudda",
    "skuddanden": "skuddande",
    "skuddandena": "skuddande",
    "skuddandenas": "skuddande",
    "skuddandens": "skuddande",
    "skuddandes": "skuddande",
    "skuddandet": "skuddande",
    "skuddandets": "skuddande",
    "skuddar": "skudda",
    "skuddas": "skudda",
    "skuddat": "skudda",
    "skuddats": "skudda",
    "skuff": "skuffa",
    "skuffad": "skuffa",
    "skuffade": "skuffa",
    "skuffades": "skuffa",
    "skuffads": "skuffa",
    "skuffande": "skuffa",
    "skuffanden": "skuffande",
    "skuffandena": "skuffande",
    "skuffandenas": "skuffande",
    "skuffandens": "skuffande",
    "skuffandes": "skuffande",
    "skuffandet": "skuffande",
    "skuffandets": "skuffande",
    "skuffar": "skuffa",
    "skuffarna": "skuff",
    "skuffarnas": "skuff",
    "skuffars": "skuff",
    "skuffas": "skuffa",
    "skuffat": "skuffa",
    "skuffats": "skuffa",
    "skuffen": "skuff",
    "skuffens": "skuff",
    "skuffertar": "skuffert",
    "skuffertarna": "skuffert",
    "skuffertarnas": "skuffert",
    "skuffertars": "skuffert",
    "skufferten": "skuffert",
    "skuffertens": "skuffert",
    "skufferts": "skuffert",
    "skuffs": "skuff",
    "skugg": "skugga",
    "skuggad": "skugga",
    "skuggade": "skugga",
    "skuggades": "skugga",
    "skuggads": "skugga",
    "skuggan": "skugga",
    "skuggande": "skugga",
    "skugganden": "skuggande",
    "skuggandena": "skuggande",
    "skuggandenas": "skuggande",
    "skuggandens": "skuggande",
    "skuggandes": "skuggande",
    "skuggandet": "skuggande",
    "skuggandets": "skuggande",
    "skuggans": "skugga",
    "skuggar": "skugga",
    "skuggas": "skugga",
    "skuggat": "skugga",
    "skuggats": "skugga",
    "skuggbilden": "skuggbild",
    "skuggbildens": "skuggbild",
    "skuggbilder": "skuggbild",
    "skuggbilderna": "skuggbild",
    "skuggbildernas": "skuggbild",
    "skuggbilders": "skuggbild",
    "skuggbilds": "skuggbild",
    "skuggbox": "skuggboxa",
    "skuggboxade": "skuggboxa",
    "skuggboxades": "skuggboxa",
    "skuggboxande": "skuggboxa",
    "skuggboxanden": "skuggboxande",
    "skuggboxandena": "skuggboxande",
    "skuggboxandenas": "skuggboxande",
    "skuggboxandens": "skuggboxande",
    "skuggboxandes": "skuggboxande",
    "skuggboxandet": "skuggboxande",
    "skuggboxandets": "skuggboxande",
    "skuggboxar": "skuggboxa",
    "skuggboxas": "skuggboxa",
    "skuggboxat": "skuggboxa",
    "skuggboxats": "skuggboxa",
    "skuggboxningar": "skuggboxning",
    "skuggboxningarna": "skuggboxning",
    "skuggboxningarnas": "skuggboxning",
    "skuggboxningars": "skuggboxning",
    "skuggboxningen": "skuggboxning",
    "skuggboxningens": "skuggboxning",
    "skuggboxnings": "skuggboxning",
    "skugge": "skugga",
    "skuggiga": "skuggig",
    "skuggigare": "skuggig",
    "skuggigares": "skuggig",
    "skuggigas": "skuggig",
    "skuggigast": "skuggig",
    "skuggigaste": "skuggig",
    "skuggigastes": "skuggig",
    "skuggigasts": "skuggig",
    "skuggige": "skuggig",
    "skuggiges": "skuggig",
    "skuggigheten": "skuggighet",
    "skuggighetens": "skuggighet",
    "skuggighets": "skuggighet",
    "skuggigs": "skuggig",
    "skuggigt": "skuggig",
    "skuggigts": "skuggig",
    "skuggindustrien": "skuggindustri",
    "skuggindustriens": "skuggindustri",
    "skuggindustrier": "skuggindustri",
    "skuggindustrierna": "skuggindustri",
    "skuggindustriernas": "skuggindustri",
    "skuggindustriers": "skuggindustri",
    "skuggindustrin": "skuggindustri",
    "skuggindustrins": "skuggindustri",
    "skuggindustris": "skuggindustri",
    "skuggkabinetten": "skuggkabinett",
    "skuggkabinettens": "skuggkabinett",
    "skuggkabinettet": "skuggkabinett",
    "skuggkabinettets": "skuggkabinett",
    "skuggkabinetts": "skuggkabinett",
    "skugglösningar": "skugglösning",
    "skugglösningarna": "skugglösning",
    "skugglösningarnas": "skugglösning",
    "skugglösningars": "skugglösning",
    "skugglösningen": "skugglösning",
    "skugglösningens": "skugglösning",
    "skugglösnings": "skugglösning",
    "skuggor": "skugga",
    "skuggorna": "skugga",
    "skuggornas": "skugga",
    "skuggors": "skugga",
    "skuggregeringar": "skuggregering",
    "skuggregeringarna": "skuggregering",
    "skuggregeringarnas": "skuggregering",
    "skuggregeringars": "skuggregering",
    "skuggregeringen": "skuggregering",
    "skuggregeringens": "skuggregering",
    "skuggregerings": "skuggregering",
    "skuggs": "skugga",
    "skuggsidan": "skuggsida",
    "skuggsidans": "skuggsida",
    "skuggsidas": "skuggsida",
    "skuggside": "skuggsida",
    "skuggsides": "skuggsida",
    "skuggsidor": "skuggsida",
    "skuggsidorna": "skuggsida",
    "skuggsidornas": "skuggsida",
    "skuggsidors": "skuggsida",
    "skuggspelet": "skuggspel",
    "skuggspelets": "skuggspel",
    "skuggspels": "skuggspel",
    "skuggspelsteatern": "skuggspelsteater",
    "skuggspelsteaterns": "skuggspelsteater",
    "skuggspelsteaters": "skuggspelsteater",
    "skuggspelsteatrar": "skuggspelsteater",
    "skuggspelsteatrarna": "skuggspelsteater",
    "skuggspelsteatrarnas": "skuggspelsteater",
    "skuggspelsteatrars": "skuggspelsteater",
    "skuldbela": "skuldbelägga",
    "skuldbelade": "skuldbelägga",
    "skuldbelades": "skuldbelägga",
    "skuldbelagd": "skuldbelägga",
    "skuldbelagda": "skuldbelägga",
    "skuldbelagdas": "skuldbelägga",
    "skuldbelagde": "skuldbelägga",
    "skuldbelagdes": "skuldbelägga",
    "skuldbelagds": "skuldbelägga",
    "skuldbelagt": "skuldbelägga",
    "skuldbelagts": "skuldbelägga",
    "skuldbelas": "skuldbelägga",
    "skuldbelastade": "skuldbelastad",
    "skuldbelastades": "skuldbelastad",
    "skuldbelastads": "skuldbelastad",
    "skuldbelastat": "skuldbelastad",
    "skuldbelastats": "skuldbelastad",
    "skuldbelägg": "skuldbelägga",
    "skuldbeläggande": "skuldbelägga",
    "skuldbeläggandes": "skuldbelägga",
    "skuldbeläggas": "skuldbelägga",
    "skuldbelägger": "skuldbelägga",
    "skuldbelägges": "skuldbelägga",
    "skuldbeläggs": "skuldbelägga",
    "skuldbördan": "skuldbörda",
    "skuldbördans": "skuldbörda",
    "skuldbördas": "skuldbörda",
    "skuldbörde": "skuldbörda",
    "skuldbördor": "skuldbörda",
    "skuldbördorna": "skuldbörda",
    "skuldbördornas": "skuldbörda",
    "skuldbördors": "skuldbörda",
    "skuldderivaten": "skuldderivat",
    "skuldderivatens": "skuldderivat",
    "skuldderivatet": "skuldderivat",
    "skuldderivatets": "skuldderivat",
    "skuldderivats": "skuldderivat",
    "skuldebreven": "skuldebrev",
    "skuldebrevens": "skuldebrev",
    "skuldebrevet": "skuldebrev",
    "skuldebrevets": "skuldebrev",
    "skuldebrevs": "skuldebrev",
    "skulden": "skuld",
    "skuldens": "skuld",
    "skulder": "skuldra",
    "skulderbladen": "skulderblad",
    "skulderbladens": "skulderblad",
    "skulderbladet": "skulderblad",
    "skulderbladets": "skulderblad",
    "skulderblads": "skulderblad",
    "skuldergördeln": "skuldergördel",
    "skuldergördelns": "skuldergördel",
    "skuldergördels": "skuldergördel",
    "skulderleden": "skulderled",
    "skulderledens": "skulderled",
    "skulderleder": "skulderled",
    "skulderlederna": "skulderled",
    "skulderledernas": "skulderled",
    "skulderleders": "skulderled",
    "skulderleds": "skulderled",
    "skulderna": "skuld",
    "skuldernas": "skuld",
    "skulders": "skuld",
    "skuldfäll": "skuldfälla",
    "skuldfällan": "skuldfälla",
    "skuldfällans": "skuldfälla",
    "skuldfällas": "skuldfälla",
    "skuldfälle": "skuldfälla",
    "skuldfällor": "skuldfälla",
    "skuldfällorna": "skuldfälla",
    "skuldfällornas": "skuldfälla",
    "skuldfällors": "skuldfälla",
    "skuldfälls": "skuldfälla",
    "skuldförbindelsen": "skuldförbindelse",
    "skuldförbindelsens": "skuldförbindelse",
    "skuldförbindelser": "skuldförbindelse",
    "skuldförbindelserna": "skuldförbindelse",
    "skuldförbindelsernas": "skuldförbindelse",
    "skuldförbindelsers": "skuldförbindelse",
    "skuldförbindelses": "skuldförbindelse",
    "skuldkrisen": "skuldkris",
    "skuldkrisens": "skuldkris",
    "skuldkriser": "skuldkris",
    "skuldkriserna": "skuldkris",
    "skuldkrisernas": "skuldkris",
    "skuldkrisers": "skuldkris",
    "skuldkänsl": "skuldkänsla",
    "skuldkänslan": "skuldkänsla",
    "skuldkänslans": "skuldkänsla",
    "skuldkänslas": "skuldkänsla",
    "skuldkänsle": "skuldkänsla",
    "skuldkänslo": "skuldkänsla",
    "skuldkänslor": "skuldkänsla",
    "skuldkänslorna": "skuldkänsla",
    "skuldkänslornas": "skuldkänsla",
    "skuldkänslors": "skuldkänsla",
    "skuldmedvetens": "skuldmedveten",
    "skuldmedvetet": "skuldmedveten",
    "skuldmedvetets": "skuldmedveten",
    "skuldmedvetna": "skuldmedveten",
    "skuldmedvetnare": "skuldmedveten",
    "skuldmedvetnares": "skuldmedveten",
    "skuldmedvetnas": "skuldmedveten",
    "skuldmedvetnast": "skuldmedveten",
    "skuldmedvetnaste": "skuldmedveten",
    "skuldmedvetnastes": "skuldmedveten",
    "skuldmedvetnasts": "skuldmedveten",
    "skuldmedvetne": "skuldmedveten",
    "skuldmedvetnes": "skuldmedveten",
    "skuldran": "skuldra",
    "skuldrans": "skuldra",
    "skuldras": "skuldra",
    "skuldre": "skuldra",
    "skuldror": "skuldra",
    "skuldrorna": "skuldra",
    "skuldrornas": "skuldra",
    "skuldrors": "skuldra",
    "skuldräntan": "skuldränta",
    "skuldräntans": "skuldränta",
    "skuldräntas": "skuldränta",
    "skuldränte": "skuldränta",
    "skuldräntor": "skuldränta",
    "skuldräntorna": "skuldränta",
    "skuldräntornas": "skuldränta",
    "skuldräntors": "skuldränta",
    "skulds": "skuld",
    "skuldsatt": "skuldsätta",
    "skuldsatta": "skuldsätta",
    "skuldsattare": "skuldsatt",
    "skuldsattares": "skuldsatt",
    "skuldsattas": "skuldsätta",
    "skuldsattast": "skuldsatt",
    "skuldsattaste": "skuldsatt",
    "skuldsattastes": "skuldsatt",
    "skuldsattasts": "skuldsatt",
    "skuldsatte": "skuldsätta",
    "skuldsattes": "skuldsätta",
    "skuldsattheten": "skuldsatthet",
    "skuldsatthetens": "skuldsatthet",
    "skuldsatthets": "skuldsatthet",
    "skuldsatts": "skuldsätta",
    "skuldsätt": "skuldsätta",
    "skuldsättande": "skuldsätta",
    "skuldsättanden": "skuldsättande",
    "skuldsättandena": "skuldsättande",
    "skuldsättandenas": "skuldsättande",
    "skuldsättandens": "skuldsättande",
    "skuldsättandes": "skuldsättande",
    "skuldsättandet": "skuldsättande",
    "skuldsättandets": "skuldsättande",
    "skuldsättas": "skuldsätta",
    "skuldsätter": "skuldsätta",
    "skuldsättes": "skuldsätta",
    "skuldsätts": "skuldsätta",
    "skuldtyngda": "skuldtyngd",
    "skuldtyngdare": "skuldtyngd",
    "skuldtyngdares": "skuldtyngd",
    "skuldtyngdas": "skuldtyngd",
    "skuldtyngdast": "skuldtyngd",
    "skuldtyngdaste": "skuldtyngd",
    "skuldtyngdastes": "skuldtyngd",
    "skuldtyngdasts": "skuldtyngd",
    "skuldtyngde": "skuldtyngd",
    "skuldtyngdes": "skuldtyngd",
    "skuldtyngdheten": "skuldtyngdhet",
    "skuldtyngdhetens": "skuldtyngdhet",
    "skuldtyngdhets": "skuldtyngdhet",
    "skuldtyngds": "skuldtyngd",
    "skuldtyngt": "skuldtyngd",
    "skuldtyngts": "skuldtyngd",
    "skull": "skulle",
    "skullar": "skulle",
    "skullarna": "skulle",
    "skullarnas": "skulle",
    "skullars": "skulle",
    "skulle": "skola",
    "skullen": "skulle",
    "skullens": "skulle",
    "skulles": "skulle",
    "skulls": "skulle",
    "skulorna": "skulor",
    "skulornas": "skulor",
    "skulors": "skulor",
    "skulpterad": "skulptera",
    "skulpterade": "skulptera",
    "skulpterades": "skulptera",
    "skulpterads": "skulptera",
    "skulpterande": "skulptera",
    "skulpteranden": "skulpterande",
    "skulpterandena": "skulpterande",
    "skulpterandenas": "skulpterande",
    "skulpterandens": "skulpterande",
    "skulpterandes": "skulpterande",
    "skulpterandet": "skulpterande",
    "skulpterandets": "skulpterande",
    "skulpterar": "skulptera",
    "skulpteras": "skulptera",
    "skulpterat": "skulptera",
    "skulpterats": "skulptera",
    "skulpterbara": "skulpterbar",
    "skulpterbarare": "skulpterbar",
    "skulpterbarares": "skulpterbar",
    "skulpterbaras": "skulpterbar",
    "skulpterbarast": "skulpterbar",
    "skulpterbaraste": "skulpterbar",
    "skulpterbarastes": "skulpterbar",
    "skulpterbarasts": "skulpterbar",
    "skulpterbare": "skulpterbar",
    "skulpterbares": "skulpterbar",
    "skulpterbarheten": "skulpterbarhet",
    "skulpterbarhetens": "skulpterbarhet",
    "skulpterbarhets": "skulpterbarhet",
    "skulpterbars": "skulpterbar",
    "skulpterbart": "skulpterbar",
    "skulpterbarts": "skulpterbar",
    "skulpteringar": "skulptering",
    "skulpteringarna": "skulptering",
    "skulpteringarnas": "skulptering",
    "skulpteringars": "skulptering",
    "skulpteringen": "skulptering",
    "skulpteringens": "skulptering",
    "skulpterings": "skulptering",
    "skulptrisen": "skulptris",
    "skulptrisens": "skulptris",
    "skulptriser": "skulptris",
    "skulptriserna": "skulptris",
    "skulptrisernas": "skulptris",
    "skulptrisers": "skulptris",
    "skulpturala": "skulptural",
    "skulpturalare": "skulptural",
    "skulpturalares": "skulptural",
    "skulpturalas": "skulptural",
    "skulpturalast": "skulptural",
    "skulpturalaste": "skulptural",
    "skulpturalastes": "skulptural",
    "skulpturalasts": "skulptural",
    "skulpturale": "skulptural",
    "skulpturales": "skulptural",
    "skulpturals": "skulptural",
    "skulpturalt": "skulptural",
    "skulpturalts": "skulptural",
    "skulpturen": "skulptur",
    "skulpturens": "skulptur",
    "skulpturer": "skulptur",
    "skulpturerad": "skulpturera",
    "skulpturerade": "skulpturera",
    "skulpturerades": "skulpturera",
    "skulpturerads": "skulpturera",
    "skulpturerande": "skulpturera",
    "skulptureranden": "skulpturerande",
    "skulpturerandena": "skulpturerande",
    "skulpturerandenas": "skulpturerande",
    "skulpturerandens": "skulpturerande",
    "skulpturerandes": "skulpturerande",
    "skulpturerandet": "skulpturerande",
    "skulpturerandets": "skulpturerande",
    "skulpturerar": "skulpturera",
    "skulptureras": "skulpturera",
    "skulpturerat": "skulpturera",
    "skulpturerats": "skulpturera",
    "skulpturerbara": "skulpturerbar",
    "skulpturerbarare": "skulpturerbar",
    "skulpturerbarares": "skulpturerbar",
    "skulpturerbaras": "skulpturerbar",
    "skulpturerbarast": "skulpturerbar",
    "skulpturerbaraste": "skulpturerbar",
    "skulpturerbarastes": "skulpturerbar",
    "skulpturerbarasts": "skulpturerbar",
    "skulpturerbare": "skulpturerbar",
    "skulpturerbares": "skulpturerbar",
    "skulpturerbarheten": "skulpturerbarhet",
    "skulpturerbarhetens": "skulpturerbarhet",
    "skulpturerbarhets": "skulpturerbarhet",
    "skulpturerbars": "skulpturerbar",
    "skulpturerbart": "skulpturerbar",
    "skulpturerbarts": "skulpturerbar",
    "skulptureringar": "skulpturering",
    "skulptureringarna": "skulpturering",
    "skulptureringarnas": "skulpturering",
    "skulptureringars": "skulpturering",
    "skulptureringen": "skulpturering",
    "skulptureringens": "skulpturering",
    "skulpturerings": "skulpturering",
    "skulpturerna": "skulptur",
    "skulpturernas": "skulptur",
    "skulpturers": "skulptur",
    "skulpturs": "skulptur",
    "skulptören": "skulptör",
    "skulptörens": "skulptör",
    "skulptörer": "skulptör",
    "skulptörerna": "skulptör",
    "skulptörernas": "skulptör",
    "skulptörers": "skulptör",
    "skulptörs": "skulptör",
    "skultar": "skult",
    "skultarna": "skult",
    "skultarnas": "skult",
    "skultars": "skult",
    "skulten": "skult",
    "skultens": "skult",
    "skults": "skult",
    "skulve": "skälva",
    "skumbaden": "skumbad",
    "skumbadens": "skumbad",
    "skumbadet": "skumbad",
    "skumbadets": "skumbad",
    "skumbads": "skumbad",
    "skumbubbel": "skumbubbla",
    "skumbubblan": "skumbubbla",
    "skumbubblans": "skumbubbla",
    "skumbubblas": "skumbubbla",
    "skumbubble": "skumbubbla",
    "skumbubblor": "skumbubbla",
    "skumbubblorna": "skumbubbla",
    "skumbubblornas": "skumbubbla",
    "skumbubblors": "skumbubbla",
    "skumgummimadrassen": "skumgummimadrass",
    "skumgummimadrassens": "skumgummimadrass",
    "skumgummimadrasser": "skumgummimadrass",
    "skumgummimadrasserna": "skumgummimadrass",
    "skumgummimadrassernas": "skumgummimadrass",
    "skumgummimadrassers": "skumgummimadrass",
    "skumgummis": "skumgummi",
    "skumgummit": "skumgummi",
    "skumgummits": "skumgummi",
    "skumheten": "skumhet",
    "skumhetens": "skumhet",
    "skumheter": "skumhet",
    "skumheterna": "skumhet",
    "skumheternas": "skumhet",
    "skumheters": "skumhet",
    "skumhets": "skumhet",
    "skumma": "skum",
    "skummad": "skumma",
    "skummade": "skumma",
    "skummades": "skumma",
    "skummads": "skumma",
    "skummande": "skumma",
    "skummanden": "skummande",
    "skummandena": "skummande",
    "skummandenas": "skummande",
    "skummandens": "skummande",
    "skummandes": "skummande",
    "skummandet": "skummande",
    "skummandets": "skummande",
    "skummar": "skumma",
    "skummare": "skum",
    "skummares": "skum",
    "skummas": "skumma",
    "skummast": "skum",
    "skummaste": "skum",
    "skummastes": "skum",
    "skummasts": "skum",
    "skummat": "skumma",
    "skummats": "skumma",
    "skumme": "skum",
    "skummes": "skum",
    "skummet": "skum",
    "skummets": "skum",
    "skummiga": "skummig",
    "skummigare": "skummig",
    "skummigares": "skummig",
    "skummigas": "skummig",
    "skummigast": "skummig",
    "skummigaste": "skummig",
    "skummigastes": "skummig",
    "skummigasts": "skummig",
    "skummige": "skummig",
    "skummiges": "skummig",
    "skummigheten": "skummighet",
    "skummighetens": "skummighet",
    "skummighets": "skummighet",
    "skummigs": "skummig",
    "skummigt": "skummig",
    "skummigts": "skummig",
    "skummisar": "skummis",
    "skummisarna": "skummis",
    "skummisarnas": "skummis",
    "skummisars": "skummis",
    "skummisen": "skummis",
    "skummisens": "skummis",
    "skummjölken": "skummjölk",
    "skummjölkens": "skummjölk",
    "skummjölks": "skummjölk",
    "skump": "skumpa",
    "skumpad": "skumpa",
    "skumpade": "skumpa",
    "skumpades": "skumpa",
    "skumpads": "skumpa",
    "skumpan": "skumpa",
    "skumpande": "skumpa",
    "skumpanden": "skumpande",
    "skumpandena": "skumpande",
    "skumpandenas": "skumpande",
    "skumpandens": "skumpande",
    "skumpandes": "skumpande",
    "skumpandet": "skumpande",
    "skumpandets": "skumpande",
    "skumpans": "skumpa",
    "skumpar": "skumpa",
    "skumpas": "skumpa",
    "skumpat": "skumpa",
    "skumpats": "skumpa",
    "skumpiga": "skumpig",
    "skumpigare": "skumpig",
    "skumpigares": "skumpig",
    "skumpigas": "skumpig",
    "skumpigast": "skumpig",
    "skumpigaste": "skumpig",
    "skumpigastes": "skumpig",
    "skumpigasts": "skumpig",
    "skumpige": "skumpig",
    "skumpiges": "skumpig",
    "skumpigheten": "skumpighet",
    "skumpighetens": "skumpighet",
    "skumpighets": "skumpighet",
    "skumpigs": "skumpig",
    "skumpigt": "skumpig",
    "skumpigts": "skumpig",
    "skumpiskade": "skumpiskad",
    "skumpiskades": "skumpiskad",
    "skumpiskads": "skumpiskad",
    "skumpiskat": "skumpiskad",
    "skumpiskats": "skumpiskad",
    "skumplasten": "skumplast",
    "skumplastens": "skumplast",
    "skumplasts": "skumplast",
    "skumplasttejpen": "skumplasttejp",
    "skumplasttejpens": "skumplasttejp",
    "skumplasttejps": "skumplasttejp",
    "skumpor": "skumpa",
    "skumporna": "skumpa",
    "skumpornas": "skumpa",
    "skumpors": "skumpa",
    "skumraskaffären": "skumraskaffär",
    "skumraskaffärens": "skumraskaffär",
    "skumraskaffärer": "skumraskaffär",
    "skumraskaffärerna": "skumraskaffär",
    "skumraskaffärernas": "skumraskaffär",
    "skumraskaffärers": "skumraskaffär",
    "skumraskaffärs": "skumraskaffär",
    "skumrasken": "skumrask",
    "skumraskens": "skumrask",
    "skumrasket": "skumrask",
    "skumraskets": "skumrask",
    "skumrasks": "skumrask",
    "skums": "skum",
    "skumsläckar": "skumsläckare",
    "skumsläckaren": "skumsläckare",
    "skumsläckarens": "skumsläckare",
    "skumsläckares": "skumsläckare",
    "skumsläckarna": "skumsläckare",
    "skumsläckarnas": "skumsläckare",
    "skumt": "skum",
    "skumts": "skum",
    "skumtvätt": "skumtvätta",
    "skumtvättad": "skumtvätta",
    "skumtvättade": "skumtvätta",
    "skumtvättades": "skumtvätta",
    "skumtvättads": "skumtvätta",
    "skumtvättande": "skumtvätta",
    "skumtvättanden": "skumtvättande",
    "skumtvättandena": "skumtvättande",
    "skumtvättandenas": "skumtvättande",
    "skumtvättandens": "skumtvättande",
    "skumtvättandes": "skumtvättande",
    "skumtvättandet": "skumtvättande",
    "skumtvättandets": "skumtvättande",
    "skumtvättar": "skumtvätta",
    "skumtvättarna": "skumtvätt",
    "skumtvättarnas": "skumtvätt",
    "skumtvättars": "skumtvätt",
    "skumtvättas": "skumtvätta",
    "skumtvättat": "skumtvätta",
    "skumtvättats": "skumtvätta",
    "skumtvätten": "skumtvätt",
    "skumtvättens": "skumtvätt",
    "skumtvättningar": "skumtvättning",
    "skumtvättningarna": "skumtvättning",
    "skumtvättningarnas": "skumtvättning",
    "skumtvättningars": "skumtvättning",
    "skumtvättningen": "skumtvättning",
    "skumtvättningens": "skumtvättning",
    "skumtvättnings": "skumtvättning",
    "skumtvätts": "skumtvätt",
    "skumutrustningar": "skumutrustning",
    "skumutrustningarna": "skumutrustning",
    "skumutrustningarnas": "skumutrustning",
    "skumutrustningars": "skumutrustning",
    "skumutrustningen": "skumutrustning",
    "skumutrustningens": "skumutrustning",
    "skumutrustnings": "skumutrustning",
    "skumögda": "skumögd",
    "skumögdare": "skumögd",
    "skumögdares": "skumögd",
    "skumögdas": "skumögd",
    "skumögdast": "skumögd",
    "skumögdaste": "skumögd",
    "skumögdastes": "skumögd",
    "skumögdasts": "skumögd",
    "skumögde": "skumögd",
    "skumögdes": "skumögd",
    "skumögdheten": "skumögdhet",
    "skumögdhetens": "skumögdhet",
    "skumögdhets": "skumögdhet",
    "skumögds": "skumögd",
    "skumögt": "skumögd",
    "skumögts": "skumögd",
    "skunkar": "skunk",
    "skunkarna": "skunk",
    "skunkarnas": "skunk",
    "skunkars": "skunk",
    "skunkdjuren": "skunkdjur",
    "skunkdjurens": "skunkdjur",
    "skunkdjuret": "skunkdjur",
    "skunkdjurets": "skunkdjur",
    "skunkdjurs": "skunkdjur",
    "skunken": "skunk",
    "skunkens": "skunk",
    "skunkiga": "skunkig",
    "skunkigare": "skunkig",
    "skunkigares": "skunkig",
    "skunkigas": "skunkig",
    "skunkigast": "skunkig",
    "skunkigaste": "skunkig",
    "skunkigastes": "skunkig",
    "skunkigasts": "skunkig",
    "skunkige": "skunkig",
    "skunkiges": "skunkig",
    "skunkigheten": "skunkighet",
    "skunkighetens": "skunkighet",
    "skunkigheter": "skunkighet",
    "skunkigheterna": "skunkighet",
    "skunkigheternas": "skunkighet",
    "skunkigheters": "skunkighet",
    "skunkighets": "skunkighet",
    "skunkigs": "skunkig",
    "skunkigt": "skunkig",
    "skunkigts": "skunkig",
    "skunks": "skunk",
    "skur": "skura",
    "skurad": "skura",
    "skurade": "skura",
    "skurades": "skura",
    "skurads": "skura",
    "skuramedels": "skuramedel",
    "skuramedlen": "skuramedel",
    "skuramedlens": "skuramedel",
    "skuramedlet": "skuramedel",
    "skuramedlets": "skuramedel",
    "skurande": "skura",
    "skuranden": "skurande",
    "skurandena": "skurande",
    "skurandenas": "skurande",
    "skurandens": "skurande",
    "skurandes": "skurande",
    "skurandet": "skurande",
    "skurandets": "skurande",
    "skurar": "skura",
    "skurarna": "skur",
    "skurarnas": "skur",
    "skurars": "skur",
    "skuras": "skura",
    "skurat": "skura",
    "skurats": "skura",
    "skurborst": "skurborste",
    "skurborstar": "skurborste",
    "skurborstarna": "skurborste",
    "skurborstarnas": "skurborste",
    "skurborstars": "skurborste",
    "skurborsten": "skurborste",
    "skurborstens": "skurborste",
    "skurborstes": "skurborste",
    "skurdukar": "skurduk",
    "skurdukarna": "skurduk",
    "skurdukarnas": "skurduk",
    "skurdukars": "skurduk",
    "skurduken": "skurduk",
    "skurdukens": "skurduk",
    "skurduks": "skurduk",
    "skure": "skära",
    "skuren": "skur",
    "skurens": "skur",
    "skures": "skära",
    "skuret": "skära",
    "skurets": "skära",
    "skurgolven": "skurgolv",
    "skurgolvens": "skurgolv",
    "skurgolvet": "skurgolv",
    "skurgolvets": "skurgolv",
    "skurgolvs": "skurgolv",
    "skurgum": "skurgumma",
    "skurgumman": "skurgumma",
    "skurgummans": "skurgumma",
    "skurgummas": "skurgumma",
    "skurgumme": "skurgumma",
    "skurgummor": "skurgumma",
    "skurgummorna": "skurgumma",
    "skurgummornas": "skurgumma",
    "skurgummors": "skurgumma",
    "skurgums": "skurgumma",
    "skurhinkar": "skurhink",
    "skurhinkarna": "skurhink",
    "skurhinkarnas": "skurhink",
    "skurhinkars": "skurhink",
    "skurhinken": "skurhink",
    "skurhinkens": "skurhink",
    "skurhinks": "skurhink",
    "skurit": "skära",
    "skurits": "skära",
    "skurkaktiga": "skurkaktig",
    "skurkaktigare": "skurkaktig",
    "skurkaktigares": "skurkaktig",
    "skurkaktigas": "skurkaktig",
    "skurkaktigast": "skurkaktig",
    "skurkaktigaste": "skurkaktig",
    "skurkaktigastes": "skurkaktig",
    "skurkaktigasts": "skurkaktig",
    "skurkaktige": "skurkaktig",
    "skurkaktiges": "skurkaktig",
    "skurkaktigheten": "skurkaktighet",
    "skurkaktighetens": "skurkaktighet",
    "skurkaktigheter": "skurkaktighet",
    "skurkaktigheterna": "skurkaktighet",
    "skurkaktigheternas": "skurkaktighet",
    "skurkaktigheters": "skurkaktighet",
    "skurkaktighets": "skurkaktighet",
    "skurkaktigs": "skurkaktig",
    "skurkaktigt": "skurkaktig",
    "skurkaktigts": "skurkaktig",
    "skurkar": "skurk",
    "skurkarna": "skurk",
    "skurkarnas": "skurk",
    "skurkars": "skurk",
    "skurken": "skurk",
    "skurkens": "skurk",
    "skurkregimen": "skurkregim",
    "skurkregimens": "skurkregim",
    "skurkregimer": "skurkregim",
    "skurkregimerna": "skurkregim",
    "skurkregimernas": "skurkregim",
    "skurkregimers": "skurkregim",
    "skurkregims": "skurkregim",
    "skurks": "skurk",
    "skurkstaten": "skurkstat",
    "skurkstatens": "skurkstat",
    "skurkstater": "skurkstat",
    "skurkstaterna": "skurkstat",
    "skurkstaternas": "skurkstat",
    "skurkstaters": "skurkstat",
    "skurkstats": "skurkstat",
    "skurkstrecken": "skurkstreck",
    "skurkstreckens": "skurkstreck",
    "skurkstrecket": "skurkstreck",
    "skurkstreckets": "skurkstreck",
    "skurkstrecks": "skurkstreck",
    "skurloven": "skurlov",
    "skurlovens": "skurlov",
    "skurlovet": "skurlov",
    "skurlovets": "skurlov",
    "skurlovs": "skurlov",
    "skurmedels": "skurmedel",
    "skurmedlen": "skurmedel",
    "skurmedlens": "skurmedel",
    "skurmedlet": "skurmedel",
    "skurmedlets": "skurmedel",
    "skurna": "skära",
    "skurnas": "skära",
    "skurne": "skära",
    "skurnes": "skära",
    "skurpulverna": "skurpulver",
    "skurpulvernas": "skurpulver",
    "skurpulvers": "skurpulver",
    "skurpulvren": "skurpulver",
    "skurpulvrens": "skurpulver",
    "skurpulvret": "skurpulver",
    "skurpulvrets": "skurpulver",
    "skurrila": "skurril",
    "skurrilare": "skurril",
    "skurrilares": "skurril",
    "skurrilas": "skurril",
    "skurrilast": "skurril",
    "skurrilaste": "skurril",
    "skurrilastes": "skurril",
    "skurrilasts": "skurril",
    "skurrile": "skurril",
    "skurriles": "skurril",
    "skurrils": "skurril",
    "skurrilt": "skurril",
    "skurrilts": "skurril",
    "skurs": "skur",
    "skurtras": "skurtrasa",
    "skurtrasan": "skurtrasa",
    "skurtrasans": "skurtrasa",
    "skurtrasas": "skurtrasa",
    "skurtrase": "skurtrasa",
    "skurtrasor": "skurtrasa",
    "skurtrasorna": "skurtrasa",
    "skurtrasornas": "skurtrasa",
    "skurtrasors": "skurtrasa",
    "skut": "skuta",
    "skutan": "skuta",
    "skutans": "skuta",
    "skutas": "skuta",
    "skute": "skuta",
    "skutor": "skuta",
    "skutorna": "skuta",
    "skutornas": "skuta",
    "skutors": "skuta",
    "skuts": "skuta",
    "skutt": "skutta",
    "skuttad": "skutta",
    "skuttade": "skutta",
    "skuttades": "skutta",
    "skuttads": "skutta",
    "skuttande": "skutta",
    "skuttanden": "skuttande",
    "skuttandena": "skuttande",
    "skuttandenas": "skuttande",
    "skuttandens": "skuttande",
    "skuttandes": "skuttande",
    "skuttandet": "skuttande",
    "skuttandets": "skuttande",
    "skuttar": "skutta",
    "skuttas": "skutta",
    "skuttat": "skutta",
    "skuttats": "skutta",
    "skutten": "skutt",
    "skuttens": "skutt",
    "skuttet": "skutt",
    "skuttets": "skutt",
    "skutts": "skutt",
    "skvadern": "skvader",
    "skvaderns": "skvader",
    "skvaders": "skvader",
    "skvadrar": "skvader",
    "skvadrarna": "skvader",
    "skvadrarnas": "skvader",
    "skvadrars": "skvader",
    "skvadronen": "skvadron",
    "skvadronens": "skvadron",
    "skvadroner": "skvadron",
    "skvadronerna": "skvadron",
    "skvadronernas": "skvadron",
    "skvadroners": "skvadron",
    "skvadrons": "skvadron",
    "skval": "skvala",
    "skvalad": "skvala",
    "skvalade": "skvala",
    "skvalades": "skvala",
    "skvalads": "skvala",
    "skvalande": "skvala",
    "skvalanden": "skvalande",
    "skvalandena": "skvalande",
    "skvalandenas": "skvalande",
    "skvalandens": "skvalande",
    "skvalandes": "skvalande",
    "skvalandet": "skvalande",
    "skvalandets": "skvalande",
    "skvalar": "skvala",
    "skvalas": "skvala",
    "skvalat": "skvala",
    "skvalats": "skvala",
    "skvalbankar": "skvalbank",
    "skvalbankarna": "skvalbank",
    "skvalbankarnas": "skvalbank",
    "skvalbankars": "skvalbank",
    "skvalbanken": "skvalbank",
    "skvalbankens": "skvalbank",
    "skvalbanks": "skvalbank",
    "skvalet": "skval",
    "skvalets": "skval",
    "skvaller": "skvallra",
    "skvalleraktiga": "skvalleraktig",
    "skvalleraktigare": "skvalleraktig",
    "skvalleraktigares": "skvalleraktig",
    "skvalleraktigas": "skvalleraktig",
    "skvalleraktigast": "skvalleraktig",
    "skvalleraktigaste": "skvalleraktig",
    "skvalleraktigastes": "skvalleraktig",
    "skvalleraktigasts": "skvalleraktig",
    "skvalleraktige": "skvalleraktig",
    "skvalleraktiges": "skvalleraktig",
    "skvalleraktigheten": "skvalleraktighet",
    "skvalleraktighetens": "skvalleraktighet",
    "skvalleraktighets": "skvalleraktighet",
    "skvalleraktigs": "skvalleraktig",
    "skvalleraktigt": "skvalleraktig",
    "skvalleraktigts": "skvalleraktig",
    "skvallerbytt": "skvallerbytta",
    "skvallerbyttan": "skvallerbytta",
    "skvallerbyttans": "skvallerbytta",
    "skvallerbyttas": "skvallerbytta",
    "skvallerbytte": "skvallerbytta",
    "skvallerbyttor": "skvallerbytta",
    "skvallerbyttorna": "skvallerbytta",
    "skvallerbyttornas": "skvallerbytta",
    "skvallerbyttors": "skvallerbytta",
    "skvallerbytts": "skvallerbytta",
    "skvallerbären": "skvallerbär",
    "skvallerbärens": "skvallerbär",
    "skvallerbäret": "skvallerbär",
    "skvallerbärets": "skvallerbär",
    "skvallerbärs": "skvallerbär",
    "skvallerdreven": "skvallerdrev",
    "skvallerdrevens": "skvallerdrev",
    "skvallerdrevet": "skvallerdrev",
    "skvallerdrevets": "skvallerdrev",
    "skvallerdrevs": "skvallerdrev",
    "skvallerkålen": "skvallerkål",
    "skvallerkålens": "skvallerkål",
    "skvallerkåls": "skvallerkål",
    "skvallermostern": "skvallermoster",
    "skvallermosterns": "skvallermoster",
    "skvallermosters": "skvallermoster",
    "skvallermostrar": "skvallermoster",
    "skvallermostrarna": "skvallermoster",
    "skvallermostrarnas": "skvallermoster",
    "skvallermostrars": "skvallermoster",
    "skvallers": "skvaller",
    "skvallerspalten": "skvallerspalt",
    "skvallerspaltens": "skvallerspalt",
    "skvallerspalter": "skvallerspalt",
    "skvallerspalterna": "skvallerspalt",
    "skvallerspalternas": "skvallerspalt",
    "skvallerspalters": "skvallerspalt",
    "skvallerspalts": "skvallerspalt",
    "skvallerspegeln": "skvallerspegel",
    "skvallerspegelns": "skvallerspegel",
    "skvallerspegels": "skvallerspegel",
    "skvallerspeglar": "skvallerspegel",
    "skvallerspeglarna": "skvallerspegel",
    "skvallerspeglarnas": "skvallerspegel",
    "skvallerspeglars": "skvallerspegel",
    "skvallertack": "skvallertacka",
    "skvallertackan": "skvallertacka",
    "skvallertackans": "skvallertacka",
    "skvallertackas": "skvallertacka",
    "skvallertacke": "skvallertacka",
    "skvallertackor": "skvallertacka",
    "skvallertackorna": "skvallertacka",
    "skvallertackornas": "skvallertacka",
    "skvallertackors": "skvallertacka",
    "skvallertacks": "skvallertacka",
    "skvallertanten": "skvallertant",
    "skvallertantens": "skvallertant",
    "skvallertanter": "skvallertant",
    "skvallertanterna": "skvallertant",
    "skvallertanternas": "skvallertant",
    "skvallertanters": "skvallertant",
    "skvallertants": "skvallertant",
    "skvallertaskan": "skvallertaska",
    "skvallertaskans": "skvallertaska",
    "skvallertaskas": "skvallertaska",
    "skvallertaske": "skvallertaska",
    "skvallertaskor": "skvallertaska",
    "skvallertaskorna": "skvallertaska",
    "skvallertaskornas": "skvallertaska",
    "skvallertaskors": "skvallertaska",
    "skvallrad": "skvallra",
    "skvallrade": "skvallra",
    "skvallrades": "skvallra",
    "skvallrads": "skvallra",
    "skvallrande": "skvallra",
    "skvallranden": "skvallrande",
    "skvallrandena": "skvallrande",
    "skvallrandenas": "skvallrande",
    "skvallrandens": "skvallrande",
    "skvallrandes": "skvallrande",
    "skvallrandet": "skvallrande",
    "skvallrandets": "skvallrande",
    "skvallrar": "skvallra",
    "skvallras": "skvallra",
    "skvallrat": "skvallra",
    "skvallrats": "skvallra",
    "skvallret": "skvaller",
    "skvallrets": "skvaller",
    "skvallriga": "skvallrig",
    "skvallrigare": "skvallrig",
    "skvallrigares": "skvallrig",
    "skvallrigas": "skvallrig",
    "skvallrigast": "skvallrig",
    "skvallrigaste": "skvallrig",
    "skvallrigastes": "skvallrig",
    "skvallrigasts": "skvallrig",
    "skvallrige": "skvallrig",
    "skvallriges": "skvallrig",
    "skvallrigheten": "skvallrighet",
    "skvallrighetens": "skvallrighet",
    "skvallrighets": "skvallrighet",
    "skvallrigs": "skvallrig",
    "skvallrigt": "skvallrig",
    "skvallrigts": "skvallrig",
    "skvalmusiken": "skvalmusik",
    "skvalmusikens": "skvalmusik",
    "skvalmusiks": "skvalmusik",
    "skvalp": "skvalpa",
    "skvalpad": "skvalpa",
    "skvalpade": "skvalpa",
    "skvalpades": "skvalpa",
    "skvalpads": "skvalpa",
    "skvalpande": "skvalpa",
    "skvalpanden": "skvalpande",
    "skvalpandena": "skvalpande",
    "skvalpandenas": "skvalpande",
    "skvalpandens": "skvalpande",
    "skvalpandes": "skvalpande",
    "skvalpandet": "skvalpande",
    "skvalpandets": "skvalpande",
    "skvalpar": "skvalpa",
    "skvalpas": "skvalpa",
    "skvalpat": "skvalpa",
    "skvalpats": "skvalpa",
    "skvalpet": "skvalp",
    "skvalpets": "skvalp",
    "skvalpiga": "skvalpig",
    "skvalpigare": "skvalpig",
    "skvalpigares": "skvalpig",
    "skvalpigas": "skvalpig",
    "skvalpigast": "skvalpig",
    "skvalpigaste": "skvalpig",
    "skvalpigastes": "skvalpig",
    "skvalpigasts": "skvalpig",
    "skvalpige": "skvalpig",
    "skvalpiges": "skvalpig",
    "skvalpigheten": "skvalpighet",
    "skvalpighetens": "skvalpighet",
    "skvalpighets": "skvalpighet",
    "skvalpigs": "skvalpig",
    "skvalpigt": "skvalpig",
    "skvalpigts": "skvalpig",
    "skvalps": "skvalp",
    "skvals": "skval",
    "skvalt": "skvalta",
    "skvaltad": "skvalta",
    "skvaltade": "skvalta",
    "skvaltades": "skvalta",
    "skvaltads": "skvalta",
    "skvaltan": "skvalta",
    "skvaltande": "skvalta",
    "skvaltanden": "skvaltande",
    "skvaltandena": "skvaltande",
    "skvaltandenas": "skvaltande",
    "skvaltandens": "skvaltande",
    "skvaltandes": "skvaltande",
    "skvaltandet": "skvaltande",
    "skvaltandets": "skvaltande",
    "skvaltans": "skvalta",
    "skvaltar": "skvalta",
    "skvaltas": "skvalta",
    "skvaltat": "skvalta",
    "skvaltats": "skvalta",
    "skvalte": "skvalta",
    "skvaltkvarnar": "skvaltkvarn",
    "skvaltkvarnarna": "skvaltkvarn",
    "skvaltkvarnarnas": "skvaltkvarn",
    "skvaltkvarnars": "skvaltkvarn",
    "skvaltkvarnen": "skvaltkvarn",
    "skvaltkvarnens": "skvaltkvarn",
    "skvaltkvarns": "skvaltkvarn",
    "skvaltor": "skvalta",
    "skvaltorna": "skvalta",
    "skvaltornas": "skvalta",
    "skvaltorr": "skvaltorre",
    "skvaltorrar": "skvaltorre",
    "skvaltorrarna": "skvaltorre",
    "skvaltorrarnas": "skvaltorre",
    "skvaltorrars": "skvaltorre",
    "skvaltorren": "skvaltorre",
    "skvaltorrens": "skvaltorre",
    "skvaltorres": "skvaltorre",
    "skvaltorrs": "skvaltorre",
    "skvaltors": "skvalta",
    "skvalts": "skvalta",
    "skvatt": "skvätta",
    "skvatte": "skvätta",
    "skvattes": "skvätta",
    "skvattramen": "skvattram",
    "skvattramens": "skvattram",
    "skvattrams": "skvattram",
    "skvatts": "skvätta",
    "skvimp": "skvimpa",
    "skvimpad": "skvimpa",
    "skvimpade": "skvimpa",
    "skvimpades": "skvimpa",
    "skvimpads": "skvimpa",
    "skvimpande": "skvimpa",
    "skvimpanden": "skvimpande",
    "skvimpandena": "skvimpande",
    "skvimpandenas": "skvimpande",
    "skvimpandens": "skvimpande",
    "skvimpandes": "skvimpande",
    "skvimpandet": "skvimpande",
    "skvimpandets": "skvimpande",
    "skvimpar": "skvimpa",
    "skvimpas": "skvimpa",
    "skvimpat": "skvimpa",
    "skvimpats": "skvimpa",
    "skvis": "skvisa",
    "skvisad": "skvisa",
    "skvisade": "skvisa",
    "skvisades": "skvisa",
    "skvisads": "skvisa",
    "skvisande": "skvisa",
    "skvisanden": "skvisande",
    "skvisandena": "skvisande",
    "skvisandenas": "skvisande",
    "skvisandens": "skvisande",
    "skvisandes": "skvisande",
    "skvisandet": "skvisande",
    "skvisandets": "skvisande",
    "skvisar": "skvisa",
    "skvisarna": "skvis",
    "skvisarnas": "skvis",
    "skvisars": "skvis",
    "skvisas": "skvisa",
    "skvisat": "skvisa",
    "skvisats": "skvisa",
    "skvisen": "skvis",
    "skvisens": "skvis",
    "skvätt": "skvätta",
    "skvättad": "skvätta",
    "skvättade": "skvätta",
    "skvättades": "skvätta",
    "skvättads": "skvätta",
    "skvättan": "skvätta",
    "skvättande": "skvätta",
    "skvättanden": "skvättande",
    "skvättandena": "skvättande",
    "skvättandenas": "skvättande",
    "skvättandens": "skvättande",
    "skvättandes": "skvättande",
    "skvättandet": "skvättande",
    "skvättandets": "skvättande",
    "skvättans": "skvätta",
    "skvättar": "skvätt",
    "skvättarna": "skvätt",
    "skvättarnas": "skvätt",
    "skvättars": "skvätt",
    "skvättas": "skvätta",
    "skvättat": "skvätta",
    "skvättats": "skvätta",
    "skvätte": "skvätta",
    "skvätten": "skvätt",
    "skvättens": "skvätt",
    "skvätter": "skvätta",
    "skvättes": "skvätta",
    "skvättor": "skvätta",
    "skvättorna": "skvätta",
    "skvättornas": "skvätta",
    "skvättors": "skvätta",
    "skvätts": "skvätta",
    "sky": "skya",
    "skyad": "skya",
    "skyade": "skya",
    "skyades": "skya",
    "skyads": "skya",
    "skyande": "skya",
    "skyanden": "skyande",
    "skyandena": "skyande",
    "skyandenas": "skyande",
    "skyandens": "skyande",
    "skyandes": "skyande",
    "skyandet": "skyande",
    "skyandets": "skyande",
    "skyar": "skya",
    "skyarna": "sky",
    "skyarnas": "sky",
    "skyars": "sky",
    "skyas": "skya",
    "skyat": "skya",
    "skyats": "skya",
    "skydd": "skydda",
    "skydda": "sky",
    "skyddad": "skydda",
    "skyddade": "skydda",
    "skyddades": "skydda",
    "skyddads": "skydda",
    "skyddande": "skydda",
    "skyddanden": "skyddande",
    "skyddandena": "skyddande",
    "skyddandenas": "skyddande",
    "skyddandens": "skyddande",
    "skyddandes": "skyddande",
    "skyddandet": "skyddande",
    "skyddandets": "skyddande",
    "skyddar": "skydda",
    "skyddas": "skydda",
    "skyddat": "skydda",
    "skyddats": "skydda",
    "skydde": "sky",
    "skydden": "skydd",
    "skyddens": "skydd",
    "skyddes": "sky",
    "skyddet": "skydd",
    "skyddets": "skydd",
    "skydds": "skydd",
    "skyddsandar": "skyddsande",
    "skyddsandarna": "skyddsande",
    "skyddsandarnas": "skyddsande",
    "skyddsandars": "skyddsande",
    "skyddsanden": "skyddsande",
    "skyddsandens": "skyddsande",
    "skyddsandes": "skyddsande",
    "skyddsdräkten": "skyddsdräkt",
    "skyddsdräktens": "skyddsdräkt",
    "skyddsdräkter": "skyddsdräkt",
    "skyddsdräkterna": "skyddsdräkt",
    "skyddsdräkternas": "skyddsdräkt",
    "skyddsdräkters": "skyddsdräkt",
    "skyddsdräkts": "skyddsdräkt",
    "skyddsdukar": "skyddsduk",
    "skyddsdukarna": "skyddsduk",
    "skyddsdukarnas": "skyddsduk",
    "skyddsdukars": "skyddsduk",
    "skyddsduken": "skyddsduk",
    "skyddsdukens": "skyddsduk",
    "skyddsduks": "skyddsduk",
    "skyddsfärgen": "skyddsfärg",
    "skyddsfärgens": "skyddsfärg",
    "skyddsfärger": "skyddsfärg",
    "skyddsfärgerna": "skyddsfärg",
    "skyddsfärgernas": "skyddsfärg",
    "skyddsfärgers": "skyddsfärg",
    "skyddsfärgs": "skyddsfärg",
    "skyddsglasögonen": "skyddsglasögon",
    "skyddsglasögonens": "skyddsglasögon",
    "skyddsglasögons": "skyddsglasögon",
    "skyddsgravar": "skyddsgrav",
    "skyddsgravarna": "skyddsgrav",
    "skyddsgravarnas": "skyddsgrav",
    "skyddsgravars": "skyddsgrav",
    "skyddsgraven": "skyddsgrav",
    "skyddsgravens": "skyddsgrav",
    "skyddsgravs": "skyddsgrav",
    "skyddshelgonen": "skyddshelgon",
    "skyddshelgonens": "skyddshelgon",
    "skyddshelgonet": "skyddshelgon",
    "skyddshelgonets": "skyddshelgon",
    "skyddshelgons": "skyddshelgon",
    "skyddshöljen": "skyddshölje",
    "skyddshöljena": "skyddshölje",
    "skyddshöljenas": "skyddshölje",
    "skyddshöljens": "skyddshölje",
    "skyddshöljes": "skyddshölje",
    "skyddshöljet": "skyddshölje",
    "skyddshöljets": "skyddshölje",
    "skyddshöljs": "skyddshölje",
    "skyddsimpregnerad": "skyddsimpregnera",
    "skyddsimpregnerade": "skyddsimpregnera",
    "skyddsimpregnerades": "skyddsimpregnera",
    "skyddsimpregnerads": "skyddsimpregnera",
    "skyddsimpregnerande": "skyddsimpregnera",
    "skyddsimpregneranden": "skyddsimpregnerande",
    "skyddsimpregnerandena": "skyddsimpregnerande",
    "skyddsimpregnerandenas": "skyddsimpregnerande",
    "skyddsimpregnerandens": "skyddsimpregnerande",
    "skyddsimpregnerandes": "skyddsimpregnerande",
    "skyddsimpregnerandet": "skyddsimpregnerande",
    "skyddsimpregnerandets": "skyddsimpregnerande",
    "skyddsimpregnerar": "skyddsimpregnera",
    "skyddsimpregneras": "skyddsimpregnera",
    "skyddsimpregnerat": "skyddsimpregnera",
    "skyddsimpregnerats": "skyddsimpregnera",
    "skyddsimpregnerbara": "skyddsimpregnerbar",
    "skyddsimpregnerbarare": "skyddsimpregnerbar",
    "skyddsimpregnerbarares": "skyddsimpregnerbar",
    "skyddsimpregnerbaras": "skyddsimpregnerbar",
    "skyddsimpregnerbarast": "skyddsimpregnerbar",
    "skyddsimpregnerbaraste": "skyddsimpregnerbar",
    "skyddsimpregnerbarastes": "skyddsimpregnerbar",
    "skyddsimpregnerbarasts": "skyddsimpregnerbar",
    "skyddsimpregnerbare": "skyddsimpregnerbar",
    "skyddsimpregnerbares": "skyddsimpregnerbar",
    "skyddsimpregnerbarheten": "skyddsimpregnerbarhet",
    "skyddsimpregnerbarhetens": "skyddsimpregnerbarhet",
    "skyddsimpregnerbarhets": "skyddsimpregnerbarhet",
    "skyddsimpregnerbars": "skyddsimpregnerbar",
    "skyddsimpregnerbart": "skyddsimpregnerbar",
    "skyddsimpregnerbarts": "skyddsimpregnerbar",
    "skyddsimpregneringar": "skyddsimpregnering",
    "skyddsimpregneringarna": "skyddsimpregnering",
    "skyddsimpregneringarnas": "skyddsimpregnering",
    "skyddsimpregneringars": "skyddsimpregnering",
    "skyddsimpregneringen": "skyddsimpregnering",
    "skyddsimpregneringens": "skyddsimpregnering",
    "skyddsimpregnerings": "skyddsimpregnering",
    "skyddskläderna": "skyddskläder",
    "skyddsklädernas": "skyddskläder",
    "skyddskläders": "skyddskläder",
    "skyddsklädes": "skyddskläder",
    "skyddskläds": "skyddskläder",
    "skyddskonsulenten": "skyddskonsulent",
    "skyddskonsulentens": "skyddskonsulent",
    "skyddskonsulenter": "skyddskonsulent",
    "skyddskonsulenterna": "skyddskonsulent",
    "skyddskonsulenternas": "skyddskonsulent",
    "skyddskonsulenters": "skyddskonsulent",
    "skyddskonsulents": "skyddskonsulent",
    "skyddskroppar": "skyddskropp",
    "skyddskropparna": "skyddskropp",
    "skyddskropparnas": "skyddskropp",
    "skyddskroppars": "skyddskropp",
    "skyddskroppen": "skyddskropp",
    "skyddskroppens": "skyddskropp",
    "skyddskropps": "skyddskropp",
    "skyddskåren": "skyddskår",
    "skyddskårens": "skyddskår",
    "skyddskårer": "skyddskår",
    "skyddskårerna": "skyddskår",
    "skyddskårernas": "skyddskår",
    "skyddskårers": "skyddskår",
    "skyddskårs": "skyddskår",
    "skyddslingar": "skyddsling",
    "skyddslingarna": "skyddsling",
    "skyddslingarnas": "skyddsling",
    "skyddslingars": "skyddsling",
    "skyddslingen": "skyddsling",
    "skyddslingens": "skyddsling",
    "skyddslings": "skyddsling",
    "skyddslocken": "skyddslock",
    "skyddslockens": "skyddslock",
    "skyddslocket": "skyddslock",
    "skyddslockets": "skyddslock",
    "skyddslocks": "skyddslock",
    "skyddslösa": "skyddslös",
    "skyddslösare": "skyddslös",
    "skyddslösares": "skyddslös",
    "skyddslösas": "skyddslös",
    "skyddslösast": "skyddslös",
    "skyddslösaste": "skyddslös",
    "skyddslösastes": "skyddslös",
    "skyddslösasts": "skyddslös",
    "skyddslöse": "skyddslös",
    "skyddslöses": "skyddslös",
    "skyddslösheten": "skyddslöshet",
    "skyddslöshetens": "skyddslöshet",
    "skyddslöshets": "skyddslöshet",
    "skyddslöst": "skyddslös",
    "skyddslösts": "skyddslös",
    "skyddsmasken": "skyddsmask",
    "skyddsmaskens": "skyddsmask",
    "skyddsmasker": "skyddsmask",
    "skyddsmaskerna": "skyddsmask",
    "skyddsmaskernas": "skyddsmask",
    "skyddsmaskers": "skyddsmask",
    "skyddsmasks": "skyddsmask",
    "skyddsmedels": "skyddsmedel",
    "skyddsmedlen": "skyddsmedel",
    "skyddsmedlens": "skyddsmedel",
    "skyddsmedlet": "skyddsmedel",
    "skyddsmedlets": "skyddsmedel",
    "skyddsmekanismen": "skyddsmekanism",
    "skyddsmekanismens": "skyddsmekanism",
    "skyddsmekanismer": "skyddsmekanism",
    "skyddsmekanismerna": "skyddsmekanism",
    "skyddsmekanismernas": "skyddsmekanism",
    "skyddsmekanismers": "skyddsmekanism",
    "skyddsmekanisms": "skyddsmekanism",
    "skyddsmurar": "skyddsmur",
    "skyddsmurarna": "skyddsmur",
    "skyddsmurarnas": "skyddsmur",
    "skyddsmurars": "skyddsmur",
    "skyddsmuren": "skyddsmur",
    "skyddsmurens": "skyddsmur",
    "skyddsmurs": "skyddsmur",
    "skyddsombuden": "skyddsombud",
    "skyddsombudens": "skyddsombud",
    "skyddsombudet": "skyddsombud",
    "skyddsombudets": "skyddsombud",
    "skyddsombuds": "skyddsombud",
    "skyddsområden": "skyddsområde",
    "skyddsområdena": "skyddsområde",
    "skyddsområdenas": "skyddsområde",
    "skyddsområdens": "skyddsområde",
    "skyddsområdes": "skyddsområde",
    "skyddsområdet": "skyddsområde",
    "skyddsområdets": "skyddsområde",
    "skyddspapperen": "skyddspapper",
    "skyddspapperens": "skyddspapper",
    "skyddspapperet": "skyddspapper",
    "skyddspapperets": "skyddspapper",
    "skyddspapperna": "skyddspapper",
    "skyddspappernas": "skyddspapper",
    "skyddspappers": "skyddspapper",
    "skyddspappren": "skyddspapper",
    "skyddspapprens": "skyddspapper",
    "skyddspappret": "skyddspapper",
    "skyddspapprets": "skyddspapper",
    "skyddspatronen": "skyddspatron",
    "skyddspatronens": "skyddspatron",
    "skyddspatroner": "skyddspatron",
    "skyddspatronerna": "skyddspatron",
    "skyddspatronernas": "skyddspatron",
    "skyddspatroners": "skyddspatron",
    "skyddspatrons": "skyddspatron",
    "skyddsrockar": "skyddsrock",
    "skyddsrockarna": "skyddsrock",
    "skyddsrockarnas": "skyddsrock",
    "skyddsrockars": "skyddsrock",
    "skyddsrocken": "skyddsrock",
    "skyddsrockens": "skyddsrock",
    "skyddsrocks": "skyddsrock",
    "skyddsrummen": "skyddsrum",
    "skyddsrummens": "skyddsrum",
    "skyddsrummet": "skyddsrum",
    "skyddsrummets": "skyddsrum",
    "skyddsrums": "skyddsrum",
    "skyddsslangar": "skyddsslang",
    "skyddsslangarna": "skyddsslang",
    "skyddsslangarnas": "skyddsslang",
    "skyddsslangars": "skyddsslang",
    "skyddsslangen": "skyddsslang",
    "skyddsslangens": "skyddsslang",
    "skyddsslangs": "skyddsslang",
    "skyddsstaten": "skyddsstat",
    "skyddsstatens": "skyddsstat",
    "skyddsstater": "skyddsstat",
    "skyddsstaterna": "skyddsstat",
    "skyddsstaternas": "skyddsstat",
    "skyddsstaters": "skyddsstat",
    "skyddsstats": "skyddsstat",
    "skyddstaken": "skyddstak",
    "skyddstakens": "skyddstak",
    "skyddstaket": "skyddstak",
    "skyddstakets": "skyddstak",
    "skyddstaks": "skyddstak",
    "skyddstillsynen": "skyddstillsyn",
    "skyddstillsynens": "skyddstillsyn",
    "skyddstillsyns": "skyddstillsyn",
    "skyddstjänsten": "skyddstjänst",
    "skyddstjänstens": "skyddstjänst",
    "skyddstjänsts": "skyddstjänst",
    "skyddstullar": "skyddstull",
    "skyddstullarna": "skyddstull",
    "skyddstullarnas": "skyddstull",
    "skyddstullars": "skyddstull",
    "skyddstullen": "skyddstull",
    "skyddstullens": "skyddstull",
    "skyddstulls": "skyddstull",
    "skyddsvärda": "skyddsvärd",
    "skyddsvärdare": "skyddsvärd",
    "skyddsvärdares": "skyddsvärd",
    "skyddsvärdas": "skyddsvärd",
    "skyddsvärdast": "skyddsvärd",
    "skyddsvärdaste": "skyddsvärd",
    "skyddsvärdastes": "skyddsvärd",
    "skyddsvärdasts": "skyddsvärd",
    "skyddsvärde": "skyddsvärd",
    "skyddsvärdes": "skyddsvärd",
    "skyddsvärds": "skyddsvärd",
    "skyddsvärt": "skyddsvärd",
    "skyddsvärts": "skyddsvärd",
    "skyddsymp": "skyddsympa",
    "skyddsympad": "skyddsympa",
    "skyddsympade": "skyddsympa",
    "skyddsympades": "skyddsympa",
    "skyddsympads": "skyddsympa",
    "skyddsympande": "skyddsympa",
    "skyddsympanden": "skyddsympande",
    "skyddsympandena": "skyddsympande",
    "skyddsympandenas": "skyddsympande",
    "skyddsympandens": "skyddsympande",
    "skyddsympandes": "skyddsympande",
    "skyddsympandet": "skyddsympande",
    "skyddsympandets": "skyddsympande",
    "skyddsympar": "skyddsympa",
    "skyddsympas": "skyddsympa",
    "skyddsympat": "skyddsympa",
    "skyddsympats": "skyddsympa",
    "skyddsängeln": "skyddsängel",
    "skyddsängelns": "skyddsängel",
    "skyddsängels": "skyddsängel",
    "skyddsängla": "skyddsängel",
    "skyddsänglar": "skyddsängel",
    "skyddsänglarna": "skyddsängel",
    "skyddsänglarnas": "skyddsängel",
    "skyddsänglars": "skyddsängel",
    "skyddsöverdragen": "skyddsöverdrag",
    "skyddsöverdragens": "skyddsöverdrag",
    "skyddsöverdraget": "skyddsöverdrag",
    "skyddsöverdragets": "skyddsöverdrag",
    "skyddsöverdrags": "skyddsöverdrag",
    "skydragen": "skydrag",
    "skydragens": "skydrag",
    "skydraget": "skydrag",
    "skydragets": "skydrag",
    "skydrags": "skydrag",
    "skyende": "sky",
    "skyenden": "skyende",
    "skyendena": "skyende",
    "skyendenas": "skyende",
    "skyendens": "skyende",
    "skyendes": "skyende",
    "skyendet": "skyende",
    "skyendets": "skyende",
    "skyeterriern": "skyeterrier",
    "skyeterrierna": "skyeterrier",
    "skyeterriernas": "skyeterrier",
    "skyeterrierns": "skyeterrier",
    "skyeterriers": "skyeterrier",
    "skyfallen": "skyfall",
    "skyfallens": "skyfall",
    "skyfallet": "skyfall",
    "skyfallets": "skyfall",
    "skyfalls": "skyfall",
    "skyffel": "skyffla",
    "skyffeln": "skyffel",
    "skyffelns": "skyffel",
    "skyffels": "skyffel",
    "skyfflad": "skyffla",
    "skyfflade": "skyffla",
    "skyfflades": "skyffla",
    "skyfflads": "skyffla",
    "skyfflande": "skyffla",
    "skyfflanden": "skyfflande",
    "skyfflandena": "skyfflande",
    "skyfflandenas": "skyfflande",
    "skyfflandens": "skyfflande",
    "skyfflandes": "skyfflande",
    "skyfflandet": "skyfflande",
    "skyfflandets": "skyfflande",
    "skyfflar": "skyffla",
    "skyfflarna": "skyffel",
    "skyfflarnas": "skyffel",
    "skyfflars": "skyffel",
    "skyfflas": "skyffla",
    "skyfflat": "skyffla",
    "skyfflats": "skyffla",
    "skygdet": "skygd",
    "skygdets": "skygd",
    "skygds": "skygd",
    "skygg": "skygga",
    "skygga": "skygg",
    "skyggad": "skygga",
    "skyggade": "skygga",
    "skyggades": "skygga",
    "skyggads": "skygga",
    "skyggande": "skygga",
    "skygganden": "skyggande",
    "skyggandena": "skyggande",
    "skyggandenas": "skyggande",
    "skyggandens": "skyggande",
    "skyggandes": "skyggande",
    "skyggandet": "skyggande",
    "skyggandets": "skyggande",
    "skyggar": "skygga",
    "skyggare": "skygg",
    "skyggares": "skygg",
    "skyggas": "skygga",
    "skyggast": "skygg",
    "skyggaste": "skygg",
    "skyggastes": "skygg",
    "skyggasts": "skygg",
    "skyggat": "skygga",
    "skyggats": "skygga",
    "skygge": "skygg",
    "skyggen": "skygge",
    "skyggena": "skygge",
    "skyggenas": "skygge",
    "skyggens": "skygge",
    "skygges": "skygge",
    "skygget": "skygge",
    "skyggets": "skygge",
    "skyggheten": "skygghet",
    "skygghetens": "skygghet",
    "skygghets": "skygghet",
    "skygglappar": "skygglapp",
    "skygglapparna": "skygglapp",
    "skygglapparnas": "skygglapp",
    "skygglappars": "skygglapp",
    "skygglappen": "skygglapp",
    "skygglappens": "skygglapp",
    "skygglapps": "skygglapp",
    "skyggs": "skygge",
    "skyggt": "skygg",
    "skyggts": "skygg",
    "skyhöga": "skyhög",
    "skyhögare": "skyhög",
    "skyhögares": "skyhög",
    "skyhögas": "skyhög",
    "skyhögast": "skyhög",
    "skyhögaste": "skyhög",
    "skyhögastes": "skyhög",
    "skyhögasts": "skyhög",
    "skyhöge": "skyhög",
    "skyhöges": "skyhög",
    "skyhögs": "skyhög",
    "skyhögt": "skyhög",
    "skyhögts": "skyhög",
    "skyiga": "skyig",
    "skyigare": "skyig",
    "skyigares": "skyig",
    "skyigas": "skyig",
    "skyigast": "skyig",
    "skyigaste": "skyig",
    "skyigastes": "skyig",
    "skyigasts": "skyig",
    "skyige": "skyig",
    "skyiges": "skyig",
    "skyigheten": "skyighet",
    "skyighetens": "skyighet",
    "skyighets": "skyighet",
    "skyigs": "skyig",
    "skyigt": "skyig",
    "skyigts": "skyig",
    "skyl": "skyla",
    "skylad": "skyla",
    "skylade": "skyla",
    "skylades": "skyla",
    "skylads": "skyla",
    "skylande": "skyla",
    "skylanden": "skylande",
    "skylandena": "skylande",
    "skylandenas": "skylande",
    "skylandens": "skylande",
    "skylandes": "skylande",
    "skylandet": "skylande",
    "skylandets": "skylande",
    "skylar": "skyla",
    "skylarna": "skyl",
    "skylarnas": "skyl",
    "skylars": "skyl",
    "skylas": "skyla",
    "skylat": "skyla",
    "skylats": "skyla",
    "skyld": "skyla",
    "skylda": "skyld",
    "skyldare": "skyld",
    "skyldares": "skyld",
    "skyldas": "skyld",
    "skyldast": "skyld",
    "skyldaste": "skyld",
    "skyldastes": "skyld",
    "skyldasts": "skyld",
    "skylde": "skyld",
    "skylder": "skyldra",
    "skyldes": "skyld",
    "skyldiga": "skyldig",
    "skyldigare": "skyldig",
    "skyldigares": "skyldig",
    "skyldigas": "skyldig",
    "skyldigast": "skyldig",
    "skyldigaste": "skyldig",
    "skyldigastes": "skyldig",
    "skyldigasts": "skyldig",
    "skyldige": "skyldig",
    "skyldiges": "skyldig",
    "skyldigheten": "skyldighet",
    "skyldighetens": "skyldighet",
    "skyldigheter": "skyldighet",
    "skyldigheterna": "skyldighet",
    "skyldigheternas": "skyldighet",
    "skyldigheters": "skyldighet",
    "skyldighets": "skyldighet",
    "skyldigs": "skyldig",
    "skyldigt": "skyldig",
    "skyldigts": "skyldig",
    "skyldrad": "skyldra",
    "skyldrade": "skyldra",
    "skyldrades": "skyldra",
    "skyldrads": "skyldra",
    "skyldrande": "skyldra",
    "skyldranden": "skyldrande",
    "skyldrandena": "skyldrande",
    "skyldrandenas": "skyldrande",
    "skyldrandens": "skyldrande",
    "skyldrandes": "skyldrande",
    "skyldrandet": "skyldrande",
    "skyldrandets": "skyldrande",
    "skyldrar": "skyldra",
    "skyldras": "skyldra",
    "skyldrat": "skyldra",
    "skyldrats": "skyldra",
    "skylds": "skyld",
    "skylen": "skyl",
    "skylens": "skyl",
    "skyler": "skyla",
    "skyles": "skyla",
    "skylighten": "skylight",
    "skylightens": "skylight",
    "skylightet": "skylight",
    "skylightets": "skylight",
    "skylights": "skylight",
    "skyll": "skylla",
    "skyllande": "skylla",
    "skyllanden": "skyllande",
    "skyllandena": "skyllande",
    "skyllandenas": "skyllande",
    "skyllandens": "skyllande",
    "skyllandes": "skyllande",
    "skyllandet": "skyllande",
    "skyllandets": "skyllande",
    "skyllas": "skylla",
    "skylld": "skylla",
    "skyllda": "skylla",
    "skylldas": "skylla",
    "skyllde": "skylla",
    "skylldes": "skylla",
    "skyllds": "skylla",
    "skyller": "skylla",
    "skyllerkurar": "skyllerkur",
    "skyllerkurarna": "skyllerkur",
    "skyllerkurarnas": "skyllerkur",
    "skyllerkurars": "skyllerkur",
    "skyllerkuren": "skyllerkur",
    "skyllerkurens": "skyllerkur",
    "skyllerkurs": "skyllerkur",
    "skylles": "skylla",
    "skylls": "skylla",
    "skyllt": "skylla",
    "skyllts": "skylla",
    "skyls": "skyla",
    "skylt": "skylta",
    "skyltad": "skylta",
    "skyltade": "skylta",
    "skyltades": "skylta",
    "skyltads": "skylta",
    "skyltande": "skylta",
    "skyltanden": "skyltande",
    "skyltandena": "skyltande",
    "skyltandenas": "skyltande",
    "skyltandens": "skyltande",
    "skyltandes": "skyltande",
    "skyltandet": "skyltande",
    "skyltandets": "skyltande",
    "skyltar": "skylta",
    "skyltarna": "skylt",
    "skyltarnas": "skylt",
    "skyltars": "skylt",
    "skyltas": "skylta",
    "skyltat": "skylta",
    "skyltats": "skylta",
    "skyltdock": "skyltdocka",
    "skyltdockan": "skyltdocka",
    "skyltdockans": "skyltdocka",
    "skyltdockas": "skyltdocka",
    "skyltdocke": "skyltdocka",
    "skyltdockekroppar": "skyltdockekropp",
    "skyltdockekropparna": "skyltdockekropp",
    "skyltdockekropparnas": "skyltdockekropp",
    "skyltdockekroppars": "skyltdockekropp",
    "skyltdockekroppen": "skyltdockekropp",
    "skyltdockekroppens": "skyltdockekropp",
    "skyltdockekropps": "skyltdockekropp",
    "skyltdockor": "skyltdocka",
    "skyltdockorna": "skyltdocka",
    "skyltdockornas": "skyltdocka",
    "skyltdockors": "skyltdocka",
    "skyltdocks": "skyltdocka",
    "skylten": "skylt",
    "skyltens": "skylt",
    "skyltfönsterna": "skyltfönster",
    "skyltfönsternas": "skyltfönster",
    "skyltfönsters": "skyltfönster",
    "skyltfönstren": "skyltfönster",
    "skyltfönstrens": "skyltfönster",
    "skyltfönstret": "skyltfönster",
    "skyltfönstrets": "skyltfönster",
    "skyltlåd": "skyltlåda",
    "skyltlådan": "skyltlåda",
    "skyltlådans": "skyltlåda",
    "skyltlådas": "skyltlåda",
    "skyltlåde": "skyltlåda",
    "skyltlådor": "skyltlåda",
    "skyltlådorna": "skyltlåda",
    "skyltlådornas": "skyltlåda",
    "skyltlådors": "skyltlåda",
    "skyltlåds": "skyltlåda",
    "skyltningar": "skyltning",
    "skyltningarna": "skyltning",
    "skyltningarnas": "skyltning",
    "skyltningars": "skyltning",
    "skyltningen": "skyltning",
    "skyltningens": "skyltning",
    "skyltnings": "skyltning",
    "skylts": "skylt",
    "skyltskåpen": "skyltskåp",
    "skyltskåpens": "skyltskåp",
    "skyltskåpet": "skyltskåp",
    "skyltskåpets": "skyltskåp",
    "skyltskåps": "skyltskåp",
    "skyltsöndagar": "skyltsöndag",
    "skyltsöndagarna": "skyltsöndag",
    "skyltsöndagarnas": "skyltsöndag",
    "skyltsöndagars": "skyltsöndag",
    "skyltsöndagen": "skyltsöndag",
    "skyltsöndagens": "skyltsöndag",
    "skyltsöndags": "skyltsöndag",
    "skylttjuvar": "skylttjuv",
    "skylttjuvarna": "skylttjuv",
    "skylttjuvarnas": "skylttjuv",
    "skylttjuvars": "skylttjuv",
    "skylttjuven": "skylttjuv",
    "skylttjuvens": "skylttjuv",
    "skylttjuvs": "skylttjuv",
    "skym": "skymma",
    "skymd": "skymma",
    "skymda": "skymma",
    "skymdas": "skymma",
    "skymde": "skymma",
    "skymdes": "skymma",
    "skymds": "skymma",
    "skymf": "skymfa",
    "skymfad": "skymfa",
    "skymfade": "skymfa",
    "skymfades": "skymfa",
    "skymfads": "skymfa",
    "skymfande": "skymfa",
    "skymfanden": "skymfande",
    "skymfandena": "skymfande",
    "skymfandenas": "skymfande",
    "skymfandens": "skymfande",
    "skymfandes": "skymfande",
    "skymfandet": "skymfande",
    "skymfandets": "skymfande",
    "skymfar": "skymfa",
    "skymfas": "skymfa",
    "skymfat": "skymfa",
    "skymfats": "skymfa",
    "skymfen": "skymf",
    "skymfens": "skymf",
    "skymfer": "skymf",
    "skymferna": "skymf",
    "skymfernas": "skymf",
    "skymfers": "skymf",
    "skymfliga": "skymflig",
    "skymfligare": "skymflig",
    "skymfligares": "skymflig",
    "skymfligas": "skymflig",
    "skymfligast": "skymflig",
    "skymfligaste": "skymflig",
    "skymfligastes": "skymflig",
    "skymfligasts": "skymflig",
    "skymflige": "skymflig",
    "skymfliges": "skymflig",
    "skymfligheten": "skymflighet",
    "skymflighetens": "skymflighet",
    "skymflighets": "skymflighet",
    "skymfligs": "skymflig",
    "skymfligt": "skymflig",
    "skymfligts": "skymflig",
    "skymforden": "skymford",
    "skymfordens": "skymford",
    "skymfordet": "skymford",
    "skymfordets": "skymford",
    "skymfords": "skymford",
    "skymfs": "skymf",
    "skymlade": "skymla",
    "skymlades": "skymla",
    "skymlande": "skymla",
    "skymlanden": "skymlande",
    "skymlandena": "skymlande",
    "skymlandenas": "skymlande",
    "skymlandens": "skymlande",
    "skymlandes": "skymlande",
    "skymlandet": "skymlande",
    "skymlandets": "skymlande",
    "skymlar": "skymmel",
    "skymlarna": "skymmel",
    "skymlarnas": "skymmel",
    "skymlars": "skymmel",
    "skymlas": "skymla",
    "skymlat": "skymla",
    "skymlats": "skymla",
    "skymlet": "skymmel",
    "skymlets": "skymmel",
    "skymmande": "skymma",
    "skymmanden": "skymmande",
    "skymmandena": "skymmande",
    "skymmandenas": "skymmande",
    "skymmandens": "skymmande",
    "skymmandes": "skymmande",
    "skymmandet": "skymmande",
    "skymmandets": "skymmande",
    "skymmas": "skymma",
    "skymmel": "skymla",
    "skymmeln": "skymmel",
    "skymmelns": "skymmel",
    "skymmels": "skymmel",
    "skymmer": "skymma",
    "skymmlar": "skymmel",
    "skymmlarna": "skymmel",
    "skymmlarnas": "skymmel",
    "skymmlars": "skymmel",
    "skymningar": "skymning",
    "skymningarna": "skymning",
    "skymningarnas": "skymning",
    "skymningars": "skymning",
    "skymningen": "skymning",
    "skymningens": "skymning",
    "skymnings": "skymning",
    "skymningslandet": "skymningsland",
    "skymningslandets": "skymningsland",
    "skymningslands": "skymningsland",
    "skyms": "skymma",
    "skymt": "skymta",
    "skymtad": "skymta",
    "skymtade": "skymta",
    "skymtades": "skymta",
    "skymtads": "skymta",
    "skymtande": "skymta",
    "skymtanden": "skymtande",
    "skymtandena": "skymtande",
    "skymtandenas": "skymtande",
    "skymtandens": "skymtande",
    "skymtandes": "skymtande",
    "skymtandet": "skymtande",
    "skymtandets": "skymtande",
    "skymtar": "skymta",
    "skymtarna": "skymt",
    "skymtarnas": "skymt",
    "skymtars": "skymt",
    "skymtas": "skymta",
    "skymtat": "skymta",
    "skymtats": "skymta",
    "skymten": "skymt",
    "skymtens": "skymt",
    "skymts": "skymt",
    "skyn": "sky",
    "skynd": "skynda",
    "skyndad": "skynda",
    "skyndade": "skynda",
    "skyndades": "skynda",
    "skyndads": "skynda",
    "skyndande": "skynda",
    "skyndanden": "skyndande",
    "skyndandena": "skyndande",
    "skyndandenas": "skyndande",
    "skyndandens": "skyndande",
    "skyndandes": "skyndande",
    "skyndandet": "skyndande",
    "skyndandets": "skyndande",
    "skyndar": "skynda",
    "skyndas": "skynda",
    "skyndat": "skynda",
    "skyndats": "skynda",
    "skyndsamheten": "skyndsamhet",
    "skyndsamhetens": "skyndsamhet",
    "skyndsamhets": "skyndsamhet",
    "skyndsamma": "skyndsam",
    "skyndsammare": "skyndsam",
    "skyndsammares": "skyndsam",
    "skyndsammas": "skyndsam",
    "skyndsammast": "skyndsam",
    "skyndsammaste": "skyndsam",
    "skyndsammastes": "skyndsam",
    "skyndsammasts": "skyndsam",
    "skyndsamme": "skyndsam",
    "skyndsammes": "skyndsam",
    "skyndsams": "skyndsam",
    "skyndsamt": "skyndsam",
    "skyndsamts": "skyndsam",
    "skynken": "skynke",
    "skynkena": "skynke",
    "skynkenas": "skynke",
    "skynkens": "skynke",
    "skynkes": "skynke",
    "skynket": "skynke",
    "skynkets": "skynke",
    "skynks": "skynke",
    "skyns": "sky",
    "skyr": "sky",
    "skys": "sky",
    "skyskrap": "skyskrapa",
    "skyskrapan": "skyskrapa",
    "skyskrapans": "skyskrapa",
    "skyskrapas": "skyskrapa",
    "skyskrape": "skyskrapa",
    "skyskrapor": "skyskrapa",
    "skyskraporna": "skyskrapa",
    "skyskrapornas": "skyskrapa",
    "skyskrapors": "skyskrapa",
    "skyskraps": "skyskrapa",
    "skyten": "skyt",
    "skytens": "skyt",
    "skyter": "skyt",
    "skyterna": "skyt",
    "skyternas": "skyt",
    "skyters": "skyt",
    "skyts": "skyt",
    "skytt": "sky",
    "skyttar": "skytt",
    "skyttarna": "skytt",
    "skyttarnas": "skytt",
    "skyttars": "skytt",
    "skyttegravar": "skyttegrav",
    "skyttegravarna": "skyttegrav",
    "skyttegravarnas": "skyttegrav",
    "skyttegravars": "skyttegrav",
    "skyttegraven": "skyttegrav",
    "skyttegravens": "skyttegrav",
    "skyttegravs": "skyttegrav",
    "skyttegravskanten": "skyttegravskant",
    "skyttegravskantens": "skyttegravskant",
    "skyttegravskanter": "skyttegravskant",
    "skyttegravskanterna": "skyttegravskant",
    "skyttegravskanternas": "skyttegravskant",
    "skyttegravskanters": "skyttegravskant",
    "skyttegravskants": "skyttegravskant",
    "skyttegravskrigen": "skyttegravskrig",
    "skyttegravskrigens": "skyttegravskrig",
    "skyttegravskriget": "skyttegravskrig",
    "skyttegravskrigets": "skyttegravskrig",
    "skyttegravskrigs": "skyttegravskrig",
    "skyttegropar": "skyttegrop",
    "skyttegroparna": "skyttegrop",
    "skyttegroparnas": "skyttegrop",
    "skyttegropars": "skyttegrop",
    "skyttegropen": "skyttegrop",
    "skyttegropens": "skyttegrop",
    "skyttegrops": "skyttegrop",
    "skyttegruppen": "skyttegrupp",
    "skyttegruppens": "skyttegrupp",
    "skyttegrupper": "skyttegrupp",
    "skyttegrupperna": "skyttegrupp",
    "skyttegruppernas": "skyttegrupp",
    "skyttegruppers": "skyttegrupp",
    "skyttegrupps": "skyttegrupp",
    "skyttelinjen": "skyttelinje",
    "skyttelinjens": "skyttelinje",
    "skyttelinjer": "skyttelinje",
    "skyttelinjerna": "skyttelinje",
    "skyttelinjernas": "skyttelinje",
    "skyttelinjers": "skyttelinje",
    "skyttelinjes": "skyttelinje",
    "skytteln": "skyttel",
    "skyttelns": "skyttel",
    "skyttels": "skyttel",
    "skytteltrafiken": "skytteltrafik",
    "skytteltrafikens": "skytteltrafik",
    "skytteltrafiks": "skytteltrafik",
    "skytten": "skytte",
    "skyttena": "skytte",
    "skyttenas": "skytte",
    "skyttens": "skytte",
    "skyttepaviljongen": "skyttepaviljong",
    "skyttepaviljongens": "skyttepaviljong",
    "skyttepaviljonger": "skyttepaviljong",
    "skyttepaviljongerna": "skyttepaviljong",
    "skyttepaviljongernas": "skyttepaviljong",
    "skyttepaviljongers": "skyttepaviljong",
    "skyttepaviljongs": "skyttepaviljong",
    "skyttes": "skytte",
    "skytteskälvan": "skytteskälva",
    "skytteskälvans": "skytteskälva",
    "skytteskälvas": "skytteskälva",
    "skyttet": "skytte",
    "skyttets": "skytte",
    "skyttevärnen": "skyttevärn",
    "skyttevärnens": "skyttevärn",
    "skyttevärnet": "skyttevärn",
    "skyttevärnets": "skyttevärn",
    "skyttevärns": "skyttevärn",
    "skyttlar": "skyttel",
    "skyttlarna": "skyttel",
    "skyttlarnas": "skyttel",
    "skyttlars": "skyttel",
    "skytts": "skytt",
    "skäckar": "skäck",
    "skäckarna": "skäck",
    "skäckarnas": "skäck",
    "skäckars": "skäck",
    "skäcken": "skäck",
    "skäckens": "skäck",
    "skäckiga": "skäckig",
    "skäckigare": "skäckig",
    "skäckigares": "skäckig",
    "skäckigas": "skäckig",
    "skäckigast": "skäckig",
    "skäckigaste": "skäckig",
    "skäckigastes": "skäckig",
    "skäckigasts": "skäckig",
    "skäckige": "skäckig",
    "skäckiges": "skäckig",
    "skäckigheten": "skäckighet",
    "skäckighetens": "skäckighet",
    "skäckighets": "skäckighet",
    "skäckigs": "skäckig",
    "skäckigt": "skäckig",
    "skäckigts": "skäckig",
    "skäcks": "skäck",
    "skädd": "skädda",
    "skäddan": "skädda",
    "skäddans": "skädda",
    "skäddas": "skädda",
    "skädde": "skädda",
    "skäddor": "skädda",
    "skäddorna": "skädda",
    "skäddornas": "skädda",
    "skäddors": "skädda",
    "skädds": "skädda",
    "skäft": "skäfta",
    "skäftad": "skäfta",
    "skäftade": "skäfta",
    "skäftades": "skäfta",
    "skäftads": "skäfta",
    "skäftande": "skäfta",
    "skäftanden": "skäftande",
    "skäftandena": "skäftande",
    "skäftandenas": "skäftande",
    "skäftandens": "skäftande",
    "skäftandes": "skäftande",
    "skäftandet": "skäftande",
    "skäftandets": "skäftande",
    "skäftar": "skäfta",
    "skäftas": "skäfta",
    "skäftat": "skäfta",
    "skäftats": "skäfta",
    "skäftiga": "skäftig",
    "skäftigare": "skäftig",
    "skäftigares": "skäftig",
    "skäftigas": "skäftig",
    "skäftigast": "skäftig",
    "skäftigaste": "skäftig",
    "skäftigastes": "skäftig",
    "skäftigasts": "skäftig",
    "skäftige": "skäftig",
    "skäftiges": "skäftig",
    "skäftigheten": "skäftighet",
    "skäftighetens": "skäftighet",
    "skäftighets": "skäftighet",
    "skäftigs": "skäftig",
    "skäftigt": "skäftig",
    "skäftigts": "skäftig",
    "skägg": "skägga",
    "skäggad": "skägga",
    "skäggade": "skägga",
    "skäggades": "skägga",
    "skäggads": "skägga",
    "skäggande": "skägga",
    "skägganden": "skäggande",
    "skäggandena": "skäggande",
    "skäggandenas": "skäggande",
    "skäggandens": "skäggande",
    "skäggandes": "skäggande",
    "skäggandet": "skäggande",
    "skäggandets": "skäggande",
    "skäggar": "skägga",
    "skäggas": "skägga",
    "skäggat": "skägga",
    "skäggats": "skägga",
    "skäggbottens": "skäggbotten",
    "skäggbottnar": "skäggbotten",
    "skäggbottnarna": "skäggbotten",
    "skäggbottnarnas": "skäggbotten",
    "skäggbottnars": "skäggbotten",
    "skäggbottnen": "skäggbotten",
    "skäggbottnens": "skäggbotten",
    "skäggdoppingar": "skäggdopping",
    "skäggdoppingarna": "skäggdopping",
    "skäggdoppingarnas": "skäggdopping",
    "skäggdoppingars": "skäggdopping",
    "skäggdoppingen": "skäggdopping",
    "skäggdoppingens": "skäggdopping",
    "skäggdoppings": "skäggdopping",
    "skäggen": "skägg",
    "skäggens": "skägg",
    "skägget": "skägg",
    "skäggets": "skägg",
    "skäggiga": "skäggig",
    "skäggigare": "skäggig",
    "skäggigares": "skäggig",
    "skäggigas": "skäggig",
    "skäggigast": "skäggig",
    "skäggigaste": "skäggig",
    "skäggigastes": "skäggig",
    "skäggigasts": "skäggig",
    "skäggige": "skäggig",
    "skäggiges": "skäggig",
    "skäggigheten": "skäggighet",
    "skäggighetens": "skäggighet",
    "skäggighets": "skäggighet",
    "skäggigs": "skäggig",
    "skäggigt": "skäggig",
    "skäggigts": "skäggig",
    "skägglappar": "skägglapp",
    "skägglapparna": "skägglapp",
    "skägglapparnas": "skägglapp",
    "skägglappars": "skägglapp",
    "skägglappen": "skägglapp",
    "skägglappens": "skägglapp",
    "skägglapps": "skägglapp",
    "skägglaven": "skägglav",
    "skägglavens": "skägglav",
    "skägglavs": "skägglav",
    "skägglösa": "skägglös",
    "skägglösare": "skägglös",
    "skägglösares": "skägglös",
    "skägglösas": "skägglös",
    "skägglösast": "skägglös",
    "skägglösaste": "skägglös",
    "skägglösastes": "skägglös",
    "skägglösasts": "skägglös",
    "skägglöse": "skägglös",
    "skägglöses": "skägglös",
    "skägglösheten": "skägglöshet",
    "skägglöshetens": "skägglöshet",
    "skägglöshets": "skägglöshet",
    "skägglöst": "skägglös",
    "skägglösts": "skägglös",
    "skäggmunsmalar": "skäggmunsmal",
    "skäggmunsmalarna": "skäggmunsmal",
    "skäggmunsmalarnas": "skäggmunsmal",
    "skäggmunsmalars": "skäggmunsmal",
    "skäggmunsmalen": "skäggmunsmal",
    "skäggmunsmalens": "skäggmunsmal",
    "skäggmunsmals": "skäggmunsmal",
    "skäggs": "skägg",
    "skäggstrået": "skäggstrå",
    "skäggstråets": "skäggstrå",
    "skäggstrån": "skäggstrå",
    "skäggstråna": "skäggstrå",
    "skäggstrånas": "skäggstrå",
    "skäggstråns": "skäggstrå",
    "skäggstrås": "skäggstrå",
    "skäggstråt": "skäggstrå",
    "skäggstråts": "skäggstrå",
    "skäggstubben": "skäggstubb",
    "skäggstubbens": "skäggstubb",
    "skäggstubbs": "skäggstubb",
    "skäggsvampen": "skäggsvamp",
    "skäggsvampens": "skäggsvamp",
    "skäggsvamps": "skäggsvamp",
    "skäggtömmar": "skäggtöm",
    "skäggtömmarna": "skäggtöm",
    "skäggtömmarnas": "skäggtöm",
    "skäggtömmars": "skäggtöm",
    "skäggtömmen": "skäggtöm",
    "skäggtömmens": "skäggtöm",
    "skäggtöms": "skäggtöm",
    "skäggvårt": "skäggvårta",
    "skäggvårtan": "skäggvårta",
    "skäggvårtans": "skäggvårta",
    "skäggvårtas": "skäggvårta",
    "skäggvårte": "skäggvårta",
    "skäggvårtor": "skäggvårta",
    "skäggvårtorna": "skäggvårta",
    "skäggvårtornas": "skäggvårta",
    "skäggvårtors": "skäggvårta",
    "skäggvårts": "skäggvårta",
    "skäkt": "skäkta",
    "skäktad": "skäkta",
    "skäktade": "skäkta",
    "skäktades": "skäkta",
    "skäktads": "skäkta",
    "skäktan": "skäkta",
    "skäktande": "skäkta",
    "skäktanden": "skäktande",
    "skäktandena": "skäktande",
    "skäktandenas": "skäktande",
    "skäktandens": "skäktande",
    "skäktandes": "skäktande",
    "skäktandet": "skäktande",
    "skäktandets": "skäktande",
    "skäktans": "skäkta",
    "skäktar": "skäkta",
    "skäktas": "skäkta",
    "skäktat": "skäkta",
    "skäktats": "skäkta",
    "skäkte": "skäkta",
    "skäkteträet": "skäkteträ",
    "skäkteträets": "skäkteträ",
    "skäkteträn": "skäkteträ",
    "skäkteträna": "skäkteträ",
    "skäktetränas": "skäkteträ",
    "skäkteträns": "skäkteträ",
    "skäkteträs": "skäkteträ",
    "skäkteträt": "skäkteträ",
    "skäkteträts": "skäkteträ",
    "skäktknivar": "skäktkniv",
    "skäktknivarna": "skäktkniv",
    "skäktknivarnas": "skäktkniv",
    "skäktknivars": "skäktkniv",
    "skäktkniven": "skäktkniv",
    "skäktknivens": "skäktkniv",
    "skäktknivs": "skäktkniv",
    "skäktor": "skäkta",
    "skäktorna": "skäkta",
    "skäktornas": "skäkta",
    "skäktors": "skäkta",
    "skäkts": "skäkta",
    "skäktstolar": "skäktstol",
    "skäktstolarna": "skäktstol",
    "skäktstolarnas": "skäktstol",
    "skäktstolars": "skäktstol",
    "skäktstolen": "skäktstol",
    "skäktstolens": "skäktstol",
    "skäktstols": "skäktstol",
    "skäktträn": "skäktträ",
    "skäktträna": "skäktträ",
    "skäkttränas": "skäktträ",
    "skäktträns": "skäktträ",
    "skäktträs": "skäktträ",
    "skäktträt": "skäktträ",
    "skäktträts": "skäktträ",
    "skälen": "skäl",
    "skälens": "skäl",
    "skälet": "skäl",
    "skälets": "skäl",
    "skäliga": "skälig",
    "skäligare": "skälig",
    "skäligares": "skälig",
    "skäligas": "skälig",
    "skäligast": "skälig",
    "skäligaste": "skälig",
    "skäligastes": "skälig",
    "skäligasts": "skälig",
    "skälige": "skälig",
    "skäliges": "skälig",
    "skäligheten": "skälighet",
    "skälighetens": "skälighet",
    "skälighets": "skälighet",
    "skäligs": "skälig",
    "skäligt": "skälig",
    "skäligts": "skälig",
    "skäll": "skälla",
    "skälla": "skäll",
    "skällan": "skälla",
    "skällande": "skälla",
    "skällanden": "skällande",
    "skällandena": "skällande",
    "skällandenas": "skällande",
    "skällandens": "skällande",
    "skällandes": "skällande",
    "skällandet": "skällande",
    "skällandets": "skällande",
    "skällans": "skälla",
    "skällare": "skäll",
    "skällares": "skäll",
    "skällas": "skälla",
    "skällast": "skäll",
    "skällaste": "skäll",
    "skällastes": "skäll",
    "skällasts": "skäll",
    "skälld": "skälla",
    "skällda": "skälla",
    "skälldas": "skälla",
    "skällde": "skälla",
    "skälldes": "skälla",
    "skällds": "skälla",
    "skälle": "skälla",
    "skäller": "skälla",
    "skälles": "skälla",
    "skället": "skäll",
    "skällets": "skäll",
    "skällkon": "skällko",
    "skällkons": "skällko",
    "skällkor": "skällko",
    "skällkorna": "skällko",
    "skällkornas": "skällko",
    "skällkors": "skällko",
    "skällkos": "skällko",
    "skällningar": "skällning",
    "skällningarna": "skällning",
    "skällningarnas": "skällning",
    "skällningars": "skällning",
    "skällningen": "skällning",
    "skällningens": "skällning",
    "skällnings": "skällning",
    "skällor": "skälla",
    "skällorna": "skälla",
    "skällornas": "skälla",
    "skällors": "skälla",
    "skälls": "skälla",
    "skällsorden": "skällsord",
    "skällsordens": "skällsord",
    "skällsordet": "skällsord",
    "skällsordets": "skällsord",
    "skällsords": "skällsord",
    "skällt": "skälla",
    "skällts": "skälla",
    "skälmaktiga": "skälmaktig",
    "skälmaktigare": "skälmaktig",
    "skälmaktigares": "skälmaktig",
    "skälmaktigas": "skälmaktig",
    "skälmaktigast": "skälmaktig",
    "skälmaktigaste": "skälmaktig",
    "skälmaktigastes": "skälmaktig",
    "skälmaktigasts": "skälmaktig",
    "skälmaktige": "skälmaktig",
    "skälmaktiges": "skälmaktig",
    "skälmaktigheten": "skälmaktighet",
    "skälmaktighetens": "skälmaktighet",
    "skälmaktighets": "skälmaktighet",
    "skälmaktigs": "skälmaktig",
    "skälmaktigt": "skälmaktig",
    "skälmaktigts": "skälmaktig",
    "skälmar": "skälm",
    "skälmarna": "skälm",
    "skälmarnas": "skälm",
    "skälmars": "skälm",
    "skälmen": "skälm",
    "skälmens": "skälm",
    "skälmromanen": "skälmroman",
    "skälmromanens": "skälmroman",
    "skälmromaner": "skälmroman",
    "skälmromanerna": "skälmroman",
    "skälmromanernas": "skälmroman",
    "skälmromaners": "skälmroman",
    "skälmromans": "skälmroman",
    "skälms": "skälm",
    "skälmska": "skälmsk",
    "skälmskare": "skälmsk",
    "skälmskares": "skälmsk",
    "skälmskas": "skälmsk",
    "skälmskast": "skälmsk",
    "skälmskaste": "skälmsk",
    "skälmskastes": "skälmsk",
    "skälmskasts": "skälmsk",
    "skälmske": "skälmsk",
    "skälmskes": "skälmsk",
    "skälmskheten": "skälmskhet",
    "skälmskhetens": "skälmskhet",
    "skälmskhets": "skälmskhet",
    "skälmsks": "skälmsk",
    "skälmskt": "skälmsk",
    "skälmskts": "skälmsk",
    "skäls": "skäl",
    "skälv": "skälva",
    "skälvan": "skälva",
    "skälvande": "skälva",
    "skälvanden": "skälvande",
    "skälvandena": "skälvande",
    "skälvandenas": "skälvande",
    "skälvandens": "skälvande",
    "skälvandes": "skälvande",
    "skälvandet": "skälvande",
    "skälvandets": "skälvande",
    "skälvans": "skälva",
    "skälvas": "skälva",
    "skälvde": "skälva",
    "skälve": "skälva",
    "skälver": "skälva",
    "skälvesoten": "skälvesot",
    "skälvesotens": "skälvesot",
    "skälvesots": "skälvesot",
    "skälvosoten": "skälvosot",
    "skälvosotens": "skälvosot",
    "skälvosots": "skälvosot",
    "skäm": "skämma",
    "skämd": "skämma",
    "skämda": "skämma",
    "skämdare": "skämd",
    "skämdares": "skämd",
    "skämdas": "skämma",
    "skämdast": "skämd",
    "skämdaste": "skämd",
    "skämdastes": "skämd",
    "skämdasts": "skämd",
    "skämde": "skämma",
    "skämdes": "skämma",
    "skämdheten": "skämdhet",
    "skämdhetens": "skämdhet",
    "skämdhets": "skämdhet",
    "skämds": "skämma",
    "skämmande": "skämma",
    "skämmanden": "skämmande",
    "skämmandena": "skämmande",
    "skämmandenas": "skämmande",
    "skämmandens": "skämmande",
    "skämmandes": "skämmande",
    "skämmandet": "skämmande",
    "skämmandets": "skämmande",
    "skämmas": "skämma",
    "skämmdes": "skämmas",
    "skämmer": "skämma",
    "skämmiga": "skämmig",
    "skämmigare": "skämmig",
    "skämmigares": "skämmig",
    "skämmigas": "skämmig",
    "skämmigast": "skämmig",
    "skämmigaste": "skämmig",
    "skämmigastes": "skämmig",
    "skämmigasts": "skämmig",
    "skämmige": "skämmig",
    "skämmiges": "skämmig",
    "skämmigheten": "skämmighet",
    "skämmighetens": "skämmighet",
    "skämmighets": "skämmighet",
    "skämmigs": "skämmig",
    "skämmigt": "skämmig",
    "skämmigts": "skämmig",
    "skämmts": "skämmas",
    "skäms": "skämmas",
    "skämt": "skämta",
    "skämtad": "skämta",
    "skämtade": "skämta",
    "skämtades": "skämta",
    "skämtads": "skämta",
    "skämtande": "skämta",
    "skämtanden": "skämtande",
    "skämtandena": "skämtande",
    "skämtandenas": "skämtande",
    "skämtandens": "skämtande",
    "skämtandes": "skämtande",
    "skämtandet": "skämtande",
    "skämtandets": "skämtande",
    "skämtar": "skämtare",
    "skämtaren": "skämtare",
    "skämtarens": "skämtare",
    "skämtares": "skämtare",
    "skämtarna": "skämtare",
    "skämtarnas": "skämtare",
    "skämtas": "skämta",
    "skämtat": "skämta",
    "skämtats": "skämta",
    "skämten": "skämt",
    "skämtens": "skämt",
    "skämtet": "skämt",
    "skämtets": "skämt",
    "skämtlynnes": "skämtlynne",
    "skämtlynnet": "skämtlynne",
    "skämtlynnets": "skämtlynne",
    "skämts": "skämt",
    "skämtsamheten": "skämtsamhet",
    "skämtsamhetens": "skämtsamhet",
    "skämtsamheter": "skämtsamhet",
    "skämtsamheterna": "skämtsamhet",
    "skämtsamheternas": "skämtsamhet",
    "skämtsamheters": "skämtsamhet",
    "skämtsamhets": "skämtsamhet",
    "skämtsamma": "skämtsam",
    "skämtsammare": "skämtsam",
    "skämtsammares": "skämtsam",
    "skämtsammas": "skämtsam",
    "skämtsammast": "skämtsam",
    "skämtsammaste": "skämtsam",
    "skämtsammastes": "skämtsam",
    "skämtsammasts": "skämtsam",
    "skämtsamme": "skämtsam",
    "skämtsammes": "skämtsam",
    "skämtsams": "skämtsam",
    "skämtsamt": "skämtsam",
    "skämtsamts": "skämtsam",
    "skämttecknar": "skämttecknare",
    "skämttecknaren": "skämttecknare",
    "skämttecknarens": "skämttecknare",
    "skämttecknares": "skämttecknare",
    "skämttecknarna": "skämttecknare",
    "skämttecknarnas": "skämttecknare",
    "skämtteckningar": "skämtteckning",
    "skämtteckningarna": "skämtteckning",
    "skämtteckningarnas": "skämtteckning",
    "skämtteckningars": "skämtteckning",
    "skämtteckningen": "skämtteckning",
    "skämtteckningens": "skämtteckning",
    "skämttecknings": "skämtteckning",
    "skänd": "skända",
    "skändad": "skända",
    "skändade": "skända",
    "skändades": "skända",
    "skändads": "skända",
    "skändande": "skända",
    "skändanden": "skändande",
    "skändandena": "skändande",
    "skändandenas": "skändande",
    "skändandens": "skändande",
    "skändandes": "skändande",
    "skändandet": "skändande",
    "skändandets": "skändande",
    "skändar": "skända",
    "skändas": "skända",
    "skändat": "skända",
    "skändats": "skända",
    "skändliga": "skändlig",
    "skändligare": "skändlig",
    "skändligares": "skändlig",
    "skändligas": "skändlig",
    "skändligast": "skändlig",
    "skändligaste": "skändlig",
    "skändligastes": "skändlig",
    "skändligasts": "skändlig",
    "skändlige": "skändlig",
    "skändliges": "skändlig",
    "skändligheten": "skändlighet",
    "skändlighetens": "skändlighet",
    "skändligheter": "skändlighet",
    "skändligheterna": "skändlighet",
    "skändligheternas": "skändlighet",
    "skändligheters": "skändlighet",
    "skändlighets": "skändlighet",
    "skändligs": "skändlig",
    "skändligt": "skändlig",
    "skändligts": "skändlig",
    "skändningar": "skändning",
    "skändningarna": "skändning",
    "skändningarnas": "skändning",
    "skändningars": "skändning",
    "skändningen": "skändning",
    "skändningens": "skändning",
    "skändnings": "skändning",
    "skänk": "skänka",
    "skänkande": "skänka",
    "skänkanden": "skänkande",
    "skänkandena": "skänkande",
    "skänkandenas": "skänkande",
    "skänkandens": "skänkande",
    "skänkandes": "skänkande",
    "skänkandet": "skänkande",
    "skänkandets": "skänkande",
    "skänkar": "skänk",
    "skänkarna": "skänk",
    "skänkarnas": "skänk",
    "skänkars": "skänk",
    "skänkas": "skänka",
    "skänkel": "skänkla",
    "skänkelhjälpen": "skänkelhjälp",
    "skänkelhjälpens": "skänkelhjälp",
    "skänkelhjälps": "skänkelhjälp",
    "skänkeln": "skänkel",
    "skänkelns": "skänkel",
    "skänkels": "skänkel",
    "skänken": "skänk",
    "skänkens": "skänk",
    "skänker": "skänka",
    "skänkerna": "skänk",
    "skänkernas": "skänk",
    "skänkers": "skänk",
    "skänkes": "skänka",
    "skänklad": "skänkla",
    "skänklade": "skänkla",
    "skänklades": "skänkla",
    "skänklads": "skänkla",
    "skänklande": "skänkla",
    "skänklanden": "skänklande",
    "skänklandena": "skänklande",
    "skänklandenas": "skänklande",
    "skänklandens": "skänklande",
    "skänklandes": "skänklande",
    "skänklandet": "skänklande",
    "skänklandets": "skänklande",
    "skänklar": "skänkla",
    "skänklarna": "skänkel",
    "skänklarnas": "skänkel",
    "skänklars": "skänkel",
    "skänklas": "skänkla",
    "skänklat": "skänkla",
    "skänklats": "skänkla",
    "skänks": "skänka",
    "skänkt": "skänka",
    "skänkta": "skänka",
    "skänktas": "skänka",
    "skänkte": "skänka",
    "skänktes": "skänka",
    "skänkts": "skänka",
    "skäpp": "skäppa",
    "skäppan": "skäppa",
    "skäppans": "skäppa",
    "skäppas": "skäppa",
    "skäppe": "skäppa",
    "skäppor": "skäppa",
    "skäpporna": "skäppa",
    "skäppornas": "skäppa",
    "skäppors": "skäppa",
    "skäpps": "skäppa",
    "skär": "skära",
    "skära": "skär",
    "skärad": "skära",
    "skärade": "skära",
    "skärades": "skära",
    "skärads": "skära",
    "skäran": "skära",
    "skärande": "skära",
    "skäranden": "skärande",
    "skärandena": "skärande",
    "skärandenas": "skärande",
    "skärandens": "skärande",
    "skärandes": "skärande",
    "skärandet": "skärande",
    "skärandets": "skärande",
    "skärans": "skära",
    "skärar": "skära",
    "skärare": "skär",
    "skärares": "skär",
    "skäras": "skära",
    "skärast": "skär",
    "skäraste": "skär",
    "skärastes": "skär",
    "skärasts": "skär",
    "skärat": "skära",
    "skärats": "skära",
    "skärbräd": "skärbräda",
    "skärbrädan": "skärbräda",
    "skärbrädans": "skärbräda",
    "skärbrädas": "skärbräda",
    "skärbräde": "skärbräda",
    "skärbräden": "skärbräde",
    "skärbrädena": "skärbräde",
    "skärbrädenas": "skärbräde",
    "skärbrädens": "skärbräde",
    "skärbrädes": "skärbräde",
    "skärbrädet": "skärbräde",
    "skärbrädets": "skärbräde",
    "skärbrädor": "skärbräda",
    "skärbrädorna": "skärbräda",
    "skärbrädornas": "skärbräda",
    "skärbrädors": "skärbräda",
    "skärbräds": "skärbräda",
    "skärbrännar": "skärbrännare",
    "skärbrännaren": "skärbrännare",
    "skärbrännarens": "skärbrännare",
    "skärbrännares": "skärbrännare",
    "skärbrännarna": "skärbrännare",
    "skärbrännarnas": "skärbrännare",
    "skärbön": "skärböna",
    "skärbönan": "skärböna",
    "skärbönans": "skärböna",
    "skärbönas": "skärböna",
    "skärböne": "skärböna",
    "skärbönor": "skärböna",
    "skärbönorna": "skärböna",
    "skärbönornas": "skärböna",
    "skärbönors": "skärböna",
    "skärböns": "skärböna",
    "skäre": "skära",
    "skäreggar": "skäregg",
    "skäreggarna": "skäregg",
    "skäreggarnas": "skäregg",
    "skäreggars": "skäregg",
    "skäreggen": "skäregg",
    "skäreggens": "skäregg",
    "skäreggs": "skäregg",
    "skären": "skär",
    "skärens": "skär",
    "skäres": "skära",
    "skäret": "skär",
    "skärets": "skär",
    "skärfläck": "skärfläcka",
    "skärfläckan": "skärfläcka",
    "skärfläckans": "skärfläcka",
    "skärfläckas": "skärfläcka",
    "skärfläcke": "skärfläcka",
    "skärfläckor": "skärfläcka",
    "skärfläckorna": "skärfläcka",
    "skärfläckornas": "skärfläcka",
    "skärfläckors": "skärfläcka",
    "skärfläcks": "skärfläcka",
    "skärgårdar": "skärgård",
    "skärgårdarna": "skärgård",
    "skärgårdarnas": "skärgård",
    "skärgårdars": "skärgård",
    "skärgården": "skärgård",
    "skärgårdens": "skärgård",
    "skärgårds": "skärgård",
    "skärgårdsbon": "skärgårdsbo",
    "skärgårdsbons": "skärgårdsbo",
    "skärgårdsbor": "skärgårdsbo",
    "skärgårdsborna": "skärgårdsbo",
    "skärgårdsbornas": "skärgårdsbo",
    "skärgårdsbors": "skärgårdsbo",
    "skärgårdsbos": "skärgårdsbo",
    "skärgårdskryssar": "skärgårdskryssare",
    "skärgårdskryssaren": "skärgårdskryssare",
    "skärgårdskryssarens": "skärgårdskryssare",
    "skärgårdskryssares": "skärgårdskryssare",
    "skärgårdskryssarna": "skärgårdskryssare",
    "skärgårdskryssarnas": "skärgårdskryssare",
    "skärgårdsturisten": "skärgårdsturist",
    "skärgårdsturistens": "skärgårdsturist",
    "skärgårdsturister": "skärgårdsturist",
    "skärgårdsturisterna": "skärgårdsturist",
    "skärgårdsturisternas": "skärgårdsturist",
    "skärgårdsturisters": "skärgårdsturist",
    "skärgårdsturists": "skärgårdsturist",
    "skärgårdsöar": "skärgårdsö",
    "skärgårdsöarna": "skärgårdsö",
    "skärgårdsöarnas": "skärgårdsö",
    "skärgårdsöars": "skärgårdsö",
    "skärgårdsön": "skärgårdsö",
    "skärgårdsöns": "skärgårdsö",
    "skärgårdsös": "skärgårdsö",
    "skärhållfastheten": "skärhållfasthet",
    "skärhållfasthetens": "skärhållfasthet",
    "skärhållfastheter": "skärhållfasthet",
    "skärhållfastheterna": "skärhållfasthet",
    "skärhållfastheternas": "skärhållfasthet",
    "skärhållfastheters": "skärhållfasthet",
    "skärhållfasthets": "skärhållfasthet",
    "skärkapaciteten": "skärkapacitet",
    "skärkapacitetens": "skärkapacitet",
    "skärkapacitets": "skärkapacitet",
    "skärkarlar": "skärkarl",
    "skärkarlarna": "skärkarl",
    "skärkarlarnas": "skärkarl",
    "skärkarlars": "skärkarl",
    "skärkarlen": "skärkarl",
    "skärkarlens": "skärkarl",
    "skärkarls": "skärkarl",
    "skärknivar": "skärkniv",
    "skärknivarna": "skärkniv",
    "skärknivarnas": "skärkniv",
    "skärknivars": "skärkniv",
    "skärkniven": "skärkniv",
    "skärknivens": "skärkniv",
    "skärknivs": "skärkniv",
    "skärlåd": "skärlåda",
    "skärlådan": "skärlåda",
    "skärlådans": "skärlåda",
    "skärlådas": "skärlåda",
    "skärlåde": "skärlåda",
    "skärlådor": "skärlåda",
    "skärlådorna": "skärlåda",
    "skärlådornas": "skärlåda",
    "skärlådors": "skärlåda",
    "skärlåds": "skärlåda",
    "skärmar": "skärm",
    "skärmarna": "skärm",
    "skärmarnas": "skärm",
    "skärmars": "skärm",
    "skärmbild": "skärmbilda",
    "skärmbildad": "skärmbilda",
    "skärmbildade": "skärmbilda",
    "skärmbildades": "skärmbilda",
    "skärmbildads": "skärmbilda",
    "skärmbildande": "skärmbilda",
    "skärmbildanden": "skärmbildande",
    "skärmbildandena": "skärmbildande",
    "skärmbildandenas": "skärmbildande",
    "skärmbildandens": "skärmbildande",
    "skärmbildandes": "skärmbildande",
    "skärmbildandet": "skärmbildande",
    "skärmbildandets": "skärmbildande",
    "skärmbildar": "skärmbilda",
    "skärmbildas": "skärmbilda",
    "skärmbildat": "skärmbilda",
    "skärmbildats": "skärmbilda",
    "skärmbilden": "skärmbild",
    "skärmbildens": "skärmbild",
    "skärmbilder": "skärmbild",
    "skärmbilderna": "skärmbild",
    "skärmbildernas": "skärmbild",
    "skärmbilders": "skärmbild",
    "skärmbilds": "skärmbild",
    "skärmbildsundersökningar": "skärmbildsundersökning",
    "skärmbildsundersökningarna": "skärmbildsundersökning",
    "skärmbildsundersökningarnas": "skärmbildsundersökning",
    "skärmbildsundersökningars": "skärmbildsundersökning",
    "skärmbildsundersökningen": "skärmbildsundersökning",
    "skärmbildsundersökningens": "skärmbildsundersökning",
    "skärmbildsundersöknings": "skärmbildsundersökning",
    "skärmen": "skärm",
    "skärmens": "skärm",
    "skärmmöss": "skärmmössa",
    "skärmmössan": "skärmmössa",
    "skärmmössans": "skärmmössa",
    "skärmmössas": "skärmmössa",
    "skärmmösse": "skärmmössa",
    "skärmmössor": "skärmmössa",
    "skärmmössorna": "skärmmössa",
    "skärmmössornas": "skärmmössa",
    "skärmmössors": "skärmmössa",
    "skärms": "skärm",
    "skärmsläckar": "skärmsläckare",
    "skärmsläckaren": "skärmsläckare",
    "skärmsläckarens": "skärmsläckare",
    "skärmsläckares": "skärmsläckare",
    "skärmsläckarna": "skärmsläckare",
    "skärmsläckarnas": "skärmsläckare",
    "skärmytseln": "skärmytsel",
    "skärmytselns": "skärmytsel",
    "skärmytsels": "skärmytsel",
    "skärmytslar": "skärmytsel",
    "skärmytslarna": "skärmytsel",
    "skärmytslarnas": "skärmytsel",
    "skärmytslars": "skärmytsel",
    "skärmytslingar": "skärmytsling",
    "skärmytslingarna": "skärmytsling",
    "skärmytslingarnas": "skärmytsling",
    "skärmytslingars": "skärmytsling",
    "skärmytslingen": "skärmytsling",
    "skärmytslingens": "skärmytsling",
    "skärmytslings": "skärmytsling",
    "skärningar": "skärning",
    "skärningarna": "skärning",
    "skärningarnas": "skärning",
    "skärningars": "skärning",
    "skärningen": "skärning",
    "skärningens": "skärning",
    "skärnings": "skärning",
    "skärningspunkten": "skärningspunkt",
    "skärningspunktens": "skärningspunkt",
    "skärningspunkter": "skärningspunkt",
    "skärningspunkterna": "skärningspunkt",
    "skärningspunkternas": "skärningspunkt",
    "skärningspunkters": "skärningspunkt",
    "skärningspunkts": "skärningspunkt",
    "skäror": "skära",
    "skärorna": "skära",
    "skärornas": "skära",
    "skärors": "skära",
    "skärp": "skärpa",
    "skärpan": "skärpa",
    "skärpande": "skärpa",
    "skärpanden": "skärpande",
    "skärpandena": "skärpande",
    "skärpandenas": "skärpande",
    "skärpandens": "skärpande",
    "skärpandes": "skärpande",
    "skärpandet": "skärpande",
    "skärpandets": "skärpande",
    "skärpans": "skärpa",
    "skärpas": "skärpa",
    "skärpedjupen": "skärpedjup",
    "skärpedjupens": "skärpedjup",
    "skärpedjupet": "skärpedjup",
    "skärpedjupets": "skärpedjup",
    "skärpedjups": "skärpedjup",
    "skärpen": "skärp",
    "skärpens": "skärp",
    "skärper": "skärpa",
    "skärpes": "skärpa",
    "skärpet": "skärp",
    "skärpets": "skärp",
    "skärpiplärk": "skärpiplärka",
    "skärpiplärkan": "skärpiplärka",
    "skärpiplärkans": "skärpiplärka",
    "skärpiplärkas": "skärpiplärka",
    "skärpiplärke": "skärpiplärka",
    "skärpiplärkor": "skärpiplärka",
    "skärpiplärkorna": "skärpiplärka",
    "skärpiplärkornas": "skärpiplärka",
    "skärpiplärkors": "skärpiplärka",
    "skärpiplärks": "skärpiplärka",
    "skärpningar": "skärpning",
    "skärpningarna": "skärpning",
    "skärpningarnas": "skärpning",
    "skärpningars": "skärpning",
    "skärpningen": "skärpning",
    "skärpningens": "skärpning",
    "skärpnings": "skärpning",
    "skärps": "skärpa",
    "skärpt": "skärpa",
    "skärpta": "skärpt",
    "skärptare": "skärpt",
    "skärptares": "skärpt",
    "skärptas": "skärpt",
    "skärptast": "skärpt",
    "skärptaste": "skärpt",
    "skärptastes": "skärpt",
    "skärptasts": "skärpt",
    "skärpte": "skärpt",
    "skärptes": "skärpt",
    "skärptheten": "skärpthet",
    "skärpthetens": "skärpthet",
    "skärpthets": "skärpthet",
    "skärpts": "skärpt",
    "skärr": "skärra",
    "skärrad": "skärra",
    "skärrade": "skärra",
    "skärrades": "skärra",
    "skärrads": "skärra",
    "skärran": "skärra",
    "skärrande": "skärra",
    "skärranden": "skärrande",
    "skärrandena": "skärrande",
    "skärrandenas": "skärrande",
    "skärrandens": "skärrande",
    "skärrandes": "skärrande",
    "skärrandet": "skärrande",
    "skärrandets": "skärrande",
    "skärrans": "skärra",
    "skärrar": "skärra",
    "skärras": "skärra",
    "skärrat": "skärra",
    "skärrats": "skärra",
    "skärre": "skärra",
    "skärror": "skärra",
    "skärrorna": "skärra",
    "skärrornas": "skärra",
    "skärrors": "skärra",
    "skärrs": "skärra",
    "skärs": "skära",
    "skärselden": "skärseld",
    "skärseldens": "skärseld",
    "skärselds": "skärseld",
    "skärskåd": "skärskåda",
    "skärskådad": "skärskåda",
    "skärskådade": "skärskåda",
    "skärskådades": "skärskåda",
    "skärskådads": "skärskåda",
    "skärskådande": "skärskåda",
    "skärskådanden": "skärskådande",
    "skärskådandena": "skärskådande",
    "skärskådandenas": "skärskådande",
    "skärskådandens": "skärskådande",
    "skärskådandes": "skärskådande",
    "skärskådandet": "skärskådande",
    "skärskådandets": "skärskådande",
    "skärskådar": "skärskåda",
    "skärskådas": "skärskåda",
    "skärskådat": "skärskåda",
    "skärskådats": "skärskåda",
    "skärslipar": "skärslipare",
    "skärsliparen": "skärslipare",
    "skärsliparens": "skärslipare",
    "skärslipares": "skärslipare",
    "skärsliparna": "skärslipare",
    "skärsliparnas": "skärslipare",
    "skärstenen": "skärsten",
    "skärstenens": "skärsten",
    "skärstens": "skärsten",
    "skärstockar": "skärstock",
    "skärstockarna": "skärstock",
    "skärstockarnas": "skärstock",
    "skärstockars": "skärstock",
    "skärstocken": "skärstock",
    "skärstockens": "skärstock",
    "skärstocks": "skärstock",
    "skärt": "skär",
    "skärtorsdagar": "skärtorsdag",
    "skärtorsdagarna": "skärtorsdag",
    "skärtorsdagarnas": "skärtorsdag",
    "skärtorsdagars": "skärtorsdag",
    "skärtorsdagen": "skärtorsdag",
    "skärtorsdagens": "skärtorsdag",
    "skärtorsdags": "skärtorsdag",
    "skärtorven": "skärtorv",
    "skärtorvens": "skärtorv",
    "skärtorvs": "skärtorv",
    "skärts": "skär",
    "skärv": "skärva",
    "skärvad": "skärva",
    "skärvade": "skärva",
    "skärvades": "skärva",
    "skärvads": "skärva",
    "skärvan": "skärva",
    "skärvande": "skärva",
    "skärvanden": "skärvande",
    "skärvandena": "skärvande",
    "skärvandenas": "skärvande",
    "skärvandens": "skärvande",
    "skärvandes": "skärvande",
    "skärvandet": "skärvande",
    "skärvandets": "skärvande",
    "skärvans": "skärva",
    "skärvar": "skärva",
    "skärvarna": "skärv",
    "skärvarnas": "skärv",
    "skärvars": "skärv",
    "skärvas": "skärva",
    "skärvat": "skärva",
    "skärvats": "skärva",
    "skärve": "skärva",
    "skärven": "skärv",
    "skärvens": "skärv",
    "skärvfröet": "skärvfrö",
    "skärvfröets": "skärvfrö",
    "skärvfrös": "skärvfrö",
    "skärvfröt": "skärvfrö",
    "skärvfröts": "skärvfrö",
    "skärvor": "skärva",
    "skärvorna": "skärva",
    "skärvornas": "skärva",
    "skärvors": "skärva",
    "skärvs": "skärva",
    "skäviga": "skävig",
    "skävigare": "skävig",
    "skävigares": "skävig",
    "skävigas": "skävig",
    "skävigast": "skävig",
    "skävigaste": "skävig",
    "skävigastes": "skävig",
    "skävigasts": "skävig",
    "skävige": "skävig",
    "skäviges": "skävig",
    "skävigs": "skävig",
    "skävigt": "skävig",
    "skävigts": "skävig",
    "skävorna": "skävor",
    "skävornas": "skävor",
    "skävors": "skävor",
    "skådad": "skåda",
    "skådade": "skåda",
    "skådades": "skåda",
    "skådads": "skåda",
    "skådande": "skåda",
    "skådanden": "skådande",
    "skådandena": "skådande",
    "skådandenas": "skådande",
    "skådandens": "skådande",
    "skådandes": "skådande",
    "skådandet": "skådande",
    "skådandets": "skådande",
    "skådar": "skåda",
    "skådas": "skåda",
    "skådat": "skåda",
    "skådats": "skåda",
    "skåde": "skåda",
    "skådebanan": "skådebana",
    "skådebanans": "skådebana",
    "skådebanas": "skådebana",
    "skådebane": "skådebana",
    "skådebanor": "skådebana",
    "skådebanorna": "skådebana",
    "skådebanornas": "skådebana",
    "skådebanors": "skådebana",
    "skådebrödet": "skådebröd",
    "skådebrödets": "skådebröd",
    "skådebröds": "skådebröd",
    "skådemynten": "skådemynt",
    "skådemyntens": "skådemynt",
    "skådemyntet": "skådemynt",
    "skådemyntets": "skådemynt",
    "skådemynts": "skådemynt",
    "skådeplatsen": "skådeplats",
    "skådeplatsens": "skådeplats",
    "skådeplatser": "skådeplats",
    "skådeplatserna": "skådeplats",
    "skådeplatsernas": "skådeplats",
    "skådeplatsers": "skådeplats",
    "skådeprocessen": "skådeprocess",
    "skådeprocessens": "skådeprocess",
    "skådeprocesser": "skådeprocess",
    "skådeprocesserna": "skådeprocess",
    "skådeprocessernas": "skådeprocess",
    "skådeprocessers": "skådeprocess",
    "skådespelar": "skådespelare",
    "skådespelardrömmar": "skådespelardröm",
    "skådespelardrömmarna": "skådespelardröm",
    "skådespelardrömmarnas": "skådespelardröm",
    "skådespelardrömmars": "skådespelardröm",
    "skådespelardrömmen": "skådespelardröm",
    "skådespelardrömmens": "skådespelardröm",
    "skådespelardröms": "skådespelardröm",
    "skådespelaren": "skådespelare",
    "skådespelarens": "skådespelare",
    "skådespelares": "skådespelare",
    "skådespelarkonsten": "skådespelarkonst",
    "skådespelarkonstens": "skådespelarkonst",
    "skådespelarkonsts": "skådespelarkonst",
    "skådespelarmässiga": "skådespelarmässig",
    "skådespelarmässigare": "skådespelarmässig",
    "skådespelarmässigares": "skådespelarmässig",
    "skådespelarmässigas": "skådespelarmässig",
    "skådespelarmässigast": "skådespelarmässig",
    "skådespelarmässigaste": "skådespelarmässig",
    "skådespelarmässigastes": "skådespelarmässig",
    "skådespelarmässigasts": "skådespelarmässig",
    "skådespelarmässige": "skådespelarmässig",
    "skådespelarmässiges": "skådespelarmässig",
    "skådespelarmässigs": "skådespelarmässig",
    "skådespelarmässigt": "skådespelarmässig",
    "skådespelarmässigts": "skådespelarmässig",
    "skådespelarna": "skådespelare",
    "skådespelarnas": "skådespelare",
    "skådespelarparen": "skådespelarpar",
    "skådespelarparens": "skådespelarpar",
    "skådespelarparet": "skådespelarpar",
    "skådespelarparets": "skådespelarpar",
    "skådespelarpars": "skådespelarpar",
    "skådespelen": "skådespel",
    "skådespelens": "skådespel",
    "skådespeleriet": "skådespeleri",
    "skådespeleriets": "skådespeleri",
    "skådespeleris": "skådespeleri",
    "skådespelerit": "skådespeleri",
    "skådespelerits": "skådespeleri",
    "skådespelerskan": "skådespelerska",
    "skådespelerskans": "skådespelerska",
    "skådespelerskas": "skådespelerska",
    "skådespelerske": "skådespelerska",
    "skådespelerskor": "skådespelerska",
    "skådespelerskorna": "skådespelerska",
    "skådespelerskornas": "skådespelerska",
    "skådespelerskors": "skådespelerska",
    "skådespelet": "skådespel",
    "skådespelets": "skådespel",
    "skådespels": "skådespel",
    "skådisar": "skådis",
    "skådisarna": "skådis",
    "skådisarnas": "skådis",
    "skådisars": "skådis",
    "skådisen": "skådis",
    "skådisens": "skådis",
    "skål": "skåla",
    "skålad": "skåla",
    "skålade": "skåla",
    "skålades": "skåla",
    "skålads": "skåla",
    "skålande": "skåla",
    "skålanden": "skålande",
    "skålandena": "skålande",
    "skålandenas": "skålande",
    "skålandens": "skålande",
    "skålandes": "skålande",
    "skålandet": "skålande",
    "skålandets": "skålande",
    "skålar": "skåla",
    "skålarna": "skål",
    "skålarnas": "skål",
    "skålars": "skål",
    "skålas": "skåla",
    "skålat": "skåla",
    "skålats": "skåla",
    "skålen": "skål",
    "skålens": "skål",
    "skålformiga": "skålformig",
    "skålformigare": "skålformig",
    "skålformigares": "skålformig",
    "skålformigas": "skålformig",
    "skålformigast": "skålformig",
    "skålformigaste": "skålformig",
    "skålformigastes": "skålformig",
    "skålformigasts": "skålformig",
    "skålformige": "skålformig",
    "skålformiges": "skålformig",
    "skålformigheten": "skålformighet",
    "skålformighetens": "skålformighet",
    "skålformighets": "skålformighet",
    "skålformigs": "skålformig",
    "skålformigt": "skålformig",
    "skålformigts": "skålformig",
    "skålgropar": "skålgrop",
    "skålgroparna": "skålgrop",
    "skålgroparnas": "skålgrop",
    "skålgropars": "skålgrop",
    "skålgropen": "skålgrop",
    "skålgropens": "skålgrop",
    "skålgrops": "skålgrop",
    "skåliga": "skålig",
    "skåligare": "skålig",
    "skåligares": "skålig",
    "skåligas": "skålig",
    "skåligast": "skålig",
    "skåligaste": "skålig",
    "skåligastes": "skålig",
    "skåligasts": "skålig",
    "skålige": "skålig",
    "skåliges": "skålig",
    "skåligheten": "skålighet",
    "skålighetens": "skålighet",
    "skålighets": "skålighet",
    "skåligs": "skålig",
    "skåligt": "skålig",
    "skåligts": "skålig",
    "skålkorsen": "skålkors",
    "skålkorsens": "skålkors",
    "skålkorset": "skålkors",
    "skålkorsets": "skålkors",
    "skåll": "skålla",
    "skållad": "skålla",
    "skållade": "skålla",
    "skållades": "skålla",
    "skållads": "skålla",
    "skållande": "skålla",
    "skållanden": "skållande",
    "skållandena": "skållande",
    "skållandenas": "skållande",
    "skållandens": "skållande",
    "skållandes": "skållande",
    "skållandet": "skållande",
    "skållandets": "skållande",
    "skållar": "skålla",
    "skållas": "skålla",
    "skållat": "skålla",
    "skållats": "skålla",
    "skållheta": "skållhet",
    "skållhetare": "skållhet",
    "skållhetares": "skållhet",
    "skållhetas": "skållhet",
    "skållhetast": "skållhet",
    "skållhetaste": "skållhet",
    "skållhetastes": "skållhet",
    "skållhetasts": "skållhet",
    "skållhete": "skållhet",
    "skållhetes": "skållhet",
    "skållhets": "skållhet",
    "skållhett": "skållhet",
    "skållhetts": "skållhet",
    "skålpunden": "skålpund",
    "skålpundens": "skålpund",
    "skålpundet": "skålpund",
    "skålpundets": "skålpund",
    "skålpunds": "skålpund",
    "skålrosten": "skålrost",
    "skålrostens": "skålrost",
    "skålrosts": "skålrost",
    "skåls": "skål",
    "skålsnäck": "skålsnäcka",
    "skålsnäckan": "skålsnäcka",
    "skålsnäckans": "skålsnäcka",
    "skålsnäckas": "skålsnäcka",
    "skålsnäcke": "skålsnäcka",
    "skålsnäckor": "skålsnäcka",
    "skålsnäckorna": "skålsnäcka",
    "skålsnäckornas": "skålsnäcka",
    "skålsnäckors": "skålsnäcka",
    "skålsnäcks": "skålsnäcka",
    "skålsvampar": "skålsvamp",
    "skålsvamparna": "skålsvamp",
    "skålsvamparnas": "skålsvamp",
    "skålsvampars": "skålsvamp",
    "skålsvampen": "skålsvamp",
    "skålsvampens": "skålsvamp",
    "skålsvamps": "skålsvamp",
    "skåltomma": "skåltom",
    "skåltommare": "skåltom",
    "skåltommares": "skåltom",
    "skåltommas": "skåltom",
    "skåltommast": "skåltom",
    "skåltommaste": "skåltom",
    "skåltommastes": "skåltom",
    "skåltommasts": "skåltom",
    "skåltomme": "skåltom",
    "skåltommes": "skåltom",
    "skåltoms": "skåltom",
    "skåltomt": "skåltom",
    "skåltomts": "skåltom",
    "skålvirkes": "skålvirke",
    "skålvirket": "skålvirke",
    "skålvirkets": "skålvirke",
    "skånger": "skångra",
    "skångrade": "skångra",
    "skångrades": "skångra",
    "skångrande": "skångra",
    "skångranden": "skångrande",
    "skångrandena": "skångrande",
    "skångrandenas": "skångrande",
    "skångrandens": "skångrande",
    "skångrandes": "skångrande",
    "skångrandet": "skångrande",
    "skångrandets": "skångrande",
    "skångrar": "skångra",
    "skångras": "skångra",
    "skångrat": "skångra",
    "skångrats": "skångra",
    "skåningar": "skåning",
    "skåningarna": "skåning",
    "skåningarnas": "skåning",
    "skåningars": "skåning",
    "skåningen": "skåning",
    "skåningens": "skåning",
    "skånings": "skåning",
    "skånkar": "skånk",
    "skånkarna": "skånk",
    "skånkarnas": "skånk",
    "skånkars": "skånk",
    "skånken": "skånk",
    "skånkens": "skånk",
    "skånks": "skånk",
    "skånsk": "skånska",
    "skånska": "skånsk",
    "skånskan": "skånska",
    "skånskans": "skånska",
    "skånskare": "skånsk",
    "skånskares": "skånsk",
    "skånskas": "skånska",
    "skånskast": "skånsk",
    "skånskaste": "skånsk",
    "skånskastes": "skånsk",
    "skånskasts": "skånsk",
    "skånske": "skånska",
    "skånskes": "skånsk",
    "skånskheten": "skånskhet",
    "skånskhetens": "skånskhet",
    "skånskhets": "skånskhet",
    "skånskor": "skånska",
    "skånskorna": "skånska",
    "skånskornas": "skånska",
    "skånskors": "skånska",
    "skånsks": "skånsk",
    "skånskt": "skånsk",
    "skånskts": "skånsk",
    "skåpbilar": "skåpbil",
    "skåpbilarna": "skåpbil",
    "skåpbilarnas": "skåpbil",
    "skåpbilars": "skåpbil",
    "skåpbilen": "skåpbil",
    "skåpbilens": "skåpbil",
    "skåpbils": "skåpbil",
    "skåpdörrar": "skåpdörr",
    "skåpdörrarna": "skåpdörr",
    "skåpdörrarnas": "skåpdörr",
    "skåpdörrars": "skåpdörr",
    "skåpdörren": "skåpdörr",
    "skåpdörrens": "skåpdörr",
    "skåpdörrs": "skåpdörr",
    "skåpen": "skåp",
    "skåpens": "skåp",
    "skåpet": "skåp",
    "skåpets": "skåp",
    "skåpmaten": "skåpmat",
    "skåpmatens": "skåpmat",
    "skåpmats": "skåpmat",
    "skåps": "skåp",
    "skåpsup": "skåpsupa",
    "skåpsupande": "skåpsupa",
    "skåpsupanden": "skåpsupande",
    "skåpsupandena": "skåpsupande",
    "skåpsupandenas": "skåpsupande",
    "skåpsupandens": "skåpsupande",
    "skåpsupandes": "skåpsupande",
    "skåpsupandet": "skåpsupande",
    "skåpsupandets": "skåpsupande",
    "skåpsupas": "skåpsupa",
    "skåpsupe": "skåpsupa",
    "skåpsuper": "skåpsupa",
    "skåpsupes": "skåpsupa",
    "skåpsupit": "skåpsupa",
    "skåpsupits": "skåpsupa",
    "skåpsups": "skåpsupa",
    "skåpsängar": "skåpsäng",
    "skåpsängarna": "skåpsäng",
    "skåpsängarnas": "skåpsäng",
    "skåpsängars": "skåpsäng",
    "skåpsängen": "skåpsäng",
    "skåpsängens": "skåpsäng",
    "skåpsängs": "skåpsäng",
    "skåpsöp": "skåpsupa",
    "skåpsöpe": "skåpsupa",
    "skåpsöpes": "skåpsupa",
    "skåpsöps": "skåpsupa",
    "skåpvagnar": "skåpvagn",
    "skåpvagnarna": "skåpvagn",
    "skåpvagnarnas": "skåpvagn",
    "skåpvagnars": "skåpvagn",
    "skåpvagnen": "skåpvagn",
    "skåpvagnens": "skåpvagn",
    "skåpvagns": "skåpvagn",
    "skåpät": "skåpäta",
    "skåpätande": "skåpäta",
    "skåpätanden": "skåpätande",
    "skåpätandena": "skåpätande",
    "skåpätandenas": "skåpätande",
    "skåpätandens": "skåpätande",
    "skåpätandes": "skåpätande",
    "skåpätandet": "skåpätande",
    "skåpätandets": "skåpätande",
    "skåpätas": "skåpäta",
    "skåpäte": "skåpäta",
    "skåpätes": "skåpäta",
    "skåpätit": "skåpäta",
    "skåpätits": "skåpäta",
    "skåpäts": "skåpäta",
    "skåpåt": "skåpäta",
    "skåpåte": "skåpäta",
    "skåpåtes": "skåpäta",
    "skåpåts": "skåpäta",
    "skår": "skåre",
    "skårad": "skåra",
    "skårade": "skåra",
    "skårades": "skåra",
    "skårads": "skåra",
    "skåran": "skåra",
    "skårande": "skåra",
    "skåranden": "skårande",
    "skårandena": "skårande",
    "skårandenas": "skårande",
    "skårandens": "skårande",
    "skårandes": "skårande",
    "skårandet": "skårande",
    "skårandets": "skårande",
    "skårans": "skåra",
    "skårar": "skåre",
    "skårarna": "skåre",
    "skårarnas": "skåre",
    "skårars": "skåre",
    "skåras": "skåra",
    "skårat": "skåra",
    "skårats": "skåra",
    "skåre": "skåra",
    "skåren": "skåre",
    "skårens": "skåre",
    "skåres": "skåre",
    "skåret": "skår",
    "skårets": "skår",
    "skåror": "skåra",
    "skårorna": "skåra",
    "skårornas": "skåra",
    "skårors": "skåra",
    "skårs": "skåre",
    "skök": "sköka",
    "skökan": "sköka",
    "skökans": "sköka",
    "skökas": "sköka",
    "sköke": "sköka",
    "skökor": "sköka",
    "skökorna": "sköka",
    "skökornas": "sköka",
    "skökors": "sköka",
    "sköks": "sköka",
    "skölar": "sköl",
    "skölarna": "sköl",
    "skölarnas": "sköl",
    "skölars": "sköl",
    "sköldar": "sköld",
    "sköldarna": "sköld",
    "sköldarnas": "sköld",
    "sköldars": "sköld",
    "sköldborgar": "sköldborg",
    "sköldborgarna": "sköldborg",
    "sköldborgarnas": "sköldborg",
    "sköldborgars": "sköldborg",
    "sköldborgen": "sköldborg",
    "sköldborgens": "sköldborg",
    "sköldborgs": "sköldborg",
    "sköldbrosket": "sköldbrosk",
    "sköldbroskets": "sköldbrosk",
    "sköldbrosks": "sköldbrosk",
    "sköldebreven": "sköldebrev",
    "sköldebrevens": "sköldebrev",
    "sköldebrevet": "sköldebrev",
    "sköldebrevets": "sköldebrev",
    "sköldebrevs": "sköldebrev",
    "sköldemärken": "sköldemärke",
    "sköldemärkena": "sköldemärke",
    "sköldemärkenas": "sköldemärke",
    "sköldemärkens": "sköldemärke",
    "sköldemärkes": "sköldemärke",
    "sköldemärket": "sköldemärke",
    "sköldemärkets": "sköldemärke",
    "skölden": "sköld",
    "sköldens": "sköld",
    "sköldhållar": "sköldhållare",
    "sköldhållaren": "sköldhållare",
    "sköldhållarens": "sköldhållare",
    "sköldhållares": "sköldhållare",
    "sköldhållarna": "sköldhållare",
    "sköldhållarnas": "sköldhållare",
    "sköldkörtelcancern": "sköldkörtelcancer",
    "sköldkörtelcancerns": "sköldkörtelcancer",
    "sköldkörtelcancers": "sköldkörtelcancer",
    "sköldkörtelcancrar": "sköldkörtelcancer",
    "sköldkörtelcancrarna": "sköldkörtelcancer",
    "sköldkörtelcancrarnas": "sköldkörtelcancer",
    "sköldkörtelcancrars": "sköldkörtelcancer",
    "sköldkörtelhormonen": "sköldkörtelhormon",
    "sköldkörtelhormonens": "sköldkörtelhormon",
    "sköldkörtelhormoner": "sköldkörtelhormon",
    "sköldkörtelhormonerna": "sköldkörtelhormon",
    "sköldkörtelhormonernas": "sköldkörtelhormon",
    "sköldkörtelhormoners": "sköldkörtelhormon",
    "sköldkörtelhormonet": "sköldkörtelhormon",
    "sköldkörtelhormonets": "sköldkörtelhormon",
    "sköldkörtelhormons": "sköldkörtelhormon",
    "sköldkörteln": "sköldkörtel",
    "sköldkörtelns": "sköldkörtel",
    "sköldkörtels": "sköldkörtel",
    "sköldkörtlar": "sköldkörtel",
    "sköldkörtlarna": "sköldkörtel",
    "sköldkörtlarnas": "sköldkörtel",
    "sköldkörtlars": "sköldkörtel",
    "sköldlusen": "sköldlus",
    "sköldlusens": "sköldlus",
    "sköldlöss": "sköldlus",
    "sköldlössen": "sköldlus",
    "sköldlössens": "sköldlus",
    "sköldmön": "sköldmö",
    "sköldmöns": "sköldmö",
    "sköldmör": "sköldmö",
    "sköldmörna": "sköldmö",
    "sköldmörnas": "sköldmö",
    "sköldmörs": "sköldmö",
    "sköldmös": "sköldmö",
    "sköldpadd": "sköldpadda",
    "sköldpaddan": "sköldpadda",
    "sköldpaddans": "sköldpadda",
    "sköldpaddas": "sköldpadda",
    "sköldpadde": "sköldpadda",
    "sköldpadden": "sköldpadd",
    "sköldpaddens": "sköldpadd",
    "sköldpaddor": "sköldpadda",
    "sköldpaddorna": "sköldpadda",
    "sköldpaddornas": "sköldpadda",
    "sköldpaddors": "sköldpadda",
    "sköldpadds": "sköldpadda",
    "skölds": "sköld",
    "skölen": "sköl",
    "skölens": "sköl",
    "skölj": "skölja",
    "sköljande": "skölja",
    "sköljanden": "sköljande",
    "sköljandena": "sköljande",
    "sköljandenas": "sköljande",
    "sköljandens": "sköljande",
    "sköljandes": "sköljande",
    "sköljandet": "sköljande",
    "sköljandets": "sköljande",
    "sköljas": "skölja",
    "sköljd": "skölja",
    "sköljda": "skölja",
    "sköljdas": "skölja",
    "sköljde": "skölja",
    "sköljdes": "skölja",
    "sköljds": "skölja",
    "sköljer": "skölja",
    "sköljes": "skölja",
    "sköljkannan": "sköljkanna",
    "sköljkannans": "sköljkanna",
    "sköljkannas": "sköljkanna",
    "sköljkanne": "sköljkanna",
    "sköljkannor": "sköljkanna",
    "sköljkannorna": "sköljkanna",
    "sköljkannornas": "sköljkanna",
    "sköljkannors": "sköljkanna",
    "sköljkoppar": "sköljkopp",
    "sköljkopparna": "sköljkopp",
    "sköljkopparnas": "sköljkopp",
    "sköljkoppars": "sköljkopp",
    "sköljkoppen": "sköljkopp",
    "sköljkoppens": "sköljkopp",
    "sköljkopps": "sköljkopp",
    "sköljs": "skölja",
    "sköljt": "skölja",
    "sköljts": "skölja",
    "skölp": "skölpa",
    "skölpad": "skölpa",
    "skölpade": "skölpa",
    "skölpades": "skölpa",
    "skölpads": "skölpa",
    "skölpande": "skölpa",
    "skölpanden": "skölpande",
    "skölpandena": "skölpande",
    "skölpandenas": "skölpande",
    "skölpandens": "skölpande",
    "skölpandes": "skölpande",
    "skölpandet": "skölpande",
    "skölpandets": "skölpande",
    "skölpar": "skölpa",
    "skölparna": "skölp",
    "skölparnas": "skölp",
    "skölpars": "skölp",
    "skölpas": "skölpa",
    "skölpat": "skölpa",
    "skölpats": "skölpa",
    "skölpen": "skölp",
    "skölpens": "skölp",
    "skölps": "skölp",
    "sköls": "sköl",
    "skön": "sköna",
    "sköna": "skön",
    "skönade": "sköna",
    "skönades": "sköna",
    "skönandar": "skönande",
    "skönandarna": "skönande",
    "skönandarnas": "skönande",
    "skönandars": "skönande",
    "skönande": "sköna",
    "skönanden": "skönande",
    "skönandena": "skönande",
    "skönandenas": "skönande",
    "skönandens": "skönande",
    "skönandes": "skönande",
    "skönandet": "skönande",
    "skönandets": "skönande",
    "skönar": "sköna",
    "skönare": "skön",
    "skönares": "skön",
    "skönas": "sköna",
    "skönast": "skön",
    "skönaste": "skön",
    "skönastes": "skön",
    "skönasts": "skön",
    "skönat": "sköna",
    "skönats": "sköna",
    "sköne": "skön",
    "skönes": "skön",
    "skönheten": "skönhet",
    "skönhetens": "skönhet",
    "skönheter": "skönhet",
    "skönheterna": "skönhet",
    "skönheternas": "skönhet",
    "skönheters": "skönhet",
    "skönhets": "skönhet",
    "skönhetsdrottningar": "skönhetsdrottning",
    "skönhetsdrottningarna": "skönhetsdrottning",
    "skönhetsdrottningarnas": "skönhetsdrottning",
    "skönhetsdrottningars": "skönhetsdrottning",
    "skönhetsdrottningen": "skönhetsdrottning",
    "skönhetsdrottningens": "skönhetsdrottning",
    "skönhetsdrottnings": "skönhetsdrottning",
    "skönhetsfelen": "skönhetsfel",
    "skönhetsfelens": "skönhetsfel",
    "skönhetsfelet": "skönhetsfel",
    "skönhetsfelets": "skönhetsfel",
    "skönhetsfels": "skönhetsfel",
    "skönhetsfläckar": "skönhetsfläck",
    "skönhetsfläckarna": "skönhetsfläck",
    "skönhetsfläckarnas": "skönhetsfläck",
    "skönhetsfläckars": "skönhetsfläck",
    "skönhetsfläcken": "skönhetsfläck",
    "skönhetsfläckens": "skönhetsfläck",
    "skönhetsfläcks": "skönhetsfläck",
    "skönhetsidealen": "skönhetsideal",
    "skönhetsidealens": "skönhetsideal",
    "skönhetsidealet": "skönhetsideal",
    "skönhetsidealets": "skönhetsideal",
    "skönhetsideals": "skönhetsideal",
    "skönhetsmedels": "skönhetsmedel",
    "skönhetsmedlen": "skönhetsmedel",
    "skönhetsmedlens": "skönhetsmedel",
    "skönhetsmedlet": "skönhetsmedel",
    "skönhetsmedlets": "skönhetsmedel",
    "skönhetsmissar": "skönhetsmiss",
    "skönhetsmissarna": "skönhetsmiss",
    "skönhetsmissarnas": "skönhetsmiss",
    "skönhetsmissars": "skönhetsmiss",
    "skönhetsmissen": "skönhetsmiss",
    "skönhetsmissens": "skönhetsmiss",
    "skönhetsoperationen": "skönhetsoperation",
    "skönhetsoperationens": "skönhetsoperation",
    "skönhetsoperationer": "skönhetsoperation",
    "skönhetsoperationerna": "skönhetsoperation",
    "skönhetsoperationernas": "skönhetsoperation",
    "skönhetsoperationers": "skönhetsoperation",
    "skönhetsoperations": "skönhetsoperation",
    "skönhetsprisen": "skönhetspris",
    "skönhetsprisens": "skönhetspris",
    "skönhetspriser": "skönhetspris",
    "skönhetspriserna": "skönhetspris",
    "skönhetsprisernas": "skönhetspris",
    "skönhetsprisers": "skönhetspris",
    "skönhetspriset": "skönhetspris",
    "skönhetsprisets": "skönhetspris",
    "skönhetssömnen": "skönhetssömn",
    "skönhetssömnens": "skönhetssömn",
    "skönhetssömns": "skönhetssömn",
    "skönhetstävlingar": "skönhetstävling",
    "skönhetstävlingarna": "skönhetstävling",
    "skönhetstävlingarnas": "skönhetstävling",
    "skönhetstävlingars": "skönhetstävling",
    "skönhetstävlingen": "skönhetstävling",
    "skönhetstävlingens": "skönhetstävling",
    "skönhetstävlings": "skönhetstävling",
    "skönhetsupplevelsen": "skönhetsupplevelse",
    "skönhetsupplevelsens": "skönhetsupplevelse",
    "skönhetsupplevelser": "skönhetsupplevelse",
    "skönhetsupplevelserna": "skönhetsupplevelse",
    "skönhetsupplevelsernas": "skönhetsupplevelse",
    "skönhetsupplevelsers": "skönhetsupplevelse",
    "skönhetsupplevelses": "skönhetsupplevelse",
    "skönhetsvärden": "skönhetsvärde",
    "skönhetsvärdena": "skönhetsvärde",
    "skönhetsvärdenas": "skönhetsvärde",
    "skönhetsvärdens": "skönhetsvärde",
    "skönhetsvärdes": "skönhetsvärde",
    "skönhetsvärdet": "skönhetsvärde",
    "skönhetsvärdets": "skönhetsvärde",
    "skönhetsvårdar": "skönhetsvård",
    "skönhetsvårdarna": "skönhetsvård",
    "skönhetsvårdarnas": "skönhetsvård",
    "skönhetsvårdars": "skönhetsvård",
    "skönhetsvården": "skönhetsvård",
    "skönhetsvårdens": "skönhetsvård",
    "skönhetsvårds": "skönhetsvård",
    "skönj": "skönja",
    "skönjande": "skönja",
    "skönjanden": "skönjande",
    "skönjandena": "skönjande",
    "skönjandenas": "skönjande",
    "skönjandens": "skönjande",
    "skönjandes": "skönjande",
    "skönjandet": "skönjande",
    "skönjandets": "skönjande",
    "skönjas": "skönja",
    "skönjbara": "skönjbar",
    "skönjbarare": "skönjbar",
    "skönjbarares": "skönjbar",
    "skönjbaras": "skönjbar",
    "skönjbarast": "skönjbar",
    "skönjbaraste": "skönjbar",
    "skönjbarastes": "skönjbar",
    "skönjbarasts": "skönjbar",
    "skönjbare": "skönjbar",
    "skönjbares": "skönjbar",
    "skönjbarheten": "skönjbarhet",
    "skönjbarhetens": "skönjbarhet",
    "skönjbarhets": "skönjbarhet",
    "skönjbars": "skönjbar",
    "skönjbart": "skönjbar",
    "skönjbarts": "skönjbar",
    "skönjd": "skönja",
    "skönjda": "skönja",
    "skönjdas": "skönja",
    "skönjde": "skönja",
    "skönjdes": "skönja",
    "skönjds": "skönja",
    "skönjer": "skönja",
    "skönjes": "skönja",
    "skönjs": "skönja",
    "skönjt": "skönja",
    "skönjts": "skönja",
    "skönlitteraturen": "skönlitteratur",
    "skönlitteraturens": "skönlitteratur",
    "skönlitteraturs": "skönlitteratur",
    "skönlitterära": "skönlitterär",
    "skönlitterärare": "skönlitterär",
    "skönlitterärares": "skönlitterär",
    "skönlitteräras": "skönlitterär",
    "skönlitterärast": "skönlitterär",
    "skönlitteräraste": "skönlitterär",
    "skönlitterärastes": "skönlitterär",
    "skönlitterärasts": "skönlitterär",
    "skönlitteräre": "skönlitterär",
    "skönlitteräres": "skönlitterär",
    "skönlitterärs": "skönlitterär",
    "skönlitterärt": "skönlitterär",
    "skönlitterärts": "skönlitterär",
    "skönlockiga": "skönlockig",
    "skönlockigare": "skönlockig",
    "skönlockigares": "skönlockig",
    "skönlockigas": "skönlockig",
    "skönlockigast": "skönlockig",
    "skönlockigaste": "skönlockig",
    "skönlockigastes": "skönlockig",
    "skönlockigasts": "skönlockig",
    "skönlockige": "skönlockig",
    "skönlockiges": "skönlockig",
    "skönlockigheten": "skönlockighet",
    "skönlockighetens": "skönlockighet",
    "skönlockighets": "skönlockighet",
    "skönlockigs": "skönlockig",
    "skönlockigt": "skönlockig",
    "skönlockigts": "skönlockig",
    "skönmål": "skönmåla",
    "skönmålad": "skönmåla",
    "skönmålade": "skönmåla",
    "skönmålades": "skönmåla",
    "skönmålads": "skönmåla",
    "skönmålande": "skönmåla",
    "skönmålanden": "skönmålande",
    "skönmålandena": "skönmålande",
    "skönmålandenas": "skönmålande",
    "skönmålandens": "skönmålande",
    "skönmålandes": "skönmålande",
    "skönmålandet": "skönmålande",
    "skönmålandets": "skönmålande",
    "skönmålar": "skönmåla",
    "skönmålas": "skönmåla",
    "skönmålat": "skönmåla",
    "skönmålats": "skönmåla",
    "skönprosan": "skönprosa",
    "skönprosans": "skönprosa",
    "skönprosas": "skönprosa",
    "sköns": "skön",
    "skönskriften": "skönskrift",
    "skönskriftens": "skönskrift",
    "skönskrifts": "skönskrift",
    "skönskrivar": "skönskrivare",
    "skönskrivaren": "skönskrivare",
    "skönskrivarens": "skönskrivare",
    "skönskrivares": "skönskrivare",
    "skönskrivarna": "skönskrivare",
    "skönskrivarnas": "skönskrivare",
    "skönsmässiga": "skönsmässig",
    "skönsmässigare": "skönsmässig",
    "skönsmässigares": "skönsmässig",
    "skönsmässigas": "skönsmässig",
    "skönsmässigast": "skönsmässig",
    "skönsmässigaste": "skönsmässig",
    "skönsmässigastes": "skönsmässig",
    "skönsmässigasts": "skönsmässig",
    "skönsmässige": "skönsmässig",
    "skönsmässiges": "skönsmässig",
    "skönsmässigs": "skönsmässig",
    "skönsmässigt": "skönsmässig",
    "skönsmässigts": "skönsmässig",
    "skönstaxerad": "skönstaxera",
    "skönstaxerade": "skönstaxera",
    "skönstaxerades": "skönstaxera",
    "skönstaxerads": "skönstaxera",
    "skönstaxerande": "skönstaxera",
    "skönstaxeranden": "skönstaxerande",
    "skönstaxerandena": "skönstaxerande",
    "skönstaxerandenas": "skönstaxerande",
    "skönstaxerandens": "skönstaxerande",
    "skönstaxerandes": "skönstaxerande",
    "skönstaxerandet": "skönstaxerande",
    "skönstaxerandets": "skönstaxerande",
    "skönstaxerar": "skönstaxera",
    "skönstaxeras": "skönstaxera",
    "skönstaxerat": "skönstaxera",
    "skönstaxerats": "skönstaxera",
    "skönstaxerbara": "skönstaxerbar",
    "skönstaxerbarare": "skönstaxerbar",
    "skönstaxerbarares": "skönstaxerbar",
    "skönstaxerbaras": "skönstaxerbar",
    "skönstaxerbarast": "skönstaxerbar",
    "skönstaxerbaraste": "skönstaxerbar",
    "skönstaxerbarastes": "skönstaxerbar",
    "skönstaxerbarasts": "skönstaxerbar",
    "skönstaxerbare": "skönstaxerbar",
    "skönstaxerbares": "skönstaxerbar",
    "skönstaxerbarheten": "skönstaxerbarhet",
    "skönstaxerbarhetens": "skönstaxerbarhet",
    "skönstaxerbarhets": "skönstaxerbarhet",
    "skönstaxerbars": "skönstaxerbar",
    "skönstaxerbart": "skönstaxerbar",
    "skönstaxerbarts": "skönstaxerbar",
    "skönstaxeringar": "skönstaxering",
    "skönstaxeringarna": "skönstaxering",
    "skönstaxeringarnas": "skönstaxering",
    "skönstaxeringars": "skönstaxering",
    "skönstaxeringen": "skönstaxering",
    "skönstaxeringens": "skönstaxering",
    "skönstaxerings": "skönstaxering",
    "skönt": "skön",
    "sköntaxerad": "sköntaxera",
    "sköntaxerade": "sköntaxera",
    "sköntaxerades": "sköntaxera",
    "sköntaxerads": "sköntaxera",
    "sköntaxerande": "sköntaxera",
    "sköntaxeranden": "sköntaxerande",
    "sköntaxerandena": "sköntaxerande",
    "sköntaxerandenas": "sköntaxerande",
    "sköntaxerandens": "sköntaxerande",
    "sköntaxerandes": "sköntaxerande",
    "sköntaxerandet": "sköntaxerande",
    "sköntaxerandets": "sköntaxerande",
    "sköntaxerar": "sköntaxera",
    "sköntaxeras": "sköntaxera",
    "sköntaxerat": "sköntaxera",
    "sköntaxerats": "sköntaxera",
    "sköntaxerbara": "sköntaxerbar",
    "sköntaxerbarare": "sköntaxerbar",
    "sköntaxerbarares": "sköntaxerbar",
    "sköntaxerbaras": "sköntaxerbar",
    "sköntaxerbarast": "sköntaxerbar",
    "sköntaxerbaraste": "sköntaxerbar",
    "sköntaxerbarastes": "sköntaxerbar",
    "sköntaxerbarasts": "sköntaxerbar",
    "sköntaxerbare": "sköntaxerbar",
    "sköntaxerbares": "sköntaxerbar",
    "sköntaxerbarheten": "sköntaxerbarhet",
    "sköntaxerbarhetens": "sköntaxerbarhet",
    "sköntaxerbarhets": "sköntaxerbarhet",
    "sköntaxerbars": "sköntaxerbar",
    "sköntaxerbart": "sköntaxerbar",
    "sköntaxerbarts": "sköntaxerbar",
    "sköntaxeringar": "sköntaxering",
    "sköntaxeringarna": "sköntaxering",
    "sköntaxeringarnas": "sköntaxering",
    "sköntaxeringars": "sköntaxering",
    "sköntaxeringen": "sköntaxering",
    "sköntaxeringens": "sköntaxering",
    "sköntaxerings": "sköntaxering",
    "skönts": "skön",
    "skör": "sköra",
    "sköra": "skör",
    "skörad": "sköra",
    "skörade": "sköra",
    "skörades": "sköra",
    "skörads": "sköra",
    "sköran": "sköra",
    "skörande": "sköra",
    "sköranden": "skörande",
    "skörandena": "skörande",
    "skörandenas": "skörande",
    "skörandens": "skörande",
    "skörandes": "skörande",
    "skörandet": "skörande",
    "skörandets": "skörande",
    "skörans": "sköra",
    "skörar": "sköra",
    "skörare": "skör",
    "skörares": "skör",
    "sköras": "sköra",
    "skörast": "skör",
    "sköraste": "skör",
    "skörastes": "skör",
    "skörasts": "skör",
    "skörat": "sköra",
    "skörats": "sköra",
    "skörbjuggen": "skörbjugg",
    "skörbjuggens": "skörbjugg",
    "skörbjuggs": "skörbjugg",
    "skörbjuggsörten": "skörbjuggsört",
    "skörbjuggsörtens": "skörbjuggsört",
    "skörbjuggsörts": "skörbjuggsört",
    "skörd": "skörda",
    "skördad": "skörda",
    "skördade": "skörda",
    "skördades": "skörda",
    "skördads": "skörda",
    "skördande": "skörda",
    "skördanden": "skördande",
    "skördandena": "skördande",
    "skördandenas": "skördande",
    "skördandens": "skördande",
    "skördandes": "skördande",
    "skördandet": "skördande",
    "skördandets": "skördande",
    "skördar": "skörda",
    "skördarna": "skörd",
    "skördarnas": "skörd",
    "skördars": "skörd",
    "skördas": "skörda",
    "skördat": "skörda",
    "skördats": "skörda",
    "skördeanden": "skördeand",
    "skördeandens": "skördeand",
    "skördeands": "skördeand",
    "skördeenheten": "skördeenhet",
    "skördeenhetens": "skördeenhet",
    "skördeenheter": "skördeenhet",
    "skördeenheterna": "skördeenhet",
    "skördeenheternas": "skördeenhet",
    "skördeenheters": "skördeenhet",
    "skördeenhets": "skördeenhet",
    "skördemaskinen": "skördemaskin",
    "skördemaskinens": "skördemaskin",
    "skördemaskiner": "skördemaskin",
    "skördemaskinerna": "skördemaskin",
    "skördemaskinernas": "skördemaskin",
    "skördemaskiners": "skördemaskin",
    "skördemaskins": "skördemaskin",
    "skördemånaden": "skördemånad",
    "skördemånadens": "skördemånad",
    "skördemånader": "skördemånad",
    "skördemånaderna": "skördemånad",
    "skördemånadernas": "skördemånad",
    "skördemånaders": "skördemånad",
    "skördemånads": "skördemånad",
    "skörden": "skörd",
    "skördens": "skörd",
    "skördetiden": "skördetid",
    "skördetidens": "skördetid",
    "skördetider": "skördetid",
    "skördetiderna": "skördetid",
    "skördetidernas": "skördetid",
    "skördetiders": "skördetid",
    "skördetids": "skördetid",
    "skördetröskan": "skördetröska",
    "skördetröskans": "skördetröska",
    "skördetröskas": "skördetröska",
    "skördetröske": "skördetröska",
    "skördetröskor": "skördetröska",
    "skördetröskorna": "skördetröska",
    "skördetröskornas": "skördetröska",
    "skördetröskors": "skördetröska",
    "skördeuppskattningar": "skördeuppskattning",
    "skördeuppskattningarna": "skördeuppskattning",
    "skördeuppskattningarnas": "skördeuppskattning",
    "skördeuppskattningars": "skördeuppskattning",
    "skördeuppskattningen": "skördeuppskattning",
    "skördeuppskattningens": "skördeuppskattning",
    "skördeuppskattnings": "skördeuppskattning",
    "skörds": "skörd",
    "sköre": "sköra",
    "sköres": "sköre",
    "sköret": "sköre",
    "skörets": "sköre",
    "skörheten": "skörhet",
    "skörhetens": "skörhet",
    "skörhets": "skörhet",
    "skörlen": "skörl",
    "skörlens": "skörl",
    "skörlevnaden": "skörlevnad",
    "skörlevnadens": "skörlevnad",
    "skörlevnader": "skörlevnad",
    "skörlevnaderna": "skörlevnad",
    "skörlevnadernas": "skörlevnad",
    "skörlevnaders": "skörlevnad",
    "skörlevnads": "skörlevnad",
    "skörls": "skörl",
    "skörn": "skörna",
    "skörnad": "skörna",
    "skörnade": "skörna",
    "skörnades": "skörna",
    "skörnads": "skörna",
    "skörnande": "skörna",
    "skörnanden": "skörnande",
    "skörnandena": "skörnande",
    "skörnandenas": "skörnande",
    "skörnandens": "skörnande",
    "skörnandes": "skörnande",
    "skörnandet": "skörnande",
    "skörnandets": "skörnande",
    "skörnar": "skörna",
    "skörnas": "skörna",
    "skörnat": "skörna",
    "skörnats": "skörna",
    "sköror": "sköra",
    "skörorna": "sköra",
    "skörornas": "sköra",
    "skörors": "sköra",
    "skörpilar": "skörpil",
    "skörpilarna": "skörpil",
    "skörpilarnas": "skörpil",
    "skörpilars": "skörpil",
    "skörpilen": "skörpil",
    "skörpilens": "skörpil",
    "skörpils": "skörpil",
    "skörs": "sköra",
    "skört": "skör",
    "skörten": "skört",
    "skörtens": "skört",
    "skörtet": "skört",
    "skörtets": "skört",
    "skörts": "skört",
    "sköt": "sköta",
    "skötande": "sköta",
    "skötanden": "skötande",
    "skötandena": "skötande",
    "skötandenas": "skötande",
    "skötandens": "skötande",
    "skötandes": "skötande",
    "skötandet": "skötande",
    "skötandets": "skötande",
    "skötar": "skötare",
    "skötaren": "skötare",
    "skötarens": "skötare",
    "skötares": "skötare",
    "skötarna": "skötare",
    "skötarnas": "skötare",
    "skötars": "sköt",
    "skötas": "sköta",
    "skötborden": "skötbord",
    "skötbordens": "skötbord",
    "skötbordet": "skötbord",
    "skötbordets": "skötbord",
    "skötbords": "skötbord",
    "sköte": "skjuta",
    "skötebarnen": "skötebarn",
    "skötebarnens": "skötebarn",
    "skötebarnet": "skötebarn",
    "skötebarnets": "skötebarn",
    "skötebarns": "skötebarn",
    "sköten": "sköte",
    "skötena": "sköte",
    "skötenas": "sköte",
    "skötens": "sköte",
    "sköter": "sköta",
    "sköterskan": "sköterska",
    "sköterskans": "sköterska",
    "sköterskas": "sköterska",
    "sköterske": "sköterska",
    "sköterskor": "sköterska",
    "sköterskorna": "sköterska",
    "sköterskornas": "sköterska",
    "sköterskors": "sköterska",
    "skötes": "sköte",
    "skötesynden": "skötesynd",
    "skötesyndens": "skötesynd",
    "skötesynder": "skötesynd",
    "skötesynderna": "skötesynd",
    "skötesyndernas": "skötesynd",
    "skötesynders": "skötesynd",
    "skötesynds": "skötesynd",
    "skötet": "sköte",
    "skötets": "sköte",
    "skötrummen": "skötrum",
    "skötrummens": "skötrum",
    "skötrummet": "skötrum",
    "skötrummets": "skötrum",
    "skötrums": "skötrum",
    "sköts": "sköte",
    "skötsamheten": "skötsamhet",
    "skötsamhetens": "skötsamhet",
    "skötsamhets": "skötsamhet",
    "skötsamma": "skötsam",
    "skötsammare": "skötsam",
    "skötsammares": "skötsam",
    "skötsammas": "skötsam",
    "skötsammast": "skötsam",
    "skötsammaste": "skötsam",
    "skötsammastes": "skötsam",
    "skötsammasts": "skötsam",
    "skötsamme": "skötsam",
    "skötsammes": "skötsam",
    "skötsams": "skötsam",
    "skötsamt": "skötsam",
    "skötsamts": "skötsam",
    "skötseln": "skötsel",
    "skötselns": "skötsel",
    "skötsels": "skötsel",
    "skött": "sköta",
    "skötta": "sköta",
    "sköttas": "sköta",
    "skötte": "sköta",
    "sköttes": "sköta",
    "skötts": "sköta",
    "skövel": "skövla",
    "skövlad": "skövla",
    "skövlade": "skövla",
    "skövlades": "skövla",
    "skövlads": "skövla",
    "skövlande": "skövla",
    "skövlanden": "skövlande",
    "skövlandena": "skövlande",
    "skövlandenas": "skövlande",
    "skövlandens": "skövlande",
    "skövlandes": "skövlande",
    "skövlandet": "skövlande",
    "skövlandets": "skövlande",
    "skövlar": "skövla",
    "skövlas": "skövla",
    "skövlat": "skövla",
    "skövlats": "skövla",
    "slabb": "slabba",
    "slabba": "slabb",
    "slabbad": "slabba",
    "slabbade": "slabba",
    "slabbades": "slabba",
    "slabbads": "slabba",
    "slabbande": "slabba",
    "slabbanden": "slabbande",
    "slabbandena": "slabbande",
    "slabbandenas": "slabbande",
    "slabbandens": "slabbande",
    "slabbandes": "slabbande",
    "slabbandet": "slabbande",
    "slabbandets": "slabbande",
    "slabbar": "slabba",
    "slabbare": "slabb",
    "slabbares": "slabb",
    "slabbas": "slabba",
    "slabbast": "slabb",
    "slabbaste": "slabb",
    "slabbastes": "slabb",
    "slabbasts": "slabb",
    "slabbat": "slabba",
    "slabbats": "slabba",
    "slabbe": "slabb",
    "slabber": "slabbra",
    "slabbertack": "slabbertacka",
    "slabbertackan": "slabbertacka",
    "slabbertackans": "slabbertacka",
    "slabbertackas": "slabbertacka",
    "slabbertacke": "slabbertacka",
    "slabbertackor": "slabbertacka",
    "slabbertackorna": "slabbertacka",
    "slabbertackornas": "slabbertacka",
    "slabbertackors": "slabbertacka",
    "slabbertacks": "slabbertacka",
    "slabbes": "slabb",
    "slabbet": "slabb",
    "slabbets": "slabb",
    "slabbheten": "slabbhet",
    "slabbhetens": "slabbhet",
    "slabbhets": "slabbhet",
    "slabbiga": "slabbig",
    "slabbigare": "slabbig",
    "slabbigares": "slabbig",
    "slabbigas": "slabbig",
    "slabbigast": "slabbig",
    "slabbigaste": "slabbig",
    "slabbigastes": "slabbig",
    "slabbigasts": "slabbig",
    "slabbige": "slabbig",
    "slabbiges": "slabbig",
    "slabbigheten": "slabbighet",
    "slabbighetens": "slabbighet",
    "slabbighets": "slabbighet",
    "slabbigs": "slabbig",
    "slabbigt": "slabbig",
    "slabbigts": "slabbig",
    "slabbkist": "slabbkista",
    "slabbkistan": "slabbkista",
    "slabbkistans": "slabbkista",
    "slabbkistas": "slabbkista",
    "slabbkiste": "slabbkista",
    "slabbkistor": "slabbkista",
    "slabbkistorna": "slabbkista",
    "slabbkistornas": "slabbkista",
    "slabbkistors": "slabbkista",
    "slabbrade": "slabbra",
    "slabbrades": "slabbra",
    "slabbrande": "slabbra",
    "slabbranden": "slabbrande",
    "slabbrandena": "slabbrande",
    "slabbrandenas": "slabbrande",
    "slabbrandens": "slabbrande",
    "slabbrandes": "slabbrande",
    "slabbrandet": "slabbrande",
    "slabbrandets": "slabbrande",
    "slabbrar": "slabbra",
    "slabbras": "slabbra",
    "slabbrat": "slabbra",
    "slabbrats": "slabbra",
    "slabbs": "slabb",
    "slabbt": "slabb",
    "slabbts": "slabb",
    "slack": "slacka",
    "slacka": "slack",
    "slackad": "slacka",
    "slackade": "slacka",
    "slackades": "slacka",
    "slackads": "slacka",
    "slackande": "slacka",
    "slackanden": "slackande",
    "slackandena": "slackande",
    "slackandenas": "slackande",
    "slackandens": "slackande",
    "slackandes": "slackande",
    "slackandet": "slackande",
    "slackandets": "slackande",
    "slackar": "slacka",
    "slackare": "slack",
    "slackares": "slack",
    "slackas": "slacka",
    "slackast": "slack",
    "slackaste": "slack",
    "slackastes": "slack",
    "slackasts": "slack",
    "slackat": "slacka",
    "slackats": "slacka",
    "slacke": "slack",
    "slackes": "slack",
    "slacket": "slack",
    "slackets": "slack",
    "slackheten": "slackhet",
    "slackhetens": "slackhet",
    "slackhets": "slackhet",
    "slacks": "slack",
    "slacksen": "slacks",
    "slacksens": "slacks",
    "slackt": "slack",
    "slackts": "slack",
    "sladd": "sladda",
    "sladdad": "sladda",
    "sladdade": "sladda",
    "sladdades": "sladda",
    "sladdads": "sladda",
    "sladdande": "sladda",
    "sladdanden": "sladdande",
    "sladdandena": "sladdande",
    "sladdandenas": "sladdande",
    "sladdandens": "sladdande",
    "sladdandes": "sladdande",
    "sladdandet": "sladdande",
    "sladdandets": "sladdande",
    "sladdar": "sladda",
    "sladdarna": "sladd",
    "sladdarnas": "sladd",
    "sladdars": "sladd",
    "sladdas": "sladda",
    "sladdat": "sladda",
    "sladdats": "sladda",
    "sladdbarnen": "sladdbarn",
    "sladdbarnens": "sladdbarn",
    "sladdbarnet": "sladdbarn",
    "sladdbarnets": "sladdbarn",
    "sladdbarns": "sladdbarn",
    "sladden": "sladd",
    "sladdens": "sladd",
    "sladder": "sladdra",
    "sladders": "sladder",
    "sladdhållar": "sladdhållare",
    "sladdhållaren": "sladdhållare",
    "sladdhållarens": "sladdhållare",
    "sladdhållares": "sladdhållare",
    "sladdhållarna": "sladdhållare",
    "sladdhållarnas": "sladdhållare",
    "sladdiga": "sladdig",
    "sladdigare": "sladdig",
    "sladdigares": "sladdig",
    "sladdigas": "sladdig",
    "sladdigast": "sladdig",
    "sladdigaste": "sladdig",
    "sladdigastes": "sladdig",
    "sladdigasts": "sladdig",
    "sladdige": "sladdig",
    "sladdiges": "sladdig",
    "sladdigheten": "sladdighet",
    "sladdighetens": "sladdighet",
    "sladdighets": "sladdighet",
    "sladdigs": "sladdig",
    "sladdigt": "sladdig",
    "sladdigts": "sladdig",
    "sladdklämman": "sladdklämma",
    "sladdklämmans": "sladdklämma",
    "sladdklämmas": "sladdklämma",
    "sladdklämme": "sladdklämma",
    "sladdklämmor": "sladdklämma",
    "sladdklämmorna": "sladdklämma",
    "sladdklämmornas": "sladdklämma",
    "sladdklämmors": "sladdklämma",
    "sladdlamp": "sladdlampa",
    "sladdlampan": "sladdlampa",
    "sladdlampans": "sladdlampa",
    "sladdlampas": "sladdlampa",
    "sladdlampe": "sladdlampa",
    "sladdlampor": "sladdlampa",
    "sladdlamporna": "sladdlampa",
    "sladdlampornas": "sladdlampa",
    "sladdlampors": "sladdlampa",
    "sladdlamps": "sladdlampa",
    "sladdrade": "sladdra",
    "sladdrades": "sladdra",
    "sladdrande": "sladdra",
    "sladdranden": "sladdrande",
    "sladdrandena": "sladdrande",
    "sladdrandenas": "sladdrande",
    "sladdrandens": "sladdrande",
    "sladdrandes": "sladdrande",
    "sladdrandet": "sladdrande",
    "sladdrandets": "sladdrande",
    "sladdrar": "sladdra",
    "sladdras": "sladdra",
    "sladdrat": "sladdra",
    "sladdrats": "sladdra",
    "sladdret": "sladder",
    "sladdrets": "sladder",
    "sladdriga": "sladdrig",
    "sladdrigare": "sladdrig",
    "sladdrigares": "sladdrig",
    "sladdrigas": "sladdrig",
    "sladdrigast": "sladdrig",
    "sladdrigaste": "sladdrig",
    "sladdrigastes": "sladdrig",
    "sladdrigasts": "sladdrig",
    "sladdrige": "sladdrig",
    "sladdriges": "sladdrig",
    "sladdrigheten": "sladdrighet",
    "sladdrighetens": "sladdrighet",
    "sladdrighets": "sladdrighet",
    "sladdrigs": "sladdrig",
    "sladdrigt": "sladdrig",
    "sladdrigts": "sladdrig",
    "sladds": "sladd",
    "slaf": "slafa",
    "slafad": "slafa",
    "slafade": "slafa",
    "slafades": "slafa",
    "slafads": "slafa",
    "slafande": "slafa",
    "slafanden": "slafande",
    "slafandena": "slafande",
    "slafandenas": "slafande",
    "slafandens": "slafande",
    "slafandes": "slafande",
    "slafandet": "slafande",
    "slafandets": "slafande",
    "slafar": "slafa",
    "slafarna": "slaf",
    "slafarnas": "slaf",
    "slafars": "slaf",
    "slafas": "slafa",
    "slafat": "slafa",
    "slafats": "slafa",
    "slafen": "slaf",
    "slafens": "slaf",
    "slafs": "slafsa",
    "slafsad": "slafsa",
    "slafsade": "slafsa",
    "slafsades": "slafsa",
    "slafsads": "slafsa",
    "slafsan": "slafsa",
    "slafsande": "slafsa",
    "slafsanden": "slafsande",
    "slafsandena": "slafsande",
    "slafsandenas": "slafsande",
    "slafsandens": "slafsande",
    "slafsandes": "slafsande",
    "slafsandet": "slafsande",
    "slafsandets": "slafsande",
    "slafsans": "slafsa",
    "slafsar": "slafsa",
    "slafsarna": "slafs",
    "slafsarnas": "slafs",
    "slafsars": "slafs",
    "slafsas": "slafsa",
    "slafsat": "slafsa",
    "slafsats": "slafsa",
    "slafse": "slafsa",
    "slafsen": "slafs",
    "slafsens": "slafs",
    "slafset": "slafs",
    "slafsets": "slafs",
    "slafsiga": "slafsig",
    "slafsigare": "slafsig",
    "slafsigares": "slafsig",
    "slafsigas": "slafsig",
    "slafsigast": "slafsig",
    "slafsigaste": "slafsig",
    "slafsigastes": "slafsig",
    "slafsigasts": "slafsig",
    "slafsige": "slafsig",
    "slafsiges": "slafsig",
    "slafsigheten": "slafsighet",
    "slafsighetens": "slafsighet",
    "slafsighets": "slafsighet",
    "slafsigs": "slafsig",
    "slafsigt": "slafsig",
    "slafsigts": "slafsig",
    "slafsor": "slafsa",
    "slafsorna": "slafsa",
    "slafsornas": "slafsa",
    "slafsors": "slafsa",
    "slag": "slaga",
    "slagan": "slaga",
    "slaganfallen": "slaganfall",
    "slaganfallens": "slaganfall",
    "slaganfallet": "slaganfall",
    "slaganfallets": "slaganfall",
    "slaganfalls": "slaganfall",
    "slaganfallspatienten": "slaganfallspatient",
    "slaganfallspatientens": "slaganfallspatient",
    "slaganfallspatienter": "slaganfallspatient",
    "slaganfallspatienterna": "slaganfallspatient",
    "slaganfallspatienternas": "slaganfallspatient",
    "slaganfallspatienters": "slaganfallspatient",
    "slaganfallspatients": "slaganfallspatient",
    "slagans": "slaga",
    "slagas": "slaga",
    "slagbjörnar": "slagbjörn",
    "slagbjörnarna": "slagbjörn",
    "slagbjörnarnas": "slagbjörn",
    "slagbjörnars": "slagbjörn",
    "slagbjörnen": "slagbjörn",
    "slagbjörnens": "slagbjörn",
    "slagbjörns": "slagbjörn",
    "slagbommar": "slagbom",
    "slagbommarna": "slagbom",
    "slagbommarnas": "slagbom",
    "slagbommars": "slagbom",
    "slagbommen": "slagbom",
    "slagbommens": "slagbom",
    "slagboms": "slagbom",
    "slagborden": "slagbord",
    "slagbordens": "slagbord",
    "slagbordet": "slagbord",
    "slagbordets": "slagbord",
    "slagbords": "slagbord",
    "slagborrar": "slagborr",
    "slagborrarna": "slagborr",
    "slagborrarnas": "slagborr",
    "slagborrars": "slagborr",
    "slagborren": "slagborr",
    "slagborrens": "slagborr",
    "slagborrs": "slagborr",
    "slagdäng": "slagdänga",
    "slagdängan": "slagdänga",
    "slagdängans": "slagdänga",
    "slagdängas": "slagdänga",
    "slagdänge": "slagdänga",
    "slagdängor": "slagdänga",
    "slagdängorna": "slagdänga",
    "slagdängornas": "slagdänga",
    "slagdängors": "slagdänga",
    "slagdängs": "slagdänga",
    "slage": "slaga",
    "slagen": "slag",
    "slagens": "slag",
    "slaget": "slag",
    "slagets": "slag",
    "slagfjädern": "slagfjäder",
    "slagfjäderns": "slagfjäder",
    "slagfjäders": "slagfjäder",
    "slagfjädrar": "slagfjäder",
    "slagfjädrarna": "slagfjäder",
    "slagfjädrarnas": "slagfjäder",
    "slagfjädrars": "slagfjäder",
    "slagfälten": "slagfält",
    "slagfältens": "slagfält",
    "slagfältet": "slagfält",
    "slagfältets": "slagfält",
    "slagfälts": "slagfält",
    "slagfärdiga": "slagfärdig",
    "slagfärdigare": "slagfärdig",
    "slagfärdigares": "slagfärdig",
    "slagfärdigas": "slagfärdig",
    "slagfärdigast": "slagfärdig",
    "slagfärdigaste": "slagfärdig",
    "slagfärdigastes": "slagfärdig",
    "slagfärdigasts": "slagfärdig",
    "slagfärdige": "slagfärdig",
    "slagfärdiges": "slagfärdig",
    "slagfärdigheten": "slagfärdighet",
    "slagfärdighetens": "slagfärdighet",
    "slagfärdighets": "slagfärdighet",
    "slagfärdigs": "slagfärdig",
    "slagfärdigt": "slagfärdig",
    "slagfärdigts": "slagfärdig",
    "slagg": "slagga",
    "slaggad": "slagga",
    "slaggade": "slagga",
    "slaggades": "slagga",
    "slaggads": "slagga",
    "slaggande": "slagga",
    "slagganden": "slaggande",
    "slaggandena": "slaggande",
    "slaggandenas": "slaggande",
    "slaggandens": "slaggande",
    "slaggandes": "slaggande",
    "slaggandet": "slaggande",
    "slaggandets": "slaggande",
    "slaggar": "slagga",
    "slaggas": "slagga",
    "slaggat": "slagga",
    "slaggats": "slagga",
    "slaggen": "slagg",
    "slaggens": "slagg",
    "slagger": "slagg",
    "slaggerna": "slagg",
    "slaggernas": "slagg",
    "slaggers": "slagg",
    "slagget": "slagg",
    "slaggets": "slagg",
    "slaggfärskningar": "slaggfärskning",
    "slaggfärskningarna": "slaggfärskning",
    "slaggfärskningarnas": "slaggfärskning",
    "slaggfärskningars": "slaggfärskning",
    "slaggfärskningen": "slaggfärskning",
    "slaggfärskningens": "slaggfärskning",
    "slaggfärsknings": "slaggfärskning",
    "slaggiga": "slaggig",
    "slaggigare": "slaggig",
    "slaggigares": "slaggig",
    "slaggigas": "slaggig",
    "slaggigast": "slaggig",
    "slaggigaste": "slaggig",
    "slaggigastes": "slaggig",
    "slaggigasts": "slaggig",
    "slaggige": "slaggig",
    "slaggiges": "slaggig",
    "slaggigheten": "slaggighet",
    "slaggighetens": "slaggighet",
    "slaggighets": "slaggighet",
    "slaggigs": "slaggig",
    "slaggigt": "slaggig",
    "slaggigts": "slaggig",
    "slaggmängden": "slaggmängd",
    "slaggmängdens": "slaggmängd",
    "slaggmängder": "slaggmängd",
    "slaggmängderna": "slaggmängd",
    "slaggmängdernas": "slaggmängd",
    "slaggmängders": "slaggmängd",
    "slaggmängds": "slaggmängd",
    "slaggs": "slagg",
    "slaghökar": "slaghök",
    "slaghökarna": "slaghök",
    "slaghökarnas": "slaghök",
    "slaghökars": "slaghök",
    "slaghöken": "slaghök",
    "slaghökens": "slaghök",
    "slaghöks": "slaghök",
    "slaginstrumenten": "slaginstrument",
    "slaginstrumentens": "slaginstrument",
    "slaginstrumentet": "slaginstrument",
    "slaginstrumentets": "slaginstrument",
    "slaginstruments": "slaginstrument",
    "slagit": "slå",
    "slagits": "slåss",
    "slagkraften": "slagkraft",
    "slagkraftens": "slagkraft",
    "slagkraftiga": "slagkraftig",
    "slagkraftigare": "slagkraftig",
    "slagkraftigares": "slagkraftig",
    "slagkraftigas": "slagkraftig",
    "slagkraftigast": "slagkraftig",
    "slagkraftigaste": "slagkraftig",
    "slagkraftigastes": "slagkraftig",
    "slagkraftigasts": "slagkraftig",
    "slagkraftige": "slagkraftig",
    "slagkraftiges": "slagkraftig",
    "slagkraftigheten": "slagkraftighet",
    "slagkraftighetens": "slagkraftighet",
    "slagkraftighets": "slagkraftighet",
    "slagkraftigs": "slagkraftig",
    "slagkraftigt": "slagkraftig",
    "slagkraftigts": "slagkraftig",
    "slagkrafts": "slagkraft",
    "slaglodet": "slaglod",
    "slaglodets": "slaglod",
    "slaglods": "slaglod",
    "slaglängden": "slaglängd",
    "slaglängdens": "slaglängd",
    "slaglängder": "slaglängd",
    "slaglängderna": "slaglängd",
    "slaglängdernas": "slaglängd",
    "slaglängders": "slaglängd",
    "slaglängds": "slaglängd",
    "slagmasken": "slagmask",
    "slagmaskens": "slagmask",
    "slagmasker": "slagmask",
    "slagmaskerna": "slagmask",
    "slagmaskernas": "slagmask",
    "slagmaskers": "slagmask",
    "slagmasks": "slagmask",
    "slagna": "slå",
    "slagnas": "slå",
    "slagne": "slå",
    "slagnes": "slå",
    "slagnummerna": "slagnummer",
    "slagnummernas": "slagnummer",
    "slagnummers": "slagnummer",
    "slagnumren": "slagnummer",
    "slagnumrens": "slagnummer",
    "slagnumret": "slagnummer",
    "slagnumrets": "slagnummer",
    "slagor": "slaga",
    "slagorden": "slagord",
    "slagordens": "slagord",
    "slagordet": "slagord",
    "slagordets": "slagord",
    "slagordningar": "slagordning",
    "slagordningarna": "slagordning",
    "slagordningarnas": "slagordning",
    "slagordningars": "slagordning",
    "slagordningen": "slagordning",
    "slagordningens": "slagordning",
    "slagordnings": "slagordning",
    "slagords": "slagord",
    "slagordsmässiga": "slagordsmässig",
    "slagordsmässigare": "slagordsmässig",
    "slagordsmässigares": "slagordsmässig",
    "slagordsmässigas": "slagordsmässig",
    "slagordsmässigast": "slagordsmässig",
    "slagordsmässigaste": "slagordsmässig",
    "slagordsmässigastes": "slagordsmässig",
    "slagordsmässigasts": "slagordsmässig",
    "slagordsmässige": "slagordsmässig",
    "slagordsmässiges": "slagordsmässig",
    "slagordsmässigheten": "slagordsmässighet",
    "slagordsmässighetens": "slagordsmässighet",
    "slagordsmässighets": "slagordsmässighet",
    "slagordsmässigs": "slagordsmässig",
    "slagordsmässigt": "slagordsmässig",
    "slagordsmässigts": "slagordsmässig",
    "slagorna": "slaga",
    "slagornas": "slaga",
    "slagors": "slaga",
    "slagpås": "slagpåse",
    "slagpåsar": "slagpåse",
    "slagpåsarna": "slagpåse",
    "slagpåsarnas": "slagpåse",
    "slagpåsars": "slagpåse",
    "slagpåsen": "slagpåse",
    "slagpåsens": "slagpåse",
    "slagpåses": "slagpåse",
    "slagregnen": "slagregn",
    "slagregnens": "slagregn",
    "slagregnet": "slagregn",
    "slagregnets": "slagregn",
    "slagregns": "slagregn",
    "slagrodden": "slagrodd",
    "slagroddens": "slagrodd",
    "slagrodds": "slagrodd",
    "slagrutan": "slagruta",
    "slagrutans": "slagruta",
    "slagrutas": "slagruta",
    "slagrute": "slagruta",
    "slagrutor": "slagruta",
    "slagrutorna": "slagruta",
    "slagrutornas": "slagruta",
    "slagrutors": "slagruta",
    "slagrörda": "slagrörd",
    "slagrördare": "slagrörd",
    "slagrördares": "slagrörd",
    "slagrördas": "slagrörd",
    "slagrördast": "slagrörd",
    "slagrördaste": "slagrörd",
    "slagrördastes": "slagrörd",
    "slagrördasts": "slagrörd",
    "slagrörde": "slagrörd",
    "slagrördes": "slagrörd",
    "slagrörds": "slagrörd",
    "slagrört": "slagrörd",
    "slagrörts": "slagrörd",
    "slags": "slaga",
    "slagsegheten": "slagseghet",
    "slagseghetens": "slagseghet",
    "slagsegheter": "slagseghet",
    "slagsegheterna": "slagseghet",
    "slagsegheternas": "slagseghet",
    "slagsegheters": "slagseghet",
    "slagseghets": "slagseghet",
    "slagsidan": "slagsida",
    "slagsidans": "slagsida",
    "slagsidas": "slagsida",
    "slagskatten": "slagskatt",
    "slagskattens": "slagskatt",
    "slagskatter": "slagskatt",
    "slagskatterna": "slagskatt",
    "slagskatternas": "slagskatt",
    "slagskatters": "slagskatt",
    "slagskatts": "slagskatt",
    "slagskeppen": "slagskepp",
    "slagskeppens": "slagskepp",
    "slagskeppet": "slagskepp",
    "slagskeppets": "slagskepp",
    "slagskepps": "slagskepp",
    "slagskeppsmatrosen": "slagskeppsmatros",
    "slagskeppsmatrosens": "slagskeppsmatros",
    "slagskeppsmatroser": "slagskeppsmatros",
    "slagskeppsmatroserna": "slagskeppsmatros",
    "slagskeppsmatrosernas": "slagskeppsmatros",
    "slagskeppsmatrosers": "slagskeppsmatros",
    "slagskugg": "slagskugga",
    "slagskuggan": "slagskugga",
    "slagskuggans": "slagskugga",
    "slagskuggas": "slagskugga",
    "slagskugge": "slagskugga",
    "slagskuggor": "slagskugga",
    "slagskuggorna": "slagskugga",
    "slagskuggornas": "slagskugga",
    "slagskuggors": "slagskugga",
    "slagskuggs": "slagskugga",
    "slagskämpar": "slagskämpe",
    "slagskämparna": "slagskämpe",
    "slagskämparnas": "slagskämpe",
    "slagskämpars": "slagskämpe",
    "slagskämpen": "slagskämpe",
    "slagskämpens": "slagskämpe",
    "slagskämpes": "slagskämpe",
    "slagsmålen": "slagsmål",
    "slagsmålens": "slagsmål",
    "slagsmålet": "slagsmål",
    "slagsmålets": "slagsmål",
    "slagsmåls": "slagsmål",
    "slagsvärden": "slagsvärd",
    "slagsvärdens": "slagsvärd",
    "slagsvärdet": "slagsvärd",
    "slagsvärdets": "slagsvärd",
    "slagsvärds": "slagsvärd",
    "slagträet": "slagträ",
    "slagträets": "slagträ",
    "slagträn": "slagträ",
    "slagträna": "slagträ",
    "slagtränas": "slagträ",
    "slagträns": "slagträ",
    "slagträs": "slagträ",
    "slagträt": "slagträ",
    "slagträts": "slagträ",
    "slagtåliga": "slagtålig",
    "slagtåligare": "slagtålig",
    "slagtåligares": "slagtålig",
    "slagtåligas": "slagtålig",
    "slagtåligast": "slagtålig",
    "slagtåligaste": "slagtålig",
    "slagtåligastes": "slagtålig",
    "slagtåligasts": "slagtålig",
    "slagtålige": "slagtålig",
    "slagtåliges": "slagtålig",
    "slagtåligheten": "slagtålighet",
    "slagtålighetens": "slagtålighet",
    "slagtålighets": "slagtålighet",
    "slagtåligs": "slagtålig",
    "slagtåligt": "slagtålig",
    "slagtåligts": "slagtålig",
    "slagugglan": "slaguggla",
    "slagugglans": "slaguggla",
    "slagugglas": "slaguggla",
    "slaguggle": "slaguggla",
    "slagugglor": "slaguggla",
    "slagugglorna": "slaguggla",
    "slagugglornas": "slaguggla",
    "slagugglors": "slaguggla",
    "slagvapens": "slagvapen",
    "slagvapnen": "slagvapen",
    "slagvapnens": "slagvapen",
    "slagvapnet": "slagvapen",
    "slagvapnets": "slagvapen",
    "slagvattens": "slagvatten",
    "slagvattnet": "slagvatten",
    "slagvattnets": "slagvatten",
    "slagverken": "slagverk",
    "slagverkens": "slagverk",
    "slagverket": "slagverk",
    "slagverkets": "slagverk",
    "slagverks": "slagverk",
    "slagvolymen": "slagvolym",
    "slagvolymens": "slagvolym",
    "slagvolyms": "slagvolym",
    "slagväxlingar": "slagväxling",
    "slagväxlingarna": "slagväxling",
    "slagväxlingarnas": "slagväxling",
    "slagväxlingars": "slagväxling",
    "slagväxlingen": "slagväxling",
    "slagväxlingens": "slagväxling",
    "slagväxlings": "slagväxling",
    "slagäntringar": "slagäntring",
    "slagäntringarna": "slagäntring",
    "slagäntringarnas": "slagäntring",
    "slagäntringars": "slagäntring",
    "slagäntringen": "slagäntring",
    "slagäntringens": "slagäntring",
    "slagäntrings": "slagäntring",
    "slak": "slaka",
    "slaka": "slak",
    "slakad": "slaka",
    "slakade": "slaka",
    "slakades": "slaka",
    "slakads": "slaka",
    "slakande": "slaka",
    "slakanden": "slakande",
    "slakandena": "slakande",
    "slakandenas": "slakande",
    "slakandens": "slakande",
    "slakandes": "slakande",
    "slakandet": "slakande",
    "slakandets": "slakande",
    "slakar": "slaka",
    "slakare": "slak",
    "slakares": "slak",
    "slakas": "slaka",
    "slakast": "slak",
    "slakaste": "slak",
    "slakastes": "slak",
    "slakasts": "slak",
    "slakat": "slaka",
    "slakats": "slaka",
    "slake": "slak",
    "slakes": "slak",
    "slakheten": "slakhet",
    "slakhetens": "slakhet",
    "slakhets": "slakhet",
    "slakn": "slakna",
    "slaknad": "slakna",
    "slaknade": "slakna",
    "slaknades": "slakna",
    "slaknads": "slakna",
    "slaknande": "slakna",
    "slaknanden": "slaknande",
    "slaknandena": "slaknande",
    "slaknandenas": "slaknande",
    "slaknandens": "slaknande",
    "slaknandes": "slaknande",
    "slaknandet": "slaknande",
    "slaknandets": "slaknande",
    "slaknar": "slakna",
    "slaknas": "slakna",
    "slaknat": "slakna",
    "slaknats": "slakna",
    "slaks": "slak",
    "slaksidan": "slaksida",
    "slaksidans": "slaksida",
    "slaksidas": "slaksida",
    "slakt": "slakta",
    "slaktad": "slakta",
    "slaktade": "slakta",
    "slaktades": "slakta",
    "slaktads": "slakta",
    "slaktande": "slakta",
    "slaktanden": "slaktande",
    "slaktandena": "slaktande",
    "slaktandenas": "slaktande",
    "slaktandens": "slaktande",
    "slaktandes": "slaktande",
    "slaktandet": "slaktande",
    "slaktandets": "slaktande",
    "slaktar": "slaktare",
    "slaktaren": "slaktare",
    "slaktarens": "slaktare",
    "slaktares": "slaktare",
    "slaktarna": "slaktare",
    "slaktarnas": "slaktare",
    "slaktas": "slakta",
    "slaktat": "slakta",
    "slaktats": "slakta",
    "slaktdjuren": "slaktdjur",
    "slaktdjurens": "slaktdjur",
    "slaktdjuret": "slaktdjur",
    "slaktdjurets": "slaktdjur",
    "slaktdjurs": "slaktdjur",
    "slakten": "slakt",
    "slaktens": "slakt",
    "slakter": "slakt",
    "slakterier": "slakteri",
    "slakterierna": "slakteri",
    "slakteriernas": "slakteri",
    "slakteriers": "slakteri",
    "slakteriet": "slakteri",
    "slakteriets": "slakteri",
    "slakteris": "slakteri",
    "slakterit": "slakteri",
    "slakterits": "slakteri",
    "slakterna": "slakt",
    "slakternas": "slakt",
    "slakters": "slakt",
    "slakthusen": "slakthus",
    "slakthusens": "slakthus",
    "slakthuset": "slakthus",
    "slakthusets": "slakthus",
    "slaktmasken": "slaktmask",
    "slaktmaskens": "slaktmask",
    "slaktmasker": "slaktmask",
    "slaktmaskerna": "slaktmask",
    "slaktmaskernas": "slaktmask",
    "slaktmaskers": "slaktmask",
    "slaktmasks": "slaktmask",
    "slaktmånaden": "slaktmånad",
    "slaktmånadens": "slaktmånad",
    "slaktmånader": "slaktmånad",
    "slaktmånaderna": "slaktmånad",
    "slaktmånadernas": "slaktmånad",
    "slaktmånaders": "slaktmånad",
    "slaktmånads": "slaktmånad",
    "slaktoffers": "slaktoffer",
    "slaktoffren": "slaktoffer",
    "slaktoffrens": "slaktoffer",
    "slaktoffret": "slaktoffer",
    "slaktoffrets": "slaktoffer",
    "slakts": "slakt",
    "slaktvikten": "slaktvikt",
    "slaktviktens": "slaktvikt",
    "slaktvikts": "slaktvikt",
    "slalomen": "slalom",
    "slalomens": "slalom",
    "slaloms": "slalom",
    "slalomskid": "slalomskida",
    "slalomskidan": "slalomskida",
    "slalomskidans": "slalomskida",
    "slalomskidas": "slalomskida",
    "slalomskide": "slalomskida",
    "slalomskidor": "slalomskida",
    "slalomskidorna": "slalomskida",
    "slalomskidornas": "slalomskida",
    "slalomskidors": "slalomskida",
    "slalomskids": "slalomskida",
    "slalomåkar": "slalomåkare",
    "slalomåkaren": "slalomåkare",
    "slalomåkarens": "slalomåkare",
    "slalomåkares": "slalomåkare",
    "slalomåkarna": "slalomåkare",
    "slalomåkarnas": "slalomåkare",
    "slamflug": "slamfluga",
    "slamflugan": "slamfluga",
    "slamflugans": "slamfluga",
    "slamflugas": "slamfluga",
    "slamfluge": "slamfluga",
    "slamflugor": "slamfluga",
    "slamflugorna": "slamfluga",
    "slamflugornas": "slamfluga",
    "slamflugors": "slamfluga",
    "slamflugs": "slamfluga",
    "slamfärgen": "slamfärg",
    "slamfärgens": "slamfärg",
    "slamfärgs": "slamfärg",
    "slamkrypar": "slamkrypare",
    "slamkryparen": "slamkrypare",
    "slamkryparens": "slamkrypare",
    "slamkrypares": "slamkrypare",
    "slamkryparna": "slamkrypare",
    "slamkryparnas": "slamkrypare",
    "slammad": "slamma",
    "slammade": "slamma",
    "slammades": "slamma",
    "slammads": "slamma",
    "slammande": "slamma",
    "slammanden": "slammande",
    "slammandena": "slammande",
    "slammandenas": "slammande",
    "slammandens": "slammande",
    "slammandes": "slammande",
    "slammandet": "slammande",
    "slammandets": "slammande",
    "slammar": "slamma",
    "slammarna": "slam",
    "slammarnas": "slam",
    "slammars": "slam",
    "slammas": "slamma",
    "slammat": "slamma",
    "slammats": "slamma",
    "slammen": "slam",
    "slammens": "slam",
    "slammer": "slamra",
    "slammers": "slammer",
    "slammet": "slam",
    "slammets": "slam",
    "slammiga": "slammig",
    "slammigare": "slammig",
    "slammigares": "slammig",
    "slammigas": "slammig",
    "slammigast": "slammig",
    "slammigaste": "slammig",
    "slammigastes": "slammig",
    "slammigasts": "slammig",
    "slammige": "slammig",
    "slammiges": "slammig",
    "slammigheten": "slammighet",
    "slammighetens": "slammighet",
    "slammighets": "slammighet",
    "slammigs": "slammig",
    "slammigt": "slammig",
    "slammigts": "slammig",
    "slamp": "slampa",
    "slampan": "slampa",
    "slampans": "slampa",
    "slampas": "slampa",
    "slampe": "slampa",
    "slampiga": "slampig",
    "slampigare": "slampig",
    "slampigares": "slampig",
    "slampigas": "slampig",
    "slampigast": "slampig",
    "slampigaste": "slampig",
    "slampigastes": "slampig",
    "slampigasts": "slampig",
    "slampige": "slampig",
    "slampiges": "slampig",
    "slampigheten": "slampighet",
    "slampighetens": "slampighet",
    "slampighets": "slampighet",
    "slampigs": "slampig",
    "slampigt": "slampig",
    "slampigts": "slampig",
    "slampor": "slampa",
    "slamporna": "slampa",
    "slampornas": "slampa",
    "slampors": "slampa",
    "slamps": "slampa",
    "slamrade": "slamra",
    "slamrades": "slamra",
    "slamrande": "slamra",
    "slamranden": "slamrande",
    "slamrandena": "slamrande",
    "slamrandenas": "slamrande",
    "slamrandens": "slamrande",
    "slamrandes": "slamrande",
    "slamrandet": "slamrande",
    "slamrandets": "slamrande",
    "slamrar": "slamra",
    "slamras": "slamra",
    "slamrat": "slamra",
    "slamrats": "slamra",
    "slamret": "slammer",
    "slamrets": "slammer",
    "slams": "slamsa",
    "slamsad": "slamsa",
    "slamsade": "slamsa",
    "slamsades": "slamsa",
    "slamsads": "slamsa",
    "slamsan": "slamsa",
    "slamsande": "slamsa",
    "slamsanden": "slamsande",
    "slamsandena": "slamsande",
    "slamsandenas": "slamsande",
    "slamsandens": "slamsande",
    "slamsandes": "slamsande",
    "slamsandet": "slamsande",
    "slamsandets": "slamsande",
    "slamsans": "slamsa",
    "slamsar": "slamsa",
    "slamsas": "slamsa",
    "slamsat": "slamsa",
    "slamsats": "slamsa",
    "slamse": "slamsa",
    "slamset": "slams",
    "slamsets": "slams",
    "slamsiga": "slamsig",
    "slamsigare": "slamsig",
    "slamsigares": "slamsig",
    "slamsigas": "slamsig",
    "slamsigast": "slamsig",
    "slamsigaste": "slamsig",
    "slamsigastes": "slamsig",
    "slamsigasts": "slamsig",
    "slamsige": "slamsig",
    "slamsiges": "slamsig",
    "slamsigheten": "slamsighet",
    "slamsighetens": "slamsighet",
    "slamsighets": "slamsighet",
    "slamsigs": "slamsig",
    "slamsigt": "slamsig",
    "slamsigts": "slamsig",
    "slamsor": "slamsa",
    "slamsorna": "slamsa",
    "slamsornas": "slamsa",
    "slamsors": "slamsa",
    "slamsugningar": "slamsugning",
    "slamsugningarna": "slamsugning",
    "slamsugningarnas": "slamsugning",
    "slamsugningars": "slamsugning",
    "slamsugningen": "slamsugning",
    "slamsugningens": "slamsugning",
    "slamsugnings": "slamsugning",
    "slamsugningsbilar": "slamsugningsbil",
    "slamsugningsbilarna": "slamsugningsbil",
    "slamsugningsbilarnas": "slamsugningsbil",
    "slamsugningsbilars": "slamsugningsbil",
    "slamsugningsbilen": "slamsugningsbil",
    "slamsugningsbilens": "slamsugningsbil",
    "slamsugningsbils": "slamsugningsbil",
    "slan": "slana",
    "slanan": "slana",
    "slanans": "slana",
    "slanas": "slana",
    "slane": "slana",
    "slangar": "slang",
    "slangarna": "slang",
    "slangarnas": "slang",
    "slangars": "slang",
    "slangbell": "slangbella",
    "slangbellan": "slangbella",
    "slangbellans": "slangbella",
    "slangbellas": "slangbella",
    "slangbelle": "slangbella",
    "slangbellor": "slangbella",
    "slangbellorna": "slangbella",
    "slangbellornas": "slangbella",
    "slangbellors": "slangbella",
    "slangbells": "slangbella",
    "slangbåg": "slangbåge",
    "slangbågar": "slangbåge",
    "slangbågarna": "slangbåge",
    "slangbågarnas": "slangbåge",
    "slangbågars": "slangbåge",
    "slangbågen": "slangbåge",
    "slangbågens": "slangbåge",
    "slangbåges": "slangbåge",
    "slangbågs": "slangbåge",
    "slangen": "slang",
    "slangens": "slang",
    "slanggurk": "slanggurka",
    "slanggurkan": "slanggurka",
    "slanggurkans": "slanggurka",
    "slanggurkas": "slanggurka",
    "slanggurke": "slanggurka",
    "slanggurkor": "slanggurka",
    "slanggurkorna": "slanggurka",
    "slanggurkornas": "slanggurka",
    "slanggurkors": "slanggurka",
    "slanggurks": "slanggurka",
    "slangklämman": "slangklämma",
    "slangklämmans": "slangklämma",
    "slangklämmas": "slangklämma",
    "slangklämme": "slangklämma",
    "slangklämmor": "slangklämma",
    "slangklämmorna": "slangklämma",
    "slangklämmornas": "slangklämma",
    "slangklämmors": "slangklämma",
    "slangkopplingar": "slangkoppling",
    "slangkopplingarna": "slangkoppling",
    "slangkopplingarnas": "slangkoppling",
    "slangkopplingars": "slangkoppling",
    "slangkopplingen": "slangkoppling",
    "slangkopplingens": "slangkoppling",
    "slangkopplings": "slangkoppling",
    "slanglösa": "slanglös",
    "slanglösare": "slanglös",
    "slanglösares": "slanglös",
    "slanglösas": "slanglös",
    "slanglösast": "slanglös",
    "slanglösaste": "slanglös",
    "slanglösastes": "slanglös",
    "slanglösasts": "slanglös",
    "slanglöse": "slanglös",
    "slanglöses": "slanglös",
    "slanglösheten": "slanglöshet",
    "slanglöshetens": "slanglöshet",
    "slanglöshets": "slanglöshet",
    "slanglöst": "slanglös",
    "slanglösts": "slanglös",
    "slangs": "slang",
    "slank": "slinka",
    "slanka": "slank",
    "slankad": "slanka",
    "slankade": "slanka",
    "slankades": "slanka",
    "slankads": "slanka",
    "slankande": "slanka",
    "slankanden": "slankande",
    "slankandena": "slankande",
    "slankandenas": "slankande",
    "slankandens": "slankande",
    "slankandes": "slankande",
    "slankandet": "slankande",
    "slankandets": "slankande",
    "slankar": "slanka",
    "slankare": "slank",
    "slankares": "slank",
    "slankas": "slanka",
    "slankast": "slank",
    "slankaste": "slank",
    "slankastes": "slank",
    "slankasts": "slank",
    "slankat": "slanka",
    "slankats": "slanka",
    "slanke": "slank",
    "slankes": "slank",
    "slankheten": "slankhet",
    "slankhetens": "slankhet",
    "slankhets": "slankhet",
    "slankiga": "slankig",
    "slankigare": "slankig",
    "slankigares": "slankig",
    "slankigas": "slankig",
    "slankigast": "slankig",
    "slankigaste": "slankig",
    "slankigastes": "slankig",
    "slankigasts": "slankig",
    "slankige": "slankig",
    "slankiges": "slankig",
    "slankigheten": "slankighet",
    "slankighetens": "slankighet",
    "slankighets": "slankighet",
    "slankigs": "slankig",
    "slankigt": "slankig",
    "slankigts": "slankig",
    "slankn": "slankna",
    "slanknad": "slankna",
    "slanknade": "slankna",
    "slanknades": "slankna",
    "slanknads": "slankna",
    "slanknande": "slankna",
    "slanknanden": "slanknande",
    "slanknandena": "slanknande",
    "slanknandenas": "slanknande",
    "slanknandens": "slanknande",
    "slanknandes": "slanknande",
    "slanknandet": "slanknande",
    "slanknandets": "slanknande",
    "slanknar": "slankna",
    "slanknas": "slankna",
    "slanknat": "slankna",
    "slanknats": "slankna",
    "slanks": "slinka",
    "slankt": "slank",
    "slankts": "slank",
    "slanor": "slana",
    "slanorna": "slana",
    "slanornas": "slana",
    "slanors": "slana",
    "slans": "slana",
    "slant": "slinta",
    "slantad": "slanta",
    "slantade": "slanta",
    "slantades": "slanta",
    "slantads": "slanta",
    "slantande": "slanta",
    "slantanden": "slantande",
    "slantandena": "slantande",
    "slantandenas": "slantande",
    "slantandens": "slantande",
    "slantandes": "slantande",
    "slantandet": "slantande",
    "slantandets": "slantande",
    "slantar": "slanta",
    "slantarna": "slant",
    "slantarnas": "slant",
    "slantars": "slant",
    "slantas": "slanta",
    "slantat": "slanta",
    "slantats": "slanta",
    "slanten": "slant",
    "slantens": "slant",
    "slants": "slinta",
    "slantsinglingar": "slantsingling",
    "slantsinglingarna": "slantsingling",
    "slantsinglingarnas": "slantsingling",
    "slantsinglingars": "slantsingling",
    "slantsinglingen": "slantsingling",
    "slantsinglingens": "slantsingling",
    "slantsinglings": "slantsingling",
    "slantspön": "slantspö",
    "slantspöna": "slantspö",
    "slantspönas": "slantspö",
    "slantspöns": "slantspö",
    "slantspös": "slantspö",
    "slantspöt": "slantspö",
    "slantspöts": "slantspö",
    "slapp": "slippa",
    "slappa": "slapp",
    "slappad": "slappa",
    "slappade": "slappa",
    "slappades": "slappa",
    "slappads": "slappa",
    "slappande": "slappa",
    "slappanden": "slappande",
    "slappandena": "slappande",
    "slappandenas": "slappande",
    "slappandens": "slappande",
    "slappandes": "slappande",
    "slappandet": "slappande",
    "slappandets": "slappande",
    "slappar": "slappa",
    "slappare": "slapp",
    "slappares": "slapp",
    "slappas": "slappa",
    "slappast": "slapp",
    "slappaste": "slapp",
    "slappastes": "slapp",
    "slappasts": "slapp",
    "slappat": "slappa",
    "slappats": "slappa",
    "slappe": "slapp",
    "slappes": "slapp",
    "slappheten": "slapphet",
    "slapphetens": "slapphet",
    "slapphets": "slapphet",
    "slapphänta": "slapphänt",
    "slapphäntare": "slapphänt",
    "slapphäntares": "slapphänt",
    "slapphäntas": "slapphänt",
    "slapphäntast": "slapphänt",
    "slapphäntaste": "slapphänt",
    "slapphäntastes": "slapphänt",
    "slapphäntasts": "slapphänt",
    "slapphänte": "slapphänt",
    "slapphäntes": "slapphänt",
    "slapphäntheten": "slapphänthet",
    "slapphänthetens": "slapphänthet",
    "slapphänthets": "slapphänthet",
    "slapphänts": "slapphänt",
    "slappn": "slappna",
    "slappnad": "slappna",
    "slappnade": "slappna",
    "slappnades": "slappna",
    "slappnads": "slappna",
    "slappnande": "slappna",
    "slappnanden": "slappnande",
    "slappnandena": "slappnande",
    "slappnandenas": "slappnande",
    "slappnandens": "slappnande",
    "slappnandes": "slappnande",
    "slappnandet": "slappnande",
    "slappnandets": "slappnande",
    "slappnar": "slappna",
    "slappnas": "slappna",
    "slappnat": "slappna",
    "slappnats": "slappna",
    "slapps": "slippa",
    "slappt": "slapp",
    "slappts": "slapp",
    "slapsticken": "slapstick",
    "slapstickens": "slapstick",
    "slapsticks": "slapstick",
    "slarv": "slarva",
    "slarvad": "slarva",
    "slarvade": "slarva",
    "slarvades": "slarva",
    "slarvads": "slarva",
    "slarvan": "slarva",
    "slarvande": "slarva",
    "slarvanden": "slarvande",
    "slarvandena": "slarvande",
    "slarvandenas": "slarvande",
    "slarvandens": "slarvande",
    "slarvandes": "slarvande",
    "slarvandet": "slarvande",
    "slarvandets": "slarvande",
    "slarvans": "slarva",
    "slarvar": "slarver",
    "slarvarna": "slarver",
    "slarvarnas": "slarver",
    "slarvars": "slarver",
    "slarvas": "slarva",
    "slarvat": "slarva",
    "slarvats": "slarva",
    "slarve": "slarva",
    "slarvern": "slarver",
    "slarverns": "slarver",
    "slarvers": "slarver",
    "slarvet": "slarv",
    "slarvets": "slarv",
    "slarvfelen": "slarvfel",
    "slarvfelens": "slarvfel",
    "slarvfelet": "slarvfel",
    "slarvfelets": "slarvfel",
    "slarvfels": "slarvfel",
    "slarviga": "slarvig",
    "slarvigare": "slarvig",
    "slarvigares": "slarvig",
    "slarvigas": "slarvig",
    "slarvigast": "slarvig",
    "slarvigaste": "slarvig",
    "slarvigastes": "slarvig",
    "slarvigasts": "slarvig",
    "slarvige": "slarvig",
    "slarviges": "slarvig",
    "slarvigheten": "slarvighet",
    "slarvighetens": "slarvighet",
    "slarvigheter": "slarvighet",
    "slarvigheterna": "slarvighet",
    "slarvigheternas": "slarvighet",
    "slarvigheters": "slarvighet",
    "slarvighets": "slarvighet",
    "slarvigs": "slarvig",
    "slarvigt": "slarvig",
    "slarvigts": "slarvig",
    "slarvor": "slarva",
    "slarvorna": "slarva",
    "slarvornas": "slarva",
    "slarvors": "slarva",
    "slarvrar": "slarver",
    "slarvrarna": "slarver",
    "slarvrarnas": "slarver",
    "slarvrars": "slarver",
    "slarvs": "slarva",
    "slarvsyltan": "slarvsylta",
    "slarvsyltans": "slarvsylta",
    "slarvsyltas": "slarvsylta",
    "slarvsylte": "slarvsylta",
    "slarvsyltor": "slarvsylta",
    "slarvsyltorna": "slarvsylta",
    "slarvsyltornas": "slarvsylta",
    "slarvsyltors": "slarvsylta",
    "slas": "slase",
    "slasad": "slasa",
    "slasade": "slasa",
    "slasades": "slasa",
    "slasads": "slasa",
    "slasande": "slasa",
    "slasanden": "slasande",
    "slasandena": "slasande",
    "slasandenas": "slasande",
    "slasandens": "slasande",
    "slasandes": "slasande",
    "slasandet": "slasande",
    "slasandets": "slasande",
    "slasar": "slase",
    "slasarna": "slase",
    "slasarnas": "slase",
    "slasars": "slase",
    "slasas": "slasa",
    "slasat": "slasa",
    "slasats": "slasa",
    "slasen": "slase",
    "slasens": "slase",
    "slases": "slase",
    "slashar": "slash",
    "slasharna": "slash",
    "slasharnas": "slash",
    "slashars": "slash",
    "slashasar": "slashas",
    "slashasarna": "slashas",
    "slashasarnas": "slashas",
    "slashasars": "slashas",
    "slashasen": "slashas",
    "slashasens": "slashas",
    "slashen": "slash",
    "slashens": "slash",
    "slashs": "slash",
    "slask": "slaska",
    "slaskad": "slaska",
    "slaskade": "slaska",
    "slaskades": "slaska",
    "slaskads": "slaska",
    "slaskande": "slaska",
    "slaskanden": "slaskande",
    "slaskandena": "slaskande",
    "slaskandenas": "slaskande",
    "slaskandens": "slaskande",
    "slaskandes": "slaskande",
    "slaskandet": "slaskande",
    "slaskandets": "slaskande",
    "slaskar": "slaska",
    "slaskarna": "slask",
    "slaskarnas": "slask",
    "slaskars": "slask",
    "slaskas": "slaska",
    "slaskat": "slaska",
    "slaskats": "slaska",
    "slasken": "slask",
    "slaskens": "slask",
    "slasket": "slask",
    "slaskets": "slask",
    "slaskiga": "slaskig",
    "slaskigare": "slaskig",
    "slaskigares": "slaskig",
    "slaskigas": "slaskig",
    "slaskigast": "slaskig",
    "slaskigaste": "slaskig",
    "slaskigastes": "slaskig",
    "slaskigasts": "slaskig",
    "slaskige": "slaskig",
    "slaskiges": "slaskig",
    "slaskigheten": "slaskighet",
    "slaskighetens": "slaskighet",
    "slaskighets": "slaskighet",
    "slaskigs": "slaskig",
    "slaskigt": "slaskig",
    "slaskigts": "slaskig",
    "slasks": "slask",
    "slaskspalten": "slaskspalt",
    "slaskspaltens": "slaskspalt",
    "slaskspalter": "slaskspalt",
    "slaskspalterna": "slaskspalt",
    "slaskspalternas": "slaskspalt",
    "slaskspalters": "slaskspalt",
    "slaskspalts": "slaskspalt",
    "slasktrattar": "slasktratt",
    "slasktrattarna": "slasktratt",
    "slasktrattarnas": "slasktratt",
    "slasktrattars": "slasktratt",
    "slasktratten": "slasktratt",
    "slasktrattens": "slasktratt",
    "slasktratts": "slasktratt",
    "slaskvattens": "slaskvatten",
    "slaskvattnen": "slaskvatten",
    "slaskvattnens": "slaskvatten",
    "slaskvattnet": "slaskvatten",
    "slaskvattnets": "slaskvatten",
    "slattar": "slatt",
    "slattarna": "slatt",
    "slattarnas": "slatt",
    "slattars": "slatt",
    "slatten": "slatt",
    "slattens": "slatt",
    "slattriga": "slattrig",
    "slattrigare": "slattrig",
    "slattrigares": "slattrig",
    "slattrigas": "slattrig",
    "slattrigast": "slattrig",
    "slattrigaste": "slattrig",
    "slattrigastes": "slattrig",
    "slattrigasts": "slattrig",
    "slattrige": "slattrig",
    "slattriges": "slattrig",
    "slattrigheten": "slattrighet",
    "slattrighetens": "slattrighet",
    "slattrighets": "slattrighet",
    "slattrigs": "slattrig",
    "slattrigt": "slattrig",
    "slattrigts": "slattrig",
    "slatts": "slatt",
    "slav": "slava",
    "slavad": "slava",
    "slavade": "slava",
    "slavades": "slava",
    "slavads": "slava",
    "slavande": "slava",
    "slavanden": "slavande",
    "slavandena": "slavande",
    "slavandenas": "slavande",
    "slavandens": "slavande",
    "slavandes": "slavande",
    "slavandet": "slavande",
    "slavandets": "slavande",
    "slavar": "slava",
    "slavarbetar": "slavarbetare",
    "slavarbetaren": "slavarbetare",
    "slavarbetarens": "slavarbetare",
    "slavarbetares": "slavarbetare",
    "slavarbetarna": "slavarbetare",
    "slavarbetarnas": "slavarbetare",
    "slavarbeten": "slavarbete",
    "slavarbetena": "slavarbete",
    "slavarbetenas": "slavarbete",
    "slavarbetens": "slavarbete",
    "slavarbetes": "slavarbete",
    "slavarbetet": "slavarbete",
    "slavarbetets": "slavarbete",
    "slavarbets": "slavarbete",
    "slavarbetslägerna": "slavarbetsläger",
    "slavarbetslägernas": "slavarbetsläger",
    "slavarbetslägers": "slavarbetsläger",
    "slavarbetslägren": "slavarbetsläger",
    "slavarbetslägrens": "slavarbetsläger",
    "slavarbetslägret": "slavarbetsläger",
    "slavarbetslägrets": "slavarbetsläger",
    "slavarna": "slav",
    "slavarnas": "slav",
    "slavars": "slav",
    "slavas": "slava",
    "slavat": "slava",
    "slavats": "slava",
    "slavdrivar": "slavdrivare",
    "slavdrivaren": "slavdrivare",
    "slavdrivarens": "slavdrivare",
    "slavdrivares": "slavdrivare",
    "slavdrivarna": "slavdrivare",
    "slavdrivarnas": "slavdrivare",
    "slaven": "slav",
    "slavens": "slav",
    "slaver": "slav",
    "slaveriet": "slaveri",
    "slaveriets": "slaveri",
    "slaveris": "slaveri",
    "slaverit": "slaveri",
    "slaverits": "slaveri",
    "slaverna": "slav",
    "slavernas": "slav",
    "slavers": "slav",
    "slavhandeln": "slavhandel",
    "slavhandelns": "slavhandel",
    "slavhandels": "slavhandel",
    "slavhusen": "slavhus",
    "slavhusens": "slavhus",
    "slavhuset": "slavhus",
    "slavhusets": "slavhus",
    "slavinnan": "slavinna",
    "slavinnans": "slavinna",
    "slavinnas": "slavinna",
    "slavinne": "slavinna",
    "slavinnor": "slavinna",
    "slavinnorna": "slavinna",
    "slavinnornas": "slavinna",
    "slavinnors": "slavinna",
    "slaviserad": "slavisera",
    "slaviserade": "slavisera",
    "slaviserades": "slavisera",
    "slaviserads": "slavisera",
    "slaviserande": "slavisera",
    "slaviseranden": "slaviserande",
    "slaviserandena": "slaviserande",
    "slaviserandenas": "slaviserande",
    "slaviserandens": "slaviserande",
    "slaviserandes": "slaviserande",
    "slaviserandet": "slaviserande",
    "slaviserandets": "slaviserande",
    "slaviserar": "slavisera",
    "slaviseras": "slavisera",
    "slaviserat": "slavisera",
    "slaviserats": "slavisera",
    "slaviserbara": "slaviserbar",
    "slaviserbarare": "slaviserbar",
    "slaviserbarares": "slaviserbar",
    "slaviserbaras": "slaviserbar",
    "slaviserbarast": "slaviserbar",
    "slaviserbaraste": "slaviserbar",
    "slaviserbarastes": "slaviserbar",
    "slaviserbarasts": "slaviserbar",
    "slaviserbare": "slaviserbar",
    "slaviserbares": "slaviserbar",
    "slaviserbarheten": "slaviserbarhet",
    "slaviserbarhetens": "slaviserbarhet",
    "slaviserbarhets": "slaviserbarhet",
    "slaviserbars": "slaviserbar",
    "slaviserbart": "slaviserbar",
    "slaviserbarts": "slaviserbar",
    "slaviseringar": "slavisering",
    "slaviseringarna": "slavisering",
    "slaviseringarnas": "slavisering",
    "slaviseringars": "slavisering",
    "slaviseringen": "slavisering",
    "slaviseringens": "slavisering",
    "slaviserings": "slavisering",
    "slaviska": "slavisk",
    "slaviskare": "slavisk",
    "slaviskares": "slavisk",
    "slaviskas": "slavisk",
    "slaviskast": "slavisk",
    "slaviskaste": "slavisk",
    "slaviskastes": "slavisk",
    "slaviskasts": "slavisk",
    "slaviske": "slavisk",
    "slaviskes": "slavisk",
    "slavisks": "slavisk",
    "slaviskt": "slavisk",
    "slaviskts": "slavisk",
    "slavismen": "slavism",
    "slavismens": "slavism",
    "slavismer": "slavism",
    "slavismerna": "slavism",
    "slavismernas": "slavism",
    "slavismers": "slavism",
    "slavisms": "slavism",
    "slavisten": "slavist",
    "slavistens": "slavist",
    "slavister": "slavist",
    "slavisterna": "slavist",
    "slavisternas": "slavist",
    "slavisters": "slavist",
    "slavistiken": "slavistik",
    "slavistikens": "slavistik",
    "slavistiks": "slavistik",
    "slavists": "slavist",
    "slavlägerna": "slavläger",
    "slavlägernas": "slavläger",
    "slavlägers": "slavläger",
    "slavlägren": "slavläger",
    "slavlägrens": "slavläger",
    "slavlägret": "slavläger",
    "slavlägrets": "slavläger",
    "slavlönen": "slavlön",
    "slavlönens": "slavlön",
    "slavlöner": "slavlön",
    "slavlönerna": "slavlön",
    "slavlönernas": "slavlön",
    "slavlöners": "slavlön",
    "slavlöns": "slavlön",
    "slavmärken": "slavmärke",
    "slavmärkena": "slavmärke",
    "slavmärkenas": "slavmärke",
    "slavmärkens": "slavmärke",
    "slavmärkes": "slavmärke",
    "slavmärket": "slavmärke",
    "slavmärkets": "slavmärke",
    "slavofila": "slavofil",
    "slavofilare": "slavofil",
    "slavofilares": "slavofil",
    "slavofilas": "slavofil",
    "slavofilast": "slavofil",
    "slavofilaste": "slavofil",
    "slavofilastes": "slavofil",
    "slavofilasts": "slavofil",
    "slavofile": "slavofil",
    "slavofiles": "slavofil",
    "slavofils": "slavofil",
    "slavofilt": "slavofil",
    "slavofilts": "slavofil",
    "slavs": "slav",
    "slavstationen": "slavstation",
    "slavstationens": "slavstation",
    "slavstationer": "slavstation",
    "slavstationerna": "slavstation",
    "slavstationernas": "slavstation",
    "slavstationers": "slavstation",
    "slavstations": "slavstation",
    "slavsändar": "slavsändare",
    "slavsändaren": "slavsändare",
    "slavsändarens": "slavsändare",
    "slavsändares": "slavsändare",
    "slavsändarna": "slavsändare",
    "slavsändarnas": "slavsändare",
    "slavupproren": "slavuppror",
    "slavupprorens": "slavuppror",
    "slavupproret": "slavuppror",
    "slavupprorets": "slavuppror",
    "slavupprors": "slavuppror",
    "slejfar": "slejf",
    "slejfarna": "slejf",
    "slejfarnas": "slejf",
    "slejfars": "slejf",
    "slejfen": "slejf",
    "slejfens": "slejf",
    "slejfer": "slejf",
    "slejferna": "slejf",
    "slejfernas": "slejf",
    "slejfers": "slejf",
    "slejfs": "slejf",
    "slejsar": "slejs",
    "slejsarna": "slejs",
    "slejsarnas": "slejs",
    "slejsars": "slejs",
    "slejsen": "slejs",
    "slejsens": "slejs",
    "sleken": "sleke",
    "slekena": "sleke",
    "slekenas": "sleke",
    "slekens": "sleke",
    "slekes": "sleke",
    "sleket": "sleke",
    "slekets": "sleke",
    "sleks": "sleke",
    "slemheten": "slemhet",
    "slemhetens": "slemhet",
    "slemhets": "slemhet",
    "slemhinnan": "slemhinna",
    "slemhinnans": "slemhinna",
    "slemhinnas": "slemhinna",
    "slemhinne": "slemhinna",
    "slemhinnor": "slemhinna",
    "slemhinnorna": "slemhinna",
    "slemhinnornas": "slemhinna",
    "slemhinnors": "slemhinna",
    "slemma": "slem",
    "slemmare": "slem",
    "slemmares": "slem",
    "slemmas": "slem",
    "slemmast": "slem",
    "slemmaste": "slem",
    "slemmastes": "slem",
    "slemmasts": "slem",
    "slemme": "slem",
    "slemmes": "slem",
    "slemmet": "slem",
    "slemmets": "slem",
    "slemmiga": "slemmig",
    "slemmigare": "slemmig",
    "slemmigares": "slemmig",
    "slemmigas": "slemmig",
    "slemmigast": "slemmig",
    "slemmigaste": "slemmig",
    "slemmigastes": "slemmig",
    "slemmigasts": "slemmig",
    "slemmige": "slemmig",
    "slemmiges": "slemmig",
    "slemmigheten": "slemmighet",
    "slemmighetens": "slemmighet",
    "slemmigheter": "slemmighet",
    "slemmigheterna": "slemmighet",
    "slemmigheternas": "slemmighet",
    "slemmigheters": "slemmighet",
    "slemmighets": "slemmighet",
    "slemmigs": "slemmig",
    "slemmigt": "slemmig",
    "slemmigts": "slemmig",
    "slems": "slem",
    "slemsvampar": "slemsvamp",
    "slemsvamparna": "slemsvamp",
    "slemsvamparnas": "slemsvamp",
    "slemsvampars": "slemsvamp",
    "slemsvampen": "slemsvamp",
    "slemsvampens": "slemsvamp",
    "slemsvamps": "slemsvamp",
    "slemsäckar": "slemsäck",
    "slemsäckarna": "slemsäck",
    "slemsäckarnas": "slemsäck",
    "slemsäckars": "slemsäck",
    "slemsäcken": "slemsäck",
    "slemsäckens": "slemsäck",
    "slemsäcks": "slemsäck",
    "slemt": "slem",
    "slemts": "slem",
    "slentrianen": "slentrian",
    "slentrianens": "slentrian",
    "slentrianföreställningar": "slentrianföreställning",
    "slentrianföreställningarna": "slentrianföreställning",
    "slentrianföreställningarnas": "slentrianföreställning",
    "slentrianföreställningars": "slentrianföreställning",
    "slentrianföreställningen": "slentrianföreställning",
    "slentrianföreställningens": "slentrianföreställning",
    "slentrianföreställnings": "slentrianföreställning",
    "slentrianmässiga": "slentrianmässig",
    "slentrianmässigare": "slentrianmässig",
    "slentrianmässigares": "slentrianmässig",
    "slentrianmässigas": "slentrianmässig",
    "slentrianmässigast": "slentrianmässig",
    "slentrianmässigaste": "slentrianmässig",
    "slentrianmässigastes": "slentrianmässig",
    "slentrianmässigasts": "slentrianmässig",
    "slentrianmässige": "slentrianmässig",
    "slentrianmässiges": "slentrianmässig",
    "slentrianmässigs": "slentrianmässig",
    "slentrianmässigt": "slentrianmässig",
    "slentrianmässigts": "slentrianmässig",
    "slentrians": "slentrian",
    "slet": "slita",
    "slets": "slita",
    "slev": "sleva",
    "slevad": "sleva",
    "slevade": "sleva",
    "slevades": "sleva",
    "slevads": "sleva",
    "slevande": "sleva",
    "slevanden": "slevande",
    "slevandena": "slevande",
    "slevandenas": "slevande",
    "slevandens": "slevande",
    "slevandes": "slevande",
    "slevandet": "slevande",
    "slevandets": "slevande",
    "slevar": "sleva",
    "slevarna": "slev",
    "slevarnas": "slev",
    "slevars": "slev",
    "slevas": "sleva",
    "slevat": "sleva",
    "slevats": "sleva",
    "sleven": "slev",
    "slevens": "slev",
    "slevs": "slev",
    "slibbiga": "slibbig",
    "slibbigare": "slibbig",
    "slibbigares": "slibbig",
    "slibbigas": "slibbig",
    "slibbigast": "slibbig",
    "slibbigaste": "slibbig",
    "slibbigastes": "slibbig",
    "slibbigasts": "slibbig",
    "slibbige": "slibbig",
    "slibbiges": "slibbig",
    "slibbigheten": "slibbighet",
    "slibbighetens": "slibbighet",
    "slibbigheter": "slibbighet",
    "slibbigheterna": "slibbighet",
    "slibbigheternas": "slibbighet",
    "slibbigheters": "slibbighet",
    "slibbighets": "slibbighet",
    "slibbigs": "slibbig",
    "slibbigt": "slibbig",
    "slibbigts": "slibbig",
    "slic": "slice",
    "slicar": "slice",
    "slicarna": "slice",
    "slicarnas": "slice",
    "slicars": "slice",
    "slicen": "slice",
    "slicens": "slice",
    "slices": "slice",
    "slick": "slicka",
    "slickad": "slicka",
    "slickade": "slicka",
    "slickades": "slicka",
    "slickads": "slicka",
    "slickande": "slicka",
    "slickanden": "slickande",
    "slickandena": "slickande",
    "slickandenas": "slickande",
    "slickandens": "slickande",
    "slickandes": "slickande",
    "slickandet": "slickande",
    "slickandets": "slickande",
    "slickar": "slicka",
    "slickarna": "slick",
    "slickarnas": "slick",
    "slickars": "slick",
    "slickas": "slicka",
    "slickat": "slicka",
    "slickats": "slicka",
    "slicken": "slick",
    "slickens": "slick",
    "slickepinn": "slickepinne",
    "slickepinnar": "slickepinne",
    "slickepinnarna": "slickepinne",
    "slickepinnarnas": "slickepinne",
    "slickepinnars": "slickepinne",
    "slickepinnen": "slickepinne",
    "slickepinnens": "slickepinne",
    "slickepinnes": "slickepinne",
    "slickepinns": "slickepinne",
    "slickepottar": "slickepott",
    "slickepottarna": "slickepott",
    "slickepottarnas": "slickepott",
    "slickepottars": "slickepott",
    "slickepotten": "slickepott",
    "slickepottens": "slickepott",
    "slickepotts": "slickepott",
    "slicks": "slick",
    "slickstenar": "slicksten",
    "slickstenarna": "slicksten",
    "slickstenarnas": "slicksten",
    "slickstenars": "slicksten",
    "slickstenen": "slicksten",
    "slickstenens": "slicksten",
    "slickstens": "slicksten",
    "slics": "slice",
    "slid": "slida",
    "slidan": "slik",
    "slidana": "slik",
    "slidanas": "slik",
    "slidans": "slik",
    "slidant": "slik",
    "slidants": "slik",
    "slidas": "slida",
    "slidders": "slidder",
    "sliddret": "slidder",
    "sliddrets": "slidder",
    "sliddriga": "sliddrig",
    "sliddrigare": "sliddrig",
    "sliddrigares": "sliddrig",
    "sliddrigas": "sliddrig",
    "sliddrigast": "sliddrig",
    "sliddrigaste": "sliddrig",
    "sliddrigastes": "sliddrig",
    "sliddrigasts": "sliddrig",
    "sliddrige": "sliddrig",
    "sliddriges": "sliddrig",
    "sliddrigheten": "sliddrighet",
    "sliddrighetens": "sliddrighet",
    "sliddrighets": "sliddrighet",
    "sliddrigs": "sliddrig",
    "sliddrigt": "sliddrig",
    "sliddrigts": "sliddrig",
    "slide": "slida",
    "sliden": "slid",
    "slidens": "slid",
    "slider": "slid",
    "sliderna": "slid",
    "slidernas": "slid",
    "sliders": "slid",
    "slidhornsdjuren": "slidhornsdjur",
    "slidhornsdjurens": "slidhornsdjur",
    "slidhornsdjuret": "slidhornsdjur",
    "slidhornsdjurets": "slidhornsdjur",
    "slidhornsdjurs": "slidhornsdjur",
    "slidknivar": "slidkniv",
    "slidknivarna": "slidkniv",
    "slidknivarnas": "slidkniv",
    "slidknivars": "slidkniv",
    "slidkniven": "slidkniv",
    "slidknivens": "slidkniv",
    "slidknivs": "slidkniv",
    "slidkransar": "slidkrans",
    "slidkransarna": "slidkrans",
    "slidkransarnas": "slidkrans",
    "slidkransars": "slidkrans",
    "slidkransen": "slidkrans",
    "slidkransens": "slidkrans",
    "slidmotorer": "slidmotor",
    "slidmotorerna": "slidmotor",
    "slidmotorernas": "slidmotor",
    "slidmotorers": "slidmotor",
    "slidmotorn": "slidmotor",
    "slidmotorns": "slidmotor",
    "slidmotors": "slidmotor",
    "slidor": "slida",
    "slidorna": "slida",
    "slidornas": "slida",
    "slidors": "slida",
    "slids": "slida",
    "sligen": "slig",
    "sligens": "slig",
    "sligs": "slig",
    "slika": "slik",
    "slikas": "slik",
    "sliks": "slik",
    "slikt": "slikta",
    "sliktad": "slikta",
    "sliktade": "slikta",
    "sliktades": "slikta",
    "sliktads": "slikta",
    "sliktande": "slikta",
    "sliktanden": "sliktande",
    "sliktandena": "sliktande",
    "sliktandenas": "sliktande",
    "sliktandens": "sliktande",
    "sliktandes": "sliktande",
    "sliktandet": "sliktande",
    "sliktandets": "sliktande",
    "sliktar": "slikta",
    "sliktas": "slikta",
    "sliktat": "slikta",
    "sliktats": "slikta",
    "slikts": "slik",
    "slimmade": "slimmad",
    "slimmades": "slimmad",
    "slimmads": "slimmad",
    "slimmat": "slimmad",
    "slimmats": "slimmad",
    "slinderna": "slinder",
    "slindernas": "slinder",
    "slinders": "slinder",
    "slindren": "slinder",
    "slindrens": "slinder",
    "slindret": "slinder",
    "slindrets": "slinder",
    "sling": "slinga",
    "slingan": "slinga",
    "slingans": "slinga",
    "slingas": "slinga",
    "slinge": "slinga",
    "slingen": "sling",
    "slingens": "sling",
    "slinger": "slingra",
    "slingerborden": "slingerbord",
    "slingerbordens": "slingerbord",
    "slingerbordet": "slingerbord",
    "slingerbordets": "slingerbord",
    "slingerbords": "slingerbord",
    "slingerbultar": "slingerbult",
    "slingerbultarna": "slingerbult",
    "slingerbultarnas": "slingerbult",
    "slingerbultars": "slingerbult",
    "slingerbulten": "slingerbult",
    "slingerbultens": "slingerbult",
    "slingerbults": "slingerbult",
    "slingerkojen": "slingerkoj",
    "slingerkojens": "slingerkoj",
    "slingerkojer": "slingerkoj",
    "slingerkojerna": "slingerkoj",
    "slingerkojernas": "slingerkoj",
    "slingerkojers": "slingerkoj",
    "slingerkojs": "slingerkoj",
    "slingerkrokarna": "slingerkrokar",
    "slingerkrokarnas": "slingerkrokar",
    "slingerkrokars": "slingerkrokar",
    "slingerkroks": "slingerkrokar",
    "slingerkölar": "slingerköl",
    "slingerkölarna": "slingerköl",
    "slingerkölarnas": "slingerköl",
    "slingerkölars": "slingerköl",
    "slingerkölen": "slingerköl",
    "slingerkölens": "slingerköl",
    "slingerköls": "slingerköl",
    "slingerskotten": "slingerskott",
    "slingerskottens": "slingerskott",
    "slingerskottet": "slingerskott",
    "slingerskottets": "slingerskott",
    "slingerskotts": "slingerskott",
    "slingerväxten": "slingerväxt",
    "slingerväxtens": "slingerväxt",
    "slingerväxter": "slingerväxt",
    "slingerväxterna": "slingerväxt",
    "slingerväxternas": "slingerväxt",
    "slingerväxters": "slingerväxt",
    "slingerväxts": "slingerväxt",
    "slinget": "sling",
    "slingets": "sling",
    "slingor": "slinga",
    "slingorna": "slinga",
    "slingornas": "slinga",
    "slingors": "slinga",
    "slingrade": "slingra",
    "slingrades": "slingra",
    "slingrande": "slingra",
    "slingranden": "slingrande",
    "slingrandena": "slingrande",
    "slingrandenas": "slingrande",
    "slingrandens": "slingrande",
    "slingrandes": "slingrande",
    "slingrandet": "slingrande",
    "slingrandets": "slingrande",
    "slingrar": "slingra",
    "slingras": "slingra",
    "slingrat": "slingra",
    "slingrats": "slingra",
    "slingriga": "slingrig",
    "slingrigare": "slingrig",
    "slingrigares": "slingrig",
    "slingrigas": "slingrig",
    "slingrigast": "slingrig",
    "slingrigaste": "slingrig",
    "slingrigastes": "slingrig",
    "slingrigasts": "slingrig",
    "slingrige": "slingrig",
    "slingriges": "slingrig",
    "slingrigheten": "slingrighet",
    "slingrighetens": "slingrighet",
    "slingrighets": "slingrighet",
    "slingrigs": "slingrig",
    "slingrigt": "slingrig",
    "slingrigts": "slingrig",
    "slings": "slinga",
    "slink": "slinka",
    "slinkan": "slinka",
    "slinkande": "slinka",
    "slinkanden": "slinkande",
    "slinkandena": "slinkande",
    "slinkandenas": "slinkande",
    "slinkandens": "slinkande",
    "slinkandes": "slinkande",
    "slinkandet": "slinkande",
    "slinkandets": "slinkande",
    "slinkans": "slinka",
    "slinkas": "slinka",
    "slinke": "slinka",
    "slinker": "slinka",
    "slinkes": "slinka",
    "slinkiga": "slinkig",
    "slinkigare": "slinkig",
    "slinkigares": "slinkig",
    "slinkigas": "slinkig",
    "slinkigast": "slinkig",
    "slinkigaste": "slinkig",
    "slinkigastes": "slinkig",
    "slinkigasts": "slinkig",
    "slinkige": "slinkig",
    "slinkiges": "slinkig",
    "slinkigheten": "slinkighet",
    "slinkighetens": "slinkighet",
    "slinkighets": "slinkighet",
    "slinkigs": "slinkig",
    "slinkigt": "slinkig",
    "slinkigts": "slinkig",
    "slinkleden": "slinkled",
    "slinkledens": "slinkled",
    "slinkleder": "slinkled",
    "slinklederna": "slinkled",
    "slinkledernas": "slinkled",
    "slinkleders": "slinkled",
    "slinkleds": "slinkled",
    "slinkor": "slinka",
    "slinkorna": "slinka",
    "slinkornas": "slinka",
    "slinkors": "slinka",
    "slinks": "slinka",
    "slint": "slinta",
    "slintande": "slinta",
    "slintanden": "slintande",
    "slintandena": "slintande",
    "slintandenas": "slintande",
    "slintandens": "slintande",
    "slintandes": "slintande",
    "slintandet": "slintande",
    "slintandets": "slintande",
    "slintas": "slinta",
    "slinte": "slinta",
    "slinter": "slinta",
    "slintes": "slinta",
    "slints": "slinta",
    "slip": "slipa",
    "slipad": "slipa",
    "slipade": "slipad",
    "slipades": "slipad",
    "slipads": "slipad",
    "slipande": "slipa",
    "slipanden": "slipande",
    "slipandena": "slipande",
    "slipandenas": "slipande",
    "slipandens": "slipande",
    "slipandes": "slipande",
    "slipandet": "slipande",
    "slipandets": "slipande",
    "slipar": "slipa",
    "sliparna": "slip",
    "sliparnas": "slip",
    "slipars": "slip",
    "slipas": "slipa",
    "slipat": "slipad",
    "slipats": "slipad",
    "slipen": "slip",
    "slipens": "slip",
    "sliperier": "sliperi",
    "sliperierna": "sliperi",
    "sliperiernas": "sliperi",
    "sliperiers": "sliperi",
    "sliperiet": "sliperi",
    "sliperiets": "sliperi",
    "sliperis": "sliperi",
    "sliperit": "sliperi",
    "sliperits": "sliperi",
    "slipern": "sliper",
    "sliperns": "sliper",
    "slipers": "sliper",
    "slipersoljan": "slipersolja",
    "slipersoljans": "slipersolja",
    "slipersoljas": "slipersolja",
    "slipersolje": "slipersolja",
    "slipklossar": "slipkloss",
    "slipklossarna": "slipkloss",
    "slipklossarnas": "slipkloss",
    "slipklossars": "slipkloss",
    "slipklossen": "slipkloss",
    "slipklossens": "slipkloss",
    "slipmaskinen": "slipmaskin",
    "slipmaskinens": "slipmaskin",
    "slipmaskiner": "slipmaskin",
    "slipmaskinerna": "slipmaskin",
    "slipmaskinernas": "slipmaskin",
    "slipmaskiners": "slipmaskin",
    "slipmaskins": "slipmaskin",
    "slipmassan": "slipmassa",
    "slipmassans": "slipmassa",
    "slipmassas": "slipmassa",
    "slipmasse": "slipmassa",
    "slipmedels": "slipmedel",
    "slipmedlen": "slipmedel",
    "slipmedlens": "slipmedel",
    "slipmedlet": "slipmedel",
    "slipmedlets": "slipmedel",
    "slipningen": "slipning",
    "slipningens": "slipning",
    "slipnings": "slipning",
    "slipovern": "slipover",
    "slipoverns": "slipover",
    "slipovers": "slipover",
    "slipoversarna": "slipover",
    "slipoversarnas": "slipover",
    "slipoversen": "slipover",
    "slipoversens": "slipover",
    "slipovrar": "slipover",
    "slipovrarna": "slipover",
    "slipovrarnas": "slipover",
    "slipovrars": "slipover",
    "slipp": "slippa",
    "slippande": "slippa",
    "slippanden": "slippande",
    "slippandena": "slippande",
    "slippandenas": "slippande",
    "slippandens": "slippande",
    "slippandes": "slippande",
    "slippandet": "slippande",
    "slippandets": "slippande",
    "slippapperen": "slippapper",
    "slippapperens": "slippapper",
    "slippapperet": "slippapper",
    "slippapperets": "slippapper",
    "slippapperna": "slippapper",
    "slippappernas": "slippapper",
    "slippappers": "slippapper",
    "slippappren": "slippapper",
    "slippapprens": "slippapper",
    "slippappret": "slippapper",
    "slippapprets": "slippapper",
    "slippas": "slippa",
    "slippast": "slippasta",
    "slippastan": "slippasta",
    "slippastans": "slippasta",
    "slippastas": "slippasta",
    "slippaste": "slippasta",
    "slippastor": "slippasta",
    "slippastorna": "slippasta",
    "slippastornas": "slippasta",
    "slippastors": "slippasta",
    "slippe": "slippa",
    "slipper": "slippa",
    "slippes": "slippa",
    "slippriga": "slipprig",
    "slipprigare": "slipprig",
    "slipprigares": "slipprig",
    "slipprigas": "slipprig",
    "slipprigast": "slipprig",
    "slipprigaste": "slipprig",
    "slipprigastes": "slipprig",
    "slipprigasts": "slipprig",
    "slipprige": "slipprig",
    "slippriges": "slipprig",
    "slipprigheten": "slipprighet",
    "slipprighetens": "slipprighet",
    "slipprigheter": "slipprighet",
    "slipprigheterna": "slipprighet",
    "slipprigheternas": "slipprighet",
    "slipprigheters": "slipprighet",
    "slipprighets": "slipprighet",
    "slipprigs": "slipprig",
    "slipprigt": "slipprig",
    "slipprigts": "slipprig",
    "slipproven": "slipprov",
    "slipprovens": "slipprov",
    "slipprover": "slipprov",
    "slipproverna": "slipprov",
    "slipprovernas": "slipprov",
    "slipprovers": "slipprov",
    "slipprovet": "slipprov",
    "slipprovets": "slipprov",
    "slipprovs": "slipprov",
    "slipps": "slippa",
    "sliprar": "sliper",
    "sliprarna": "sliper",
    "sliprarnas": "sliper",
    "sliprars": "sliper",
    "slipresultaten": "slipresultat",
    "slipresultatens": "slipresultat",
    "slipresultatet": "slipresultat",
    "slipresultatets": "slipresultat",
    "slipresultats": "slipresultat",
    "slips": "slip",
    "slipsar": "slips",
    "slipsarna": "slips",
    "slipsarnas": "slips",
    "slipsars": "slips",
    "slipsen": "slips",
    "slipsens": "slips",
    "slipsknutar": "slipsknut",
    "slipsknutarna": "slipsknut",
    "slipsknutarnas": "slipsknut",
    "slipsknutars": "slipsknut",
    "slipsknuten": "slipsknut",
    "slipsknutens": "slipsknut",
    "slipsknuts": "slipsknut",
    "slipsnitten": "slipsnitt",
    "slipsnittens": "slipsnitt",
    "slipsnittet": "slipsnitt",
    "slipsnittets": "slipsnitt",
    "slipsnitts": "slipsnitt",
    "slipstenar": "slipsten",
    "slipstenarna": "slipsten",
    "slipstenarnas": "slipsten",
    "slipstenars": "slipsten",
    "slipstenen": "slipsten",
    "slipstenens": "slipsten",
    "slipstens": "slipsten",
    "slipstvånget": "slipstvång",
    "slipstvångets": "slipstvång",
    "slipstvångs": "slipstvång",
    "slipsvalen": "slipsval",
    "slipsvalens": "slipsval",
    "slipsvalet": "slipsval",
    "slipsvalets": "slipsval",
    "slipsvals": "slipsval",
    "slipsvampar": "slipsvamp",
    "slipsvamparna": "slipsvamp",
    "slipsvamparnas": "slipsvamp",
    "slipsvampars": "slipsvamp",
    "slipsvampen": "slipsvamp",
    "slipsvampens": "slipsvamp",
    "slipsvamps": "slipsvamp",
    "slir": "slira",
    "slirad": "slira",
    "slirade": "slira",
    "slirades": "slira",
    "slirads": "slira",
    "sliran": "slira",
    "slirande": "slira",
    "sliranden": "slirande",
    "slirandena": "slirande",
    "slirandenas": "slirande",
    "slirandens": "slirande",
    "slirandes": "slirande",
    "slirandet": "slirande",
    "slirandets": "slirande",
    "slirans": "slira",
    "slirar": "slira",
    "sliras": "slira",
    "slirat": "slira",
    "slirats": "slira",
    "slire": "slira",
    "sliriga": "slirig",
    "slirigare": "slirig",
    "slirigares": "slirig",
    "slirigas": "slirig",
    "slirigast": "slirig",
    "slirigaste": "slirig",
    "slirigastes": "slirig",
    "slirigasts": "slirig",
    "slirige": "slirig",
    "sliriges": "slirig",
    "slirigheten": "slirighet",
    "slirighetens": "slirighet",
    "slirigheter": "slirighet",
    "slirigheterna": "slirighet",
    "slirigheternas": "slirighet",
    "slirigheters": "slirighet",
    "slirighets": "slirighet",
    "slirigs": "slirig",
    "slirigt": "slirig",
    "slirigts": "slirig",
    "slirkopplingar": "slirkoppling",
    "slirkopplingarna": "slirkoppling",
    "slirkopplingarnas": "slirkoppling",
    "slirkopplingars": "slirkoppling",
    "slirkopplingen": "slirkoppling",
    "slirkopplingens": "slirkoppling",
    "slirkopplings": "slirkoppling",
    "sliror": "slira",
    "slirorna": "slira",
    "slirornas": "slira",
    "slirors": "slira",
    "slirs": "slira",
    "slirskydden": "slirskydd",
    "slirskyddens": "slirskydd",
    "slirskyddet": "slirskydd",
    "slirskyddets": "slirskydd",
    "slirskydds": "slirskydd",
    "slisket": "slisk",
    "sliskets": "slisk",
    "sliskiga": "sliskig",
    "sliskigare": "sliskig",
    "sliskigares": "sliskig",
    "sliskigas": "sliskig",
    "sliskigast": "sliskig",
    "sliskigaste": "sliskig",
    "sliskigastes": "sliskig",
    "sliskigasts": "sliskig",
    "sliskige": "sliskig",
    "sliskiges": "sliskig",
    "sliskigheten": "sliskighet",
    "sliskighetens": "sliskighet",
    "sliskighets": "sliskighet",
    "sliskigs": "sliskig",
    "sliskigt": "sliskig",
    "sliskigts": "sliskig",
    "slisks": "slisk",
    "slit": "slita",
    "slitages": "slitage",
    "slitaget": "slitage",
    "slitagets": "slitage",
    "slitande": "slita",
    "slitanden": "slitande",
    "slitandena": "slitande",
    "slitandenas": "slitande",
    "slitandens": "slitande",
    "slitandes": "slitande",
    "slitandet": "slitande",
    "slitandets": "slitande",
    "slitas": "slita",
    "slitbanan": "slitbana",
    "slitbanans": "slitbana",
    "slitbanas": "slitbana",
    "slitbane": "slitbana",
    "slitbanor": "slitbana",
    "slitbanorna": "slitbana",
    "slitbanornas": "slitbana",
    "slitbanors": "slitbana",
    "slite": "slita",
    "sliten": "slita",
    "slitens": "sliten",
    "sliter": "slita",
    "slites": "slita",
    "slitet": "sliten",
    "slitets": "sliten",
    "slitiga": "slitig",
    "slitigare": "slitig",
    "slitigares": "slitig",
    "slitigas": "slitig",
    "slitigast": "slitig",
    "slitigaste": "slitig",
    "slitigastes": "slitig",
    "slitigasts": "slitig",
    "slitige": "slitig",
    "slitiges": "slitig",
    "slitigs": "slitig",
    "slitigt": "slitig",
    "slitigts": "slitig",
    "slitit": "slita",
    "slitits": "slita",
    "slitna": "sliten",
    "slitnare": "sliten",
    "slitnares": "sliten",
    "slitnas": "sliten",
    "slitnast": "sliten",
    "slitnaste": "sliten",
    "slitnastes": "sliten",
    "slitnasts": "sliten",
    "slitne": "sliten",
    "slitnes": "sliten",
    "slitningar": "slitning",
    "slitningarna": "slitning",
    "slitningarnas": "slitning",
    "slitningars": "slitning",
    "slitningen": "slitning",
    "slitningens": "slitning",
    "slitnings": "slitning",
    "slits": "slitsa",
    "slitsad": "slitsa",
    "slitsade": "slitsa",
    "slitsades": "slitsa",
    "slitsads": "slitsa",
    "slitsamheten": "slitsamhet",
    "slitsamhetens": "slitsamhet",
    "slitsamhets": "slitsamhet",
    "slitsamma": "slitsam",
    "slitsammare": "slitsam",
    "slitsammares": "slitsam",
    "slitsammas": "slitsam",
    "slitsammast": "slitsam",
    "slitsammaste": "slitsam",
    "slitsammastes": "slitsam",
    "slitsammasts": "slitsam",
    "slitsamme": "slitsam",
    "slitsammes": "slitsam",
    "slitsams": "slitsam",
    "slitsamt": "slitsam",
    "slitsamts": "slitsam",
    "slitsande": "slitsa",
    "slitsanden": "slitsande",
    "slitsandena": "slitsande",
    "slitsandenas": "slitsande",
    "slitsandens": "slitsande",
    "slitsandes": "slitsande",
    "slitsandet": "slitsande",
    "slitsandets": "slitsande",
    "slitsar": "slitsa",
    "slitsarna": "slits",
    "slitsarnas": "slits",
    "slitsars": "slits",
    "slitsas": "slitsa",
    "slitsat": "slitsa",
    "slitsats": "slitsa",
    "slitsen": "slits",
    "slitsens": "slits",
    "slitskydden": "slitskydd",
    "slitskyddens": "slitskydd",
    "slitskyddet": "slitskydd",
    "slitskyddets": "slitskydd",
    "slitskydds": "slitskydd",
    "slitstarka": "slitstark",
    "slitstarkare": "slitstark",
    "slitstarkares": "slitstark",
    "slitstarkas": "slitstark",
    "slitstarkast": "slitstark",
    "slitstarkaste": "slitstark",
    "slitstarkastes": "slitstark",
    "slitstarkasts": "slitstark",
    "slitstarke": "slitstark",
    "slitstarkes": "slitstark",
    "slitstarkheten": "slitstarkhet",
    "slitstarkhetens": "slitstarkhet",
    "slitstarkhets": "slitstarkhet",
    "slitstarks": "slitstark",
    "slitstarkt": "slitstark",
    "slitstarkts": "slitstark",
    "slittåliga": "slittålig",
    "slittåligare": "slittålig",
    "slittåligares": "slittålig",
    "slittåligas": "slittålig",
    "slittåligast": "slittålig",
    "slittåligaste": "slittålig",
    "slittåligastes": "slittålig",
    "slittåligasts": "slittålig",
    "slittålige": "slittålig",
    "slittåliges": "slittålig",
    "slittåligheten": "slittålighet",
    "slittålighetens": "slittålighet",
    "slittålighets": "slittålighet",
    "slittåligs": "slittålig",
    "slittåligt": "slittålig",
    "slittåligts": "slittålig",
    "slitvargar": "slitvarg",
    "slitvargarna": "slitvarg",
    "slitvargarnas": "slitvarg",
    "slitvargars": "slitvarg",
    "slitvargen": "slitvarg",
    "slitvargens": "slitvarg",
    "slitvargs": "slitvarg",
    "slitytan": "slityta",
    "slitytans": "slityta",
    "slitytas": "slityta",
    "slityte": "slityta",
    "slitytor": "slityta",
    "slitytorna": "slityta",
    "slitytornas": "slityta",
    "slitytors": "slityta",
    "slivovican": "slivovica",
    "slivovicans": "slivovica",
    "slivovicas": "slivovica",
    "slivovicen": "slivovice",
    "slivovicens": "slivovice",
    "slivovices": "slivovice",
    "slivovitsen": "slivovits",
    "slivovitsens": "slivovits",
    "slivovitzen": "slivovitz",
    "slivovitzens": "slivovitz",
    "sliwowitzen": "sliwowitz",
    "sliwowitzens": "sliwowitz",
    "slocknad": "slockna",
    "slocknade": "slockna",
    "slocknades": "slockna",
    "slocknads": "slockna",
    "slocknande": "slockna",
    "slocknanden": "slocknande",
    "slocknandena": "slocknande",
    "slocknandenas": "slocknande",
    "slocknandens": "slocknande",
    "slocknandes": "slocknande",
    "slocknandet": "slocknande",
    "slocknandets": "slocknande",
    "slocknar": "slockna",
    "slocknas": "slockna",
    "slocknat": "slockna",
    "slocknats": "slockna",
    "slog": "slå",
    "sloganen": "slogan",
    "sloganens": "slogan",
    "slogans": "slogan",
    "slogansen": "slogan",
    "slogansens": "slogan",
    "slogar": "slog",
    "slogarna": "slog",
    "slogarnas": "slog",
    "slogars": "slog",
    "sloge": "slå",
    "slogen": "slog",
    "slogens": "slog",
    "sloges": "slå",
    "slogs": "slog",
    "slok": "sloka",
    "slokad": "sloka",
    "slokade": "sloka",
    "slokades": "sloka",
    "slokads": "sloka",
    "slokande": "sloka",
    "slokanden": "slokande",
    "slokandena": "slokande",
    "slokandenas": "slokande",
    "slokandens": "slokande",
    "slokandes": "slokande",
    "slokandet": "slokande",
    "slokandets": "slokande",
    "slokar": "sloka",
    "slokarna": "slok",
    "slokarnas": "slok",
    "slokars": "slok",
    "slokas": "sloka",
    "slokat": "sloka",
    "slokats": "sloka",
    "sloken": "slok",
    "slokens": "slok",
    "slokhattar": "slokhatt",
    "slokhattarna": "slokhatt",
    "slokhattarnas": "slokhatt",
    "slokhattars": "slokhatt",
    "slokhatten": "slokhatt",
    "slokhattens": "slokhatt",
    "slokhatts": "slokhatt",
    "slokiga": "slokig",
    "slokigare": "slokig",
    "slokigares": "slokig",
    "slokigas": "slokig",
    "slokigast": "slokig",
    "slokigaste": "slokig",
    "slokigastes": "slokig",
    "slokigasts": "slokig",
    "slokige": "slokig",
    "slokiges": "slokig",
    "slokigs": "slokig",
    "slokigt": "slokig",
    "slokigts": "slokig",
    "sloks": "slok",
    "slokörade": "slokörad",
    "slokörades": "slokörad",
    "slokörads": "slokörad",
    "slokörat": "slokörad",
    "slokörats": "slokörad",
    "slommar": "slom",
    "slommarna": "slom",
    "slommarnas": "slom",
    "slommars": "slom",
    "slommen": "slom",
    "slommens": "slom",
    "sloms": "slom",
    "slop": "slopa",
    "slopad": "slopa",
    "slopade": "slopa",
    "slopades": "slopa",
    "slopads": "slopa",
    "slopande": "slopa",
    "slopanden": "slopande",
    "slopandena": "slopande",
    "slopandenas": "slopande",
    "slopandens": "slopande",
    "slopandes": "slopande",
    "slopandet": "slopande",
    "slopandets": "slopande",
    "slopar": "slopa",
    "slopas": "slopa",
    "slopat": "slopa",
    "slopats": "slopa",
    "slosillen": "slosill",
    "slosillens": "slosill",
    "slosills": "slosill",
    "slotten": "slott",
    "slottens": "slott",
    "slottet": "slott",
    "slottets": "slott",
    "slotts": "slott",
    "slottsfruar": "slottsfru",
    "slottsfruarna": "slottsfru",
    "slottsfruarnas": "slottsfru",
    "slottsfruars": "slottsfru",
    "slottsfrun": "slottsfru",
    "slottsfruns": "slottsfru",
    "slottsfrus": "slottsfru",
    "slottsherrar": "slottsherre",
    "slottsherrarna": "slottsherre",
    "slottsherrarnas": "slottsherre",
    "slottsherrars": "slottsherre",
    "slottsherren": "slottsherre",
    "slottsherrens": "slottsherre",
    "slottsherres": "slottsherre",
    "slottsknektar": "slottsknekt",
    "slottsknektarna": "slottsknekt",
    "slottsknektarnas": "slottsknekt",
    "slottsknektars": "slottsknekt",
    "slottsknekten": "slottsknekt",
    "slottsknektens": "slottsknekt",
    "slottsknekts": "slottsknekt",
    "slottskyrk": "slottskyrka",
    "slottskyrkan": "slottskyrka",
    "slottskyrkans": "slottskyrka",
    "slottskyrkas": "slottskyrka",
    "slottskyrke": "slottskyrka",
    "slottskyrko": "slottskyrka",
    "slottskyrkor": "slottskyrka",
    "slottskyrkorna": "slottskyrka",
    "slottskyrkornas": "slottskyrka",
    "slottskyrkors": "slottskyrka",
    "slottskyrks": "slottskyrka",
    "slottsruinen": "slottsruin",
    "slottsruinens": "slottsruin",
    "slottsruiner": "slottsruin",
    "slottsruinerna": "slottsruin",
    "slottsruinernas": "slottsruin",
    "slottsruiners": "slottsruin",
    "slottsruins": "slottsruin",
    "slottssalar": "slottssal",
    "slottssalarna": "slottssal",
    "slottssalarnas": "slottssal",
    "slottssalars": "slottssal",
    "slottssalen": "slottssal",
    "slottssalens": "slottssal",
    "slottssals": "slottssal",
    "slottsstekar": "slottsstek",
    "slottsstekarna": "slottsstek",
    "slottsstekarnas": "slottsstek",
    "slottsstekars": "slottsstek",
    "slottssteken": "slottsstek",
    "slottsstekens": "slottsstek",
    "slottssteks": "slottsstek",
    "slottstappade": "slottstappad",
    "slottstappades": "slottstappad",
    "slottstappads": "slottstappad",
    "slottstappat": "slottstappad",
    "slottstappats": "slottstappad",
    "slottsviner": "slottsvin",
    "slottsvinerna": "slottsvin",
    "slottsvinernas": "slottsvin",
    "slottsviners": "slottsvin",
    "slottsvinet": "slottsvin",
    "slottsvinets": "slottsvin",
    "slottsvins": "slottsvin",
    "slovaken": "slovak",
    "slovakens": "slovak",
    "slovaker": "slovak",
    "slovakerna": "slovak",
    "slovakernas": "slovak",
    "slovakers": "slovak",
    "slovakisk": "slovakiska",
    "slovakiska": "slovakisk",
    "slovakiskan": "slovakiska",
    "slovakiskans": "slovakiska",
    "slovakiskare": "slovakisk",
    "slovakiskares": "slovakisk",
    "slovakiskas": "slovakiska",
    "slovakiskast": "slovakisk",
    "slovakiskaste": "slovakisk",
    "slovakiskastes": "slovakisk",
    "slovakiskasts": "slovakisk",
    "slovakiske": "slovakiska",
    "slovakiskes": "slovakisk",
    "slovakiskor": "slovakiska",
    "slovakiskorna": "slovakiska",
    "slovakiskornas": "slovakiska",
    "slovakiskors": "slovakiska",
    "slovakisks": "slovakisk",
    "slovakiskt": "slovakisk",
    "slovakiskts": "slovakisk",
    "slovaks": "slovak",
    "slovenen": "sloven",
    "slovenens": "sloven",
    "slovener": "sloven",
    "slovenerna": "sloven",
    "slovenernas": "sloven",
    "sloveners": "sloven",
    "slovens": "sloven",
    "slovensk": "slovenska",
    "slovenska": "slovensk",
    "slovenskan": "slovenska",
    "slovenskans": "slovenska",
    "slovenskare": "slovensk",
    "slovenskares": "slovensk",
    "slovenskas": "slovenska",
    "slovenskast": "slovensk",
    "slovenskaste": "slovensk",
    "slovenskastes": "slovensk",
    "slovenskasts": "slovensk",
    "slovenske": "slovenska",
    "slovenskes": "slovensk",
    "slovenskor": "slovenska",
    "slovenskorna": "slovenska",
    "slovenskornas": "slovenska",
    "slovenskors": "slovenska",
    "slovensks": "slovensk",
    "slovenskt": "slovensk",
    "slovenskts": "slovensk",
    "slow-foxar": "slow-fox",
    "slow-foxarna": "slow-fox",
    "slow-foxarnas": "slow-fox",
    "slow-foxars": "slow-fox",
    "slow-foxen": "slow-fox",
    "slow-foxens": "slow-fox",
    "slubb": "slubba",
    "slubbad": "slubba",
    "slubbade": "slubba",
    "slubbades": "slubba",
    "slubbads": "slubba",
    "slubbande": "slubba",
    "slubbanden": "slubbande",
    "slubbandena": "slubbande",
    "slubbandenas": "slubbande",
    "slubbandens": "slubbande",
    "slubbandes": "slubbande",
    "slubbandet": "slubbande",
    "slubbandets": "slubbande",
    "slubbar": "slubba",
    "slubbarna": "slubb",
    "slubbarnas": "slubb",
    "slubbars": "slubb",
    "slubbas": "slubba",
    "slubbat": "slubba",
    "slubbats": "slubba",
    "slubben": "slubb",
    "slubbens": "slubb",
    "slubbs": "slubb",
    "sludder": "sluddra",
    "sludders": "sludder",
    "sluddrad": "sluddra",
    "sluddrade": "sluddra",
    "sluddrades": "sluddra",
    "sluddrads": "sluddra",
    "sluddrande": "sluddra",
    "sluddranden": "sluddrande",
    "sluddrandena": "sluddrande",
    "sluddrandenas": "sluddrande",
    "sluddrandens": "sluddrande",
    "sluddrandes": "sluddrande",
    "sluddrandet": "sluddrande",
    "sluddrandets": "sluddrande",
    "sluddrar": "sluddra",
    "sluddras": "sluddra",
    "sluddrat": "sluddra",
    "sluddrats": "sluddra",
    "sluddret": "sludder",
    "sluddrets": "sludder",
    "sluddriga": "sluddrig",
    "sluddrigare": "sluddrig",
    "sluddrigares": "sluddrig",
    "sluddrigas": "sluddrig",
    "sluddrigast": "sluddrig",
    "sluddrigaste": "sluddrig",
    "sluddrigastes": "sluddrig",
    "sluddrigasts": "sluddrig",
    "sluddrige": "sluddrig",
    "sluddriges": "sluddrig",
    "sluddrigheten": "sluddrighet",
    "sluddrighetens": "sluddrighet",
    "sluddrighets": "sluddrighet",
    "sluddrigs": "sluddrig",
    "sluddrigt": "sluddrig",
    "sluddrigts": "sluddrig",
    "sluga": "slug",
    "slugare": "slug",
    "slugares": "slug",
    "slugas": "slug",
    "slugast": "slug",
    "slugaste": "slug",
    "slugastes": "slug",
    "slugasts": "slug",
    "sluge": "slug",
    "sluges": "slug",
    "slugg": "slugga",
    "sluggad": "slugga",
    "sluggade": "slugga",
    "sluggades": "slugga",
    "sluggads": "slugga",
    "sluggande": "slugga",
    "slugganden": "sluggande",
    "sluggandena": "sluggande",
    "sluggandenas": "sluggande",
    "sluggandens": "sluggande",
    "sluggandes": "sluggande",
    "sluggandet": "sluggande",
    "sluggandets": "sluggande",
    "sluggar": "slugga",
    "sluggas": "slugga",
    "sluggat": "slugga",
    "sluggats": "slugga",
    "sluggermässiga": "sluggermässig",
    "sluggermässigare": "sluggermässig",
    "sluggermässigares": "sluggermässig",
    "sluggermässigas": "sluggermässig",
    "sluggermässigast": "sluggermässig",
    "sluggermässigaste": "sluggermässig",
    "sluggermässigastes": "sluggermässig",
    "sluggermässigasts": "sluggermässig",
    "sluggermässige": "sluggermässig",
    "sluggermässiges": "sluggermässig",
    "sluggermässigs": "sluggermässig",
    "sluggermässigt": "sluggermässig",
    "sluggermässigts": "sluggermässig",
    "sluggern": "slugger",
    "sluggerns": "slugger",
    "sluggers": "slugger",
    "sluggersarna": "slugger",
    "sluggersarnas": "slugger",
    "sluggersen": "slugger",
    "sluggersens": "slugger",
    "sluggrar": "slugger",
    "sluggrarna": "slugger",
    "sluggrarnas": "slugger",
    "sluggrars": "slugger",
    "slugheten": "slughet",
    "slughetens": "slughet",
    "slugheter": "slughet",
    "slugheterna": "slughet",
    "slugheternas": "slughet",
    "slugheters": "slughet",
    "slughets": "slughet",
    "slughuvuden": "slughuvud",
    "slughuvudena": "slughuvud",
    "slughuvudenas": "slughuvud",
    "slughuvudens": "slughuvud",
    "slughuvudet": "slughuvud",
    "slughuvudets": "slughuvud",
    "slughuvuds": "slughuvud",
    "slugs": "slug",
    "slugt": "slug",
    "slugts": "slug",
    "sluk": "sluka",
    "slukad": "sluka",
    "slukade": "sluka",
    "slukades": "sluka",
    "slukads": "sluka",
    "slukande": "sluka",
    "slukanden": "slukande",
    "slukandena": "slukande",
    "slukandenas": "slukande",
    "slukandens": "slukande",
    "slukandes": "slukande",
    "slukandet": "slukande",
    "slukandets": "slukande",
    "slukar": "sluka",
    "slukas": "sluka",
    "slukat": "sluka",
    "slukats": "sluka",
    "sluke": "sluka",
    "slukes": "sluka",
    "slukristar": "slukrist",
    "slukristarna": "slukrist",
    "slukristarnas": "slukrist",
    "slukristars": "slukrist",
    "slukristen": "slukrist",
    "slukristens": "slukrist",
    "slukrister": "slukrist",
    "slukristerna": "slukrist",
    "slukristernas": "slukrist",
    "slukristers": "slukrist",
    "slukrists": "slukrist",
    "slummen": "slum",
    "slummens": "slum",
    "slummern": "slummer",
    "slummerns": "slummer",
    "slummers": "slummer",
    "slumområden": "slumområde",
    "slumområdena": "slumområde",
    "slumområdenas": "slumområde",
    "slumområdens": "slumområde",
    "slumområdes": "slumområde",
    "slumområdet": "slumområde",
    "slumområdets": "slumområde",
    "slump": "slumpa",
    "slumpad": "slumpa",
    "slumpade": "slumpa",
    "slumpades": "slumpa",
    "slumpads": "slumpa",
    "slumpande": "slumpa",
    "slumpanden": "slumpande",
    "slumpandena": "slumpande",
    "slumpandenas": "slumpande",
    "slumpandens": "slumpande",
    "slumpandes": "slumpande",
    "slumpandet": "slumpande",
    "slumpandets": "slumpande",
    "slumpar": "slumpa",
    "slumparna": "slump",
    "slumparnas": "slump",
    "slumpars": "slump",
    "slumpartade": "slumpartad",
    "slumpartades": "slumpartad",
    "slumpartads": "slumpartad",
    "slumpartat": "slumpartad",
    "slumpartats": "slumpartad",
    "slumpas": "slumpa",
    "slumpat": "slumpa",
    "slumpats": "slumpa",
    "slumpen": "slump",
    "slumpens": "slump",
    "slumper": "slump",
    "slumperna": "slump",
    "slumpernas": "slump",
    "slumpers": "slump",
    "slumpmässiga": "slumpmässig",
    "slumpmässigare": "slumpmässig",
    "slumpmässigares": "slumpmässig",
    "slumpmässigas": "slumpmässig",
    "slumpmässigast": "slumpmässig",
    "slumpmässigaste": "slumpmässig",
    "slumpmässigastes": "slumpmässig",
    "slumpmässigasts": "slumpmässig",
    "slumpmässige": "slumpmässig",
    "slumpmässiges": "slumpmässig",
    "slumpmässigheten": "slumpmässighet",
    "slumpmässighetens": "slumpmässighet",
    "slumpmässighets": "slumpmässighet",
    "slumpmässigs": "slumpmässig",
    "slumpmässigt": "slumpmässig",
    "slumpmässigts": "slumpmässig",
    "slumps": "slump",
    "slumptalen": "slumptal",
    "slumptalens": "slumptal",
    "slumptalet": "slumptal",
    "slumptalets": "slumptal",
    "slumptals": "slumptal",
    "slumrade": "slumra",
    "slumrades": "slumra",
    "slumrande": "slumra",
    "slumranden": "slumrande",
    "slumrandena": "slumrande",
    "slumrandenas": "slumrande",
    "slumrandens": "slumrande",
    "slumrandes": "slumrande",
    "slumrandet": "slumrande",
    "slumrandets": "slumrande",
    "slumrar": "slumra",
    "slumras": "slumra",
    "slumrat": "slumra",
    "slumrats": "slumra",
    "slums": "slum",
    "slumsystern": "slumsyster",
    "slumsysterns": "slumsyster",
    "slumsysters": "slumsyster",
    "slumsystrar": "slumsyster",
    "slumsystrarna": "slumsyster",
    "slumsystrarnas": "slumsyster",
    "slumsystrars": "slumsyster",
    "slung": "slunga",
    "slungad": "slunga",
    "slungade": "slunga",
    "slungades": "slunga",
    "slungads": "slunga",
    "slungan": "slunga",
    "slungande": "slunga",
    "slunganden": "slungande",
    "slungandena": "slungande",
    "slungandenas": "slungande",
    "slungandens": "slungande",
    "slungandes": "slungande",
    "slungandet": "slungande",
    "slungandets": "slungande",
    "slungans": "slunga",
    "slungar": "slunga",
    "slungas": "slunga",
    "slungat": "slunga",
    "slungats": "slunga",
    "slungbollar": "slungboll",
    "slungbollarna": "slungboll",
    "slungbollarnas": "slungboll",
    "slungbollars": "slungboll",
    "slungbollen": "slungboll",
    "slungbollens": "slungboll",
    "slungbolls": "slungboll",
    "slunge": "slunga",
    "slungor": "slunga",
    "slungorna": "slunga",
    "slungornas": "slunga",
    "slungors": "slunga",
    "slungs": "slunga",
    "slunke": "slinka",
    "slunkes": "slinka",
    "slunkit": "slinka",
    "slunkits": "slinka",
    "slunte": "slinta",
    "sluntes": "slinta",
    "sluntit": "slinta",
    "sluntits": "slinta",
    "slupar": "slup",
    "sluparna": "slup",
    "sluparnas": "slup",
    "slupars": "slup",
    "slupen": "slup",
    "slupens": "slup",
    "sluppe": "slippa",
    "sluppes": "slippa",
    "sluppit": "slippa",
    "sluppits": "slippa",
    "slups": "slup",
    "slurf": "slurfa",
    "slurfade": "slurfa",
    "slurfades": "slurfa",
    "slurfande": "slurfa",
    "slurfandes": "slurfa",
    "slurfar": "slurfa",
    "slurfas": "slurfa",
    "slurfat": "slurfa",
    "slurfats": "slurfa",
    "sluringen": "sluring",
    "sluringens": "sluring",
    "slurings": "sluring",
    "slurkar": "slurk",
    "slurkarna": "slurk",
    "slurkarnas": "slurk",
    "slurkars": "slurk",
    "slurken": "slurk",
    "slurkens": "slurk",
    "slurks": "slurk",
    "sluskar": "slusk",
    "sluskarna": "slusk",
    "sluskarnas": "slusk",
    "sluskars": "slusk",
    "slusken": "slusk",
    "sluskens": "slusk",
    "sluskiga": "sluskig",
    "sluskigare": "sluskig",
    "sluskigares": "sluskig",
    "sluskigas": "sluskig",
    "sluskigast": "sluskig",
    "sluskigaste": "sluskig",
    "sluskigastes": "sluskig",
    "sluskigasts": "sluskig",
    "sluskige": "sluskig",
    "sluskiges": "sluskig",
    "sluskigheten": "sluskighet",
    "sluskighetens": "sluskighet",
    "sluskighets": "sluskighet",
    "sluskigs": "sluskig",
    "sluskigt": "sluskig",
    "sluskigts": "sluskig",
    "slusks": "slusk",
    "sluss": "slussa",
    "slussad": "slussa",
    "slussade": "slussa",
    "slussades": "slussa",
    "slussads": "slussa",
    "slussande": "slussa",
    "slussanden": "slussande",
    "slussandena": "slussande",
    "slussandenas": "slussande",
    "slussandens": "slussande",
    "slussandes": "slussande",
    "slussandet": "slussande",
    "slussandets": "slussande",
    "slussar": "slussa",
    "slussarna": "sluss",
    "slussarnas": "sluss",
    "slussars": "sluss",
    "slussas": "slussa",
    "slussat": "slussa",
    "slussats": "slussa",
    "slussen": "sluss",
    "slussens": "sluss",
    "slusshuvuden": "slusshuvud",
    "slusshuvudena": "slusshuvud",
    "slusshuvudenas": "slusshuvud",
    "slusshuvudens": "slusshuvud",
    "slusshuvudet": "slusshuvud",
    "slusshuvudets": "slusshuvud",
    "slusshuvuds": "slusshuvud",
    "slussportar": "slussport",
    "slussportarna": "slussport",
    "slussportarnas": "slussport",
    "slussportars": "slussport",
    "slussporten": "slussport",
    "slussportens": "slussport",
    "slussports": "slussport",
    "slusstrapp": "slusstrappa",
    "slusstrappan": "slusstrappa",
    "slusstrappans": "slusstrappa",
    "slusstrappas": "slusstrappa",
    "slusstrappe": "slusstrappa",
    "slusstrappor": "slusstrappa",
    "slusstrapporna": "slusstrappa",
    "slusstrappornas": "slusstrappa",
    "slusstrappors": "slusstrappa",
    "slusstrapps": "slusstrappa",
    "slut": "sluta",
    "slutade": "sluta",
    "slutades": "sluta",
    "slutande": "sluta",
    "slutanden": "slutande",
    "slutandena": "slutande",
    "slutandenas": "slutande",
    "slutandens": "slutande",
    "slutandes": "slutande",
    "slutandet": "slutande",
    "slutandets": "slutande",
    "slutar": "slutare",
    "slutaren": "slutare",
    "slutarens": "slutare",
    "slutares": "slutare",
    "slutarna": "slutare",
    "slutarnas": "slutare",
    "slutartikeln": "slutartikel",
    "slutartikelns": "slutartikel",
    "slutartikels": "slutartikel",
    "slutartiklar": "slutartikel",
    "slutartiklarna": "slutartikel",
    "slutartiklarnas": "slutartikel",
    "slutartiklars": "slutartikel",
    "slutas": "sluta",
    "slutat": "sluta",
    "slutats": "sluta",
    "slutbehandlad": "slutbehandla",
    "slutbehandlade": "slutbehandla",
    "slutbehandlades": "slutbehandla",
    "slutbehandlads": "slutbehandla",
    "slutbehandlande": "slutbehandla",
    "slutbehandlanden": "slutbehandlande",
    "slutbehandlandena": "slutbehandlande",
    "slutbehandlandenas": "slutbehandlande",
    "slutbehandlandens": "slutbehandlande",
    "slutbehandlandes": "slutbehandlande",
    "slutbehandlandet": "slutbehandlande",
    "slutbehandlandets": "slutbehandlande",
    "slutbehandlar": "slutbehandla",
    "slutbehandlas": "slutbehandla",
    "slutbehandlat": "slutbehandla",
    "slutbehandlats": "slutbehandla",
    "slute": "sluta",
    "sluten": "sluta",
    "slutens": "sluten",
    "slutenvården": "slutenvård",
    "slutenvårdens": "slutenvård",
    "slutenvårds": "slutenvård",
    "sluter": "sluta",
    "slutes": "sluta",
    "slutet": "sluten",
    "slutets": "sluten",
    "slutfallen": "slutfall",
    "slutfallens": "slutfall",
    "slutfallet": "slutfall",
    "slutfallets": "slutfall",
    "slutfalls": "slutfall",
    "slutfasen": "slutfas",
    "slutfasens": "slutfas",
    "slutfaser": "slutfas",
    "slutfaserna": "slutfas",
    "slutfasernas": "slutfas",
    "slutfasers": "slutfas",
    "slutfår": "slutfåra",
    "slutfåran": "slutfåra",
    "slutfårans": "slutfåra",
    "slutfåras": "slutfåra",
    "slutfåre": "slutfåra",
    "slutfåror": "slutfåra",
    "slutfårorna": "slutfåra",
    "slutfårornas": "slutfåra",
    "slutfårors": "slutfåra",
    "slutfårs": "slutfåra",
    "slutför": "slutföra",
    "slutförande": "slutföra",
    "slutföranden": "slutförande",
    "slutförandena": "slutförande",
    "slutförandenas": "slutförande",
    "slutförandens": "slutförande",
    "slutförandes": "slutförande",
    "slutförandet": "slutförande",
    "slutförandets": "slutförande",
    "slutföras": "slutföra",
    "slutförd": "slutföra",
    "slutförda": "slutföra",
    "slutfördas": "slutföra",
    "slutförde": "slutföra",
    "slutfördes": "slutföra",
    "slutförds": "slutföra",
    "slutföres": "slutföra",
    "slutförs": "slutföra",
    "slutfört": "slutföra",
    "slutförts": "slutföra",
    "slutförvaringar": "slutförvaring",
    "slutförvaringarna": "slutförvaring",
    "slutförvaringarnas": "slutförvaring",
    "slutförvaringars": "slutförvaring",
    "slutförvaringen": "slutförvaring",
    "slutförvaringens": "slutförvaring",
    "slutförvarings": "slutförvaring",
    "slutgiltiga": "slutgiltig",
    "slutgiltigare": "slutgiltig",
    "slutgiltigares": "slutgiltig",
    "slutgiltigas": "slutgiltig",
    "slutgiltigast": "slutgiltig",
    "slutgiltigaste": "slutgiltig",
    "slutgiltigastes": "slutgiltig",
    "slutgiltigasts": "slutgiltig",
    "slutgiltige": "slutgiltig",
    "slutgiltiges": "slutgiltig",
    "slutgiltigheten": "slutgiltighet",
    "slutgiltighetens": "slutgiltighet",
    "slutgiltighets": "slutgiltighet",
    "slutgiltigs": "slutgiltig",
    "slutgiltigt": "slutgiltig",
    "slutgiltigts": "slutgiltig",
    "slutit": "sluta",
    "slutits": "sluta",
    "slutklämmar": "slutkläm",
    "slutklämmarna": "slutkläm",
    "slutklämmarnas": "slutkläm",
    "slutklämmars": "slutkläm",
    "slutklämmen": "slutkläm",
    "slutklämmens": "slutkläm",
    "slutkläms": "slutkläm",
    "slutkörda": "slutkörd",
    "slutkördare": "slutkörd",
    "slutkördares": "slutkörd",
    "slutkördas": "slutkörd",
    "slutkördast": "slutkörd",
    "slutkördaste": "slutkörd",
    "slutkördastes": "slutkörd",
    "slutkördasts": "slutkörd",
    "slutkörde": "slutkörd",
    "slutkördes": "slutkörd",
    "slutkördheten": "slutkördhet",
    "slutkördhetens": "slutkördhet",
    "slutkördhets": "slutkördhet",
    "slutkörds": "slutkörd",
    "slutkört": "slutkörd",
    "slutkörts": "slutkörd",
    "slutledningar": "slutledning",
    "slutledningarna": "slutledning",
    "slutledningarnas": "slutledning",
    "slutledningars": "slutledning",
    "slutledningen": "slutledning",
    "slutledningens": "slutledning",
    "slutlednings": "slutledning",
    "slutliga": "slutlig",
    "slutligare": "slutlig",
    "slutligares": "slutlig",
    "slutligas": "slutlig",
    "slutligast": "slutlig",
    "slutligaste": "slutlig",
    "slutligastes": "slutlig",
    "slutligasts": "slutlig",
    "slutlige": "slutlig",
    "slutliges": "slutlig",
    "slutligheten": "slutlighet",
    "slutlighetens": "slutlighet",
    "slutlighets": "slutlighet",
    "slutligs": "slutlig",
    "slutligt": "slutlig",
    "slutligts": "slutlig",
    "slutljuden": "slutljud",
    "slutljudens": "slutljud",
    "slutljudet": "slutljud",
    "slutljudets": "slutljud",
    "slutljuds": "slutljud",
    "slutlönen": "slutlön",
    "slutlönens": "slutlön",
    "slutlöner": "slutlön",
    "slutlönerna": "slutlön",
    "slutlönernas": "slutlön",
    "slutlöners": "slutlön",
    "slutlöns": "slutlön",
    "slutminuten": "slutminut",
    "slutminutens": "slutminut",
    "slutminuter": "slutminut",
    "slutminuterna": "slutminut",
    "slutminuternas": "slutminut",
    "slutminuters": "slutminut",
    "slutminutrar": "slutminut",
    "slutminutrarna": "slutminut",
    "slutminutrarnas": "slutminut",
    "slutminutrars": "slutminut",
    "slutminuts": "slutminut",
    "slutmålen": "slutmål",
    "slutmålens": "slutmål",
    "slutmålet": "slutmål",
    "slutmålets": "slutmål",
    "slutmåls": "slutmål",
    "slutna": "sluten",
    "slutnare": "sluten",
    "slutnares": "sluten",
    "slutnas": "sluten",
    "slutnast": "sluten",
    "slutnaste": "sluten",
    "slutnastes": "sluten",
    "slutnasts": "sluten",
    "slutne": "sluten",
    "slutnes": "sluten",
    "slutnotan": "slutnota",
    "slutnotans": "slutnota",
    "slutnotas": "slutnota",
    "slutnote": "slutnota",
    "slutnotor": "slutnota",
    "slutnotorna": "slutnota",
    "slutnotornas": "slutnota",
    "slutnotors": "slutnota",
    "slutoffensiven": "slutoffensiv",
    "slutoffensivens": "slutoffensiv",
    "slutoffensiver": "slutoffensiv",
    "slutoffensiverna": "slutoffensiv",
    "slutoffensivernas": "slutoffensiv",
    "slutoffensivers": "slutoffensiv",
    "slutoffensivs": "slutoffensiv",
    "slutpläderade": "slutplädera",
    "slutpläderades": "slutplädera",
    "slutpläderande": "slutplädera",
    "slutpläderanden": "slutpläderande",
    "slutpläderandena": "slutpläderande",
    "slutpläderandenas": "slutpläderande",
    "slutpläderandens": "slutpläderande",
    "slutpläderandes": "slutpläderande",
    "slutpläderandet": "slutpläderande",
    "slutpläderandets": "slutpläderande",
    "slutpläderar": "slutplädera",
    "slutpläderas": "slutplädera",
    "slutpläderat": "slutplädera",
    "slutpläderats": "slutplädera",
    "slutpläderingar": "slutplädering",
    "slutpläderingarna": "slutplädering",
    "slutpläderingarnas": "slutplädering",
    "slutpläderingars": "slutplädering",
    "slutpläderingen": "slutplädering",
    "slutpläderingens": "slutplädering",
    "slutpläderings": "slutplädering",
    "slutprodukten": "slutprodukt",
    "slutproduktens": "slutprodukt",
    "slutprodukter": "slutprodukt",
    "slutprodukterna": "slutprodukt",
    "slutprodukternas": "slutprodukt",
    "slutprodukters": "slutprodukt",
    "slutprodukts": "slutprodukt",
    "slutproven": "slutprov",
    "slutprovens": "slutprov",
    "slutprovet": "slutprov",
    "slutprovets": "slutprov",
    "slutprovs": "slutprov",
    "slutpunkten": "slutpunkt",
    "slutpunktens": "slutpunkt",
    "slutpunkter": "slutpunkt",
    "slutpunkterna": "slutpunkt",
    "slutpunkternas": "slutpunkt",
    "slutpunkters": "slutpunkt",
    "slutpunkts": "slutpunkt",
    "slutraden": "slutrad",
    "slutradens": "slutrad",
    "slutrader": "slutrad",
    "slutraderna": "slutrad",
    "slutradernas": "slutrad",
    "slutraders": "slutrad",
    "slutrads": "slutrad",
    "slutresultaten": "slutresultat",
    "slutresultatens": "slutresultat",
    "slutresultatet": "slutresultat",
    "slutresultatets": "slutresultat",
    "slutresultats": "slutresultat",
    "slutrimmen": "slutrim",
    "slutrimmens": "slutrim",
    "slutrimmet": "slutrim",
    "slutrimmets": "slutrim",
    "slutrims": "slutrim",
    "sluts": "sluta",
    "slutsatsen": "slutsats",
    "slutsatsens": "slutsats",
    "slutsatser": "slutsats",
    "slutsatserna": "slutsats",
    "slutsatsernas": "slutsats",
    "slutsatsers": "slutsats",
    "slutskeden": "slutskede",
    "slutskedena": "slutskede",
    "slutskedenas": "slutskede",
    "slutskedens": "slutskede",
    "slutskedes": "slutskede",
    "slutskedet": "slutskede",
    "slutskedets": "slutskede",
    "slutskriften": "slutskrift",
    "slutskriftens": "slutskrift",
    "slutskrifter": "slutskrift",
    "slutskrifterna": "slutskrift",
    "slutskrifternas": "slutskrift",
    "slutskrifters": "slutskrift",
    "slutskrifts": "slutskrift",
    "slutspelen": "slutspel",
    "slutspelens": "slutspel",
    "slutspelet": "slutspel",
    "slutspelets": "slutspel",
    "slutspels": "slutspel",
    "slutspurten": "slutspurt",
    "slutspurtens": "slutspurt",
    "slutspurter": "slutspurt",
    "slutspurterna": "slutspurt",
    "slutspurternas": "slutspurt",
    "slutspurters": "slutspurt",
    "slutspurts": "slutspurt",
    "slutstationen": "slutstation",
    "slutstationens": "slutstation",
    "slutstationer": "slutstation",
    "slutstationerna": "slutstation",
    "slutstationernas": "slutstation",
    "slutstationers": "slutstation",
    "slutstations": "slutstation",
    "slutstegen": "slutsteg",
    "slutstegens": "slutsteg",
    "slutsteget": "slutsteg",
    "slutstegets": "slutsteg",
    "slutstegs": "slutsteg",
    "slutstenar": "slutsten",
    "slutstenarna": "slutsten",
    "slutstenarnas": "slutsten",
    "slutstenars": "slutsten",
    "slutstenen": "slutsten",
    "slutstenens": "slutsten",
    "slutstens": "slutsten",
    "slutstrecken": "slutstreck",
    "slutstreckens": "slutstreck",
    "slutstrecket": "slutstreck",
    "slutstreckets": "slutstreck",
    "slutstrecks": "slutstreck",
    "slutsträck": "slutsträcka",
    "slutsträckan": "slutsträcka",
    "slutsträckans": "slutsträcka",
    "slutsträckas": "slutsträcka",
    "slutsträcke": "slutsträcka",
    "slutsträckor": "slutsträcka",
    "slutsträckorna": "slutsträcka",
    "slutsträckornas": "slutsträcka",
    "slutsträckors": "slutsträcka",
    "slutsträcks": "slutsträcka",
    "slutstycken": "slutstycke",
    "slutstyckena": "slutstycke",
    "slutstyckenas": "slutstycke",
    "slutstyckens": "slutstycke",
    "slutstyckes": "slutstycke",
    "slutstycket": "slutstycke",
    "slutstyckets": "slutstycke",
    "slutstycks": "slutstycke",
    "slutt": "slutta",
    "sluttad": "slutta",
    "sluttade": "slutta",
    "sluttades": "slutta",
    "sluttads": "slutta",
    "sluttampen": "sluttamp",
    "sluttampens": "sluttamp",
    "sluttamps": "sluttamp",
    "sluttande": "slutta",
    "sluttanden": "sluttande",
    "sluttandena": "sluttande",
    "sluttandenas": "sluttande",
    "sluttandens": "sluttande",
    "sluttandes": "sluttande",
    "sluttandet": "sluttande",
    "sluttandets": "sluttande",
    "sluttar": "slutta",
    "sluttas": "slutta",
    "sluttat": "slutta",
    "sluttats": "slutta",
    "sluttningar": "sluttning",
    "sluttningarna": "sluttning",
    "sluttningarnas": "sluttning",
    "sluttningars": "sluttning",
    "sluttningen": "sluttning",
    "sluttningens": "sluttning",
    "sluttnings": "sluttning",
    "slutuppgörelsen": "slutuppgörelse",
    "slutuppgörelsens": "slutuppgörelse",
    "slutuppgörelser": "slutuppgörelse",
    "slutuppgörelserna": "slutuppgörelse",
    "slutuppgörelsernas": "slutuppgörelse",
    "slutuppgörelsers": "slutuppgörelse",
    "slutuppgörelses": "slutuppgörelse",
    "slutverkans": "slutverkan",
    "slutvinjetten": "slutvinjett",
    "slutvinjettens": "slutvinjett",
    "slutvinjetter": "slutvinjett",
    "slutvinjetterna": "slutvinjett",
    "slutvinjetternas": "slutvinjett",
    "slutvinjetters": "slutvinjett",
    "slutvinjetts": "slutvinjett",
    "slutvokalen": "slutvokal",
    "slutvokalens": "slutvokal",
    "slutvokaler": "slutvokal",
    "slutvokalerna": "slutvokal",
    "slutvokalernas": "slutvokal",
    "slutvokalers": "slutvokal",
    "slutvokals": "slutvokal",
    "sly": "slya",
    "slyan": "slya",
    "slyans": "slya",
    "slyas": "slya",
    "slye": "slya",
    "slyet": "sly",
    "slyets": "sly",
    "slykling": "slyklinga",
    "slyklingan": "slyklinga",
    "slyklingans": "slyklinga",
    "slyklingas": "slyklinga",
    "slyklinge": "slyklinga",
    "slyklingor": "slyklinga",
    "slyklingorna": "slyklinga",
    "slyklingornas": "slyklinga",
    "slyklingors": "slyklinga",
    "slyklings": "slyklinga",
    "slyn": "slyna",
    "slyna": "sly",
    "slynan": "slyna",
    "slynans": "slyna",
    "slynas": "slyna",
    "slyne": "slyna",
    "slyng": "slynga",
    "slyngan": "slynga",
    "slyngans": "slynga",
    "slyngas": "slynga",
    "slynge": "slynga",
    "slyngeln": "slyngel",
    "slyngelns": "slyngel",
    "slyngels": "slyngel",
    "slynglar": "slyngel",
    "slynglarna": "slyngel",
    "slynglarnas": "slyngel",
    "slynglars": "slyngel",
    "slyngor": "slynga",
    "slyngorna": "slynga",
    "slyngornas": "slynga",
    "slyngors": "slynga",
    "slyngs": "slynga",
    "slyniga": "slynig",
    "slynigare": "slynig",
    "slynigares": "slynig",
    "slynigas": "slynig",
    "slynigast": "slynig",
    "slynigaste": "slynig",
    "slynigastes": "slynig",
    "slynigasts": "slynig",
    "slynige": "slynig",
    "slyniges": "slynig",
    "slynigs": "slynig",
    "slynigt": "slynig",
    "slynigts": "slynig",
    "slynor": "slyna",
    "slynorna": "slyna",
    "slynornas": "slyna",
    "slynors": "slyna",
    "slyns": "slyna",
    "slyor": "slya",
    "slyorna": "slya",
    "slyornas": "slya",
    "slyors": "slya",
    "slypinn": "slypinne",
    "slypinnar": "slypinne",
    "slypinnarna": "slypinne",
    "slypinnarnas": "slypinne",
    "slypinnars": "slypinne",
    "slypinnen": "slypinne",
    "slypinnens": "slypinne",
    "slypinnes": "slypinne",
    "slypinns": "slypinne",
    "slys": "slya",
    "slyt": "sly",
    "slyts": "sly",
    "släck": "släcka",
    "släckande": "släcka",
    "släckanden": "släckande",
    "släckandena": "släckande",
    "släckandenas": "släckande",
    "släckandens": "släckande",
    "släckandes": "släckande",
    "släckandet": "släckande",
    "släckandets": "släckande",
    "släckas": "släcka",
    "släcker": "släcka",
    "släckes": "släcka",
    "släcks": "släcka",
    "släckt": "släcka",
    "släckta": "släcka",
    "släcktas": "släcka",
    "släckte": "släcka",
    "släcktes": "släcka",
    "släckts": "släcka",
    "släd": "släde",
    "slädar": "släde",
    "slädarna": "släde",
    "slädarnas": "släde",
    "slädars": "släde",
    "släddonen": "släddon",
    "släddonens": "släddon",
    "släddonet": "släddon",
    "släddonets": "släddon",
    "släddons": "släddon",
    "släden": "släde",
    "slädens": "släde",
    "slädes": "släde",
    "slädhundar": "slädhund",
    "slädhundarna": "slädhund",
    "slädhundarnas": "slädhund",
    "slädhundars": "slädhund",
    "slädhunden": "slädhund",
    "slädhundens": "slädhund",
    "slädhunds": "slädhund",
    "slädmedar": "slädmed",
    "slädmedarna": "slädmed",
    "slädmedarnas": "slädmed",
    "slädmedars": "slädmed",
    "slädmeden": "slädmed",
    "slädmedens": "slädmed",
    "slädmeds": "slädmed",
    "slädpartier": "slädparti",
    "slädpartierna": "slädparti",
    "slädpartiernas": "slädparti",
    "slädpartiers": "slädparti",
    "slädpartiet": "slädparti",
    "slädpartiets": "slädparti",
    "slädpartis": "slädparti",
    "slädpartit": "slädparti",
    "slädpartits": "slädparti",
    "släds": "släde",
    "slägg": "slägga",
    "släggad": "slägga",
    "släggade": "slägga",
    "släggades": "slägga",
    "släggads": "slägga",
    "släggan": "slägga",
    "släggande": "slägga",
    "slägganden": "släggande",
    "släggandena": "släggande",
    "släggandenas": "släggande",
    "släggandens": "släggande",
    "släggandes": "släggande",
    "släggandet": "släggande",
    "släggandets": "släggande",
    "släggans": "slägga",
    "släggar": "slägga",
    "släggas": "slägga",
    "släggat": "slägga",
    "släggats": "slägga",
    "slägge": "slägga",
    "slägghammar": "slägghammare",
    "slägghammaren": "slägghammare",
    "slägghammarens": "slägghammare",
    "slägghammares": "slägghammare",
    "slägghamrar": "slägghammare",
    "slägghamrarna": "slägghammare",
    "slägghamrarnas": "slägghammare",
    "slägghamrars": "slägghammare",
    "släggor": "slägga",
    "släggorna": "slägga",
    "släggornas": "slägga",
    "släggors": "slägga",
    "släggs": "slägga",
    "släktades": "släktas",
    "släktats": "släktas",
    "släktbanden": "släktband",
    "släktbandens": "släktband",
    "släktbandet": "släktband",
    "släktbandets": "släktband",
    "släktbands": "släktband",
    "släktbesöken": "släktbesök",
    "släktbesökens": "släktbesök",
    "släktbesöket": "släktbesök",
    "släktbesökets": "släktbesök",
    "släktbesöks": "släktbesök",
    "släktdragen": "släktdrag",
    "släktdragens": "släktdrag",
    "släktdraget": "släktdrag",
    "släktdragets": "släktdrag",
    "släktdrags": "släktdrag",
    "släktdriften": "släktdrift",
    "släktdriftens": "släktdrift",
    "släktdrifter": "släktdrift",
    "släktdrifterna": "släktdrift",
    "släktdrifternas": "släktdrift",
    "släktdrifters": "släktdrift",
    "släktdrifts": "släktdrift",
    "släkten": "släkte",
    "släktena": "släkte",
    "släktenas": "släkte",
    "släktens": "släkte",
    "släkter": "släkt",
    "släkterna": "släkt",
    "släkternas": "släkt",
    "släkters": "släkt",
    "släktes": "släkte",
    "släktet": "släkte",
    "släktets": "släkte",
    "släktfejden": "släktfejd",
    "släktfejdens": "släktfejd",
    "släktfejder": "släktfejd",
    "släktfejderna": "släktfejd",
    "släktfejdernas": "släktfejd",
    "släktfejders": "släktfejd",
    "släktfejds": "släktfejd",
    "släktforskningar": "släktforskning",
    "släktforskningarna": "släktforskning",
    "släktforskningarnas": "släktforskning",
    "släktforskningars": "släktforskning",
    "släktforskningen": "släktforskning",
    "släktforskningens": "släktforskning",
    "släktforsknings": "släktforskning",
    "släktgårdar": "släktgård",
    "släktgårdarna": "släktgård",
    "släktgårdarnas": "släktgård",
    "släktgårdars": "släktgård",
    "släktgården": "släktgård",
    "släktgårdens": "släktgård",
    "släktgårds": "släktgård",
    "släkthistorian": "släkthistoria",
    "släkthistorians": "släkthistoria",
    "släkthistorias": "släkthistoria",
    "släkthistorien": "släkthistoria",
    "släkthistoriens": "släkthistoria",
    "släkthistorier": "släkthistoria",
    "släkthistorierna": "släkthistoria",
    "släkthistoriernas": "släkthistoria",
    "släkthistoriers": "släkthistoria",
    "släktingar": "släkting",
    "släktingarna": "släkting",
    "släktingarnas": "släkting",
    "släktingars": "släkting",
    "släktingen": "släkting",
    "släktingens": "släkting",
    "släktings": "släkting",
    "släktkalasen": "släktkalas",
    "släktkalasens": "släktkalas",
    "släktkalaset": "släktkalas",
    "släktkalasets": "släktkalas",
    "släktkrönik": "släktkrönika",
    "släktkrönikan": "släktkrönika",
    "släktkrönikans": "släktkrönika",
    "släktkrönikas": "släktkrönika",
    "släktkrönike": "släktkrönika",
    "släktkrönikor": "släktkrönika",
    "släktkrönikorna": "släktkrönika",
    "släktkrönikornas": "släktkrönika",
    "släktkrönikors": "släktkrönika",
    "släktkröniks": "släktkrönika",
    "släktleden": "släktled",
    "släktledens": "släktled",
    "släktledet": "släktled",
    "släktledets": "släktled",
    "släktledningar": "släktledning",
    "släktledningarna": "släktledning",
    "släktledningarnas": "släktledning",
    "släktledningars": "släktledning",
    "släktledningen": "släktledning",
    "släktledningens": "släktledning",
    "släktlednings": "släktledning",
    "släktleds": "släktled",
    "släktlinjen": "släktlinje",
    "släktlinjens": "släktlinje",
    "släktlinjer": "släktlinje",
    "släktlinjerna": "släktlinje",
    "släktlinjernas": "släktlinje",
    "släktlinjers": "släktlinje",
    "släktlinjes": "släktlinje",
    "släktmässiga": "släktmässig",
    "släktmässigare": "släktmässig",
    "släktmässigares": "släktmässig",
    "släktmässigas": "släktmässig",
    "släktmässigast": "släktmässig",
    "släktmässigaste": "släktmässig",
    "släktmässigastes": "släktmässig",
    "släktmässigasts": "släktmässig",
    "släktmässige": "släktmässig",
    "släktmässiges": "släktmässig",
    "släktmässigs": "släktmässig",
    "släktmässigt": "släktmässig",
    "släktmässigts": "släktmässig",
    "släktnamnen": "släktnamn",
    "släktnamnens": "släktnamn",
    "släktnamnet": "släktnamn",
    "släktnamnets": "släktnamn",
    "släktnamns": "släktnamn",
    "släktporträtten": "släktporträtt",
    "släktporträttens": "släktporträtt",
    "släktporträttet": "släktporträtt",
    "släktporträttets": "släktporträtt",
    "släktporträtts": "släktporträtt",
    "släktregisterna": "släktregister",
    "släktregisternas": "släktregister",
    "släktregisters": "släktregister",
    "släktregistren": "släktregister",
    "släktregistrens": "släktregister",
    "släktregistret": "släktregister",
    "släktregistrets": "släktregister",
    "släkts": "släkte",
    "släktsagan": "släktsaga",
    "släktsagans": "släktsaga",
    "släktsagas": "släktsaga",
    "släktsage": "släktsaga",
    "släktsago": "släktsaga",
    "släktsagor": "släktsaga",
    "släktsagorna": "släktsaga",
    "släktsagornas": "släktsaga",
    "släktsagors": "släktsaga",
    "släktskapen": "släktskap",
    "släktskapens": "släktskap",
    "släktskapet": "släktskap",
    "släktskapets": "släktskap",
    "släktskaps": "släktskap",
    "släktskapsförhållanden": "släktskapsförhållande",
    "släktskapsförhållandena": "släktskapsförhållande",
    "släktskapsförhållandenas": "släktskapsförhållande",
    "släktskapsförhållandens": "släktskapsförhållande",
    "släktskapsförhållandes": "släktskapsförhållande",
    "släktskapsförhållandet": "släktskapsförhållande",
    "släktskapsförhållandets": "släktskapsförhållande",
    "släktskapsträden": "släktskapsträd",
    "släktskapsträdens": "släktskapsträd",
    "släktskapsträdet": "släktskapsträd",
    "släktskapsträdets": "släktskapsträd",
    "släktskapsträds": "släktskapsträd",
    "släktträden": "släktträd",
    "släktträdens": "släktträd",
    "släktträdet": "släktträd",
    "släktträdets": "släktträd",
    "släktträds": "släktträd",
    "släkttyckes": "släkttycke",
    "släkttycket": "släkttycke",
    "släkttyckets": "släkttycke",
    "släktvapens": "släktvapen",
    "släktvapnen": "släktvapen",
    "släktvapnens": "släktvapen",
    "släktvapnet": "släktvapen",
    "släktvapnets": "släktvapen",
    "sländ": "slända",
    "sländan": "slända",
    "sländans": "slända",
    "sländas": "slända",
    "slände": "slända",
    "sländlarven": "sländlarv",
    "sländlarvens": "sländlarv",
    "sländlarver": "sländlarv",
    "sländlarverna": "sländlarv",
    "sländlarvernas": "sländlarv",
    "sländlarvers": "sländlarv",
    "sländlarvs": "sländlarv",
    "sländor": "slända",
    "sländorna": "slända",
    "sländornas": "slända",
    "sländors": "slända",
    "sländs": "slända",
    "sländtriss": "sländtrissa",
    "sländtrissan": "sländtrissa",
    "sländtrissans": "sländtrissa",
    "sländtrissas": "sländtrissa",
    "sländtrisse": "sländtrissa",
    "sländtrissor": "sländtrissa",
    "sländtrissorna": "sländtrissa",
    "sländtrissornas": "sländtrissa",
    "sländtrissors": "sländtrissa",
    "släng": "slänga",
    "slängande": "slänga",
    "slänganden": "slängande",
    "slängandena": "slängande",
    "slängandenas": "slängande",
    "slängandens": "slängande",
    "slängandes": "slängande",
    "slängandet": "slängande",
    "slängandets": "slängande",
    "slängar": "släng",
    "slängarna": "släng",
    "slängarnas": "släng",
    "slängars": "släng",
    "slängas": "slänga",
    "slängd": "slänga",
    "slängda": "slängd",
    "slängdare": "slängd",
    "slängdares": "slängd",
    "slängdas": "slängd",
    "slängdast": "slängd",
    "slängdaste": "slängd",
    "slängdastes": "slängd",
    "slängdasts": "slängd",
    "slängde": "slängd",
    "slängdes": "slängd",
    "slängds": "slängd",
    "slängen": "släng",
    "slängens": "släng",
    "slänger": "slänga",
    "slänges": "slänga",
    "slänggung": "slänggunga",
    "slänggungan": "slänggunga",
    "slänggungans": "slänggunga",
    "slänggungas": "slänggunga",
    "slänggunge": "slänggunga",
    "slänggungor": "slänggunga",
    "slänggungorna": "slänggunga",
    "slänggungornas": "slänggunga",
    "slänggungors": "slänggunga",
    "slänggungs": "slänggunga",
    "slängiga": "slängig",
    "slängigare": "slängig",
    "slängigares": "slängig",
    "slängigas": "slängig",
    "slängigast": "slängig",
    "slängigaste": "slängig",
    "slängigastes": "slängig",
    "slängigasts": "slängig",
    "slängige": "slängig",
    "slängiges": "slängig",
    "slängigheten": "slängighet",
    "slängighetens": "slängighet",
    "slängighets": "slängighet",
    "slängigs": "slängig",
    "slängigt": "slängig",
    "slängigts": "slängig",
    "slängkapp": "slängkappa",
    "slängkappan": "slängkappa",
    "slängkappans": "slängkappa",
    "slängkappas": "slängkappa",
    "slängkappe": "slängkappa",
    "slängkappor": "slängkappa",
    "slängkapporna": "slängkappa",
    "slängkappornas": "slängkappa",
    "slängkappors": "slängkappa",
    "slängkapps": "slängkappa",
    "slängkyssar": "slängkyss",
    "slängkyssarna": "slängkyss",
    "slängkyssarnas": "slängkyss",
    "slängkyssars": "slängkyss",
    "slängkyssen": "slängkyss",
    "slängkyssens": "slängkyss",
    "slängkälk": "slängkälke",
    "slängkälkar": "slängkälke",
    "slängkälkarna": "slängkälke",
    "slängkälkarnas": "slängkälke",
    "slängkälkars": "slängkälke",
    "slängkälken": "slängkälke",
    "slängkälkens": "slängkälke",
    "slängkälkes": "slängkälke",
    "slängkälks": "slängkälke",
    "slängpolskan": "slängpolska",
    "slängpolskans": "slängpolska",
    "slängpolskas": "slängpolska",
    "slängpolske": "slängpolska",
    "slängpolskor": "slängpolska",
    "slängpolskorna": "slängpolska",
    "slängpolskornas": "slängpolska",
    "slängpolskors": "slängpolska",
    "slängs": "slänga",
    "slängskotten": "slängskott",
    "slängskottens": "slängskott",
    "slängskottet": "slängskott",
    "slängskottets": "slängskott",
    "slängskotts": "slängskott",
    "slängt": "slängd",
    "slängts": "slängd",
    "slänten": "slänt",
    "släntens": "slänt",
    "slänter": "släntra",
    "slänterna": "slänt",
    "slänternas": "slänt",
    "slänters": "slänt",
    "släntrad": "släntra",
    "släntrade": "släntra",
    "släntrades": "släntra",
    "släntrads": "släntra",
    "släntrande": "släntra",
    "släntranden": "släntrande",
    "släntrandena": "släntrande",
    "släntrandenas": "släntrande",
    "släntrandens": "släntrande",
    "släntrandes": "släntrande",
    "släntrandet": "släntrande",
    "släntrandets": "släntrande",
    "släntrar": "släntra",
    "släntras": "släntra",
    "släntrat": "släntra",
    "släntrats": "släntra",
    "slänts": "slänt",
    "släp": "släpa",
    "släpad": "släpa",
    "släpade": "släpa",
    "släpades": "släpa",
    "släpads": "släpa",
    "släpande": "släpa",
    "släpanden": "släpande",
    "släpandena": "släpande",
    "släpandenas": "släpande",
    "släpandens": "släpande",
    "släpandes": "släpande",
    "släpandet": "släpande",
    "släpandets": "släpande",
    "släpar": "släpa",
    "släpas": "släpa",
    "släpat": "släpa",
    "släpats": "släpa",
    "släpen": "släp",
    "släpens": "släp",
    "släpet": "släp",
    "släpets": "släp",
    "släpiga": "släpig",
    "släpigare": "släpig",
    "släpigares": "släpig",
    "släpigas": "släpig",
    "släpigast": "släpig",
    "släpigaste": "släpig",
    "släpigastes": "släpig",
    "släpigasts": "släpig",
    "släpige": "släpig",
    "släpiges": "släpig",
    "släpigs": "släpig",
    "släpigt": "släpig",
    "släpigts": "släpig",
    "släpkontakten": "släpkontakt",
    "släpkontaktens": "släpkontakt",
    "släpkontakter": "släpkontakt",
    "släpkontakterna": "släpkontakt",
    "släpkontakternas": "släpkontakt",
    "släpkontakters": "släpkontakt",
    "släpkontakts": "släpkontakt",
    "släpkärr": "släpkärra",
    "släpkärran": "släpkärra",
    "släpkärrans": "släpkärra",
    "släpkärras": "släpkärra",
    "släpkärre": "släpkärra",
    "släpkärror": "släpkärra",
    "släpkärrorna": "släpkärra",
    "släpkärrornas": "släpkärra",
    "släpkärrors": "släpkärra",
    "släpkärrs": "släpkärra",
    "släpliftar": "släplift",
    "släpliftarna": "släplift",
    "släpliftarnas": "släplift",
    "släpliftars": "släplift",
    "släpliften": "släplift",
    "släpliftens": "släplift",
    "släplifter": "släplift",
    "släplifterna": "släplift",
    "släplifternas": "släplift",
    "släplifters": "släplift",
    "släplifts": "släplift",
    "släplin": "släplina",
    "släplinan": "släplina",
    "släplinans": "släplina",
    "släplinas": "släplina",
    "släpline": "släplina",
    "släplinor": "släplina",
    "släplinorna": "släplina",
    "släplinornas": "släplina",
    "släplinors": "släplina",
    "släplins": "släplina",
    "släpljuset": "släpljus",
    "släpljusets": "släpljus",
    "släploggar": "släplogg",
    "släploggarna": "släplogg",
    "släploggarnas": "släplogg",
    "släploggars": "släplogg",
    "släploggen": "släplogg",
    "släploggens": "släplogg",
    "släploggs": "släplogg",
    "släpnotar": "släpnot",
    "släpnotarna": "släpnot",
    "släpnotarnas": "släpnot",
    "släpnotars": "släpnot",
    "släpnoten": "släpnot",
    "släpnotens": "släpnot",
    "släpnots": "släpnot",
    "släpp": "släppa",
    "släppande": "släppa",
    "släppanden": "släppande",
    "släppandena": "släppande",
    "släppandenas": "släppande",
    "släppandens": "släppande",
    "släppandes": "släppande",
    "släppandet": "släppande",
    "släppandets": "släppande",
    "släppas": "släppa",
    "släppen": "släpp",
    "släppens": "släpp",
    "släpper": "släppa",
    "släppes": "släppa",
    "släppet": "släpp",
    "släppets": "släpp",
    "släpphänta": "släpphänt",
    "släpphäntare": "släpphänt",
    "släpphäntares": "släpphänt",
    "släpphäntas": "släpphänt",
    "släpphäntast": "släpphänt",
    "släpphäntaste": "släpphänt",
    "släpphäntastes": "släpphänt",
    "släpphäntasts": "släpphänt",
    "släpphänte": "släpphänt",
    "släpphäntes": "släpphänt",
    "släpphäntheten": "släpphänthet",
    "släpphänthetens": "släpphänthet",
    "släpphänthets": "släpphänthet",
    "släpphänts": "släpphänt",
    "släpps": "släppa",
    "släppt": "släppa",
    "släppta": "släppa",
    "släpptas": "släppa",
    "släppte": "släppa",
    "släpptes": "släppa",
    "släppts": "släppa",
    "släpringar": "släpring",
    "släpringarna": "släpring",
    "släpringarnas": "släpring",
    "släpringars": "släpring",
    "släpringen": "släpring",
    "släpringens": "släpring",
    "släprings": "släpring",
    "släps": "släp",
    "släpsamheten": "släpsamhet",
    "släpsamhetens": "släpsamhet",
    "släpsamhets": "släpsamhet",
    "släpsamma": "släpsam",
    "släpsammare": "släpsam",
    "släpsammares": "släpsam",
    "släpsammas": "släpsam",
    "släpsammast": "släpsam",
    "släpsammaste": "släpsam",
    "släpsammastes": "släpsam",
    "släpsammasts": "släpsam",
    "släpsamme": "släpsam",
    "släpsammes": "släpsam",
    "släpsams": "släpsam",
    "släpsamt": "släpsam",
    "släpsamts": "släpsam",
    "släpskon": "släpsko",
    "släpskons": "släpsko",
    "släpskor": "släpsko",
    "släpskorna": "släpsko",
    "släpskornas": "släpsko",
    "släpskors": "släpsko",
    "släpskos": "släpsko",
    "släpvadar": "släpvad",
    "släpvadarna": "släpvad",
    "släpvadarnas": "släpvad",
    "släpvadars": "släpvad",
    "släpvaden": "släpvad",
    "släpvadens": "släpvad",
    "släpvads": "släpvad",
    "släpvagnar": "släpvagn",
    "släpvagnarna": "släpvagn",
    "släpvagnarnas": "släpvagn",
    "släpvagnars": "släpvagn",
    "släpvagnen": "släpvagn",
    "släpvagnens": "släpvagn",
    "släpvagns": "släpvagn",
    "släpvagnskopplingar": "släpvagnskoppling",
    "släpvagnskopplingarna": "släpvagnskoppling",
    "släpvagnskopplingarnas": "släpvagnskoppling",
    "släpvagnskopplingars": "släpvagnskoppling",
    "släpvagnskopplingen": "släpvagnskoppling",
    "släpvagnskopplingens": "släpvagnskoppling",
    "släpvagnskopplings": "släpvagnskoppling",
    "släpärterna": "släpärter",
    "släpärternas": "släpärter",
    "släpärters": "släpärter",
    "släpärts": "släpärter",
    "slät": "släta",
    "släta": "slät",
    "slätad": "släta",
    "slätade": "släta",
    "slätades": "släta",
    "slätads": "släta",
    "slätande": "släta",
    "slätanden": "slätande",
    "slätandena": "slätande",
    "slätandenas": "slätande",
    "slätandens": "slätande",
    "slätandes": "slätande",
    "slätandet": "slätande",
    "slätandets": "slätande",
    "slätar": "släta",
    "slätare": "slät",
    "slätares": "slät",
    "slätas": "släta",
    "slätast": "slät",
    "slätaste": "slät",
    "slätastes": "slät",
    "slätasts": "slät",
    "slätat": "släta",
    "slätats": "släta",
    "slätbanan": "slätbana",
    "slätbanans": "slätbana",
    "slätbanas": "slätbana",
    "slätbane": "slätbana",
    "slätbanor": "slätbana",
    "slätbanorna": "slätbana",
    "slätbanornas": "slätbana",
    "slätbanors": "slätbana",
    "släte": "slät",
    "slätes": "slät",
    "slätfogar": "slätfog",
    "slätfogarna": "slätfog",
    "slätfogarnas": "slätfog",
    "slätfogars": "slätfog",
    "slätfogen": "slätfog",
    "slätfogens": "slätfog",
    "slätfogs": "slätfog",
    "slätharvar": "slätharv",
    "slätharvarna": "slätharv",
    "slätharvarnas": "slätharv",
    "slätharvars": "slätharv",
    "slätharven": "slätharv",
    "slätharvens": "slätharv",
    "slätharvs": "slätharv",
    "slätheten": "släthet",
    "släthetens": "släthet",
    "släthets": "släthet",
    "släthåriga": "släthårig",
    "släthårigare": "släthårig",
    "släthårigares": "släthårig",
    "släthårigas": "släthårig",
    "släthårigast": "släthårig",
    "släthårigaste": "släthårig",
    "släthårigastes": "släthårig",
    "släthårigasts": "släthårig",
    "släthårige": "släthårig",
    "släthåriges": "släthårig",
    "släthårigheten": "släthårighet",
    "släthårighetens": "släthårighet",
    "släthårighets": "släthårighet",
    "släthårigs": "släthårig",
    "släthårigt": "släthårig",
    "släthårigts": "släthårig",
    "slätkammade": "slätkammad",
    "slätkammades": "slätkammad",
    "slätkammads": "slätkammad",
    "slätkammat": "slätkammad",
    "slätkammats": "slätkammad",
    "slätlöpningar": "slätlöpning",
    "slätlöpningarna": "slätlöpning",
    "slätlöpningarnas": "slätlöpning",
    "slätlöpningars": "slätlöpning",
    "slätlöpningen": "slätlöpning",
    "slätlöpningens": "slätlöpning",
    "slätlöpnings": "slätlöpning",
    "slätprickar": "slätprick",
    "slätprickarna": "slätprick",
    "slätprickarnas": "slätprick",
    "slätprickars": "slätprick",
    "slätpricken": "slätprick",
    "slätprickens": "slätprick",
    "slätpricks": "slätprick",
    "slätrak": "slätraka",
    "slätrakad": "slätraka",
    "slätrakade": "slätrakad",
    "slätrakades": "slätrakad",
    "slätrakads": "slätrakad",
    "slätrakande": "slätraka",
    "slätrakanden": "slätrakande",
    "slätrakandena": "slätrakande",
    "slätrakandenas": "slätrakande",
    "slätrakandens": "slätrakande",
    "slätrakandes": "slätrakande",
    "slätrakandet": "slätrakande",
    "slätrakandets": "slätrakande",
    "slätrakar": "slätraka",
    "slätrakas": "slätraka",
    "slätrakat": "slätrakad",
    "slätrakats": "slätrakad",
    "slätriggade": "slätriggad",
    "slätriggades": "slätriggad",
    "slätriggads": "slätriggad",
    "slätriggat": "slätriggad",
    "slätriggats": "slätriggad",
    "släts": "slät",
    "slätslip": "slätslipa",
    "slätslipad": "slätslipa",
    "slätslipade": "slätslipa",
    "slätslipades": "slätslipa",
    "slätslipads": "slätslipa",
    "slätslipande": "slätslipa",
    "slätslipanden": "slätslipande",
    "slätslipandena": "slätslipande",
    "slätslipandenas": "slätslipande",
    "slätslipandens": "slätslipande",
    "slätslipandes": "slätslipande",
    "slätslipandet": "slätslipande",
    "slätslipandets": "slätslipande",
    "slätslipar": "slätslipa",
    "slätslipas": "slätslipa",
    "slätslipat": "slätslipa",
    "slätslipats": "slätslipa",
    "slätstickade": "slätstickad",
    "slätstickades": "slätstickad",
    "slätstickads": "slätstickad",
    "slätstickat": "slätstickad",
    "slätstickats": "slätstickad",
    "slätstickningar": "slätstickning",
    "slätstickningarna": "slätstickning",
    "slätstickningarnas": "slätstickning",
    "slätstickningars": "slätstickning",
    "slätstickningen": "slätstickning",
    "slätstickningens": "slätstickning",
    "slätsticknings": "slätstickning",
    "slätstrukens": "slätstruken",
    "slätstruket": "slätstruken",
    "slätstrukets": "slätstruken",
    "slätstrukna": "slätstruken",
    "slätstruknare": "slätstruken",
    "slätstruknares": "slätstruken",
    "slätstruknas": "slätstruken",
    "slätstruknast": "slätstruken",
    "slätstruknaste": "slätstruken",
    "slätstruknastes": "slätstruken",
    "slätstruknasts": "slätstruken",
    "slätstrukne": "slätstruken",
    "slätstruknes": "slätstruken",
    "slätsvampar": "slätsvamp",
    "slätsvamparna": "slätsvamp",
    "slätsvamparnas": "slätsvamp",
    "slätsvampars": "slätsvamp",
    "slätsvampen": "slätsvamp",
    "slätsvampens": "slätsvamp",
    "slätsvamps": "slätsvamp",
    "slätt": "slät",
    "slättbygden": "slättbygd",
    "slättbygdens": "slättbygd",
    "slättbygder": "slättbygd",
    "slättbygderna": "slättbygd",
    "slättbygdernas": "slättbygd",
    "slättbygders": "slättbygd",
    "slättbygds": "slättbygd",
    "slätten": "slätt",
    "slättens": "slätt",
    "slätter": "slätt",
    "slätterna": "slätt",
    "slätternas": "slätt",
    "slätters": "slätt",
    "slättmarken": "slättmark",
    "slättmarkens": "slättmark",
    "slättmarker": "slättmark",
    "slättmarkerna": "slättmark",
    "slättmarkernas": "slättmark",
    "slättmarkers": "slättmark",
    "slättmarks": "slättmark",
    "slättoppade": "slättoppad",
    "slättoppades": "slättoppad",
    "slättoppads": "slättoppad",
    "slättoppat": "slättoppad",
    "slättoppats": "slättoppad",
    "slätts": "slätt",
    "slätvarar": "slätvar",
    "slätvararna": "slätvar",
    "slätvararnas": "slätvar",
    "slätvarars": "slätvar",
    "slätvaren": "slätvar",
    "slätvarens": "slätvar",
    "slätvars": "slätvar",
    "slätvällingar": "slätvälling",
    "slätvällingarna": "slätvälling",
    "slätvällingarnas": "slätvälling",
    "slätvällingars": "slätvälling",
    "slätvällingen": "slätvälling",
    "slätvällingens": "slätvälling",
    "slätvällings": "slätvälling",
    "slåar": "slå",
    "slåarna": "slå",
    "slåarnas": "slå",
    "slåars": "slå",
    "slående": "slå",
    "slåenden": "slående",
    "slåendena": "slående",
    "slåendenas": "slående",
    "slåendens": "slående",
    "slåendes": "slående",
    "slåendet": "slående",
    "slåendets": "slående",
    "slån": "slå",
    "slånbären": "slånbär",
    "slånbärens": "slånbär",
    "slånbäret": "slånbär",
    "slånbärets": "slånbär",
    "slånbärs": "slånbär",
    "slånbärsbusk": "slånbärsbuske",
    "slånbärsbuskar": "slånbärsbuske",
    "slånbärsbuskarna": "slånbärsbuske",
    "slånbärsbuskarnas": "slånbärsbuske",
    "slånbärsbuskars": "slånbärsbuske",
    "slånbärsbusken": "slånbärsbuske",
    "slånbärsbuskens": "slånbärsbuske",
    "slånbärsbuskes": "slånbärsbuske",
    "slånen": "slån",
    "slånens": "slån",
    "slånet": "slån",
    "slånets": "slån",
    "slåns": "slån",
    "slår": "slå",
    "slås": "slå",
    "slått": "slåtta",
    "slåttad": "slåtta",
    "slåttade": "slåtta",
    "slåttades": "slåtta",
    "slåttads": "slåtta",
    "slåttande": "slåtta",
    "slåttanden": "slåttande",
    "slåttandena": "slåttande",
    "slåttandenas": "slåttande",
    "slåttandens": "slåttande",
    "slåttandes": "slåttande",
    "slåttandet": "slåttande",
    "slåttandets": "slåttande",
    "slåttar": "slåtta",
    "slåttas": "slåtta",
    "slåttat": "slåtta",
    "slåttats": "slåtta",
    "slåtterblom": "slåtterblomma",
    "slåtterblomman": "slåtterblomma",
    "slåtterblommans": "slåtterblomma",
    "slåtterblommas": "slåtterblomma",
    "slåtterblomme": "slåtterblomma",
    "slåtterblommor": "slåtterblomma",
    "slåtterblommorna": "slåtterblomma",
    "slåtterblommornas": "slåtterblomma",
    "slåtterblommors": "slåtterblomma",
    "slåtterbloms": "slåtterblomma",
    "slåtterfesten": "slåtterfest",
    "slåtterfestens": "slåtterfest",
    "slåtterfester": "slåtterfest",
    "slåtterfesterna": "slåtterfest",
    "slåtterfesternas": "slåtterfest",
    "slåtterfesters": "slåtterfest",
    "slåtterfests": "slåtterfest",
    "slåtterknivar": "slåtterkniv",
    "slåtterknivarna": "slåtterkniv",
    "slåtterknivarnas": "slåtterkniv",
    "slåtterknivars": "slåtterkniv",
    "slåtterkniven": "slåtterkniv",
    "slåtterknivens": "slåtterkniv",
    "slåtterknivs": "slåtterkniv",
    "slåttermaskinen": "slåttermaskin",
    "slåttermaskinens": "slåttermaskin",
    "slåttermaskiner": "slåttermaskin",
    "slåttermaskinerna": "slåttermaskin",
    "slåttermaskinernas": "slåttermaskin",
    "slåttermaskiners": "slåttermaskin",
    "slåttermaskins": "slåttermaskin",
    "slåttermyrar": "slåttermyr",
    "slåttermyrarna": "slåttermyr",
    "slåttermyrarnas": "slåttermyr",
    "slåttermyrars": "slåttermyr",
    "slåttermyren": "slåttermyr",
    "slåttermyrens": "slåttermyr",
    "slåttermyrs": "slåttermyr",
    "slåttern": "slåtter",
    "slåtterns": "slåtter",
    "slåtters": "slåtter",
    "slåtterängar": "slåtteräng",
    "slåtterängarna": "slåtteräng",
    "slåtterängarnas": "slåtteräng",
    "slåtterängars": "slåtteräng",
    "slåtterängen": "slåtteräng",
    "slåtterängens": "slåtteräng",
    "slåtterängs": "slåtteräng",
    "slåttrar": "slåtter",
    "slåttrarna": "slåtter",
    "slåttrarnas": "slåtter",
    "slåttrars": "slåtter",
    "slö": "slöa",
    "slöa": "slö",
    "slöad": "slöa",
    "slöade": "slöa",
    "slöades": "slöa",
    "slöads": "slöa",
    "slöande": "slöa",
    "slöanden": "slöande",
    "slöandena": "slöande",
    "slöandenas": "slöande",
    "slöandens": "slöande",
    "slöandes": "slöande",
    "slöandet": "slöande",
    "slöandets": "slöande",
    "slöar": "slöa",
    "slöare": "slö",
    "slöares": "slö",
    "slöas": "slöa",
    "slöast": "slö",
    "slöaste": "slö",
    "slöastes": "slö",
    "slöasts": "slö",
    "slöat": "slöa",
    "slöats": "slöa",
    "slödders": "slödder",
    "slöddret": "slödder",
    "slöddrets": "slödder",
    "slödrickan": "slödricka",
    "slödrickans": "slödricka",
    "slödrickas": "slödricka",
    "slödrickat": "slödricka",
    "slödrickats": "slödricka",
    "slödrycken": "slödryck",
    "slödryckens": "slödryck",
    "slödrycks": "slödryck",
    "slöe": "slö",
    "slöes": "slö",
    "slöfockar": "slöfock",
    "slöfockarna": "slöfock",
    "slöfockarnas": "slöfock",
    "slöfockars": "slöfock",
    "slöfocken": "slöfock",
    "slöfockens": "slöfock",
    "slöfocks": "slöfock",
    "slöj": "slöja",
    "slöjan": "slöja",
    "slöjans": "slöja",
    "slöjas": "slöja",
    "slöjd": "slöjda",
    "slöjdad": "slöjda",
    "slöjdade": "slöjda",
    "slöjdades": "slöjda",
    "slöjdads": "slöjda",
    "slöjdande": "slöjda",
    "slöjdanden": "slöjdande",
    "slöjdandena": "slöjdande",
    "slöjdandenas": "slöjdande",
    "slöjdandens": "slöjdande",
    "slöjdandes": "slöjdande",
    "slöjdandet": "slöjdande",
    "slöjdandets": "slöjdande",
    "slöjdar": "slöjda",
    "slöjdas": "slöjda",
    "slöjdat": "slöjda",
    "slöjdats": "slöjda",
    "slöjdebatten": "slöjdebatt",
    "slöjdebattens": "slöjdebatt",
    "slöjdebatter": "slöjdebatt",
    "slöjdebatterna": "slöjdebatt",
    "slöjdebatternas": "slöjdebatt",
    "slöjdebatters": "slöjdebatt",
    "slöjdebatts": "slöjdebatt",
    "slöjden": "slöjd",
    "slöjdens": "slöjd",
    "slöjder": "slöjd",
    "slöjderna": "slöjd",
    "slöjdernas": "slöjd",
    "slöjders": "slöjd",
    "slöjdknivar": "slöjdkniv",
    "slöjdknivarna": "slöjdkniv",
    "slöjdknivarnas": "slöjdkniv",
    "slöjdknivars": "slöjdkniv",
    "slöjdkniven": "slöjdkniv",
    "slöjdknivens": "slöjdkniv",
    "slöjdknivs": "slöjdkniv",
    "slöjds": "slöjd",
    "slöjdspäntknivar": "slöjdspäntkniv",
    "slöjdspäntknivarna": "slöjdspäntkniv",
    "slöjdspäntknivarnas": "slöjdspäntkniv",
    "slöjdspäntknivars": "slöjdspäntkniv",
    "slöjdspäntkniven": "slöjdspäntkniv",
    "slöjdspäntknivens": "slöjdspäntkniv",
    "slöjdspäntknivs": "slöjdspäntkniv",
    "slöje": "slöja",
    "slöjiga": "slöjig",
    "slöjigare": "slöjig",
    "slöjigares": "slöjig",
    "slöjigas": "slöjig",
    "slöjigast": "slöjig",
    "slöjigaste": "slöjig",
    "slöjigastes": "slöjig",
    "slöjigasts": "slöjig",
    "slöjige": "slöjig",
    "slöjiges": "slöjig",
    "slöjigs": "slöjig",
    "slöjigt": "slöjig",
    "slöjigts": "slöjig",
    "slöjmolnen": "slöjmoln",
    "slöjmolnens": "slöjmoln",
    "slöjmolnet": "slöjmoln",
    "slöjmolnets": "slöjmoln",
    "slöjmolns": "slöjmoln",
    "slöjor": "slöja",
    "slöjorna": "slöja",
    "slöjornas": "slöja",
    "slöjors": "slöja",
    "slöjs": "slöja",
    "slöjskivlingar": "slöjskivling",
    "slöjskivlingarna": "slöjskivling",
    "slöjskivlingarnas": "slöjskivling",
    "slöjskivlingars": "slöjskivling",
    "slöjskivlingen": "slöjskivling",
    "slöjskivlingens": "slöjskivling",
    "slöjskivlings": "slöjskivling",
    "slöjstjärtar": "slöjstjärt",
    "slöjstjärtarna": "slöjstjärt",
    "slöjstjärtarnas": "slöjstjärt",
    "slöjstjärtars": "slöjstjärt",
    "slöjstjärten": "slöjstjärt",
    "slöjstjärtens": "slöjstjärt",
    "slöjstjärts": "slöjstjärt",
    "slök": "sluka",
    "slöke": "sluka",
    "slökes": "sluka",
    "slökornet": "slökorn",
    "slökornets": "slökorn",
    "slökorns": "slökorn",
    "slöks": "sluka",
    "slör": "slöra",
    "slörad": "slöra",
    "slörade": "slöra",
    "slörades": "slöra",
    "slörads": "slöra",
    "slörande": "slöra",
    "slöranden": "slörande",
    "slörandena": "slörande",
    "slörandenas": "slörande",
    "slörandens": "slörande",
    "slörandes": "slörande",
    "slörandet": "slörande",
    "slörandets": "slörande",
    "slörar": "slöra",
    "slöras": "slöra",
    "slörat": "slöra",
    "slörats": "slöra",
    "slören": "slör",
    "slörens": "slör",
    "slöret": "slör",
    "slörets": "slör",
    "slörs": "slör",
    "slös": "slösa",
    "slösad": "slösa",
    "slösade": "slösa",
    "slösades": "slösa",
    "slösads": "slösa",
    "slösaktiga": "slösaktig",
    "slösaktigare": "slösaktig",
    "slösaktigares": "slösaktig",
    "slösaktigas": "slösaktig",
    "slösaktigast": "slösaktig",
    "slösaktigaste": "slösaktig",
    "slösaktigastes": "slösaktig",
    "slösaktigasts": "slösaktig",
    "slösaktige": "slösaktig",
    "slösaktiges": "slösaktig",
    "slösaktigheten": "slösaktighet",
    "slösaktighetens": "slösaktighet",
    "slösaktighets": "slösaktighet",
    "slösaktigs": "slösaktig",
    "slösaktigt": "slösaktig",
    "slösaktigts": "slösaktig",
    "slösande": "slösa",
    "slösanden": "slösande",
    "slösandena": "slösande",
    "slösandenas": "slösande",
    "slösandens": "slösande",
    "slösandes": "slösande",
    "slösandet": "slösande",
    "slösandets": "slösande",
    "slösar": "slösare",
    "slösaren": "slösare",
    "slösarens": "slösare",
    "slösares": "slösare",
    "slösarna": "slösare",
    "slösarnas": "slösare",
    "slösas": "slösa",
    "slösat": "slösa",
    "slösats": "slösa",
    "slöseriet": "slöseri",
    "slöseriets": "slöseri",
    "slöseris": "slöseri",
    "slöserit": "slöseri",
    "slöserits": "slöseri",
    "slösiga": "slösig",
    "slösigare": "slösig",
    "slösigares": "slösig",
    "slösigas": "slösig",
    "slösigast": "slösig",
    "slösigaste": "slösig",
    "slösigastes": "slösig",
    "slösigasts": "slösig",
    "slösige": "slösig",
    "slösiges": "slösig",
    "slösigs": "slösig",
    "slösigt": "slösig",
    "slösigts": "slösig",
    "slösinta": "slösint",
    "slösintare": "slösint",
    "slösintares": "slösint",
    "slösintas": "slösint",
    "slösintast": "slösint",
    "slösintaste": "slösint",
    "slösintastes": "slösint",
    "slösintasts": "slösint",
    "slösinte": "slösint",
    "slösintes": "slösint",
    "slösintheten": "slösinthet",
    "slösinthetens": "slösinthet",
    "slösinthets": "slösinthet",
    "slösints": "slösint",
    "slösurf": "slösurfa",
    "slösurfade": "slösurfa",
    "slösurfades": "slösurfa",
    "slösurfande": "slösurfa",
    "slösurfandes": "slösurfa",
    "slösurfar": "slösurfa",
    "slösurfas": "slösurfa",
    "slösurfat": "slösurfa",
    "slösurfats": "slösurfa",
    "slösäden": "slösäd",
    "slösädens": "slösäd",
    "slösädes": "slösäd",
    "slösäds": "slösäd",
    "slöt": "sluta",
    "slöte": "sluta",
    "slötes": "sluta",
    "slötittade": "slötitta",
    "slötittades": "slötitta",
    "slötittande": "slötitta",
    "slötittanden": "slötittande",
    "slötittandena": "slötittande",
    "slötittandenas": "slötittande",
    "slötittandens": "slötittande",
    "slötittandes": "slötittande",
    "slötittandet": "slötittande",
    "slötittandets": "slötittande",
    "slötittar": "slötitta",
    "slötittas": "slötitta",
    "slötittat": "slötitta",
    "slötittats": "slötitta",
    "slöts": "sluta",
    "slött": "slö",
    "slötts": "slö",
    "smack": "smacka",
    "smackad": "smacka",
    "smackade": "smacka",
    "smackades": "smacka",
    "smackads": "smacka",
    "smackande": "smacka",
    "smackanden": "smackande",
    "smackandena": "smackande",
    "smackandenas": "smackande",
    "smackandens": "smackande",
    "smackandes": "smackande",
    "smackandet": "smackande",
    "smackandets": "smackande",
    "smackar": "smacka",
    "smackarna": "smack",
    "smackarnas": "smack",
    "smackars": "smack",
    "smackas": "smacka",
    "smackat": "smacka",
    "smackats": "smacka",
    "smacken": "smack",
    "smackens": "smack",
    "smacket": "smack",
    "smackets": "smack",
    "smackningar": "smackning",
    "smackningarna": "smackning",
    "smackningarnas": "smackning",
    "smackningars": "smackning",
    "smackningen": "smackning",
    "smackningens": "smackning",
    "smacknings": "smackning",
    "smacks": "smack",
    "smajlen": "smajl",
    "smajlens": "smajl",
    "smajlet": "smajl",
    "smajlets": "smajl",
    "smajls": "smajl",
    "smak": "smaka",
    "smakad": "smaka",
    "smakade": "smaka",
    "smakades": "smaka",
    "smakads": "smaka",
    "smakande": "smaka",
    "smakanden": "smakande",
    "smakandena": "smakande",
    "smakandenas": "smakande",
    "smakandens": "smakande",
    "smakandes": "smakande",
    "smakandet": "smakande",
    "smakandets": "smakande",
    "smakar": "smaka",
    "smakas": "smaka",
    "smakat": "smaka",
    "smakats": "smaka",
    "smakbitar": "smakbit",
    "smakbitarna": "smakbit",
    "smakbitarnas": "smakbit",
    "smakbitars": "smakbit",
    "smakbiten": "smakbit",
    "smakbitens": "smakbit",
    "smakbits": "smakbit",
    "smakdomar": "smakdomare",
    "smakdomaren": "smakdomare",
    "smakdomarens": "smakdomare",
    "smakdomares": "smakdomare",
    "smakdomarna": "smakdomare",
    "smakdomarnas": "smakdomare",
    "smaken": "smak",
    "smakens": "smak",
    "smaker": "smak",
    "smakerna": "smak",
    "smakernas": "smak",
    "smakers": "smak",
    "smakfrågan": "smakfråga",
    "smakfrågans": "smakfråga",
    "smakfrågas": "smakfråga",
    "smakfråge": "smakfråga",
    "smakfrågor": "smakfråga",
    "smakfrågorna": "smakfråga",
    "smakfrågornas": "smakfråga",
    "smakfrågors": "smakfråga",
    "smakfulla": "smakfull",
    "smakfullare": "smakfull",
    "smakfullares": "smakfull",
    "smakfullas": "smakfull",
    "smakfullast": "smakfull",
    "smakfullaste": "smakfull",
    "smakfullastes": "smakfull",
    "smakfullasts": "smakfull",
    "smakfulle": "smakfull",
    "smakfulles": "smakfull",
    "smakfullheten": "smakfullhet",
    "smakfullhetens": "smakfullhet",
    "smakfullheter": "smakfullhet",
    "smakfullheterna": "smakfullhet",
    "smakfullheternas": "smakfullhet",
    "smakfullheters": "smakfullhet",
    "smakfullhets": "smakfullhet",
    "smakfulls": "smakfull",
    "smakfullt": "smakfull",
    "smakfullts": "smakfull",
    "smakliga": "smaklig",
    "smakligare": "smaklig",
    "smakligares": "smaklig",
    "smakligas": "smaklig",
    "smakligast": "smaklig",
    "smakligaste": "smaklig",
    "smakligastes": "smaklig",
    "smakligasts": "smaklig",
    "smaklige": "smaklig",
    "smakliges": "smaklig",
    "smakligheten": "smaklighet",
    "smaklighetens": "smaklighet",
    "smakligheter": "smaklighet",
    "smakligheterna": "smaklighet",
    "smakligheternas": "smaklighet",
    "smakligheters": "smaklighet",
    "smaklighets": "smaklighet",
    "smakligs": "smaklig",
    "smakligt": "smaklig",
    "smakligts": "smaklig",
    "smaklökar": "smaklök",
    "smaklökarna": "smaklök",
    "smaklökarnas": "smaklök",
    "smaklökars": "smaklök",
    "smaklöken": "smaklök",
    "smaklökens": "smaklök",
    "smaklöks": "smaklök",
    "smaklösa": "smaklös",
    "smaklösare": "smaklös",
    "smaklösares": "smaklös",
    "smaklösas": "smaklös",
    "smaklösast": "smaklös",
    "smaklösaste": "smaklös",
    "smaklösastes": "smaklös",
    "smaklösasts": "smaklös",
    "smaklöse": "smaklös",
    "smaklöses": "smaklös",
    "smaklösheten": "smaklöshet",
    "smaklöshetens": "smaklöshet",
    "smaklösheter": "smaklöshet",
    "smaklösheterna": "smaklöshet",
    "smaklösheternas": "smaklöshet",
    "smaklösheters": "smaklöshet",
    "smaklöshets": "smaklöshet",
    "smaklöst": "smaklös",
    "smaklösts": "smaklös",
    "smakmässiga": "smakmässig",
    "smakmässigare": "smakmässig",
    "smakmässigares": "smakmässig",
    "smakmässigas": "smakmässig",
    "smakmässigast": "smakmässig",
    "smakmässigaste": "smakmässig",
    "smakmässigastes": "smakmässig",
    "smakmässigasts": "smakmässig",
    "smakmässige": "smakmässig",
    "smakmässiges": "smakmässig",
    "smakmässigs": "smakmässig",
    "smakmässigt": "smakmässig",
    "smakmässigts": "smakmässig",
    "smakpanelen": "smakpanel",
    "smakpanelens": "smakpanel",
    "smakpaneler": "smakpanel",
    "smakpanelerna": "smakpanel",
    "smakpanelernas": "smakpanel",
    "smakpanelers": "smakpanel",
    "smakpanels": "smakpanel",
    "smakproblemen": "smakproblem",
    "smakproblemens": "smakproblem",
    "smakproblemet": "smakproblem",
    "smakproblemets": "smakproblem",
    "smakproblems": "smakproblem",
    "smakproven": "smakprov",
    "smakprovens": "smakprov",
    "smakprover": "smakprov",
    "smakproverna": "smakprov",
    "smakprovernas": "smakprov",
    "smakprovers": "smakprov",
    "smakprovet": "smakprov",
    "smakprovets": "smakprov",
    "smakprovs": "smakprov",
    "smakråden": "smakråd",
    "smakrådens": "smakråd",
    "smakrådet": "smakråd",
    "smakrådets": "smakråd",
    "smakråds": "smakråd",
    "smaks": "smak",
    "smaksaken": "smaksak",
    "smaksakens": "smaksak",
    "smaksaker": "smaksak",
    "smaksakerna": "smaksak",
    "smaksakernas": "smaksak",
    "smaksakers": "smaksak",
    "smaksaks": "smaksak",
    "smaksatt": "smaksätta",
    "smaksatta": "smaksätta",
    "smaksattas": "smaksätta",
    "smaksatte": "smaksätta",
    "smaksattes": "smaksätta",
    "smaksatts": "smaksätta",
    "smaksinnes": "smaksinne",
    "smaksinnet": "smaksinne",
    "smaksinnets": "smaksinne",
    "smaksätt": "smaksätta",
    "smaksättande": "smaksätta",
    "smaksättanden": "smaksättande",
    "smaksättandena": "smaksättande",
    "smaksättandenas": "smaksättande",
    "smaksättandens": "smaksättande",
    "smaksättandes": "smaksättande",
    "smaksättandet": "smaksättande",
    "smaksättandets": "smaksättande",
    "smaksättas": "smaksätta",
    "smaksätter": "smaksätta",
    "smaksättes": "smaksätta",
    "smaksätts": "smaksätta",
    "smakupplevelsen": "smakupplevelse",
    "smakupplevelsens": "smakupplevelse",
    "smakupplevelser": "smakupplevelse",
    "smakupplevelserna": "smakupplevelse",
    "smakupplevelsernas": "smakupplevelse",
    "smakupplevelsers": "smakupplevelse",
    "smakupplevelses": "smakupplevelse",
    "smakämnen": "smakämne",
    "smakämnena": "smakämne",
    "smakämnenas": "smakämne",
    "smakämnens": "smakämne",
    "smakämnes": "smakämne",
    "smakämnet": "smakämne",
    "smakämnets": "smakämne",
    "smala": "smal",
    "smalare": "smal",
    "smalares": "smal",
    "smalas": "smal",
    "smalast": "smal",
    "smalaste": "smal",
    "smalastes": "smal",
    "smalasts": "smal",
    "smalbenen": "smalben",
    "smalbenens": "smalben",
    "smalbenet": "smalben",
    "smalbenets": "smalben",
    "smalbens": "smalben",
    "smaldjuren": "smaldjur",
    "smaldjurens": "smaldjur",
    "smaldjuret": "smaldjur",
    "smaldjurets": "smaldjur",
    "smaldjurs": "smaldjur",
    "smale": "smal",
    "smales": "smal",
    "smalfilm": "smalfilma",
    "smalfilmad": "smalfilma",
    "smalfilmade": "smalfilma",
    "smalfilmades": "smalfilma",
    "smalfilmads": "smalfilma",
    "smalfilmande": "smalfilma",
    "smalfilmanden": "smalfilmande",
    "smalfilmandena": "smalfilmande",
    "smalfilmandenas": "smalfilmande",
    "smalfilmandens": "smalfilmande",
    "smalfilmandes": "smalfilmande",
    "smalfilmandet": "smalfilmande",
    "smalfilmandets": "smalfilmande",
    "smalfilmar": "smalfilma",
    "smalfilmas": "smalfilma",
    "smalfilmat": "smalfilma",
    "smalfilmats": "smalfilma",
    "smalfilmen": "smalfilm",
    "smalfilmens": "smalfilm",
    "smalfilmer": "smalfilm",
    "smalfilmerna": "smalfilm",
    "smalfilmernas": "smalfilm",
    "smalfilmers": "smalfilm",
    "smalfilms": "smalfilm",
    "smalheten": "smalhet",
    "smalhetens": "smalhet",
    "smalhets": "smalhet",
    "small": "smälla",
    "smaln": "smalna",
    "smalnad": "smalna",
    "smalnade": "smalna",
    "smalnades": "smalna",
    "smalnads": "smalna",
    "smalnande": "smalna",
    "smalnanden": "smalnande",
    "smalnandena": "smalnande",
    "smalnandenas": "smalnande",
    "smalnandens": "smalnande",
    "smalnandes": "smalnande",
    "smalnandet": "smalnande",
    "smalnandets": "smalnande",
    "smalnar": "smalna",
    "smalnas": "smalna",
    "smalnat": "smalna",
    "smalnats": "smalna",
    "smalnäsap": "smalnäsapa",
    "smalnäsapan": "smalnäsapa",
    "smalnäsapans": "smalnäsapa",
    "smalnäsapas": "smalnäsapa",
    "smalnäsape": "smalnäsapa",
    "smalnäsapor": "smalnäsapa",
    "smalnäsaporna": "smalnäsapa",
    "smalnäsapornas": "smalnäsapa",
    "smalnäsapors": "smalnäsapa",
    "smalnäsaps": "smalnäsapa",
    "smals": "smal",
    "smalspåriga": "smalspårig",
    "smalspårigare": "smalspårig",
    "smalspårigares": "smalspårig",
    "smalspårigas": "smalspårig",
    "smalspårigast": "smalspårig",
    "smalspårigaste": "smalspårig",
    "smalspårigastes": "smalspårig",
    "smalspårigasts": "smalspårig",
    "smalspårige": "smalspårig",
    "smalspåriges": "smalspårig",
    "smalspårigheten": "smalspårighet",
    "smalspårighetens": "smalspårighet",
    "smalspårighets": "smalspårighet",
    "smalspårigs": "smalspårig",
    "smalspårigt": "smalspårig",
    "smalspårigts": "smalspårig",
    "smalt": "smälta",
    "smalten": "smalt",
    "smaltens": "smalt",
    "smalts": "smälta",
    "smaltsen": "smalts",
    "smaltsens": "smalts",
    "smalväggar": "smalvägg",
    "smalväggarna": "smalvägg",
    "smalväggarnas": "smalvägg",
    "smalväggars": "smalvägg",
    "smalväggen": "smalvägg",
    "smalväggens": "smalvägg",
    "smalväggs": "smalvägg",
    "smaländ": "smalända",
    "smaländan": "smalända",
    "smaländans": "smalända",
    "smaländar": "smalände",
    "smaländarna": "smalände",
    "smaländarnas": "smalände",
    "smaländars": "smalände",
    "smaländas": "smalända",
    "smalände": "smalända",
    "smaländen": "smalände",
    "smaländens": "smalände",
    "smaländes": "smalände",
    "smaländor": "smalända",
    "smaländorna": "smalända",
    "smaländornas": "smalända",
    "smaländors": "smalända",
    "smaländs": "smalända",
    "smaragden": "smaragd",
    "smaragdens": "smaragd",
    "smaragder": "smaragd",
    "smaragderna": "smaragd",
    "smaragdernas": "smaragd",
    "smaragders": "smaragd",
    "smaragdfärgade": "smaragdfärgad",
    "smaragdfärgades": "smaragdfärgad",
    "smaragdfärgads": "smaragdfärgad",
    "smaragdfärgat": "smaragdfärgad",
    "smaragdfärgats": "smaragdfärgad",
    "smaragdgröna": "smaragdgrön",
    "smaragdgrönare": "smaragdgrön",
    "smaragdgrönares": "smaragdgrön",
    "smaragdgrönas": "smaragdgrön",
    "smaragdgrönast": "smaragdgrön",
    "smaragdgrönaste": "smaragdgrön",
    "smaragdgrönastes": "smaragdgrön",
    "smaragdgrönasts": "smaragdgrön",
    "smaragdgröne": "smaragdgrön",
    "smaragdgrönes": "smaragdgrön",
    "smaragdgröns": "smaragdgrön",
    "smaragdgrönt": "smaragdgrön",
    "smaragdgrönts": "smaragdgrön",
    "smaragds": "smaragd",
    "smarr": "smarra",
    "smarrade": "smarra",
    "smarrades": "smarra",
    "smarrande": "smarra",
    "smarranden": "smarrande",
    "smarrandena": "smarrande",
    "smarrandenas": "smarrande",
    "smarrandens": "smarrande",
    "smarrandes": "smarrande",
    "smarrandet": "smarrande",
    "smarrandets": "smarrande",
    "smarrar": "smarra",
    "smarras": "smarra",
    "smarrat": "smarra",
    "smarrats": "smarra",
    "smarriga": "smarrig",
    "smarrigare": "smarrig",
    "smarrigares": "smarrig",
    "smarrigas": "smarrig",
    "smarrigast": "smarrig",
    "smarrigaste": "smarrig",
    "smarrigastes": "smarrig",
    "smarrigasts": "smarrig",
    "smarrige": "smarrig",
    "smarriges": "smarrig",
    "smarrigheten": "smarrighet",
    "smarrighetens": "smarrighet",
    "smarrighets": "smarrighet",
    "smarrigs": "smarrig",
    "smarrigt": "smarrig",
    "smarrigts": "smarrig",
    "smarta": "smart",
    "smartare": "smart",
    "smartares": "smart",
    "smartas": "smart",
    "smartast": "smart",
    "smartaste": "smart",
    "smartastes": "smart",
    "smartasts": "smart",
    "smarte": "smart",
    "smartes": "smart",
    "smartheten": "smarthet",
    "smarthetens": "smarthet",
    "smartheter": "smarthet",
    "smartheterna": "smarthet",
    "smartheternas": "smarthet",
    "smartheters": "smarthet",
    "smarthets": "smarthet",
    "smarton": "smarto",
    "smartona": "smarto",
    "smartonas": "smarto",
    "smartons": "smarto",
    "smartos": "smarto",
    "smartot": "smarto",
    "smartots": "smarto",
    "smartphonen": "smartphone",
    "smartphonens": "smartphone",
    "smartphoner": "smartphone",
    "smartphonerna": "smartphone",
    "smartphonernas": "smartphone",
    "smartphoners": "smartphone",
    "smartphones": "smartphone",
    "smartphonesen": "smartphone",
    "smartphonesens": "smartphone",
    "smarts": "smart",
    "smash": "smasha",
    "smashad": "smasha",
    "smashade": "smasha",
    "smashades": "smasha",
    "smashads": "smasha",
    "smashande": "smasha",
    "smashanden": "smashande",
    "smashandena": "smashande",
    "smashandenas": "smashande",
    "smashandens": "smashande",
    "smashandes": "smashande",
    "smashandet": "smashande",
    "smashandets": "smashande",
    "smashar": "smasha",
    "smasharna": "smash",
    "smasharnas": "smash",
    "smashars": "smash",
    "smashas": "smasha",
    "smashat": "smasha",
    "smashats": "smasha",
    "smashen": "smash",
    "smashens": "smash",
    "smashs": "smash",
    "smask": "smaska",
    "smaskad": "smaska",
    "smaskade": "smaska",
    "smaskades": "smaska",
    "smaskads": "smaska",
    "smaskande": "smaska",
    "smaskanden": "smaskande",
    "smaskandena": "smaskande",
    "smaskandenas": "smaskande",
    "smaskandens": "smaskande",
    "smaskandes": "smaskande",
    "smaskandet": "smaskande",
    "smaskandets": "smaskande",
    "smaskar": "smaska",
    "smaskas": "smaska",
    "smaskat": "smaska",
    "smaskats": "smaska",
    "smasket": "smask",
    "smaskets": "smask",
    "smaskiga": "smaskig",
    "smaskigare": "smaskig",
    "smaskigares": "smaskig",
    "smaskigas": "smaskig",
    "smaskigast": "smaskig",
    "smaskigaste": "smaskig",
    "smaskigastes": "smaskig",
    "smaskigasts": "smaskig",
    "smaskige": "smaskig",
    "smaskiges": "smaskig",
    "smaskigheten": "smaskighet",
    "smaskighetens": "smaskighet",
    "smaskigheter": "smaskighet",
    "smaskigheterna": "smaskighet",
    "smaskigheternas": "smaskighet",
    "smaskigheters": "smaskighet",
    "smaskighets": "smaskighet",
    "smaskigs": "smaskig",
    "smaskigt": "smaskig",
    "smaskigts": "smaskig",
    "smasks": "smask",
    "smattar": "smatt",
    "smattarna": "smatt",
    "smattarnas": "smatt",
    "smattars": "smatt",
    "smatten": "smatt",
    "smattens": "smatt",
    "smatter": "smattra",
    "smatters": "smatter",
    "smattrade": "smattra",
    "smattrades": "smattra",
    "smattrande": "smattra",
    "smattranden": "smattrande",
    "smattrandena": "smattrande",
    "smattrandenas": "smattrande",
    "smattrandens": "smattrande",
    "smattrandes": "smattrande",
    "smattrandet": "smattrande",
    "smattrandets": "smattrande",
    "smattrar": "smattra",
    "smattras": "smattra",
    "smattrat": "smattra",
    "smattrats": "smattra",
    "smattret": "smatter",
    "smattrets": "smatter",
    "smatts": "smatt",
    "smeden": "smed",
    "smedens": "smed",
    "smeder": "smed",
    "smederna": "smed",
    "smedernas": "smed",
    "smeders": "smed",
    "smedjan": "smedja",
    "smedjans": "smedja",
    "smedjas": "smedja",
    "smedje": "smedja",
    "smedjor": "smedja",
    "smedjorna": "smedja",
    "smedjornas": "smedja",
    "smedjors": "smedja",
    "smeds": "smed",
    "smegman": "smegma",
    "smegmans": "smegma",
    "smegmas": "smegma",
    "smegmat": "smegma",
    "smegmats": "smegma",
    "smek": "smeka",
    "smekan": "smeka",
    "smekande": "smeka",
    "smekanden": "smekande",
    "smekandena": "smekande",
    "smekandenas": "smekande",
    "smekandens": "smekande",
    "smekandes": "smekande",
    "smekandet": "smekande",
    "smekandets": "smekande",
    "smekans": "smeka",
    "smekas": "smeka",
    "smeke": "smeka",
    "smeker": "smeka",
    "smekes": "smeka",
    "smeket": "smek",
    "smekets": "smek",
    "smekmånaden": "smekmånad",
    "smekmånadens": "smekmånad",
    "smekmånader": "smekmånad",
    "smekmånaderna": "smekmånad",
    "smekmånadernas": "smekmånad",
    "smekmånaders": "smekmånad",
    "smekmånads": "smekmånad",
    "smekmånadslyxen": "smekmånadslyx",
    "smekmånadslyxens": "smekmånadslyx",
    "smeknamnen": "smeknamn",
    "smeknamnens": "smeknamn",
    "smeknamnet": "smeknamn",
    "smeknamnets": "smeknamn",
    "smeknamns": "smeknamn",
    "smekningar": "smekning",
    "smekningarna": "smekning",
    "smekningarnas": "smekning",
    "smekningars": "smekning",
    "smekningen": "smekning",
    "smekningens": "smekning",
    "smeknings": "smekning",
    "smekor": "smeka",
    "smekorden": "smekord",
    "smekordens": "smekord",
    "smekordet": "smekord",
    "smekordets": "smekord",
    "smekords": "smekord",
    "smekorna": "smeka",
    "smekornas": "smeka",
    "smekors": "smeka",
    "smeks": "smeka",
    "smeksamheten": "smeksamhet",
    "smeksamhetens": "smeksamhet",
    "smeksamhets": "smeksamhet",
    "smeksamma": "smeksam",
    "smeksammare": "smeksam",
    "smeksammares": "smeksam",
    "smeksammas": "smeksam",
    "smeksammast": "smeksam",
    "smeksammaste": "smeksam",
    "smeksammastes": "smeksam",
    "smeksammasts": "smeksam",
    "smeksamme": "smeksam",
    "smeksammes": "smeksam",
    "smeksams": "smeksam",
    "smeksamt": "smeksam",
    "smeksamts": "smeksam",
    "smekt": "smeka",
    "smekta": "smeka",
    "smektas": "smeka",
    "smekte": "smeka",
    "smektes": "smekas",
    "smekts": "smekas",
    "smet": "smita",
    "smetad": "smeta",
    "smetade": "smeta",
    "smetades": "smeta",
    "smetads": "smeta",
    "smetanan": "smetana",
    "smetanans": "smetana",
    "smetanas": "smetana",
    "smetande": "smeta",
    "smetanden": "smetande",
    "smetandena": "smetande",
    "smetandenas": "smetande",
    "smetandens": "smetande",
    "smetandes": "smetande",
    "smetandet": "smetande",
    "smetandets": "smetande",
    "smetar": "smeta",
    "smetas": "smeta",
    "smetat": "smeta",
    "smetats": "smeta",
    "smeten": "smet",
    "smetens": "smet",
    "smeter": "smet",
    "smeterna": "smet",
    "smeternas": "smet",
    "smeters": "smet",
    "smetiga": "smetig",
    "smetigare": "smetig",
    "smetigares": "smetig",
    "smetigas": "smetig",
    "smetigast": "smetig",
    "smetigaste": "smetig",
    "smetigastes": "smetig",
    "smetigasts": "smetig",
    "smetige": "smetig",
    "smetiges": "smetig",
    "smetigs": "smetig",
    "smetigt": "smetig",
    "smetigts": "smetig",
    "smets": "smita",
    "smicker": "smickra",
    "smickers": "smicker",
    "smickrad": "smickra",
    "smickrade": "smickrad",
    "smickrades": "smickrad",
    "smickrads": "smickrad",
    "smickrande": "smickra",
    "smickranden": "smickrande",
    "smickrandena": "smickrande",
    "smickrandenas": "smickrande",
    "smickrandens": "smickrande",
    "smickrandes": "smickrande",
    "smickrandet": "smickrande",
    "smickrandets": "smickrande",
    "smickrar": "smickrare",
    "smickraren": "smickrare",
    "smickrarens": "smickrare",
    "smickrares": "smickrare",
    "smickrarna": "smickrare",
    "smickrarnas": "smickrare",
    "smickras": "smickra",
    "smickrat": "smickrad",
    "smickrats": "smickrad",
    "smickret": "smicker",
    "smickrets": "smicker",
    "smid": "smida",
    "smidande": "smida",
    "smidanden": "smidande",
    "smidandena": "smidande",
    "smidandenas": "smidande",
    "smidandens": "smidande",
    "smidandes": "smidande",
    "smidandet": "smidande",
    "smidandets": "smidande",
    "smidar": "smidare",
    "smidaren": "smidare",
    "smidarens": "smidare",
    "smidares": "smidare",
    "smidarna": "smidare",
    "smidarnas": "smidare",
    "smidas": "smida",
    "smidbara": "smidbar",
    "smidbarare": "smidbar",
    "smidbarares": "smidbar",
    "smidbaras": "smidbar",
    "smidbarast": "smidbar",
    "smidbaraste": "smidbar",
    "smidbarastes": "smidbar",
    "smidbarasts": "smidbar",
    "smidbare": "smidbar",
    "smidbares": "smidbar",
    "smidbarheten": "smidbarhet",
    "smidbarhetens": "smidbarhet",
    "smidbarhets": "smidbarhet",
    "smidbars": "smidbar",
    "smidbart": "smidbar",
    "smidbarts": "smidbar",
    "smidd": "smida",
    "smidda": "smida",
    "smiddas": "smida",
    "smidde": "smida",
    "smiddes": "smida",
    "smidds": "smida",
    "smiden": "smide",
    "smidena": "smide",
    "smidenas": "smide",
    "smidens": "smide",
    "smider": "smida",
    "smiderier": "smideri",
    "smiderierna": "smideri",
    "smideriernas": "smideri",
    "smideriers": "smideri",
    "smideriet": "smideri",
    "smideriets": "smideri",
    "smideris": "smideri",
    "smiderit": "smideri",
    "smiderits": "smideri",
    "smides": "smide",
    "smidesjärnet": "smidesjärn",
    "smidesjärnets": "smidesjärn",
    "smidesjärns": "smidesjärn",
    "smidesljusstak": "smidesljusstake",
    "smidesljusstakar": "smidesljusstake",
    "smidesljusstakarna": "smidesljusstake",
    "smidesljusstakarnas": "smidesljusstake",
    "smidesljusstakars": "smidesljusstake",
    "smidesljusstaken": "smidesljusstake",
    "smidesljusstakens": "smidesljusstake",
    "smidesljusstakes": "smidesljusstake",
    "smidesljusstaks": "smidesljusstake",
    "smidespustar": "smidespust",
    "smidespustarna": "smidespust",
    "smidespustarnas": "smidespust",
    "smidespustars": "smidespust",
    "smidespusten": "smidespust",
    "smidespustens": "smidespust",
    "smidespusts": "smidespust",
    "smidesverktygen": "smidesverktyg",
    "smidesverktygens": "smidesverktyg",
    "smidesverktyget": "smidesverktyg",
    "smidesverktygets": "smidesverktyg",
    "smidesverktygs": "smidesverktyg",
    "smidet": "smide",
    "smidets": "smide",
    "smidiga": "smidig",
    "smidigare": "smidig",
    "smidigares": "smidig",
    "smidigas": "smidig",
    "smidigast": "smidig",
    "smidigaste": "smidig",
    "smidigastes": "smidig",
    "smidigasts": "smidig",
    "smidige": "smidig",
    "smidiges": "smidig",
    "smidigheten": "smidighet",
    "smidighetens": "smidighet",
    "smidighets": "smidighet",
    "smidigs": "smidig",
    "smidigt": "smidig",
    "smidigts": "smidig",
    "smidjebälten": "smidjebälte",
    "smidjebältena": "smidjebälte",
    "smidjebältenas": "smidjebälte",
    "smidjebältens": "smidjebälte",
    "smidjebältes": "smidjebälte",
    "smidjebältet": "smidjebälte",
    "smidjebältets": "smidjebälte",
    "smids": "smida",
    "smil": "smila",
    "smilad": "smila",
    "smilade": "smila",
    "smilades": "smila",
    "smilads": "smila",
    "smilande": "smila",
    "smilanden": "smilande",
    "smilandena": "smilande",
    "smilandenas": "smilande",
    "smilandens": "smilande",
    "smilandes": "smilande",
    "smilandet": "smilande",
    "smilandets": "smilande",
    "smilar": "smilare",
    "smilaren": "smilare",
    "smilarens": "smilare",
    "smilares": "smilare",
    "smilarna": "smilare",
    "smilarnas": "smilare",
    "smilas": "smila",
    "smilat": "smila",
    "smilats": "smila",
    "smilen": "smil",
    "smilens": "smil",
    "smilet": "smil",
    "smilets": "smil",
    "smileyn": "smiley",
    "smileyns": "smiley",
    "smileys": "smiley",
    "smileysarna": "smiley",
    "smileysarnas": "smiley",
    "smileysen": "smiley",
    "smileysens": "smiley",
    "smilfinkar": "smilfink",
    "smilfinkarna": "smilfink",
    "smilfinkarnas": "smilfink",
    "smilfinkars": "smilfink",
    "smilfinken": "smilfink",
    "smilfinkens": "smilfink",
    "smilfinks": "smilfink",
    "smilgropar": "smilgrop",
    "smilgroparna": "smilgrop",
    "smilgroparnas": "smilgrop",
    "smilgropars": "smilgrop",
    "smilgropen": "smilgrop",
    "smilgropens": "smilgrop",
    "smilgrops": "smilgrop",
    "smiliga": "smilig",
    "smiligare": "smilig",
    "smiligares": "smilig",
    "smiligas": "smilig",
    "smiligast": "smilig",
    "smiligaste": "smilig",
    "smiligastes": "smilig",
    "smiligasts": "smilig",
    "smilige": "smilig",
    "smiliges": "smilig",
    "smiligheten": "smilighet",
    "smilighetens": "smilighet",
    "smilighets": "smilighet",
    "smiligs": "smilig",
    "smiligt": "smilig",
    "smiligts": "smilig",
    "smils": "smil",
    "smilska": "smilsk",
    "smilskare": "smilsk",
    "smilskares": "smilsk",
    "smilskas": "smilsk",
    "smilskast": "smilsk",
    "smilskaste": "smilsk",
    "smilskastes": "smilsk",
    "smilskasts": "smilsk",
    "smilske": "smilsk",
    "smilskes": "smilsk",
    "smilskheten": "smilskhet",
    "smilskhetens": "smilskhet",
    "smilskhets": "smilskhet",
    "smilsks": "smilsk",
    "smilskt": "smilsk",
    "smilskts": "smilsk",
    "smink": "sminka",
    "sminkad": "sminka",
    "sminkade": "sminka",
    "sminkades": "sminka",
    "sminkads": "sminka",
    "sminkande": "sminka",
    "sminkanden": "sminkande",
    "sminkandena": "sminkande",
    "sminkandenas": "sminkande",
    "sminkandens": "sminkande",
    "sminkandes": "sminkande",
    "sminkandet": "sminkande",
    "sminkandets": "sminkande",
    "sminkar": "sminkare",
    "sminkaren": "sminkare",
    "sminkarens": "sminkare",
    "sminkares": "sminkare",
    "sminkarna": "sminkare",
    "sminkarnas": "sminkare",
    "sminkas": "sminka",
    "sminkat": "sminka",
    "sminkats": "sminka",
    "sminker": "smink",
    "sminkerna": "smink",
    "sminkernas": "smink",
    "sminkers": "smink",
    "sminkerskan": "sminkerska",
    "sminkerskans": "sminkerska",
    "sminkerskas": "sminkerska",
    "sminkerske": "sminkerska",
    "sminkerskor": "sminkerska",
    "sminkerskorna": "sminkerska",
    "sminkerskornas": "sminkerska",
    "sminkerskors": "sminkerska",
    "sminket": "smink",
    "sminkets": "smink",
    "sminkexperten": "sminkexpert",
    "sminkexpertens": "sminkexpert",
    "sminkexperter": "sminkexpert",
    "sminkexperterna": "sminkexpert",
    "sminkexperternas": "sminkexpert",
    "sminkexperters": "sminkexpert",
    "sminkexperts": "sminkexpert",
    "sminkningar": "sminkning",
    "sminkningarna": "sminkning",
    "sminkningarnas": "sminkning",
    "sminkningars": "sminkning",
    "sminkningen": "sminkning",
    "sminkningens": "sminkning",
    "sminknings": "sminkning",
    "sminkroten": "sminkrot",
    "sminkrotens": "sminkrot",
    "sminkrots": "sminkrot",
    "sminks": "smink",
    "sminkören": "sminkör",
    "sminkörens": "sminkör",
    "sminkörer": "sminkör",
    "sminkörerna": "sminkör",
    "sminkörernas": "sminkör",
    "sminkörers": "sminkör",
    "sminkörs": "sminkör",
    "sminkösen": "sminkös",
    "sminkösens": "sminkös",
    "sminköser": "sminkös",
    "sminköserna": "sminkös",
    "sminkösernas": "sminkös",
    "sminkösers": "sminkös",
    "smisk": "smiska",
    "smiskad": "smiska",
    "smiskade": "smiska",
    "smiskades": "smiska",
    "smiskads": "smiska",
    "smiskande": "smiska",
    "smiskanden": "smiskande",
    "smiskandena": "smiskande",
    "smiskandenas": "smiskande",
    "smiskandens": "smiskande",
    "smiskandes": "smiskande",
    "smiskandet": "smiskande",
    "smiskandets": "smiskande",
    "smiskar": "smiska",
    "smiskas": "smiska",
    "smiskat": "smiska",
    "smiskats": "smiska",
    "smisket": "smisk",
    "smiskets": "smisk",
    "smisks": "smisk",
    "smit": "smita",
    "smitan": "smita",
    "smitande": "smita",
    "smitanden": "smitande",
    "smitandena": "smitande",
    "smitandenas": "smitande",
    "smitandens": "smitande",
    "smitandes": "smitande",
    "smitandet": "smitande",
    "smitandets": "smitande",
    "smitans": "smita",
    "smitas": "smita",
    "smite": "smita",
    "smiter": "smita",
    "smites": "smita",
    "smitit": "smita",
    "smitits": "smita",
    "smitor": "smita",
    "smitorna": "smita",
    "smitornas": "smita",
    "smitors": "smita",
    "smits": "smita",
    "smitt": "smitta",
    "smittad": "smitta",
    "smittade": "smitta",
    "smittades": "smitta",
    "smittads": "smitta",
    "smittan": "smitta",
    "smittande": "smitta",
    "smittanden": "smittande",
    "smittandena": "smittande",
    "smittandenas": "smittande",
    "smittandens": "smittande",
    "smittandes": "smittande",
    "smittandet": "smittande",
    "smittandets": "smittande",
    "smittans": "smitta",
    "smittar": "smitta",
    "smittas": "smitta",
    "smittat": "smitta",
    "smittats": "smitta",
    "smittbara": "smittbar",
    "smittbaras": "smittbar",
    "smittbare": "smittbar",
    "smittbares": "smittbar",
    "smittbars": "smittbar",
    "smittbart": "smittbar",
    "smittbarts": "smittbar",
    "smittbärar": "smittbärare",
    "smittbäraren": "smittbärare",
    "smittbärarens": "smittbärare",
    "smittbärares": "smittbärare",
    "smittbärarna": "smittbärare",
    "smittbärarnas": "smittbärare",
    "smitte": "smitta",
    "smitthärdar": "smitthärd",
    "smitthärdarna": "smitthärd",
    "smitthärdarnas": "smitthärd",
    "smitthärdars": "smitthärd",
    "smitthärden": "smitthärd",
    "smitthärdens": "smitthärd",
    "smitthärds": "smitthärd",
    "smittkopp": "smittkoppa",
    "smittkoppan": "smittkoppa",
    "smittkoppans": "smittkoppa",
    "smittkoppas": "smittkoppa",
    "smittkoppe": "smittkoppa",
    "smittkoppor": "smittkoppa",
    "smittkopporna": "smittkoppa",
    "smittkoppornas": "smittkoppa",
    "smittkoppors": "smittkoppa",
    "smittkopps": "smittkoppa",
    "smittkäll": "smittkälla",
    "smittkällan": "smittkälla",
    "smittkällans": "smittkälla",
    "smittkällas": "smittkälla",
    "smittkälle": "smittkälla",
    "smittkällor": "smittkälla",
    "smittkällorna": "smittkälla",
    "smittkällornas": "smittkälla",
    "smittkällors": "smittkälla",
    "smittkälls": "smittkälla",
    "smittohärdar": "smittohärd",
    "smittohärdarna": "smittohärd",
    "smittohärdarnas": "smittohärd",
    "smittohärdars": "smittohärd",
    "smittohärden": "smittohärd",
    "smittohärdens": "smittohärd",
    "smittohärds": "smittohärd",
    "smittor": "smitta",
    "smittorisken": "smittorisk",
    "smittoriskens": "smittorisk",
    "smittorisker": "smittorisk",
    "smittoriskerna": "smittorisk",
    "smittoriskernas": "smittorisk",
    "smittoriskers": "smittorisk",
    "smittorisks": "smittorisk",
    "smittorna": "smitta",
    "smittornas": "smitta",
    "smittors": "smitta",
    "smittosamheten": "smittosamhet",
    "smittosamhetens": "smittosamhet",
    "smittosamhets": "smittosamhet",
    "smittosamma": "smittosam",
    "smittosammare": "smittosam",
    "smittosammares": "smittosam",
    "smittosammas": "smittosam",
    "smittosammast": "smittosam",
    "smittosammaste": "smittosam",
    "smittosammastes": "smittosam",
    "smittosammasts": "smittosam",
    "smittosamme": "smittosam",
    "smittosammes": "smittosam",
    "smittosams": "smittosam",
    "smittosamt": "smittosam",
    "smittosamts": "smittosam",
    "smittoövervakningar": "smittoövervakning",
    "smittoövervakningarna": "smittoövervakning",
    "smittoövervakningarnas": "smittoövervakning",
    "smittoövervakningars": "smittoövervakning",
    "smittoövervakningen": "smittoövervakning",
    "smittoövervakningens": "smittoövervakning",
    "smittoövervaknings": "smittoövervakning",
    "smitts": "smitta",
    "smittsamheten": "smittsamhet",
    "smittsamhetens": "smittsamhet",
    "smittsamhets": "smittsamhet",
    "smittsamma": "smittsam",
    "smittsammare": "smittsam",
    "smittsammares": "smittsam",
    "smittsammas": "smittsam",
    "smittsammast": "smittsam",
    "smittsammaste": "smittsam",
    "smittsammastes": "smittsam",
    "smittsammasts": "smittsam",
    "smittsamme": "smittsam",
    "smittsammes": "smittsam",
    "smittsams": "smittsam",
    "smittsamt": "smittsam",
    "smittsamts": "smittsam",
    "smittskyddet": "smittskydd",
    "smittskyddets": "smittskydd",
    "smittskydds": "smittskydd",
    "smittskyddsmyndigheten": "smittskyddsmyndighet",
    "smittskyddsmyndighetens": "smittskyddsmyndighet",
    "smittskyddsmyndigheter": "smittskyddsmyndighet",
    "smittskyddsmyndigheterna": "smittskyddsmyndighet",
    "smittskyddsmyndigheternas": "smittskyddsmyndighet",
    "smittskyddsmyndigheters": "smittskyddsmyndighet",
    "smittskyddsmyndighets": "smittskyddsmyndighet",
    "smittspridningen": "smittspridning",
    "smittspridningens": "smittspridning",
    "smittspridnings": "smittspridning",
    "smittämnen": "smittämne",
    "smittämnena": "smittämne",
    "smittämnenas": "smittämne",
    "smittämnens": "smittämne",
    "smittämnes": "smittämne",
    "smittämnet": "smittämne",
    "smittämnets": "smittämne",
    "smock": "smocka",
    "smockad": "smocka",
    "smockade": "smockad",
    "smockades": "smockad",
    "smockads": "smockad",
    "smockan": "smocka",
    "smockande": "smocka",
    "smockanden": "smockande",
    "smockandena": "smockande",
    "smockandenas": "smockande",
    "smockandens": "smockande",
    "smockandes": "smockande",
    "smockandet": "smockande",
    "smockandets": "smockande",
    "smockans": "smocka",
    "smockar": "smocka",
    "smockas": "smocka",
    "smockat": "smockad",
    "smockats": "smockad",
    "smocke": "smocka",
    "smocken": "smock",
    "smockens": "smock",
    "smockfulla": "smockfull",
    "smockfullare": "smockfull",
    "smockfullares": "smockfull",
    "smockfullas": "smockfull",
    "smockfullast": "smockfull",
    "smockfullaste": "smockfull",
    "smockfullastes": "smockfull",
    "smockfullasts": "smockfull",
    "smockfulle": "smockfull",
    "smockfulles": "smockfull",
    "smockfullheten": "smockfullhet",
    "smockfullhetens": "smockfullhet",
    "smockfullhets": "smockfullhet",
    "smockfulls": "smockfull",
    "smockfullt": "smockfull",
    "smockfullts": "smockfull",
    "smockor": "smocka",
    "smockorna": "smocka",
    "smockornas": "smocka",
    "smockors": "smocka",
    "smocks": "smocka",
    "smogen": "smog",
    "smogens": "smog",
    "smogs": "smog",
    "smokingar": "smoking",
    "smokingarna": "smoking",
    "smokingarnas": "smoking",
    "smokingars": "smoking",
    "smokingen": "smoking",
    "smokingens": "smoking",
    "smokingklänningar": "smokingklänning",
    "smokingklänningarna": "smokingklänning",
    "smokingklänningarnas": "smokingklänning",
    "smokingklänningars": "smokingklänning",
    "smokingklänningen": "smokingklänning",
    "smokingklänningens": "smokingklänning",
    "smokingklännings": "smokingklänning",
    "smokings": "smoking",
    "smokingskjort": "smokingskjorta",
    "smokingskjortan": "smokingskjorta",
    "smokingskjortans": "smokingskjorta",
    "smokingskjortas": "smokingskjorta",
    "smokingskjorte": "smokingskjorta",
    "smokingskjortor": "smokingskjorta",
    "smokingskjortorna": "smokingskjorta",
    "smokingskjortornas": "smokingskjorta",
    "smokingskjortors": "smokingskjorta",
    "smokingskjorts": "smokingskjorta",
    "smolket": "smolk",
    "smolkets": "smolk",
    "smolks": "smolk",
    "smolten": "smolt",
    "smoltens": "smolt",
    "smolts": "smolt",
    "smord": "smörja",
    "smorda": "smörja",
    "smordas": "smörja",
    "smorde": "smörja",
    "smordes": "smörja",
    "smords": "smörja",
    "smorläders": "smorläder",
    "smorlädret": "smorläder",
    "smorlädrets": "smorläder",
    "smort": "smörja",
    "smorts": "smörja",
    "sms-n": "sms",
    "sms-na": "sms",
    "sms-nas": "sms",
    "sms-ns": "sms",
    "sms-s": "sms",
    "sms-t": "sms",
    "sms-ts": "sms",
    "sms:ad": "sms:a",
    "sms:ade": "sms:a",
    "sms:ades": "sms:a",
    "sms:ads": "sms:a",
    "sms:ande": "sms:a",
    "sms:anden": "sms:ande",
    "sms:andena": "sms:ande",
    "sms:andenas": "sms:ande",
    "sms:andens": "sms:ande",
    "sms:andes": "sms:ande",
    "sms:andet": "sms:ande",
    "sms:andets": "sms:ande",
    "sms:ar": "sms:a",
    "sms:as": "sms:a",
    "sms:at": "sms:a",
    "sms:ats": "sms:a",
    "sms:n": "sms",
    "sms:na": "sms",
    "sms:nas": "sms",
    "sms:ns": "sms",
    "sms:s": "sms",
    "sms:t": "sms",
    "sms:ts": "sms",
    "smsn": "sms",
    "smsna": "sms",
    "smsnas": "sms",
    "smsns": "sms",
    "smss": "sms",
    "smst": "sms",
    "smsts": "sms",
    "smugen": "smyga",
    "smugens": "smyga",
    "smuget": "smyga",
    "smugets": "smyga",
    "smuggel": "smuggla",
    "smuggelcigaretten": "smuggelcigarett",
    "smuggelcigarettens": "smuggelcigarett",
    "smuggelcigaretter": "smuggelcigarett",
    "smuggelcigaretterna": "smuggelcigarett",
    "smuggelcigaretternas": "smuggelcigarett",
    "smuggelcigaretters": "smuggelcigarett",
    "smuggelcigaretts": "smuggelcigarett",
    "smuggels": "smuggel",
    "smuggelspriten": "smuggelsprit",
    "smuggelspritens": "smuggelsprit",
    "smuggelsprits": "smuggelsprit",
    "smugglad": "smuggla",
    "smugglade": "smuggla",
    "smugglades": "smuggla",
    "smugglads": "smuggla",
    "smugglande": "smuggla",
    "smugglanden": "smugglande",
    "smugglandena": "smugglande",
    "smugglandenas": "smugglande",
    "smugglandens": "smugglande",
    "smugglandes": "smugglande",
    "smugglandet": "smugglande",
    "smugglandets": "smugglande",
    "smugglar": "smugglare",
    "smugglaren": "smugglare",
    "smugglarens": "smugglare",
    "smugglares": "smugglare",
    "smugglarna": "smugglare",
    "smugglarnas": "smugglare",
    "smugglarskeppen": "smugglarskepp",
    "smugglarskeppens": "smugglarskepp",
    "smugglarskeppet": "smugglarskepp",
    "smugglarskeppets": "smugglarskepp",
    "smugglarskepps": "smugglarskepp",
    "smugglas": "smuggla",
    "smugglat": "smuggla",
    "smugglats": "smuggla",
    "smugglerier": "smuggleri",
    "smugglerierna": "smuggleri",
    "smuggleriernas": "smuggleri",
    "smuggleriers": "smuggleri",
    "smuggleriet": "smuggleri",
    "smuggleriets": "smuggleri",
    "smuggleris": "smuggleri",
    "smugglerit": "smuggleri",
    "smugglerits": "smuggleri",
    "smugglet": "smuggel",
    "smugglets": "smuggel",
    "smugglingar": "smuggling",
    "smugglingarna": "smuggling",
    "smugglingarnas": "smuggling",
    "smugglingars": "smuggling",
    "smugglingen": "smuggling",
    "smugglingens": "smuggling",
    "smugglings": "smuggling",
    "smugglingsbrotten": "smugglingsbrott",
    "smugglingsbrottens": "smugglingsbrott",
    "smugglingsbrottet": "smugglingsbrott",
    "smugglingsbrottets": "smugglingsbrott",
    "smugglingsbrotts": "smugglingsbrott",
    "smugit": "smyga",
    "smugits": "smyga",
    "smugna": "smyga",
    "smugnas": "smyga",
    "smugne": "smyga",
    "smugnes": "smyga",
    "smul": "smula",
    "smula": "smul",
    "smulad": "smula",
    "smulade": "smula",
    "smulades": "smula",
    "smulads": "smula",
    "smulan": "smula",
    "smulande": "smula",
    "smulanden": "smulande",
    "smulandena": "smulande",
    "smulandenas": "smulande",
    "smulandens": "smulande",
    "smulandes": "smulande",
    "smulandet": "smulande",
    "smulandets": "smulande",
    "smulans": "smula",
    "smular": "smula",
    "smulare": "smul",
    "smulares": "smul",
    "smulas": "smula",
    "smulast": "smul",
    "smulaste": "smul",
    "smulastes": "smul",
    "smulasts": "smul",
    "smulat": "smula",
    "smulats": "smula",
    "smule": "smula",
    "smules": "smul",
    "smulgråtar": "smulgråt",
    "smulgråtarna": "smulgråt",
    "smulgråtarnas": "smulgråt",
    "smulgråtars": "smulgråt",
    "smulgråten": "smulgråt",
    "smulgråtens": "smulgråt",
    "smulgråts": "smulgråt",
    "smuliga": "smulig",
    "smuligare": "smulig",
    "smuligares": "smulig",
    "smuligas": "smulig",
    "smuligast": "smulig",
    "smuligaste": "smulig",
    "smuligastes": "smulig",
    "smuligasts": "smulig",
    "smulige": "smulig",
    "smuliges": "smulig",
    "smuligheten": "smulighet",
    "smulighetens": "smulighet",
    "smulighets": "smulighet",
    "smuligs": "smulig",
    "smuligt": "smulig",
    "smuligts": "smulig",
    "smulle": "smälla",
    "smulor": "smula",
    "smulorna": "smula",
    "smulornas": "smula",
    "smulors": "smula",
    "smuls": "smula",
    "smult": "smulta",
    "smultad": "smulta",
    "smultade": "smulta",
    "smultades": "smulta",
    "smultads": "smulta",
    "smultande": "smulta",
    "smultanden": "smultande",
    "smultandena": "smultande",
    "smultandenas": "smultande",
    "smultandens": "smultande",
    "smultandes": "smultande",
    "smultandet": "smultande",
    "smultandets": "smultande",
    "smultar": "smulta",
    "smultas": "smulta",
    "smultat": "smulta",
    "smultats": "smulta",
    "smulte": "smälta",
    "smulten": "smälta",
    "smultens": "smälta",
    "smultes": "smälta",
    "smultet": "smult",
    "smultets": "smult",
    "smultit": "smälta",
    "smultits": "smälta",
    "smultna": "smälta",
    "smultnas": "smälta",
    "smultne": "smälta",
    "smultnes": "smälta",
    "smultronen": "smultron",
    "smultronens": "smultron",
    "smultronet": "smultron",
    "smultronets": "smultron",
    "smultrons": "smultron",
    "smultronstrået": "smultronstrå",
    "smultronstråets": "smultronstrå",
    "smultronstrån": "smultronstrå",
    "smultronstråna": "smultronstrå",
    "smultronstrånas": "smultronstrå",
    "smultronstråns": "smultronstrå",
    "smultronstrås": "smultronstrå",
    "smultronstråt": "smultronstrå",
    "smultronstråts": "smultronstrå",
    "smultronställen": "smultronställe",
    "smultronställena": "smultronställe",
    "smultronställenas": "smultronställe",
    "smultronställens": "smultronställe",
    "smultronställes": "smultronställe",
    "smultronstället": "smultronställe",
    "smultronställets": "smultronställe",
    "smultrontungan": "smultrontunga",
    "smultrontungans": "smultrontunga",
    "smultrontungas": "smultrontunga",
    "smults": "smult",
    "smurfar": "smurf",
    "smurfarna": "smurf",
    "smurfarnas": "smurf",
    "smurfars": "smurf",
    "smurfen": "smurf",
    "smurfens": "smurf",
    "smurfs": "smurf",
    "smussel": "smussla",
    "smussels": "smussel",
    "smusslade": "smussla",
    "smusslades": "smussla",
    "smusslande": "smussla",
    "smusslanden": "smusslande",
    "smusslandena": "smusslande",
    "smusslandenas": "smusslande",
    "smusslandens": "smusslande",
    "smusslandes": "smusslande",
    "smusslandet": "smusslande",
    "smusslandets": "smusslande",
    "smusslar": "smussla",
    "smusslas": "smussla",
    "smusslat": "smussla",
    "smusslats": "smussla",
    "smusslet": "smussel",
    "smusslets": "smussel",
    "smuts": "smutsa",
    "smutsad": "smutsa",
    "smutsade": "smutsa",
    "smutsades": "smutsa",
    "smutsads": "smutsa",
    "smutsande": "smutsa",
    "smutsanden": "smutsande",
    "smutsandena": "smutsande",
    "smutsandenas": "smutsande",
    "smutsandens": "smutsande",
    "smutsandes": "smutsande",
    "smutsandet": "smutsande",
    "smutsandets": "smutsande",
    "smutsar": "smutsa",
    "smutsas": "smutsa",
    "smutsat": "smutsa",
    "smutsats": "smutsa",
    "smutsbladen": "smutsblad",
    "smutsbladens": "smutsblad",
    "smutsbladet": "smutsblad",
    "smutsbladets": "smutsblad",
    "smutsblads": "smutsblad",
    "smutsen": "smuts",
    "smutsens": "smuts",
    "smutsgrisar": "smutsgris",
    "smutsgrisarna": "smutsgris",
    "smutsgrisarnas": "smutsgris",
    "smutsgrisars": "smutsgris",
    "smutsgrisen": "smutsgris",
    "smutsgrisens": "smutsgris",
    "smutsgråa": "smutsgrå",
    "smutsgråare": "smutsgrå",
    "smutsgråares": "smutsgrå",
    "smutsgråas": "smutsgrå",
    "smutsgråast": "smutsgrå",
    "smutsgråaste": "smutsgrå",
    "smutsgråastes": "smutsgrå",
    "smutsgråasts": "smutsgrå",
    "smutsgråe": "smutsgrå",
    "smutsgråes": "smutsgrå",
    "smutsgrås": "smutsgrå",
    "smutsgrått": "smutsgrå",
    "smutsgråtts": "smutsgrå",
    "smutsiga": "smutsig",
    "smutsigare": "smutsig",
    "smutsigares": "smutsig",
    "smutsigas": "smutsig",
    "smutsigast": "smutsig",
    "smutsigaste": "smutsig",
    "smutsigastes": "smutsig",
    "smutsigasts": "smutsig",
    "smutsige": "smutsig",
    "smutsiges": "smutsig",
    "smutsigheten": "smutsighet",
    "smutsighetens": "smutsighet",
    "smutsighets": "smutsighet",
    "smutsigs": "smutsig",
    "smutsigt": "smutsig",
    "smutsigts": "smutsig",
    "smutskast": "smutskasta",
    "smutskastad": "smutskasta",
    "smutskastade": "smutskasta",
    "smutskastades": "smutskasta",
    "smutskastads": "smutskasta",
    "smutskastande": "smutskasta",
    "smutskastanden": "smutskastande",
    "smutskastandena": "smutskastande",
    "smutskastandenas": "smutskastande",
    "smutskastandens": "smutskastande",
    "smutskastandes": "smutskastande",
    "smutskastandet": "smutskastande",
    "smutskastandets": "smutskastande",
    "smutskastar": "smutskasta",
    "smutskastas": "smutskasta",
    "smutskastat": "smutskasta",
    "smutskastats": "smutskasta",
    "smutskastningen": "smutskastning",
    "smutskastningens": "smutskastning",
    "smutskastnings": "smutskastning",
    "smutskastningskampanjen": "smutskastningskampanj",
    "smutskastningskampanjens": "smutskastningskampanj",
    "smutskastningskampanjer": "smutskastningskampanj",
    "smutskastningskampanjerna": "smutskastningskampanj",
    "smutskastningskampanjernas": "smutskastningskampanj",
    "smutskastningskampanjers": "smutskastningskampanj",
    "smutskastningskampanjs": "smutskastningskampanj",
    "smutskläderna": "smutskläder",
    "smutsklädernas": "smutskläder",
    "smutskläders": "smutskläder",
    "smutsklädes": "smutskläder",
    "smutskläds": "smutskläder",
    "smutslitteraturen": "smutslitteratur",
    "smutslitteraturens": "smutslitteratur",
    "smutslitteraturs": "smutslitteratur",
    "smutsoranga": "smutsorange",
    "smutsorangare": "smutsorange",
    "smutsorangares": "smutsorange",
    "smutsorangas": "smutsorange",
    "smutsorangast": "smutsorange",
    "smutsorangaste": "smutsorange",
    "smutsorangastes": "smutsorange",
    "smutsorangasts": "smutsorange",
    "smutsorangea": "smutsorange",
    "smutsorangeare": "smutsorange",
    "smutsorangeares": "smutsorange",
    "smutsorangeas": "smutsorange",
    "smutsorangeast": "smutsorange",
    "smutsorangeaste": "smutsorange",
    "smutsorangeastes": "smutsorange",
    "smutsorangeasts": "smutsorange",
    "smutsoranges": "smutsorange",
    "smutsoranget": "smutsorange",
    "smutsorangets": "smutsorange",
    "smutsorangt": "smutsorange",
    "smutsorangts": "smutsorange",
    "smutspås": "smutspåse",
    "smutspåsar": "smutspåse",
    "smutspåsarna": "smutspåse",
    "smutspåsarnas": "smutspåse",
    "smutspåsars": "smutspåse",
    "smutspåsen": "smutspåse",
    "smutspåsens": "smutspåse",
    "smutspåses": "smutspåse",
    "smutstiteln": "smutstitel",
    "smutstitelns": "smutstitel",
    "smutstitels": "smutstitel",
    "smutstitlar": "smutstitel",
    "smutstitlarna": "smutstitel",
    "smutstitlarnas": "smutstitel",
    "smutstitlars": "smutstitel",
    "smutstvätten": "smutstvätt",
    "smutstvättens": "smutstvätt",
    "smutstvätts": "smutstvätt",
    "smutsvattens": "smutsvatten",
    "smutsvattnen": "smutsvatten",
    "smutsvattnens": "smutsvatten",
    "smutsvattnet": "smutsvatten",
    "smutsvattnets": "smutsvatten",
    "smutt": "smutta",
    "smuttad": "smutta",
    "smuttade": "smutta",
    "smuttades": "smutta",
    "smuttads": "smutta",
    "smuttande": "smutta",
    "smuttanden": "smuttande",
    "smuttandena": "smuttande",
    "smuttandenas": "smuttande",
    "smuttandens": "smuttande",
    "smuttandes": "smuttande",
    "smuttandet": "smuttande",
    "smuttandets": "smuttande",
    "smuttar": "smutta",
    "smuttarna": "smutt",
    "smuttarnas": "smutt",
    "smuttars": "smutt",
    "smuttas": "smutta",
    "smuttat": "smutta",
    "smuttats": "smutta",
    "smutten": "smutt",
    "smuttens": "smutt",
    "smutts": "smutt",
    "smyck": "smycka",
    "smyckad": "smycka",
    "smyckade": "smycka",
    "smyckades": "smycka",
    "smyckads": "smycka",
    "smyckande": "smycka",
    "smyckanden": "smyckande",
    "smyckandena": "smyckande",
    "smyckandenas": "smyckande",
    "smyckandens": "smyckande",
    "smyckandes": "smyckande",
    "smyckandet": "smyckande",
    "smyckandets": "smyckande",
    "smyckar": "smycka",
    "smyckas": "smycka",
    "smyckat": "smycka",
    "smyckats": "smycka",
    "smyckegarnityren": "smyckegarnityr",
    "smyckegarnityrens": "smyckegarnityr",
    "smyckegarnityret": "smyckegarnityr",
    "smyckegarnityrets": "smyckegarnityr",
    "smyckegarnityrs": "smyckegarnityr",
    "smycken": "smycke",
    "smyckena": "smycke",
    "smyckenas": "smycke",
    "smyckens": "smycke",
    "smyckes": "smycke",
    "smycket": "smycke",
    "smyckets": "smycke",
    "smycketypen": "smycketyp",
    "smycketypens": "smycketyp",
    "smycketyper": "smycketyp",
    "smycketyperna": "smycketyp",
    "smycketypernas": "smycketyp",
    "smycketypers": "smycketyp",
    "smycketyps": "smycketyp",
    "smyg": "smyga",
    "smygande": "smyga",
    "smyganden": "smygande",
    "smygandena": "smygande",
    "smygandenas": "smygande",
    "smygandens": "smygande",
    "smygandes": "smygande",
    "smygandet": "smygande",
    "smygandets": "smygande",
    "smygar": "smyg",
    "smygarna": "smyg",
    "smygarnas": "smyg",
    "smygars": "smyg",
    "smygas": "smyga",
    "smyge": "smyga",
    "smygen": "smyg",
    "smygens": "smyg",
    "smyger": "smyga",
    "smyges": "smyga",
    "smyghålen": "smyghål",
    "smyghålens": "smyghål",
    "smyghålet": "smyghål",
    "smyghålets": "smyghål",
    "smyghåls": "smyghål",
    "smygimpulsen": "smygimpuls",
    "smygimpulsens": "smygimpuls",
    "smygimpulser": "smygimpuls",
    "smygimpulserna": "smygimpuls",
    "smygimpulsernas": "smygimpuls",
    "smygimpulsers": "smygimpuls",
    "smyglyssn": "smyglyssna",
    "smyglyssnade": "smyglyssna",
    "smyglyssnades": "smyglyssna",
    "smyglyssnande": "smyglyssna",
    "smyglyssnanden": "smyglyssnande",
    "smyglyssnandena": "smyglyssnande",
    "smyglyssnandenas": "smyglyssnande",
    "smyglyssnandens": "smyglyssnande",
    "smyglyssnandes": "smyglyssnande",
    "smyglyssnandet": "smyglyssnande",
    "smyglyssnandets": "smyglyssnande",
    "smyglyssnar": "smyglyssna",
    "smyglyssnas": "smyglyssna",
    "smyglyssnat": "smyglyssna",
    "smyglyssnats": "smyglyssna",
    "smygpremiären": "smygpremiär",
    "smygpremiärens": "smygpremiär",
    "smygpremiärer": "smygpremiär",
    "smygpremiärerna": "smygpremiär",
    "smygpremiärernas": "smygpremiär",
    "smygpremiärers": "smygpremiär",
    "smygpremiärs": "smygpremiär",
    "smygrök": "smygröka",
    "smygrökande": "smygröka",
    "smygrökandes": "smygröka",
    "smygrökas": "smygröka",
    "smygröker": "smygröka",
    "smygrökes": "smygröka",
    "smygröks": "smygröka",
    "smygrökt": "smygröka",
    "smygrökta": "smygröka",
    "smygröktas": "smygröka",
    "smygrökte": "smygröka",
    "smygröktes": "smygröka",
    "smygrökts": "smygröka",
    "smygs": "smyga",
    "smygsup": "smygsupa",
    "smygsupande": "smygsupa",
    "smygsupanden": "smygsupande",
    "smygsupandena": "smygsupande",
    "smygsupandenas": "smygsupande",
    "smygsupandens": "smygsupande",
    "smygsupandes": "smygsupande",
    "smygsupandet": "smygsupande",
    "smygsupandets": "smygsupande",
    "smygsupas": "smygsupa",
    "smygsupe": "smygsupa",
    "smygsuper": "smygsupa",
    "smygsupes": "smygsupa",
    "smygsupit": "smygsupa",
    "smygsupits": "smygsupa",
    "smygsups": "smygsupa",
    "smygsömmar": "smygsöm",
    "smygsömmarna": "smygsöm",
    "smygsömmarnas": "smygsöm",
    "smygsömmars": "smygsöm",
    "smygsömmen": "smygsöm",
    "smygsömmens": "smygsöm",
    "smygsöms": "smygsöm",
    "smygsöp": "smygsupa",
    "smygsöpe": "smygsupa",
    "smygsöpes": "smygsupa",
    "smygsöps": "smygsupa",
    "smygtittade": "smygtitta",
    "smygtittades": "smygtitta",
    "smygtittande": "smygtitta",
    "smygtittanden": "smygtittande",
    "smygtittandena": "smygtittande",
    "smygtittandenas": "smygtittande",
    "smygtittandens": "smygtittande",
    "smygtittandes": "smygtittande",
    "smygtittandet": "smygtittande",
    "smygtittandets": "smygtittande",
    "smygtittar": "smygtitta",
    "smygtittas": "smygtitta",
    "smygtittat": "smygtitta",
    "smygtittats": "smygtitta",
    "smygvinkeln": "smygvinkel",
    "smygvinkelns": "smygvinkel",
    "smygvinkels": "smygvinkel",
    "smygvinklar": "smygvinkel",
    "smygvinklarna": "smygvinkel",
    "smygvinklarnas": "smygvinkel",
    "smygvinklars": "smygvinkel",
    "smygvägar": "smygväg",
    "smygvägarna": "smygväg",
    "smygvägarnas": "smygväg",
    "smygvägars": "smygväg",
    "smygvägen": "smygväg",
    "smygvägens": "smygväg",
    "smygvägs": "smygväg",
    "smygät": "smygäta",
    "smygätande": "smygäta",
    "smygätanden": "smygätande",
    "smygätandena": "smygätande",
    "smygätandenas": "smygätande",
    "smygätandens": "smygätande",
    "smygätandes": "smygätande",
    "smygätandet": "smygätande",
    "smygätandets": "smygätande",
    "smygätas": "smygäta",
    "smygäte": "smygäta",
    "smygäten": "smygäta",
    "smygätens": "smygäta",
    "smygäter": "smygäta",
    "smygätes": "smygäta",
    "smygätet": "smygäta",
    "smygätets": "smygäta",
    "smygätit": "smygäta",
    "smygätits": "smygäta",
    "smygätna": "smygäta",
    "smygätnas": "smygäta",
    "smygätne": "smygäta",
    "smygätnes": "smygäta",
    "smygäts": "smygäta",
    "smygåt": "smygäta",
    "smygåte": "smygäta",
    "smygåtes": "smygäta",
    "smygåts": "smygäta",
    "smäck": "smäcka",
    "smäckande": "smäcka",
    "smäckanden": "smäckande",
    "smäckandena": "smäckande",
    "smäckandenas": "smäckande",
    "smäckandens": "smäckande",
    "smäckandes": "smäckande",
    "smäckandet": "smäckande",
    "smäckandets": "smäckande",
    "smäckar": "smäck",
    "smäckarna": "smäck",
    "smäckarnas": "smäck",
    "smäckars": "smäck",
    "smäckas": "smäcka",
    "smäcken": "smäck",
    "smäckens": "smäck",
    "smäcker": "smäcka",
    "smäckerheten": "smäckerhet",
    "smäckerhetens": "smäckerhet",
    "smäckerhets": "smäckerhet",
    "smäckers": "smäcker",
    "smäckert": "smäcker",
    "smäckerts": "smäcker",
    "smäckes": "smäcka",
    "smäcket": "smäck",
    "smäckets": "smäck",
    "smäckfeta": "smäckfet",
    "smäckfetare": "smäckfet",
    "smäckfetares": "smäckfet",
    "smäckfetas": "smäckfet",
    "smäckfetast": "smäckfet",
    "smäckfetaste": "smäckfet",
    "smäckfetastes": "smäckfet",
    "smäckfetasts": "smäckfet",
    "smäckfete": "smäckfet",
    "smäckfetes": "smäckfet",
    "smäckfetheten": "smäckfethet",
    "smäckfethetens": "smäckfethet",
    "smäckfethets": "smäckfethet",
    "smäckfets": "smäckfet",
    "smäckfett": "smäckfet",
    "smäckfetts": "smäckfet",
    "smäckfulla": "smäckfull",
    "smäckfullare": "smäckfull",
    "smäckfullares": "smäckfull",
    "smäckfullas": "smäckfull",
    "smäckfullast": "smäckfull",
    "smäckfullaste": "smäckfull",
    "smäckfullastes": "smäckfull",
    "smäckfullasts": "smäckfull",
    "smäckfulle": "smäckfull",
    "smäckfulles": "smäckfull",
    "smäckfullheten": "smäckfullhet",
    "smäckfullhetens": "smäckfullhet",
    "smäckfullhets": "smäckfullhet",
    "smäckfulls": "smäckfull",
    "smäckfullt": "smäckfull",
    "smäckfullts": "smäckfull",
    "smäckiga": "smäckig",
    "smäckigare": "smäckig",
    "smäckigares": "smäckig",
    "smäckigas": "smäckig",
    "smäckigast": "smäckig",
    "smäckigaste": "smäckig",
    "smäckigastes": "smäckig",
    "smäckigasts": "smäckig",
    "smäckige": "smäckig",
    "smäckiges": "smäckig",
    "smäckigheten": "smäckighet",
    "smäckighetens": "smäckighet",
    "smäckighets": "smäckighet",
    "smäckigs": "smäckig",
    "smäckigt": "smäckig",
    "smäckigts": "smäckig",
    "smäcklåsen": "smäcklås",
    "smäcklåsens": "smäcklås",
    "smäcklåset": "smäcklås",
    "smäcklåsets": "smäcklås",
    "smäckra": "smäcker",
    "smäckrare": "smäcker",
    "smäckrares": "smäcker",
    "smäckras": "smäcker",
    "smäckrast": "smäcker",
    "smäckraste": "smäcker",
    "smäckrastes": "smäcker",
    "smäckrasts": "smäcker",
    "smäckre": "smäcker",
    "smäckres": "smäcker",
    "smäcks": "smäcka",
    "smäckt": "smäcka",
    "smäckta": "smäcka",
    "smäcktas": "smäcka",
    "smäckte": "smäcka",
    "smäcktes": "smäcka",
    "smäckts": "smäcka",
    "smäd": "smäda",
    "smädad": "smäda",
    "smädade": "smäda",
    "smädades": "smäda",
    "smädads": "smäda",
    "smädande": "smäda",
    "smädanden": "smädande",
    "smädandena": "smädande",
    "smädandenas": "smädande",
    "smädandens": "smädande",
    "smädandes": "smädande",
    "smädandet": "smädande",
    "smädandets": "smädande",
    "smädar": "smädare",
    "smädaren": "smädare",
    "smädarens": "smädare",
    "smädares": "smädare",
    "smädarna": "smädare",
    "smädarnas": "smädare",
    "smädas": "smäda",
    "smädat": "smäda",
    "smädats": "smäda",
    "smädebilden": "smädebild",
    "smädebildens": "smädebild",
    "smädebilder": "smädebild",
    "smädebilderna": "smädebild",
    "smädebildernas": "smädebild",
    "smädebilders": "smädebild",
    "smädebilds": "smädebild",
    "smädelsen": "smädelse",
    "smädelsens": "smädelse",
    "smädelser": "smädelse",
    "smädelserna": "smädelse",
    "smädelsernas": "smädelse",
    "smädelsers": "smädelse",
    "smädelses": "smädelse",
    "smädenamnen": "smädenamn",
    "smädenamnens": "smädenamn",
    "smädenamnet": "smädenamn",
    "smädenamnets": "smädenamn",
    "smädenamns": "smädenamn",
    "smädeskriften": "smädeskrift",
    "smädeskriftens": "smädeskrift",
    "smädeskrifter": "smädeskrift",
    "smädeskrifterna": "smädeskrift",
    "smädeskrifternas": "smädeskrift",
    "smädeskrifters": "smädeskrift",
    "smädeskrifts": "smädeskrift",
    "smädliga": "smädlig",
    "smädligare": "smädlig",
    "smädligares": "smädlig",
    "smädligas": "smädlig",
    "smädligast": "smädlig",
    "smädligaste": "smädlig",
    "smädligastes": "smädlig",
    "smädligasts": "smädlig",
    "smädlige": "smädlig",
    "smädliges": "smädlig",
    "smädligheten": "smädlighet",
    "smädlighetens": "smädlighet",
    "smädligheter": "smädlighet",
    "smädligheterna": "smädlighet",
    "smädligheternas": "smädlighet",
    "smädligheters": "smädlighet",
    "smädlighets": "smädlighet",
    "smädligs": "smädlig",
    "smädligt": "smädlig",
    "smädligts": "smädlig",
    "smäkt": "smäkta",
    "smäktad": "smäkta",
    "smäktade": "smäkta",
    "smäktades": "smäkta",
    "smäktads": "smäkta",
    "smäktande": "smäkta",
    "smäktanden": "smäktande",
    "smäktandena": "smäktande",
    "smäktandenas": "smäktande",
    "smäktandens": "smäktande",
    "smäktandes": "smäktande",
    "smäktandet": "smäktande",
    "smäktandets": "smäktande",
    "smäktans": "smäktan",
    "smäktar": "smäkta",
    "smäktas": "smäkta",
    "smäktat": "smäkta",
    "smäktats": "smäkta",
    "smälekar": "smälek",
    "smälekarna": "smälek",
    "smälekarnas": "smälek",
    "smälekars": "smälek",
    "smäleken": "smälek",
    "smälekens": "smälek",
    "smäleks": "smälek",
    "smäll": "smälla",
    "smällan": "smälla",
    "smällande": "smälla",
    "smällanden": "smällande",
    "smällandena": "smällande",
    "smällandenas": "smällande",
    "smällandens": "smällande",
    "smällandes": "smällande",
    "smällandet": "smällande",
    "smällandets": "smällande",
    "smällans": "smälla",
    "smällar": "smällare",
    "smällaren": "smällare",
    "smällarens": "smällare",
    "smällares": "smällare",
    "smällarna": "smällare",
    "smällarnas": "smällare",
    "smällars": "smäll",
    "smällas": "smälla",
    "smälld": "smälla",
    "smällda": "smälla",
    "smälldas": "smälla",
    "smällde": "smälla",
    "smälldes": "smälla",
    "smällds": "smälla",
    "smälle": "smälla",
    "smällen": "smäll",
    "smällens": "smäll",
    "smäller": "smälla",
    "smälles": "smälla",
    "smället": "smäll",
    "smällets": "smäll",
    "smällfeta": "smällfet",
    "smällfetare": "smällfet",
    "smällfetares": "smällfet",
    "smällfetas": "smällfet",
    "smällfetast": "smällfet",
    "smällfetaste": "smällfet",
    "smällfetastes": "smällfet",
    "smällfetasts": "smällfet",
    "smällfete": "smällfet",
    "smällfetes": "smällfet",
    "smällfetheten": "smällfethet",
    "smällfethetens": "smällfethet",
    "smällfethets": "smällfethet",
    "smällfets": "smällfet",
    "smällfett": "smällfet",
    "smällfetts": "smällfet",
    "smällglimmen": "smällglim",
    "smällglimmens": "smällglim",
    "smällglims": "smällglim",
    "smällkalla": "smällkall",
    "smällkallare": "smällkall",
    "smällkallares": "smällkall",
    "smällkallas": "smällkall",
    "smällkallast": "smällkall",
    "smällkallaste": "smällkall",
    "smällkallastes": "smällkall",
    "smällkallasts": "smällkall",
    "smällkalle": "smällkall",
    "smällkalles": "smällkall",
    "smällkalls": "smällkall",
    "smällkallt": "smällkall",
    "smällkallts": "smällkall",
    "smällkaramellen": "smällkaramell",
    "smällkaramellens": "smällkaramell",
    "smällkarameller": "smällkaramell",
    "smällkaramellerna": "smällkaramell",
    "smällkaramellernas": "smällkaramell",
    "smällkaramellers": "smällkaramell",
    "smällkaramells": "smällkaramell",
    "smällor": "smälla",
    "smällorna": "smälla",
    "smällornas": "smälla",
    "smällors": "smälla",
    "smälls": "smälla",
    "smällt": "smälla",
    "smällts": "smälla",
    "smält": "smälta",
    "smältan": "smälta",
    "smältande": "smälta",
    "smältanden": "smältande",
    "smältandena": "smältande",
    "smältandenas": "smältande",
    "smältandens": "smältande",
    "smältandes": "smältande",
    "smältandet": "smältande",
    "smältandets": "smältande",
    "smältans": "smälta",
    "smältas": "smälta",
    "smältdegeln": "smältdegel",
    "smältdegelns": "smältdegel",
    "smältdegels": "smältdegel",
    "smältdeglar": "smältdegel",
    "smältdeglarna": "smältdegel",
    "smältdeglarnas": "smältdegel",
    "smältdeglars": "smältdegel",
    "smälte": "smälta",
    "smältentalpiteten": "smältentalpitet",
    "smältentalpitetens": "smältentalpitet",
    "smältentalpiteter": "smältentalpitet",
    "smältentalpiteterna": "smältentalpitet",
    "smältentalpiteternas": "smältentalpitet",
    "smältentalpiteters": "smältentalpitet",
    "smältentalpitets": "smältentalpitet",
    "smälter": "smälta",
    "smälterier": "smälteri",
    "smälterierna": "smälteri",
    "smälteriernas": "smälteri",
    "smälteriers": "smälteri",
    "smälteriet": "smälteri",
    "smälteriets": "smälteri",
    "smälteris": "smälteri",
    "smälterit": "smälteri",
    "smälterits": "smälteri",
    "smältes": "smälta",
    "smältmetallen": "smältmetall",
    "smältmetallens": "smältmetall",
    "smältmetalls": "smältmetall",
    "smältor": "smälta",
    "smältorna": "smälta",
    "smältornas": "smälta",
    "smältors": "smälta",
    "smältostar": "smältost",
    "smältostarna": "smältost",
    "smältostarnas": "smältost",
    "smältostars": "smältost",
    "smältosten": "smältost",
    "smältostens": "smältost",
    "smältosts": "smältost",
    "smältproppar": "smältpropp",
    "smältpropparna": "smältpropp",
    "smältpropparnas": "smältpropp",
    "smältproppars": "smältpropp",
    "smältproppen": "smältpropp",
    "smältproppens": "smältpropp",
    "smältpropps": "smältpropp",
    "smältpunkten": "smältpunkt",
    "smältpunktens": "smältpunkt",
    "smältpunkter": "smältpunkt",
    "smältpunkterna": "smältpunkt",
    "smältpunkternas": "smältpunkt",
    "smältpunkters": "smältpunkt",
    "smältpunkts": "smältpunkt",
    "smälts": "smälta",
    "smältskydden": "smältskydd",
    "smältskyddens": "smältskydd",
    "smältskyddet": "smältskydd",
    "smältskyddets": "smältskydd",
    "smältskydds": "smältskydd",
    "smältsäkringar": "smältsäkring",
    "smältsäkringarna": "smältsäkring",
    "smältsäkringarnas": "smältsäkring",
    "smältsäkringars": "smältsäkring",
    "smältsäkringen": "smältsäkring",
    "smältsäkringens": "smältsäkring",
    "smältsäkrings": "smältsäkring",
    "smältugnar": "smältugn",
    "smältugnarna": "smältugn",
    "smältugnarnas": "smältugn",
    "smältugnars": "smältugn",
    "smältugnen": "smältugn",
    "smältugnens": "smältugn",
    "smältugns": "smältugn",
    "smältvattens": "smältvatten",
    "smältvattnen": "smältvatten",
    "smältvattnens": "smältvatten",
    "smältvattnet": "smältvatten",
    "smältvattnets": "smältvatten",
    "smältverken": "smältverk",
    "smältverkens": "smältverk",
    "smältverket": "smältverk",
    "smältverkets": "smältverk",
    "smältverks": "smältverk",
    "smältvärmen": "smältvärme",
    "smältvärmens": "smältvärme",
    "smältvärmes": "smältvärme",
    "smältvärmet": "smältvärme",
    "smältvärmets": "smältvärme",
    "smärgeldukar": "smärgelduk",
    "smärgeldukarna": "smärgelduk",
    "smärgeldukarnas": "smärgelduk",
    "smärgeldukars": "smärgelduk",
    "smärgelduken": "smärgelduk",
    "smärgeldukens": "smärgelduk",
    "smärgelduks": "smärgelduk",
    "smärgeln": "smärgel",
    "smärgelns": "smärgel",
    "smärgels": "smärgel",
    "smärres": "smärre",
    "smärt": "smärta",
    "smärta": "smärt",
    "smärtad": "smärta",
    "smärtade": "smärta",
    "smärtades": "smärta",
    "smärtads": "smärta",
    "smärtaktiveringen": "smärtaktivering",
    "smärtaktiveringens": "smärtaktivering",
    "smärtaktiverings": "smärtaktivering",
    "smärtan": "smärta",
    "smärtande": "smärta",
    "smärtanden": "smärtande",
    "smärtandena": "smärtande",
    "smärtandenas": "smärtande",
    "smärtandens": "smärtande",
    "smärtandes": "smärtande",
    "smärtandet": "smärtande",
    "smärtandets": "smärtande",
    "smärtans": "smärta",
    "smärtar": "smärta",
    "smärtare": "smärt",
    "smärtares": "smärt",
    "smärtas": "smärta",
    "smärtast": "smärt",
    "smärtaste": "smärt",
    "smärtastes": "smärt",
    "smärtasts": "smärt",
    "smärtat": "smärta",
    "smärtats": "smärta",
    "smärtattacken": "smärtattack",
    "smärtattackens": "smärtattack",
    "smärtattacker": "smärtattack",
    "smärtattackerna": "smärtattack",
    "smärtattackernas": "smärtattack",
    "smärtattackers": "smärtattack",
    "smärtattacks": "smärtattack",
    "smärtbehandlingar": "smärtbehandling",
    "smärtbehandlingarna": "smärtbehandling",
    "smärtbehandlingarnas": "smärtbehandling",
    "smärtbehandlingars": "smärtbehandling",
    "smärtbehandlingen": "smärtbehandling",
    "smärtbehandlingens": "smärtbehandling",
    "smärtbehandlings": "smärtbehandling",
    "smärte": "smärta",
    "smärtes": "smärt",
    "smärtfria": "smärtfri",
    "smärtfriare": "smärtfri",
    "smärtfriares": "smärtfri",
    "smärtfrias": "smärtfri",
    "smärtfriast": "smärtfri",
    "smärtfriaste": "smärtfri",
    "smärtfriastes": "smärtfri",
    "smärtfriasts": "smärtfri",
    "smärtfrie": "smärtfri",
    "smärtfries": "smärtfri",
    "smärtfris": "smärtfri",
    "smärtfritt": "smärtfri",
    "smärtfritts": "smärtfri",
    "smärtförnimmelsen": "smärtförnimmelse",
    "smärtförnimmelsens": "smärtförnimmelse",
    "smärtförnimmelser": "smärtförnimmelse",
    "smärtförnimmelserna": "smärtförnimmelse",
    "smärtförnimmelsernas": "smärtförnimmelse",
    "smärtförnimmelsers": "smärtförnimmelse",
    "smärtförnimmelses": "smärtförnimmelse",
    "smärtgränsen": "smärtgräns",
    "smärtgränsens": "smärtgräns",
    "smärtheten": "smärthet",
    "smärthetens": "smärthet",
    "smärthets": "smärthet",
    "smärthämningar": "smärthämning",
    "smärthämningarna": "smärthämning",
    "smärthämningarnas": "smärthämning",
    "smärthämningars": "smärthämning",
    "smärthämningen": "smärthämning",
    "smärthämningens": "smärthämning",
    "smärthämnings": "smärthämning",
    "smärtingen": "smärting",
    "smärtingens": "smärting",
    "smärtings": "smärting",
    "smärtlindringar": "smärtlindring",
    "smärtlindringarna": "smärtlindring",
    "smärtlindringarnas": "smärtlindring",
    "smärtlindringars": "smärtlindring",
    "smärtlindringen": "smärtlindring",
    "smärtlindringens": "smärtlindring",
    "smärtlindrings": "smärtlindring",
    "smärtor": "smärta",
    "smärtorna": "smärta",
    "smärtornas": "smärta",
    "smärtors": "smärta",
    "smärtpunkten": "smärtpunkt",
    "smärtpunktens": "smärtpunkt",
    "smärtpunkter": "smärtpunkt",
    "smärtpunkterna": "smärtpunkt",
    "smärtpunkternas": "smärtpunkt",
    "smärtpunkters": "smärtpunkt",
    "smärtpunkts": "smärtpunkt",
    "smärtreceptorer": "smärtreceptor",
    "smärtreceptorerna": "smärtreceptor",
    "smärtreceptorernas": "smärtreceptor",
    "smärtreceptorers": "smärtreceptor",
    "smärtreceptorn": "smärtreceptor",
    "smärtreceptorns": "smärtreceptor",
    "smärtreceptors": "smärtreceptor",
    "smärts": "smärta",
    "smärtsamheten": "smärtsamhet",
    "smärtsamhetens": "smärtsamhet",
    "smärtsamhets": "smärtsamhet",
    "smärtsamma": "smärtsam",
    "smärtsammare": "smärtsam",
    "smärtsammares": "smärtsam",
    "smärtsammas": "smärtsam",
    "smärtsammast": "smärtsam",
    "smärtsammaste": "smärtsam",
    "smärtsammastes": "smärtsam",
    "smärtsammasts": "smärtsam",
    "smärtsamme": "smärtsam",
    "smärtsammes": "smärtsam",
    "smärtsams": "smärtsam",
    "smärtsamt": "smärtsam",
    "smärtsamts": "smärtsam",
    "smärtsinnes": "smärtsinne",
    "smärtsinnet": "smärtsinne",
    "smärtsinnets": "smärtsinne",
    "smärttillstånden": "smärttillstånd",
    "smärttillståndens": "smärttillstånd",
    "smärttillståndet": "smärttillstånd",
    "smärttillståndets": "smärttillstånd",
    "smärttillstånds": "smärttillstånd",
    "smärttröskeln": "smärttröskel",
    "smärttröskelns": "smärttröskel",
    "smärttröskels": "smärttröskel",
    "smärttåligheten": "smärttålighet",
    "smärttålighetens": "smärttålighet",
    "smärttålighets": "smärttålighet",
    "smärtupplevelsen": "smärtupplevelse",
    "smärtupplevelsens": "smärtupplevelse",
    "smärtupplevelser": "smärtupplevelse",
    "smärtupplevelserna": "smärtupplevelse",
    "smärtupplevelsernas": "smärtupplevelse",
    "smärtupplevelsers": "smärtupplevelse",
    "smärtupplevelses": "smärtupplevelse",
    "smätt": "smätta",
    "smättande": "smätta",
    "smättanden": "smättande",
    "smättandena": "smättande",
    "smättandenas": "smättande",
    "smättandens": "smättande",
    "smättandes": "smättande",
    "smättandet": "smättande",
    "smättandets": "smättande",
    "smättas": "smätta",
    "smätte": "smätta",
    "smätter": "smätta",
    "smättes": "smätta",
    "smätts": "smätta",
    "små": "liten",
    "småaktiga": "småaktig",
    "småaktigare": "småaktig",
    "småaktigares": "småaktig",
    "småaktigas": "småaktig",
    "småaktigast": "småaktig",
    "småaktigaste": "småaktig",
    "småaktigastes": "småaktig",
    "småaktigasts": "småaktig",
    "småaktige": "småaktig",
    "småaktiges": "småaktig",
    "småaktigheten": "småaktighet",
    "småaktighetens": "småaktighet",
    "småaktigheter": "småaktighet",
    "småaktigheterna": "småaktighet",
    "småaktigheternas": "småaktighet",
    "småaktigheters": "småaktighet",
    "småaktighets": "småaktighet",
    "småaktigs": "småaktig",
    "småaktigt": "småaktig",
    "småaktigts": "småaktig",
    "småaxen": "småax",
    "småaxens": "småax",
    "småaxet": "småax",
    "småaxets": "småax",
    "småbarnen": "småbarn",
    "småbarnens": "småbarn",
    "småbarnet": "småbarn",
    "småbarnets": "småbarn",
    "småbarns": "småbarn",
    "småbarnsboken": "småbarnsbok",
    "småbarnsbokens": "småbarnsbok",
    "småbarnsboks": "småbarnsbok",
    "småbarnsböcker": "småbarnsbok",
    "småbarnsböckerna": "småbarnsbok",
    "småbarnsböckernas": "småbarnsbok",
    "småbarnsböckers": "småbarnsbok",
    "småbarnsfamiljen": "småbarnsfamilj",
    "småbarnsfamiljens": "småbarnsfamilj",
    "småbarnsfamiljer": "småbarnsfamilj",
    "småbarnsfamiljerna": "småbarnsfamilj",
    "småbarnsfamiljernas": "småbarnsfamilj",
    "småbarnsfamiljers": "småbarnsfamilj",
    "småbarnsfamiljs": "småbarnsfamilj",
    "småbarnsföräldern": "småbarnsförälder",
    "småbarnsförälderns": "småbarnsförälder",
    "småbarnsförälders": "småbarnsförälder",
    "småbarnsföräldrar": "småbarnsförälder",
    "småbarnsföräldrarna": "småbarnsförälder",
    "småbarnsföräldrarnas": "småbarnsförälder",
    "småbarnsföräldrars": "småbarnsförälder",
    "småbarnsliven": "småbarnsliv",
    "småbarnslivens": "småbarnsliv",
    "småbarnslivet": "småbarnsliv",
    "småbarnslivets": "småbarnsliv",
    "småbarnslivs": "småbarnsliv",
    "småbarnsmamman": "småbarnsmamma",
    "småbarnsmammans": "småbarnsmamma",
    "småbarnsmammas": "småbarnsmamma",
    "småbarnsmamme": "småbarnsmamma",
    "småbarnsmammor": "småbarnsmamma",
    "småbarnsmammorna": "småbarnsmamma",
    "småbarnsmammornas": "småbarnsmamma",
    "småbarnsmammors": "småbarnsmamma",
    "småbilar": "småbil",
    "småbilarna": "småbil",
    "småbilarnas": "småbil",
    "småbilars": "småbil",
    "småbildskameran": "småbildskamera",
    "småbildskamerans": "småbildskamera",
    "småbildskameras": "småbildskamera",
    "småbildskameror": "småbildskamera",
    "småbildskamerorna": "småbildskamera",
    "småbildskamerornas": "småbildskamera",
    "småbildskamerors": "småbildskamera",
    "småbilen": "småbil",
    "småbilens": "småbil",
    "småbils": "småbil",
    "småbladiga": "småbladig",
    "småbladigare": "småbladig",
    "småbladigares": "småbladig",
    "småbladigas": "småbladig",
    "småbladigast": "småbladig",
    "småbladigaste": "småbladig",
    "småbladigastes": "småbladig",
    "småbladigasts": "småbladig",
    "småbladige": "småbladig",
    "småbladiges": "småbladig",
    "småbladigs": "småbladig",
    "småbladigt": "småbladig",
    "småbladigts": "småbladig",
    "småblommiga": "småblommig",
    "småblommigare": "småblommig",
    "småblommigares": "småblommig",
    "småblommigas": "småblommig",
    "småblommigast": "småblommig",
    "småblommigaste": "småblommig",
    "småblommigastes": "småblommig",
    "småblommigasts": "småblommig",
    "småblommige": "småblommig",
    "småblommiges": "småblommig",
    "småblommigs": "småblommig",
    "småblommigt": "småblommig",
    "småblommigts": "småblommig",
    "småblåsiga": "småblåsig",
    "småblåsigare": "småblåsig",
    "småblåsigares": "småblåsig",
    "småblåsigas": "småblåsig",
    "småblåsigast": "småblåsig",
    "småblåsigaste": "småblåsig",
    "småblåsigastes": "småblåsig",
    "småblåsigasts": "småblåsig",
    "småblåsige": "småblåsig",
    "småblåsiges": "småblåsig",
    "småblåsigs": "småblåsig",
    "småblåsigt": "småblåsig",
    "småblåsigts": "småblåsig",
    "småbond": "småbonde",
    "småbonden": "småbonde",
    "småbondens": "småbonde",
    "småbondes": "småbonde",
    "småbonds": "småbonde",
    "småborgar": "småborgare",
    "småborgaren": "småborgare",
    "småborgarens": "småborgare",
    "småborgares": "småborgare",
    "småborgarna": "småborgare",
    "småborgarnas": "småborgare",
    "småborgerliga": "småborgerlig",
    "småborgerligare": "småborgerlig",
    "småborgerligares": "småborgerlig",
    "småborgerligas": "småborgerlig",
    "småborgerligast": "småborgerlig",
    "småborgerligaste": "småborgerlig",
    "småborgerligastes": "småborgerlig",
    "småborgerligasts": "småborgerlig",
    "småborgerlige": "småborgerlig",
    "småborgerliges": "småborgerlig",
    "småborgerligheten": "småborgerlighet",
    "småborgerlighetens": "småborgerlighet",
    "småborgerligheter": "småborgerlighet",
    "småborgerligheterna": "småborgerlighet",
    "småborgerligheternas": "småborgerlighet",
    "småborgerligheters": "småborgerlighet",
    "småborgerlighets": "småborgerlighet",
    "småborgerligs": "småborgerlig",
    "småborgerligt": "småborgerlig",
    "småborgerligts": "småborgerlig",
    "småborgerskapet": "småborgerskap",
    "småborgerskapets": "småborgerskap",
    "småborgerskaps": "småborgerskap",
    "småbrukar": "småbrukare",
    "småbrukaren": "småbrukare",
    "småbrukarens": "småbrukare",
    "småbrukares": "småbrukare",
    "småbrukarna": "småbrukare",
    "småbrukarnas": "småbrukare",
    "småbruken": "småbruk",
    "småbrukens": "småbruk",
    "småbruket": "småbruk",
    "småbrukets": "småbruk",
    "småbruks": "småbruk",
    "småbrödet": "småbröd",
    "småbrödets": "småbröd",
    "småbröds": "småbröd",
    "småbåtshamnar": "småbåtshamn",
    "småbåtshamnarna": "småbåtshamn",
    "småbåtshamnarnas": "småbåtshamn",
    "småbåtshamnars": "småbåtshamn",
    "småbåtshamnen": "småbåtshamn",
    "småbåtshamnens": "småbåtshamn",
    "småbåtshamns": "småbåtshamn",
    "småbönder": "småbonde",
    "småbönderna": "småbonde",
    "småböndernas": "småbonde",
    "småbönders": "småbonde",
    "småcitrusar": "småcitrus",
    "småcitrusarna": "småcitrus",
    "småcitrusarnas": "småcitrus",
    "småcitrusars": "småcitrus",
    "småcitrusen": "småcitrus",
    "småcitrusens": "småcitrus",
    "smådelar": "smådel",
    "smådelarna": "smådel",
    "smådelarnas": "smådel",
    "smådelars": "smådel",
    "smådelen": "smådel",
    "smådelens": "smådel",
    "smådels": "smådel",
    "smådetaljen": "smådetalj",
    "smådetaljens": "smådetalj",
    "smådetaljer": "smådetalj",
    "smådetaljerna": "smådetalj",
    "smådetaljernas": "smådetalj",
    "smådetaljers": "smådetalj",
    "smådetaljs": "smådetalj",
    "smådjuren": "smådjur",
    "smådjurens": "smådjur",
    "smådjuret": "smådjur",
    "smådjurets": "smådjur",
    "smådjurs": "smådjur",
    "småekern": "småeker",
    "småekerns": "småeker",
    "småekers": "småeker",
    "småekrar": "småeker",
    "småekrarna": "småeker",
    "småekrarnas": "småeker",
    "småekrars": "småeker",
    "småelaka": "småelak",
    "småelakare": "småelak",
    "småelakares": "småelak",
    "småelakas": "småelak",
    "småelakast": "småelak",
    "småelakaste": "småelak",
    "småelakastes": "småelak",
    "småelakasts": "småelak",
    "småelake": "småelak",
    "småelakes": "småelak",
    "småelakheten": "småelakhet",
    "småelakhetens": "småelakhet",
    "småelakhets": "småelakhet",
    "småelaks": "småelak",
    "småelakt": "småelak",
    "småelakts": "småelak",
    "småfolket": "småfolk",
    "småfolkets": "småfolk",
    "småfolks": "småfolk",
    "småfranskan": "småfranska",
    "småfranskana": "småfranska",
    "småfranskanas": "småfranska",
    "småfranskans": "småfranska",
    "småfranskas": "småfranska",
    "småfranskat": "småfranska",
    "småfranskats": "småfranska",
    "småfranskor": "småfranska",
    "småfranskorna": "småfranska",
    "småfranskornas": "småfranska",
    "småfranskors": "småfranska",
    "småfågeln": "småfågel",
    "småfågelns": "småfågel",
    "småfågels": "småfågel",
    "småfåglar": "småfågel",
    "småfåglarna": "småfågel",
    "småfåglarnas": "småfågel",
    "småfåglars": "småfågel",
    "småföretagar": "småföretagare",
    "småföretagaren": "småföretagare",
    "småföretagarens": "småföretagare",
    "småföretagares": "småföretagare",
    "småföretagarna": "småföretagare",
    "småföretagarnas": "småföretagare",
    "småföretagen": "småföretag",
    "småföretagens": "småföretag",
    "småföretaget": "småföretag",
    "småföretagets": "småföretag",
    "småföretags": "småföretag",
    "smågangstern": "smågangster",
    "smågangsterns": "smågangster",
    "smågangsters": "smågangster",
    "smågangstersarna": "smågangster",
    "smågangstersarnas": "smågangster",
    "smågangstersen": "smågangster",
    "smågangstersens": "smågangster",
    "smågangstrar": "smågangster",
    "smågangstrarna": "smågangster",
    "smågangstrarnas": "smågangster",
    "smågangstrars": "smågangster",
    "småglien": "smågli",
    "smågliens": "smågli",
    "smågliet": "smågli",
    "smågliets": "smågli",
    "småglin": "smågli",
    "småglina": "smågli",
    "småglinas": "smågli",
    "småglins": "smågli",
    "småglis": "smågli",
    "småglit": "smågli",
    "småglits": "smågli",
    "smågnagar": "smågnagare",
    "smågnagaren": "smågnagare",
    "smågnagarens": "smågnagare",
    "smågnagares": "smågnagare",
    "smågnagarna": "smågnagare",
    "smågnagarnas": "smågnagare",
    "smågrisar": "smågris",
    "smågrisarna": "smågris",
    "smågrisarnas": "smågris",
    "smågrisars": "smågris",
    "smågrisen": "smågris",
    "smågrisens": "smågris",
    "smågrälade": "smågräla",
    "smågrälades": "smågräla",
    "smågrälande": "smågräla",
    "smågrälanden": "smågrälande",
    "smågrälandena": "smågrälande",
    "smågrälandenas": "smågrälande",
    "smågrälandens": "smågrälande",
    "smågrälandes": "smågrälande",
    "smågrälandet": "smågrälande",
    "smågrälandets": "smågrälande",
    "smågrälar": "smågräla",
    "smågrälas": "smågräla",
    "smågrälat": "smågräla",
    "smågrälats": "smågräla",
    "smågrälen": "smågräl",
    "smågrälens": "smågräl",
    "smågrälet": "smågräl",
    "smågrälets": "smågräl",
    "smågräls": "smågräl",
    "småhackorna": "småhackor",
    "småhackornas": "småhackor",
    "småhackors": "småhackor",
    "småhacks": "småhackor",
    "småhandlar": "småhandlare",
    "småhandlaren": "småhandlare",
    "småhandlarens": "småhandlare",
    "småhandlares": "småhandlare",
    "småhandlarna": "småhandlare",
    "småhandlarnas": "småhandlare",
    "småheta": "småhet",
    "småhetas": "småhet",
    "småhete": "småhet",
    "småheten": "småhet",
    "småhetens": "småhet",
    "småheter": "småhet",
    "småheterna": "småhet",
    "småheternas": "småhet",
    "småheters": "småhet",
    "småhetes": "småhet",
    "småhets": "småhet",
    "småhett": "småhet",
    "småhetts": "småhet",
    "småhusen": "småhus",
    "småhusens": "småhus",
    "småhuset": "småhus",
    "småhusets": "småhus",
    "småhuslånen": "småhuslån",
    "småhuslånens": "småhuslån",
    "småhuslånet": "småhuslån",
    "småhuslånets": "småhuslån",
    "småhuslåns": "småhuslån",
    "småhusägar": "småhusägare",
    "småhusägaren": "småhusägare",
    "småhusägarens": "småhusägare",
    "småhusägares": "småhusägare",
    "småhusägarna": "småhusägare",
    "småhusägarnas": "småhusägare",
    "småjordbrukar": "småjordbrukare",
    "småjordbrukaren": "småjordbrukare",
    "småjordbrukarens": "småjordbrukare",
    "småjordbrukares": "småjordbrukare",
    "småjordbrukarna": "småjordbrukare",
    "småjordbrukarnas": "småjordbrukare",
    "småjordbruken": "småjordbruk",
    "småjordbrukens": "småjordbruk",
    "småjordbruket": "småjordbruk",
    "småjordbrukets": "småjordbruk",
    "småjordbruks": "småjordbruk",
    "småkak": "småkaka",
    "småkakan": "småkaka",
    "småkakans": "småkaka",
    "småkakas": "småkaka",
    "småkake": "småkaka",
    "småkakor": "småkaka",
    "småkakorna": "småkaka",
    "småkakornas": "småkaka",
    "småkakors": "småkaka",
    "småkaks": "småkaka",
    "småkrafset": "småkrafs",
    "småkrafsets": "småkrafs",
    "småkrypen": "småkryp",
    "småkrypens": "småkryp",
    "småkrypet": "småkryp",
    "småkrypets": "småkryp",
    "småkryps": "småkryp",
    "småkusinerna": "småkusiner",
    "småkusinernas": "småkusiner",
    "småkusiners": "småkusiner",
    "småkusins": "småkusiner",
    "småleende": "småle",
    "småleenden": "småleende",
    "småleendena": "småleende",
    "småleendenas": "småleende",
    "småleendens": "småleende",
    "småleendes": "småleende",
    "småleendet": "småleende",
    "småleendets": "småleende",
    "småler": "småle",
    "småles": "småle",
    "smålett": "småle",
    "småletts": "småle",
    "smålog": "småle",
    "småloge": "småle",
    "småloges": "småle",
    "smålogs": "småle",
    "småländsk": "småländska",
    "småländska": "småländsk",
    "småländskan": "småländska",
    "småländskans": "småländska",
    "småländskare": "småländsk",
    "småländskares": "småländsk",
    "småländskas": "småländska",
    "småländskast": "småländsk",
    "småländskaste": "småländsk",
    "småländskastes": "småländsk",
    "småländskasts": "småländsk",
    "småländske": "småländska",
    "småländskes": "småländsk",
    "småländskor": "småländska",
    "småländskorna": "småländska",
    "småländskornas": "småländska",
    "småländskors": "småländska",
    "småländsks": "småländsk",
    "småländskt": "småländsk",
    "småländskts": "småländsk",
    "smålänningar": "smålänning",
    "smålänningarna": "smålänning",
    "smålänningarnas": "smålänning",
    "smålänningars": "smålänning",
    "smålänningen": "smålänning",
    "smålänningens": "smålänning",
    "smålännings": "smålänning",
    "småmynten": "småmynt",
    "småmyntens": "småmynt",
    "småmyntet": "småmynt",
    "småmyntets": "småmynt",
    "småmynts": "småmynt",
    "småmönstrade": "småmönstrad",
    "småmönstrades": "småmönstrad",
    "småmönstrads": "småmönstrad",
    "småmönstrat": "småmönstrad",
    "småmönstrats": "småmönstrad",
    "småorden": "småord",
    "småordens": "småord",
    "småordet": "småord",
    "småordets": "småord",
    "småords": "småord",
    "småorganismen": "småorganism",
    "småorganismens": "småorganism",
    "småorganismer": "småorganism",
    "småorganismerna": "småorganism",
    "småorganismernas": "småorganism",
    "småorganismers": "småorganism",
    "småorganisms": "småorganism",
    "småpaketen": "småpaket",
    "småpaketens": "småpaket",
    "småpaketet": "småpaket",
    "småpaketets": "småpaket",
    "småpakets": "småpaket",
    "småpengar": "småpeng",
    "småpengarna": "småpeng",
    "småpengarnas": "småpeng",
    "småpengars": "småpeng",
    "småpengen": "småpeng",
    "småpengens": "småpeng",
    "småpengs": "småpeng",
    "småpipiga": "småpipig",
    "småpipigare": "småpipig",
    "småpipigares": "småpipig",
    "småpipigas": "småpipig",
    "småpipigast": "småpipig",
    "småpipigaste": "småpipig",
    "småpipigastes": "småpipig",
    "småpipigasts": "småpipig",
    "småpipige": "småpipig",
    "småpipiges": "småpipig",
    "småpipigs": "småpipig",
    "småpipigt": "småpipig",
    "småpipigts": "småpipig",
    "småplaneten": "småplanet",
    "småplanetens": "småplanet",
    "småplaneter": "småplanet",
    "småplaneterna": "småplanet",
    "småplaneternas": "småplanet",
    "småplaneters": "småplanet",
    "småplanets": "småplanet",
    "småplocket": "småplock",
    "småplockets": "småplock",
    "småplocks": "småplock",
    "småpratade": "småprata",
    "småpratades": "småprata",
    "småpratande": "småprata",
    "småpratanden": "småpratande",
    "småpratandena": "småpratande",
    "småpratandenas": "småpratande",
    "småpratandens": "småpratande",
    "småpratandes": "småpratande",
    "småpratandet": "småpratande",
    "småpratandets": "småpratande",
    "småpratar": "småprata",
    "småpratas": "småprata",
    "småpratat": "småprata",
    "småpratats": "småprata",
    "småpratet": "småprat",
    "småpratets": "småprat",
    "småprats": "småprat",
    "småpåvar": "småpåve",
    "småpåvarna": "småpåve",
    "småpåvarnas": "småpåve",
    "småpåvars": "småpåve",
    "småpåven": "småpåve",
    "småpåvens": "småpåve",
    "småpåves": "småpåve",
    "småroliga": "smårolig",
    "småroligare": "smårolig",
    "småroligares": "smårolig",
    "småroligas": "smårolig",
    "småroligast": "smårolig",
    "småroligaste": "smårolig",
    "småroligastes": "smårolig",
    "småroligasts": "smårolig",
    "smårolige": "smårolig",
    "småroliges": "smårolig",
    "småroligheten": "smårolighet",
    "smårolighetens": "smårolighet",
    "småroligheter": "smårolighet",
    "småroligheterna": "smårolighet",
    "småroligheternas": "smårolighet",
    "småroligheters": "smårolighet",
    "smårolighets": "smårolighet",
    "småroligs": "smårolig",
    "småroligt": "smårolig",
    "småroligts": "smårolig",
    "smårutiga": "smårutig",
    "smårutigare": "smårutig",
    "smårutigares": "smårutig",
    "smårutigas": "smårutig",
    "smårutigast": "smårutig",
    "smårutigaste": "smårutig",
    "smårutigastes": "smårutig",
    "smårutigasts": "smårutig",
    "smårutige": "smårutig",
    "smårutiges": "smårutig",
    "smårutigs": "smårutig",
    "smårutigt": "smårutig",
    "smårutigts": "smårutig",
    "smårätten": "smårätt",
    "smårättens": "smårätt",
    "smårätter": "smårätt",
    "smårätterna": "smårätter",
    "smårätternas": "smårätter",
    "smårätters": "smårätter",
    "smårätts": "smårätter",
    "smås": "liten",
    "småsaken": "småsak",
    "småsakens": "småsak",
    "småsaker": "småsak",
    "småsakerna": "småsak",
    "småsakernas": "småsak",
    "småsakers": "småsak",
    "småsaks": "småsak",
    "småsinta": "småsint",
    "småsintare": "småsint",
    "småsintares": "småsint",
    "småsintas": "småsint",
    "småsintast": "småsint",
    "småsintaste": "småsint",
    "småsintastes": "småsint",
    "småsintasts": "småsint",
    "småsinte": "småsint",
    "småsintes": "småsint",
    "småsintheten": "småsinthet",
    "småsinthetens": "småsinthet",
    "småsinthets": "småsinthet",
    "småsints": "småsint",
    "småsjung": "småsjunga",
    "småsjungande": "småsjunga",
    "småsjunganden": "småsjungande",
    "småsjungandena": "småsjungande",
    "småsjungandenas": "småsjungande",
    "småsjungandens": "småsjungande",
    "småsjungandes": "småsjungande",
    "småsjungandet": "småsjungande",
    "småsjungandets": "småsjungande",
    "småsjungas": "småsjunga",
    "småsjunge": "småsjunga",
    "småsjunger": "småsjunga",
    "småsjunges": "småsjunga",
    "småsjungit": "småsjunga",
    "småsjungits": "småsjunga",
    "småsjungs": "småsjunga",
    "småsjöng": "småsjunga",
    "småsjönge": "småsjunga",
    "småsjönges": "småsjunga",
    "småsjöngs": "småsjunga",
    "småskaliga": "småskalig",
    "småskaligare": "småskalig",
    "småskaligares": "småskalig",
    "småskaligas": "småskalig",
    "småskaligast": "småskalig",
    "småskaligaste": "småskalig",
    "småskaligastes": "småskalig",
    "småskaligasts": "småskalig",
    "småskalige": "småskalig",
    "småskaliges": "småskalig",
    "småskaligheten": "småskalighet",
    "småskalighetens": "småskalighet",
    "småskalighets": "småskalighet",
    "småskaligs": "småskalig",
    "småskaligt": "småskalig",
    "småskaligts": "småskalig",
    "småskogar": "småskog",
    "småskogarna": "småskog",
    "småskogarnas": "småskog",
    "småskogars": "småskog",
    "småskogen": "småskog",
    "småskogens": "småskog",
    "småskogs": "småskog",
    "småskolan": "småskola",
    "småskolans": "småskola",
    "småskolas": "småskola",
    "småskole": "småskola",
    "småskolor": "småskola",
    "småskolorna": "småskola",
    "småskolornas": "småskola",
    "småskolors": "småskola",
    "småskrakar": "småskrak",
    "småskrakarna": "småskrak",
    "småskrakarnas": "småskrak",
    "småskrakars": "småskrak",
    "småskraken": "småskrak",
    "småskrakens": "småskrak",
    "småskraks": "småskrak",
    "småskrattade": "småskratta",
    "småskrattades": "småskratta",
    "småskrattande": "småskratta",
    "småskrattandes": "småskratta",
    "småskrattar": "småskratta",
    "småskrattas": "småskratta",
    "småskrattat": "småskratta",
    "småskrattats": "småskratta",
    "småskurens": "småskuren",
    "småskuret": "småskuren",
    "småskurets": "småskuren",
    "småskurna": "småskuren",
    "småskurnare": "småskuren",
    "småskurnares": "småskuren",
    "småskurnas": "småskuren",
    "småskurnast": "småskuren",
    "småskurnaste": "småskuren",
    "småskurnastes": "småskuren",
    "småskurnasts": "småskuren",
    "småskurne": "småskuren",
    "småskurnes": "småskuren",
    "småslantarna": "småslantar",
    "småslantarnas": "småslantar",
    "småslantars": "småslantar",
    "småslants": "småslantar",
    "småsmulorna": "småsmulor",
    "småsmulornas": "småsmulor",
    "småsmulors": "småsmulor",
    "småsnäpp": "småsnäppa",
    "småsnäppan": "småsnäppa",
    "småsnäppans": "småsnäppa",
    "småsnäppas": "småsnäppa",
    "småsnäppe": "småsnäppa",
    "småsnäppor": "småsnäppa",
    "småsnäpporna": "småsnäppa",
    "småsnäppornas": "småsnäppa",
    "småsnäppors": "småsnäppa",
    "småsnäpps": "småsnäppa",
    "småsov": "småsova",
    "småsovande": "småsova",
    "småsovanden": "småsovande",
    "småsovandena": "småsovande",
    "småsovandenas": "småsovande",
    "småsovandens": "småsovande",
    "småsovandes": "småsovande",
    "småsovandet": "småsovande",
    "småsovandets": "småsovande",
    "småsovas": "småsova",
    "småsove": "småsova",
    "småsover": "småsova",
    "småsoves": "småsova",
    "småsovit": "småsova",
    "småsovits": "småsova",
    "småsovs": "småsova",
    "småsparar": "småsparare",
    "småspararen": "småsparare",
    "småspararens": "småsparare",
    "småsparares": "småsparare",
    "småspararna": "småsparare",
    "småspararnas": "småsparare",
    "småsprang": "småspringa",
    "småsprangs": "småspringa",
    "småspring": "småspringa",
    "småspringande": "småspringa",
    "småspringanden": "småspringande",
    "småspringandena": "småspringande",
    "småspringandenas": "småspringande",
    "småspringandens": "småspringande",
    "småspringandes": "småspringande",
    "småspringandet": "småspringande",
    "småspringandets": "småspringande",
    "småspringas": "småspringa",
    "småspringe": "småspringa",
    "småspringer": "småspringa",
    "småspringes": "småspringa",
    "småsprings": "småspringa",
    "småsprunge": "småspringa",
    "småsprunges": "småspringa",
    "småsprungit": "småspringa",
    "småsprungits": "småspringa",
    "småstaden": "småstad",
    "småstadens": "småstad",
    "småstads": "småstad",
    "småstadsbodd": "småstadsbo",
    "småstadsbodda": "småstadsbo",
    "småstadsboddas": "småstadsbo",
    "småstadsbodde": "småstadsbo",
    "småstadsboddes": "småstadsbo",
    "småstadsbodds": "småstadsbo",
    "småstadsboende": "småstadsbo",
    "småstadsboendes": "småstadsbo",
    "småstadsbor": "småstadsbo",
    "småstadsbos": "småstadsbo",
    "småstadsbott": "småstadsbo",
    "småstadsbotts": "småstadsbo",
    "småstan": "småstad",
    "småstans": "småstad",
    "småstenar": "småsten",
    "småstenarna": "småsten",
    "småstenarnas": "småsten",
    "småstenars": "småsten",
    "småstenen": "småsten",
    "småstenens": "småsten",
    "småstens": "småsten",
    "småstäder": "småstad",
    "småstäderna": "småstad",
    "småstädernas": "småstad",
    "småstäders": "småstad",
    "småsura": "småsur",
    "småsuras": "småsur",
    "småsure": "småsur",
    "småsures": "småsur",
    "småsurs": "småsur",
    "småsurt": "småsur",
    "småsurts": "småsur",
    "småsvennar": "småsven",
    "småsvennarna": "småsven",
    "småsvennarnas": "småsven",
    "småsvennars": "småsven",
    "småsvennen": "småsven",
    "småsvennens": "småsven",
    "småsvens": "småsven",
    "småsvor": "småsvära",
    "småsvors": "småsvära",
    "småsvure": "småsvära",
    "småsvures": "småsvära",
    "småsvurit": "småsvära",
    "småsvurits": "småsvära",
    "småsvär": "småsvära",
    "småsvärande": "småsvära",
    "småsväranden": "småsvärande",
    "småsvärandena": "småsvärande",
    "småsvärandenas": "småsvärande",
    "småsvärandens": "småsvärande",
    "småsvärandes": "småsvärande",
    "småsvärandet": "småsvärande",
    "småsvärandets": "småsvärande",
    "småsväras": "småsvära",
    "småsväre": "småsvära",
    "småsväres": "småsvära",
    "småsvärj": "småsvära",
    "småsvärja": "småsvära",
    "småsvärjande": "småsvära",
    "småsvärjandes": "småsvära",
    "småsvärjas": "småsvära",
    "småsvärjer": "småsvära",
    "småsvärs": "småsvära",
    "småsyskonen": "småsyskon",
    "småsyskonens": "småsyskon",
    "småsyskonet": "småsyskon",
    "småsyskonets": "småsyskon",
    "småsyskons": "småsyskon",
    "småsysslorna": "småsysslor",
    "småsysslornas": "småsysslor",
    "småsysslors": "småsysslor",
    "småtimmarnas": "småtimmarna",
    "småtterier": "småtteri",
    "småtterierna": "småtteri",
    "småtteriernas": "småtteri",
    "småtteriers": "småtteri",
    "småtteriet": "småtteri",
    "småtteriets": "småtteri",
    "småtteris": "småtteri",
    "småtterit": "småtteri",
    "småtterits": "småtteri",
    "småttiga": "småttig",
    "småttigare": "småttig",
    "småttigares": "småttig",
    "småttigas": "småttig",
    "småttigast": "småttig",
    "småttigaste": "småttig",
    "småttigastes": "småttig",
    "småttigasts": "småttig",
    "småttige": "småttig",
    "småttiges": "småttig",
    "småttigheten": "småttighet",
    "småttighetens": "småttighet",
    "småttigheter": "småttighet",
    "småttigheterna": "småttighet",
    "småttigheternas": "småttighet",
    "småttigheters": "småttighet",
    "småttighets": "småttighet",
    "småttigs": "småttig",
    "småttigt": "småttig",
    "småttigts": "småttig",
    "småttingar": "småtting",
    "småttingarna": "småtting",
    "småttingarnas": "småtting",
    "småttingars": "småtting",
    "småttingen": "småtting",
    "småttingens": "småtting",
    "småttings": "småtting",
    "småtvättar": "småtvätt",
    "småtvättarna": "småtvätt",
    "småtvättarnas": "småtvätt",
    "småtvättars": "småtvätt",
    "småtvätten": "småtvätt",
    "småtvättens": "småtvätt",
    "småtvätts": "småtvätt",
    "småung": "småungar",
    "småungarna": "småungar",
    "småungarnas": "småungar",
    "småungars": "småungar",
    "småunges": "småungar",
    "småungs": "småungar",
    "småviktiga": "småviktig",
    "småviktigare": "småviktig",
    "småviktigares": "småviktig",
    "småviktigas": "småviktig",
    "småviktigast": "småviktig",
    "småviktigaste": "småviktig",
    "småviktigastes": "småviktig",
    "småviktigasts": "småviktig",
    "småviktige": "småviktig",
    "småviktiges": "småviktig",
    "småviktigheten": "småviktighet",
    "småviktighetens": "småviktighet",
    "småviktighets": "småviktighet",
    "småviktigs": "småviktig",
    "småviktigt": "småviktig",
    "småviktigts": "småviktig",
    "småviltet": "småvilt",
    "småviltets": "småvilt",
    "småvilts": "småvilt",
    "småvuxens": "småvuxen",
    "småvuxet": "småvuxen",
    "småvuxets": "småvuxen",
    "småvuxna": "småvuxen",
    "småvuxnare": "småvuxen",
    "småvuxnares": "småvuxen",
    "småvuxnas": "småvuxen",
    "småvuxnast": "småvuxen",
    "småvuxnaste": "småvuxen",
    "småvuxnastes": "småvuxen",
    "småvuxnasts": "småvuxen",
    "småvuxne": "småvuxen",
    "småvuxnes": "småvuxen",
    "småväxta": "småväxt",
    "småväxtare": "småväxt",
    "småväxtares": "småväxt",
    "småväxtas": "småväxt",
    "småväxtast": "småväxt",
    "småväxtaste": "småväxt",
    "småväxtastes": "småväxt",
    "småväxtasts": "småväxt",
    "småväxte": "småväxt",
    "småväxtes": "småväxt",
    "småväxtheten": "småväxthet",
    "småväxthetens": "småväxthet",
    "småväxthets": "småväxthet",
    "småväxts": "småväxt",
    "smög": "smyga",
    "smöge": "smyga",
    "smöges": "smyga",
    "smögs": "smyga",
    "smör": "smöra",
    "smörad": "smöra",
    "smörade": "smöra",
    "smörades": "smöra",
    "smörads": "smöra",
    "smörande": "smöra",
    "smöranden": "smörande",
    "smörandena": "smörande",
    "smörandenas": "smörande",
    "smörandens": "smörande",
    "smörandes": "smörande",
    "smörandet": "smörande",
    "smörandets": "smörande",
    "smörar": "smöra",
    "smöras": "smöra",
    "smörat": "smöra",
    "smörats": "smöra",
    "smörbakelsen": "smörbakelse",
    "smörbakelsens": "smörbakelse",
    "smörbakelser": "smörbakelse",
    "smörbakelserna": "smörbakelse",
    "smörbakelsernas": "smörbakelse",
    "smörbakelsers": "smörbakelse",
    "smörbakelses": "smörbakelse",
    "smörbergen": "smörberg",
    "smörbergens": "smörberg",
    "smörberget": "smörberg",
    "smörbergets": "smörberg",
    "smörbergs": "smörberg",
    "smörblom": "smörblomma",
    "smörblomman": "smörblomma",
    "smörblommans": "smörblomma",
    "smörblommas": "smörblomma",
    "smörblomme": "smörblomma",
    "smörblommor": "smörblomma",
    "smörblommorna": "smörblomma",
    "smörblommornas": "smörblomma",
    "smörblommors": "smörblomma",
    "smörbloms": "smörblomma",
    "smörbollar": "smörboll",
    "smörbollarna": "smörboll",
    "smörbollarnas": "smörboll",
    "smörbollars": "smörboll",
    "smörbollen": "smörboll",
    "smörbollens": "smörboll",
    "smörbolls": "smörboll",
    "smörbultar": "smörbult",
    "smörbultarna": "smörbult",
    "smörbultarnas": "smörbult",
    "smörbultars": "smörbult",
    "smörbulten": "smörbult",
    "smörbultens": "smörbult",
    "smörbults": "smörbult",
    "smördegen": "smördeg",
    "smördegens": "smördeg",
    "smördegs": "smördeg",
    "smördegspastejen": "smördegspastej",
    "smördegspastejens": "smördegspastej",
    "smördegspastejer": "smördegspastej",
    "smördegspastejerna": "smördegspastej",
    "smördegspastejernas": "smördegspastej",
    "smördegspastejers": "smördegspastej",
    "smördegspastejs": "smördegspastej",
    "smörer": "smör",
    "smörerna": "smör",
    "smörernas": "smör",
    "smörers": "smör",
    "smöret": "smör",
    "smörets": "smör",
    "smörfräs": "smörfräsa",
    "smörfräsande": "smörfräsa",
    "smörfräsanden": "smörfräsande",
    "smörfräsandena": "smörfräsande",
    "smörfräsandenas": "smörfräsande",
    "smörfräsandens": "smörfräsande",
    "smörfräsandes": "smörfräsande",
    "smörfräsandet": "smörfräsande",
    "smörfräsandets": "smörfräsande",
    "smörfräsas": "smörfräsa",
    "smörfräser": "smörfräsa",
    "smörfräses": "smörfräsa",
    "smörfräst": "smörfräsa",
    "smörfrästa": "smörfräsa",
    "smörfrästas": "smörfräsa",
    "smörfräste": "smörfräsa",
    "smörfrästes": "smörfräsa",
    "smörfrästs": "smörfräsa",
    "smörgåsar": "smörgås",
    "smörgåsarna": "smörgås",
    "smörgåsarnas": "smörgås",
    "smörgåsars": "smörgås",
    "smörgåsborden": "smörgåsbord",
    "smörgåsbordens": "smörgåsbord",
    "smörgåsbordet": "smörgåsbord",
    "smörgåsbordets": "smörgåsbord",
    "smörgåsbords": "smörgåsbord",
    "smörgåsen": "smörgås",
    "smörgåsens": "smörgås",
    "smörgåsgaffeln": "smörgåsgaffel",
    "smörgåsgaffelns": "smörgåsgaffel",
    "smörgåsgaffels": "smörgåsgaffel",
    "smörgåsgafflar": "smörgåsgaffel",
    "smörgåsgafflarna": "smörgåsgaffel",
    "smörgåsgafflarnas": "smörgåsgaffel",
    "smörgåsgafflars": "smörgåsgaffel",
    "smörgåsknivar": "smörgåskniv",
    "smörgåsknivarna": "smörgåskniv",
    "smörgåsknivarnas": "smörgåskniv",
    "smörgåsknivars": "smörgåskniv",
    "smörgåskniven": "smörgåskniv",
    "smörgåsknivens": "smörgåskniv",
    "smörgåsknivs": "smörgåskniv",
    "smörgåskrassen": "smörgåskrasse",
    "smörgåskrassens": "smörgåskrasse",
    "smörgåskrasses": "smörgåskrasse",
    "smörgåsmargarinen": "smörgåsmargarin",
    "smörgåsmargarinens": "smörgåsmargarin",
    "smörgåsmargariner": "smörgåsmargarin",
    "smörgåsmargarinerna": "smörgåsmargarin",
    "smörgåsmargarinernas": "smörgåsmargarin",
    "smörgåsmargariners": "smörgåsmargarin",
    "smörgåsmargarinet": "smörgåsmargarin",
    "smörgåsmargarinets": "smörgåsmargarin",
    "smörgåsmargarins": "smörgåsmargarin",
    "smörgåsmaten": "smörgåsmat",
    "smörgåsmatens": "smörgåsmat",
    "smörgåsmats": "smörgåsmat",
    "smörgåsniss": "smörgåsnisse",
    "smörgåsnissar": "smörgåsnisse",
    "smörgåsnissarna": "smörgåsnisse",
    "smörgåsnissarnas": "smörgåsnisse",
    "smörgåsnissars": "smörgåsnisse",
    "smörgåsnissen": "smörgåsnisse",
    "smörgåsnissens": "smörgåsnisse",
    "smörgåsnisses": "smörgåsnisse",
    "smörgåspapperet": "smörgåspapper",
    "smörgåspapperets": "smörgåspapper",
    "smörgåspappers": "smörgåspapper",
    "smörgåspappret": "smörgåspapper",
    "smörgåspapprets": "smörgåspapper",
    "smörgåspåläggen": "smörgåspålägg",
    "smörgåspåläggens": "smörgåspålägg",
    "smörgåspålägget": "smörgåspålägg",
    "smörgåspåläggets": "smörgåspålägg",
    "smörgåspåläggs": "smörgåspålägg",
    "smörgåstårt": "smörgåstårta",
    "smörgåstårtan": "smörgåstårta",
    "smörgåstårtans": "smörgåstårta",
    "smörgåstårtas": "smörgåstårta",
    "smörgåstårte": "smörgåstårta",
    "smörgåstårtor": "smörgåstårta",
    "smörgåstårtorna": "smörgåstårta",
    "smörgåstårtornas": "smörgåstårta",
    "smörgåstårtors": "smörgåstårta",
    "smörgåstårts": "smörgåstårta",
    "smöriga": "smörig",
    "smörigare": "smörig",
    "smörigares": "smörig",
    "smörigas": "smörig",
    "smörigast": "smörig",
    "smörigaste": "smörig",
    "smörigastes": "smörig",
    "smörigasts": "smörig",
    "smörige": "smörig",
    "smöriges": "smörig",
    "smörigs": "smörig",
    "smörigt": "smörig",
    "smörigts": "smörig",
    "smörj": "smörja",
    "smörjan": "smörja",
    "smörjande": "smörja",
    "smörjanden": "smörjande",
    "smörjandena": "smörjande",
    "smörjandenas": "smörjande",
    "smörjandens": "smörjande",
    "smörjandes": "smörjande",
    "smörjandet": "smörjande",
    "smörjandets": "smörjande",
    "smörjanordningar": "smörjanordning",
    "smörjanordningarna": "smörjanordning",
    "smörjanordningarnas": "smörjanordning",
    "smörjanordningars": "smörjanordning",
    "smörjanordningen": "smörjanordning",
    "smörjanordningens": "smörjanordning",
    "smörjanordnings": "smörjanordning",
    "smörjans": "smörja",
    "smörjas": "smörja",
    "smörje": "smörja",
    "smörjelsen": "smörjelse",
    "smörjelsens": "smörjelse",
    "smörjelser": "smörjelse",
    "smörjelserna": "smörjelse",
    "smörjelsernas": "smörjelse",
    "smörjelsers": "smörjelse",
    "smörjelses": "smörjelse",
    "smörjer": "smörja",
    "smörjes": "smörja",
    "smörjet": "smörj",
    "smörjets": "smörj",
    "smörjfettet": "smörjfett",
    "smörjfettets": "smörjfett",
    "smörjfetts": "smörjfett",
    "smörjgropar": "smörjgrop",
    "smörjgroparna": "smörjgrop",
    "smörjgroparnas": "smörjgrop",
    "smörjgropars": "smörjgrop",
    "smörjgropen": "smörjgrop",
    "smörjgropens": "smörjgrop",
    "smörjgrops": "smörjgrop",
    "smörjhallar": "smörjhall",
    "smörjhallarna": "smörjhall",
    "smörjhallarnas": "smörjhall",
    "smörjhallars": "smörjhall",
    "smörjhallen": "smörjhall",
    "smörjhallens": "smörjhall",
    "smörjhalls": "smörjhall",
    "smörjhålen": "smörjhål",
    "smörjhålens": "smörjhål",
    "smörjhålet": "smörjhål",
    "smörjhålets": "smörjhål",
    "smörjhåls": "smörjhål",
    "smörjiga": "smörjig",
    "smörjigare": "smörjig",
    "smörjigares": "smörjig",
    "smörjigas": "smörjig",
    "smörjigast": "smörjig",
    "smörjigaste": "smörjig",
    "smörjigastes": "smörjig",
    "smörjigasts": "smörjig",
    "smörjige": "smörjig",
    "smörjiges": "smörjig",
    "smörjigheten": "smörjighet",
    "smörjighetens": "smörjighet",
    "smörjighets": "smörjighet",
    "smörjigs": "smörjig",
    "smörjigt": "smörjig",
    "smörjigts": "smörjig",
    "smörjkannan": "smörjkanna",
    "smörjkannans": "smörjkanna",
    "smörjkannas": "smörjkanna",
    "smörjkanne": "smörjkanna",
    "smörjkannor": "smörjkanna",
    "smörjkannorna": "smörjkanna",
    "smörjkannornas": "smörjkanna",
    "smörjkannors": "smörjkanna",
    "smörjmedels": "smörjmedel",
    "smörjmedlen": "smörjmedel",
    "smörjmedlens": "smörjmedel",
    "smörjmedlet": "smörjmedel",
    "smörjmedlets": "smörjmedel",
    "smörjningar": "smörjning",
    "smörjningarna": "smörjning",
    "smörjningarnas": "smörjning",
    "smörjningars": "smörjning",
    "smörjningen": "smörjning",
    "smörjningens": "smörjning",
    "smörjnings": "smörjning",
    "smörjoljan": "smörjolja",
    "smörjoljans": "smörjolja",
    "smörjoljas": "smörjolja",
    "smörjolje": "smörjolja",
    "smörjor": "smörja",
    "smörjorna": "smörja",
    "smörjornas": "smörja",
    "smörjors": "smörja",
    "smörjs": "smörja",
    "smörknivar": "smörkniv",
    "smörknivarna": "smörkniv",
    "smörknivarnas": "smörkniv",
    "smörknivars": "smörkniv",
    "smörkniven": "smörkniv",
    "smörknivens": "smörkniv",
    "smörknivs": "smörkniv",
    "smörkrämen": "smörkräm",
    "smörkrämens": "smörkräm",
    "smörkräms": "smörkräm",
    "smörkul": "smörkula",
    "smörkulan": "smörkula",
    "smörkulans": "smörkula",
    "smörkulas": "smörkula",
    "smörkule": "smörkula",
    "smörkulor": "smörkula",
    "smörkulorna": "smörkula",
    "smörkulornas": "smörkula",
    "smörkulors": "smörkula",
    "smörkuls": "smörkula",
    "smörpapperet": "smörpapper",
    "smörpapperets": "smörpapper",
    "smörpappers": "smörpapper",
    "smörpappret": "smörpapper",
    "smörpapprets": "smörpapper",
    "smörs": "smör",
    "smörsoppar": "smörsopp",
    "smörsopparna": "smörsopp",
    "smörsopparnas": "smörsopp",
    "smörsoppars": "smörsopp",
    "smörsoppen": "smörsopp",
    "smörsoppens": "smörsopp",
    "smörsopps": "smörsopp",
    "smörspad": "smörspade",
    "smörspadar": "smörspade",
    "smörspadarna": "smörspade",
    "smörspadarnas": "smörspade",
    "smörspadars": "smörspade",
    "smörspaden": "smörspade",
    "smörspadens": "smörspade",
    "smörspades": "smörspade",
    "smörspads": "smörspade",
    "smörsvampar": "smörsvamp",
    "smörsvamparna": "smörsvamp",
    "smörsvamparnas": "smörsvamp",
    "smörsvampars": "smörsvamp",
    "smörsvampen": "smörsvamp",
    "smörsvampens": "smörsvamp",
    "smörsvamps": "smörsvamp",
    "smörsyran": "smörsyra",
    "smörsyrans": "smörsyra",
    "smörsyras": "smörsyra",
    "smörsyre": "smörsyra",
    "smörsången": "smörsång",
    "smörsångens": "smörsång",
    "smörsångs": "smörsång",
    "smörtenoren": "smörtenor",
    "smörtenorens": "smörtenor",
    "smörtenorer": "smörtenor",
    "smörtenorerna": "smörtenor",
    "smörtenorernas": "smörtenor",
    "smörtenorers": "smörtenor",
    "smörtenors": "smörtenor",
    "snabba": "snabb",
    "snabbare": "snabb",
    "snabbares": "snabb",
    "snabbas": "snabb",
    "snabbast": "snabb",
    "snabbaste": "snabb",
    "snabbastes": "snabb",
    "snabbasts": "snabb",
    "snabbcementen": "snabbcement",
    "snabbcementens": "snabbcement",
    "snabbcementet": "snabbcement",
    "snabbcementets": "snabbcement",
    "snabbcements": "snabbcement",
    "snabbe": "snabb",
    "snabbelden": "snabbeld",
    "snabbeldens": "snabbeld",
    "snabbelds": "snabbeld",
    "snabbes": "snabb",
    "snabbfotade": "snabbfotad",
    "snabbfotades": "snabbfotad",
    "snabbfotads": "snabbfotad",
    "snabbfotat": "snabbfotad",
    "snabbfotats": "snabbfotad",
    "snabbfoton": "snabbfoto",
    "snabbfotona": "snabbfoto",
    "snabbfotonas": "snabbfoto",
    "snabbfotons": "snabbfoto",
    "snabbfotos": "snabbfoto",
    "snabbfotot": "snabbfoto",
    "snabbfotots": "snabbfoto",
    "snabbfruse": "snabbfrysa",
    "snabbfrusen": "snabbfrysa",
    "snabbfrusens": "snabbfrysa",
    "snabbfruses": "snabbfrysa",
    "snabbfruset": "snabbfrysa",
    "snabbfrusets": "snabbfrysa",
    "snabbfrusit": "snabbfrysa",
    "snabbfrusits": "snabbfrysa",
    "snabbfrusna": "snabbfrysa",
    "snabbfrusnas": "snabbfrysa",
    "snabbfrusne": "snabbfrysa",
    "snabbfrusnes": "snabbfrysa",
    "snabbfrys": "snabbfrysa",
    "snabbfrysande": "snabbfrysa",
    "snabbfrysanden": "snabbfrysande",
    "snabbfrysandena": "snabbfrysande",
    "snabbfrysandenas": "snabbfrysande",
    "snabbfrysandens": "snabbfrysande",
    "snabbfrysandes": "snabbfrysande",
    "snabbfrysandet": "snabbfrysande",
    "snabbfrysandets": "snabbfrysande",
    "snabbfrysas": "snabbfrysa",
    "snabbfryse": "snabbfrysa",
    "snabbfryser": "snabbfrysa",
    "snabbfryses": "snabbfrysa",
    "snabbfryst": "snabbfrysa",
    "snabbfrysta": "snabbfrysa",
    "snabbfrystas": "snabbfrysa",
    "snabbfryste": "snabbfrysa",
    "snabbfrystes": "snabbfrysa",
    "snabbfrysts": "snabbfrysa",
    "snabbfrös": "snabbfrysa",
    "snabbförbanden": "snabbförband",
    "snabbförbandens": "snabbförband",
    "snabbförbandet": "snabbförband",
    "snabbförbandets": "snabbförband",
    "snabbförbands": "snabbförband",
    "snabbgranskad": "snabbgranska",
    "snabbgranskade": "snabbgranska",
    "snabbgranskades": "snabbgranska",
    "snabbgranskads": "snabbgranska",
    "snabbgranskande": "snabbgranska",
    "snabbgranskanden": "snabbgranskande",
    "snabbgranskandena": "snabbgranskande",
    "snabbgranskandenas": "snabbgranskande",
    "snabbgranskandens": "snabbgranskande",
    "snabbgranskandes": "snabbgranskande",
    "snabbgranskandet": "snabbgranskande",
    "snabbgranskandets": "snabbgranskande",
    "snabbgranskar": "snabbgranska",
    "snabbgranskas": "snabbgranska",
    "snabbgranskat": "snabbgranska",
    "snabbgranskats": "snabbgranska",
    "snabbguiden": "snabbguide",
    "snabbguidens": "snabbguide",
    "snabbguider": "snabbguide",
    "snabbguiderna": "snabbguide",
    "snabbguidernas": "snabbguide",
    "snabbguiders": "snabbguide",
    "snabbguides": "snabbguide",
    "snabbheten": "snabbhet",
    "snabbhetens": "snabbhet",
    "snabbheter": "snabbhet",
    "snabbheterna": "snabbhet",
    "snabbheternas": "snabbhet",
    "snabbheters": "snabbhet",
    "snabbhets": "snabbhet",
    "snabbkaffes": "snabbkaffe",
    "snabbkaffet": "snabbkaffe",
    "snabbkaffets": "snabbkaffe",
    "snabbkassan": "snabbkassa",
    "snabbkassans": "snabbkassa",
    "snabbkassas": "snabbkassa",
    "snabbkasse": "snabbkassa",
    "snabbkassor": "snabbkassa",
    "snabbkassorna": "snabbkassa",
    "snabbkassornas": "snabbkassa",
    "snabbkassors": "snabbkassa",
    "snabbkopplingar": "snabbkoppling",
    "snabbkopplingarna": "snabbkoppling",
    "snabbkopplingarnas": "snabbkoppling",
    "snabbkopplingars": "snabbkoppling",
    "snabbkopplingen": "snabbkoppling",
    "snabbkopplingens": "snabbkoppling",
    "snabbkopplings": "snabbkoppling",
    "snabbkursen": "snabbkurs",
    "snabbkursens": "snabbkurs",
    "snabbkurser": "snabbkurs",
    "snabbkurserna": "snabbkurs",
    "snabbkursernas": "snabbkurs",
    "snabbkursers": "snabbkurs",
    "snabbköpen": "snabbköp",
    "snabbköpens": "snabbköp",
    "snabbköpet": "snabbköp",
    "snabbköpets": "snabbköp",
    "snabbköps": "snabbköp",
    "snabbköpsbutiken": "snabbköpsbutik",
    "snabbköpsbutikens": "snabbköpsbutik",
    "snabbköpsbutiker": "snabbköpsbutik",
    "snabbköpsbutikerna": "snabbköpsbutik",
    "snabbköpsbutikernas": "snabbköpsbutik",
    "snabbköpsbutikers": "snabbköpsbutik",
    "snabbköpsbutiks": "snabbköpsbutik",
    "snabbköpskassan": "snabbköpskassa",
    "snabbköpskassans": "snabbköpskassa",
    "snabbköpskassas": "snabbköpskassa",
    "snabbköpskasse": "snabbköpskassa",
    "snabbköpskassor": "snabbköpskassa",
    "snabbköpskassorna": "snabbköpskassa",
    "snabbköpskassornas": "snabbköpskassa",
    "snabbköpskassors": "snabbköpskassa",
    "snabbladdar": "snabbladdare",
    "snabbladdaren": "snabbladdare",
    "snabbladdarens": "snabbladdare",
    "snabbladdares": "snabbladdare",
    "snabbladdarna": "snabbladdare",
    "snabbladdarnas": "snabbladdare",
    "snabblagade": "snabblagad",
    "snabblagades": "snabblagad",
    "snabblagads": "snabblagad",
    "snabblagat": "snabblagad",
    "snabblagats": "snabblagad",
    "snabblunchen": "snabblunch",
    "snabblunchens": "snabblunch",
    "snabbluncher": "snabblunch",
    "snabbluncherna": "snabblunch",
    "snabblunchernas": "snabblunch",
    "snabblunchers": "snabblunch",
    "snabblunchs": "snabblunch",
    "snabblånet": "snabblån",
    "snabblånets": "snabblån",
    "snabblåns": "snabblån",
    "snabblösliga": "snabblöslig",
    "snabblösligare": "snabblöslig",
    "snabblösligares": "snabblöslig",
    "snabblösligas": "snabblöslig",
    "snabblösligast": "snabblöslig",
    "snabblösligaste": "snabblöslig",
    "snabblösligastes": "snabblöslig",
    "snabblösligasts": "snabblöslig",
    "snabblöslige": "snabblöslig",
    "snabblösliges": "snabblöslig",
    "snabblösligheten": "snabblöslighet",
    "snabblöslighetens": "snabblöslighet",
    "snabblöslighets": "snabblöslighet",
    "snabblösligs": "snabblöslig",
    "snabblösligt": "snabblöslig",
    "snabblösligts": "snabblöslig",
    "snabbmaten": "snabbmat",
    "snabbmatens": "snabbmat",
    "snabbmats": "snabbmat",
    "snabbmatsrestaurangen": "snabbmatsrestaurang",
    "snabbmatsrestaurangens": "snabbmatsrestaurang",
    "snabbmatsrestauranger": "snabbmatsrestaurang",
    "snabbmatsrestaurangerna": "snabbmatsrestaurang",
    "snabbmatsrestaurangernas": "snabbmatsrestaurang",
    "snabbmatsrestaurangers": "snabbmatsrestaurang",
    "snabbmatsrestaurangs": "snabbmatsrestaurang",
    "snabbmiddagar": "snabbmiddag",
    "snabbmiddagarna": "snabbmiddag",
    "snabbmiddagarnas": "snabbmiddag",
    "snabbmiddagars": "snabbmiddag",
    "snabbmiddagen": "snabbmiddag",
    "snabbmiddagens": "snabbmiddag",
    "snabbmiddags": "snabbmiddag",
    "snabbnudel": "snabbnudlar",
    "snabbnudels": "snabbnudlar",
    "snabbnudlarna": "snabbnudlar",
    "snabbnudlarnas": "snabbnudlar",
    "snabbnudlars": "snabbnudlar",
    "snabbplatt": "snabbplatta",
    "snabbplattan": "snabbplatta",
    "snabbplattans": "snabbplatta",
    "snabbplattas": "snabbplatta",
    "snabbplatte": "snabbplatta",
    "snabbplattor": "snabbplatta",
    "snabbplattorna": "snabbplatta",
    "snabbplattornas": "snabbplatta",
    "snabbplattors": "snabbplatta",
    "snabbplatts": "snabbplatta",
    "snabbporträtten": "snabbporträtt",
    "snabbporträttens": "snabbporträtt",
    "snabbporträttet": "snabbporträtt",
    "snabbporträttets": "snabbporträtt",
    "snabbporträtts": "snabbporträtt",
    "snabbprotokollen": "snabbprotokoll",
    "snabbprotokollens": "snabbprotokoll",
    "snabbprotokollet": "snabbprotokoll",
    "snabbprotokollets": "snabbprotokoll",
    "snabbprotokolls": "snabbprotokoll",
    "snabbregulatorer": "snabbregulator",
    "snabbregulatorerna": "snabbregulator",
    "snabbregulatorernas": "snabbregulator",
    "snabbregulatorers": "snabbregulator",
    "snabbregulatorn": "snabbregulator",
    "snabbregulatorns": "snabbregulator",
    "snabbregulators": "snabbregulator",
    "snabbremissen": "snabbremiss",
    "snabbremissens": "snabbremiss",
    "snabbremisser": "snabbremiss",
    "snabbremisserna": "snabbremiss",
    "snabbremissernas": "snabbremiss",
    "snabbremissers": "snabbremiss",
    "snabbreparationen": "snabbreparation",
    "snabbreparationens": "snabbreparation",
    "snabbreparationer": "snabbreparation",
    "snabbreparationerna": "snabbreparation",
    "snabbreparationernas": "snabbreparation",
    "snabbreparationers": "snabbreparation",
    "snabbreparations": "snabbreparation",
    "snabbreprisen": "snabbrepris",
    "snabbreprisens": "snabbrepris",
    "snabbrepriser": "snabbrepris",
    "snabbrepriserna": "snabbrepris",
    "snabbreprisernas": "snabbrepris",
    "snabbreprisers": "snabbrepris",
    "snabbs": "snabb",
    "snabbskilsmässan": "snabbskilsmässa",
    "snabbskilsmässans": "snabbskilsmässa",
    "snabbskilsmässas": "snabbskilsmässa",
    "snabbskilsmässo": "snabbskilsmässa",
    "snabbskilsmässor": "snabbskilsmässa",
    "snabbskilsmässorna": "snabbskilsmässa",
    "snabbskilsmässornas": "snabbskilsmässa",
    "snabbskilsmässors": "snabbskilsmässa",
    "snabbskissen": "snabbskiss",
    "snabbskissens": "snabbskiss",
    "snabbskisser": "snabbskiss",
    "snabbskisserna": "snabbskiss",
    "snabbskissernas": "snabbskiss",
    "snabbskissers": "snabbskiss",
    "snabbskriften": "snabbskrift",
    "snabbskriftens": "snabbskrift",
    "snabbskrifts": "snabbskrift",
    "snabbspolad": "snabbspola",
    "snabbspolade": "snabbspola",
    "snabbspolades": "snabbspola",
    "snabbspolads": "snabbspola",
    "snabbspolande": "snabbspola",
    "snabbspolanden": "snabbspolande",
    "snabbspolandena": "snabbspolande",
    "snabbspolandenas": "snabbspolande",
    "snabbspolandens": "snabbspolande",
    "snabbspolandes": "snabbspolande",
    "snabbspolandet": "snabbspolande",
    "snabbspolandets": "snabbspolande",
    "snabbspolar": "snabbspola",
    "snabbspolas": "snabbspola",
    "snabbspolat": "snabbspola",
    "snabbspolats": "snabbspola",
    "snabbspännen": "snabbspänne",
    "snabbspännena": "snabbspänne",
    "snabbspännenas": "snabbspänne",
    "snabbspännens": "snabbspänne",
    "snabbspännes": "snabbspänne",
    "snabbspännet": "snabbspänne",
    "snabbspännets": "snabbspänne",
    "snabbstoppen": "snabbstopp",
    "snabbstoppens": "snabbstopp",
    "snabbstoppet": "snabbstopp",
    "snabbstoppets": "snabbstopp",
    "snabbstopps": "snabbstopp",
    "snabbstålet": "snabbstål",
    "snabbstålets": "snabbstål",
    "snabbståls": "snabbstål",
    "snabbsvarvstålet": "snabbsvarvstål",
    "snabbsvarvstålets": "snabbsvarvstål",
    "snabbsvarvståls": "snabbsvarvstål",
    "snabbt": "snabb",
    "snabbteckn": "snabbteckna",
    "snabbtecknad": "snabbteckna",
    "snabbtecknade": "snabbteckna",
    "snabbtecknades": "snabbteckna",
    "snabbtecknads": "snabbteckna",
    "snabbtecknande": "snabbteckna",
    "snabbtecknanden": "snabbtecknande",
    "snabbtecknandena": "snabbtecknande",
    "snabbtecknandenas": "snabbtecknande",
    "snabbtecknandens": "snabbtecknande",
    "snabbtecknandes": "snabbtecknande",
    "snabbtecknandet": "snabbtecknande",
    "snabbtecknandets": "snabbtecknande",
    "snabbtecknar": "snabbteckna",
    "snabbtecknas": "snabbteckna",
    "snabbtecknat": "snabbteckna",
    "snabbtecknats": "snabbteckna",
    "snabbtelefonen": "snabbtelefon",
    "snabbtelefonens": "snabbtelefon",
    "snabbtelefoner": "snabbtelefon",
    "snabbtelefonerna": "snabbtelefon",
    "snabbtelefonernas": "snabbtelefon",
    "snabbtelefoners": "snabbtelefon",
    "snabbtelefons": "snabbtelefon",
    "snabbts": "snabb",
    "snabbtänkta": "snabbtänkt",
    "snabbtänktare": "snabbtänkt",
    "snabbtänktares": "snabbtänkt",
    "snabbtänktas": "snabbtänkt",
    "snabbtänktast": "snabbtänkt",
    "snabbtänktaste": "snabbtänkt",
    "snabbtänktastes": "snabbtänkt",
    "snabbtänktasts": "snabbtänkt",
    "snabbtänkte": "snabbtänkt",
    "snabbtänktes": "snabbtänkt",
    "snabbtänktheten": "snabbtänkthet",
    "snabbtänkthetens": "snabbtänkthet",
    "snabbtänkthets": "snabbtänkthet",
    "snabbtänkts": "snabbtänkt",
    "snabbtågen": "snabbtåg",
    "snabbtågens": "snabbtåg",
    "snabbtåget": "snabbtåg",
    "snabbtågets": "snabbtåg",
    "snabbtågs": "snabbtåg",
    "snabbussar": "snabbuss",
    "snabbussarna": "snabbuss",
    "snabbussarnas": "snabbuss",
    "snabbussars": "snabbuss",
    "snabbussen": "snabbuss",
    "snabbussens": "snabbuss",
    "snabbutred": "snabbutreda",
    "snabbutredande": "snabbutreda",
    "snabbutredanden": "snabbutredande",
    "snabbutredandena": "snabbutredande",
    "snabbutredandenas": "snabbutredande",
    "snabbutredandens": "snabbutredande",
    "snabbutredandes": "snabbutredande",
    "snabbutredandet": "snabbutredande",
    "snabbutredandets": "snabbutredande",
    "snabbutredas": "snabbutreda",
    "snabbutredd": "snabbutreda",
    "snabbutredda": "snabbutreda",
    "snabbutreddas": "snabbutreda",
    "snabbutredde": "snabbutreda",
    "snabbutreddes": "snabbutreda",
    "snabbutredds": "snabbutreda",
    "snabbutreder": "snabbutreda",
    "snabbutredes": "snabbutreda",
    "snabbutreds": "snabbutreda",
    "snabbutrett": "snabbutreda",
    "snabbutretts": "snabbutreda",
    "snabbversionen": "snabbversion",
    "snabbversionens": "snabbversion",
    "snabbversioner": "snabbversion",
    "snabbversionerna": "snabbversion",
    "snabbversionernas": "snabbversion",
    "snabbversioners": "snabbversion",
    "snabbversions": "snabbversion",
    "snabbvisiten": "snabbvisit",
    "snabbvisitens": "snabbvisit",
    "snabbvisiter": "snabbvisit",
    "snabbvisiterna": "snabbvisit",
    "snabbvisiternas": "snabbvisit",
    "snabbvisiters": "snabbvisit",
    "snabbvisits": "snabbvisit",
    "snabbväljar": "snabbväljare",
    "snabbväljaren": "snabbväljare",
    "snabbväljarens": "snabbväljare",
    "snabbväljares": "snabbväljare",
    "snabbväljarna": "snabbväljare",
    "snabbväljarnas": "snabbväljare",
    "snabel-a-et": "snabel-a",
    "snabel-a-ets": "snabel-a",
    "snabel-a-n": "snabel-a",
    "snabel-a-na": "snabel-a",
    "snabel-a-nas": "snabel-a",
    "snabel-a-ns": "snabel-a",
    "snabel-a-s": "snabel-a",
    "snabel-a-t": "snabel-a",
    "snabel-a-ts": "snabel-a",
    "snabel-a:et": "snabel-a",
    "snabel-a:ets": "snabel-a",
    "snabel-a:n": "snabel-a",
    "snabel-a:na": "snabel-a",
    "snabel-a:nas": "snabel-a",
    "snabel-a:ns": "snabel-a",
    "snabel-a:s": "snabel-a",
    "snabel-a:t": "snabel-a",
    "snabel-a:ts": "snabel-a",
    "snabeln": "snabel",
    "snabelns": "snabel",
    "snabels": "snabel",
    "snabelskon": "snabelsko",
    "snabelskons": "snabelsko",
    "snabelskor": "snabelsko",
    "snabelskorna": "snabelsko",
    "snabelskornas": "snabelsko",
    "snabelskors": "snabelsko",
    "snabelskos": "snabelsko",
    "snablar": "snabel",
    "snablarna": "snabel",
    "snablarnas": "snabel",
    "snablars": "snabel",
    "snack": "snacka",
    "snackad": "snacka",
    "snackade": "snacka",
    "snackades": "snacka",
    "snackads": "snacka",
    "snackande": "snacka",
    "snackanden": "snackande",
    "snackandena": "snackande",
    "snackandenas": "snackande",
    "snackandens": "snackande",
    "snackandes": "snackande",
    "snackandet": "snackande",
    "snackandets": "snackande",
    "snackar": "snacka",
    "snackas": "snacka",
    "snackat": "snacka",
    "snackats": "snacka",
    "snackbaren": "snackbar",
    "snackbarens": "snackbar",
    "snackbarer": "snackbar",
    "snackbarerna": "snackbar",
    "snackbarernas": "snackbar",
    "snackbarers": "snackbar",
    "snackbars": "snackbar",
    "snackesaliga": "snackesalig",
    "snackesaligare": "snackesalig",
    "snackesaligares": "snackesalig",
    "snackesaligas": "snackesalig",
    "snackesaligast": "snackesalig",
    "snackesaligaste": "snackesalig",
    "snackesaligastes": "snackesalig",
    "snackesaligasts": "snackesalig",
    "snackesalige": "snackesalig",
    "snackesaliges": "snackesalig",
    "snackesaligheten": "snackesalighet",
    "snackesalighetens": "snackesalighet",
    "snackesalighets": "snackesalighet",
    "snackesaligs": "snackesalig",
    "snackesaligt": "snackesalig",
    "snackesaligts": "snackesalig",
    "snacket": "snack",
    "snackets": "snack",
    "snackisar": "snackis",
    "snackisarna": "snackis",
    "snackisarnas": "snackis",
    "snackisars": "snackis",
    "snackisen": "snackis",
    "snackisens": "snackis",
    "snacks": "snack",
    "snacksaliga": "snacksalig",
    "snacksaligare": "snacksalig",
    "snacksaligares": "snacksalig",
    "snacksaligas": "snacksalig",
    "snacksaligast": "snacksalig",
    "snacksaligaste": "snacksalig",
    "snacksaligastes": "snacksalig",
    "snacksaligasts": "snacksalig",
    "snacksalige": "snacksalig",
    "snacksaliges": "snacksalig",
    "snacksaligheten": "snacksalighet",
    "snacksalighetens": "snacksalighet",
    "snacksalighets": "snacksalighet",
    "snacksaligs": "snacksalig",
    "snacksaligt": "snacksalig",
    "snacksaligts": "snacksalig",
    "snacksen": "snacks",
    "snacksens": "snacks",
    "snackset": "snacks",
    "snacksets": "snacks",
    "snafset": "snafs",
    "snafsets": "snafs",
    "snagg": "snagga",
    "snaggad": "snagga",
    "snaggade": "snagga",
    "snaggades": "snagga",
    "snaggads": "snagga",
    "snaggande": "snagga",
    "snagganden": "snaggande",
    "snaggandena": "snaggande",
    "snaggandenas": "snaggande",
    "snaggandens": "snaggande",
    "snaggandes": "snaggande",
    "snaggandet": "snaggande",
    "snaggandets": "snaggande",
    "snaggar": "snagga",
    "snaggas": "snagga",
    "snaggat": "snagga",
    "snaggats": "snagga",
    "snaggen": "snagg",
    "snaggens": "snagg",
    "snaggs": "snagg",
    "snapp": "snappa",
    "snappad": "snappa",
    "snappade": "snappa",
    "snappades": "snappa",
    "snappads": "snappa",
    "snappande": "snappa",
    "snappanden": "snappande",
    "snappandena": "snappande",
    "snappandenas": "snappande",
    "snappandens": "snappande",
    "snappandes": "snappande",
    "snappandet": "snappande",
    "snappandets": "snappande",
    "snappar": "snappa",
    "snappas": "snappa",
    "snappat": "snappa",
    "snappats": "snappa",
    "snapphan": "snapphane",
    "snapphanar": "snapphane",
    "snapphanarna": "snapphane",
    "snapphanarnas": "snapphane",
    "snapphanars": "snapphane",
    "snapphanen": "snapphane",
    "snapphanens": "snapphane",
    "snapphanes": "snapphane",
    "snapphans": "snapphane",
    "snaps": "snapsa",
    "snapsad": "snapsa",
    "snapsade": "snapsa",
    "snapsades": "snapsa",
    "snapsads": "snapsa",
    "snapsande": "snapsa",
    "snapsanden": "snapsande",
    "snapsandena": "snapsande",
    "snapsandenas": "snapsande",
    "snapsandens": "snapsande",
    "snapsandes": "snapsande",
    "snapsandet": "snapsande",
    "snapsandets": "snapsande",
    "snapsar": "snapsa",
    "snapsarna": "snaps",
    "snapsarnas": "snaps",
    "snapsars": "snaps",
    "snapsas": "snapsa",
    "snapsat": "snapsa",
    "snapsats": "snapsa",
    "snapsen": "snaps",
    "snapsens": "snaps",
    "snapshoten": "snapshot",
    "snapshotens": "snapshot",
    "snapshotet": "snapshot",
    "snapshotets": "snapshot",
    "snapshots": "snapshot",
    "snapshotsen": "snapshot",
    "snapshotsens": "snapshot",
    "snapsvis": "snapsvisa",
    "snapsvisan": "snapsvisa",
    "snapsvisans": "snapsvisa",
    "snapsvisas": "snapsvisa",
    "snapsvise": "snapsvisa",
    "snapsvisor": "snapsvisa",
    "snapsvisorna": "snapsvisa",
    "snapsvisornas": "snapsvisa",
    "snapsvisors": "snapsvisa",
    "snar": "snara",
    "snara": "snar",
    "snarad": "snara",
    "snarade": "snara",
    "snarades": "snara",
    "snarads": "snara",
    "snaran": "snara",
    "snarande": "snara",
    "snaranden": "snarande",
    "snarandena": "snarande",
    "snarandenas": "snarande",
    "snarandens": "snarande",
    "snarandes": "snarande",
    "snarandet": "snarande",
    "snarandets": "snarande",
    "snarans": "snara",
    "snarar": "snara",
    "snarare": "snar",
    "snarares": "snar",
    "snaras": "snara",
    "snarast": "snar",
    "snaraste": "snar",
    "snarastes": "snar",
    "snarasts": "snar",
    "snarat": "snara",
    "snarats": "snara",
    "snare": "snara",
    "snares": "snar",
    "snarfagerheten": "snarfagerhet",
    "snarfagerhetens": "snarfagerhet",
    "snarfagerhets": "snarfagerhet",
    "snarfagers": "snarfager",
    "snarfagert": "snarfager",
    "snarfagerts": "snarfager",
    "snarfagra": "snarfager",
    "snarfagrare": "snarfager",
    "snarfagrares": "snarfager",
    "snarfagras": "snarfager",
    "snarfagrast": "snarfager",
    "snarfagraste": "snarfager",
    "snarfagrastes": "snarfager",
    "snarfagrasts": "snarfager",
    "snarfagre": "snarfager",
    "snarfagres": "snarfager",
    "snarfyndiga": "snarfyndig",
    "snarfyndigare": "snarfyndig",
    "snarfyndigares": "snarfyndig",
    "snarfyndigas": "snarfyndig",
    "snarfyndigast": "snarfyndig",
    "snarfyndigaste": "snarfyndig",
    "snarfyndigastes": "snarfyndig",
    "snarfyndigasts": "snarfyndig",
    "snarfyndige": "snarfyndig",
    "snarfyndiges": "snarfyndig",
    "snarfyndigheten": "snarfyndighet",
    "snarfyndighetens": "snarfyndighet",
    "snarfyndighets": "snarfyndighet",
    "snarfyndigs": "snarfyndig",
    "snarfyndigt": "snarfyndig",
    "snarfyndigts": "snarfyndig",
    "snarfärdiga": "snarfärdig",
    "snarfärdigare": "snarfärdig",
    "snarfärdigares": "snarfärdig",
    "snarfärdigas": "snarfärdig",
    "snarfärdigast": "snarfärdig",
    "snarfärdigaste": "snarfärdig",
    "snarfärdigastes": "snarfärdig",
    "snarfärdigasts": "snarfärdig",
    "snarfärdige": "snarfärdig",
    "snarfärdiges": "snarfärdig",
    "snarfärdigheten": "snarfärdighet",
    "snarfärdighetens": "snarfärdighet",
    "snarfärdighets": "snarfärdighet",
    "snarfärdigs": "snarfärdig",
    "snarfärdigt": "snarfärdig",
    "snarfärdigts": "snarfärdig",
    "snarheten": "snarhet",
    "snarhetens": "snarhet",
    "snarhets": "snarhet",
    "snark": "snarka",
    "snarkad": "snarka",
    "snarkade": "snarka",
    "snarkades": "snarka",
    "snarkads": "snarka",
    "snarkande": "snarka",
    "snarkanden": "snarkande",
    "snarkandena": "snarkande",
    "snarkandenas": "snarkande",
    "snarkandens": "snarkande",
    "snarkandes": "snarkande",
    "snarkandet": "snarkande",
    "snarkandets": "snarkande",
    "snarkar": "snarka",
    "snarkas": "snarka",
    "snarkat": "snarka",
    "snarkats": "snarka",
    "snarkningar": "snarkning",
    "snarkningarna": "snarkning",
    "snarkningarnas": "snarkning",
    "snarkningars": "snarkning",
    "snarkningen": "snarkning",
    "snarkningens": "snarkning",
    "snarknings": "snarkning",
    "snarliga": "snarlig",
    "snarligare": "snarlig",
    "snarligares": "snarlig",
    "snarligas": "snarlig",
    "snarligast": "snarlig",
    "snarligaste": "snarlig",
    "snarligastes": "snarlig",
    "snarligasts": "snarlig",
    "snarlige": "snarlig",
    "snarliges": "snarlig",
    "snarligheten": "snarlighet",
    "snarlighetens": "snarlighet",
    "snarlighets": "snarlighet",
    "snarligs": "snarlig",
    "snarligt": "snarlig",
    "snarligts": "snarlig",
    "snarlika": "snarlik",
    "snarlikare": "snarlik",
    "snarlikares": "snarlik",
    "snarlikas": "snarlik",
    "snarlikast": "snarlik",
    "snarlikaste": "snarlik",
    "snarlikastes": "snarlik",
    "snarlikasts": "snarlik",
    "snarlike": "snarlik",
    "snarlikes": "snarlik",
    "snarlikheten": "snarlikhet",
    "snarlikhetens": "snarlikhet",
    "snarlikhets": "snarlikhet",
    "snarliks": "snarlik",
    "snarlikt": "snarlik",
    "snarlikts": "snarlik",
    "snaror": "snara",
    "snarorna": "snara",
    "snarornas": "snara",
    "snarors": "snara",
    "snarp": "snarpa",
    "snarpad": "snarpa",
    "snarpade": "snarpa",
    "snarpades": "snarpa",
    "snarpads": "snarpa",
    "snarpande": "snarpa",
    "snarpanden": "snarpande",
    "snarpandena": "snarpande",
    "snarpandenas": "snarpande",
    "snarpandens": "snarpande",
    "snarpandes": "snarpande",
    "snarpandet": "snarpande",
    "snarpandets": "snarpande",
    "snarpar": "snarpa",
    "snarpas": "snarpa",
    "snarpat": "snarpa",
    "snarpats": "snarpa",
    "snarr": "snarra",
    "snarrad": "snarra",
    "snarrade": "snarra",
    "snarrades": "snarra",
    "snarrads": "snarra",
    "snarrande": "snarra",
    "snarranden": "snarrande",
    "snarrandena": "snarrande",
    "snarrandenas": "snarrande",
    "snarrandens": "snarrande",
    "snarrandes": "snarrande",
    "snarrandet": "snarrande",
    "snarrandets": "snarrande",
    "snarrar": "snarra",
    "snarras": "snarra",
    "snarrat": "snarra",
    "snarrats": "snarra",
    "snarrev": "snarreva",
    "snarrevan": "snarreva",
    "snarrevans": "snarreva",
    "snarrevas": "snarreva",
    "snarreve": "snarreva",
    "snarrevor": "snarreva",
    "snarrevorna": "snarreva",
    "snarrevornas": "snarreva",
    "snarrevors": "snarreva",
    "snarrevs": "snarreva",
    "snars": "snara",
    "snarstuckens": "snarstucken",
    "snarstucket": "snarstucken",
    "snarstuckets": "snarstucken",
    "snarstuckna": "snarstucken",
    "snarstucknare": "snarstucken",
    "snarstucknares": "snarstucken",
    "snarstucknas": "snarstucken",
    "snarstucknast": "snarstucken",
    "snarstucknaste": "snarstucken",
    "snarstucknastes": "snarstucken",
    "snarstucknasts": "snarstucken",
    "snarstuckne": "snarstucken",
    "snarstucknes": "snarstucken",
    "snart": "snar",
    "snarts": "snar",
    "snartänkta": "snartänkt",
    "snartänktare": "snartänkt",
    "snartänktares": "snartänkt",
    "snartänktas": "snartänkt",
    "snartänktast": "snartänkt",
    "snartänktaste": "snartänkt",
    "snartänktastes": "snartänkt",
    "snartänktasts": "snartänkt",
    "snartänkte": "snartänkt",
    "snartänktes": "snartänkt",
    "snartänktheten": "snartänkthet",
    "snartänkthetens": "snartänkthet",
    "snartänkthets": "snartänkthet",
    "snartänkts": "snartänkt",
    "snarvackerheten": "snarvackerhet",
    "snarvackerhetens": "snarvackerhet",
    "snarvackerhets": "snarvackerhet",
    "snarvackers": "snarvacker",
    "snarvackert": "snarvacker",
    "snarvackerts": "snarvacker",
    "snarvackra": "snarvacker",
    "snarvackrare": "snarvacker",
    "snarvackrares": "snarvacker",
    "snarvackras": "snarvacker",
    "snarvackrast": "snarvacker",
    "snarvackraste": "snarvacker",
    "snarvackrastes": "snarvacker",
    "snarvackrasts": "snarvacker",
    "snarvackre": "snarvacker",
    "snarvackres": "snarvacker",
    "snask": "snaska",
    "snaskad": "snaska",
    "snaskade": "snaska",
    "snaskades": "snaska",
    "snaskads": "snaska",
    "snaskande": "snaska",
    "snaskanden": "snaskande",
    "snaskandena": "snaskande",
    "snaskandenas": "snaskande",
    "snaskandens": "snaskande",
    "snaskandes": "snaskande",
    "snaskandet": "snaskande",
    "snaskandets": "snaskande",
    "snaskar": "snasker",
    "snaskarna": "snasker",
    "snaskarnas": "snasker",
    "snaskars": "snasker",
    "snaskas": "snaska",
    "snaskat": "snaska",
    "snaskats": "snaska",
    "snaskerier": "snaskeri",
    "snaskerierna": "snaskeri",
    "snaskeriernas": "snaskeri",
    "snaskeriers": "snaskeri",
    "snaskeriet": "snaskeri",
    "snaskeriets": "snaskeri",
    "snaskeris": "snaskeri",
    "snaskerit": "snaskeri",
    "snaskerits": "snaskeri",
    "snaskern": "snasker",
    "snaskerns": "snasker",
    "snaskers": "snasker",
    "snasket": "snask",
    "snaskets": "snask",
    "snaskiga": "snaskig",
    "snaskigare": "snaskig",
    "snaskigares": "snaskig",
    "snaskigas": "snaskig",
    "snaskigast": "snaskig",
    "snaskigaste": "snaskig",
    "snaskigastes": "snaskig",
    "snaskigasts": "snaskig",
    "snaskige": "snaskig",
    "snaskiges": "snaskig",
    "snaskigheten": "snaskighet",
    "snaskighetens": "snaskighet",
    "snaskigheter": "snaskighet",
    "snaskigheterna": "snaskighet",
    "snaskigheternas": "snaskighet",
    "snaskigheters": "snaskighet",
    "snaskighets": "snaskighet",
    "snaskigs": "snaskig",
    "snaskigt": "snaskig",
    "snaskigts": "snaskig",
    "snaskrar": "snasker",
    "snaskrarna": "snasker",
    "snaskrarnas": "snasker",
    "snaskrars": "snasker",
    "snasks": "snask",
    "snatt": "snatta",
    "snattad": "snatta",
    "snattade": "snatta",
    "snattades": "snatta",
    "snattads": "snatta",
    "snattande": "snatta",
    "snattanden": "snattande",
    "snattandena": "snattande",
    "snattandenas": "snattande",
    "snattandens": "snattande",
    "snattandes": "snattande",
    "snattandet": "snattande",
    "snattandets": "snattande",
    "snattar": "snattare",
    "snattaren": "snattare",
    "snattarens": "snattare",
    "snattares": "snattare",
    "snattarna": "snattare",
    "snattarnas": "snattare",
    "snattas": "snatta",
    "snattat": "snatta",
    "snattats": "snatta",
    "snatter": "snattra",
    "snatteranden": "snatterand",
    "snatterandens": "snatterand",
    "snatterands": "snatterand",
    "snatterier": "snatteri",
    "snatterierna": "snatteri",
    "snatteriernas": "snatteri",
    "snatteriers": "snatteri",
    "snatteriet": "snatteri",
    "snatteriets": "snatteri",
    "snatteris": "snatteri",
    "snatterit": "snatteri",
    "snatterits": "snatteri",
    "snatters": "snatter",
    "snatteränder": "snatterand",
    "snatteränderna": "snatterand",
    "snatterändernas": "snatterand",
    "snatteränders": "snatterand",
    "snattrade": "snattra",
    "snattrades": "snattra",
    "snattrande": "snattra",
    "snattranden": "snattrande",
    "snattrandena": "snattrande",
    "snattrandenas": "snattrande",
    "snattrandens": "snattrande",
    "snattrandes": "snattrande",
    "snattrandet": "snattrande",
    "snattrandets": "snattrande",
    "snattrar": "snattra",
    "snattras": "snattra",
    "snattrat": "snattra",
    "snattrats": "snattra",
    "snattret": "snatter",
    "snattrets": "snatter",
    "snav": "snava",
    "snavad": "snava",
    "snavade": "snava",
    "snavades": "snava",
    "snavads": "snava",
    "snavande": "snava",
    "snavanden": "snavande",
    "snavandena": "snavande",
    "snavandenas": "snavande",
    "snavandens": "snavande",
    "snavandes": "snavande",
    "snavandet": "snavande",
    "snavandets": "snavande",
    "snavar": "snava",
    "snavas": "snava",
    "snavat": "snava",
    "snavats": "snava",
    "sneda": "sned",
    "snedare": "sned",
    "snedares": "sned",
    "snedas": "sned",
    "snedast": "sned",
    "snedaste": "sned",
    "snedastes": "sned",
    "snedasts": "sned",
    "snedben": "snedbena",
    "snedbenan": "snedbena",
    "snedbenans": "snedbena",
    "snedbenas": "snedbena",
    "snedbene": "snedbena",
    "snedbenor": "snedbena",
    "snedbenorna": "snedbena",
    "snedbenornas": "snedbena",
    "snedbenors": "snedbena",
    "snedbens": "snedbena",
    "snedd": "snedda",
    "sneddad": "snedda",
    "sneddade": "snedda",
    "sneddades": "snedda",
    "sneddads": "snedda",
    "sneddande": "snedda",
    "sneddanden": "sneddande",
    "sneddandena": "sneddande",
    "sneddandenas": "sneddande",
    "sneddandens": "sneddande",
    "sneddandes": "sneddande",
    "sneddandet": "sneddande",
    "sneddandets": "sneddande",
    "sneddar": "snedda",
    "sneddas": "snedda",
    "sneddat": "snedda",
    "sneddats": "snedda",
    "snede": "sned",
    "snedes": "sned",
    "snedfördelningar": "snedfördelning",
    "snedfördelningarna": "snedfördelning",
    "snedfördelningarnas": "snedfördelning",
    "snedfördelningars": "snedfördelning",
    "snedfördelningen": "snedfördelning",
    "snedfördelningens": "snedfördelning",
    "snedfördelnings": "snedfördelning",
    "snedgångens": "snedgången",
    "snedgånget": "snedgången",
    "snedgångets": "snedgången",
    "snedgångna": "snedgången",
    "snedgångnare": "snedgången",
    "snedgångnares": "snedgången",
    "snedgångnas": "snedgången",
    "snedgångnast": "snedgången",
    "snedgångnaste": "snedgången",
    "snedgångnastes": "snedgången",
    "snedgångnasts": "snedgången",
    "snedgångne": "snedgången",
    "snedgångnes": "snedgången",
    "snedheten": "snedhet",
    "snedhetens": "snedhet",
    "snedheter": "snedhet",
    "snedheterna": "snedhet",
    "snedheternas": "snedhet",
    "snedheters": "snedhet",
    "snedhets": "snedhet",
    "snedhissar": "snedhiss",
    "snedhissarna": "snedhiss",
    "snedhissarnas": "snedhiss",
    "snedhissars": "snedhiss",
    "snedhissen": "snedhiss",
    "snedhissens": "snedhiss",
    "snedhörniga": "snedhörnig",
    "snedhörnigare": "snedhörnig",
    "snedhörnigares": "snedhörnig",
    "snedhörnigas": "snedhörnig",
    "snedhörnigast": "snedhörnig",
    "snedhörnigaste": "snedhörnig",
    "snedhörnigastes": "snedhörnig",
    "snedhörnigasts": "snedhörnig",
    "snedhörnige": "snedhörnig",
    "snedhörniges": "snedhörnig",
    "snedhörnigs": "snedhörnig",
    "snedhörnigt": "snedhörnig",
    "snedhörnigts": "snedhörnig",
    "snediga": "snedig",
    "snedigare": "snedig",
    "snedigares": "snedig",
    "snedigas": "snedig",
    "snedigast": "snedig",
    "snedigaste": "snedig",
    "snedigastes": "snedig",
    "snedigasts": "snedig",
    "snedige": "snedig",
    "snediges": "snedig",
    "snedigs": "snedig",
    "snedigt": "snedig",
    "snedigts": "snedig",
    "snedparkerad": "snedparkera",
    "snedparkerade": "snedparkera",
    "snedparkerades": "snedparkera",
    "snedparkerads": "snedparkera",
    "snedparkerande": "snedparkera",
    "snedparkeranden": "snedparkerande",
    "snedparkerandena": "snedparkerande",
    "snedparkerandenas": "snedparkerande",
    "snedparkerandens": "snedparkerande",
    "snedparkerandes": "snedparkerande",
    "snedparkerandet": "snedparkerande",
    "snedparkerandets": "snedparkerande",
    "snedparkerar": "snedparkera",
    "snedparkeras": "snedparkera",
    "snedparkerat": "snedparkera",
    "snedparkerats": "snedparkera",
    "snedparkerbara": "snedparkerbar",
    "snedparkerbarare": "snedparkerbar",
    "snedparkerbarares": "snedparkerbar",
    "snedparkerbaras": "snedparkerbar",
    "snedparkerbarast": "snedparkerbar",
    "snedparkerbaraste": "snedparkerbar",
    "snedparkerbarastes": "snedparkerbar",
    "snedparkerbarasts": "snedparkerbar",
    "snedparkerbare": "snedparkerbar",
    "snedparkerbares": "snedparkerbar",
    "snedparkerbarheten": "snedparkerbarhet",
    "snedparkerbarhetens": "snedparkerbarhet",
    "snedparkerbarhets": "snedparkerbarhet",
    "snedparkerbars": "snedparkerbar",
    "snedparkerbart": "snedparkerbar",
    "snedparkerbarts": "snedparkerbar",
    "snedparkeringar": "snedparkering",
    "snedparkeringarna": "snedparkering",
    "snedparkeringarnas": "snedparkering",
    "snedparkeringars": "snedparkering",
    "snedparkeringen": "snedparkering",
    "snedparkeringens": "snedparkering",
    "snedparkerings": "snedparkering",
    "snedprofilen": "snedprofil",
    "snedprofilens": "snedprofil",
    "snedprofiler": "snedprofil",
    "snedprofilerna": "snedprofil",
    "snedprofilernas": "snedprofil",
    "snedprofilers": "snedprofil",
    "snedprofils": "snedprofil",
    "snedrekryterad": "snedrekrytera",
    "snedrekryterade": "snedrekrytera",
    "snedrekryterades": "snedrekrytera",
    "snedrekryterads": "snedrekrytera",
    "snedrekryterande": "snedrekrytera",
    "snedrekryteranden": "snedrekryterande",
    "snedrekryterandena": "snedrekryterande",
    "snedrekryterandenas": "snedrekryterande",
    "snedrekryterandens": "snedrekryterande",
    "snedrekryterandes": "snedrekryterande",
    "snedrekryterandet": "snedrekryterande",
    "snedrekryterandets": "snedrekryterande",
    "snedrekryterar": "snedrekrytera",
    "snedrekryteras": "snedrekrytera",
    "snedrekryterat": "snedrekrytera",
    "snedrekryterats": "snedrekrytera",
    "snedrekryterbara": "snedrekryterbar",
    "snedrekryterbarare": "snedrekryterbar",
    "snedrekryterbarares": "snedrekryterbar",
    "snedrekryterbaras": "snedrekryterbar",
    "snedrekryterbarast": "snedrekryterbar",
    "snedrekryterbaraste": "snedrekryterbar",
    "snedrekryterbarastes": "snedrekryterbar",
    "snedrekryterbarasts": "snedrekryterbar",
    "snedrekryterbare": "snedrekryterbar",
    "snedrekryterbares": "snedrekryterbar",
    "snedrekryterbarheten": "snedrekryterbarhet",
    "snedrekryterbarhetens": "snedrekryterbarhet",
    "snedrekryterbarhets": "snedrekryterbarhet",
    "snedrekryterbars": "snedrekryterbar",
    "snedrekryterbart": "snedrekryterbar",
    "snedrekryterbarts": "snedrekryterbar",
    "snedrekryteringar": "snedrekrytering",
    "snedrekryteringarna": "snedrekrytering",
    "snedrekryteringarnas": "snedrekrytering",
    "snedrekryteringars": "snedrekrytering",
    "snedrekryteringen": "snedrekrytering",
    "snedrekryteringens": "snedrekrytering",
    "snedrekryterings": "snedrekrytering",
    "snedrems": "snedremsa",
    "snedremsan": "snedremsa",
    "snedremsans": "snedremsa",
    "snedremsas": "snedremsa",
    "snedremse": "snedremsa",
    "snedremsor": "snedremsa",
    "snedremsorna": "snedremsa",
    "snedremsornas": "snedremsa",
    "snedremsors": "snedremsa",
    "snedrutan": "snedruta",
    "snedrutans": "snedruta",
    "snedrutas": "snedruta",
    "snedrute": "snedruta",
    "snedrutor": "snedruta",
    "snedrutorna": "snedruta",
    "snedrutornas": "snedruta",
    "snedrutors": "snedruta",
    "snedryggen": "snedrygg",
    "snedryggens": "snedrygg",
    "snedryggs": "snedrygg",
    "sneds": "sned",
    "snedsegels": "snedsegel",
    "snedseglar": "snedseglare",
    "snedseglaren": "snedseglare",
    "snedseglarens": "snedseglare",
    "snedseglares": "snedseglare",
    "snedseglarna": "snedseglare",
    "snedseglarnas": "snedseglare",
    "snedseglen": "snedsegel",
    "snedseglens": "snedsegel",
    "snedseglet": "snedsegel",
    "snedseglets": "snedsegel",
    "snedskurens": "snedskuren",
    "snedskuret": "snedskuren",
    "snedskurets": "snedskuren",
    "snedskurna": "snedskuren",
    "snedskurnare": "snedskuren",
    "snedskurnares": "snedskuren",
    "snedskurnas": "snedskuren",
    "snedskurnast": "snedskuren",
    "snedskurnaste": "snedskuren",
    "snedskurnastes": "snedskuren",
    "snedskurnasts": "snedskuren",
    "snedskurne": "snedskuren",
    "snedskurnes": "snedskuren",
    "snedslåar": "snedslå",
    "snedslåarna": "snedslå",
    "snedslåarnas": "snedslå",
    "snedslåars": "snedslå",
    "snedslån": "snedslå",
    "snedslåns": "snedslå",
    "snedslås": "snedslå",
    "snedsprången": "snedsprång",
    "snedsprångens": "snedsprång",
    "snedsprånget": "snedsprång",
    "snedsprångets": "snedsprång",
    "snedsprångs": "snedsprång",
    "snedstegen": "snedsteg",
    "snedstegens": "snedsteg",
    "snedsteget": "snedsteg",
    "snedstegets": "snedsteg",
    "snedstegs": "snedsteg",
    "snedstrecken": "snedstreck",
    "snedstreckens": "snedstreck",
    "snedstrecket": "snedstreck",
    "snedstreckets": "snedstreck",
    "snedstrecks": "snedstreck",
    "snedställ": "snedställa",
    "snedställande": "snedställa",
    "snedställanden": "snedställande",
    "snedställandena": "snedställande",
    "snedställandenas": "snedställande",
    "snedställandens": "snedställande",
    "snedställandes": "snedställande",
    "snedställandet": "snedställande",
    "snedställandets": "snedställande",
    "snedställas": "snedställa",
    "snedställd": "snedställa",
    "snedställda": "snedställa",
    "snedställdas": "snedställa",
    "snedställde": "snedställa",
    "snedställdes": "snedställa",
    "snedställds": "snedställa",
    "snedställer": "snedställa",
    "snedställes": "snedställa",
    "snedställs": "snedställa",
    "snedställt": "snedställa",
    "snedställts": "snedställa",
    "snedtaken": "snedtak",
    "snedtakens": "snedtak",
    "snedtaket": "snedtak",
    "snedtakets": "snedtak",
    "snedtaks": "snedtak",
    "snedtrampade": "snedtrampad",
    "snedtrampades": "snedtrampad",
    "snedtrampads": "snedtrampad",
    "snedtrampat": "snedtrampad",
    "snedtrampats": "snedtrampad",
    "snedtändningar": "snedtändning",
    "snedtändningarna": "snedtändning",
    "snedtändningarnas": "snedtändning",
    "snedtändningars": "snedtändning",
    "snedtändningen": "snedtändning",
    "snedtändningens": "snedtändning",
    "snedtändnings": "snedtändning",
    "snedvinkliga": "snedvinklig",
    "snedvinkligare": "snedvinklig",
    "snedvinkligares": "snedvinklig",
    "snedvinkligas": "snedvinklig",
    "snedvinkligast": "snedvinklig",
    "snedvinkligaste": "snedvinklig",
    "snedvinkligastes": "snedvinklig",
    "snedvinkligasts": "snedvinklig",
    "snedvinklige": "snedvinklig",
    "snedvinkliges": "snedvinklig",
    "snedvinkligheten": "snedvinklighet",
    "snedvinklighetens": "snedvinklighet",
    "snedvinklighets": "snedvinklighet",
    "snedvinkligs": "snedvinklig",
    "snedvinkligt": "snedvinklig",
    "snedvinkligts": "snedvinklig",
    "snedvred": "snedvrida",
    "snedvreds": "snedvrida",
    "snedvrid": "snedvrida",
    "snedvridande": "snedvrida",
    "snedvridanden": "snedvridande",
    "snedvridandena": "snedvridande",
    "snedvridandenas": "snedvridande",
    "snedvridandens": "snedvridande",
    "snedvridandes": "snedvridande",
    "snedvridandet": "snedvridande",
    "snedvridandets": "snedvridande",
    "snedvridas": "snedvrida",
    "snedvride": "snedvrida",
    "snedvriden": "snedvrida",
    "snedvridens": "snedvrida",
    "snedvrider": "snedvrida",
    "snedvrides": "snedvrida",
    "snedvridet": "snedvrida",
    "snedvridets": "snedvrida",
    "snedvridit": "snedvrida",
    "snedvridits": "snedvrida",
    "snedvridna": "snedvrida",
    "snedvridnas": "snedvrida",
    "snedvridne": "snedvrida",
    "snedvridnes": "snedvrida",
    "snedvridningar": "snedvridning",
    "snedvridningarna": "snedvridning",
    "snedvridningarnas": "snedvridning",
    "snedvridningars": "snedvridning",
    "snedvridningen": "snedvridning",
    "snedvridningens": "snedvridning",
    "snedvridnings": "snedvridning",
    "snedvrids": "snedvrida",
    "snedögda": "snedögd",
    "snedögdare": "snedögd",
    "snedögdares": "snedögd",
    "snedögdas": "snedögd",
    "snedögdast": "snedögd",
    "snedögdaste": "snedögd",
    "snedögdastes": "snedögd",
    "snedögdasts": "snedögd",
    "snedögde": "snedögd",
    "snedögdes": "snedögd",
    "snedögdheten": "snedögdhet",
    "snedögdhetens": "snedögdhet",
    "snedögdhets": "snedögdhet",
    "snedögds": "snedögd",
    "snedögt": "snedögd",
    "snedögts": "snedögd",
    "snegel": "snegla",
    "sneglad": "snegla",
    "sneglade": "snegla",
    "sneglades": "snegla",
    "sneglads": "snegla",
    "sneglande": "snegla",
    "sneglanden": "sneglande",
    "sneglandena": "sneglande",
    "sneglandenas": "sneglande",
    "sneglandens": "sneglande",
    "sneglandes": "sneglande",
    "sneglandet": "sneglande",
    "sneglandets": "sneglande",
    "sneglar": "snegla",
    "sneglas": "snegla",
    "sneglat": "snegla",
    "sneglats": "snegla",
    "snek": "snika",
    "sneke": "snika",
    "snekes": "snika",
    "sneks": "snika",
    "snesar": "snes",
    "snesarna": "snes",
    "snesarnas": "snes",
    "snesars": "snes",
    "snesen": "snes",
    "snesens": "snes",
    "snett": "sned",
    "snetts": "sned",
    "snibbar": "snibb",
    "snibbarna": "snibb",
    "snibbarnas": "snibb",
    "snibbars": "snibb",
    "snibben": "snibb",
    "snibbens": "snibb",
    "snibbiga": "snibbig",
    "snibbigare": "snibbig",
    "snibbigares": "snibbig",
    "snibbigas": "snibbig",
    "snibbigast": "snibbig",
    "snibbigaste": "snibbig",
    "snibbigastes": "snibbig",
    "snibbigasts": "snibbig",
    "snibbige": "snibbig",
    "snibbiges": "snibbig",
    "snibbigheten": "snibbighet",
    "snibbighetens": "snibbighet",
    "snibbighets": "snibbighet",
    "snibbigs": "snibbig",
    "snibbigt": "snibbig",
    "snibbigts": "snibbig",
    "snibbs": "snibb",
    "snibbskålar": "snibbskål",
    "snibbskålarna": "snibbskål",
    "snibbskålarnas": "snibbskål",
    "snibbskålars": "snibbskål",
    "snibbskålen": "snibbskål",
    "snibbskålens": "snibbskål",
    "snibbskåls": "snibbskål",
    "snickar": "snickare",
    "snickarbälten": "snickarbälte",
    "snickarbältena": "snickarbälte",
    "snickarbältenas": "snickarbälte",
    "snickarbältens": "snickarbälte",
    "snickarbältes": "snickarbälte",
    "snickarbältet": "snickarbälte",
    "snickarbältets": "snickarbälte",
    "snickarbänkar": "snickarbänk",
    "snickarbänkarna": "snickarbänk",
    "snickarbänkarnas": "snickarbänk",
    "snickarbänkars": "snickarbänk",
    "snickarbänken": "snickarbänk",
    "snickarbänkens": "snickarbänk",
    "snickarbänks": "snickarbänk",
    "snickaren": "snickare",
    "snickarens": "snickare",
    "snickares": "snickare",
    "snickarförkläden": "snickarförkläde",
    "snickarförklädena": "snickarförkläde",
    "snickarförklädenas": "snickarförkläde",
    "snickarförklädens": "snickarförkläde",
    "snickarförklädes": "snickarförkläde",
    "snickarförklädet": "snickarförkläde",
    "snickarförklädets": "snickarförkläde",
    "snickarförkläds": "snickarförkläde",
    "snickarglädjen": "snickarglädje",
    "snickarglädjens": "snickarglädje",
    "snickarglädjes": "snickarglädje",
    "snickarna": "snickare",
    "snickarnas": "snickare",
    "snickarverkstaden": "snickarverkstad",
    "snickarverkstadens": "snickarverkstad",
    "snickarverkstads": "snickarverkstad",
    "snickarverkstan": "snickarverkstad",
    "snickarverkstans": "snickarverkstad",
    "snickarverkstäder": "snickarverkstad",
    "snickarverkstäderna": "snickarverkstad",
    "snickarverkstädernas": "snickarverkstad",
    "snickarverkstäders": "snickarverkstad",
    "snickarverktygen": "snickarverktyg",
    "snickarverktygens": "snickarverktyg",
    "snickarverktyget": "snickarverktyg",
    "snickarverktygets": "snickarverktyg",
    "snickarverktygs": "snickarverktyg",
    "snickerier": "snickeri",
    "snickerierna": "snickeri",
    "snickeriernas": "snickeri",
    "snickeriers": "snickeri",
    "snickeriet": "snickeri",
    "snickeriets": "snickeri",
    "snickerifabriken": "snickerifabrik",
    "snickerifabrikens": "snickerifabrik",
    "snickerifabriker": "snickerifabrik",
    "snickerifabrikerna": "snickerifabrik",
    "snickerifabrikernas": "snickerifabrik",
    "snickerifabrikers": "snickerifabrik",
    "snickerifabriks": "snickerifabrik",
    "snickeris": "snickeri",
    "snickerit": "snickeri",
    "snickerits": "snickeri",
    "snickrad": "snickra",
    "snickrade": "snickra",
    "snickrades": "snickra",
    "snickrads": "snickra",
    "snickrande": "snickra",
    "snickranden": "snickrande",
    "snickrandena": "snickrande",
    "snickrandenas": "snickrande",
    "snickrandens": "snickrande",
    "snickrandes": "snickrande",
    "snickrandet": "snickrande",
    "snickrandets": "snickrande",
    "snickrar": "snickra",
    "snickras": "snickra",
    "snickrat": "snickra",
    "snickrats": "snickra",
    "snicksnacket": "snicksnack",
    "snicksnackets": "snicksnack",
    "snicksnacks": "snicksnack",
    "snid": "snida",
    "snidad": "snida",
    "snidade": "snida",
    "snidades": "snida",
    "snidads": "snida",
    "snidande": "snida",
    "snidanden": "snidande",
    "snidandena": "snidande",
    "snidandenas": "snidande",
    "snidandens": "snidande",
    "snidandes": "snidande",
    "snidandet": "snidande",
    "snidandets": "snidande",
    "snidar": "snidare",
    "snidaren": "snidare",
    "snidarens": "snidare",
    "snidares": "snidare",
    "snidarna": "snidare",
    "snidarnas": "snidare",
    "snidas": "snida",
    "snidat": "snida",
    "snidats": "snida",
    "sniderier": "snideri",
    "sniderierna": "snideri",
    "snideriernas": "snideri",
    "snideriers": "snideri",
    "snideriet": "snideri",
    "snideriets": "snideri",
    "snideris": "snideri",
    "sniderit": "snideri",
    "sniderits": "snideri",
    "sniff": "sniffa",
    "sniffad": "sniffa",
    "sniffade": "sniffa",
    "sniffades": "sniffa",
    "sniffads": "sniffa",
    "sniffande": "sniffa",
    "sniffanden": "sniffande",
    "sniffandena": "sniffande",
    "sniffandenas": "sniffande",
    "sniffandens": "sniffande",
    "sniffandes": "sniffande",
    "sniffandet": "sniffande",
    "sniffandets": "sniffande",
    "sniffar": "sniffa",
    "sniffarna": "sniff",
    "sniffarnas": "sniff",
    "sniffars": "sniff",
    "sniffas": "sniffa",
    "sniffat": "sniffa",
    "sniffats": "sniffa",
    "sniffen": "sniff",
    "sniffens": "sniff",
    "sniffet": "sniff",
    "sniffets": "sniff",
    "sniffs": "sniff",
    "snigelfarten": "snigelfart",
    "snigelfartens": "snigelfart",
    "snigelfarts": "snigelfart",
    "snigelhusen": "snigelhus",
    "snigelhusens": "snigelhus",
    "snigelhuset": "snigelhus",
    "snigelhusets": "snigelhus",
    "snigeln": "snigel",
    "snigelns": "snigel",
    "snigelposten": "snigelpost",
    "snigelpostens": "snigelpost",
    "snigelposts": "snigelpost",
    "snigels": "snigel",
    "sniglar": "snigel",
    "sniglarna": "snigel",
    "sniglarnas": "snigel",
    "sniglars": "snigel",
    "snik": "snika",
    "snikande": "snika",
    "snikanden": "snikande",
    "snikandena": "snikande",
    "snikandenas": "snikande",
    "snikandens": "snikande",
    "snikandes": "snikande",
    "snikandet": "snikande",
    "snikandets": "snikande",
    "snikas": "snika",
    "snike": "snika",
    "snikens": "sniken",
    "sniker": "snika",
    "snikes": "snika",
    "sniket": "sniken",
    "snikets": "sniken",
    "snikit": "snika",
    "snikits": "snika",
    "snikna": "sniken",
    "sniknare": "sniken",
    "sniknares": "sniken",
    "sniknas": "sniken",
    "sniknast": "sniken",
    "sniknaste": "sniken",
    "sniknastes": "sniken",
    "sniknasts": "sniken",
    "snikne": "sniken",
    "sniknes": "sniken",
    "snikte": "snika",
    "sniktes": "snika",
    "snilj": "snilja",
    "sniljan": "snilja",
    "sniljans": "snilja",
    "sniljas": "snilja",
    "snilje": "snilja",
    "sniljeflossan": "sniljeflossa",
    "sniljeflossans": "sniljeflossa",
    "sniljeflossas": "sniljeflossa",
    "sniljen": "snilj",
    "sniljens": "snilj",
    "sniljer": "snilj",
    "sniljerna": "snilj",
    "sniljernas": "snilj",
    "sniljers": "snilj",
    "sniljor": "snilja",
    "sniljorna": "snilja",
    "sniljornas": "snilja",
    "sniljors": "snilja",
    "sniljs": "snilja",
    "snilleblixtar": "snilleblixt",
    "snilleblixtarna": "snilleblixt",
    "snilleblixtarnas": "snilleblixt",
    "snilleblixtars": "snilleblixt",
    "snilleblixten": "snilleblixt",
    "snilleblixtens": "snilleblixt",
    "snilleblixts": "snilleblixt",
    "snilledragen": "snilledrag",
    "snilledragens": "snilledrag",
    "snilledraget": "snilledrag",
    "snilledragets": "snilledrag",
    "snilledrags": "snilledrag",
    "snillefosterna": "snillefoster",
    "snillefosternas": "snillefoster",
    "snillefosters": "snillefoster",
    "snillefostren": "snillefoster",
    "snillefostrens": "snillefoster",
    "snillefostret": "snillefoster",
    "snillefostrets": "snillefoster",
    "snillen": "snille",
    "snillena": "snille",
    "snillenas": "snille",
    "snillens": "snille",
    "snilleproven": "snilleprov",
    "snilleprovens": "snilleprov",
    "snilleprovet": "snilleprov",
    "snilleprovets": "snilleprov",
    "snilleprovs": "snilleprov",
    "snilles": "snille",
    "snillet": "snille",
    "snillets": "snille",
    "snilleverken": "snilleverk",
    "snilleverkens": "snilleverk",
    "snilleverket": "snilleverk",
    "snilleverkets": "snilleverk",
    "snilleverks": "snilleverk",
    "snillrika": "snillrik",
    "snillrikare": "snillrik",
    "snillrikares": "snillrik",
    "snillrikas": "snillrik",
    "snillrikast": "snillrik",
    "snillrikaste": "snillrik",
    "snillrikastes": "snillrik",
    "snillrikasts": "snillrik",
    "snillrike": "snillrik",
    "snillrikes": "snillrik",
    "snillrikheten": "snillrikhet",
    "snillrikhetens": "snillrikhet",
    "snillrikheter": "snillrikhet",
    "snillrikheterna": "snillrikhet",
    "snillrikheternas": "snillrikhet",
    "snillrikheters": "snillrikhet",
    "snillrikhets": "snillrikhet",
    "snillriks": "snillrik",
    "snillrikt": "snillrik",
    "snillrikts": "snillrik",
    "snills": "snille",
    "snip": "snipa",
    "snipan": "snipa",
    "snipans": "snipa",
    "snipar": "snip",
    "sniparna": "snip",
    "sniparnas": "snip",
    "snipars": "snip",
    "snipas": "snipa",
    "snipe": "snipa",
    "snipen": "snip",
    "snipens": "snip",
    "snipiga": "snipig",
    "snipigare": "snipig",
    "snipigares": "snipig",
    "snipigas": "snipig",
    "snipigast": "snipig",
    "snipigaste": "snipig",
    "snipigastes": "snipig",
    "snipigasts": "snipig",
    "snipige": "snipig",
    "snipiges": "snipig",
    "snipigs": "snipig",
    "snipigt": "snipig",
    "snipigts": "snipig",
    "snipor": "snipa",
    "sniporna": "snipa",
    "snipornas": "snipa",
    "snipors": "snipa",
    "snipp": "snippa",
    "snippan": "snippa",
    "snippans": "snippa",
    "snippas": "snippa",
    "snippe": "snippa",
    "snippor": "snippa",
    "snipporna": "snippa",
    "snippornas": "snippa",
    "snippors": "snippa",
    "snipps": "snippa",
    "snips": "snipa",
    "snirkel": "snirkla",
    "snirkeln": "snirkel",
    "snirkelns": "snirkel",
    "snirkels": "snirkel",
    "snirklad": "snirkla",
    "snirklade": "snirkla",
    "snirklades": "snirkla",
    "snirklads": "snirkla",
    "snirklande": "snirkla",
    "snirklanden": "snirklande",
    "snirklandena": "snirklande",
    "snirklandenas": "snirklande",
    "snirklandens": "snirklande",
    "snirklandes": "snirklande",
    "snirklandet": "snirklande",
    "snirklandets": "snirklande",
    "snirklar": "snirkla",
    "snirklarna": "snirkel",
    "snirklarnas": "snirkel",
    "snirklars": "snirkel",
    "snirklas": "snirkla",
    "snirklat": "snirkla",
    "snirklats": "snirkla",
    "snirkliga": "snirklig",
    "snirkligare": "snirklig",
    "snirkligares": "snirklig",
    "snirkligas": "snirklig",
    "snirkligast": "snirklig",
    "snirkligaste": "snirklig",
    "snirkligastes": "snirklig",
    "snirkligasts": "snirklig",
    "snirklige": "snirklig",
    "snirkliges": "snirklig",
    "snirkligheten": "snirklighet",
    "snirklighetens": "snirklighet",
    "snirklighets": "snirklighet",
    "snirkligs": "snirklig",
    "snirkligt": "snirklig",
    "snirkligts": "snirklig",
    "snits": "snitsa",
    "snitsad": "snitsa",
    "snitsade": "snitsa",
    "snitsades": "snitsa",
    "snitsads": "snitsa",
    "snitsande": "snitsa",
    "snitsanden": "snitsande",
    "snitsandena": "snitsande",
    "snitsandenas": "snitsande",
    "snitsandens": "snitsande",
    "snitsandes": "snitsande",
    "snitsandet": "snitsande",
    "snitsandets": "snitsande",
    "snitsar": "snitsare",
    "snitsaren": "snitsare",
    "snitsarens": "snitsare",
    "snitsares": "snitsare",
    "snitsarna": "snitsare",
    "snitsarnas": "snitsare",
    "snitsas": "snitsa",
    "snitsat": "snitsa",
    "snitsats": "snitsa",
    "snitsel": "snitsla",
    "snitseln": "snitsel",
    "snitselns": "snitsel",
    "snitsels": "snitsel",
    "snitsen": "snits",
    "snitsens": "snits",
    "snitsiga": "snitsig",
    "snitsigare": "snitsig",
    "snitsigares": "snitsig",
    "snitsigas": "snitsig",
    "snitsigast": "snitsig",
    "snitsigaste": "snitsig",
    "snitsigastes": "snitsig",
    "snitsigasts": "snitsig",
    "snitsige": "snitsig",
    "snitsiges": "snitsig",
    "snitsigheten": "snitsighet",
    "snitsighetens": "snitsighet",
    "snitsighets": "snitsighet",
    "snitsigs": "snitsig",
    "snitsigt": "snitsig",
    "snitsigts": "snitsig",
    "snitslad": "snitsla",
    "snitslade": "snitsla",
    "snitslades": "snitsla",
    "snitslads": "snitsla",
    "snitslande": "snitsla",
    "snitslanden": "snitslande",
    "snitslandena": "snitslande",
    "snitslandenas": "snitslande",
    "snitslandens": "snitslande",
    "snitslandes": "snitslande",
    "snitslandet": "snitslande",
    "snitslandets": "snitslande",
    "snitslar": "snitsla",
    "snitslarna": "snitsel",
    "snitslarnas": "snitsel",
    "snitslars": "snitsel",
    "snitslas": "snitsla",
    "snitslat": "snitsla",
    "snitslats": "snitsla",
    "snitt": "snitta",
    "snittad": "snitta",
    "snittade": "snitta",
    "snittades": "snitta",
    "snittads": "snitta",
    "snittande": "snitta",
    "snittanden": "snittande",
    "snittandena": "snittande",
    "snittandenas": "snittande",
    "snittandens": "snittande",
    "snittandes": "snittande",
    "snittandet": "snittande",
    "snittandets": "snittande",
    "snittar": "snitta",
    "snittarna": "snitt",
    "snittarnas": "snitt",
    "snittars": "snitt",
    "snittas": "snitta",
    "snittat": "snitta",
    "snittats": "snitta",
    "snittbetygen": "snittbetyg",
    "snittbetygens": "snittbetyg",
    "snittbetyget": "snittbetyg",
    "snittbetygets": "snittbetyg",
    "snittbetygs": "snittbetyg",
    "snittblom": "snittblomma",
    "snittblomman": "snittblomma",
    "snittblommans": "snittblomma",
    "snittblommas": "snittblomma",
    "snittblomme": "snittblomma",
    "snittblommor": "snittblomma",
    "snittblommorna": "snittblomma",
    "snittblommornas": "snittblomma",
    "snittblommors": "snittblomma",
    "snittbloms": "snittblomma",
    "snitten": "snitt",
    "snittens": "snitt",
    "snittet": "snitt",
    "snittets": "snitt",
    "snittmängden": "snittmängd",
    "snittmängdens": "snittmängd",
    "snittmängder": "snittmängd",
    "snittmängderna": "snittmängd",
    "snittmängdernas": "snittmängd",
    "snittmängders": "snittmängd",
    "snittmängds": "snittmängd",
    "snitts": "snitt",
    "snittytan": "snittyta",
    "snittytans": "snittyta",
    "snittytas": "snittyta",
    "snittyte": "snittyta",
    "snittytor": "snittyta",
    "snittytorna": "snittyta",
    "snittytornas": "snittyta",
    "snittytors": "snittyta",
    "sno": "snoa",
    "snoan": "snoa",
    "snoans": "snoa",
    "snoas": "snoa",
    "snobb": "snobba",
    "snobbad": "snobba",
    "snobbade": "snobba",
    "snobbades": "snobba",
    "snobbads": "snobba",
    "snobbande": "snobba",
    "snobbanden": "snobbande",
    "snobbandena": "snobbande",
    "snobbandenas": "snobbande",
    "snobbandens": "snobbande",
    "snobbandes": "snobbande",
    "snobbandet": "snobbande",
    "snobbandets": "snobbande",
    "snobbar": "snobba",
    "snobbarna": "snobb",
    "snobbarnas": "snobb",
    "snobbars": "snobb",
    "snobbas": "snobba",
    "snobbat": "snobba",
    "snobbats": "snobba",
    "snobben": "snobb",
    "snobbens": "snobb",
    "snobberier": "snobberi",
    "snobberierna": "snobberi",
    "snobberiernas": "snobberi",
    "snobberiers": "snobberi",
    "snobberiet": "snobberi",
    "snobberiets": "snobberi",
    "snobberis": "snobberi",
    "snobberit": "snobberi",
    "snobberits": "snobberi",
    "snobbiga": "snobbig",
    "snobbigare": "snobbig",
    "snobbigares": "snobbig",
    "snobbigas": "snobbig",
    "snobbigast": "snobbig",
    "snobbigaste": "snobbig",
    "snobbigastes": "snobbig",
    "snobbigasts": "snobbig",
    "snobbige": "snobbig",
    "snobbiges": "snobbig",
    "snobbigheten": "snobbighet",
    "snobbighetens": "snobbighet",
    "snobbighets": "snobbighet",
    "snobbigs": "snobbig",
    "snobbigt": "snobbig",
    "snobbigts": "snobbig",
    "snobbismen": "snobbism",
    "snobbismens": "snobbism",
    "snobbismer": "snobbism",
    "snobbismerna": "snobbism",
    "snobbismernas": "snobbism",
    "snobbismers": "snobbism",
    "snobbisms": "snobbism",
    "snobbistiska": "snobbistisk",
    "snobbistiskare": "snobbistisk",
    "snobbistiskares": "snobbistisk",
    "snobbistiskas": "snobbistisk",
    "snobbistiskast": "snobbistisk",
    "snobbistiskaste": "snobbistisk",
    "snobbistiskastes": "snobbistisk",
    "snobbistiskasts": "snobbistisk",
    "snobbistiske": "snobbistisk",
    "snobbistiskes": "snobbistisk",
    "snobbistisks": "snobbistisk",
    "snobbistiskt": "snobbistisk",
    "snobbistiskts": "snobbistisk",
    "snobbränn": "snobbränna",
    "snobbrännan": "snobbränna",
    "snobbrännans": "snobbränna",
    "snobbrännas": "snobbränna",
    "snobbränne": "snobbränna",
    "snobbrännor": "snobbränna",
    "snobbrännorna": "snobbränna",
    "snobbrännornas": "snobbränna",
    "snobbrännors": "snobbränna",
    "snobbränns": "snobbränna",
    "snobbs": "snobb",
    "snodd": "sno",
    "snodda": "sno",
    "snoddar": "snodd",
    "snoddarna": "snodd",
    "snoddarnas": "snodd",
    "snoddars": "snodd",
    "snoddas": "sno",
    "snodde": "sno",
    "snodden": "snodd",
    "snoddens": "snodd",
    "snoddes": "sno",
    "snodds": "snodd",
    "snoe": "snoa",
    "snoende": "sno",
    "snoenden": "snoende",
    "snoendena": "snoende",
    "snoendenas": "snoende",
    "snoendens": "snoende",
    "snoendes": "snoende",
    "snoendet": "snoende",
    "snoendets": "snoende",
    "snofsiga": "snofsig",
    "snofsigare": "snofsig",
    "snofsigares": "snofsig",
    "snofsigas": "snofsig",
    "snofsigast": "snofsig",
    "snofsigaste": "snofsig",
    "snofsigastes": "snofsig",
    "snofsigasts": "snofsig",
    "snofsige": "snofsig",
    "snofsiges": "snofsig",
    "snofsigheten": "snofsighet",
    "snofsighetens": "snofsighet",
    "snofsighets": "snofsighet",
    "snofsigs": "snofsig",
    "snofsigt": "snofsig",
    "snofsigts": "snofsig",
    "snok": "snoka",
    "snokad": "snoka",
    "snokade": "snoka",
    "snokades": "snoka",
    "snokads": "snoka",
    "snokande": "snoka",
    "snokanden": "snokande",
    "snokandena": "snokande",
    "snokandenas": "snokande",
    "snokandens": "snokande",
    "snokandes": "snokande",
    "snokandet": "snokande",
    "snokandets": "snokande",
    "snokar": "snoka",
    "snokarna": "snok",
    "snokarnas": "snok",
    "snokars": "snok",
    "snokas": "snoka",
    "snokat": "snoka",
    "snokats": "snoka",
    "snoken": "snok",
    "snokens": "snok",
    "snoks": "snok",
    "snoor": "snoa",
    "snoorna": "snoa",
    "snoornas": "snoa",
    "snoors": "snoa",
    "snopens": "snopen",
    "snopet": "snopen",
    "snopets": "snopen",
    "snopna": "snopen",
    "snopnare": "snopen",
    "snopnares": "snopen",
    "snopnas": "snopen",
    "snopnast": "snopen",
    "snopnaste": "snopen",
    "snopnastes": "snopen",
    "snopnasts": "snopen",
    "snopne": "snopen",
    "snopnes": "snopen",
    "snopp": "snoppa",
    "snoppad": "snoppa",
    "snoppade": "snoppa",
    "snoppades": "snoppa",
    "snoppads": "snoppa",
    "snoppande": "snoppa",
    "snoppanden": "snoppande",
    "snoppandena": "snoppande",
    "snoppandenas": "snoppande",
    "snoppandens": "snoppande",
    "snoppandes": "snoppande",
    "snoppandet": "snoppande",
    "snoppandets": "snoppande",
    "snoppar": "snoppare",
    "snopparen": "snoppare",
    "snopparens": "snoppare",
    "snoppares": "snoppare",
    "snopparna": "snoppare",
    "snopparnas": "snoppare",
    "snoppars": "snopp",
    "snoppas": "snoppa",
    "snoppat": "snoppa",
    "snoppats": "snoppa",
    "snoppen": "snopp",
    "snoppens": "snopp",
    "snopps": "snopp",
    "snor": "snora",
    "snorad": "snora",
    "snorade": "snora",
    "snorades": "snora",
    "snorads": "snora",
    "snorande": "snora",
    "snoranden": "snorande",
    "snorandena": "snorande",
    "snorandenas": "snorande",
    "snorandens": "snorande",
    "snorandes": "snorande",
    "snorandet": "snorande",
    "snorandets": "snorande",
    "snorar": "snora",
    "snoras": "snora",
    "snorat": "snora",
    "snorats": "snora",
    "snoren": "snor",
    "snorens": "snor",
    "snoret": "snor",
    "snorets": "snor",
    "snorgersar": "snorgers",
    "snorgersarna": "snorgers",
    "snorgersarnas": "snorgers",
    "snorgersars": "snorgers",
    "snorgersen": "snorgers",
    "snorgersens": "snorgers",
    "snorgärsar": "snorgärs",
    "snorgärsarna": "snorgärs",
    "snorgärsarnas": "snorgärs",
    "snorgärsars": "snorgärs",
    "snorgärsen": "snorgärs",
    "snorgärsens": "snorgärs",
    "snoriga": "snorig",
    "snorigare": "snorig",
    "snorigares": "snorig",
    "snorigas": "snorig",
    "snorigast": "snorig",
    "snorigaste": "snorig",
    "snorigastes": "snorig",
    "snorigasts": "snorig",
    "snorige": "snorig",
    "snoriges": "snorig",
    "snorigs": "snorig",
    "snorigt": "snorig",
    "snorigts": "snorig",
    "snorkar": "snork",
    "snorkarna": "snork",
    "snorkarnas": "snork",
    "snorkars": "snork",
    "snorkeln": "snorkel",
    "snorkelns": "snorkel",
    "snorkels": "snorkel",
    "snorken": "snork",
    "snorkens": "snork",
    "snorkiga": "snorkig",
    "snorkigare": "snorkig",
    "snorkigares": "snorkig",
    "snorkigas": "snorkig",
    "snorkigast": "snorkig",
    "snorkigaste": "snorkig",
    "snorkigastes": "snorkig",
    "snorkigasts": "snorkig",
    "snorkige": "snorkig",
    "snorkiges": "snorkig",
    "snorkigheten": "snorkighet",
    "snorkighetens": "snorkighet",
    "snorkighets": "snorkighet",
    "snorkigs": "snorkig",
    "snorkigt": "snorkig",
    "snorkigts": "snorkig",
    "snorklad": "snorkla",
    "snorklade": "snorkla",
    "snorklades": "snorkla",
    "snorklads": "snorkla",
    "snorklande": "snorkla",
    "snorklanden": "snorklande",
    "snorklandena": "snorklande",
    "snorklandenas": "snorklande",
    "snorklandens": "snorklande",
    "snorklandes": "snorklande",
    "snorklandet": "snorklande",
    "snorklandets": "snorklande",
    "snorklar": "snorkla",
    "snorklarna": "snorkel",
    "snorklarnas": "snorkel",
    "snorklars": "snorkel",
    "snorklas": "snorkla",
    "snorklat": "snorkla",
    "snorklats": "snorkla",
    "snorks": "snork",
    "snorrar": "snorre",
    "snorrarna": "snorre",
    "snorrarnas": "snorre",
    "snorrars": "snorre",
    "snorren": "snorre",
    "snorrens": "snorre",
    "snorres": "snorre",
    "snors": "snor",
    "snorungar": "snorunge",
    "snorungarna": "snorunge",
    "snorungarnas": "snorunge",
    "snorungars": "snorunge",
    "snorungen": "snorunge",
    "snorungens": "snorunge",
    "snorunges": "snorunge",
    "snorvalpar": "snorvalp",
    "snorvalparna": "snorvalp",
    "snorvalparnas": "snorvalp",
    "snorvalpars": "snorvalp",
    "snorvalpen": "snorvalp",
    "snorvalpens": "snorvalp",
    "snorvalps": "snorvalp",
    "snos": "snoa",
    "snott": "sno",
    "snotts": "sno",
    "snowboarden": "snowboard",
    "snowboardens": "snowboard",
    "snowboards": "snowboard",
    "snowboardsarna": "snowboard",
    "snowboardsarnas": "snowboard",
    "snowboardsen": "snowboard",
    "snowboardsens": "snowboard",
    "snubb": "snubbe",
    "snubbad": "snubba",
    "snubbade": "snubba",
    "snubbades": "snubba",
    "snubbads": "snubba",
    "snubban": "snubba",
    "snubbande": "snubba",
    "snubbanden": "snubbande",
    "snubbandena": "snubbande",
    "snubbandenas": "snubbande",
    "snubbandens": "snubbande",
    "snubbandes": "snubbande",
    "snubbandet": "snubbande",
    "snubbandets": "snubbande",
    "snubbans": "snubba",
    "snubbar": "snubbe",
    "snubbarna": "snubbe",
    "snubbarnas": "snubbe",
    "snubbars": "snubbe",
    "snubbas": "snubba",
    "snubbat": "snubba",
    "snubbats": "snubba",
    "snubbe": "snubba",
    "snubbel": "snubbla",
    "snubbelfotade": "snubbelfotad",
    "snubbelfotades": "snubbelfotad",
    "snubbelfotads": "snubbelfotad",
    "snubbelfotat": "snubbelfotad",
    "snubbelfotats": "snubbelfotad",
    "snubbelsladdar": "snubbelsladd",
    "snubbelsladdarna": "snubbelsladd",
    "snubbelsladdarnas": "snubbelsladd",
    "snubbelsladdars": "snubbelsladd",
    "snubbelsladden": "snubbelsladd",
    "snubbelsladdens": "snubbelsladd",
    "snubbelsladds": "snubbelsladd",
    "snubbeltrådar": "snubbeltråd",
    "snubbeltrådarna": "snubbeltråd",
    "snubbeltrådarnas": "snubbeltråd",
    "snubbeltrådars": "snubbeltråd",
    "snubbeltråden": "snubbeltråd",
    "snubbeltrådens": "snubbeltråd",
    "snubbeltråds": "snubbeltråd",
    "snubben": "snubbe",
    "snubbens": "snubbe",
    "snubbes": "snubbe",
    "snubblad": "snubbla",
    "snubblade": "snubbla",
    "snubblades": "snubbla",
    "snubblads": "snubbla",
    "snubblande": "snubbla",
    "snubblanden": "snubblande",
    "snubblandena": "snubblande",
    "snubblandenas": "snubblande",
    "snubblandens": "snubblande",
    "snubblandes": "snubblande",
    "snubblandet": "snubblande",
    "snubblandets": "snubblande",
    "snubblar": "snubbla",
    "snubblas": "snubbla",
    "snubblat": "snubbla",
    "snubblats": "snubbla",
    "snubbliga": "snubblig",
    "snubbligare": "snubblig",
    "snubbligares": "snubblig",
    "snubbligas": "snubblig",
    "snubbligast": "snubblig",
    "snubbligaste": "snubblig",
    "snubbligastes": "snubblig",
    "snubbligasts": "snubblig",
    "snubblige": "snubblig",
    "snubbliges": "snubblig",
    "snubbligheten": "snubblighet",
    "snubblighetens": "snubblighet",
    "snubblighets": "snubblighet",
    "snubbligs": "snubblig",
    "snubbligt": "snubblig",
    "snubbligts": "snubblig",
    "snubbor": "snubba",
    "snubborna": "snubba",
    "snubbornas": "snubba",
    "snubbors": "snubba",
    "snubbs": "snubbe",
    "snudd": "snudda",
    "snuddad": "snudda",
    "snuddade": "snudda",
    "snuddades": "snudda",
    "snuddads": "snudda",
    "snuddande": "snudda",
    "snuddanden": "snuddande",
    "snuddandena": "snuddande",
    "snuddandenas": "snuddande",
    "snuddandens": "snuddande",
    "snuddandes": "snuddande",
    "snuddandet": "snuddande",
    "snuddandets": "snuddande",
    "snuddar": "snudda",
    "snuddarna": "snudd",
    "snuddarnas": "snudd",
    "snuddars": "snudd",
    "snuddas": "snudda",
    "snuddat": "snudda",
    "snuddats": "snudda",
    "snudden": "snudd",
    "snuddens": "snudd",
    "snudds": "snudd",
    "snudiga": "snudig",
    "snudigare": "snudig",
    "snudigares": "snudig",
    "snudigas": "snudig",
    "snudigast": "snudig",
    "snudigaste": "snudig",
    "snudigastes": "snudig",
    "snudigasts": "snudig",
    "snudige": "snudig",
    "snudiges": "snudig",
    "snudigs": "snudig",
    "snudigt": "snudig",
    "snudigts": "snudig",
    "snugg": "snugga",
    "snuggan": "snugga",
    "snuggans": "snugga",
    "snuggas": "snugga",
    "snugge": "snugga",
    "snuggor": "snugga",
    "snuggorna": "snugga",
    "snuggornas": "snugga",
    "snuggors": "snugga",
    "snuggs": "snugga",
    "snulter": "snultra",
    "snultran": "snultra",
    "snultrans": "snultra",
    "snultras": "snultra",
    "snultre": "snultra",
    "snultror": "snultra",
    "snultrorna": "snultra",
    "snultrornas": "snultra",
    "snultrors": "snultra",
    "snurr": "snurra",
    "snurrad": "snurra",
    "snurrade": "snurra",
    "snurrades": "snurra",
    "snurrads": "snurra",
    "snurran": "snurra",
    "snurrande": "snurra",
    "snurranden": "snurrande",
    "snurrandena": "snurrande",
    "snurrandenas": "snurrande",
    "snurrandens": "snurrande",
    "snurrandes": "snurrande",
    "snurrandet": "snurrande",
    "snurrandets": "snurrande",
    "snurrans": "snurra",
    "snurrar": "snurra",
    "snurras": "snurra",
    "snurrat": "snurra",
    "snurrats": "snurra",
    "snurre": "snurra",
    "snurrefiskes": "snurrefiske",
    "snurrefisket": "snurrefiske",
    "snurrefiskets": "snurrefiske",
    "snurren": "snurr",
    "snurrens": "snurr",
    "snurrevadar": "snurrevad",
    "snurrevadarna": "snurrevad",
    "snurrevadarnas": "snurrevad",
    "snurrevadars": "snurrevad",
    "snurrevaden": "snurrevad",
    "snurrevadens": "snurrevad",
    "snurrevads": "snurrevad",
    "snurrfåtöljen": "snurrfåtölj",
    "snurrfåtöljens": "snurrfåtölj",
    "snurrfåtöljer": "snurrfåtölj",
    "snurrfåtöljerna": "snurrfåtölj",
    "snurrfåtöljernas": "snurrfåtölj",
    "snurrfåtöljers": "snurrfåtölj",
    "snurrfåtöljs": "snurrfåtölj",
    "snurriga": "snurrig",
    "snurrigare": "snurrig",
    "snurrigares": "snurrig",
    "snurrigas": "snurrig",
    "snurrigast": "snurrig",
    "snurrigaste": "snurrig",
    "snurrigastes": "snurrig",
    "snurrigasts": "snurrig",
    "snurrige": "snurrig",
    "snurriges": "snurrig",
    "snurrigheten": "snurrighet",
    "snurrighetens": "snurrighet",
    "snurrigheter": "snurrighet",
    "snurrigheterna": "snurrighet",
    "snurrigheternas": "snurrighet",
    "snurrigheters": "snurrighet",
    "snurrighets": "snurrighet",
    "snurrigs": "snurrig",
    "snurrigt": "snurrig",
    "snurrigts": "snurrig",
    "snurror": "snurra",
    "snurrorna": "snurra",
    "snurrornas": "snurra",
    "snurrors": "snurra",
    "snurrs": "snurra",
    "snurrstolar": "snurrstol",
    "snurrstolarna": "snurrstol",
    "snurrstolarnas": "snurrstol",
    "snurrstolars": "snurrstol",
    "snurrstolen": "snurrstol",
    "snurrstolens": "snurrstol",
    "snurrstols": "snurrstol",
    "snus": "snusa",
    "snusad": "snusa",
    "snusade": "snusa",
    "snusades": "snusa",
    "snusads": "snusa",
    "snusande": "snusa",
    "snusanden": "snusande",
    "snusandena": "snusande",
    "snusandenas": "snusande",
    "snusandens": "snusande",
    "snusandes": "snusande",
    "snusandet": "snusande",
    "snusandets": "snusande",
    "snusar": "snusa",
    "snusas": "snusa",
    "snusat": "snusa",
    "snusats": "snusa",
    "snusbruna": "snusbrun",
    "snusbrunare": "snusbrun",
    "snusbrunares": "snusbrun",
    "snusbrunas": "snusbrun",
    "snusbrunast": "snusbrun",
    "snusbrunaste": "snusbrun",
    "snusbrunastes": "snusbrun",
    "snusbrunasts": "snusbrun",
    "snusbrune": "snusbrun",
    "snusbrunes": "snusbrun",
    "snusbruns": "snusbrun",
    "snusbrunt": "snusbrun",
    "snusbrunts": "snusbrun",
    "snusdos": "snusdosa",
    "snusdosan": "snusdosa",
    "snusdosans": "snusdosa",
    "snusdosas": "snusdosa",
    "snusdose": "snusdosa",
    "snusdosor": "snusdosa",
    "snusdosorna": "snusdosa",
    "snusdosornas": "snusdosa",
    "snusdosors": "snusdosa",
    "snuser": "snus",
    "snuserna": "snus",
    "snusernas": "snus",
    "snusers": "snus",
    "snuset": "snus",
    "snusets": "snus",
    "snusförnuftet": "snusförnuft",
    "snusförnuftets": "snusförnuft",
    "snusförnuftiga": "snusförnuftig",
    "snusförnuftigare": "snusförnuftig",
    "snusförnuftigares": "snusförnuftig",
    "snusförnuftigas": "snusförnuftig",
    "snusförnuftigast": "snusförnuftig",
    "snusförnuftigaste": "snusförnuftig",
    "snusförnuftigastes": "snusförnuftig",
    "snusförnuftigasts": "snusförnuftig",
    "snusförnuftige": "snusförnuftig",
    "snusförnuftiges": "snusförnuftig",
    "snusförnuftigheten": "snusförnuftighet",
    "snusförnuftighetens": "snusförnuftighet",
    "snusförnuftighets": "snusförnuftighet",
    "snusförnuftigs": "snusförnuftig",
    "snusförnuftigt": "snusförnuftig",
    "snusförnuftigts": "snusförnuftig",
    "snusförnufts": "snusförnuft",
    "snusgubb": "snusgubbe",
    "snusgubbar": "snusgubbe",
    "snusgubbarna": "snusgubbe",
    "snusgubbarnas": "snusgubbe",
    "snusgubbars": "snusgubbe",
    "snusgubben": "snusgubbe",
    "snusgubbens": "snusgubbe",
    "snusgubbes": "snusgubbe",
    "snusgubbs": "snusgubbe",
    "snusiga": "snusig",
    "snusigare": "snusig",
    "snusigares": "snusig",
    "snusigas": "snusig",
    "snusigast": "snusig",
    "snusigaste": "snusig",
    "snusigastes": "snusig",
    "snusigasts": "snusig",
    "snusige": "snusig",
    "snusiges": "snusig",
    "snusigs": "snusig",
    "snusigt": "snusig",
    "snusigts": "snusig",
    "snusk": "snuska",
    "snuskad": "snuska",
    "snuskade": "snuska",
    "snuskades": "snuska",
    "snuskads": "snuska",
    "snuskande": "snuska",
    "snuskanden": "snuskande",
    "snuskandena": "snuskande",
    "snuskandenas": "snuskande",
    "snuskandens": "snuskande",
    "snuskandes": "snuskande",
    "snuskandet": "snuskande",
    "snuskandets": "snuskande",
    "snuskar": "snusker",
    "snuskarna": "snusker",
    "snuskarnas": "snusker",
    "snuskars": "snusker",
    "snuskas": "snuska",
    "snuskat": "snuska",
    "snuskats": "snuska",
    "snuskern": "snusker",
    "snuskerns": "snusker",
    "snuskers": "snusker",
    "snusket": "snusk",
    "snuskets": "snusk",
    "snuskhummern": "snuskhummer",
    "snuskhummerns": "snuskhummer",
    "snuskhummers": "snuskhummer",
    "snuskhumrar": "snuskhummer",
    "snuskhumrarna": "snuskhummer",
    "snuskhumrarnas": "snuskhummer",
    "snuskhumrars": "snuskhummer",
    "snuskiga": "snuskig",
    "snuskigare": "snuskig",
    "snuskigares": "snuskig",
    "snuskigas": "snuskig",
    "snuskigast": "snuskig",
    "snuskigaste": "snuskig",
    "snuskigastes": "snuskig",
    "snuskigasts": "snuskig",
    "snuskige": "snuskig",
    "snuskiges": "snuskig",
    "snuskigheten": "snuskighet",
    "snuskighetens": "snuskighet",
    "snuskigheter": "snuskighet",
    "snuskigheterna": "snuskighet",
    "snuskigheternas": "snuskighet",
    "snuskigheters": "snuskighet",
    "snuskighets": "snuskighet",
    "snuskigs": "snuskig",
    "snuskigt": "snuskig",
    "snuskigts": "snuskig",
    "snuskpell": "snuskpelle",
    "snuskpellar": "snuskpelle",
    "snuskpellarna": "snuskpelle",
    "snuskpellarnas": "snuskpelle",
    "snuskpellars": "snuskpelle",
    "snuskpellen": "snuskpelle",
    "snuskpellens": "snuskpelle",
    "snuskpelles": "snuskpelle",
    "snuskpells": "snuskpelle",
    "snuskrar": "snusker",
    "snuskrarna": "snusker",
    "snuskrarnas": "snusker",
    "snuskrars": "snusker",
    "snusks": "snusk",
    "snusmal": "snusmala",
    "snusmalande": "snusmala",
    "snusmalanden": "snusmalande",
    "snusmalandena": "snusmalande",
    "snusmalandenas": "snusmalande",
    "snusmalandens": "snusmalande",
    "snusmalandes": "snusmalande",
    "snusmalandet": "snusmalande",
    "snusmalandets": "snusmalande",
    "snusmalas": "snusmala",
    "snusmald": "snusmala",
    "snusmalda": "snusmala",
    "snusmaldas": "snusmala",
    "snusmalde": "snusmala",
    "snusmaldes": "snusmala",
    "snusmalds": "snusmala",
    "snusmalen": "snusmala",
    "snusmalens": "snusmala",
    "snusmales": "snusmala",
    "snusmalet": "snusmala",
    "snusmalets": "snusmala",
    "snusmalna": "snusmala",
    "snusmalnas": "snusmala",
    "snusmalne": "snusmala",
    "snusmalnes": "snusmala",
    "snusmals": "snusmala",
    "snusmalt": "snusmala",
    "snusmalts": "snusmala",
    "snusmumrikar": "snusmumrik",
    "snusmumrikarna": "snusmumrik",
    "snusmumrikarnas": "snusmumrik",
    "snusmumrikars": "snusmumrik",
    "snusmumriken": "snusmumrik",
    "snusmumrikens": "snusmumrik",
    "snusmumriks": "snusmumrik",
    "snusnäsdukar": "snusnäsduk",
    "snusnäsdukarna": "snusnäsduk",
    "snusnäsdukarnas": "snusnäsduk",
    "snusnäsdukars": "snusnäsduk",
    "snusnäsduken": "snusnäsduk",
    "snusnäsdukens": "snusnäsduk",
    "snusnäsduks": "snusnäsduk",
    "snustorra": "snustorr",
    "snustorrare": "snustorr",
    "snustorrares": "snustorr",
    "snustorras": "snustorr",
    "snustorrast": "snustorr",
    "snustorraste": "snustorr",
    "snustorrastes": "snustorr",
    "snustorrasts": "snustorr",
    "snustorre": "snustorr",
    "snustorres": "snustorr",
    "snustorrheten": "snustorrhet",
    "snustorrhetens": "snustorrhet",
    "snustorrhets": "snustorrhet",
    "snustorrs": "snustorr",
    "snustorrt": "snustorr",
    "snustorrts": "snustorr",
    "snutar": "snut",
    "snutarna": "snut",
    "snutarnas": "snut",
    "snutars": "snut",
    "snuten": "snyta",
    "snutens": "snyta",
    "snutet": "snyta",
    "snutets": "snyta",
    "snutfagerheten": "snutfagerhet",
    "snutfagerhetens": "snutfagerhet",
    "snutfagerhets": "snutfagerhet",
    "snutfagers": "snutfager",
    "snutfagert": "snutfager",
    "snutfagerts": "snutfager",
    "snutfagra": "snutfager",
    "snutfagrare": "snutfager",
    "snutfagrares": "snutfager",
    "snutfagras": "snutfager",
    "snutfagrast": "snutfager",
    "snutfagraste": "snutfager",
    "snutfagrastes": "snutfager",
    "snutfagrasts": "snutfager",
    "snutfagre": "snutfager",
    "snutfagres": "snutfager",
    "snuthäckar": "snuthäck",
    "snuthäckarna": "snuthäck",
    "snuthäckarnas": "snuthäck",
    "snuthäckars": "snuthäck",
    "snuthäcken": "snuthäck",
    "snuthäckens": "snuthäck",
    "snuthäcks": "snuthäck",
    "snutit": "snyta",
    "snutits": "snyta",
    "snutkollegan": "snutkollega",
    "snutkollegans": "snutkollega",
    "snutkollegas": "snutkollega",
    "snutkolleger": "snutkollega",
    "snutkollegerna": "snutkollega",
    "snutkollegernas": "snutkollega",
    "snutkollegers": "snutkollega",
    "snutkollegor": "snutkollega",
    "snutkollegorna": "snutkollega",
    "snutkollegornas": "snutkollega",
    "snutkollegors": "snutkollega",
    "snutna": "snyta",
    "snutnas": "snyta",
    "snutne": "snyta",
    "snutnes": "snyta",
    "snuts": "snut",
    "snuttar": "snutt",
    "snuttarna": "snutt",
    "snuttarnas": "snutt",
    "snuttars": "snutt",
    "snuttefiltar": "snuttefilt",
    "snuttefiltarna": "snuttefilt",
    "snuttefiltarnas": "snuttefilt",
    "snuttefiltars": "snuttefilt",
    "snuttefilten": "snuttefilt",
    "snuttefiltens": "snuttefilt",
    "snuttefilts": "snuttefilt",
    "snutten": "snutt",
    "snuttens": "snutt",
    "snutts": "snutt",
    "snuv": "snuva",
    "snuvad": "snuva",
    "snuvade": "snuva",
    "snuvades": "snuva",
    "snuvads": "snuva",
    "snuvan": "snuva",
    "snuvande": "snuva",
    "snuvanden": "snuvande",
    "snuvandena": "snuvande",
    "snuvandenas": "snuvande",
    "snuvandens": "snuvande",
    "snuvandes": "snuvande",
    "snuvandet": "snuvande",
    "snuvandets": "snuvande",
    "snuvans": "snuva",
    "snuvar": "snuva",
    "snuvas": "snuva",
    "snuvat": "snuva",
    "snuvats": "snuva",
    "snuviga": "snuvig",
    "snuvigare": "snuvig",
    "snuvigares": "snuvig",
    "snuvigas": "snuvig",
    "snuvigast": "snuvig",
    "snuvigaste": "snuvig",
    "snuvigastes": "snuvig",
    "snuvigasts": "snuvig",
    "snuvige": "snuvig",
    "snuviges": "snuvig",
    "snuvigs": "snuvig",
    "snuvigt": "snuvig",
    "snuvigts": "snuvig",
    "snyft": "snyfta",
    "snyftad": "snyfta",
    "snyftade": "snyfta",
    "snyftades": "snyfta",
    "snyftads": "snyfta",
    "snyftande": "snyfta",
    "snyftanden": "snyftande",
    "snyftandena": "snyftande",
    "snyftandenas": "snyftande",
    "snyftandens": "snyftande",
    "snyftandes": "snyftande",
    "snyftandet": "snyftande",
    "snyftandets": "snyftande",
    "snyftar": "snyfta",
    "snyftas": "snyfta",
    "snyftat": "snyfta",
    "snyftats": "snyfta",
    "snyften": "snyft",
    "snyftens": "snyft",
    "snyftet": "snyft",
    "snyftets": "snyft",
    "snyftningar": "snyftning",
    "snyftningarna": "snyftning",
    "snyftningarnas": "snyftning",
    "snyftningars": "snyftning",
    "snyftningen": "snyftning",
    "snyftningens": "snyftning",
    "snyftnings": "snyftning",
    "snyftreportagen": "snyftreportage",
    "snyftreportagens": "snyftreportage",
    "snyftreportages": "snyftreportage",
    "snyftreportaget": "snyftreportage",
    "snyftreportagets": "snyftreportage",
    "snyfts": "snyft",
    "snyftventilen": "snyftventil",
    "snyftventilens": "snyftventil",
    "snyftventiler": "snyftventil",
    "snyftventilerna": "snyftventil",
    "snyftventilernas": "snyftventil",
    "snyftventilers": "snyftventil",
    "snyftventils": "snyftventil",
    "snygga": "snygg",
    "snyggare": "snygg",
    "snyggares": "snygg",
    "snyggas": "snygg",
    "snyggast": "snygg",
    "snyggaste": "snygg",
    "snyggastes": "snygg",
    "snyggasts": "snygg",
    "snygge": "snygg",
    "snygges": "snygg",
    "snyggheten": "snygghet",
    "snygghetens": "snygghet",
    "snygghets": "snygghet",
    "snyggingar": "snygging",
    "snyggingarna": "snygging",
    "snyggingarnas": "snygging",
    "snyggingars": "snygging",
    "snyggingen": "snygging",
    "snyggingens": "snygging",
    "snyggings": "snygging",
    "snyggman": "snyggma",
    "snyggmans": "snyggma",
    "snyggmas": "snyggma",
    "snyggs": "snygg",
    "snyggt": "snygg",
    "snyggts": "snygg",
    "snylt": "snylta",
    "snyltad": "snylta",
    "snyltade": "snylta",
    "snyltades": "snylta",
    "snyltads": "snylta",
    "snyltande": "snylta",
    "snyltanden": "snyltande",
    "snyltandena": "snyltande",
    "snyltandenas": "snyltande",
    "snyltandens": "snyltande",
    "snyltandes": "snyltande",
    "snyltandet": "snyltande",
    "snyltandets": "snyltande",
    "snyltar": "snyltare",
    "snyltaren": "snyltare",
    "snyltarens": "snyltare",
    "snyltares": "snyltare",
    "snyltarna": "snyltare",
    "snyltarnas": "snyltare",
    "snyltas": "snylta",
    "snyltat": "snylta",
    "snyltats": "snylta",
    "snyltbien": "snyltbi",
    "snyltbiens": "snyltbi",
    "snyltbiet": "snyltbi",
    "snyltbiets": "snyltbi",
    "snyltbin": "snyltbi",
    "snyltbina": "snyltbi",
    "snyltbinas": "snyltbi",
    "snyltbins": "snyltbi",
    "snyltbis": "snyltbi",
    "snyltbit": "snyltbi",
    "snyltbits": "snyltbi",
    "snyltgästen": "snyltgäst",
    "snyltgästens": "snyltgäst",
    "snyltgäster": "snyltgäst",
    "snyltgästerna": "snyltgäst",
    "snyltgästernas": "snyltgäst",
    "snyltgästers": "snyltgäst",
    "snyltgästs": "snyltgäst",
    "snyltroten": "snyltrot",
    "snyltrotens": "snyltrot",
    "snyltrots": "snyltrot",
    "snyltväxten": "snyltväxt",
    "snyltväxtens": "snyltväxt",
    "snyltväxter": "snyltväxt",
    "snyltväxterna": "snyltväxt",
    "snyltväxternas": "snyltväxt",
    "snyltväxters": "snyltväxt",
    "snyltväxts": "snyltväxt",
    "snyt": "snyta",
    "snytande": "snyta",
    "snytanden": "snytande",
    "snytandena": "snytande",
    "snytandenas": "snytande",
    "snytandens": "snytande",
    "snytandes": "snytande",
    "snytandet": "snytande",
    "snytandets": "snytande",
    "snytas": "snyta",
    "snytbagg": "snytbagge",
    "snytbaggar": "snytbagge",
    "snytbaggarna": "snytbagge",
    "snytbaggarnas": "snytbagge",
    "snytbaggars": "snytbagge",
    "snytbaggen": "snytbagge",
    "snytbaggens": "snytbagge",
    "snytbagges": "snytbagge",
    "snytbaggs": "snytbagge",
    "snyte": "snyta",
    "snyten": "snyte",
    "snytena": "snyte",
    "snytenas": "snyte",
    "snytens": "snyte",
    "snyter": "snyta",
    "snytes": "snyte",
    "snytet": "snyte",
    "snytets": "snyte",
    "snytingar": "snyting",
    "snytingarna": "snyting",
    "snytingarnas": "snyting",
    "snytingars": "snyting",
    "snytingen": "snyting",
    "snytingens": "snyting",
    "snytings": "snyting",
    "snyts": "snyte",
    "snäck": "snäcka",
    "snäckan": "snäcka",
    "snäckans": "snäcka",
    "snäckarten": "snäckart",
    "snäckartens": "snäckart",
    "snäckarter": "snäckart",
    "snäckarterna": "snäckart",
    "snäckarternas": "snäckart",
    "snäckarters": "snäckart",
    "snäckarts": "snäckart",
    "snäckas": "snäcka",
    "snäckdjuren": "snäckdjur",
    "snäckdjurens": "snäckdjur",
    "snäckdjuret": "snäckdjur",
    "snäckdjurets": "snäckdjur",
    "snäckdjurs": "snäckdjur",
    "snäcke": "snäcka",
    "snäckhjulen": "snäckhjul",
    "snäckhjulens": "snäckhjul",
    "snäckhjulet": "snäckhjul",
    "snäckhjulets": "snäckhjul",
    "snäckhjuls": "snäckhjul",
    "snäckhusen": "snäckhus",
    "snäckhusens": "snäckhus",
    "snäckhuset": "snäckhus",
    "snäckhusets": "snäckhus",
    "snäckmärgeln": "snäckmärgel",
    "snäckmärgelns": "snäckmärgel",
    "snäckmärgels": "snäckmärgel",
    "snäckor": "snäcka",
    "snäckorna": "snäcka",
    "snäckornas": "snäcka",
    "snäckors": "snäcka",
    "snäcks": "snäcka",
    "snäckskalen": "snäckskal",
    "snäckskalens": "snäckskal",
    "snäckskalet": "snäckskal",
    "snäckskalets": "snäckskal",
    "snäckskals": "snäckskal",
    "snäckskruvar": "snäckskruv",
    "snäckskruvarna": "snäckskruv",
    "snäckskruvarnas": "snäckskruv",
    "snäckskruvars": "snäckskruv",
    "snäckskruven": "snäckskruv",
    "snäckskruvens": "snäckskruv",
    "snäckskruvs": "snäckskruv",
    "snäckväxeln": "snäckväxel",
    "snäckväxelns": "snäckväxel",
    "snäckväxels": "snäckväxel",
    "snäckväxlar": "snäckväxel",
    "snäckväxlarna": "snäckväxel",
    "snäckväxlarnas": "snäckväxel",
    "snäckväxlars": "snäckväxel",
    "snälla": "snäll",
    "snällare": "snäll",
    "snällares": "snäll",
    "snällas": "snäll",
    "snällast": "snäll",
    "snällaste": "snäll",
    "snällastes": "snäll",
    "snällasts": "snäll",
    "snälle": "snäll",
    "snälles": "snäll",
    "snällheten": "snällhet",
    "snällhetens": "snällhet",
    "snällheter": "snällhet",
    "snällheterna": "snällhet",
    "snällheternas": "snällhet",
    "snällheters": "snällhet",
    "snällhets": "snällhet",
    "snällhetsguruer": "snällhetsguru",
    "snällhetsguruerna": "snällhetsguru",
    "snällhetsguruernas": "snällhetsguru",
    "snällhetsguruers": "snällhetsguru",
    "snällhetsgurun": "snällhetsguru",
    "snällhetsguruns": "snällhetsguru",
    "snällhetsgurus": "snällhetsguru",
    "snällhetsgurusarna": "snällhetsguru",
    "snällhetsgurusarnas": "snällhetsguru",
    "snällodet": "snällod",
    "snällodets": "snällod",
    "snällods": "snällod",
    "snälls": "snäll",
    "snällt": "snäll",
    "snällts": "snäll",
    "snälltågen": "snälltåg",
    "snälltågens": "snälltåg",
    "snälltåget": "snälltåg",
    "snälltågets": "snälltåg",
    "snälltågs": "snälltåg",
    "snäpp": "snäppa",
    "snäppan": "snäppa",
    "snäppande": "snäppa",
    "snäppanden": "snäppande",
    "snäppandena": "snäppande",
    "snäppandenas": "snäppande",
    "snäppandens": "snäppande",
    "snäppandes": "snäppande",
    "snäppandet": "snäppande",
    "snäppandets": "snäppande",
    "snäppans": "snäppa",
    "snäppas": "snäppa",
    "snäppe": "snäppa",
    "snäppen": "snäpp",
    "snäppens": "snäpp",
    "snäpper": "snäppa",
    "snäppes": "snäppa",
    "snäppet": "snäpp",
    "snäppets": "snäpp",
    "snäppfågeln": "snäppfågel",
    "snäppfågelns": "snäppfågel",
    "snäppfågels": "snäppfågel",
    "snäppfåglar": "snäppfågel",
    "snäppfåglarna": "snäppfågel",
    "snäppfåglarnas": "snäppfågel",
    "snäppfåglars": "snäppfågel",
    "snäpplocken": "snäpplock",
    "snäpplockens": "snäpplock",
    "snäpplocket": "snäpplock",
    "snäpplockets": "snäpplock",
    "snäpplocks": "snäpplock",
    "snäpplåsen": "snäpplås",
    "snäpplåsens": "snäpplås",
    "snäpplåset": "snäpplås",
    "snäpplåsets": "snäpplås",
    "snäppor": "snäppa",
    "snäpporna": "snäppa",
    "snäppornas": "snäppa",
    "snäppors": "snäppa",
    "snäpps": "snäppa",
    "snäppt": "snäppa",
    "snäppta": "snäppa",
    "snäpptas": "snäppa",
    "snäppte": "snäppa",
    "snäpptes": "snäppa",
    "snäppts": "snäppa",
    "snärj": "snärja",
    "snärjan": "snärja",
    "snärjande": "snärja",
    "snärjanden": "snärjande",
    "snärjandena": "snärjande",
    "snärjandenas": "snärjande",
    "snärjandens": "snärjande",
    "snärjandes": "snärjande",
    "snärjandet": "snärjande",
    "snärjandets": "snärjande",
    "snärjans": "snärja",
    "snärjas": "snärja",
    "snärjd": "snärja",
    "snärjda": "snärja",
    "snärjdas": "snärja",
    "snärjde": "snärja",
    "snärjdes": "snärja",
    "snärjds": "snärja",
    "snärjen": "snärje",
    "snärjena": "snärje",
    "snärjenas": "snärje",
    "snärjens": "snärje",
    "snärjer": "snärja",
    "snärjes": "snärje",
    "snärjet": "snärje",
    "snärjets": "snärje",
    "snärjgräset": "snärjgräs",
    "snärjgräsets": "snärjgräs",
    "snärjiga": "snärjig",
    "snärjigare": "snärjig",
    "snärjigares": "snärjig",
    "snärjigas": "snärjig",
    "snärjigast": "snärjig",
    "snärjigaste": "snärjig",
    "snärjigastes": "snärjig",
    "snärjigasts": "snärjig",
    "snärjige": "snärjig",
    "snärjiges": "snärjig",
    "snärjigheten": "snärjighet",
    "snärjighetens": "snärjighet",
    "snärjighets": "snärjighet",
    "snärjigs": "snärjig",
    "snärjigt": "snärjig",
    "snärjigts": "snärjig",
    "snärjmår": "snärjmåra",
    "snärjmåran": "snärjmåra",
    "snärjmårans": "snärjmåra",
    "snärjmåras": "snärjmåra",
    "snärjmåre": "snärjmåra",
    "snärjmåror": "snärjmåra",
    "snärjmårorna": "snärjmåra",
    "snärjmårornas": "snärjmåra",
    "snärjmårors": "snärjmåra",
    "snärjmårs": "snärjmåra",
    "snärjs": "snärje",
    "snärjt": "snärja",
    "snärjts": "snärja",
    "snärjvävnaden": "snärjvävnad",
    "snärjvävnadens": "snärjvävnad",
    "snärjvävnader": "snärjvävnad",
    "snärjvävnaderna": "snärjvävnad",
    "snärjvävnadernas": "snärjvävnad",
    "snärjvävnaders": "snärjvävnad",
    "snärjvävnads": "snärjvävnad",
    "snärp": "snärpa",
    "snärpan": "snärpa",
    "snärpande": "snärpa",
    "snärpanden": "snärpande",
    "snärpandena": "snärpande",
    "snärpandenas": "snärpande",
    "snärpandens": "snärpande",
    "snärpandes": "snärpande",
    "snärpandet": "snärpande",
    "snärpandets": "snärpande",
    "snärpans": "snärpa",
    "snärpas": "snärpa",
    "snärpe": "snärpa",
    "snärpen": "snärp",
    "snärpens": "snärp",
    "snärper": "snärpa",
    "snärpes": "snärpa",
    "snärpet": "snärp",
    "snärpets": "snärp",
    "snärpor": "snärpa",
    "snärporna": "snärpa",
    "snärpornas": "snärpa",
    "snärpors": "snärpa",
    "snärps": "snärpa",
    "snärpt": "snärpa",
    "snärpta": "snärpa",
    "snärptas": "snärpa",
    "snärpte": "snärpa",
    "snärptes": "snärpa",
    "snärpts": "snärpa",
    "snärt": "snärta",
    "snärtad": "snärta",
    "snärtade": "snärta",
    "snärtades": "snärta",
    "snärtads": "snärta",
    "snärtan": "snärta",
    "snärtande": "snärta",
    "snärtanden": "snärtande",
    "snärtandena": "snärtande",
    "snärtandenas": "snärtande",
    "snärtandens": "snärtande",
    "snärtandes": "snärtande",
    "snärtandet": "snärtande",
    "snärtandets": "snärtande",
    "snärtans": "snärta",
    "snärtar": "snärta",
    "snärtarna": "snärt",
    "snärtarnas": "snärt",
    "snärtars": "snärt",
    "snärtas": "snärta",
    "snärtat": "snärta",
    "snärtats": "snärta",
    "snärte": "snärta",
    "snärten": "snärt",
    "snärtens": "snärt",
    "snärtiga": "snärtig",
    "snärtigare": "snärtig",
    "snärtigares": "snärtig",
    "snärtigas": "snärtig",
    "snärtigast": "snärtig",
    "snärtigaste": "snärtig",
    "snärtigastes": "snärtig",
    "snärtigasts": "snärtig",
    "snärtige": "snärtig",
    "snärtiges": "snärtig",
    "snärtigheten": "snärtighet",
    "snärtighetens": "snärtighet",
    "snärtighets": "snärtighet",
    "snärtigs": "snärtig",
    "snärtigt": "snärtig",
    "snärtigts": "snärtig",
    "snärtor": "snärta",
    "snärtorna": "snärta",
    "snärtornas": "snärta",
    "snärtors": "snärta",
    "snärts": "snärta",
    "snäs": "snäsa",
    "snäsan": "snäsa",
    "snäsande": "snäsa",
    "snäsanden": "snäsande",
    "snäsandena": "snäsande",
    "snäsandenas": "snäsande",
    "snäsandens": "snäsande",
    "snäsandes": "snäsande",
    "snäsandet": "snäsande",
    "snäsandets": "snäsande",
    "snäsans": "snäsa",
    "snäsas": "snäsa",
    "snäse": "snäsa",
    "snäser": "snäsa",
    "snäses": "snäsa",
    "snäsiga": "snäsig",
    "snäsigare": "snäsig",
    "snäsigares": "snäsig",
    "snäsigas": "snäsig",
    "snäsigast": "snäsig",
    "snäsigaste": "snäsig",
    "snäsigastes": "snäsig",
    "snäsigasts": "snäsig",
    "snäsige": "snäsig",
    "snäsiges": "snäsig",
    "snäsigs": "snäsig",
    "snäsigt": "snäsig",
    "snäsigts": "snäsig",
    "snäsor": "snäsa",
    "snäsorna": "snäsa",
    "snäsornas": "snäsa",
    "snäsors": "snäsa",
    "snäst": "snäsa",
    "snästa": "snäsa",
    "snästas": "snäsa",
    "snäste": "snäsa",
    "snästes": "snäsa",
    "snästs": "snäsa",
    "snäv": "snäva",
    "snäva": "snäv",
    "snävad": "snäva",
    "snävade": "snäva",
    "snävades": "snäva",
    "snävads": "snäva",
    "snävande": "snäva",
    "snävanden": "snävande",
    "snävandena": "snävande",
    "snävandenas": "snävande",
    "snävandens": "snävande",
    "snävandes": "snävande",
    "snävandet": "snävande",
    "snävandets": "snävande",
    "snävar": "snäva",
    "snävare": "snäv",
    "snävares": "snäv",
    "snävas": "snäva",
    "snävast": "snäv",
    "snävaste": "snäv",
    "snävastes": "snäv",
    "snävasts": "snäv",
    "snävat": "snäva",
    "snävats": "snäva",
    "snäve": "snäv",
    "snäves": "snäv",
    "snävheten": "snävhet",
    "snävhetens": "snävhet",
    "snävhets": "snävhet",
    "snävs": "snäv",
    "snävt": "snäv",
    "snävts": "snäv",
    "snål": "snåla",
    "snåla": "snål",
    "snålad": "snåla",
    "snålade": "snåla",
    "snålades": "snåla",
    "snålads": "snåla",
    "snålande": "snåla",
    "snålanden": "snålande",
    "snålandena": "snålande",
    "snålandenas": "snålande",
    "snålandens": "snålande",
    "snålandes": "snålande",
    "snålandet": "snålande",
    "snålandets": "snålande",
    "snålar": "snåla",
    "snålare": "snål",
    "snålares": "snål",
    "snålas": "snåla",
    "snålast": "snål",
    "snålaste": "snål",
    "snålastes": "snål",
    "snålasts": "snål",
    "snålat": "snåla",
    "snålats": "snåla",
    "snålblåsten": "snålblåst",
    "snålblåstens": "snålblåst",
    "snålblåsts": "snålblåst",
    "snåle": "snål",
    "snåles": "snål",
    "snålheten": "snålhet",
    "snålhetens": "snålhet",
    "snålhets": "snålhet",
    "snåljåpar": "snåljåp",
    "snåljåparna": "snåljåp",
    "snåljåparnas": "snåljåp",
    "snåljåpars": "snåljåp",
    "snåljåpen": "snåljåp",
    "snåljåpens": "snåljåp",
    "snåljåps": "snåljåp",
    "snålmånsar": "snålmåns",
    "snålmånsarna": "snålmåns",
    "snålmånsarnas": "snålmåns",
    "snålmånsars": "snålmåns",
    "snålmånsen": "snålmåns",
    "snålmånsens": "snålmåns",
    "snåls": "snål",
    "snålskjutsen": "snålskjuts",
    "snålskjutsens": "snålskjuts",
    "snålt": "snål",
    "snålts": "snål",
    "snålvargar": "snålvarg",
    "snålvargarna": "snålvarg",
    "snålvargarnas": "snålvarg",
    "snålvargars": "snålvarg",
    "snålvargen": "snålvarg",
    "snålvargens": "snålvarg",
    "snålvargs": "snålvarg",
    "snålvattens": "snålvatten",
    "snålvattnet": "snålvatten",
    "snålvattnets": "snålvatten",
    "snåren": "snår",
    "snårens": "snår",
    "snåret": "snår",
    "snårets": "snåret",
    "snåriga": "snårig",
    "snårigare": "snårig",
    "snårigares": "snårig",
    "snårigas": "snårig",
    "snårigast": "snårig",
    "snårigaste": "snårig",
    "snårigastes": "snårig",
    "snårigasts": "snårig",
    "snårige": "snårig",
    "snåriges": "snårig",
    "snårigs": "snårig",
    "snårigt": "snårig",
    "snårigts": "snårig",
    "snårs": "snår",
    "snårskogar": "snårskog",
    "snårskogarna": "snårskog",
    "snårskogarnas": "snårskog",
    "snårskogars": "snårskog",
    "snårskogen": "snårskog",
    "snårskogens": "snårskog",
    "snårskogs": "snårskog",
    "snårvindan": "snårvinda",
    "snårvindans": "snårvinda",
    "snårvindas": "snårvinda",
    "snö": "snöa",
    "snöad": "snöa",
    "snöade": "snöa",
    "snöades": "snöa",
    "snöads": "snöa",
    "snöalgen": "snöalg",
    "snöalgens": "snöalg",
    "snöalger": "snöalg",
    "snöalgerna": "snöalg",
    "snöalgernas": "snöalg",
    "snöalgers": "snöalg",
    "snöalgs": "snöalg",
    "snöande": "snöa",
    "snöanden": "snöande",
    "snöandena": "snöande",
    "snöandenas": "snöande",
    "snöandens": "snöande",
    "snöandes": "snöande",
    "snöandet": "snöande",
    "snöandets": "snöande",
    "snöar": "snöa",
    "snöas": "snöa",
    "snöat": "snöa",
    "snöats": "snöa",
    "snöbarken": "snöbark",
    "snöbarkens": "snöbark",
    "snöbarks": "snöbark",
    "snöblandade": "snöblandad",
    "snöblandades": "snöblandad",
    "snöblandads": "snöblandad",
    "snöblandat": "snöblandad",
    "snöblandats": "snöblandad",
    "snöblinda": "snöblind",
    "snöblindare": "snöblind",
    "snöblindares": "snöblind",
    "snöblindas": "snöblind",
    "snöblindast": "snöblind",
    "snöblindaste": "snöblind",
    "snöblindastes": "snöblind",
    "snöblindasts": "snöblind",
    "snöblinde": "snöblind",
    "snöblindes": "snöblind",
    "snöblindheten": "snöblindhet",
    "snöblindhetens": "snöblindhet",
    "snöblindheter": "snöblindhet",
    "snöblindheterna": "snöblindhet",
    "snöblindheternas": "snöblindhet",
    "snöblindheters": "snöblindhet",
    "snöblindhets": "snöblindhet",
    "snöblinds": "snöblind",
    "snöblint": "snöblind",
    "snöblints": "snöblind",
    "snöbollar": "snöboll",
    "snöbollarna": "snöboll",
    "snöbollarnas": "snöboll",
    "snöbollars": "snöboll",
    "snöbollen": "snöboll",
    "snöbollens": "snöboll",
    "snöbolls": "snöboll",
    "snöbollsbusk": "snöbollsbuske",
    "snöbollsbuskar": "snöbollsbuske",
    "snöbollsbuskarna": "snöbollsbuske",
    "snöbollsbuskarnas": "snöbollsbuske",
    "snöbollsbuskars": "snöbollsbuske",
    "snöbollsbusken": "snöbollsbuske",
    "snöbollsbuskens": "snöbollsbuske",
    "snöbollsbuskes": "snöbollsbuske",
    "snöbollskrigen": "snöbollskrig",
    "snöbollskrigens": "snöbollskrig",
    "snöbollskriget": "snöbollskrig",
    "snöbollskrigets": "snöbollskrig",
    "snöbollskrigs": "snöbollskrig",
    "snöborst": "snöborste",
    "snöborstar": "snöborste",
    "snöborstarna": "snöborste",
    "snöborstarnas": "snöborste",
    "snöborstars": "snöborste",
    "snöborsten": "snöborste",
    "snöborstens": "snöborste",
    "snöborstes": "snöborste",
    "snöbräd": "snöbräda",
    "snöbrädan": "snöbräda",
    "snöbrädans": "snöbräda",
    "snöbrädas": "snöbräda",
    "snöbräde": "snöbräda",
    "snöbräden": "snöbräde",
    "snöbrädena": "snöbräde",
    "snöbrädenas": "snöbräde",
    "snöbrädens": "snöbräde",
    "snöbrädes": "snöbräde",
    "snöbrädet": "snöbräde",
    "snöbrädets": "snöbräde",
    "snöbrädor": "snöbräda",
    "snöbrädorna": "snöbräda",
    "snöbrädornas": "snöbräda",
    "snöbrädors": "snöbräda",
    "snöbräds": "snöbräda",
    "snöbären": "snöbär",
    "snöbärens": "snöbär",
    "snöbäret": "snöbär",
    "snöbärets": "snöbär",
    "snöbärs": "snöbär",
    "snöda": "snöd",
    "snödare": "snöd",
    "snödares": "snöd",
    "snödas": "snöd",
    "snödast": "snöd",
    "snödaste": "snöd",
    "snödastes": "snöd",
    "snödasts": "snöd",
    "snöde": "snöd",
    "snödes": "snöd",
    "snödheten": "snödhet",
    "snödhetens": "snödhet",
    "snödhets": "snödhet",
    "snödjupen": "snödjup",
    "snödjupens": "snödjup",
    "snödjupet": "snödjup",
    "snödjupets": "snödjup",
    "snödjups": "snödjup",
    "snödrevet": "snödrev",
    "snödrevets": "snödrev",
    "snödrevs": "snödrev",
    "snödriften": "snödrift",
    "snödriftens": "snödrift",
    "snödrifts": "snödrift",
    "snödriv": "snödriva",
    "snödrivan": "snödriva",
    "snödrivans": "snödriva",
    "snödrivas": "snödriva",
    "snödrive": "snödriva",
    "snödrivor": "snödriva",
    "snödrivorna": "snödriva",
    "snödrivornas": "snödriva",
    "snödrivors": "snödriva",
    "snödrivs": "snödriva",
    "snödropp": "snödroppe",
    "snödroppar": "snödroppe",
    "snödropparna": "snödroppe",
    "snödropparnas": "snödroppe",
    "snödroppars": "snödroppe",
    "snödroppen": "snödroppe",
    "snödroppens": "snödroppe",
    "snödroppes": "snödroppe",
    "snödropps": "snödroppe",
    "snödräkten": "snödräkt",
    "snödräktens": "snödräkt",
    "snödräkter": "snödräkt",
    "snödräkterna": "snödräkt",
    "snödräkternas": "snödräkt",
    "snödräkters": "snödräkt",
    "snödräkts": "snödräkt",
    "snöds": "snöd",
    "snöfallen": "snöfall",
    "snöfallens": "snöfall",
    "snöfallet": "snöfall",
    "snöfallets": "snöfall",
    "snöfalls": "snöfall",
    "snöfattiga": "snöfattig",
    "snöfattigare": "snöfattig",
    "snöfattigares": "snöfattig",
    "snöfattigas": "snöfattig",
    "snöfattigast": "snöfattig",
    "snöfattigaste": "snöfattig",
    "snöfattigastes": "snöfattig",
    "snöfattigasts": "snöfattig",
    "snöfattige": "snöfattig",
    "snöfattiges": "snöfattig",
    "snöfattigs": "snöfattig",
    "snöfattigt": "snöfattig",
    "snöfattigts": "snöfattig",
    "snöfjällen": "snöfjäll",
    "snöfjällens": "snöfjäll",
    "snöfjället": "snöfjäll",
    "snöfjällets": "snöfjäll",
    "snöfjälls": "snöfjäll",
    "snöfling": "snöflinga",
    "snöflingan": "snöflinga",
    "snöflingans": "snöflinga",
    "snöflingas": "snöflinga",
    "snöflinge": "snöflinga",
    "snöflingedekorationen": "snöflingedekoration",
    "snöflingedekorationens": "snöflingedekoration",
    "snöflingedekorationer": "snöflingedekoration",
    "snöflingedekorationerna": "snöflingedekoration",
    "snöflingedekorationernas": "snöflingedekoration",
    "snöflingedekorationers": "snöflingedekoration",
    "snöflingedekorations": "snöflingedekoration",
    "snöflingor": "snöflinga",
    "snöflingorna": "snöflinga",
    "snöflingornas": "snöflinga",
    "snöflingors": "snöflinga",
    "snöflings": "snöflinga",
    "snögloppet": "snöglopp",
    "snögloppets": "snöglopp",
    "snöglopps": "snöglopp",
    "snögränsen": "snögräns",
    "snögränsens": "snögräns",
    "snögubb": "snögubbe",
    "snögubbar": "snögubbe",
    "snögubbarna": "snögubbe",
    "snögubbarnas": "snögubbe",
    "snögubbars": "snögubbe",
    "snögubben": "snögubbe",
    "snögubbens": "snögubbe",
    "snögubbes": "snögubbe",
    "snögubbs": "snögubbe",
    "snöhagels": "snöhagel",
    "snöhaglen": "snöhagel",
    "snöhaglens": "snöhagel",
    "snöhaglet": "snöhagel",
    "snöhaglets": "snöhagel",
    "snöhala": "snöhal",
    "snöhalare": "snöhal",
    "snöhalares": "snöhal",
    "snöhalas": "snöhal",
    "snöhalast": "snöhal",
    "snöhalaste": "snöhal",
    "snöhalastes": "snöhal",
    "snöhalasts": "snöhal",
    "snöhale": "snöhal",
    "snöhales": "snöhal",
    "snöhalkan": "snöhalka",
    "snöhalkans": "snöhalka",
    "snöhalkas": "snöhalka",
    "snöhals": "snöhal",
    "snöhalt": "snöhal",
    "snöhalts": "snöhal",
    "snöiga": "snöig",
    "snöigare": "snöig",
    "snöigares": "snöig",
    "snöigas": "snöig",
    "snöigast": "snöig",
    "snöigaste": "snöig",
    "snöigastes": "snöig",
    "snöigasts": "snöig",
    "snöige": "snöig",
    "snöiges": "snöig",
    "snöigs": "snöig",
    "snöigt": "snöig",
    "snöigts": "snöig",
    "snökanonen": "snökanon",
    "snökanonens": "snökanon",
    "snökanoner": "snökanon",
    "snökanonerna": "snökanon",
    "snökanonernas": "snökanon",
    "snökanoners": "snökanon",
    "snökanons": "snökanon",
    "snökaosen": "snökaos",
    "snökaosens": "snökaos",
    "snökaoset": "snökaos",
    "snökaosets": "snökaos",
    "snökedjan": "snökedja",
    "snökedjans": "snökedja",
    "snökedjas": "snökedja",
    "snökedje": "snökedja",
    "snökedjor": "snökedja",
    "snökedjorna": "snökedja",
    "snökedjornas": "snökedja",
    "snökedjors": "snökedja",
    "snöklock": "snöklocka",
    "snöklockan": "snöklocka",
    "snöklockans": "snöklocka",
    "snöklockas": "snöklocka",
    "snöklocke": "snöklocka",
    "snöklockor": "snöklocka",
    "snöklockorna": "snöklocka",
    "snöklockornas": "snöklocka",
    "snöklockors": "snöklocka",
    "snöklocks": "snöklocka",
    "snökloten": "snöklot",
    "snöklotens": "snöklot",
    "snöklotet": "snöklot",
    "snöklotets": "snöklot",
    "snöklots": "snöklot",
    "snöklädda": "snöklädd",
    "snökläddare": "snöklädd",
    "snökläddares": "snöklädd",
    "snökläddas": "snöklädd",
    "snökläddast": "snöklädd",
    "snökläddaste": "snöklädd",
    "snökläddastes": "snöklädd",
    "snökläddasts": "snöklädd",
    "snöklädde": "snöklädd",
    "snökläddes": "snöklädd",
    "snöklädds": "snöklädd",
    "snöklätt": "snöklädd",
    "snöklätts": "snöklädd",
    "snökristallen": "snökristall",
    "snökristallens": "snökristall",
    "snökristaller": "snökristall",
    "snökristallerna": "snökristall",
    "snökristallernas": "snökristall",
    "snökristallers": "snökristall",
    "snökristalls": "snökristall",
    "snölandskapen": "snölandskap",
    "snölandskapens": "snölandskap",
    "snölandskapet": "snölandskap",
    "snölandskapets": "snölandskap",
    "snölandskaps": "snölandskap",
    "snöleg": "snölega",
    "snölegan": "snölega",
    "snölegans": "snölega",
    "snölegas": "snölega",
    "snölege": "snölega",
    "snölegor": "snölega",
    "snölegorna": "snölega",
    "snölegornas": "snölega",
    "snölegors": "snölega",
    "snölegs": "snölega",
    "snölykt": "snölykta",
    "snölyktan": "snölykta",
    "snölyktans": "snölykta",
    "snölyktas": "snölykta",
    "snölykte": "snölykta",
    "snölyktor": "snölykta",
    "snölyktorna": "snölykta",
    "snölyktornas": "snölykta",
    "snölyktors": "snölykta",
    "snölykts": "snölykta",
    "snömoset": "snömos",
    "snömosets": "snömos",
    "snömögels": "snömögel",
    "snömöglet": "snömögel",
    "snömöglets": "snömögel",
    "snön": "snö",
    "snöns": "snö",
    "snöoväderna": "snöoväder",
    "snöovädernas": "snöoväder",
    "snöoväders": "snöoväder",
    "snöovädren": "snöoväder",
    "snöovädrens": "snöoväder",
    "snöovädret": "snöoväder",
    "snöovädrets": "snöoväder",
    "snöp": "snöpa",
    "snöpande": "snöpa",
    "snöpanden": "snöpande",
    "snöpandena": "snöpande",
    "snöpandenas": "snöpande",
    "snöpandens": "snöpande",
    "snöpandes": "snöpande",
    "snöpandet": "snöpande",
    "snöpandets": "snöpande",
    "snöpar": "snöpare",
    "snöparen": "snöpare",
    "snöparens": "snöpare",
    "snöpares": "snöpare",
    "snöparna": "snöpare",
    "snöparnas": "snöpare",
    "snöpas": "snöpa",
    "snöpegeln": "snöpegel",
    "snöpegelns": "snöpegel",
    "snöpegels": "snöpegel",
    "snöpeglar": "snöpegel",
    "snöpeglarna": "snöpegel",
    "snöpeglarnas": "snöpegel",
    "snöpeglars": "snöpegel",
    "snöper": "snöpa",
    "snöpes": "snöpa",
    "snöpingar": "snöping",
    "snöpingarna": "snöping",
    "snöpingarnas": "snöping",
    "snöpingars": "snöping",
    "snöpingen": "snöping",
    "snöpingens": "snöping",
    "snöpings": "snöping",
    "snöpliga": "snöplig",
    "snöpligare": "snöplig",
    "snöpligares": "snöplig",
    "snöpligas": "snöplig",
    "snöpligast": "snöplig",
    "snöpligaste": "snöplig",
    "snöpligastes": "snöplig",
    "snöpligasts": "snöplig",
    "snöplige": "snöplig",
    "snöpliges": "snöplig",
    "snöpligheten": "snöplighet",
    "snöplighetens": "snöplighet",
    "snöplighets": "snöplighet",
    "snöpligs": "snöplig",
    "snöpligt": "snöplig",
    "snöpligts": "snöplig",
    "snöplog": "snöploga",
    "snöplogad": "snöploga",
    "snöplogade": "snöploga",
    "snöplogades": "snöploga",
    "snöplogads": "snöploga",
    "snöplogande": "snöploga",
    "snöploganden": "snöplogande",
    "snöplogandena": "snöplogande",
    "snöplogandenas": "snöplogande",
    "snöplogandens": "snöplogande",
    "snöplogandes": "snöplogande",
    "snöplogandet": "snöplogande",
    "snöplogandets": "snöplogande",
    "snöplogar": "snöploga",
    "snöplogarna": "snöplog",
    "snöplogarnas": "snöplog",
    "snöplogars": "snöplog",
    "snöplogas": "snöploga",
    "snöplogat": "snöploga",
    "snöplogats": "snöploga",
    "snöplogen": "snöplog",
    "snöplogens": "snöplog",
    "snöplogningar": "snöplogning",
    "snöplogningarna": "snöplogning",
    "snöplogningarnas": "snöplogning",
    "snöplogningars": "snöplogning",
    "snöplogningen": "snöplogning",
    "snöplogningens": "snöplogning",
    "snöplognings": "snöplogning",
    "snöplogs": "snöplog",
    "snöps": "snöpa",
    "snöpt": "snöpa",
    "snöpta": "snöpa",
    "snöptas": "snöpa",
    "snöpte": "snöpa",
    "snöptes": "snöpa",
    "snöpts": "snöpa",
    "snör": "snöre",
    "snörande": "snöra",
    "snöranden": "snörande",
    "snörandena": "snörande",
    "snörandenas": "snörande",
    "snörandens": "snörande",
    "snörandes": "snörande",
    "snörandet": "snörande",
    "snörandets": "snörande",
    "snörapporten": "snörapport",
    "snörapportens": "snörapport",
    "snörapporter": "snörapport",
    "snörapporterna": "snörapport",
    "snörapporternas": "snörapport",
    "snörapporters": "snörapport",
    "snörapports": "snörapport",
    "snöras": "snöra",
    "snörd": "snöra",
    "snörda": "snöra",
    "snördas": "snöra",
    "snörde": "snöra",
    "snördes": "snöra",
    "snörds": "snöra",
    "snöredskapen": "snöredskap",
    "snöredskapens": "snöredskap",
    "snöredskapet": "snöredskap",
    "snöredskapets": "snöredskap",
    "snöredskaps": "snöredskap",
    "snöregionen": "snöregion",
    "snöregionens": "snöregion",
    "snöregioner": "snöregion",
    "snöregionerna": "snöregion",
    "snöregionernas": "snöregion",
    "snöregioners": "snöregion",
    "snöregions": "snöregion",
    "snöregnet": "snöregn",
    "snöregnets": "snöregn",
    "snöregns": "snöregn",
    "snören": "snöre",
    "snörena": "snöre",
    "snörenas": "snöre",
    "snörens": "snöre",
    "snöres": "snöre",
    "snöret": "snöre",
    "snörets": "snöre",
    "snörika": "snörik",
    "snörikare": "snörik",
    "snörikares": "snörik",
    "snörikas": "snörik",
    "snörikast": "snörik",
    "snörikaste": "snörik",
    "snörikastes": "snörik",
    "snörikasts": "snörik",
    "snörike": "snörik",
    "snörikes": "snörik",
    "snörikheten": "snörikhet",
    "snörikhetens": "snörikhet",
    "snörikhets": "snörikhet",
    "snöriks": "snörik",
    "snörikt": "snörik",
    "snörikts": "snörik",
    "snörip": "snöripa",
    "snöripan": "snöripa",
    "snöripans": "snöripa",
    "snöripas": "snöripa",
    "snöripe": "snöripa",
    "snöripor": "snöripa",
    "snöriporna": "snöripa",
    "snöripornas": "snöripa",
    "snöripors": "snöripa",
    "snörips": "snöripa",
    "snörkäng": "snörkänga",
    "snörkängan": "snörkänga",
    "snörkängans": "snörkänga",
    "snörkängas": "snörkänga",
    "snörkänge": "snörkänga",
    "snörkängor": "snörkänga",
    "snörkängorna": "snörkänga",
    "snörkängornas": "snörkänga",
    "snörkängors": "snörkänga",
    "snörkängs": "snörkänga",
    "snörliven": "snörliv",
    "snörlivens": "snörliv",
    "snörlivet": "snörliv",
    "snörlivets": "snörliv",
    "snörlivs": "snörliv",
    "snörmakar": "snörmakare",
    "snörmakaren": "snörmakare",
    "snörmakarens": "snörmakare",
    "snörmakares": "snörmakare",
    "snörmakarna": "snörmakare",
    "snörmakarnas": "snörmakare",
    "snörmakerier": "snörmakeri",
    "snörmakerierna": "snörmakeri",
    "snörmakeriernas": "snörmakeri",
    "snörmakeriers": "snörmakeri",
    "snörmakeriet": "snörmakeri",
    "snörmakeriets": "snörmakeri",
    "snörmakeris": "snörmakeri",
    "snörmakerit": "snörmakeri",
    "snörmakerits": "snörmakeri",
    "snörp": "snörpa",
    "snörpande": "snörpa",
    "snörpanden": "snörpande",
    "snörpandena": "snörpande",
    "snörpandenas": "snörpande",
    "snörpandens": "snörpande",
    "snörpandes": "snörpande",
    "snörpandet": "snörpande",
    "snörpandets": "snörpande",
    "snörpas": "snörpa",
    "snörper": "snörpa",
    "snörpes": "snörpa",
    "snörpiga": "snörpig",
    "snörpigare": "snörpig",
    "snörpigares": "snörpig",
    "snörpigas": "snörpig",
    "snörpigast": "snörpig",
    "snörpigaste": "snörpig",
    "snörpigastes": "snörpig",
    "snörpigasts": "snörpig",
    "snörpige": "snörpig",
    "snörpiges": "snörpig",
    "snörpigheten": "snörpighet",
    "snörpighetens": "snörpighet",
    "snörpighets": "snörpighet",
    "snörpigs": "snörpig",
    "snörpigt": "snörpig",
    "snörpigts": "snörpig",
    "snörps": "snörpa",
    "snörpt": "snörpa",
    "snörpta": "snörpa",
    "snörptas": "snörpa",
    "snörpte": "snörpa",
    "snörptes": "snörpa",
    "snörpts": "snörpa",
    "snörpvadar": "snörpvad",
    "snörpvadarna": "snörpvad",
    "snörpvadarnas": "snörpvad",
    "snörpvadars": "snörpvad",
    "snörpvaden": "snörpvad",
    "snörpvadens": "snörpvad",
    "snörpvads": "snörpvad",
    "snörräta": "snörrät",
    "snörrätare": "snörrät",
    "snörrätares": "snörrät",
    "snörrätas": "snörrät",
    "snörrätast": "snörrät",
    "snörrätaste": "snörrät",
    "snörrätastes": "snörrät",
    "snörrätasts": "snörrät",
    "snörräte": "snörrät",
    "snörrätes": "snörrät",
    "snörrätheten": "snörräthet",
    "snörräthetens": "snörräthet",
    "snörräthets": "snörräthet",
    "snörräts": "snörrät",
    "snörrätt": "snörrät",
    "snörrätts": "snörrät",
    "snörs": "snöre",
    "snörskon": "snörsko",
    "snörskons": "snörsko",
    "snörskor": "snörsko",
    "snörskorna": "snörsko",
    "snörskornas": "snörsko",
    "snörskors": "snörsko",
    "snörskos": "snörsko",
    "snörstarten": "snörstart",
    "snörstartens": "snörstart",
    "snörstarter": "snörstart",
    "snörstarterna": "snörstart",
    "snörstarternas": "snörstart",
    "snörstarters": "snörstart",
    "snörstarts": "snörstart",
    "snörstumpar": "snörstump",
    "snörstumparna": "snörstump",
    "snörstumparnas": "snörstump",
    "snörstumpars": "snörstump",
    "snörstumpen": "snörstump",
    "snörstumpens": "snörstump",
    "snörstumps": "snörstump",
    "snörstöveln": "snörstövel",
    "snörstövelns": "snörstövel",
    "snörstövels": "snörstövel",
    "snörstövlar": "snörstövel",
    "snörstövlarna": "snörstövel",
    "snörstövlarnas": "snörstövel",
    "snörstövlars": "snörstövel",
    "snört": "snöra",
    "snörts": "snöra",
    "snörvel": "snörvla",
    "snörvlade": "snörvla",
    "snörvlades": "snörvla",
    "snörvlande": "snörvla",
    "snörvlanden": "snörvlande",
    "snörvlandena": "snörvlande",
    "snörvlandenas": "snörvlande",
    "snörvlandens": "snörvlande",
    "snörvlandes": "snörvlande",
    "snörvlandet": "snörvlande",
    "snörvlandets": "snörvlande",
    "snörvlar": "snörvla",
    "snörvlas": "snörvla",
    "snörvlat": "snörvla",
    "snörvlats": "snörvla",
    "snörvliga": "snörvlig",
    "snörvligare": "snörvlig",
    "snörvligares": "snörvlig",
    "snörvligas": "snörvlig",
    "snörvligast": "snörvlig",
    "snörvligaste": "snörvlig",
    "snörvligastes": "snörvlig",
    "snörvligasts": "snörvlig",
    "snörvlige": "snörvlig",
    "snörvliges": "snörvlig",
    "snörvligheten": "snörvlighet",
    "snörvlighetens": "snörvlighet",
    "snörvlighets": "snörvlighet",
    "snörvligs": "snörvlig",
    "snörvligt": "snörvlig",
    "snörvligts": "snörvlig",
    "snörvlingar": "snörvling",
    "snörvlingarna": "snörvling",
    "snörvlingarnas": "snörvling",
    "snörvlingars": "snörvling",
    "snörvlingen": "snörvling",
    "snörvlingens": "snörvling",
    "snörvlings": "snörvling",
    "snöröjningar": "snöröjning",
    "snöröjningarna": "snöröjning",
    "snöröjningarnas": "snöröjning",
    "snöröjningars": "snöröjning",
    "snöröjningen": "snöröjning",
    "snöröjningens": "snöröjning",
    "snöröjnings": "snöröjning",
    "snös": "snö",
    "snöscooterförar": "snöscooterförare",
    "snöscooterföraren": "snöscooterförare",
    "snöscooterförarens": "snöscooterförare",
    "snöscooterförares": "snöscooterförare",
    "snöscooterförarna": "snöscooterförare",
    "snöscooterförarnas": "snöscooterförare",
    "snöscootern": "snöscooter",
    "snöscooterns": "snöscooter",
    "snöscooters": "snöscooter",
    "snöscootrar": "snöscooter",
    "snöscootrarna": "snöscooter",
    "snöscootrarnas": "snöscooter",
    "snöscootrars": "snöscooter",
    "snöskat": "snöskata",
    "snöskatan": "snöskata",
    "snöskatans": "snöskata",
    "snöskatas": "snöskata",
    "snöskate": "snöskata",
    "snöskator": "snöskata",
    "snöskatorna": "snöskata",
    "snöskatornas": "snöskata",
    "snöskators": "snöskata",
    "snöskats": "snöskata",
    "snöskon": "snösko",
    "snöskons": "snösko",
    "snöskor": "snösko",
    "snöskorna": "snösko",
    "snöskornas": "snösko",
    "snöskorpan": "snöskorpa",
    "snöskorpans": "snöskorpa",
    "snöskorpas": "snöskorpa",
    "snöskors": "snösko",
    "snöskos": "snösko",
    "snöskoterförar": "snöskoterförare",
    "snöskoterföraren": "snöskoterförare",
    "snöskoterförarens": "snöskoterförare",
    "snöskoterförares": "snöskoterförare",
    "snöskoterförarna": "snöskoterförare",
    "snöskoterförarnas": "snöskoterförare",
    "snöskotern": "snöskoter",
    "snöskoterns": "snöskoter",
    "snöskoters": "snöskoter",
    "snöskotrar": "snöskoter",
    "snöskotrarna": "snöskoter",
    "snöskotrarnas": "snöskoter",
    "snöskotrars": "snöskoter",
    "snöskottar": "snöskottare",
    "snöskottaren": "snöskottare",
    "snöskottarens": "snöskottare",
    "snöskottares": "snöskottare",
    "snöskottarna": "snöskottare",
    "snöskottarnas": "snöskottare",
    "snöskottningen": "snöskottning",
    "snöskottningens": "snöskottning",
    "snöskottnings": "snöskottning",
    "snöskreden": "snöskred",
    "snöskredens": "snöskred",
    "snöskredet": "snöskred",
    "snöskredets": "snöskred",
    "snöskreds": "snöskred",
    "snöskrudar": "snöskrud",
    "snöskrudarna": "snöskrud",
    "snöskrudarnas": "snöskrud",
    "snöskrudars": "snöskrud",
    "snöskruden": "snöskrud",
    "snöskrudens": "snöskrud",
    "snöskruds": "snöskrud",
    "snöskyffeln": "snöskyffel",
    "snöskyffelns": "snöskyffel",
    "snöskyffels": "snöskyffel",
    "snöskyfflar": "snöskyffel",
    "snöskyfflarna": "snöskyffel",
    "snöskyfflarnas": "snöskyffel",
    "snöskyfflars": "snöskyffel",
    "snöskyttes": "snöskytte",
    "snöskyttet": "snöskytte",
    "snöskyttets": "snöskytte",
    "snöslasket": "snöslask",
    "snöslaskets": "snöslask",
    "snöslasks": "snöslask",
    "snöslung": "snöslunga",
    "snöslungan": "snöslunga",
    "snöslungans": "snöslunga",
    "snöslungas": "snöslunga",
    "snöslunge": "snöslunga",
    "snöslungor": "snöslunga",
    "snöslungorna": "snöslunga",
    "snöslungornas": "snöslunga",
    "snöslungors": "snöslunga",
    "snöslungs": "snöslunga",
    "snösläd": "snösläde",
    "snöslädar": "snösläde",
    "snöslädarna": "snösläde",
    "snöslädarnas": "snösläde",
    "snöslädars": "snösläde",
    "snösläden": "snösläde",
    "snöslädens": "snösläde",
    "snöslädes": "snösläde",
    "snösläds": "snösläde",
    "snösmältningar": "snösmältning",
    "snösmältningarna": "snösmältning",
    "snösmältningarnas": "snösmältning",
    "snösmältningars": "snösmältning",
    "snösmältningen": "snösmältning",
    "snösmältningens": "snösmältning",
    "snösmältnings": "snösmältning",
    "snösparvar": "snösparv",
    "snösparvarna": "snösparv",
    "snösparvarnas": "snösparv",
    "snösparvars": "snösparv",
    "snösparven": "snösparv",
    "snösparvens": "snösparv",
    "snösparvs": "snösparv",
    "snöstaketen": "snöstaket",
    "snöstaketens": "snöstaket",
    "snöstaketet": "snöstaket",
    "snöstaketets": "snöstaket",
    "snöstakets": "snöstaket",
    "snöstjärnan": "snöstjärna",
    "snöstjärnans": "snöstjärna",
    "snöstjärnas": "snöstjärna",
    "snöstjärne": "snöstjärna",
    "snöstjärnor": "snöstjärna",
    "snöstjärnorna": "snöstjärna",
    "snöstjärnornas": "snöstjärna",
    "snöstjärnors": "snöstjärna",
    "snöstormar": "snöstorm",
    "snöstormarna": "snöstorm",
    "snöstormarnas": "snöstorm",
    "snöstormars": "snöstorm",
    "snöstormen": "snöstorm",
    "snöstormens": "snöstorm",
    "snöstorms": "snöstorm",
    "snösvängen": "snösväng",
    "snösvängens": "snösväng",
    "snösvängs": "snösväng",
    "snöt": "snyta",
    "snöte": "snyta",
    "snötes": "snyta",
    "snöts": "snyta",
    "snötyngde": "snötyngd",
    "snötyngdes": "snötyngd",
    "snötyngds": "snötyngd",
    "snötyngt": "snötyngd",
    "snötyngts": "snötyngd",
    "snötäcken": "snötäcke",
    "snötäckena": "snötäcke",
    "snötäckenas": "snötäcke",
    "snötäckens": "snötäcke",
    "snötäckes": "snötäcke",
    "snötäcket": "snötäcke",
    "snötäckets": "snötäcke",
    "snötäcks": "snötäcke",
    "snötäckta": "snötäckt",
    "snötäcktare": "snötäckt",
    "snötäcktares": "snötäckt",
    "snötäcktas": "snötäckt",
    "snötäcktast": "snötäckt",
    "snötäcktaste": "snötäckt",
    "snötäcktastes": "snötäckt",
    "snötäcktasts": "snötäckt",
    "snötäckte": "snötäckt",
    "snötäcktes": "snötäckt",
    "snötäckts": "snötäckt",
    "snövallar": "snövall",
    "snövallarna": "snövall",
    "snövallarnas": "snövall",
    "snövallars": "snövall",
    "snövallen": "snövall",
    "snövallens": "snövall",
    "snövalls": "snövall",
    "snövintern": "snövinter",
    "snövinterns": "snövinter",
    "snövinters": "snövinter",
    "snövintrar": "snövinter",
    "snövintrarna": "snövinter",
    "snövintrarnas": "snövinter",
    "snövintrars": "snövinter",
    "snövita": "snövit",
    "snövitare": "snövit",
    "snövitares": "snövit",
    "snövitas": "snövit",
    "snövitast": "snövit",
    "snövitaste": "snövit",
    "snövitastes": "snövit",
    "snövitasts": "snövit",
    "snövite": "snövit",
    "snövites": "snövit",
    "snövits": "snövit",
    "snövitt": "snövit",
    "snövitts": "snövit",
    "snöyran": "snöyra",
    "snöyrans": "snöyra",
    "snöyras": "snöyra",
    "soaréer": "soaré",
    "soaréerna": "soaré",
    "soaréernas": "soaré",
    "soaréers": "soaré",
    "soarén": "soaré",
    "soaréns": "soaré",
    "soarés": "soaré",
    "sobeln": "sobel",
    "sobelns": "sobel",
    "sobels": "sobel",
    "sobers": "sober",
    "sobert": "sober",
    "soberts": "sober",
    "soblar": "sobel",
    "soblarna": "sobel",
    "soblarnas": "sobel",
    "soblars": "sobel",
    "sobra": "sober",
    "sobrare": "sober",
    "sobrares": "sober",
    "sobras": "sober",
    "sobrast": "sober",
    "sobraste": "sober",
    "sobrastes": "sober",
    "sobrasts": "sober",
    "sobre": "sober",
    "sobres": "sober",
    "sociala": "social",
    "socialantropologen": "socialantropolog",
    "socialantropologens": "socialantropolog",
    "socialantropologer": "socialantropolog",
    "socialantropologerna": "socialantropolog",
    "socialantropologernas": "socialantropolog",
    "socialantropologers": "socialantropolog",
    "socialantropologien": "socialantropologi",
    "socialantropologiens": "socialantropologi",
    "socialantropologin": "socialantropologi",
    "socialantropologins": "socialantropologi",
    "socialantropologis": "socialantropologi",
    "socialantropologiska": "socialantropologisk",
    "socialantropologiskare": "socialantropologisk",
    "socialantropologiskares": "socialantropologisk",
    "socialantropologiskas": "socialantropologisk",
    "socialantropologiskast": "socialantropologisk",
    "socialantropologiskaste": "socialantropologisk",
    "socialantropologiskastes": "socialantropologisk",
    "socialantropologiskasts": "socialantropologisk",
    "socialantropologiske": "socialantropologisk",
    "socialantropologiskes": "socialantropologisk",
    "socialantropologisks": "socialantropologisk",
    "socialantropologiskt": "socialantropologisk",
    "socialantropologiskts": "socialantropologisk",
    "socialantropologs": "socialantropolog",
    "socialarbetar": "socialarbetare",
    "socialarbetaren": "socialarbetare",
    "socialarbetarens": "socialarbetare",
    "socialarbetares": "socialarbetare",
    "socialarbetarna": "socialarbetare",
    "socialarbetarnas": "socialarbetare",
    "socialarbeten": "socialarbete",
    "socialarbetena": "socialarbete",
    "socialarbetenas": "socialarbete",
    "socialarbetens": "socialarbete",
    "socialarbetes": "socialarbete",
    "socialarbetet": "socialarbete",
    "socialarbetets": "socialarbete",
    "socialarbets": "socialarbete",
    "socialare": "social",
    "socialares": "social",
    "socialas": "social",
    "socialassistenten": "socialassistent",
    "socialassistentens": "socialassistent",
    "socialassistenter": "socialassistent",
    "socialassistenterna": "socialassistent",
    "socialassistenternas": "socialassistent",
    "socialassistenters": "socialassistent",
    "socialassistents": "socialassistent",
    "socialast": "social",
    "socialaste": "social",
    "socialastes": "social",
    "socialasts": "social",
    "socialavgiften": "socialavgift",
    "socialavgiftens": "socialavgift",
    "socialavgifter": "socialavgift",
    "socialavgifterna": "socialavgift",
    "socialavgifternas": "socialavgift",
    "socialavgifters": "socialavgift",
    "socialavgifts": "socialavgift",
    "socialbidragen": "socialbidrag",
    "socialbidragens": "socialbidrag",
    "socialbidraget": "socialbidrag",
    "socialbidragets": "socialbidrag",
    "socialbidrags": "socialbidrag",
    "socialbidragskostnaden": "socialbidragskostnad",
    "socialbidragskostnadens": "socialbidragskostnad",
    "socialbidragskostnader": "socialbidragskostnad",
    "socialbidragskostnaderna": "socialbidragskostnad",
    "socialbidragskostnadernas": "socialbidragskostnad",
    "socialbidragskostnaders": "socialbidragskostnad",
    "socialbidragskostnads": "socialbidragskostnad",
    "socialbyråer": "socialbyrå",
    "socialbyråerna": "socialbyrå",
    "socialbyråernas": "socialbyrå",
    "socialbyråers": "socialbyrå",
    "socialbyrån": "socialbyrå",
    "socialbyråns": "socialbyrå",
    "socialbyrås": "socialbyrå",
    "socialdemokraten": "socialdemokrat",
    "socialdemokratens": "socialdemokrat",
    "socialdemokrater": "socialdemokrat",
    "socialdemokraterna": "socialdemokrat",
    "socialdemokraternas": "socialdemokrat",
    "socialdemokraters": "socialdemokrat",
    "socialdemokratien": "socialdemokrati",
    "socialdemokratiens": "socialdemokrati",
    "socialdemokratin": "socialdemokrati",
    "socialdemokratins": "socialdemokrati",
    "socialdemokratis": "socialdemokrati",
    "socialdemokratiska": "socialdemokratisk",
    "socialdemokratiskare": "socialdemokratisk",
    "socialdemokratiskares": "socialdemokratisk",
    "socialdemokratiskas": "socialdemokratisk",
    "socialdemokratiskast": "socialdemokratisk",
    "socialdemokratiskaste": "socialdemokratisk",
    "socialdemokratiskastes": "socialdemokratisk",
    "socialdemokratiskasts": "socialdemokratisk",
    "socialdemokratiske": "socialdemokratisk",
    "socialdemokratiskes": "socialdemokratisk",
    "socialdemokratisks": "socialdemokratisk",
    "socialdemokratiskt": "socialdemokratisk",
    "socialdemokratiskts": "socialdemokratisk",
    "socialdemokrats": "socialdemokrat",
    "socialdirektören": "socialdirektör",
    "socialdirektörens": "socialdirektör",
    "socialdirektörer": "socialdirektör",
    "socialdirektörerna": "socialdirektör",
    "socialdirektörernas": "socialdirektör",
    "socialdirektörers": "socialdirektör",
    "socialdirektörn": "socialdirektör",
    "socialdirektörns": "socialdirektör",
    "socialdirektörs": "socialdirektör",
    "sociale": "social",
    "socialens": "socialen",
    "sociales": "social",
    "socialfallen": "socialfall",
    "socialfallens": "socialfall",
    "socialfallet": "socialfall",
    "socialfallets": "socialfall",
    "socialfalls": "socialfall",
    "socialfascistiska": "socialfascistisk",
    "socialfascistiskare": "socialfascistisk",
    "socialfascistiskares": "socialfascistisk",
    "socialfascistiskas": "socialfascistisk",
    "socialfascistiskast": "socialfascistisk",
    "socialfascistiskaste": "socialfascistisk",
    "socialfascistiskastes": "socialfascistisk",
    "socialfascistiskasts": "socialfascistisk",
    "socialfascistiske": "socialfascistisk",
    "socialfascistiskes": "socialfascistisk",
    "socialfascistisks": "socialfascistisk",
    "socialfascistiskt": "socialfascistisk",
    "socialfascistiskts": "socialfascistisk",
    "socialförsäkringar": "socialförsäkring",
    "socialförsäkringarna": "socialförsäkring",
    "socialförsäkringarnas": "socialförsäkring",
    "socialförsäkringars": "socialförsäkring",
    "socialförsäkringen": "socialförsäkring",
    "socialförsäkringens": "socialförsäkring",
    "socialförsäkrings": "socialförsäkring",
    "socialförsäkringsministern": "socialförsäkringsminister",
    "socialförsäkringsministerns": "socialförsäkringsminister",
    "socialförsäkringsministers": "socialförsäkringsminister",
    "socialförsäkringsministrar": "socialförsäkringsminister",
    "socialförsäkringsministrarna": "socialförsäkringsminister",
    "socialförsäkringsministrarnas": "socialförsäkringsminister",
    "socialförsäkringsministrars": "socialförsäkringsminister",
    "socialförsäkringsutskotten": "socialförsäkringsutskott",
    "socialförsäkringsutskottens": "socialförsäkringsutskott",
    "socialförsäkringsutskottet": "socialförsäkringsutskott",
    "socialförsäkringsutskottets": "socialförsäkringsutskott",
    "socialförsäkringsutskotts": "socialförsäkringsutskott",
    "socialförvaltningar": "socialförvaltning",
    "socialförvaltningarna": "socialförvaltning",
    "socialförvaltningarnas": "socialförvaltning",
    "socialförvaltningars": "socialförvaltning",
    "socialförvaltningen": "socialförvaltning",
    "socialförvaltningens": "socialförvaltning",
    "socialförvaltnings": "socialförvaltning",
    "socialgruppen": "socialgrupp",
    "socialgruppens": "socialgrupp",
    "socialgrupper": "socialgrupp",
    "socialgrupperna": "socialgrupp",
    "socialgruppernas": "socialgrupp",
    "socialgruppers": "socialgrupp",
    "socialgrupps": "socialgrupp",
    "socialhjälpen": "socialhjälp",
    "socialhjälpens": "socialhjälp",
    "socialhjälps": "socialhjälp",
    "socialhjälpstagar": "socialhjälpstagare",
    "socialhjälpstagaren": "socialhjälpstagare",
    "socialhjälpstagarens": "socialhjälpstagare",
    "socialhjälpstagares": "socialhjälpstagare",
    "socialhjälpstagarna": "socialhjälpstagare",
    "socialhjälpstagarnas": "socialhjälpstagare",
    "socialhygienen": "socialhygien",
    "socialhygienens": "socialhygien",
    "socialhygiens": "socialhygien",
    "socialhögskolan": "socialhögskola",
    "socialhögskolans": "socialhögskola",
    "socialhögskolas": "socialhögskola",
    "socialhögskole": "socialhögskola",
    "socialhögskolor": "socialhögskola",
    "socialhögskolorna": "socialhögskola",
    "socialhögskolornas": "socialhögskola",
    "socialhögskolors": "socialhögskola",
    "socialisationen": "socialisation",
    "socialisationens": "socialisation",
    "socialisationer": "socialisation",
    "socialisationerna": "socialisation",
    "socialisationernas": "socialisation",
    "socialisationers": "socialisation",
    "socialisations": "socialisation",
    "socialiserad": "socialisera",
    "socialiserade": "socialisera",
    "socialiserades": "socialisera",
    "socialiserads": "socialisera",
    "socialiserande": "socialisera",
    "socialiseranden": "socialiserande",
    "socialiserandena": "socialiserande",
    "socialiserandenas": "socialiserande",
    "socialiserandens": "socialiserande",
    "socialiserandes": "socialiserande",
    "socialiserandet": "socialiserande",
    "socialiserandets": "socialiserande",
    "socialiserar": "socialisera",
    "socialiseras": "socialisera",
    "socialiserat": "socialisera",
    "socialiserats": "socialisera",
    "socialiserbara": "socialiserbar",
    "socialiserbarare": "socialiserbar",
    "socialiserbarares": "socialiserbar",
    "socialiserbaras": "socialiserbar",
    "socialiserbarast": "socialiserbar",
    "socialiserbaraste": "socialiserbar",
    "socialiserbarastes": "socialiserbar",
    "socialiserbarasts": "socialiserbar",
    "socialiserbare": "socialiserbar",
    "socialiserbares": "socialiserbar",
    "socialiserbarheten": "socialiserbarhet",
    "socialiserbarhetens": "socialiserbarhet",
    "socialiserbarhets": "socialiserbarhet",
    "socialiserbars": "socialiserbar",
    "socialiserbart": "socialiserbar",
    "socialiserbarts": "socialiserbar",
    "socialiseringar": "socialisering",
    "socialiseringarna": "socialisering",
    "socialiseringarnas": "socialisering",
    "socialiseringars": "socialisering",
    "socialiseringen": "socialisering",
    "socialiseringens": "socialisering",
    "socialiserings": "socialisering",
    "socialismen": "socialism",
    "socialismens": "socialism",
    "socialismer": "socialism",
    "socialismerna": "socialism",
    "socialismernas": "socialism",
    "socialismers": "socialism",
    "socialisms": "socialism",
    "socialisten": "socialist",
    "socialistens": "socialist",
    "socialister": "socialist",
    "socialisterna": "socialist",
    "socialisternas": "socialist",
    "socialisters": "socialist",
    "socialistiska": "socialistisk",
    "socialistiskare": "socialistisk",
    "socialistiskares": "socialistisk",
    "socialistiskas": "socialistisk",
    "socialistiskast": "socialistisk",
    "socialistiskaste": "socialistisk",
    "socialistiskastes": "socialistisk",
    "socialistiskasts": "socialistisk",
    "socialistiske": "socialistisk",
    "socialistiskes": "socialistisk",
    "socialistisks": "socialistisk",
    "socialistiskt": "socialistisk",
    "socialistiskts": "socialistisk",
    "socialists": "socialist",
    "socialiteten": "socialitet",
    "socialitetens": "socialitet",
    "socialiteter": "socialitet",
    "socialiteterna": "socialitet",
    "socialiteternas": "socialitet",
    "socialiteters": "socialitet",
    "socialitets": "socialitet",
    "socialklassen": "socialklass",
    "socialklassens": "socialklass",
    "socialklasser": "socialklass",
    "socialklasserna": "socialklass",
    "socialklassernas": "socialklass",
    "socialklassers": "socialklass",
    "socialliberala": "socialliberal",
    "socialliberalare": "socialliberal",
    "socialliberalares": "socialliberal",
    "socialliberalas": "socialliberal",
    "socialliberalast": "socialliberal",
    "socialliberalaste": "socialliberal",
    "socialliberalastes": "socialliberal",
    "socialliberalasts": "socialliberal",
    "socialliberale": "socialliberal",
    "socialliberalen": "socialliberal",
    "socialliberalens": "socialliberal",
    "socialliberaler": "socialliberal",
    "socialliberalerna": "socialliberal",
    "socialliberalernas": "socialliberal",
    "socialliberalers": "socialliberal",
    "socialliberales": "socialliberal",
    "socialliberalismen": "socialliberalism",
    "socialliberalismens": "socialliberalism",
    "socialliberalismer": "socialliberalism",
    "socialliberalismerna": "socialliberalism",
    "socialliberalismernas": "socialliberalism",
    "socialliberalismers": "socialliberalism",
    "socialliberalisms": "socialliberalism",
    "socialliberals": "socialliberal",
    "socialliberalt": "socialliberal",
    "socialliberalts": "socialliberal",
    "socialläkar": "socialläkare",
    "socialläkaren": "socialläkare",
    "socialläkarens": "socialläkare",
    "socialläkares": "socialläkare",
    "socialläkarna": "socialläkare",
    "socialläkarnas": "socialläkare",
    "sociallönen": "sociallön",
    "sociallönens": "sociallön",
    "sociallöner": "sociallön",
    "sociallönerna": "sociallön",
    "sociallönernas": "sociallön",
    "sociallöners": "sociallön",
    "sociallöns": "sociallön",
    "socialmedicinar": "socialmedicinare",
    "socialmedicinaren": "socialmedicinare",
    "socialmedicinarens": "socialmedicinare",
    "socialmedicinares": "socialmedicinare",
    "socialmedicinarna": "socialmedicinare",
    "socialmedicinarnas": "socialmedicinare",
    "socialmedicinen": "socialmedicin",
    "socialmedicinens": "socialmedicin",
    "socialmedicins": "socialmedicin",
    "socialnämnden": "socialnämnd",
    "socialnämndens": "socialnämnd",
    "socialnämnder": "socialnämnd",
    "socialnämnderna": "socialnämnd",
    "socialnämndernas": "socialnämnd",
    "socialnämnders": "socialnämnd",
    "socialnämnds": "socialnämnd",
    "socialpolitiken": "socialpolitik",
    "socialpolitikens": "socialpolitik",
    "socialpolitiks": "socialpolitik",
    "socialpolitiska": "socialpolitisk",
    "socialpolitiskare": "socialpolitisk",
    "socialpolitiskares": "socialpolitisk",
    "socialpolitiskas": "socialpolitisk",
    "socialpolitiskast": "socialpolitisk",
    "socialpolitiskaste": "socialpolitisk",
    "socialpolitiskastes": "socialpolitisk",
    "socialpolitiskasts": "socialpolitisk",
    "socialpolitiske": "socialpolitisk",
    "socialpolitiskes": "socialpolitisk",
    "socialpolitisks": "socialpolitisk",
    "socialpolitiskt": "socialpolitisk",
    "socialpolitiskts": "socialpolitisk",
    "socialpornografien": "socialpornografi",
    "socialpornografiens": "socialpornografi",
    "socialpornografin": "socialpornografi",
    "socialpornografins": "socialpornografi",
    "socialpornografis": "socialpornografi",
    "socialpsykologen": "socialpsykolog",
    "socialpsykologens": "socialpsykolog",
    "socialpsykologer": "socialpsykolog",
    "socialpsykologerna": "socialpsykolog",
    "socialpsykologernas": "socialpsykolog",
    "socialpsykologers": "socialpsykolog",
    "socialpsykologien": "socialpsykologi",
    "socialpsykologiens": "socialpsykologi",
    "socialpsykologin": "socialpsykologi",
    "socialpsykologins": "socialpsykologi",
    "socialpsykologis": "socialpsykologi",
    "socialpsykologs": "socialpsykolog",
    "socialrealismen": "socialrealism",
    "socialrealismens": "socialrealism",
    "socialrealismer": "socialrealism",
    "socialrealismerna": "socialrealism",
    "socialrealismernas": "socialrealism",
    "socialrealismers": "socialrealism",
    "socialrealisms": "socialrealism",
    "socialrealistiska": "socialrealistisk",
    "socialrealistiskas": "socialrealistisk",
    "socialrealistiske": "socialrealistisk",
    "socialrealistiskes": "socialrealistisk",
    "socialrealistisks": "socialrealistisk",
    "socialrealistiskt": "socialrealistisk",
    "socialrealistiskts": "socialrealistisk",
    "socialregisterna": "socialregister",
    "socialregisternas": "socialregister",
    "socialregisters": "socialregister",
    "socialregistren": "socialregister",
    "socialregistrens": "socialregister",
    "socialregistret": "socialregister",
    "socialregistrets": "socialregister",
    "socialreportagen": "socialreportage",
    "socialreportagens": "socialreportage",
    "socialreportages": "socialreportage",
    "socialreportaget": "socialreportage",
    "socialreportagets": "socialreportage",
    "socials": "social",
    "socialstyrelsen": "socialstyrelse",
    "socialstyrelsens": "socialstyrelse",
    "socialstyrelses": "socialstyrelse",
    "socialt": "social",
    "socialtjänsten": "socialtjänst",
    "socialtjänstens": "socialtjänst",
    "socialtjänsts": "socialtjänst",
    "socialts": "social",
    "socialvetenskapen": "socialvetenskap",
    "socialvetenskapens": "socialvetenskap",
    "socialvetenskaper": "socialvetenskap",
    "socialvetenskaperna": "socialvetenskap",
    "socialvetenskapernas": "socialvetenskap",
    "socialvetenskapers": "socialvetenskap",
    "socialvetenskaps": "socialvetenskap",
    "socialvården": "socialvård",
    "socialvårdens": "socialvård",
    "socialvårds": "socialvård",
    "societeten": "societet",
    "societetens": "societet",
    "societeter": "societet",
    "societeterna": "societet",
    "societeternas": "societet",
    "societeters": "societet",
    "societets": "societet",
    "societetshusen": "societetshus",
    "societetshusens": "societetshus",
    "societetshuset": "societetshus",
    "societetshusets": "societetshus",
    "societetslejonen": "societetslejon",
    "societetslejonens": "societetslejon",
    "societetslejonet": "societetslejon",
    "societetslejonets": "societetslejon",
    "societetslejons": "societetslejon",
    "societetssteg": "societetsstege",
    "societetsstegar": "societetsstege",
    "societetsstegarna": "societetsstege",
    "societetsstegarnas": "societetsstege",
    "societetsstegars": "societetsstege",
    "societetsstegen": "societetsstege",
    "societetsstegens": "societetsstege",
    "societetssteges": "societetsstege",
    "societetsstegs": "societetsstege",
    "socioekonomiska": "socioekonomisk",
    "socioekonomiskare": "socioekonomisk",
    "socioekonomiskares": "socioekonomisk",
    "socioekonomiskas": "socioekonomisk",
    "socioekonomiskast": "socioekonomisk",
    "socioekonomiskaste": "socioekonomisk",
    "socioekonomiskastes": "socioekonomisk",
    "socioekonomiskasts": "socioekonomisk",
    "socioekonomiske": "socioekonomisk",
    "socioekonomiskes": "socioekonomisk",
    "socioekonomisks": "socioekonomisk",
    "socioekonomiskt": "socioekonomisk",
    "socioekonomiskts": "socioekonomisk",
    "sociogrammen": "sociogram",
    "sociogrammens": "sociogram",
    "sociogrammet": "sociogram",
    "sociogrammets": "sociogram",
    "sociograms": "sociogram",
    "sociolekten": "sociolekt",
    "sociolektens": "sociolekt",
    "sociolekter": "sociolekt",
    "sociolekterna": "sociolekt",
    "sociolekternas": "sociolekt",
    "sociolekters": "sociolekt",
    "sociolekts": "sociolekt",
    "sociolingvistiken": "sociolingvistik",
    "sociolingvistikens": "sociolingvistik",
    "sociolingvistiks": "sociolingvistik",
    "sociologen": "sociolog",
    "sociologens": "sociolog",
    "sociologer": "sociolog",
    "sociologerna": "sociolog",
    "sociologernas": "sociolog",
    "sociologers": "sociolog",
    "sociologien": "sociologi",
    "sociologiens": "sociologi",
    "sociologin": "sociologi",
    "sociologins": "sociologi",
    "sociologis": "sociologi",
    "sociologiska": "sociologisk",
    "sociologiskare": "sociologisk",
    "sociologiskares": "sociologisk",
    "sociologiskas": "sociologisk",
    "sociologiskast": "sociologisk",
    "sociologiskaste": "sociologisk",
    "sociologiskastes": "sociologisk",
    "sociologiskasts": "sociologisk",
    "sociologiske": "sociologisk",
    "sociologiskes": "sociologisk",
    "sociologisks": "sociologisk",
    "sociologiskt": "sociologisk",
    "sociologiskts": "sociologisk",
    "sociologs": "sociolog",
    "socionomen": "socionom",
    "socionomens": "socionom",
    "socionomer": "socionom",
    "socionomerna": "socionom",
    "socionomernas": "socionom",
    "socionomers": "socionom",
    "socionoms": "socionom",
    "sociopaten": "sociopat",
    "sociopatens": "sociopat",
    "sociopater": "sociopat",
    "sociopaterna": "sociopat",
    "sociopaternas": "sociopat",
    "sociopaters": "sociopat",
    "sociopats": "sociopat",
    "socioterapien": "socioterapi",
    "socioterapiens": "socioterapi",
    "socioterapin": "socioterapi",
    "socioterapins": "socioterapi",
    "socioterapis": "socioterapi",
    "sock": "socka",
    "sockan": "socka",
    "sockans": "socka",
    "sockas": "socka",
    "socke": "socka",
    "sockeln": "sockel",
    "sockelns": "sockel",
    "sockels": "sockel",
    "sockenbuden": "sockenbud",
    "sockenbudens": "sockenbud",
    "sockenbudet": "sockenbud",
    "sockenbudets": "sockenbud",
    "sockenbuds": "sockenbud",
    "sockendräkten": "sockendräkt",
    "sockendräktens": "sockendräkt",
    "sockendräkter": "sockendräkt",
    "sockendräkterna": "sockendräkt",
    "sockendräkternas": "sockendräkt",
    "sockendräkters": "sockendräkt",
    "sockendräkts": "sockendräkt",
    "sockengången": "sockengång",
    "sockengångens": "sockengång",
    "sockengångs": "sockengång",
    "sockens": "socken",
    "sockenstugan": "sockenstuga",
    "sockenstugans": "sockenstuga",
    "sockenstugas": "sockenstuga",
    "sockenstuge": "sockenstuga",
    "sockenstugor": "sockenstuga",
    "sockenstugorna": "sockenstuga",
    "sockenstugornas": "sockenstuga",
    "sockenstugors": "sockenstuga",
    "sockenstugu": "sockenstuga",
    "sockerarten": "sockerart",
    "sockerartens": "sockerart",
    "sockerarter": "sockerart",
    "sockerarterna": "sockerart",
    "sockerarternas": "sockerart",
    "sockerarters": "sockerart",
    "sockerarts": "sockerart",
    "sockerbagar": "sockerbagare",
    "sockerbagaren": "sockerbagare",
    "sockerbagarens": "sockerbagare",
    "sockerbagares": "sockerbagare",
    "sockerbagarna": "sockerbagare",
    "sockerbagarnas": "sockerbagare",
    "sockerbagerier": "sockerbageri",
    "sockerbagerierna": "sockerbageri",
    "sockerbageriernas": "sockerbageri",
    "sockerbageriers": "sockerbageri",
    "sockerbageriet": "sockerbageri",
    "sockerbageriets": "sockerbageri",
    "sockerbageris": "sockerbageri",
    "sockerbagerit": "sockerbageri",
    "sockerbagerits": "sockerbageri",
    "sockerbet": "sockerbeta",
    "sockerbetan": "sockerbeta",
    "sockerbetans": "sockerbeta",
    "sockerbetas": "sockerbeta",
    "sockerbete": "sockerbeta",
    "sockerbetor": "sockerbeta",
    "sockerbetorna": "sockerbeta",
    "sockerbetornas": "sockerbeta",
    "sockerbetors": "sockerbeta",
    "sockerbets": "sockerbeta",
    "sockerbetssaften": "sockerbetssaft",
    "sockerbetssaftens": "sockerbetssaft",
    "sockerbetssafter": "sockerbetssaft",
    "sockerbetssafterna": "sockerbetssaft",
    "sockerbetssafternas": "sockerbetssaft",
    "sockerbetssafters": "sockerbetssaft",
    "sockerbetssafts": "sockerbetssaft",
    "sockerbildningar": "sockerbildning",
    "sockerbildningarna": "sockerbildning",
    "sockerbildningarnas": "sockerbildning",
    "sockerbildningars": "sockerbildning",
    "sockerbildningen": "sockerbildning",
    "sockerbildningens": "sockerbildning",
    "sockerbildnings": "sockerbildning",
    "sockerbindningar": "sockerbindning",
    "sockerbindningarna": "sockerbindning",
    "sockerbindningarnas": "sockerbindning",
    "sockerbindningars": "sockerbindning",
    "sockerbindningen": "sockerbindning",
    "sockerbindningens": "sockerbindning",
    "sockerbindnings": "sockerbindning",
    "sockerbitar": "sockerbit",
    "sockerbitarna": "sockerbit",
    "sockerbitarnas": "sockerbit",
    "sockerbitars": "sockerbit",
    "sockerbiten": "sockerbit",
    "sockerbitens": "sockerbit",
    "sockerbits": "sockerbit",
    "sockerbruken": "sockerbruk",
    "sockerbrukens": "sockerbruk",
    "sockerbruket": "sockerbruk",
    "sockerbrukets": "sockerbruk",
    "sockerbruks": "sockerbruk",
    "sockerdrick": "sockerdricka",
    "sockerdrickan": "sockerdricka",
    "sockerdrickans": "sockerdricka",
    "sockerdrickas": "sockerdricka",
    "sockerdricke": "sockerdricka",
    "sockerdrickor": "sockerdricka",
    "sockerdrickorna": "sockerdricka",
    "sockerdrickornas": "sockerdricka",
    "sockerdrickors": "sockerdricka",
    "sockerdricks": "sockerdricka",
    "sockerfria": "sockerfri",
    "sockerfriare": "sockerfri",
    "sockerfriares": "sockerfri",
    "sockerfrias": "sockerfri",
    "sockerfriast": "sockerfri",
    "sockerfriaste": "sockerfri",
    "sockerfriastes": "sockerfri",
    "sockerfriasts": "sockerfri",
    "sockerfrie": "sockerfri",
    "sockerfries": "sockerfri",
    "sockerfris": "sockerfri",
    "sockerfritt": "sockerfri",
    "sockerfritts": "sockerfri",
    "sockerglasyren": "sockerglasyr",
    "sockerglasyrens": "sockerglasyr",
    "sockerglasyrer": "sockerglasyr",
    "sockerglasyrerna": "sockerglasyr",
    "sockerglasyrernas": "sockerglasyr",
    "sockerglasyrers": "sockerglasyr",
    "sockerglasyrs": "sockerglasyr",
    "sockergrynen": "sockergryn",
    "sockergrynens": "sockergryn",
    "sockergrynet": "sockergryn",
    "sockergrynets": "sockergryn",
    "sockergryns": "sockergryn",
    "sockerhalten": "sockerhalt",
    "sockerhaltens": "sockerhalt",
    "sockerhalter": "sockerhalt",
    "sockerhalterna": "sockerhalt",
    "sockerhalternas": "sockerhalt",
    "sockerhalters": "sockerhalt",
    "sockerhaltiga": "sockerhaltig",
    "sockerhaltigare": "sockerhaltig",
    "sockerhaltigares": "sockerhaltig",
    "sockerhaltigas": "sockerhaltig",
    "sockerhaltigast": "sockerhaltig",
    "sockerhaltigaste": "sockerhaltig",
    "sockerhaltigastes": "sockerhaltig",
    "sockerhaltigasts": "sockerhaltig",
    "sockerhaltige": "sockerhaltig",
    "sockerhaltiges": "sockerhaltig",
    "sockerhaltigheten": "sockerhaltighet",
    "sockerhaltighetens": "sockerhaltighet",
    "sockerhaltighets": "sockerhaltighet",
    "sockerhaltigs": "sockerhaltig",
    "sockerhaltigt": "sockerhaltig",
    "sockerhaltigts": "sockerhaltig",
    "sockerhalts": "sockerhalt",
    "sockerkak": "sockerkaka",
    "sockerkakan": "sockerkaka",
    "sockerkakans": "sockerkaka",
    "sockerkakas": "sockerkaka",
    "sockerkake": "sockerkaka",
    "sockerkakor": "sockerkaka",
    "sockerkakorna": "sockerkaka",
    "sockerkakornas": "sockerkaka",
    "sockerkakors": "sockerkaka",
    "sockerkaks": "sockerkaka",
    "sockerkakssmeten": "sockerkakssmet",
    "sockerkakssmetens": "sockerkakssmet",
    "sockerkakssmets": "sockerkakssmet",
    "sockerkampanjen": "sockerkampanj",
    "sockerkampanjens": "sockerkampanj",
    "sockerkampanjer": "sockerkampanj",
    "sockerkampanjerna": "sockerkampanj",
    "sockerkampanjernas": "sockerkampanj",
    "sockerkampanjers": "sockerkampanj",
    "sockerkampanjs": "sockerkampanj",
    "sockerkisten": "sockerkist",
    "sockerkistens": "sockerkist",
    "sockerkists": "sockerkist",
    "sockerkulören": "sockerkulör",
    "sockerkulörens": "sockerkulör",
    "sockerkulörs": "sockerkulör",
    "sockerlagen": "sockerlag",
    "sockerlagens": "sockerlag",
    "sockerlags": "sockerlag",
    "sockerlönnar": "sockerlönn",
    "sockerlönnarna": "sockerlönn",
    "sockerlönnarnas": "sockerlönn",
    "sockerlönnars": "sockerlönn",
    "sockerlönnen": "sockerlönn",
    "sockerlönnens": "sockerlönn",
    "sockerlönns": "sockerlönn",
    "sockermolekylen": "sockermolekyl",
    "sockermolekylens": "sockermolekyl",
    "sockermolekyler": "sockermolekyl",
    "sockermolekylerna": "sockermolekyl",
    "sockermolekylernas": "sockermolekyl",
    "sockermolekylers": "sockermolekyl",
    "sockermolekyls": "sockermolekyl",
    "sockermässiga": "sockermässig",
    "sockermässigare": "sockermässig",
    "sockermässigares": "sockermässig",
    "sockermässigas": "sockermässig",
    "sockermässigast": "sockermässig",
    "sockermässigaste": "sockermässig",
    "sockermässigastes": "sockermässig",
    "sockermässigasts": "sockermässig",
    "sockermässige": "sockermässig",
    "sockermässiges": "sockermässig",
    "sockermässigs": "sockermässig",
    "sockermässigt": "sockermässig",
    "sockermässigts": "sockermässig",
    "sockerpillerna": "sockerpiller",
    "sockerpillernas": "sockerpiller",
    "sockerpillers": "sockerpiller",
    "sockerpillren": "sockerpiller",
    "sockerpillrens": "sockerpiller",
    "sockerpillret": "sockerpiller",
    "sockerpillrets": "sockerpiller",
    "sockerpull": "sockerpulla",
    "sockerpullan": "sockerpulla",
    "sockerpullans": "sockerpulla",
    "sockerpullas": "sockerpulla",
    "sockerpulle": "sockerpulla",
    "sockerpullor": "sockerpulla",
    "sockerpullorna": "sockerpulla",
    "sockerpullornas": "sockerpulla",
    "sockerpullors": "sockerpulla",
    "sockerpulls": "sockerpulla",
    "sockerraffinaderier": "sockerraffinaderi",
    "sockerraffinaderierna": "sockerraffinaderi",
    "sockerraffinaderiernas": "sockerraffinaderi",
    "sockerraffinaderiers": "sockerraffinaderi",
    "sockerraffinaderiet": "sockerraffinaderi",
    "sockerraffinaderiets": "sockerraffinaderi",
    "sockerraffinaderis": "sockerraffinaderi",
    "sockerraffinaderit": "sockerraffinaderi",
    "sockerraffinaderits": "sockerraffinaderi",
    "sockerrika": "sockerrik",
    "sockerrikare": "sockerrik",
    "sockerrikares": "sockerrik",
    "sockerrikas": "sockerrik",
    "sockerrikast": "sockerrik",
    "sockerrikaste": "sockerrik",
    "sockerrikastes": "sockerrik",
    "sockerrikasts": "sockerrik",
    "sockerrike": "sockerrik",
    "sockerrikes": "sockerrik",
    "sockerrikheten": "sockerrikhet",
    "sockerrikhetens": "sockerrikhet",
    "sockerrikhets": "sockerrikhet",
    "sockerriks": "sockerrik",
    "sockerrikt": "sockerrik",
    "sockerrikts": "sockerrik",
    "sockerroten": "sockerrot",
    "sockerrotens": "sockerrot",
    "sockerrots": "sockerrot",
    "sockerrören": "sockerrör",
    "sockerrörens": "sockerrör",
    "sockerröret": "sockerrör",
    "sockerrörets": "sockerrör",
    "sockerrörs": "sockerrör",
    "sockers": "socker",
    "sockersalt": "sockersalta",
    "sockersaltad": "sockersalta",
    "sockersaltade": "sockersalta",
    "sockersaltades": "sockersalta",
    "sockersaltads": "sockersalta",
    "sockersaltande": "sockersalta",
    "sockersaltanden": "sockersaltande",
    "sockersaltandena": "sockersaltande",
    "sockersaltandenas": "sockersaltande",
    "sockersaltandens": "sockersaltande",
    "sockersaltandes": "sockersaltande",
    "sockersaltandet": "sockersaltande",
    "sockersaltandets": "sockersaltande",
    "sockersaltar": "sockersalta",
    "sockersaltas": "sockersalta",
    "sockersaltat": "sockersalta",
    "sockersaltats": "sockersalta",
    "sockersjuka": "sockersjuk",
    "sockersjukan": "sockersjuka",
    "sockersjukans": "sockersjuka",
    "sockersjukare": "sockersjuk",
    "sockersjukares": "sockersjuk",
    "sockersjukas": "sockersjuka",
    "sockersjukast": "sockersjuk",
    "sockersjukaste": "sockersjuk",
    "sockersjukastes": "sockersjuk",
    "sockersjukasts": "sockersjuk",
    "sockersjuke": "sockersjuka",
    "sockersjukes": "sockersjuk",
    "sockersjuks": "sockersjuka",
    "sockersjukt": "sockersjuk",
    "sockersjukts": "sockersjuk",
    "sockerskorp": "sockerskorpa",
    "sockerskorpan": "sockerskorpa",
    "sockerskorpans": "sockerskorpa",
    "sockerskorpas": "sockerskorpa",
    "sockerskorpe": "sockerskorpa",
    "sockerskorpor": "sockerskorpa",
    "sockerskorporna": "sockerskorpa",
    "sockerskorpornas": "sockerskorpa",
    "sockerskorpors": "sockerskorpa",
    "sockerskorps": "sockerskorpa",
    "sockerskålar": "sockerskål",
    "sockerskålarna": "sockerskål",
    "sockerskålarnas": "sockerskål",
    "sockerskålars": "sockerskål",
    "sockerskålen": "sockerskål",
    "sockerskålens": "sockerskål",
    "sockerskåls": "sockerskål",
    "sockerströar": "sockerströare",
    "sockerströaren": "sockerströare",
    "sockerströarens": "sockerströare",
    "sockerströares": "sockerströare",
    "sockerströarna": "sockerströare",
    "sockerströarnas": "sockerströare",
    "sockersuget": "sockersug",
    "sockersugets": "sockersug",
    "sockersugs": "sockersug",
    "sockersöta": "sockersöt",
    "sockersötare": "sockersöt",
    "sockersötares": "sockersöt",
    "sockersötas": "sockersöt",
    "sockersötast": "sockersöt",
    "sockersötaste": "sockersöt",
    "sockersötastes": "sockersöt",
    "sockersötasts": "sockersöt",
    "sockersöte": "sockersöt",
    "sockersötes": "sockersöt",
    "sockersötheten": "sockersöthet",
    "sockersöthetens": "sockersöthet",
    "sockersöthets": "sockersöthet",
    "sockersöts": "sockersöt",
    "sockersött": "sockersöt",
    "sockersötts": "sockersöt",
    "sockertillverkningar": "sockertillverkning",
    "sockertillverkningarna": "sockertillverkning",
    "sockertillverkningarnas": "sockertillverkning",
    "sockertillverkningars": "sockertillverkning",
    "sockertillverkningen": "sockertillverkning",
    "sockertillverkningens": "sockertillverkning",
    "sockertillverknings": "sockertillverkning",
    "sockertoppar": "sockertopp",
    "sockertopparna": "sockertopp",
    "sockertopparnas": "sockertopp",
    "sockertoppars": "sockertopp",
    "sockertoppen": "sockertopp",
    "sockertoppens": "sockertopp",
    "sockertopps": "sockertopp",
    "sockertänger": "sockertång",
    "sockertängerna": "sockertång",
    "sockertängernas": "sockertång",
    "sockertängers": "sockertång",
    "sockertången": "sockertång",
    "sockertångens": "sockertång",
    "sockertångs": "sockertång",
    "sockervattens": "sockervatten",
    "sockervattnet": "sockervatten",
    "sockervattnets": "sockervatten",
    "sockerärterna": "sockerärter",
    "sockerärternas": "sockerärter",
    "sockerärters": "sockerärter",
    "sockerärts": "sockerärter",
    "sockeröverdragen": "sockeröverdrag",
    "sockeröverdragens": "sockeröverdrag",
    "sockeröverdraget": "sockeröverdrag",
    "sockeröverdragets": "sockeröverdrag",
    "sockeröverdrags": "sockeröverdrag",
    "socklar": "sockel",
    "socklarna": "sockel",
    "socklarnas": "sockel",
    "socklars": "sockel",
    "socknar": "socken",
    "socknarna": "socken",
    "socknarnas": "socken",
    "socknars": "socken",
    "socknen": "socken",
    "socknens": "socken",
    "sockor": "socka",
    "sockorna": "socka",
    "sockornas": "socka",
    "sockors": "socka",
    "sockrad": "sockra",
    "sockrade": "sockra",
    "sockrades": "sockra",
    "sockrads": "sockra",
    "sockrande": "sockra",
    "sockranden": "sockrande",
    "sockrandena": "sockrande",
    "sockrandenas": "sockrande",
    "sockrandens": "sockrande",
    "sockrandes": "sockrande",
    "sockrandet": "sockrande",
    "sockrandets": "sockrande",
    "sockrar": "sockra",
    "sockras": "sockra",
    "sockrat": "sockra",
    "sockrats": "sockra",
    "sockret": "socker",
    "sockrets": "socker",
    "sockriga": "sockrig",
    "sockrigare": "sockrig",
    "sockrigares": "sockrig",
    "sockrigas": "sockrig",
    "sockrigast": "sockrig",
    "sockrigaste": "sockrig",
    "sockrigastes": "sockrig",
    "sockrigasts": "sockrig",
    "sockrige": "sockrig",
    "sockriges": "sockrig",
    "sockrigheten": "sockrighet",
    "sockrighetens": "sockrighet",
    "sockrighets": "sockrighet",
    "sockrigs": "sockrig",
    "sockrigt": "sockrig",
    "sockrigts": "sockrig",
    "socks": "socka",
    "sodaglasen": "sodaglas",
    "sodaglasens": "sodaglas",
    "sodaglaset": "sodaglas",
    "sodaglasets": "sodaglas",
    "sodahalten": "sodahalt",
    "sodahaltens": "sodahalt",
    "sodahalter": "sodahalt",
    "sodahalterna": "sodahalt",
    "sodahalternas": "sodahalt",
    "sodahalters": "sodahalt",
    "sodahaltiga": "sodahaltig",
    "sodahaltigare": "sodahaltig",
    "sodahaltigares": "sodahaltig",
    "sodahaltigas": "sodahaltig",
    "sodahaltigast": "sodahaltig",
    "sodahaltigaste": "sodahaltig",
    "sodahaltigastes": "sodahaltig",
    "sodahaltigasts": "sodahaltig",
    "sodahaltige": "sodahaltig",
    "sodahaltiges": "sodahaltig",
    "sodahaltigs": "sodahaltig",
    "sodahaltigt": "sodahaltig",
    "sodahaltigts": "sodahaltig",
    "sodahalts": "sodahalt",
    "sodamassan": "sodamassa",
    "sodamassans": "sodamassa",
    "sodamassas": "sodamassa",
    "sodamasse": "sodamassa",
    "sodamassor": "sodamassa",
    "sodamassorna": "sodamassa",
    "sodamassornas": "sodamassa",
    "sodamassors": "sodamassa",
    "sodan": "soda",
    "sodans": "soda",
    "sodas": "soda",
    "sodavattens": "sodavatten",
    "sodavattnen": "sodavatten",
    "sodavattnens": "sodavatten",
    "sodavattnet": "sodavatten",
    "sodavattnets": "sodavatten",
    "sodaörten": "sodaört",
    "sodaörtens": "sodaört",
    "sodaörts": "sodaört",
    "sodomien": "sodomi",
    "sodomiens": "sodomi",
    "sodomin": "sodomi",
    "sodomins": "sodomi",
    "sodomis": "sodomi",
    "sodomsäpplen": "sodomsäpple",
    "sodomsäpplena": "sodomsäpple",
    "sodomsäpplenas": "sodomsäpple",
    "sodomsäpplens": "sodomsäpple",
    "sodomsäpples": "sodomsäpple",
    "sodomsäpplet": "sodomsäpple",
    "sodomsäpplets": "sodomsäpple",
    "sodomsäppls": "sodomsäpple",
    "soff": "soffa",
    "soffan": "soffa",
    "soffans": "soffa",
    "soffas": "soffa",
    "soffborden": "soffbord",
    "soffbordens": "soffbord",
    "soffbordet": "soffbord",
    "soffbordets": "soffbord",
    "soffbords": "soffbord",
    "soffe": "soffa",
    "soffgruppen": "soffgrupp",
    "soffgruppens": "soffgrupp",
    "soffgrupper": "soffgrupp",
    "soffgrupperna": "soffgrupp",
    "soffgruppernas": "soffgrupp",
    "soffgruppers": "soffgrupp",
    "soffgrupps": "soffgrupp",
    "soffiten": "soffit",
    "soffitens": "soffit",
    "soffiter": "soffit",
    "soffiterna": "soffit",
    "soffiternas": "soffit",
    "soffiters": "soffit",
    "soffits": "soffit",
    "soffliggar": "soffliggare",
    "soffliggaren": "soffliggare",
    "soffliggarens": "soffliggare",
    "soffliggares": "soffliggare",
    "soffliggarna": "soffliggare",
    "soffliggarnas": "soffliggare",
    "sofflocken": "sofflock",
    "sofflockens": "sofflock",
    "sofflocket": "sofflock",
    "sofflockets": "sofflock",
    "sofflocks": "sofflock",
    "soffor": "soffa",
    "sofforna": "soffa",
    "soffornas": "soffa",
    "soffors": "soffa",
    "soffpotatisar": "soffpotatis",
    "soffpotatisarna": "soffpotatis",
    "soffpotatisarnas": "soffpotatis",
    "soffpotatisars": "soffpotatis",
    "soffpotatisen": "soffpotatis",
    "soffpotatisens": "soffpotatis",
    "soffs": "soffa",
    "soffsurfade": "soffsurfa",
    "soffsurfades": "soffsurfa",
    "soffsurfande": "soffsurfa",
    "soffsurfanden": "soffsurfande",
    "soffsurfandena": "soffsurfande",
    "soffsurfandenas": "soffsurfande",
    "soffsurfandens": "soffsurfande",
    "soffsurfandes": "soffsurfande",
    "soffsurfandet": "soffsurfande",
    "soffsurfandets": "soffsurfande",
    "soffsurfar": "soffsurfa",
    "soffsurfas": "soffsurfa",
    "soffsurfat": "soffsurfa",
    "soffsurfats": "soffsurfa",
    "sofismen": "sofism",
    "sofismens": "sofism",
    "sofismer": "sofism",
    "sofismerna": "sofism",
    "sofismernas": "sofism",
    "sofismers": "sofism",
    "sofisms": "sofism",
    "sofisten": "sofist",
    "sofistens": "sofist",
    "sofister": "sofist",
    "sofisterier": "sofisteri",
    "sofisterierna": "sofisteri",
    "sofisteriernas": "sofisteri",
    "sofisteriers": "sofisteri",
    "sofisteriet": "sofisteri",
    "sofisteriets": "sofisteri",
    "sofisteris": "sofisteri",
    "sofisterit": "sofisteri",
    "sofisterits": "sofisteri",
    "sofisterna": "sofist",
    "sofisternas": "sofist",
    "sofisters": "sofist",
    "sofistiken": "sofistik",
    "sofistikens": "sofistik",
    "sofistikerade": "sofistikerad",
    "sofistikerades": "sofistikerad",
    "sofistikerads": "sofistikerad",
    "sofistikerat": "sofistikerad",
    "sofistikerats": "sofistikerad",
    "sofistiks": "sofistik",
    "sofistiska": "sofistisk",
    "sofistiskas": "sofistisk",
    "sofistiske": "sofistisk",
    "sofistiskes": "sofistisk",
    "sofistisks": "sofistisk",
    "sofistiskt": "sofistisk",
    "sofistiskts": "sofistisk",
    "sofists": "sofist",
    "softade": "softa",
    "softades": "softa",
    "softande": "softa",
    "softandes": "softa",
    "softar": "softa",
    "softas": "softa",
    "softat": "softa",
    "softats": "softa",
    "softwaren": "software",
    "softwarens": "software",
    "softwares": "software",
    "soignerade": "soignerad",
    "soignerades": "soignerad",
    "soignerads": "soignerad",
    "soignerat": "soignerad",
    "soignerats": "soignerad",
    "sojabiffar": "sojabiff",
    "sojabiffarna": "sojabiff",
    "sojabiffarnas": "sojabiff",
    "sojabiffars": "sojabiff",
    "sojabiffen": "sojabiff",
    "sojabiffens": "sojabiff",
    "sojabiffs": "sojabiff",
    "sojabön": "sojaböna",
    "sojabönan": "sojaböna",
    "sojabönans": "sojaböna",
    "sojabönas": "sojaböna",
    "sojaböne": "sojaböna",
    "sojabönor": "sojaböna",
    "sojabönorna": "sojaböna",
    "sojabönornas": "sojaböna",
    "sojabönors": "sojaböna",
    "sojaböns": "sojaböna",
    "sojakak": "sojakaka",
    "sojakakan": "sojakaka",
    "sojakakans": "sojakaka",
    "sojakakas": "sojakaka",
    "sojakake": "sojakaka",
    "sojakakor": "sojakaka",
    "sojakakorna": "sojakaka",
    "sojakakornas": "sojakaka",
    "sojakakors": "sojakaka",
    "sojakaks": "sojakaka",
    "sojamjölet": "sojamjöl",
    "sojamjölets": "sojamjöl",
    "sojamjölken": "sojamjölk",
    "sojamjölkens": "sojamjölk",
    "sojamjölks": "sojamjölk",
    "sojamjöls": "sojamjöl",
    "sojan": "soja",
    "sojans": "soja",
    "sojas": "soja",
    "sokratiska": "sokratisk",
    "sokratiskare": "sokratisk",
    "sokratiskares": "sokratisk",
    "sokratiskas": "sokratisk",
    "sokratiskast": "sokratisk",
    "sokratiskaste": "sokratisk",
    "sokratiskastes": "sokratisk",
    "sokratiskasts": "sokratisk",
    "sokratiske": "sokratisk",
    "sokratiskes": "sokratisk",
    "sokratisks": "sokratisk",
    "sokratiskt": "sokratisk",
    "sokratiskts": "sokratisk",
    "sol": "sola",
    "sol-och-vår": "sol-och-våra",
    "sol-och-vårad": "sol-och-våra",
    "sol-och-vårade": "sol-och-våra",
    "sol-och-vårades": "sol-och-våra",
    "sol-och-vårads": "sol-och-våra",
    "sol-och-vårande": "sol-och-våra",
    "sol-och-våranden": "sol-och-vårande",
    "sol-och-vårandena": "sol-och-vårande",
    "sol-och-vårandenas": "sol-och-vårande",
    "sol-och-vårandens": "sol-och-vårande",
    "sol-och-vårandes": "sol-och-vårande",
    "sol-och-vårandet": "sol-och-vårande",
    "sol-och-vårandets": "sol-och-vårande",
    "sol-och-vårar": "sol-och-vårare",
    "sol-och-våraren": "sol-och-vårare",
    "sol-och-vårarens": "sol-och-vårare",
    "sol-och-vårares": "sol-och-vårare",
    "sol-och-vårarna": "sol-och-vårare",
    "sol-och-vårarnas": "sol-och-vårare",
    "sol-och-våras": "sol-och-våra",
    "sol-och-vårat": "sol-och-våra",
    "sol-och-vårats": "sol-och-våra",
    "sol-och-vårs": "sol-och-vår",
    "solad": "sola",
    "solade": "sola",
    "solades": "sola",
    "solads": "sola",
    "solande": "sola",
    "solanden": "solande",
    "solandena": "solande",
    "solandenas": "solande",
    "solandens": "solande",
    "solandes": "solande",
    "solandet": "solande",
    "solandets": "solande",
    "solaninen": "solanin",
    "solaninens": "solanin",
    "solaniner": "solanin",
    "solaninerna": "solanin",
    "solaninernas": "solanin",
    "solaniners": "solanin",
    "solaninet": "solanin",
    "solaninets": "solanin",
    "solanins": "solanin",
    "solar": "sola",
    "solara": "solar",
    "solarare": "solar",
    "solarares": "solar",
    "solaras": "solar",
    "solarast": "solar",
    "solaraste": "solar",
    "solarastes": "solar",
    "solarasts": "solar",
    "solare": "solar",
    "solares": "solar",
    "solarie": "solarium",
    "solarier": "solarium",
    "solarierna": "solarium",
    "solariernas": "solarium",
    "solariers": "solarium",
    "solariet": "solarium",
    "solariets": "solarium",
    "solariska": "solarisk",
    "solariskare": "solarisk",
    "solariskares": "solarisk",
    "solariskas": "solarisk",
    "solariskast": "solarisk",
    "solariskaste": "solarisk",
    "solariskastes": "solarisk",
    "solariskasts": "solarisk",
    "solariske": "solarisk",
    "solariskes": "solarisk",
    "solarisks": "solarisk",
    "solariskt": "solarisk",
    "solariskts": "solarisk",
    "solariums": "solarium",
    "solarna": "sol",
    "solarnas": "sol",
    "solars": "solar",
    "solart": "solar",
    "solarts": "solar",
    "solas": "sola",
    "solat": "sola",
    "solats": "sola",
    "solaväxeln": "solaväxel",
    "solaväxelns": "solaväxel",
    "solaväxels": "solaväxel",
    "solaväxlar": "solaväxel",
    "solaväxlarna": "solaväxel",
    "solaväxlarnas": "solaväxel",
    "solaväxlars": "solaväxel",
    "solbad": "solbada",
    "solbadad": "solbada",
    "solbadade": "solbada",
    "solbadades": "solbada",
    "solbadads": "solbada",
    "solbadande": "solbada",
    "solbadanden": "solbadande",
    "solbadandena": "solbadande",
    "solbadandenas": "solbadande",
    "solbadandens": "solbadande",
    "solbadandes": "solbadande",
    "solbadandet": "solbadande",
    "solbadandets": "solbadande",
    "solbadar": "solbada",
    "solbadas": "solbada",
    "solbadat": "solbada",
    "solbadats": "solbada",
    "solbaden": "solbad",
    "solbadens": "solbad",
    "solbadet": "solbad",
    "solbadets": "solbad",
    "solbads": "solbad",
    "solbatterier": "solbatteri",
    "solbatterierna": "solbatteri",
    "solbatteriernas": "solbatteri",
    "solbatteriers": "solbatteri",
    "solbatteriet": "solbatteri",
    "solbatteriets": "solbatteri",
    "solbatteris": "solbatteri",
    "solbatterit": "solbatteri",
    "solbatterits": "solbatteri",
    "solbelysningar": "solbelysning",
    "solbelysningarna": "solbelysning",
    "solbelysningarnas": "solbelysning",
    "solbelysningars": "solbelysning",
    "solbelysningen": "solbelysning",
    "solbelysningens": "solbelysning",
    "solbelysnings": "solbelysning",
    "solbelysta": "solbelyst",
    "solbelystare": "solbelyst",
    "solbelystares": "solbelyst",
    "solbelystas": "solbelyst",
    "solbelystast": "solbelyst",
    "solbelystaste": "solbelyst",
    "solbelystastes": "solbelyst",
    "solbelystasts": "solbelyst",
    "solbelyste": "solbelyst",
    "solbelystes": "solbelyst",
    "solbelysts": "solbelyst",
    "solbestrålningar": "solbestrålning",
    "solbestrålningarna": "solbestrålning",
    "solbestrålningarnas": "solbestrålning",
    "solbestrålningars": "solbestrålning",
    "solbestrålningen": "solbestrålning",
    "solbestrålningens": "solbestrålning",
    "solbestrålnings": "solbestrålning",
    "solblekta": "solblekt",
    "solblektare": "solblekt",
    "solblektares": "solblekt",
    "solblektas": "solblekt",
    "solblektast": "solblekt",
    "solblektaste": "solblekt",
    "solblektastes": "solblekt",
    "solblektasts": "solblekt",
    "solblekte": "solblekt",
    "solblektes": "solblekt",
    "solblekts": "solblekt",
    "solblinda": "solblind",
    "solblindare": "solblind",
    "solblindares": "solblind",
    "solblindas": "solblind",
    "solblindast": "solblind",
    "solblindaste": "solblind",
    "solblindastes": "solblind",
    "solblindasts": "solblind",
    "solblinde": "solblind",
    "solblindes": "solblind",
    "solblindheten": "solblindhet",
    "solblindhetens": "solblindhet",
    "solblindheter": "solblindhet",
    "solblindheterna": "solblindhet",
    "solblindheternas": "solblindhet",
    "solblindheters": "solblindhet",
    "solblindhets": "solblindhet",
    "solblinds": "solblind",
    "solblint": "solblind",
    "solblints": "solblind",
    "solbrända": "solbränd",
    "solbrändare": "solbränd",
    "solbrändares": "solbränd",
    "solbrändas": "solbränd",
    "solbrändast": "solbränd",
    "solbrändaste": "solbränd",
    "solbrändastes": "solbränd",
    "solbrändasts": "solbränd",
    "solbrände": "solbränd",
    "solbrändes": "solbränd",
    "solbrändheten": "solbrändhet",
    "solbrändhetens": "solbrändhet",
    "solbrändhets": "solbrändhet",
    "solbränds": "solbränd",
    "solbrännan": "solbränna",
    "solbrännans": "solbränna",
    "solbrännas": "solbränna",
    "solbränt": "solbränd",
    "solbränts": "solbränd",
    "solbänkar": "solbänk",
    "solbänkarna": "solbänk",
    "solbänkarnas": "solbänk",
    "solbänkars": "solbänk",
    "solbänken": "solbänk",
    "solbänkens": "solbänk",
    "solbänks": "solbänk",
    "solbärgningar": "solbärgning",
    "solbärgningarna": "solbärgning",
    "solbärgningarnas": "solbärgning",
    "solbärgningars": "solbärgning",
    "solbärgningen": "solbärgning",
    "solbärgningens": "solbärgning",
    "solbärgnings": "solbärgning",
    "solcellen": "solcell",
    "solcellens": "solcell",
    "solceller": "solcell",
    "solcellerna": "solcell",
    "solcellernas": "solcell",
    "solcellers": "solcell",
    "solcells": "solcell",
    "solcellsanläggningar": "solcellsanläggning",
    "solcellsanläggningarna": "solcellsanläggning",
    "solcellsanläggningarnas": "solcellsanläggning",
    "solcellsanläggningars": "solcellsanläggning",
    "solcellsanläggningen": "solcellsanläggning",
    "solcellsanläggningens": "solcellsanläggning",
    "solcellsanläggnings": "solcellsanläggning",
    "solcellspanelen": "solcellspanel",
    "solcellspanelens": "solcellspanel",
    "solcellspaneler": "solcellspanel",
    "solcellspanelerna": "solcellspanel",
    "solcellspanelernas": "solcellspanel",
    "solcellspanelers": "solcellspanel",
    "solcellspanels": "solcellspanel",
    "solcellsväsk": "solcellsväska",
    "solcellsväskan": "solcellsväska",
    "solcellsväskans": "solcellsväska",
    "solcellsväskas": "solcellsväska",
    "solcellsväske": "solcellsväska",
    "solcellsväskor": "solcellsväska",
    "solcellsväskorna": "solcellsväska",
    "solcellsväskornas": "solcellsväska",
    "solcellsväskors": "solcellsväska",
    "solcirkeln": "solcirkel",
    "solcirkelns": "solcirkel",
    "solcirkels": "solcirkel",
    "solcirklar": "solcirkel",
    "solcirklarna": "solcirkel",
    "solcirklarnas": "solcirkel",
    "solcirklars": "solcirkel",
    "solcykeln": "solcykel",
    "solcykelns": "solcykel",
    "solcykels": "solcykel",
    "solcyklar": "solcykel",
    "solcyklarna": "solcykel",
    "solcyklarnas": "solcykel",
    "solcyklars": "solcykel",
    "solcykler": "solcykel",
    "solcyklerna": "solcykel",
    "solcyklernas": "solcykel",
    "solcyklers": "solcykel",
    "soldagar": "soldag",
    "soldagarna": "soldag",
    "soldagarnas": "soldag",
    "soldagars": "soldag",
    "soldagen": "soldag",
    "soldagens": "soldag",
    "soldags": "soldag",
    "soldaten": "soldat",
    "soldatens": "soldat",
    "soldater": "soldat",
    "soldaterna": "soldat",
    "soldaternas": "soldat",
    "soldaters": "soldat",
    "soldatesken": "soldatesk",
    "soldateskens": "soldatesk",
    "soldatesks": "soldatesk",
    "soldatfiguren": "soldatfigur",
    "soldatfigurens": "soldatfigur",
    "soldatfigurer": "soldatfigur",
    "soldatfigurerna": "soldatfigur",
    "soldatfigurernas": "soldatfigur",
    "soldatfigurers": "soldatfigur",
    "soldatfigurs": "soldatfigur",
    "soldathemmen": "soldathem",
    "soldathemmens": "soldathem",
    "soldathemmet": "soldathem",
    "soldathemmets": "soldathem",
    "soldathems": "soldathem",
    "soldathopar": "soldathop",
    "soldathoparna": "soldathop",
    "soldathoparnas": "soldathop",
    "soldathopars": "soldathop",
    "soldathopen": "soldathop",
    "soldathopens": "soldathop",
    "soldathops": "soldathop",
    "soldatkapp": "soldatkappa",
    "soldatkappan": "soldatkappa",
    "soldatkappans": "soldatkappa",
    "soldatkappas": "soldatkappa",
    "soldatkappe": "soldatkappa",
    "soldatkappor": "soldatkappa",
    "soldatkapporna": "soldatkappa",
    "soldatkappornas": "soldatkappa",
    "soldatkappors": "soldatkappa",
    "soldatkapps": "soldatkappa",
    "soldatmässiga": "soldatmässig",
    "soldatmässigare": "soldatmässig",
    "soldatmässigares": "soldatmässig",
    "soldatmässigas": "soldatmässig",
    "soldatmässigast": "soldatmässig",
    "soldatmässigaste": "soldatmässig",
    "soldatmässigastes": "soldatmässig",
    "soldatmässigasts": "soldatmässig",
    "soldatmässige": "soldatmässig",
    "soldatmässiges": "soldatmässig",
    "soldatmässigs": "soldatmässig",
    "soldatmässigt": "soldatmässig",
    "soldatmässigts": "soldatmässig",
    "soldatnamnen": "soldatnamn",
    "soldatnamnens": "soldatnamn",
    "soldatnamnet": "soldatnamn",
    "soldatnamnets": "soldatnamn",
    "soldatnamns": "soldatnamn",
    "soldatrockar": "soldatrock",
    "soldatrockarna": "soldatrock",
    "soldatrockarnas": "soldatrock",
    "soldatrockars": "soldatrock",
    "soldatrocken": "soldatrock",
    "soldatrockens": "soldatrock",
    "soldatrocks": "soldatrock",
    "soldats": "soldat",
    "soldattorpen": "soldattorp",
    "soldattorpens": "soldattorp",
    "soldattorpet": "soldattorp",
    "soldattorpets": "soldattorp",
    "soldattorps": "soldattorp",
    "soldatutrustningar": "soldatutrustning",
    "soldatutrustningarna": "soldatutrustning",
    "soldatutrustningarnas": "soldatutrustning",
    "soldatutrustningars": "soldatutrustning",
    "soldatutrustningen": "soldatutrustning",
    "soldatutrustningens": "soldatutrustning",
    "soldatutrustnings": "soldatutrustning",
    "solden": "sold",
    "soldens": "sold",
    "soldenären": "soldenär",
    "soldenärens": "soldenär",
    "soldenärer": "soldenär",
    "soldenärerna": "soldenär",
    "soldenärernas": "soldenär",
    "soldenärers": "soldenär",
    "soldenärs": "soldenär",
    "soldiset": "soldis",
    "soldisets": "soldis",
    "soldnären": "soldnär",
    "soldnärens": "soldnär",
    "soldnärer": "soldnär",
    "soldnärerna": "soldnär",
    "soldnärernas": "soldnär",
    "soldnärers": "soldnär",
    "soldnärs": "soldnär",
    "soldruckens": "soldrucken",
    "soldrucket": "soldrucken",
    "soldruckets": "soldrucken",
    "soldruckna": "soldrucken",
    "soldrucknare": "soldrucken",
    "soldrucknares": "soldrucken",
    "soldrucknas": "soldrucken",
    "soldrucknast": "soldrucken",
    "soldrucknaste": "soldrucken",
    "soldrucknastes": "soldrucken",
    "soldrucknasts": "soldrucken",
    "soldruckne": "soldrucken",
    "soldrucknes": "soldrucken",
    "soldräkten": "soldräkt",
    "soldräktens": "soldräkt",
    "soldräkter": "soldräkt",
    "soldräkterna": "soldräkt",
    "soldräkternas": "soldräkt",
    "soldräkters": "soldräkt",
    "soldräkts": "soldräkt",
    "solds": "sold",
    "soldygnen": "soldygn",
    "soldygnens": "soldygn",
    "soldygnet": "soldygn",
    "soldygnets": "soldygn",
    "soldygns": "soldygn",
    "soldyrkans": "soldyrkan",
    "soldyrkar": "soldyrkare",
    "soldyrkaren": "soldyrkare",
    "soldyrkarens": "soldyrkare",
    "soldyrkares": "soldyrkare",
    "soldyrkarna": "soldyrkare",
    "soldyrkarnas": "soldyrkare",
    "soleksemen": "soleksem",
    "soleksemens": "soleksem",
    "soleksemet": "soleksem",
    "soleksemets": "soleksem",
    "soleksems": "soleksem",
    "solen": "sol",
    "solenergien": "solenergi",
    "solenergiens": "solenergi",
    "solenergin": "solenergi",
    "solenergins": "solenergi",
    "solenergis": "solenergi",
    "solenergiteknologien": "solenergiteknologi",
    "solenergiteknologiens": "solenergiteknologi",
    "solenergiteknologier": "solenergiteknologi",
    "solenergiteknologierna": "solenergiteknologi",
    "solenergiteknologiernas": "solenergiteknologi",
    "solenergiteknologiers": "solenergiteknologi",
    "solenergiteknologin": "solenergiteknologi",
    "solenergiteknologins": "solenergiteknologi",
    "solenergiteknologis": "solenergiteknologi",
    "solenna": "solenn",
    "solennare": "solenn",
    "solennares": "solenn",
    "solennas": "solenn",
    "solennast": "solenn",
    "solennaste": "solenn",
    "solennastes": "solenn",
    "solennasts": "solenn",
    "solenne": "solenn",
    "solennes": "solenn",
    "solenniteten": "solennitet",
    "solennitetens": "solennitet",
    "solenniteter": "solennitet",
    "solenniteterna": "solennitet",
    "solenniteternas": "solennitet",
    "solenniteters": "solennitet",
    "solennitets": "solennitet",
    "solenns": "solenn",
    "solens": "sol",
    "solent": "solenn",
    "solents": "solenn",
    "solfallen": "solfall",
    "solfallens": "solfall",
    "solfallet": "solfall",
    "solfallets": "solfall",
    "solfalls": "solfall",
    "solfataren": "solfatar",
    "solfatarens": "solfatar",
    "solfatarer": "solfatar",
    "solfatarerna": "solfatar",
    "solfatarernas": "solfatar",
    "solfatarers": "solfatar",
    "solfatars": "solfatar",
    "solfattiga": "solfattig",
    "solfattigare": "solfattig",
    "solfattigares": "solfattig",
    "solfattigas": "solfattig",
    "solfattigast": "solfattig",
    "solfattigaste": "solfattig",
    "solfattigastes": "solfattig",
    "solfattigasts": "solfattig",
    "solfattige": "solfattig",
    "solfattiges": "solfattig",
    "solfattigheten": "solfattighet",
    "solfattighetens": "solfattighet",
    "solfattighets": "solfattighet",
    "solfattigs": "solfattig",
    "solfattigt": "solfattig",
    "solfattigts": "solfattig",
    "solfesten": "solfest",
    "solfestens": "solfest",
    "solfester": "solfest",
    "solfesterna": "solfest",
    "solfesternas": "solfest",
    "solfesters": "solfest",
    "solfests": "solfest",
    "solfjädern": "solfjäder",
    "solfjäderns": "solfjäder",
    "solfjäders": "solfjäder",
    "solfjädrar": "solfjäder",
    "solfjädrarna": "solfjäder",
    "solfjädrarnas": "solfjäder",
    "solfjädrars": "solfjäder",
    "solfloden": "solflod",
    "solflodens": "solflod",
    "solfloder": "solflod",
    "solfloderna": "solflod",
    "solflodernas": "solflod",
    "solfloders": "solflod",
    "solflods": "solflod",
    "solfläckar": "solfläck",
    "solfläckarna": "solfläck",
    "solfläckarnas": "solfläck",
    "solfläckars": "solfläck",
    "solfläcken": "solfläck",
    "solfläckens": "solfläck",
    "solfläcks": "solfläck",
    "solförmörkelsen": "solförmörkelse",
    "solförmörkelsens": "solförmörkelse",
    "solförmörkelser": "solförmörkelse",
    "solförmörkelserna": "solförmörkelse",
    "solförmörkelsernas": "solförmörkelse",
    "solförmörkelsers": "solförmörkelse",
    "solförmörkelses": "solförmörkelse",
    "solgasset": "solgass",
    "solgassets": "solgass",
    "solgat": "solgata",
    "solgatan": "solgata",
    "solgatans": "solgata",
    "solgatas": "solgata",
    "solgate": "solgata",
    "solgator": "solgata",
    "solgatorna": "solgata",
    "solgatornas": "solgata",
    "solgators": "solgata",
    "solgats": "solgata",
    "solglasögonen": "solglasögon",
    "solglasögonens": "solglasögon",
    "solglasögons": "solglasögon",
    "solgudar": "solgud",
    "solgudarna": "solgud",
    "solgudarnas": "solgud",
    "solgudars": "solgud",
    "solguden": "solgud",
    "solgudens": "solgud",
    "solguds": "solgud",
    "solgula": "solgul",
    "solgulare": "solgul",
    "solgulares": "solgul",
    "solgulas": "solgul",
    "solgulast": "solgul",
    "solgulaste": "solgul",
    "solgulastes": "solgul",
    "solgulasts": "solgul",
    "solgule": "solgul",
    "solgules": "solgul",
    "solguls": "solgul",
    "solgult": "solgul",
    "solgults": "solgul",
    "solgården": "solgård",
    "solgårdens": "solgård",
    "solgårds": "solgård",
    "solhattar": "solhatt",
    "solhattarna": "solhatt",
    "solhattarnas": "solhatt",
    "solhattars": "solhatt",
    "solhatten": "solhatt",
    "solhattens": "solhatt",
    "solhatts": "solhatt",
    "solhjulen": "solhjul",
    "solhjulens": "solhjul",
    "solhjulet": "solhjul",
    "solhjulets": "solhjul",
    "solhjuls": "solhjul",
    "solhöjden": "solhöjd",
    "solhöjdens": "solhöjd",
    "solhöjds": "solhöjd",
    "soli": "solo",
    "solida": "solid",
    "solidare": "solid",
    "solidares": "solid",
    "solidariska": "solidarisk",
    "solidariskare": "solidarisk",
    "solidariskares": "solidarisk",
    "solidariskas": "solidarisk",
    "solidariskast": "solidarisk",
    "solidariskaste": "solidarisk",
    "solidariskastes": "solidarisk",
    "solidariskasts": "solidarisk",
    "solidariske": "solidarisk",
    "solidariskes": "solidarisk",
    "solidarisks": "solidarisk",
    "solidariskt": "solidarisk",
    "solidariskts": "solidarisk",
    "solidariteten": "solidaritet",
    "solidaritetens": "solidaritet",
    "solidariteter": "solidaritet",
    "solidariteterna": "solidaritet",
    "solidariteternas": "solidaritet",
    "solidariteters": "solidaritet",
    "solidaritets": "solidaritet",
    "solidas": "solid",
    "solidast": "solid",
    "solidaste": "solid",
    "solidastes": "solid",
    "solidasts": "solid",
    "solide": "solid",
    "solides": "solid",
    "soliditeten": "soliditet",
    "soliditetens": "soliditet",
    "soliditeter": "soliditet",
    "soliditeterna": "soliditet",
    "soliditeternas": "soliditet",
    "soliditeters": "soliditet",
    "soliditets": "soliditet",
    "solids": "solid",
    "soliga": "solig",
    "soligare": "solig",
    "soligares": "solig",
    "soligas": "solig",
    "soligast": "solig",
    "soligaste": "solig",
    "soligastes": "solig",
    "soligasts": "solig",
    "solige": "solig",
    "soliges": "solig",
    "soligheten": "solighet",
    "solighetens": "solighet",
    "solighets": "solighet",
    "soligs": "solig",
    "soligt": "solig",
    "soligts": "solig",
    "solinstrålningar": "solinstrålning",
    "solinstrålningarna": "solinstrålning",
    "solinstrålningarnas": "solinstrålning",
    "solinstrålningars": "solinstrålning",
    "solinstrålningen": "solinstrålning",
    "solinstrålningens": "solinstrålning",
    "solinstrålnings": "solinstrålning",
    "solipsismen": "solipsism",
    "solipsismens": "solipsism",
    "solipsismer": "solipsism",
    "solipsismerna": "solipsism",
    "solipsismernas": "solipsism",
    "solipsismers": "solipsism",
    "solipsisms": "solipsism",
    "solipsistiska": "solipsistisk",
    "solipsistiskas": "solipsistisk",
    "solipsistiske": "solipsistisk",
    "solipsistiskes": "solipsistisk",
    "solipsistisks": "solipsistisk",
    "solipsistiskt": "solipsistisk",
    "solipsistiskts": "solipsistisk",
    "solis": "solo",
    "solisten": "solist",
    "solistens": "solist",
    "solister": "solist",
    "solisterna": "solist",
    "solisternas": "solist",
    "solisters": "solist",
    "solistiska": "solistisk",
    "solistiskare": "solistisk",
    "solistiskares": "solistisk",
    "solistiskas": "solistisk",
    "solistiskast": "solistisk",
    "solistiskaste": "solistisk",
    "solistiskastes": "solistisk",
    "solistiskasts": "solistisk",
    "solistiske": "solistisk",
    "solistiskes": "solistisk",
    "solistisks": "solistisk",
    "solistiskt": "solistisk",
    "solistiskts": "solistisk",
    "solists": "solist",
    "solitt": "solid",
    "solitts": "solid",
    "solitära": "solitär",
    "solitärare": "solitär",
    "solitärares": "solitär",
    "solitäras": "solitär",
    "solitärast": "solitär",
    "solitäraste": "solitär",
    "solitärastes": "solitär",
    "solitärasts": "solitär",
    "solitäre": "solitär",
    "solitären": "solitär",
    "solitärens": "solitär",
    "solitärer": "solitär",
    "solitärerna": "solitär",
    "solitärernas": "solitär",
    "solitärers": "solitär",
    "solitäres": "solitär",
    "solitärs": "solitär",
    "solitärt": "solitär",
    "solitärts": "solitär",
    "solk": "solka",
    "solkad": "solka",
    "solkade": "solka",
    "solkades": "solka",
    "solkads": "solka",
    "solkande": "solka",
    "solkanden": "solkande",
    "solkandena": "solkande",
    "solkandenas": "solkande",
    "solkandens": "solkande",
    "solkandes": "solkande",
    "solkandet": "solkande",
    "solkandets": "solkande",
    "solkar": "solka",
    "solkas": "solka",
    "solkat": "solka",
    "solkats": "solka",
    "solkatten": "solkatt",
    "solkattens": "solkatt",
    "solkatter": "solkatt",
    "solkatterna": "solkatt",
    "solkatternas": "solkatt",
    "solkatters": "solkatt",
    "solkatts": "solkatt",
    "solket": "solk",
    "solkets": "solk",
    "solkiga": "solkig",
    "solkigare": "solkig",
    "solkigares": "solkig",
    "solkigas": "solkig",
    "solkigast": "solkig",
    "solkigaste": "solkig",
    "solkigastes": "solkig",
    "solkigasts": "solkig",
    "solkige": "solkig",
    "solkiges": "solkig",
    "solkigheten": "solkighet",
    "solkighetens": "solkighet",
    "solkighets": "solkighet",
    "solkigs": "solkig",
    "solkigt": "solkig",
    "solkigts": "solkig",
    "solklara": "solklar",
    "solklarare": "solklar",
    "solklarares": "solklar",
    "solklaras": "solklar",
    "solklarast": "solklar",
    "solklaraste": "solklar",
    "solklarastes": "solklar",
    "solklarasts": "solklar",
    "solklare": "solklar",
    "solklares": "solklar",
    "solklars": "solklar",
    "solklart": "solklar",
    "solklarts": "solklar",
    "solklippen": "solklipp",
    "solklippens": "solklipp",
    "solklippet": "solklipp",
    "solklippets": "solklipp",
    "solklipps": "solklipp",
    "solklänningar": "solklänning",
    "solklänningarna": "solklänning",
    "solklänningarnas": "solklänning",
    "solklänningars": "solklänning",
    "solklänningen": "solklänning",
    "solklänningens": "solklänning",
    "solklännings": "solklänning",
    "solkrämen": "solkräm",
    "solkrämens": "solkräm",
    "solkrämer": "solkräm",
    "solkrämerna": "solkräm",
    "solkrämernas": "solkräm",
    "solkrämers": "solkräm",
    "solkräms": "solkräm",
    "solks": "solk",
    "solkurv": "solkurva",
    "solkurvan": "solkurva",
    "solkurvans": "solkurva",
    "solkurvas": "solkurva",
    "solkurve": "solkurva",
    "solkurvor": "solkurva",
    "solkurvorna": "solkurva",
    "solkurvornas": "solkurva",
    "solkurvors": "solkurva",
    "solkurvs": "solkurva",
    "sollamp": "sollampa",
    "sollampan": "sollampa",
    "sollampans": "sollampa",
    "sollampas": "sollampa",
    "sollampe": "sollampa",
    "sollampor": "sollampa",
    "sollamporna": "sollampa",
    "sollampornas": "sollampa",
    "sollampors": "sollampa",
    "sollamps": "sollampa",
    "solljusen": "solljus",
    "solljusens": "solljus",
    "solljuset": "solljus",
    "solljusets": "solljus",
    "solmaterian": "solmateria",
    "solmaterians": "solmateria",
    "solmaterias": "solmateria",
    "solmaterier": "solmateria",
    "solmaterierna": "solmateria",
    "solmateriernas": "solmateria",
    "solmateriers": "solmateria",
    "solmisationen": "solmisation",
    "solmisationens": "solmisation",
    "solmisationer": "solmisation",
    "solmisationerna": "solmisation",
    "solmisationernas": "solmisation",
    "solmisationers": "solmisation",
    "solmisations": "solmisation",
    "solmogens": "solmogen",
    "solmoget": "solmogen",
    "solmogets": "solmogen",
    "solmogna": "solmogen",
    "solmognare": "solmogen",
    "solmognares": "solmogen",
    "solmognas": "solmogen",
    "solmognast": "solmogen",
    "solmognaste": "solmogen",
    "solmognastes": "solmogen",
    "solmognasts": "solmogen",
    "solmogne": "solmogen",
    "solmognes": "solmogen",
    "solmålen": "solmål",
    "solmålens": "solmål",
    "solmålet": "solmål",
    "solmålets": "solmål",
    "solmåls": "solmål",
    "solnedgångar": "solnedgång",
    "solnedgångarna": "solnedgång",
    "solnedgångarnas": "solnedgång",
    "solnedgångars": "solnedgång",
    "solnedgången": "solnedgång",
    "solnedgångens": "solnedgång",
    "solnedgångs": "solnedgång",
    "solochvår": "solochvåra",
    "solochvårad": "solochvåra",
    "solochvårade": "solochvåra",
    "solochvårades": "solochvåra",
    "solochvårads": "solochvåra",
    "solochvårande": "solochvåra",
    "solochvåranden": "solochvårande",
    "solochvårandena": "solochvårande",
    "solochvårandenas": "solochvårande",
    "solochvårandens": "solochvårande",
    "solochvårandes": "solochvårande",
    "solochvårandet": "solochvårande",
    "solochvårandets": "solochvårande",
    "solochvårar": "solochvårare",
    "solochvåraren": "solochvårare",
    "solochvårarens": "solochvårare",
    "solochvårares": "solochvårare",
    "solochvårarna": "solochvårare",
    "solochvårarnas": "solochvårare",
    "solochvåras": "solochvåra",
    "solochvårat": "solochvåra",
    "solochvårats": "solochvåra",
    "solochvårs": "solochvår",
    "sololjan": "sololja",
    "sololjans": "sololja",
    "sololjas": "sololja",
    "sololje": "sololja",
    "sololjor": "sololja",
    "sololjorna": "sololja",
    "sololjornas": "sololja",
    "sololjors": "sololja",
    "solon": "solo",
    "solona": "solo",
    "solonas": "solo",
    "solons": "solo",
    "solos": "solo",
    "solosången": "solosång",
    "solosångens": "solosång",
    "solosångs": "solosång",
    "solot": "solo",
    "solots": "solo",
    "solpanelen": "solpanel",
    "solpanelens": "solpanel",
    "solpaneler": "solpanel",
    "solpanelerna": "solpanel",
    "solpanelernas": "solpanel",
    "solpanelers": "solpanel",
    "solpanels": "solpanel",
    "solreflexen": "solreflex",
    "solreflexens": "solreflex",
    "solreflexer": "solreflex",
    "solreflexerna": "solreflex",
    "solreflexernas": "solreflex",
    "solreflexers": "solreflex",
    "solregnet": "solregn",
    "solregnets": "solregn",
    "solregns": "solregn",
    "solresan": "solresa",
    "solresans": "solresa",
    "solresas": "solresa",
    "solrese": "solresa",
    "solresor": "solresa",
    "solresorna": "solresa",
    "solresornas": "solresa",
    "solresors": "solresa",
    "solringen": "solring",
    "solringens": "solring",
    "solrings": "solring",
    "solrosen": "solros",
    "solrosens": "solros",
    "solrosor": "solros",
    "solrosorna": "solros",
    "solrosornas": "solros",
    "solrosors": "solros",
    "solröken": "solrök",
    "solrökens": "solrök",
    "solröks": "solrök",
    "solrörelsen": "solrörelse",
    "solrörelsens": "solrörelse",
    "solrörelser": "solrörelse",
    "solrörelserna": "solrörelse",
    "solrörelsernas": "solrörelse",
    "solrörelsers": "solrörelse",
    "solrörelses": "solrörelse",
    "sols": "sol",
    "solsemestern": "solsemester",
    "solsemesterns": "solsemester",
    "solsemesters": "solsemester",
    "solsemestrar": "solsemester",
    "solsemestrarna": "solsemester",
    "solsemestrarnas": "solsemester",
    "solsemestrars": "solsemester",
    "solsidan": "solsida",
    "solsidans": "solsida",
    "solsidas": "solsida",
    "solside": "solsida",
    "solsides": "solsida",
    "solsidor": "solsida",
    "solsidorna": "solsida",
    "solsidornas": "solsida",
    "solsidors": "solsida",
    "solskenet": "solsken",
    "solskenets": "solsken",
    "solskens": "solsken",
    "solskensväderna": "solskensväder",
    "solskensvädernas": "solskensväder",
    "solskensväders": "solskensväder",
    "solskensvädren": "solskensväder",
    "solskensvädrens": "solskensväder",
    "solskensvädret": "solskensväder",
    "solskensvädrets": "solskensväder",
    "solskiftes": "solskifte",
    "solskiftet": "solskifte",
    "solskiftets": "solskifte",
    "solskydden": "solskydd",
    "solskyddens": "solskydd",
    "solskyddet": "solskydd",
    "solskyddets": "solskydd",
    "solskydds": "solskydd",
    "solskyddsmedels": "solskyddsmedel",
    "solskyddsmedlen": "solskyddsmedel",
    "solskyddsmedlens": "solskyddsmedel",
    "solskyddsmedlet": "solskyddsmedel",
    "solskyddsmedlets": "solskyddsmedel",
    "solsnibbar": "solsnibb",
    "solsnibbarna": "solsnibb",
    "solsnibbarnas": "solsnibb",
    "solsnibbars": "solsnibb",
    "solsnibben": "solsnibb",
    "solsnibbens": "solsnibb",
    "solsnibbs": "solsnibb",
    "solsprängningar": "solsprängning",
    "solsprängningarna": "solsprängning",
    "solsprängningarnas": "solsprängning",
    "solsprängningars": "solsprängning",
    "solsprängningen": "solsprängning",
    "solsprängningens": "solsprängning",
    "solsprängnings": "solsprängning",
    "solstekta": "solstekt",
    "solstektare": "solstekt",
    "solstektares": "solstekt",
    "solstektas": "solstekt",
    "solstektast": "solstekt",
    "solstektaste": "solstekt",
    "solstektastes": "solstekt",
    "solstektasts": "solstekt",
    "solstekte": "solstekt",
    "solstektes": "solstekt",
    "solstekts": "solstekt",
    "solstinget": "solsting",
    "solstingets": "solsting",
    "solstings": "solsting",
    "solstolar": "solstol",
    "solstolarna": "solstol",
    "solstolarnas": "solstol",
    "solstolars": "solstol",
    "solstolen": "solstol",
    "solstolens": "solstol",
    "solstols": "solstol",
    "solstrim": "solstrimma",
    "solstrimman": "solstrimma",
    "solstrimmans": "solstrimma",
    "solstrimmas": "solstrimma",
    "solstrimme": "solstrimma",
    "solstrimmor": "solstrimma",
    "solstrimmorna": "solstrimma",
    "solstrimmornas": "solstrimma",
    "solstrimmors": "solstrimma",
    "solstrims": "solstrimma",
    "solstrål": "solstråle",
    "solstrålar": "solstråle",
    "solstrålarna": "solstråle",
    "solstrålarnas": "solstråle",
    "solstrålars": "solstråle",
    "solstrålen": "solstråle",
    "solstrålens": "solstråle",
    "solstråles": "solstråle",
    "solstrålningar": "solstrålning",
    "solstrålningarna": "solstrålning",
    "solstrålningarnas": "solstrålning",
    "solstrålningars": "solstrålning",
    "solstrålningen": "solstrålning",
    "solstrålningens": "solstrålning",
    "solstrålnings": "solstrålning",
    "solstråls": "solstråle",
    "solsystemen": "solsystem",
    "solsystemens": "solsystem",
    "solsystemet": "solsystem",
    "solsystemets": "solsystemet",
    "solsystems": "solsystem",
    "soltaken": "soltak",
    "soltakens": "soltak",
    "soltaket": "soltak",
    "soltakets": "soltak",
    "soltaks": "soltak",
    "solterapien": "solterapi",
    "solterapiens": "solterapi",
    "solterapin": "solterapi",
    "solterapins": "solterapi",
    "solterapis": "solterapi",
    "soltiden": "soltid",
    "soltidens": "soltid",
    "soltids": "soltid",
    "soltim": "soltimme",
    "soltimman": "soltimma",
    "soltimmans": "soltimma",
    "soltimmar": "soltimme",
    "soltimmarna": "soltimme",
    "soltimmarnas": "soltimme",
    "soltimmars": "soltimme",
    "soltimmas": "soltimma",
    "soltimmen": "soltimme",
    "soltimmens": "soltimme",
    "soltimmes": "soltimme",
    "soltims": "soltimme",
    "soltork": "soltorka",
    "soltorkad": "soltorka",
    "soltorkade": "soltorka",
    "soltorkades": "soltorka",
    "soltorkads": "soltorka",
    "soltorkande": "soltorka",
    "soltorkanden": "soltorkande",
    "soltorkandena": "soltorkande",
    "soltorkandenas": "soltorkande",
    "soltorkandens": "soltorkande",
    "soltorkandes": "soltorkande",
    "soltorkandet": "soltorkande",
    "soltorkandets": "soltorkande",
    "soltorkar": "soltorka",
    "soltorkas": "soltorka",
    "soltorkat": "soltorka",
    "soltorkats": "soltorka",
    "soluppgångar": "soluppgång",
    "soluppgångarna": "soluppgång",
    "soluppgångarnas": "soluppgång",
    "soluppgångars": "soluppgång",
    "soluppgången": "soluppgång",
    "soluppgångens": "soluppgång",
    "soluppgångs": "soluppgång",
    "soluren": "solur",
    "solurens": "solur",
    "soluret": "solur",
    "solurets": "solur",
    "solurs": "solur",
    "solutionen": "solution",
    "solutionens": "solution",
    "solutioner": "solution",
    "solutionerna": "solution",
    "solutionernas": "solution",
    "solutioners": "solution",
    "solutions": "solution",
    "solv": "solva",
    "solvad": "solva",
    "solvade": "solva",
    "solvades": "solva",
    "solvads": "solva",
    "solvande": "solva",
    "solvanden": "solvande",
    "solvandena": "solvande",
    "solvandenas": "solvande",
    "solvandens": "solvande",
    "solvandes": "solvande",
    "solvandet": "solvande",
    "solvandets": "solvande",
    "solvar": "solva",
    "solvargar": "solvarg",
    "solvargarna": "solvarg",
    "solvargarnas": "solvarg",
    "solvargars": "solvarg",
    "solvargen": "solvarg",
    "solvargens": "solvarg",
    "solvargs": "solvarg",
    "solvarma": "solvarm",
    "solvarmare": "solvarm",
    "solvarmares": "solvarm",
    "solvarmas": "solvarm",
    "solvarmast": "solvarm",
    "solvarmaste": "solvarm",
    "solvarmastes": "solvarm",
    "solvarmasts": "solvarm",
    "solvarme": "solvarm",
    "solvarmes": "solvarm",
    "solvarms": "solvarm",
    "solvarmt": "solvarm",
    "solvarmts": "solvarm",
    "solvarven": "solvarv",
    "solvarvens": "solvarv",
    "solvarvet": "solvarv",
    "solvarvets": "solvarv",
    "solvarvs": "solvarv",
    "solvas": "solva",
    "solvat": "solva",
    "solvats": "solva",
    "solven": "solv",
    "solvens": "solv",
    "solvensen": "solvens",
    "solvensens": "solvens",
    "solventa": "solvent",
    "solventare": "solvent",
    "solventares": "solvent",
    "solventas": "solvent",
    "solventast": "solvent",
    "solventaste": "solvent",
    "solventastes": "solvent",
    "solventasts": "solvent",
    "solvente": "solvent",
    "solventes": "solvent",
    "solventilen": "solventil",
    "solventilens": "solventil",
    "solventiler": "solventil",
    "solventilerna": "solventil",
    "solventilernas": "solventil",
    "solventilers": "solventil",
    "solventils": "solventil",
    "solvents": "solvent",
    "solverad": "solvera",
    "solverade": "solvera",
    "solverades": "solvera",
    "solverads": "solvera",
    "solverand": "solveranda",
    "solverandan": "solveranda",
    "solverandans": "solveranda",
    "solverandas": "solveranda",
    "solverande": "solveranda",
    "solveranden": "solverande",
    "solverandena": "solverande",
    "solverandenas": "solverande",
    "solverandens": "solverande",
    "solverandes": "solverande",
    "solverandet": "solverande",
    "solverandets": "solverande",
    "solverandor": "solveranda",
    "solverandorna": "solveranda",
    "solverandornas": "solveranda",
    "solverandors": "solveranda",
    "solverands": "solveranda",
    "solverar": "solvera",
    "solveras": "solvera",
    "solverat": "solvera",
    "solverats": "solvera",
    "solverbara": "solverbar",
    "solverbarare": "solverbar",
    "solverbarares": "solverbar",
    "solverbaras": "solverbar",
    "solverbarast": "solverbar",
    "solverbaraste": "solverbar",
    "solverbarastes": "solverbar",
    "solverbarasts": "solverbar",
    "solverbare": "solverbar",
    "solverbares": "solverbar",
    "solverbarheten": "solverbarhet",
    "solverbarhetens": "solverbarhet",
    "solverbarhets": "solverbarhet",
    "solverbars": "solverbar",
    "solverbart": "solverbar",
    "solverbarts": "solverbar",
    "solveringar": "solvering",
    "solveringarna": "solvering",
    "solveringarnas": "solvering",
    "solveringars": "solvering",
    "solveringen": "solvering",
    "solveringens": "solvering",
    "solverings": "solvering",
    "solvet": "solv",
    "solvets": "solv",
    "solvinden": "solvind",
    "solvindens": "solvind",
    "solvinds": "solvind",
    "solvkäppar": "solvkäpp",
    "solvkäpparna": "solvkäpp",
    "solvkäpparnas": "solvkäpp",
    "solvkäppars": "solvkäpp",
    "solvkäppen": "solvkäpp",
    "solvkäppens": "solvkäpp",
    "solvkäpps": "solvkäpp",
    "solvs": "solv",
    "solvänd": "solvända",
    "solvändan": "solvända",
    "solvändans": "solvända",
    "solvändas": "solvända",
    "solvände": "solvända",
    "solvändor": "solvända",
    "solvändorna": "solvända",
    "solvändornas": "solvända",
    "solvändors": "solvända",
    "solvänds": "solvända",
    "solvärmen": "solvärme",
    "solvärmens": "solvärme",
    "solvärmes": "solvärme",
    "solära": "solär",
    "solärare": "solär",
    "solärares": "solär",
    "soläras": "solär",
    "solärast": "solär",
    "soläraste": "solär",
    "solärastes": "solär",
    "solärasts": "solär",
    "soläre": "solär",
    "soläres": "solär",
    "solärs": "solär",
    "solärt": "solär",
    "solärts": "solär",
    "solåren": "solår",
    "solårens": "solår",
    "solåret": "solår",
    "solårets": "solår",
    "solårs": "solår",
    "solögas": "solöga",
    "solögat": "solöga",
    "solögats": "solöga",
    "solögon": "solöga",
    "solögonen": "solöga",
    "solögonens": "solöga",
    "solögons": "solöga",
    "somaliern": "somalier",
    "somalierna": "somalier",
    "somaliernas": "somalier",
    "somalierns": "somalier",
    "somaliers": "somalier",
    "somalisk": "somaliska",
    "somaliska": "somalisk",
    "somaliskan": "somaliska",
    "somaliskans": "somaliska",
    "somaliskare": "somalisk",
    "somaliskares": "somalisk",
    "somaliskas": "somaliska",
    "somaliskast": "somalisk",
    "somaliskaste": "somalisk",
    "somaliskastes": "somalisk",
    "somaliskasts": "somalisk",
    "somaliske": "somaliska",
    "somaliskes": "somalisk",
    "somaliskor": "somaliska",
    "somaliskorna": "somaliska",
    "somaliskornas": "somaliska",
    "somaliskors": "somaliska",
    "somalisks": "somalisk",
    "somaliskt": "somalisk",
    "somaliskts": "somalisk",
    "somatikern": "somatiker",
    "somatikerna": "somatiker",
    "somatikernas": "somatiker",
    "somatikerns": "somatiker",
    "somatikers": "somatiker",
    "somatiska": "somatisk",
    "somatiskare": "somatisk",
    "somatiskares": "somatisk",
    "somatiskas": "somatisk",
    "somatiskast": "somatisk",
    "somatiskaste": "somatisk",
    "somatiskastes": "somatisk",
    "somatiskasts": "somatisk",
    "somatiske": "somatisk",
    "somatiskes": "somatisk",
    "somatisks": "somatisk",
    "somatiskt": "somatisk",
    "somatiskts": "somatisk",
    "sombreroer": "sombrero",
    "sombreroerna": "sombrero",
    "sombreroernas": "sombrero",
    "sombreroers": "sombrero",
    "sombreron": "sombrero",
    "sombrerons": "sombrero",
    "sombreror": "sombrero",
    "sombrerorna": "sombrero",
    "sombrerornas": "sombrero",
    "sombrerors": "sombrero",
    "sombreros": "sombrero",
    "somlidan": "somlig",
    "somlidana": "somlig",
    "somlidanas": "somlig",
    "somlidans": "somlig",
    "somlidant": "somlig",
    "somlidants": "somlig",
    "somliga": "somlig",
    "somligas": "somlig",
    "somligs": "somlig",
    "somligt": "somlig",
    "somligts": "somlig",
    "sommaradressen": "sommaradress",
    "sommaradressens": "sommaradress",
    "sommaradresser": "sommaradress",
    "sommaradresserna": "sommaradress",
    "sommaradressernas": "sommaradress",
    "sommaradressers": "sommaradress",
    "sommaraktiga": "sommaraktig",
    "sommaraktigare": "sommaraktig",
    "sommaraktigares": "sommaraktig",
    "sommaraktigas": "sommaraktig",
    "sommaraktigast": "sommaraktig",
    "sommaraktigaste": "sommaraktig",
    "sommaraktigastes": "sommaraktig",
    "sommaraktigasts": "sommaraktig",
    "sommaraktige": "sommaraktig",
    "sommaraktiges": "sommaraktig",
    "sommaraktigheten": "sommaraktighet",
    "sommaraktighetens": "sommaraktighet",
    "sommaraktighets": "sommaraktighet",
    "sommaraktigs": "sommaraktig",
    "sommaraktigt": "sommaraktig",
    "sommaraktigts": "sommaraktig",
    "sommarbarnen": "sommarbarn",
    "sommarbarnens": "sommarbarn",
    "sommarbarnet": "sommarbarn",
    "sommarbarnets": "sommarbarn",
    "sommarbarns": "sommarbarn",
    "sommarbostaden": "sommarbostad",
    "sommarbostadens": "sommarbostad",
    "sommarbostads": "sommarbostad",
    "sommarbostan": "sommarbostad",
    "sommarbostans": "sommarbostad",
    "sommarbostäder": "sommarbostad",
    "sommarbostäderna": "sommarbostad",
    "sommarbostädernas": "sommarbostad",
    "sommarbostäders": "sommarbostad",
    "sommardagar": "sommardag",
    "sommardagarna": "sommardag",
    "sommardagarnas": "sommardag",
    "sommardagars": "sommardag",
    "sommardagen": "sommardag",
    "sommardagens": "sommardag",
    "sommardags": "sommardag",
    "sommardan": "sommardag",
    "sommardans": "sommardag",
    "sommardar": "sommardag",
    "sommardarna": "sommardag",
    "sommardarnas": "sommardag",
    "sommardars": "sommardag",
    "sommardim": "sommardimma",
    "sommardimman": "sommardimma",
    "sommardimmans": "sommardimma",
    "sommardimmas": "sommardimma",
    "sommardimme": "sommardimma",
    "sommardimmor": "sommardimma",
    "sommardimmorna": "sommardimma",
    "sommardimmornas": "sommardimma",
    "sommardimmors": "sommardimma",
    "sommardims": "sommardimma",
    "sommardräkten": "sommardräkt",
    "sommardräktens": "sommardräkt",
    "sommardräkts": "sommardräkt",
    "sommardäcken": "sommardäck",
    "sommardäckens": "sommardäck",
    "sommardäcket": "sommardäck",
    "sommardäckets": "sommardäck",
    "sommardäcks": "sommardäck",
    "sommareftermiddagar": "sommareftermiddag",
    "sommareftermiddagarna": "sommareftermiddag",
    "sommareftermiddagarnas": "sommareftermiddag",
    "sommareftermiddagars": "sommareftermiddag",
    "sommareftermiddagen": "sommareftermiddag",
    "sommareftermiddagens": "sommareftermiddag",
    "sommareftermiddags": "sommareftermiddag",
    "sommaren": "sommar",
    "sommarens": "sommar",
    "sommarfjärilar": "sommarfjäril",
    "sommarfjärilarna": "sommarfjäril",
    "sommarfjärilarnas": "sommarfjäril",
    "sommarfjärilars": "sommarfjäril",
    "sommarfjärilen": "sommarfjäril",
    "sommarfjärilens": "sommarfjäril",
    "sommarfjäriln": "sommarfjäril",
    "sommarfjärilns": "sommarfjäril",
    "sommarfjärils": "sommarfjäril",
    "sommarfrisyren": "sommarfrisyr",
    "sommarfrisyrens": "sommarfrisyr",
    "sommarfrisyrer": "sommarfrisyr",
    "sommarfrisyrerna": "sommarfrisyr",
    "sommarfrisyrernas": "sommarfrisyr",
    "sommarfrisyrers": "sommarfrisyr",
    "sommarfrisyrs": "sommarfrisyr",
    "sommarfågeln": "sommarfågel",
    "sommarfågelns": "sommarfågel",
    "sommarfågels": "sommarfågel",
    "sommarfåglar": "sommarfågel",
    "sommarfåglarna": "sommarfågel",
    "sommarfåglarnas": "sommarfågel",
    "sommarfåglars": "sommarfågel",
    "sommargyllenen": "sommargyllen",
    "sommargyllenens": "sommargyllen",
    "sommargyllenet": "sommargyllen",
    "sommargyllenets": "sommargyllen",
    "sommargyllens": "sommargyllen",
    "sommargyllingar": "sommargylling",
    "sommargyllingarna": "sommargylling",
    "sommargyllingarnas": "sommargylling",
    "sommargyllingars": "sommargylling",
    "sommargyllingen": "sommargylling",
    "sommargyllingens": "sommargylling",
    "sommargyllings": "sommargylling",
    "sommargästen": "sommargäst",
    "sommargästens": "sommargäst",
    "sommargäster": "sommargäst",
    "sommargästerna": "sommargäst",
    "sommargästernas": "sommargäst",
    "sommargästers": "sommargäst",
    "sommargästs": "sommargäst",
    "sommarhalvåren": "sommarhalvår",
    "sommarhalvårens": "sommarhalvår",
    "sommarhalvåret": "sommarhalvår",
    "sommarhalvårets": "sommarhalvår",
    "sommarhalvårs": "sommarhalvår",
    "sommarhattar": "sommarhatt",
    "sommarhattarna": "sommarhatt",
    "sommarhattarnas": "sommarhatt",
    "sommarhattars": "sommarhatt",
    "sommarhatten": "sommarhatt",
    "sommarhattens": "sommarhatt",
    "sommarhatts": "sommarhatt",
    "sommarhemmen": "sommarhem",
    "sommarhemmens": "sommarhem",
    "sommarhemmet": "sommarhem",
    "sommarhemmets": "sommarhem",
    "sommarhems": "sommarhem",
    "sommarhusen": "sommarhus",
    "sommarhusens": "sommarhus",
    "sommarhuset": "sommarhus",
    "sommarhusets": "sommarhus",
    "sommarjobben": "sommarjobb",
    "sommarjobbens": "sommarjobb",
    "sommarjobbet": "sommarjobb",
    "sommarjobbets": "sommarjobb",
    "sommarjobbs": "sommarjobb",
    "sommarklänningar": "sommarklänning",
    "sommarklänningarna": "sommarklänning",
    "sommarklänningarnas": "sommarklänning",
    "sommarklänningars": "sommarklänning",
    "sommarklänningen": "sommarklänning",
    "sommarklänningens": "sommarklänning",
    "sommarklännings": "sommarklänning",
    "sommarkostymen": "sommarkostym",
    "sommarkostymens": "sommarkostym",
    "sommarkostymer": "sommarkostym",
    "sommarkostymerna": "sommarkostym",
    "sommarkostymernas": "sommarkostym",
    "sommarkostymers": "sommarkostym",
    "sommarkostyms": "sommarkostym",
    "sommarlanden": "sommarland",
    "sommarlandens": "sommarland",
    "sommarlandet": "sommarland",
    "sommarlandets": "sommarland",
    "sommarlands": "sommarland",
    "sommarledigheten": "sommarledighet",
    "sommarledighetens": "sommarledighet",
    "sommarledigheter": "sommarledighet",
    "sommarledigheterna": "sommarledighet",
    "sommarledigheternas": "sommarledighet",
    "sommarledigheters": "sommarledighet",
    "sommarledighets": "sommarledighet",
    "sommarliga": "sommarlig",
    "sommarligare": "sommarlig",
    "sommarligares": "sommarlig",
    "sommarligas": "sommarlig",
    "sommarligast": "sommarlig",
    "sommarligaste": "sommarlig",
    "sommarligastes": "sommarlig",
    "sommarligasts": "sommarlig",
    "sommarlige": "sommarlig",
    "sommarliges": "sommarlig",
    "sommarligs": "sommarlig",
    "sommarligt": "sommarlig",
    "sommarligts": "sommarlig",
    "sommarloven": "sommarlov",
    "sommarlovens": "sommarlov",
    "sommarlovet": "sommarlov",
    "sommarlovets": "sommarlov",
    "sommarlovs": "sommarlov",
    "sommarlägerna": "sommarläger",
    "sommarlägernas": "sommarläger",
    "sommarlägers": "sommarläger",
    "sommarlägren": "sommarläger",
    "sommarlägrens": "sommarläger",
    "sommarlägret": "sommarläger",
    "sommarlägrets": "sommarläger",
    "sommarmolnen": "sommarmoln",
    "sommarmolnens": "sommarmoln",
    "sommarmolnet": "sommarmoln",
    "sommarmolnets": "sommarmoln",
    "sommarmolns": "sommarmoln",
    "sommarn": "sommar",
    "sommarns": "sommar",
    "sommarnöjen": "sommarnöje",
    "sommarnöjena": "sommarnöje",
    "sommarnöjenas": "sommarnöje",
    "sommarnöjens": "sommarnöje",
    "sommarnöjes": "sommarnöje",
    "sommarnöjet": "sommarnöje",
    "sommarnöjets": "sommarnöje",
    "sommarparadisen": "sommarparadis",
    "sommarparadisens": "sommarparadis",
    "sommarparadiset": "sommarparadis",
    "sommarparadisets": "sommarparadis",
    "sommarpotatisar": "sommarpotatis",
    "sommarpotatisarna": "sommarpotatis",
    "sommarpotatisarnas": "sommarpotatis",
    "sommarpotatisars": "sommarpotatis",
    "sommarpotatisen": "sommarpotatis",
    "sommarpotatisens": "sommarpotatis",
    "sommarpratar": "sommarpratare",
    "sommarprataren": "sommarpratare",
    "sommarpratarens": "sommarpratare",
    "sommarpratares": "sommarpratare",
    "sommarpratarna": "sommarpratare",
    "sommarpratarnas": "sommarpratare",
    "sommarregnen": "sommarregn",
    "sommarregnens": "sommarregn",
    "sommarregnet": "sommarregn",
    "sommarregnets": "sommarregn",
    "sommarregns": "sommarregn",
    "sommars": "sommar",
    "sommarsemestern": "sommarsemester",
    "sommarsemesterns": "sommarsemester",
    "sommarsemesters": "sommarsemester",
    "sommarsemestrar": "sommarsemester",
    "sommarsemestrarna": "sommarsemester",
    "sommarsemestrarnas": "sommarsemester",
    "sommarsemestrars": "sommarsemester",
    "sommarsjukan": "sommarsjuka",
    "sommarsjukans": "sommarsjuka",
    "sommarsjukas": "sommarsjuka",
    "sommarsjuke": "sommarsjuka",
    "sommarsjuks": "sommarsjuka",
    "sommarsolståndet": "sommarsolstånd",
    "sommarsolståndets": "sommarsolstånd",
    "sommarsolstånds": "sommarsolstånd",
    "sommarstugan": "sommarstuga",
    "sommarstugans": "sommarstuga",
    "sommarstugas": "sommarstuga",
    "sommarstuge": "sommarstuga",
    "sommarstugeägar": "sommarstugeägare",
    "sommarstugeägaren": "sommarstugeägare",
    "sommarstugeägarens": "sommarstugeägare",
    "sommarstugeägares": "sommarstugeägare",
    "sommarstugeägarna": "sommarstugeägare",
    "sommarstugeägarnas": "sommarstugeägare",
    "sommarstugor": "sommarstuga",
    "sommarstugorna": "sommarstuga",
    "sommarstugornas": "sommarstuga",
    "sommarstugors": "sommarstuga",
    "sommarstugu": "sommarstuga",
    "sommarställen": "sommarställe",
    "sommarställena": "sommarställe",
    "sommarställenas": "sommarställe",
    "sommarställens": "sommarställe",
    "sommarställes": "sommarställe",
    "sommarstället": "sommarställe",
    "sommarställets": "sommarställe",
    "sommartiden": "sommartid",
    "sommartidens": "sommartid",
    "sommartids": "sommartid",
    "sommartorkan": "sommartorka",
    "sommartorkans": "sommartorka",
    "sommartorkas": "sommartorka",
    "sommartorpen": "sommartorp",
    "sommartorpens": "sommartorp",
    "sommartorpet": "sommartorp",
    "sommartorpets": "sommartorp",
    "sommartorps": "sommartorp",
    "sommarveck": "sommarvecka",
    "sommarveckan": "sommarvecka",
    "sommarveckans": "sommarvecka",
    "sommarveckas": "sommarvecka",
    "sommarvecke": "sommarvecka",
    "sommarvecko": "sommarvecka",
    "sommarveckor": "sommarvecka",
    "sommarveckorna": "sommarvecka",
    "sommarveckornas": "sommarvecka",
    "sommarveckors": "sommarvecka",
    "sommarvecks": "sommarvecka",
    "sommarvillan": "sommarvilla",
    "sommarvillans": "sommarvilla",
    "sommarvillas": "sommarvilla",
    "sommarville": "sommarvilla",
    "sommarvillor": "sommarvilla",
    "sommarvillorna": "sommarvilla",
    "sommarvillornas": "sommarvilla",
    "sommarvillors": "sommarvilla",
    "sommarvindar": "sommarvind",
    "sommarvindarna": "sommarvind",
    "sommarvindarnas": "sommarvind",
    "sommarvindars": "sommarvind",
    "sommarvinden": "sommarvind",
    "sommarvindens": "sommarvind",
    "sommarvinds": "sommarvind",
    "sommarvistelsen": "sommarvistelse",
    "sommarvistelsens": "sommarvistelse",
    "sommarvistelser": "sommarvistelse",
    "sommarvistelserna": "sommarvistelse",
    "sommarvistelsernas": "sommarvistelse",
    "sommarvistelsers": "sommarvistelse",
    "sommarvistelses": "sommarvistelse",
    "sommarväderna": "sommarväder",
    "sommarvädernas": "sommarväder",
    "sommarväders": "sommarväder",
    "sommarvädren": "sommarväder",
    "sommarvädrens": "sommarväder",
    "sommarvädret": "sommarväder",
    "sommarvädrets": "sommarväder",
    "sommarängar": "sommaräng",
    "sommarängarna": "sommaräng",
    "sommarängarnas": "sommaräng",
    "sommarängars": "sommaräng",
    "sommarängen": "sommaräng",
    "sommarängens": "sommaräng",
    "sommarängs": "sommaräng",
    "somn": "somna",
    "somnad": "somna",
    "somnade": "somna",
    "somnades": "somna",
    "somnads": "somna",
    "somnambula": "somnambul",
    "somnambulare": "somnambul",
    "somnambulares": "somnambul",
    "somnambulas": "somnambul",
    "somnambulast": "somnambul",
    "somnambulaste": "somnambul",
    "somnambulastes": "somnambul",
    "somnambulasts": "somnambul",
    "somnambule": "somnambul",
    "somnambulen": "somnambul",
    "somnambulens": "somnambul",
    "somnambuler": "somnambul",
    "somnambulerna": "somnambul",
    "somnambulernas": "somnambul",
    "somnambulers": "somnambul",
    "somnambules": "somnambul",
    "somnambuliska": "somnambulisk",
    "somnambuliskare": "somnambulisk",
    "somnambuliskares": "somnambulisk",
    "somnambuliskas": "somnambulisk",
    "somnambuliskast": "somnambulisk",
    "somnambuliskaste": "somnambulisk",
    "somnambuliskastes": "somnambulisk",
    "somnambuliskasts": "somnambulisk",
    "somnambuliske": "somnambulisk",
    "somnambuliskes": "somnambulisk",
    "somnambulisks": "somnambulisk",
    "somnambuliskt": "somnambulisk",
    "somnambuliskts": "somnambulisk",
    "somnambulismen": "somnambulism",
    "somnambulismens": "somnambulism",
    "somnambulismer": "somnambulism",
    "somnambulismerna": "somnambulism",
    "somnambulismernas": "somnambulism",
    "somnambulismers": "somnambulism",
    "somnambulisms": "somnambulism",
    "somnambuls": "somnambul",
    "somnambult": "somnambul",
    "somnambults": "somnambul",
    "somnande": "somna",
    "somnanden": "somnande",
    "somnandena": "somnande",
    "somnandenas": "somnande",
    "somnandens": "somnande",
    "somnandes": "somnande",
    "somnandet": "somnande",
    "somnandets": "somnande",
    "somnar": "somna",
    "somnas": "somna",
    "somnat": "somna",
    "somnats": "somna",
    "somrades": "somras",
    "somrar": "sommar",
    "somrarna": "sommar",
    "somrarnas": "sommar",
    "somrars": "sommar",
    "somrats": "somras",
    "somts": "somt",
    "son": "so",
    "sonad": "sona",
    "sonade": "sona",
    "sonades": "sona",
    "sonads": "sona",
    "sonande": "sona",
    "sonanden": "sonande",
    "sonandena": "sonande",
    "sonandenas": "sonande",
    "sonandens": "sonande",
    "sonandes": "sonande",
    "sonandet": "sonande",
    "sonandets": "sonande",
    "sonanten": "sonant",
    "sonantens": "sonant",
    "sonanter": "sonant",
    "sonanterna": "sonant",
    "sonanternas": "sonant",
    "sonanters": "sonant",
    "sonantiska": "sonantisk",
    "sonantiskare": "sonantisk",
    "sonantiskares": "sonantisk",
    "sonantiskas": "sonantisk",
    "sonantiskast": "sonantisk",
    "sonantiskaste": "sonantisk",
    "sonantiskastes": "sonantisk",
    "sonantiskasts": "sonantisk",
    "sonantiske": "sonantisk",
    "sonantiskes": "sonantisk",
    "sonantisks": "sonantisk",
    "sonantiskt": "sonantisk",
    "sonantiskts": "sonantisk",
    "sonants": "sonant",
    "sonar": "sona",
    "sonarn": "sonar",
    "sonarns": "sonar",
    "sonars": "sonar",
    "sonas": "sona",
    "sonat": "sona",
    "sonaten": "sonat",
    "sonatens": "sonat",
    "sonater": "sonat",
    "sonaterna": "sonat",
    "sonaternas": "sonat",
    "sonaters": "sonat",
    "sonatformen": "sonatform",
    "sonatformens": "sonatform",
    "sonatforms": "sonatform",
    "sonatinen": "sonatin",
    "sonatinens": "sonatin",
    "sonatiner": "sonatin",
    "sonatinerna": "sonatin",
    "sonatinernas": "sonatin",
    "sonatiners": "sonatin",
    "sonatins": "sonatin",
    "sonats": "sonat",
    "sonden": "sond",
    "sondens": "sond",
    "sonder": "sond",
    "sonderad": "sondera",
    "sonderade": "sondera",
    "sonderades": "sondera",
    "sonderads": "sondera",
    "sonderande": "sondera",
    "sonderanden": "sonderande",
    "sonderandena": "sonderande",
    "sonderandenas": "sonderande",
    "sonderandens": "sonderande",
    "sonderandes": "sonderande",
    "sonderandet": "sonderande",
    "sonderandets": "sonderande",
    "sonderar": "sondera",
    "sonderas": "sondera",
    "sonderat": "sondera",
    "sonderats": "sondera",
    "sonderbara": "sonderbar",
    "sonderbarare": "sonderbar",
    "sonderbarares": "sonderbar",
    "sonderbaras": "sonderbar",
    "sonderbarast": "sonderbar",
    "sonderbaraste": "sonderbar",
    "sonderbarastes": "sonderbar",
    "sonderbarasts": "sonderbar",
    "sonderbare": "sonderbar",
    "sonderbares": "sonderbar",
    "sonderbarheten": "sonderbarhet",
    "sonderbarhetens": "sonderbarhet",
    "sonderbarhets": "sonderbarhet",
    "sonderbars": "sonderbar",
    "sonderbart": "sonderbar",
    "sonderbarts": "sonderbar",
    "sonderingar": "sondering",
    "sonderingarna": "sondering",
    "sonderingarnas": "sondering",
    "sonderingars": "sondering",
    "sonderingen": "sondering",
    "sonderingens": "sondering",
    "sonderings": "sondering",
    "sonderna": "sond",
    "sondernas": "sond",
    "sonders": "sond",
    "sondmatad": "sondmata",
    "sondmatade": "sondmata",
    "sondmatades": "sondmata",
    "sondmatads": "sondmata",
    "sondmatande": "sondmata",
    "sondmatanden": "sondmatande",
    "sondmatandena": "sondmatande",
    "sondmatandenas": "sondmatande",
    "sondmatandens": "sondmatande",
    "sondmatandes": "sondmatande",
    "sondmatandet": "sondmatande",
    "sondmatandets": "sondmatande",
    "sondmatar": "sondmata",
    "sondmatas": "sondmata",
    "sondmatat": "sondmata",
    "sondmatats": "sondmata",
    "sondmatningar": "sondmatning",
    "sondmatningarna": "sondmatning",
    "sondmatningarnas": "sondmatning",
    "sondmatningars": "sondmatning",
    "sondmatningen": "sondmatning",
    "sondmatningens": "sondmatning",
    "sondmatnings": "sondmatning",
    "sondottern": "sondotter",
    "sondotterns": "sondotter",
    "sondotters": "sondotter",
    "sonds": "sond",
    "sondöttrar": "sondotter",
    "sondöttrarna": "sondotter",
    "sondöttrarnas": "sondotter",
    "sondöttrars": "sondotter",
    "sonen": "son",
    "sonens": "son",
    "sonetten": "sonett",
    "sonettens": "sonett",
    "sonetter": "sonett",
    "sonetterna": "sonett",
    "sonetternas": "sonett",
    "sonetters": "sonett",
    "sonetts": "sonett",
    "sonhustrun": "sonhustru",
    "sonhustruns": "sonhustru",
    "sonhustrur": "sonhustru",
    "sonhustrurna": "sonhustru",
    "sonhustrurnas": "sonhustru",
    "sonhustrurs": "sonhustru",
    "sonhustrus": "sonhustru",
    "soniska": "sonisk",
    "soniskare": "sonisk",
    "soniskares": "sonisk",
    "soniskas": "sonisk",
    "soniskast": "sonisk",
    "soniskaste": "sonisk",
    "soniskastes": "sonisk",
    "soniskasts": "sonisk",
    "soniske": "sonisk",
    "soniskes": "sonisk",
    "sonisks": "sonisk",
    "soniskt": "sonisk",
    "soniskts": "sonisk",
    "sonliga": "sonlig",
    "sonligare": "sonlig",
    "sonligares": "sonlig",
    "sonligas": "sonlig",
    "sonligast": "sonlig",
    "sonligaste": "sonlig",
    "sonligastes": "sonlig",
    "sonligasts": "sonlig",
    "sonlige": "sonlig",
    "sonliges": "sonlig",
    "sonligheten": "sonlighet",
    "sonlighetens": "sonlighet",
    "sonlighets": "sonlighet",
    "sonligs": "sonlig",
    "sonligt": "sonlig",
    "sonligts": "sonlig",
    "sonnamnen": "sonnamn",
    "sonnamnens": "sonnamn",
    "sonnamnet": "sonnamn",
    "sonnamnets": "sonnamn",
    "sonnamns": "sonnamn",
    "sonora": "sonor",
    "sonorare": "sonor",
    "sonorares": "sonor",
    "sonoras": "sonor",
    "sonorast": "sonor",
    "sonoraste": "sonor",
    "sonorastes": "sonor",
    "sonorasts": "sonor",
    "sonore": "sonor",
    "sonores": "sonor",
    "sonoriteten": "sonoritet",
    "sonoritetens": "sonoritet",
    "sonoriteter": "sonoritet",
    "sonoriteterna": "sonoritet",
    "sonoriteternas": "sonoritet",
    "sonoriteters": "sonoritet",
    "sonoritets": "sonoritet",
    "sonors": "sonor",
    "sonort": "sonor",
    "sonorts": "sonor",
    "sons": "son",
    "sonsonen": "sonson",
    "sonsonens": "sonson",
    "sonsons": "sonson",
    "sonsöner": "sonson",
    "sonsönerna": "sonson",
    "sonsönernas": "sonson",
    "sonsöners": "sonson",
    "sop": "sopa",
    "sopad": "sopa",
    "sopade": "sopa",
    "sopades": "sopa",
    "sopads": "sopa",
    "sopan": "sopa",
    "sopande": "sopa",
    "sopanden": "sopande",
    "sopandena": "sopande",
    "sopandenas": "sopande",
    "sopandens": "sopande",
    "sopandes": "sopande",
    "sopandet": "sopande",
    "sopandets": "sopande",
    "sopans": "sopa",
    "sopar": "sopa",
    "soparna": "sop",
    "soparnas": "sop",
    "sopars": "sop",
    "sopas": "sopa",
    "sopat": "sopa",
    "sopats": "sopa",
    "sopback": "sopbacke",
    "sopbackar": "sopbacke",
    "sopbackarna": "sopbacke",
    "sopbackarnas": "sopbacke",
    "sopbackars": "sopbacke",
    "sopbacken": "sopbacke",
    "sopbackens": "sopbacke",
    "sopbackes": "sopbacke",
    "sopbacks": "sopbacke",
    "sopbilar": "sopbil",
    "sopbilarna": "sopbil",
    "sopbilarnas": "sopbil",
    "sopbilars": "sopbil",
    "sopbilen": "sopbil",
    "sopbilens": "sopbil",
    "sopbils": "sopbil",
    "sopborst": "sopborste",
    "sopborstar": "sopborste",
    "sopborstarna": "sopborste",
    "sopborstarnas": "sopborste",
    "sopborstars": "sopborste",
    "sopborsten": "sopborste",
    "sopborstens": "sopborste",
    "sopborstes": "sopborste",
    "sopbälten": "sopbälte",
    "sopbältena": "sopbälte",
    "sopbältenas": "sopbälte",
    "sopbältens": "sopbälte",
    "sopbältes": "sopbälte",
    "sopbältet": "sopbälte",
    "sopbältets": "sopbälte",
    "sope": "sopa",
    "sopen": "sop",
    "sopens": "sop",
    "sopkvastar": "sopkvast",
    "sopkvastarna": "sopkvast",
    "sopkvastarnas": "sopkvast",
    "sopkvastars": "sopkvast",
    "sopkvasten": "sopkvast",
    "sopkvastens": "sopkvast",
    "sopkvasts": "sopkvast",
    "sopmaj": "sopmaja",
    "sopmajan": "sopmaja",
    "sopmajans": "sopmaja",
    "sopmajas": "sopmaja",
    "sopmaje": "sopmaja",
    "sopmajor": "sopmaja",
    "sopmajorna": "sopmaja",
    "sopmajornas": "sopmaja",
    "sopmajors": "sopmaja",
    "sopmajs": "sopmaja",
    "sopnedkasten": "sopnedkast",
    "sopnedkastens": "sopnedkast",
    "sopnedkastet": "sopnedkast",
    "sopnedkastets": "sopnedkast",
    "sopnedkasts": "sopnedkast",
    "sopor": "sopa",
    "soporna": "sopa",
    "sopornas": "sopa",
    "sopors": "sopa",
    "sopp": "soppa",
    "soppan": "soppa",
    "soppans": "soppa",
    "soppar": "sopp",
    "sopparna": "sopp",
    "sopparnas": "sopp",
    "soppars": "sopp",
    "soppas": "soppa",
    "soppatorsken": "soppatorsk",
    "soppatorskens": "soppatorsk",
    "soppatorsks": "soppatorsk",
    "soppe": "soppa",
    "soppen": "sopp",
    "soppens": "sopp",
    "soppförpackningar": "soppförpackning",
    "soppförpackningarna": "soppförpackning",
    "soppförpackningarnas": "soppförpackning",
    "soppförpackningars": "soppförpackning",
    "soppförpackningen": "soppförpackning",
    "soppförpackningens": "soppförpackning",
    "soppförpacknings": "soppförpackning",
    "soppiga": "soppig",
    "soppigare": "soppig",
    "soppigares": "soppig",
    "soppigas": "soppig",
    "soppigast": "soppig",
    "soppigaste": "soppig",
    "soppigastes": "soppig",
    "soppigasts": "soppig",
    "soppige": "soppig",
    "soppiges": "soppig",
    "soppigheten": "soppighet",
    "soppighetens": "soppighet",
    "soppighets": "soppighet",
    "soppigs": "soppig",
    "soppigt": "soppig",
    "soppigts": "soppig",
    "soppköken": "soppkök",
    "soppkökens": "soppkök",
    "soppköket": "soppkök",
    "soppkökets": "soppkök",
    "soppköks": "soppkök",
    "soppor": "soppa",
    "sopporna": "soppa",
    "soppornas": "soppa",
    "soppors": "soppa",
    "sopproten": "sopprot",
    "sopprotens": "sopprot",
    "sopprots": "sopprot",
    "sopprötter": "sopprot",
    "sopprötterna": "sopprot",
    "sopprötternas": "sopprot",
    "sopprötters": "sopprot",
    "sopps": "soppa",
    "soppskålar": "soppskål",
    "soppskålarna": "soppskål",
    "soppskålarnas": "soppskål",
    "soppskålars": "soppskål",
    "soppskålen": "soppskål",
    "soppskålens": "soppskål",
    "soppskåls": "soppskål",
    "soppslevar": "soppslev",
    "soppslevarna": "soppslev",
    "soppslevarnas": "soppslev",
    "soppslevars": "soppslev",
    "soppsleven": "soppslev",
    "soppslevens": "soppslev",
    "soppslevs": "soppslev",
    "sopptallrikar": "sopptallrik",
    "sopptallrikarna": "sopptallrik",
    "sopptallrikarnas": "sopptallrik",
    "sopptallrikars": "sopptallrik",
    "sopptallriken": "sopptallrik",
    "sopptallrikens": "sopptallrik",
    "sopptallriks": "sopptallrik",
    "soppås": "soppåse",
    "soppåsar": "soppåse",
    "soppåsarna": "soppåse",
    "soppåsarnas": "soppåse",
    "soppåsars": "soppåse",
    "soppåsen": "soppåse",
    "soppåsens": "soppåse",
    "soppåses": "soppåse",
    "sopranen": "sopran",
    "sopranens": "sopran",
    "sopraner": "sopran",
    "sopranerna": "sopran",
    "sopranernas": "sopran",
    "sopraners": "sopran",
    "sopranklaven": "sopranklav",
    "sopranklavens": "sopranklav",
    "sopranklavs": "sopranklav",
    "soprans": "sopran",
    "sops": "sopa",
    "sopskyffeln": "sopskyffel",
    "sopskyffelns": "sopskyffel",
    "sopskyffels": "sopskyffel",
    "sopskyfflar": "sopskyffel",
    "sopskyfflarna": "sopskyffel",
    "sopskyfflarnas": "sopskyffel",
    "sopskyfflars": "sopskyffel",
    "sopsorterad": "sopsortera",
    "sopsorterade": "sopsortera",
    "sopsorterades": "sopsortera",
    "sopsorterads": "sopsortera",
    "sopsorterande": "sopsortera",
    "sopsorterandes": "sopsortera",
    "sopsorterar": "sopsortera",
    "sopsorteras": "sopsortera",
    "sopsorterat": "sopsortera",
    "sopsorterats": "sopsortera",
    "sopstationen": "sopstation",
    "sopstationens": "sopstation",
    "sopstationer": "sopstation",
    "sopstationerna": "sopstation",
    "sopstationernas": "sopstation",
    "sopstationers": "sopstation",
    "sopstations": "sopstation",
    "sopsäckar": "sopsäck",
    "sopsäckarna": "sopsäck",
    "sopsäckarnas": "sopsäck",
    "sopsäckars": "sopsäck",
    "sopsäcken": "sopsäck",
    "sopsäckens": "sopsäck",
    "sopsäcks": "sopsäck",
    "sopsäckshållar": "sopsäckshållare",
    "sopsäckshållaren": "sopsäckshållare",
    "sopsäckshållarens": "sopsäckshållare",
    "sopsäckshållares": "sopsäckshållare",
    "sopsäckshållarna": "sopsäckshållare",
    "sopsäckshållarnas": "sopsäckshållare",
    "sopsäckskärr": "sopsäckskärra",
    "sopsäckskärran": "sopsäckskärra",
    "sopsäckskärrans": "sopsäckskärra",
    "sopsäckskärras": "sopsäckskärra",
    "sopsäckskärre": "sopsäckskärra",
    "sopsäckskärror": "sopsäckskärra",
    "sopsäckskärrorna": "sopsäckskärra",
    "sopsäckskärrornas": "sopsäckskärra",
    "sopsäckskärrors": "sopsäckskärra",
    "sopsäckskärrs": "sopsäckskärra",
    "soptippar": "soptipp",
    "soptipparna": "soptipp",
    "soptipparnas": "soptipp",
    "soptippars": "soptipp",
    "soptippen": "soptipp",
    "soptippens": "soptipp",
    "soptipps": "soptipp",
    "soptunn": "soptunna",
    "soptunnan": "soptunna",
    "soptunnans": "soptunna",
    "soptunnas": "soptunna",
    "soptunne": "soptunna",
    "soptunnor": "soptunna",
    "soptunnorna": "soptunna",
    "soptunnornas": "soptunna",
    "soptunnors": "soptunna",
    "soptunns": "soptunna",
    "sopåkar": "sopåkare",
    "sopåkaren": "sopåkare",
    "sopåkarens": "sopåkare",
    "sopåkares": "sopåkare",
    "sopåkarna": "sopåkare",
    "sopåkarnas": "sopåkare",
    "sorben": "sorb",
    "sorbens": "sorb",
    "sorber": "sorb",
    "sorberna": "sorb",
    "sorbernas": "sorb",
    "sorbers": "sorb",
    "sorbeten": "sorbet",
    "sorbetens": "sorbet",
    "sorbets": "sorbet",
    "sorbs": "sorb",
    "sordinen": "sordin",
    "sordinens": "sordin",
    "sordiner": "sordin",
    "sordinerad": "sordinera",
    "sordinerade": "sordinera",
    "sordinerades": "sordinera",
    "sordinerads": "sordinera",
    "sordinerande": "sordinera",
    "sordineranden": "sordinerande",
    "sordinerandena": "sordinerande",
    "sordinerandenas": "sordinerande",
    "sordinerandens": "sordinerande",
    "sordinerandes": "sordinerande",
    "sordinerandet": "sordinerande",
    "sordinerandets": "sordinerande",
    "sordinerar": "sordinera",
    "sordineras": "sordinera",
    "sordinerat": "sordinera",
    "sordinerats": "sordinera",
    "sordinerbara": "sordinerbar",
    "sordinerbarare": "sordinerbar",
    "sordinerbarares": "sordinerbar",
    "sordinerbaras": "sordinerbar",
    "sordinerbarast": "sordinerbar",
    "sordinerbaraste": "sordinerbar",
    "sordinerbarastes": "sordinerbar",
    "sordinerbarasts": "sordinerbar",
    "sordinerbare": "sordinerbar",
    "sordinerbares": "sordinerbar",
    "sordinerbarheten": "sordinerbarhet",
    "sordinerbarhetens": "sordinerbarhet",
    "sordinerbarhets": "sordinerbarhet",
    "sordinerbars": "sordinerbar",
    "sordinerbart": "sordinerbar",
    "sordinerbarts": "sordinerbar",
    "sordineringar": "sordinering",
    "sordineringarna": "sordinering",
    "sordineringarnas": "sordinering",
    "sordineringars": "sordinering",
    "sordineringen": "sordinering",
    "sordineringens": "sordinering",
    "sordinerings": "sordinering",
    "sordinerna": "sordin",
    "sordinernas": "sordin",
    "sordiners": "sordin",
    "sordins": "sordin",
    "sorgbanden": "sorgband",
    "sorgbandens": "sorgband",
    "sorgbandet": "sorgband",
    "sorgbandets": "sorgband",
    "sorgbands": "sorgband",
    "sorgbarnen": "sorgbarn",
    "sorgbarnens": "sorgbarn",
    "sorgbarnet": "sorgbarn",
    "sorgbarnets": "sorgbarn",
    "sorgbarns": "sorgbarn",
    "sorgbetonade": "sorgbetonad",
    "sorgbetonades": "sorgbetonad",
    "sorgbetonads": "sorgbetonad",
    "sorgbetonat": "sorgbetonad",
    "sorgbetonats": "sorgbetonad",
    "sorgbundens": "sorgbunden",
    "sorgbundet": "sorgbunden",
    "sorgbundets": "sorgbunden",
    "sorgbundna": "sorgbunden",
    "sorgbundnare": "sorgbunden",
    "sorgbundnares": "sorgbunden",
    "sorgbundnas": "sorgbunden",
    "sorgbundnast": "sorgbunden",
    "sorgbundnaste": "sorgbunden",
    "sorgbundnastes": "sorgbunden",
    "sorgbundnasts": "sorgbunden",
    "sorgbundne": "sorgbunden",
    "sorgbundnes": "sorgbunden",
    "sorgdräkten": "sorgdräkt",
    "sorgdräktens": "sorgdräkt",
    "sorgdräkter": "sorgdräkt",
    "sorgdräkterna": "sorgdräkt",
    "sorgdräkternas": "sorgdräkt",
    "sorgdräkters": "sorgdräkt",
    "sorgdräkts": "sorgdräkt",
    "sorge": "sorg",
    "sorgeakten": "sorgeakt",
    "sorgeaktens": "sorgeakt",
    "sorgeakter": "sorgeakt",
    "sorgeakterna": "sorgeakt",
    "sorgeakternas": "sorgeakt",
    "sorgeakters": "sorgeakt",
    "sorgeakts": "sorgeakt",
    "sorgearbeten": "sorgearbete",
    "sorgearbetena": "sorgearbete",
    "sorgearbetenas": "sorgearbete",
    "sorgearbetens": "sorgearbete",
    "sorgearbetes": "sorgearbete",
    "sorgearbetet": "sorgearbete",
    "sorgearbetets": "sorgearbete",
    "sorgearbets": "sorgearbete",
    "sorgebarnen": "sorgebarn",
    "sorgebarnens": "sorgebarn",
    "sorgebarnet": "sorgebarn",
    "sorgebarnets": "sorgebarn",
    "sorgebarns": "sorgebarn",
    "sorgebuden": "sorgebud",
    "sorgebudens": "sorgebud",
    "sorgebudet": "sorgebud",
    "sorgebudets": "sorgebud",
    "sorgebuds": "sorgebud",
    "sorgedagar": "sorgedag",
    "sorgedagarna": "sorgedag",
    "sorgedagarnas": "sorgedag",
    "sorgedagars": "sorgedag",
    "sorgedagen": "sorgedag",
    "sorgedagens": "sorgedag",
    "sorgedags": "sorgedag",
    "sorgelåten": "sorgelåt",
    "sorgelåtens": "sorgelåt",
    "sorgelåts": "sorgelåt",
    "sorgemusiken": "sorgemusik",
    "sorgemusikens": "sorgemusik",
    "sorgemusiks": "sorgemusik",
    "sorgen": "sorg",
    "sorgens": "sorg",
    "sorgeprocessen": "sorgeprocess",
    "sorgeprocessens": "sorgeprocess",
    "sorgeprocesser": "sorgeprocess",
    "sorgeprocesserna": "sorgeprocess",
    "sorgeprocessernas": "sorgeprocess",
    "sorgeprocessers": "sorgeprocess",
    "sorger": "sorg",
    "sorgerna": "sorg",
    "sorgernas": "sorg",
    "sorgers": "sorg",
    "sorgesamheten": "sorgesamhet",
    "sorgesamhetens": "sorgesamhet",
    "sorgesamhets": "sorgesamhet",
    "sorgesamma": "sorgesam",
    "sorgesammare": "sorgesam",
    "sorgesammares": "sorgesam",
    "sorgesammas": "sorgesam",
    "sorgesammast": "sorgesam",
    "sorgesammaste": "sorgesam",
    "sorgesammastes": "sorgesam",
    "sorgesammasts": "sorgesam",
    "sorgesamme": "sorgesam",
    "sorgesammes": "sorgesam",
    "sorgesams": "sorgesam",
    "sorgesamt": "sorgesam",
    "sorgesamts": "sorgesam",
    "sorgespelen": "sorgespel",
    "sorgespelens": "sorgespel",
    "sorgespelet": "sorgespel",
    "sorgespelets": "sorgespel",
    "sorgespels": "sorgespel",
    "sorgestunden": "sorgestund",
    "sorgestundens": "sorgestund",
    "sorgestunder": "sorgestund",
    "sorgestunderna": "sorgestund",
    "sorgestundernas": "sorgestund",
    "sorgestunders": "sorgestund",
    "sorgestunds": "sorgestund",
    "sorgetiden": "sorgetid",
    "sorgetidens": "sorgetid",
    "sorgetids": "sorgetid",
    "sorgeämnen": "sorgeämne",
    "sorgeämnena": "sorgeämne",
    "sorgeämnenas": "sorgeämne",
    "sorgeämnens": "sorgeämne",
    "sorgeämnes": "sorgeämne",
    "sorgeämnet": "sorgeämne",
    "sorgeämnets": "sorgeämne",
    "sorgeåren": "sorgeår",
    "sorgeårens": "sorgeår",
    "sorgeåret": "sorgeår",
    "sorgeårets": "sorgeår",
    "sorgeårs": "sorgeår",
    "sorgfloren": "sorgflor",
    "sorgflorens": "sorgflor",
    "sorgfloret": "sorgflor",
    "sorgflorets": "sorgflor",
    "sorgflors": "sorgflor",
    "sorgfria": "sorgfri",
    "sorgfriare": "sorgfri",
    "sorgfriares": "sorgfri",
    "sorgfrias": "sorgfri",
    "sorgfriast": "sorgfri",
    "sorgfriaste": "sorgfri",
    "sorgfriastes": "sorgfri",
    "sorgfriasts": "sorgfri",
    "sorgfrie": "sorgfri",
    "sorgfries": "sorgfri",
    "sorgfris": "sorgfri",
    "sorgfritt": "sorgfri",
    "sorgfritts": "sorgfri",
    "sorgfälliga": "sorgfällig",
    "sorgfälligare": "sorgfällig",
    "sorgfälligares": "sorgfällig",
    "sorgfälligas": "sorgfällig",
    "sorgfälligast": "sorgfällig",
    "sorgfälligaste": "sorgfällig",
    "sorgfälligastes": "sorgfällig",
    "sorgfälligasts": "sorgfällig",
    "sorgfällige": "sorgfällig",
    "sorgfälliges": "sorgfällig",
    "sorgfälligheten": "sorgfällighet",
    "sorgfällighetens": "sorgfällighet",
    "sorgfällighets": "sorgfällighet",
    "sorgfälligs": "sorgfällig",
    "sorgfälligt": "sorgfällig",
    "sorgfälligts": "sorgfällig",
    "sorgfärgen": "sorgfärg",
    "sorgfärgens": "sorgfärg",
    "sorgfärger": "sorgfärg",
    "sorgfärgerna": "sorgfärg",
    "sorgfärgernas": "sorgfärg",
    "sorgfärgers": "sorgfärg",
    "sorgfärgs": "sorgfärg",
    "sorgkantade": "sorgkantad",
    "sorgkantades": "sorgkantad",
    "sorgkantads": "sorgkantad",
    "sorgkantat": "sorgkantad",
    "sorgkantats": "sorgkantad",
    "sorgkanten": "sorgkant",
    "sorgkantens": "sorgkant",
    "sorgkanter": "sorgkant",
    "sorgkanterna": "sorgkant",
    "sorgkanternas": "sorgkant",
    "sorgkanters": "sorgkant",
    "sorgkants": "sorgkant",
    "sorgklädda": "sorgklädd",
    "sorgkläddare": "sorgklädd",
    "sorgkläddares": "sorgklädd",
    "sorgkläddas": "sorgklädd",
    "sorgkläddast": "sorgklädd",
    "sorgkläddaste": "sorgklädd",
    "sorgkläddastes": "sorgklädd",
    "sorgkläddasts": "sorgklädd",
    "sorgklädde": "sorgklädd",
    "sorgkläddes": "sorgklädd",
    "sorgklädds": "sorgklädd",
    "sorgkläderna": "sorgkläder",
    "sorgklädernas": "sorgkläder",
    "sorgkläders": "sorgkläder",
    "sorgklädes": "sorgkläder",
    "sorgkläds": "sorgkläder",
    "sorgklätt": "sorgklädd",
    "sorgklätts": "sorgklädd",
    "sorgliga": "sorglig",
    "sorgligare": "sorglig",
    "sorgligares": "sorglig",
    "sorgligas": "sorglig",
    "sorgligast": "sorglig",
    "sorgligaste": "sorglig",
    "sorgligastes": "sorglig",
    "sorgligasts": "sorglig",
    "sorglige": "sorglig",
    "sorgliges": "sorglig",
    "sorgligheten": "sorglighet",
    "sorglighetens": "sorglighet",
    "sorgligheter": "sorglighet",
    "sorgligheterna": "sorglighet",
    "sorgligheternas": "sorglighet",
    "sorgligheters": "sorglighet",
    "sorglighets": "sorglighet",
    "sorgligs": "sorglig",
    "sorgligt": "sorglig",
    "sorgligts": "sorglig",
    "sorglustiga": "sorglustig",
    "sorglustigare": "sorglustig",
    "sorglustigares": "sorglustig",
    "sorglustigas": "sorglustig",
    "sorglustigast": "sorglustig",
    "sorglustigaste": "sorglustig",
    "sorglustigastes": "sorglustig",
    "sorglustigasts": "sorglustig",
    "sorglustige": "sorglustig",
    "sorglustiges": "sorglustig",
    "sorglustigheten": "sorglustighet",
    "sorglustighetens": "sorglustighet",
    "sorglustighets": "sorglustighet",
    "sorglustigs": "sorglustig",
    "sorglustigt": "sorglustig",
    "sorglustigts": "sorglustig",
    "sorglösa": "sorglös",
    "sorglösare": "sorglös",
    "sorglösares": "sorglös",
    "sorglösas": "sorglös",
    "sorglösast": "sorglös",
    "sorglösaste": "sorglös",
    "sorglösastes": "sorglös",
    "sorglösasts": "sorglös",
    "sorglöse": "sorglös",
    "sorglöses": "sorglös",
    "sorglösheten": "sorglöshet",
    "sorglöshetens": "sorglöshet",
    "sorglösheter": "sorglöshet",
    "sorglösheterna": "sorglöshet",
    "sorglösheternas": "sorglöshet",
    "sorglösheters": "sorglöshet",
    "sorglöshets": "sorglöshet",
    "sorglöst": "sorglös",
    "sorglösts": "sorglös",
    "sorgmanteln": "sorgmantel",
    "sorgmantelns": "sorgmantel",
    "sorgmantels": "sorgmantel",
    "sorgmantlar": "sorgmantel",
    "sorgmantlarna": "sorgmantel",
    "sorgmantlarnas": "sorgmantel",
    "sorgmantlars": "sorgmantel",
    "sorgmodet": "sorgmod",
    "sorgmodets": "sorgmod",
    "sorgmodiga": "sorgmodig",
    "sorgmodigare": "sorgmodig",
    "sorgmodigares": "sorgmodig",
    "sorgmodigas": "sorgmodig",
    "sorgmodigast": "sorgmodig",
    "sorgmodigaste": "sorgmodig",
    "sorgmodigastes": "sorgmodig",
    "sorgmodigasts": "sorgmodig",
    "sorgmodige": "sorgmodig",
    "sorgmodiges": "sorgmodig",
    "sorgmodigheten": "sorgmodighet",
    "sorgmodighetens": "sorgmodighet",
    "sorgmodighets": "sorgmodighet",
    "sorgmodigs": "sorgmodig",
    "sorgmodigt": "sorgmodig",
    "sorgmodigts": "sorgmodig",
    "sorgmods": "sorgmod",
    "sorgmusiken": "sorgmusik",
    "sorgmusikens": "sorgmusik",
    "sorgmusiks": "sorgmusik",
    "sorgpilar": "sorgpil",
    "sorgpilarna": "sorgpil",
    "sorgpilarnas": "sorgpil",
    "sorgpilars": "sorgpil",
    "sorgpilen": "sorgpil",
    "sorgpilens": "sorgpil",
    "sorgpils": "sorgpil",
    "sorgs": "sorg",
    "sorgsens": "sorgsen",
    "sorgset": "sorgsen",
    "sorgsets": "sorgsen",
    "sorgslöjan": "sorgslöja",
    "sorgslöjans": "sorgslöja",
    "sorgslöjas": "sorgslöja",
    "sorgslöje": "sorgslöja",
    "sorgslöjor": "sorgslöja",
    "sorgslöjorna": "sorgslöja",
    "sorgslöjornas": "sorgslöja",
    "sorgslöjors": "sorgslöja",
    "sorgsna": "sorgsen",
    "sorgsnare": "sorgsen",
    "sorgsnares": "sorgsen",
    "sorgsnas": "sorgsen",
    "sorgsnast": "sorgsen",
    "sorgsnaste": "sorgsen",
    "sorgsnastes": "sorgsen",
    "sorgsnasts": "sorgsen",
    "sorgsne": "sorgsen",
    "sorgsnes": "sorgsen",
    "sorgtyngda": "sorgtyngd",
    "sorgtyngdare": "sorgtyngd",
    "sorgtyngdares": "sorgtyngd",
    "sorgtyngdas": "sorgtyngd",
    "sorgtyngdast": "sorgtyngd",
    "sorgtyngdaste": "sorgtyngd",
    "sorgtyngdastes": "sorgtyngd",
    "sorgtyngdasts": "sorgtyngd",
    "sorgtyngde": "sorgtyngd",
    "sorgtyngdes": "sorgtyngd",
    "sorgtyngdheten": "sorgtyngdhet",
    "sorgtyngdhetens": "sorgtyngdhet",
    "sorgtyngdhets": "sorgtyngdhet",
    "sorgtyngds": "sorgtyngd",
    "sorgtyngt": "sorgtyngd",
    "sorgtyngts": "sorgtyngd",
    "sorkar": "sork",
    "sorkarna": "sork",
    "sorkarnas": "sork",
    "sorkars": "sork",
    "sorken": "sork",
    "sorkens": "sork",
    "sorks": "sork",
    "sorlad": "sorla",
    "sorlade": "sorla",
    "sorlades": "sorla",
    "sorlads": "sorla",
    "sorlande": "sorla",
    "sorlanden": "sorlande",
    "sorlandena": "sorlande",
    "sorlandenas": "sorlande",
    "sorlandens": "sorlande",
    "sorlandes": "sorlande",
    "sorlandet": "sorlande",
    "sorlandets": "sorlande",
    "sorlar": "sorla",
    "sorlas": "sorla",
    "sorlat": "sorla",
    "sorlats": "sorla",
    "sorlet": "sorl",
    "sorlets": "sorl",
    "sorls": "sorl",
    "sorten": "sort",
    "sortens": "sort",
    "sorter": "sort",
    "sorterad": "sortera",
    "sorterade": "sortera",
    "sorterades": "sortera",
    "sorterads": "sortera",
    "sorterande": "sortera",
    "sorteranden": "sorterande",
    "sorterandena": "sorterande",
    "sorterandenas": "sorterande",
    "sorterandens": "sorterande",
    "sorterandes": "sorterande",
    "sorterandet": "sorterande",
    "sorterandets": "sorterande",
    "sorterar": "sorterare",
    "sorteraren": "sorterare",
    "sorterarens": "sorterare",
    "sorterares": "sorterare",
    "sorterarna": "sorterare",
    "sorterarnas": "sorterare",
    "sorteras": "sortera",
    "sorterat": "sortera",
    "sorterats": "sortera",
    "sorterbara": "sorterbar",
    "sorterbarare": "sorterbar",
    "sorterbarares": "sorterbar",
    "sorterbaras": "sorterbar",
    "sorterbarast": "sorterbar",
    "sorterbaraste": "sorterbar",
    "sorterbarastes": "sorterbar",
    "sorterbarasts": "sorterbar",
    "sorterbare": "sorterbar",
    "sorterbares": "sorterbar",
    "sorterbarheten": "sorterbarhet",
    "sorterbarhetens": "sorterbarhet",
    "sorterbarhets": "sorterbarhet",
    "sorterbars": "sorterbar",
    "sorterbart": "sorterbar",
    "sorterbarts": "sorterbar",
    "sorteringar": "sortering",
    "sorteringarna": "sortering",
    "sorteringarnas": "sortering",
    "sorteringars": "sortering",
    "sorteringen": "sortering",
    "sorteringens": "sortering",
    "sorterings": "sortering",
    "sorterna": "sort",
    "sorternas": "sort",
    "sorters": "sort",
    "sortien": "sorti",
    "sortiens": "sorti",
    "sortier": "sorti",
    "sortierna": "sorti",
    "sortiernas": "sorti",
    "sortiers": "sorti",
    "sortimentaskar": "sortimentask",
    "sortimentaskarna": "sortimentask",
    "sortimentaskarnas": "sortimentask",
    "sortimentaskars": "sortimentask",
    "sortimentasken": "sortimentask",
    "sortimentaskens": "sortimentask",
    "sortimentasks": "sortimentask",
    "sortimenten": "sortiment",
    "sortimentens": "sortiment",
    "sortimentet": "sortiment",
    "sortimentets": "sortiment",
    "sortiments": "sortiment",
    "sortin": "sorti",
    "sortins": "sorti",
    "sortis": "sorti",
    "sorts": "sort",
    "sos": "so",
    "sossar": "sosse",
    "sossarna": "sosse",
    "sossarnas": "sosse",
    "sossars": "sosse",
    "sossen": "sosse",
    "sossens": "sosse",
    "sosses": "sosse",
    "sot": "sota",
    "sotad": "sota",
    "sotade": "sota",
    "sotades": "sota",
    "sotads": "sota",
    "sotande": "sota",
    "sotanden": "sotande",
    "sotandena": "sotande",
    "sotandenas": "sotande",
    "sotandens": "sotande",
    "sotandes": "sotande",
    "sotandet": "sotande",
    "sotandets": "sotande",
    "sotar": "sotare",
    "sotaren": "sotare",
    "sotarens": "sotare",
    "sotares": "sotare",
    "sotarmurr": "sotarmurre",
    "sotarmurrar": "sotarmurre",
    "sotarmurrarna": "sotarmurre",
    "sotarmurrarnas": "sotarmurre",
    "sotarmurrars": "sotarmurre",
    "sotarmurren": "sotarmurre",
    "sotarmurrens": "sotarmurre",
    "sotarmurres": "sotarmurre",
    "sotarmurrs": "sotarmurre",
    "sotarna": "sotare",
    "sotarnas": "sotare",
    "sotarspråket": "sotarspråk",
    "sotarspråkets": "sotarspråk",
    "sotarspråks": "sotarspråk",
    "sotas": "sota",
    "sotat": "sota",
    "sotats": "sota",
    "sotbildningar": "sotbildning",
    "sotbildningarna": "sotbildning",
    "sotbildningarnas": "sotbildning",
    "sotbildningars": "sotbildning",
    "sotbildningen": "sotbildning",
    "sotbildningens": "sotbildning",
    "sotbildnings": "sotbildning",
    "sotbranden": "sotbrand",
    "sotbrandens": "sotbrand",
    "sotbrands": "sotbrand",
    "sotbrann": "sotbrand",
    "sotbranns": "sotbrand",
    "sotbränder": "sotbrand",
    "sotbränderna": "sotbrand",
    "sotbrändernas": "sotbrand",
    "sotbränders": "sotbrand",
    "sotdöden": "sotdöd",
    "sotdödens": "sotdöd",
    "sotdöds": "sotdöd",
    "soteldar": "soteld",
    "soteldarna": "soteld",
    "soteldarnas": "soteld",
    "soteldars": "soteld",
    "sotelden": "soteld",
    "soteldens": "soteld",
    "sotelds": "soteld",
    "soten": "sot",
    "sotens": "sot",
    "sotet": "sot",
    "sotets": "sot",
    "sothön": "sothöna",
    "sothönan": "sothöna",
    "sothönans": "sothöna",
    "sothönas": "sothöna",
    "sothöne": "sothöna",
    "sothönor": "sothöna",
    "sothönorna": "sothöna",
    "sothönornas": "sothöna",
    "sothönors": "sothöna",
    "sothöns": "sothöna",
    "sotiga": "sotig",
    "sotigare": "sotig",
    "sotigares": "sotig",
    "sotigas": "sotig",
    "sotigast": "sotig",
    "sotigaste": "sotig",
    "sotigastes": "sotig",
    "sotigasts": "sotig",
    "sotige": "sotig",
    "sotiges": "sotig",
    "sotigs": "sotig",
    "sotigt": "sotig",
    "sotigts": "sotig",
    "sotmolnen": "sotmoln",
    "sotmolnens": "sotmoln",
    "sotmolnet": "sotmoln",
    "sotmolnets": "sotmoln",
    "sotmolns": "sotmoln",
    "sotpartikeln": "sotpartikel",
    "sotpartikelns": "sotpartikel",
    "sotpartikels": "sotpartikel",
    "sotpartiklar": "sotpartikel",
    "sotpartiklarna": "sotpartikel",
    "sotpartiklarnas": "sotpartikel",
    "sotpartiklars": "sotpartikel",
    "sots": "sot",
    "sotskikten": "sotskikt",
    "sotskiktens": "sotskikt",
    "sotskiktet": "sotskikt",
    "sotskiktets": "sotskikt",
    "sotskikts": "sotskikt",
    "sotsvampar": "sotsvamp",
    "sotsvamparna": "sotsvamp",
    "sotsvamparnas": "sotsvamp",
    "sotsvampars": "sotsvamp",
    "sotsvampen": "sotsvamp",
    "sotsvampens": "sotsvamp",
    "sotsvamps": "sotsvamp",
    "sotsängen": "sotsäng",
    "sotsängens": "sotsäng",
    "sotsängs": "sotsäng",
    "sottisen": "sottis",
    "sottisens": "sottis",
    "sottiser": "sottis",
    "sottiserna": "sottis",
    "sottisernas": "sottis",
    "sottisers": "sottis",
    "soulagemangen": "soulagemang",
    "soulagemangens": "soulagemang",
    "soulagemanget": "soulagemang",
    "soulagemangets": "soulagemang",
    "soulagemangs": "soulagemang",
    "soulagerad": "soulagera",
    "soulagerade": "soulagera",
    "soulagerades": "soulagera",
    "soulagerads": "soulagera",
    "soulagerande": "soulagera",
    "soulageranden": "soulagerande",
    "soulagerandena": "soulagerande",
    "soulagerandenas": "soulagerande",
    "soulagerandens": "soulagerande",
    "soulagerandes": "soulagerande",
    "soulagerandet": "soulagerande",
    "soulagerandets": "soulagerande",
    "soulagerar": "soulagera",
    "soulageras": "soulagera",
    "soulagerat": "soulagera",
    "soulagerats": "soulagera",
    "soulagerbara": "soulagerbar",
    "soulagerbarare": "soulagerbar",
    "soulagerbarares": "soulagerbar",
    "soulagerbaras": "soulagerbar",
    "soulagerbarast": "soulagerbar",
    "soulagerbaraste": "soulagerbar",
    "soulagerbarastes": "soulagerbar",
    "soulagerbarasts": "soulagerbar",
    "soulagerbare": "soulagerbar",
    "soulagerbares": "soulagerbar",
    "soulagerbarheten": "soulagerbarhet",
    "soulagerbarhetens": "soulagerbarhet",
    "soulagerbarhets": "soulagerbarhet",
    "soulagerbars": "soulagerbar",
    "soulagerbart": "soulagerbar",
    "soulagerbarts": "soulagerbar",
    "soulageringar": "soulagering",
    "soulageringarna": "soulagering",
    "soulageringarnas": "soulagering",
    "soulageringars": "soulagering",
    "soulageringen": "soulagering",
    "soulageringens": "soulagering",
    "soulagerings": "soulagering",
    "soulen": "soul",
    "soulens": "soul",
    "soulmusiken": "soulmusik",
    "soulmusikens": "soulmusik",
    "soulmusiks": "soulmusik",
    "souls": "soul",
    "soumaken": "soumak",
    "soumakens": "soumak",
    "soumaks": "soumak",
    "sounden": "sound",
    "soundens": "sound",
    "soundet": "sound",
    "soundets": "sound",
    "soundmässiga": "soundmässig",
    "soundmässigare": "soundmässig",
    "soundmässigares": "soundmässig",
    "soundmässigas": "soundmässig",
    "soundmässigast": "soundmässig",
    "soundmässigaste": "soundmässig",
    "soundmässigastes": "soundmässig",
    "soundmässigasts": "soundmässig",
    "soundmässige": "soundmässig",
    "soundmässiges": "soundmässig",
    "soundmässigs": "soundmässig",
    "soundmässigt": "soundmässig",
    "soundmässigts": "soundmässig",
    "sounds": "sound",
    "sousafonen": "sousafon",
    "sousafonens": "sousafon",
    "sousafoner": "sousafon",
    "sousafonerna": "sousafon",
    "sousafonernas": "sousafon",
    "sousafoners": "sousafon",
    "sousafons": "sousafon",
    "souschefen": "souschef",
    "souschefens": "souschef",
    "souschefer": "souschef",
    "souscheferna": "souschef",
    "souschefernas": "souschef",
    "souschefers": "souschef",
    "souschefs": "souschef",
    "souterrainbyggnaden": "souterrainbyggnad",
    "souterrainbyggnadens": "souterrainbyggnad",
    "souterrainbyggnader": "souterrainbyggnad",
    "souterrainbyggnaderna": "souterrainbyggnad",
    "souterrainbyggnadernas": "souterrainbyggnad",
    "souterrainbyggnaders": "souterrainbyggnad",
    "souterrainbyggnads": "souterrainbyggnad",
    "souterrainen": "souterrain",
    "souterrainens": "souterrain",
    "souterrainer": "souterrain",
    "souterrainerna": "souterrain",
    "souterrainernas": "souterrain",
    "souterrainers": "souterrain",
    "souterrainhusen": "souterrainhus",
    "souterrainhusens": "souterrainhus",
    "souterrainhuset": "souterrainhus",
    "souterrainhusets": "souterrainhus",
    "souterrainplanen": "souterrainplan",
    "souterrainplanens": "souterrainplan",
    "souterrainplanet": "souterrainplan",
    "souterrainplanets": "souterrainplan",
    "souterrainplans": "souterrainplan",
    "souterrains": "souterrain",
    "souterrainvåningar": "souterrainvåning",
    "souterrainvåningarna": "souterrainvåning",
    "souterrainvåningarnas": "souterrainvåning",
    "souterrainvåningars": "souterrainvåning",
    "souterrainvåningen": "souterrainvåning",
    "souterrainvåningens": "souterrainvåning",
    "souterrainvånings": "souterrainvåning",
    "souterrängbyggnaden": "souterrängbyggnad",
    "souterrängbyggnadens": "souterrängbyggnad",
    "souterrängbyggnader": "souterrängbyggnad",
    "souterrängbyggnaderna": "souterrängbyggnad",
    "souterrängbyggnadernas": "souterrängbyggnad",
    "souterrängbyggnaders": "souterrängbyggnad",
    "souterrängbyggnads": "souterrängbyggnad",
    "souterrängen": "souterräng",
    "souterrängens": "souterräng",
    "souterränger": "souterräng",
    "souterrängerna": "souterräng",
    "souterrängernas": "souterräng",
    "souterrängers": "souterräng",
    "souterränghusen": "souterränghus",
    "souterränghusens": "souterränghus",
    "souterränghuset": "souterränghus",
    "souterränghusets": "souterränghus",
    "souterrängplanen": "souterrängplan",
    "souterrängplanens": "souterrängplan",
    "souterrängplanet": "souterrängplan",
    "souterrängplanets": "souterrängplan",
    "souterrängplans": "souterrängplan",
    "souterrängs": "souterräng",
    "souterrängvåningar": "souterrängvåning",
    "souterrängvåningarna": "souterrängvåning",
    "souterrängvåningarnas": "souterrängvåning",
    "souterrängvåningars": "souterrängvåning",
    "souterrängvåningen": "souterrängvåning",
    "souterrängvåningens": "souterrängvåning",
    "souterrängvånings": "souterrängvåning",
    "souveniren": "souvenir",
    "souvenirens": "souvenir",
    "souvenirer": "souvenir",
    "souvenirerna": "souvenir",
    "souvenirernas": "souvenir",
    "souvenirers": "souvenir",
    "souvenirs": "souvenir",
    "sov": "sova",
    "sovande": "sova",
    "sovanden": "sovande",
    "sovandena": "sovande",
    "sovandenas": "sovande",
    "sovandens": "sovande",
    "sovandes": "sovande",
    "sovandet": "sovande",
    "sovandets": "sovande",
    "sovas": "sova",
    "sovchosen": "sovchos",
    "sovchosens": "sovchos",
    "sovchoser": "sovchos",
    "sovchoserna": "sovchos",
    "sovchosernas": "sovchos",
    "sovchosers": "sovchos",
    "sove": "sova",
    "sovels": "sovel",
    "sover": "sova",
    "soves": "sova",
    "sovit": "sova",
    "sovits": "sova",
    "sovjeten": "sovjet",
    "sovjetens": "sovjet",
    "sovjeter": "sovjet",
    "sovjeterna": "sovjet",
    "sovjeternas": "sovjet",
    "sovjeters": "sovjet",
    "sovjetiserad": "sovjetisera",
    "sovjetiserade": "sovjetisera",
    "sovjetiserades": "sovjetisera",
    "sovjetiserads": "sovjetisera",
    "sovjetiserande": "sovjetisera",
    "sovjetiseranden": "sovjetiserande",
    "sovjetiserandena": "sovjetiserande",
    "sovjetiserandenas": "sovjetiserande",
    "sovjetiserandens": "sovjetiserande",
    "sovjetiserandes": "sovjetiserande",
    "sovjetiserandet": "sovjetiserande",
    "sovjetiserandets": "sovjetiserande",
    "sovjetiserar": "sovjetisera",
    "sovjetiseras": "sovjetisera",
    "sovjetiserat": "sovjetisera",
    "sovjetiserats": "sovjetisera",
    "sovjetiserbara": "sovjetiserbar",
    "sovjetiserbarare": "sovjetiserbar",
    "sovjetiserbarares": "sovjetiserbar",
    "sovjetiserbaras": "sovjetiserbar",
    "sovjetiserbarast": "sovjetiserbar",
    "sovjetiserbaraste": "sovjetiserbar",
    "sovjetiserbarastes": "sovjetiserbar",
    "sovjetiserbarasts": "sovjetiserbar",
    "sovjetiserbare": "sovjetiserbar",
    "sovjetiserbares": "sovjetiserbar",
    "sovjetiserbarheten": "sovjetiserbarhet",
    "sovjetiserbarhetens": "sovjetiserbarhet",
    "sovjetiserbarhets": "sovjetiserbarhet",
    "sovjetiserbars": "sovjetiserbar",
    "sovjetiserbart": "sovjetiserbar",
    "sovjetiserbarts": "sovjetiserbar",
    "sovjetiseringar": "sovjetisering",
    "sovjetiseringarna": "sovjetisering",
    "sovjetiseringarnas": "sovjetisering",
    "sovjetiseringars": "sovjetisering",
    "sovjetiseringen": "sovjetisering",
    "sovjetiseringens": "sovjetisering",
    "sovjetiserings": "sovjetisering",
    "sovjetiska": "sovjetisk",
    "sovjetiskare": "sovjetisk",
    "sovjetiskares": "sovjetisk",
    "sovjetiskas": "sovjetisk",
    "sovjetiskast": "sovjetisk",
    "sovjetiskaste": "sovjetisk",
    "sovjetiskastes": "sovjetisk",
    "sovjetiskasts": "sovjetisk",
    "sovjetiske": "sovjetisk",
    "sovjetiskes": "sovjetisk",
    "sovjetisks": "sovjetisk",
    "sovjetiskt": "sovjetisk",
    "sovjetiskts": "sovjetisk",
    "sovjetmedborgar": "sovjetmedborgare",
    "sovjetmedborgaren": "sovjetmedborgare",
    "sovjetmedborgarens": "sovjetmedborgare",
    "sovjetmedborgares": "sovjetmedborgare",
    "sovjetmedborgarna": "sovjetmedborgare",
    "sovjetmedborgarnas": "sovjetmedborgare",
    "sovjetrepubliken": "sovjetrepublik",
    "sovjetrepublikens": "sovjetrepublik",
    "sovjetrepubliker": "sovjetrepublik",
    "sovjetrepublikerna": "sovjetrepublik",
    "sovjetrepublikernas": "sovjetrepublik",
    "sovjetrepublikers": "sovjetrepublik",
    "sovjetrepubliks": "sovjetrepublik",
    "sovjetryska": "sovjetrysk",
    "sovjetryskare": "sovjetrysk",
    "sovjetryskares": "sovjetrysk",
    "sovjetryskas": "sovjetrysk",
    "sovjetryskast": "sovjetrysk",
    "sovjetryskaste": "sovjetrysk",
    "sovjetryskastes": "sovjetrysk",
    "sovjetryskasts": "sovjetrysk",
    "sovjetryske": "sovjetrysk",
    "sovjetryskes": "sovjetrysk",
    "sovjetrysks": "sovjetrysk",
    "sovjetryskt": "sovjetrysk",
    "sovjetryskts": "sovjetrysk",
    "sovlet": "sovel",
    "sovlets": "sovel",
    "sovmorgnar": "sovmorgon",
    "sovmorgnarna": "sovmorgon",
    "sovmorgnarnas": "sovmorgon",
    "sovmorgnars": "sovmorgon",
    "sovmorgonen": "sovmorgon",
    "sovmorgonens": "sovmorgon",
    "sovmorgons": "sovmorgon",
    "sovmornar": "sovmorgon",
    "sovmornarna": "sovmorgon",
    "sovmornarnas": "sovmorgon",
    "sovmornars": "sovmorgon",
    "sovplatsen": "sovplats",
    "sovplatsens": "sovplats",
    "sovplatser": "sovplats",
    "sovplatserna": "sovplats",
    "sovplatsernas": "sovplats",
    "sovplatsers": "sovplats",
    "sovrad": "sovra",
    "sovrade": "sovra",
    "sovrades": "sovra",
    "sovrads": "sovra",
    "sovrande": "sovra",
    "sovranden": "sovrande",
    "sovrandena": "sovrande",
    "sovrandenas": "sovrande",
    "sovrandens": "sovrande",
    "sovrandes": "sovrande",
    "sovrandet": "sovrande",
    "sovrandets": "sovrande",
    "sovrar": "sovra",
    "sovras": "sovra",
    "sovrat": "sovra",
    "sovrats": "sovra",
    "sovrummen": "sovrum",
    "sovrummens": "sovrum",
    "sovrummet": "sovrum",
    "sovrummets": "sovrum",
    "sovrums": "sovrum",
    "sovrumsfönsterna": "sovrumsfönster",
    "sovrumsfönsternas": "sovrumsfönster",
    "sovrumsfönsters": "sovrumsfönster",
    "sovrumsfönstren": "sovrumsfönster",
    "sovrumsfönstrens": "sovrumsfönster",
    "sovrumsfönstret": "sovrumsfönster",
    "sovrumsfönstrets": "sovrumsfönster",
    "sovs": "sova",
    "sovsalar": "sovsal",
    "sovsalarna": "sovsal",
    "sovsalarnas": "sovsal",
    "sovsalars": "sovsal",
    "sovsalen": "sovsal",
    "sovsalens": "sovsal",
    "sovsals": "sovsal",
    "sovstaden": "sovstad",
    "sovstadens": "sovstad",
    "sovstads": "sovstad",
    "sovstäder": "sovstad",
    "sovstäderna": "sovstad",
    "sovstädernas": "sovstad",
    "sovstäders": "sovstad",
    "sovställningar": "sovställning",
    "sovställningarna": "sovställning",
    "sovställningarnas": "sovställning",
    "sovställningars": "sovställning",
    "sovställningen": "sovställning",
    "sovställningens": "sovställning",
    "sovställnings": "sovställning",
    "sovsäckar": "sovsäck",
    "sovsäckarna": "sovsäck",
    "sovsäckarnas": "sovsäck",
    "sovsäckars": "sovsäck",
    "sovsäcken": "sovsäck",
    "sovsäckens": "sovsäck",
    "sovsäcks": "sovsäck",
    "sovvagnar": "sovvagn",
    "sovvagnarna": "sovvagn",
    "sovvagnarnas": "sovvagn",
    "sovvagnars": "sovvagn",
    "sovvagnen": "sovvagn",
    "sovvagnens": "sovvagn",
    "sovvagns": "sovvagn",
    "sovvagnsbiljetten": "sovvagnsbiljett",
    "sovvagnsbiljettens": "sovvagnsbiljett",
    "sovvagnsbiljetter": "sovvagnsbiljett",
    "sovvagnsbiljetterna": "sovvagnsbiljett",
    "sovvagnsbiljetternas": "sovvagnsbiljett",
    "sovvagnsbiljetters": "sovvagnsbiljett",
    "sovvagnsbiljetts": "sovvagnsbiljett",
    "spackel": "spackla",
    "spackelknivar": "spackelkniv",
    "spackelknivarna": "spackelkniv",
    "spackelknivarnas": "spackelkniv",
    "spackelknivars": "spackelkniv",
    "spackelkniven": "spackelkniv",
    "spackelknivens": "spackelkniv",
    "spackelknivs": "spackelkniv",
    "spackeln": "spackel",
    "spackelns": "spackel",
    "spackels": "spackel",
    "spacklad": "spackla",
    "spacklade": "spackla",
    "spacklades": "spackla",
    "spacklads": "spackla",
    "spacklande": "spackla",
    "spacklanden": "spacklande",
    "spacklandena": "spacklande",
    "spacklandenas": "spacklande",
    "spacklandens": "spacklande",
    "spacklandes": "spacklande",
    "spacklandet": "spacklande",
    "spacklandets": "spacklande",
    "spacklar": "spackla",
    "spacklarna": "spackel",
    "spacklarnas": "spackel",
    "spacklars": "spackel",
    "spacklas": "spackla",
    "spacklat": "spackla",
    "spacklats": "spackla",
    "spacklet": "spackel",
    "spacklets": "spackel",
    "spad": "spade",
    "spadar": "spade",
    "spadarna": "spade",
    "spadarnas": "spade",
    "spadars": "spade",
    "spaden": "spade",
    "spadens": "spade",
    "spadern": "spader",
    "spaderna": "spader",
    "spadernas": "spader",
    "spaderns": "spader",
    "spaders": "spader",
    "spades": "spade",
    "spadet": "spad",
    "spadets": "spad",
    "spads": "spade",
    "spadtagen": "spadtag",
    "spadtagens": "spadtag",
    "spadtaget": "spadtag",
    "spadtagets": "spadtag",
    "spadtags": "spadtag",
    "spadvänd": "spadvända",
    "spadvändande": "spadvända",
    "spadvändanden": "spadvändande",
    "spadvändandena": "spadvändande",
    "spadvändandenas": "spadvändande",
    "spadvändandens": "spadvändande",
    "spadvändandes": "spadvändande",
    "spadvändandet": "spadvändande",
    "spadvändandets": "spadvändande",
    "spadvändas": "spadvända",
    "spadvände": "spadvända",
    "spadvänder": "spadvända",
    "spadvändes": "spadvända",
    "spadvänds": "spadvända",
    "spadvänt": "spadvända",
    "spadvänts": "spadvända",
    "spagaten": "spagat",
    "spagatens": "spagat",
    "spagats": "spagat",
    "spagettin": "spagetti",
    "spagettins": "spagetti",
    "spagettis": "spagetti",
    "spagettiwesterns": "spagettiwestern",
    "spaghettin": "spaghetti",
    "spaghettins": "spaghetti",
    "spaghettis": "spaghetti",
    "spak": "spaka",
    "spaka": "spak",
    "spakad": "spaka",
    "spakade": "spaka",
    "spakades": "spaka",
    "spakads": "spaka",
    "spakande": "spaka",
    "spakanden": "spakande",
    "spakandena": "spakande",
    "spakandenas": "spakande",
    "spakandens": "spakande",
    "spakandes": "spakande",
    "spakandet": "spakande",
    "spakandets": "spakande",
    "spakar": "spaka",
    "spakare": "spak",
    "spakares": "spak",
    "spakarna": "spak",
    "spakarnas": "spak",
    "spakars": "spak",
    "spakas": "spaka",
    "spakast": "spak",
    "spakaste": "spak",
    "spakastes": "spak",
    "spakasts": "spak",
    "spakat": "spaka",
    "spakats": "spaka",
    "spakblocken": "spakblock",
    "spakblockens": "spakblock",
    "spakblocket": "spakblock",
    "spakblockets": "spakblock",
    "spakblocks": "spakblock",
    "spake": "spak",
    "spaken": "spak",
    "spakens": "spak",
    "spakes": "spak",
    "spakheten": "spakhet",
    "spakhetens": "spakhet",
    "spakhets": "spakhet",
    "spakn": "spakna",
    "spaknad": "spakna",
    "spaknade": "spakna",
    "spaknades": "spakna",
    "spaknads": "spakna",
    "spaknande": "spakna",
    "spaknanden": "spaknande",
    "spaknandena": "spaknande",
    "spaknandenas": "spaknande",
    "spaknandens": "spaknande",
    "spaknandes": "spaknande",
    "spaknandet": "spaknande",
    "spaknandets": "spaknande",
    "spaknar": "spakna",
    "spaknas": "spakna",
    "spaknat": "spakna",
    "spaknats": "spakna",
    "spaks": "spak",
    "spakt": "spak",
    "spakts": "spak",
    "spaljerad": "spaljera",
    "spaljerade": "spaljera",
    "spaljerades": "spaljera",
    "spaljerads": "spaljera",
    "spaljerande": "spaljera",
    "spaljeranden": "spaljerande",
    "spaljerandena": "spaljerande",
    "spaljerandenas": "spaljerande",
    "spaljerandens": "spaljerande",
    "spaljerandes": "spaljerande",
    "spaljerandet": "spaljerande",
    "spaljerandets": "spaljerande",
    "spaljerar": "spaljera",
    "spaljeras": "spaljera",
    "spaljerat": "spaljera",
    "spaljerats": "spaljera",
    "spaljerbara": "spaljerbar",
    "spaljerbarare": "spaljerbar",
    "spaljerbarares": "spaljerbar",
    "spaljerbaras": "spaljerbar",
    "spaljerbarast": "spaljerbar",
    "spaljerbaraste": "spaljerbar",
    "spaljerbarastes": "spaljerbar",
    "spaljerbarasts": "spaljerbar",
    "spaljerbare": "spaljerbar",
    "spaljerbares": "spaljerbar",
    "spaljerbarheten": "spaljerbarhet",
    "spaljerbarhetens": "spaljerbarhet",
    "spaljerbarhets": "spaljerbarhet",
    "spaljerbars": "spaljerbar",
    "spaljerbart": "spaljerbar",
    "spaljerbarts": "spaljerbar",
    "spaljeringar": "spaljering",
    "spaljeringarna": "spaljering",
    "spaljeringarnas": "spaljering",
    "spaljeringars": "spaljering",
    "spaljeringen": "spaljering",
    "spaljeringens": "spaljering",
    "spaljerings": "spaljering",
    "spaljéer": "spaljé",
    "spaljéerna": "spaljé",
    "spaljéernas": "spaljé",
    "spaljéers": "spaljé",
    "spaljén": "spaljé",
    "spaljéns": "spaljé",
    "spaljés": "spaljé",
    "spallationen": "spallation",
    "spallationens": "spallation",
    "spallations": "spallation",
    "spallerad": "spallera",
    "spallerade": "spallera",
    "spallerades": "spallera",
    "spallerads": "spallera",
    "spallerande": "spallera",
    "spalleranden": "spallerande",
    "spallerandena": "spallerande",
    "spallerandenas": "spallerande",
    "spallerandens": "spallerande",
    "spallerandes": "spallerande",
    "spallerandet": "spallerande",
    "spallerandets": "spallerande",
    "spallerar": "spallera",
    "spalleras": "spallera",
    "spallerat": "spallera",
    "spallerats": "spallera",
    "spallerbara": "spallerbar",
    "spallerbarare": "spallerbar",
    "spallerbarares": "spallerbar",
    "spallerbaras": "spallerbar",
    "spallerbarast": "spallerbar",
    "spallerbaraste": "spallerbar",
    "spallerbarastes": "spallerbar",
    "spallerbarasts": "spallerbar",
    "spallerbare": "spallerbar",
    "spallerbares": "spallerbar",
    "spallerbarheten": "spallerbarhet",
    "spallerbarhetens": "spallerbarhet",
    "spallerbarhets": "spallerbarhet",
    "spallerbars": "spallerbar",
    "spallerbart": "spallerbar",
    "spallerbarts": "spallerbar",
    "spalleringar": "spallering",
    "spalleringarna": "spallering",
    "spalleringarnas": "spallering",
    "spalleringars": "spallering",
    "spalleringen": "spallering",
    "spalleringens": "spallering",
    "spallerings": "spallering",
    "spalt": "spalta",
    "spaltad": "spalta",
    "spaltade": "spalta",
    "spaltades": "spalta",
    "spaltads": "spalta",
    "spaltande": "spalta",
    "spaltanden": "spaltande",
    "spaltandena": "spaltande",
    "spaltandenas": "spaltande",
    "spaltandens": "spaltande",
    "spaltandes": "spaltande",
    "spaltandet": "spaltande",
    "spaltandets": "spaltande",
    "spaltar": "spalta",
    "spaltas": "spalta",
    "spaltat": "spalta",
    "spaltats": "spalta",
    "spalten": "spalt",
    "spaltens": "spalt",
    "spalter": "spalt",
    "spalterna": "spalt",
    "spalternas": "spalt",
    "spalters": "spalt",
    "spaltfyllnaden": "spaltfyllnad",
    "spaltfyllnadens": "spaltfyllnad",
    "spaltfyllnader": "spaltfyllnad",
    "spaltfyllnaderna": "spaltfyllnad",
    "spaltfyllnadernas": "spaltfyllnad",
    "spaltfyllnaders": "spaltfyllnad",
    "spaltfyllnads": "spaltfyllnad",
    "spaltkilometern": "spaltkilometer",
    "spaltkilometerna": "spaltkilometer",
    "spaltkilometernas": "spaltkilometer",
    "spaltkilometerns": "spaltkilometer",
    "spaltkilometers": "spaltkilometer",
    "spaltkilometrar": "spaltkilometer",
    "spaltkilometrarna": "spaltkilometer",
    "spaltkilometrarnas": "spaltkilometer",
    "spaltkilometrars": "spaltkilometer",
    "spaltkorrekturen": "spaltkorrektur",
    "spaltkorrekturens": "spaltkorrektur",
    "spaltkorrekturet": "spaltkorrektur",
    "spaltkorrekturets": "spaltkorrektur",
    "spaltkorrekturs": "spaltkorrektur",
    "spaltläders": "spaltläder",
    "spaltlädret": "spaltläder",
    "spaltlädrets": "spaltläder",
    "spalts": "spalt",
    "span": "spana",
    "spana": "spa",
    "spanad": "spana",
    "spanade": "spana",
    "spanades": "spana",
    "spanads": "spana",
    "spanande": "spana",
    "spananden": "spanande",
    "spanandena": "spanande",
    "spanandenas": "spanande",
    "spanandens": "spanande",
    "spanandes": "spanande",
    "spanandet": "spanande",
    "spanandets": "spanande",
    "spanar": "spanare",
    "spanaren": "spanare",
    "spanarens": "spanare",
    "spanares": "spanare",
    "spanarna": "spanare",
    "spanarnas": "spanare",
    "spanas": "spana",
    "spanat": "spana",
    "spanats": "spana",
    "spanielar": "spaniel",
    "spanielarna": "spaniel",
    "spanielarnas": "spaniel",
    "spanielars": "spaniel",
    "spanieln": "spaniel",
    "spanielns": "spaniel",
    "spaniels": "spaniel",
    "spaningar": "spaning",
    "spaningarna": "spaning",
    "spaningarnas": "spaning",
    "spaningars": "spaning",
    "spaningen": "spaning",
    "spaningens": "spaning",
    "spanings": "spaning",
    "spaningspatrullen": "spaningspatrull",
    "spaningspatrullens": "spaningspatrull",
    "spaningspatruller": "spaningspatrull",
    "spaningspatrullerna": "spaningspatrull",
    "spaningspatrullernas": "spaningspatrull",
    "spaningspatrullers": "spaningspatrull",
    "spaningspatrulls": "spaningspatrull",
    "spanjoletten": "spanjolett",
    "spanjolettens": "spanjolett",
    "spanjoletter": "spanjolett",
    "spanjoletterna": "spanjolett",
    "spanjoletternas": "spanjolett",
    "spanjoletters": "spanjolett",
    "spanjoletts": "spanjolett",
    "spanjoren": "spanjor",
    "spanjorens": "spanjor",
    "spanjorer": "spanjor",
    "spanjorerna": "spanjor",
    "spanjorernas": "spanjor",
    "spanjorers": "spanjor",
    "spanjors": "spanjor",
    "spanjorskan": "spanjorska",
    "spanjorskans": "spanjorska",
    "spanjorskas": "spanjorska",
    "spanjorske": "spanjorska",
    "spanjorskor": "spanjorska",
    "spanjorskorna": "spanjorska",
    "spanjorskornas": "spanjorska",
    "spanjorskors": "spanjorska",
    "spankulerade": "spankulera",
    "spankulerades": "spankulera",
    "spankulerande": "spankulera",
    "spankuleranden": "spankulerande",
    "spankulerandena": "spankulerande",
    "spankulerandenas": "spankulerande",
    "spankulerandens": "spankulerande",
    "spankulerandes": "spankulerande",
    "spankulerandet": "spankulerande",
    "spankulerandets": "spankulerande",
    "spankulerar": "spankulera",
    "spankuleras": "spankulera",
    "spankulerat": "spankulera",
    "spankulerats": "spankulera",
    "spankuleringar": "spankulering",
    "spankuleringarna": "spankulering",
    "spankuleringarnas": "spankulering",
    "spankuleringars": "spankulering",
    "spankuleringen": "spankulering",
    "spankuleringens": "spankulering",
    "spankulerings": "spankulering",
    "spann": "spinna",
    "spannar": "spann",
    "spannarna": "spann",
    "spannarnas": "spann",
    "spannars": "spann",
    "spannen": "spann",
    "spannens": "spann",
    "spannet": "spann",
    "spannets": "spann",
    "spannmålen": "spannmål",
    "spannmålens": "spannmål",
    "spannmåls": "spannmål",
    "spannmålssmugglingen": "spannmålssmuggling",
    "spannmålssmugglingens": "spannmålssmuggling",
    "spannmålssmugglings": "spannmålssmuggling",
    "spanns": "spinna",
    "spans": "spa",
    "spansk": "spanska",
    "spanska": "spansk",
    "spanskan": "spanska",
    "spanskans": "spanska",
    "spanskare": "spansk",
    "spanskares": "spansk",
    "spanskas": "spanska",
    "spanskast": "spansk",
    "spanskaste": "spansk",
    "spanskastes": "spansk",
    "spanskasts": "spansk",
    "spanske": "spansk",
    "spanskes": "spansk",
    "spanskheten": "spanskhet",
    "spanskhetens": "spanskhet",
    "spanskhets": "spanskhet",
    "spanskrören": "spanskrör",
    "spanskrörens": "spanskrör",
    "spanskröret": "spanskrör",
    "spanskrörets": "spanskrör",
    "spanskrörs": "spanskrör",
    "spansks": "spansk",
    "spanskspråkiga": "spanskspråkig",
    "spanskspråkigas": "spanskspråkig",
    "spanskspråkige": "spanskspråkig",
    "spanskspråkiges": "spanskspråkig",
    "spanskspråkigheten": "spanskspråkighet",
    "spanskspråkighetens": "spanskspråkighet",
    "spanskspråkighets": "spanskspråkighet",
    "spanskspråkigs": "spanskspråkig",
    "spanskspråkigt": "spanskspråkig",
    "spanskspråkigts": "spanskspråkig",
    "spanskt": "spansk",
    "spanskts": "spansk",
    "spanten": "spant",
    "spantens": "spant",
    "spantet": "spant",
    "spantets": "spant",
    "spants": "spant",
    "spar": "spara",
    "sparad": "spara",
    "sparade": "spara",
    "sparades": "spara",
    "sparads": "spara",
    "sparagmiten": "sparagmit",
    "sparagmitens": "sparagmit",
    "sparagmiter": "sparagmit",
    "sparagmiterna": "sparagmit",
    "sparagmiternas": "sparagmit",
    "sparagmiters": "sparagmit",
    "sparagmits": "sparagmit",
    "sparande": "spara",
    "sparanden": "sparande",
    "sparandena": "sparande",
    "sparandenas": "sparande",
    "sparandens": "sparande",
    "sparandes": "sparande",
    "sparandet": "sparande",
    "sparandets": "sparande",
    "sparar": "sparare",
    "spararen": "sparare",
    "spararens": "sparare",
    "sparares": "sparare",
    "spararna": "sparare",
    "spararnas": "sparare",
    "sparas": "spara",
    "sparat": "spara",
    "sparats": "spara",
    "sparbanken": "sparbank",
    "sparbankens": "sparbank",
    "sparbanker": "sparbank",
    "sparbankerna": "sparbank",
    "sparbankernas": "sparbank",
    "sparbankers": "sparbank",
    "sparbanks": "sparbank",
    "sparböss": "sparbössa",
    "sparbössan": "sparbössa",
    "sparbössans": "sparbössa",
    "sparbössas": "sparbössa",
    "sparbösse": "sparbössa",
    "sparbössor": "sparbössa",
    "sparbössorna": "sparbössa",
    "sparbössornas": "sparbössa",
    "sparbössors": "sparbössa",
    "sparformen": "sparform",
    "sparformens": "sparform",
    "sparformer": "sparform",
    "sparformerna": "sparform",
    "sparformernas": "sparform",
    "sparformers": "sparform",
    "sparforms": "sparform",
    "spargrisar": "spargris",
    "spargrisarna": "spargris",
    "spargrisarnas": "spargris",
    "spargrisars": "spargris",
    "spargrisen": "spargris",
    "spargrisens": "spargris",
    "spark": "sparka",
    "sparkad": "sparka",
    "sparkade": "sparka",
    "sparkades": "sparkas",
    "sparkads": "sparka",
    "sparkande": "sparka",
    "sparkanden": "sparkande",
    "sparkandena": "sparkande",
    "sparkandenas": "sparkande",
    "sparkandens": "sparkande",
    "sparkandes": "sparkande",
    "sparkandet": "sparkande",
    "sparkandets": "sparkande",
    "sparkar": "sparka",
    "sparkarna": "spark",
    "sparkarnas": "spark",
    "sparkars": "spark",
    "sparkas": "sparka",
    "sparkassan": "sparkassa",
    "sparkassans": "sparkassa",
    "sparkassas": "sparkassa",
    "sparkasse": "sparkassa",
    "sparkassor": "sparkassa",
    "sparkassorna": "sparkassa",
    "sparkassornas": "sparkassa",
    "sparkassors": "sparkassa",
    "sparkat": "sparka",
    "sparkats": "sparkas",
    "sparkbyx": "sparkbyxa",
    "sparkbyxan": "sparkbyxa",
    "sparkbyxans": "sparkbyxa",
    "sparkbyxas": "sparkbyxa",
    "sparkbyxe": "sparkbyxa",
    "sparkbyxor": "sparkbyxa",
    "sparkbyxorna": "sparkbyxa",
    "sparkbyxornas": "sparkbyxa",
    "sparkbyxors": "sparkbyxa",
    "sparkcykeln": "sparkcykel",
    "sparkcykelns": "sparkcykel",
    "sparkcykels": "sparkcykel",
    "sparkcyklar": "sparkcykel",
    "sparkcyklarna": "sparkcykel",
    "sparkcyklarnas": "sparkcykel",
    "sparkcyklars": "sparkcykel",
    "sparkdräkten": "sparkdräkt",
    "sparkdräktens": "sparkdräkt",
    "sparkdräkter": "sparkdräkt",
    "sparkdräkterna": "sparkdräkt",
    "sparkdräkternas": "sparkdräkt",
    "sparkdräkters": "sparkdräkt",
    "sparkdräkts": "sparkdräkt",
    "sparken": "spark",
    "sparkens": "spark",
    "sparknummerna": "sparknummer",
    "sparknummernas": "sparknummer",
    "sparknummers": "sparknummer",
    "sparknumren": "sparknummer",
    "sparknumrens": "sparknummer",
    "sparknumret": "sparknummer",
    "sparknumrets": "sparknummer",
    "sparkonton": "sparkonto",
    "sparkontona": "sparkonto",
    "sparkontonas": "sparkonto",
    "sparkontons": "sparkonto",
    "sparkontos": "sparkonto",
    "sparkontot": "sparkonto",
    "sparkontots": "sparkonto",
    "sparkraven": "sparkrav",
    "sparkravens": "sparkrav",
    "sparkravet": "sparkrav",
    "sparkravets": "sparkrav",
    "sparkravs": "sparkrav",
    "sparks": "spark",
    "sparkstöttingar": "sparkstötting",
    "sparkstöttingarna": "sparkstötting",
    "sparkstöttingarnas": "sparkstötting",
    "sparkstöttingars": "sparkstötting",
    "sparkstöttingen": "sparkstötting",
    "sparkstöttingens": "sparkstötting",
    "sparkstöttings": "sparkstötting",
    "sparlakanen": "sparlakan",
    "sparlakanens": "sparlakan",
    "sparlakanet": "sparlakan",
    "sparlakanets": "sparlakan",
    "sparlakans": "sparlakan",
    "sparlakansläx": "sparlakansläxa",
    "sparlakansläxan": "sparlakansläxa",
    "sparlakansläxans": "sparlakansläxa",
    "sparlakansläxas": "sparlakansläxa",
    "sparlakansläxe": "sparlakansläxa",
    "sparlakansläxor": "sparlakansläxa",
    "sparlakansläxorna": "sparlakansläxa",
    "sparlakansläxornas": "sparlakansläxa",
    "sparlakansläxors": "sparlakansläxa",
    "sparlågan": "sparlåga",
    "sparlågans": "sparlåga",
    "sparlågas": "sparlåga",
    "sparlånen": "sparlån",
    "sparlånens": "sparlån",
    "sparlånet": "sparlån",
    "sparlånets": "sparlån",
    "sparlåns": "sparlån",
    "sparpaketen": "sparpaket",
    "sparpaketens": "sparpaket",
    "sparpaketet": "sparpaket",
    "sparpaketets": "sparpaket",
    "sparpakets": "sparpaket",
    "sparpeng": "sparpengar",
    "sparpengarna": "sparpengar",
    "sparpengarnas": "sparpengar",
    "sparpengars": "sparpengar",
    "sparpengs": "sparpengar",
    "sparr": "sparre",
    "sparrad": "sparra",
    "sparrade": "sparra",
    "sparrades": "sparra",
    "sparrads": "sparra",
    "sparrande": "sparra",
    "sparranden": "sparrande",
    "sparrandena": "sparrande",
    "sparrandenas": "sparrande",
    "sparrandens": "sparrande",
    "sparrandes": "sparrande",
    "sparrandet": "sparrande",
    "sparrandets": "sparrande",
    "sparrar": "sparre",
    "sparrarna": "sparre",
    "sparrarnas": "sparre",
    "sparrars": "sparre",
    "sparras": "sparra",
    "sparrat": "sparra",
    "sparrats": "sparra",
    "sparren": "sparre",
    "sparrens": "sparre",
    "sparres": "sparre",
    "sparringar": "sparring",
    "sparringarna": "sparring",
    "sparringarnas": "sparring",
    "sparringars": "sparring",
    "sparringen": "sparring",
    "sparringens": "sparring",
    "sparringpartnern": "sparringpartner",
    "sparringpartnerna": "sparringpartner",
    "sparringpartnernas": "sparringpartner",
    "sparringpartnerns": "sparringpartner",
    "sparringpartners": "sparringpartner",
    "sparringpartnersarna": "sparringpartner",
    "sparringpartnersarnas": "sparringpartner",
    "sparringpartnersen": "sparringpartner",
    "sparringpartnersens": "sparringpartner",
    "sparrisar": "sparris",
    "sparrisarna": "sparris",
    "sparrisarnas": "sparris",
    "sparrisars": "sparris",
    "sparrisen": "sparris",
    "sparrisens": "sparris",
    "sparrissoppan": "sparrissoppa",
    "sparrissoppans": "sparrissoppa",
    "sparrissoppas": "sparrissoppa",
    "sparrissoppe": "sparrissoppa",
    "sparrissoppor": "sparrissoppa",
    "sparrissopporna": "sparrissoppa",
    "sparrissoppornas": "sparrissoppa",
    "sparrissoppors": "sparrissoppa",
    "sparrs": "sparre",
    "spars": "spara",
    "sparsamheten": "sparsamhet",
    "sparsamhetens": "sparsamhet",
    "sparsamhets": "sparsamhet",
    "sparsamma": "sparsam",
    "sparsammare": "sparsam",
    "sparsammares": "sparsam",
    "sparsammas": "sparsam",
    "sparsammast": "sparsam",
    "sparsammaste": "sparsam",
    "sparsammastes": "sparsam",
    "sparsammasts": "sparsam",
    "sparsamme": "sparsam",
    "sparsammes": "sparsam",
    "sparsams": "sparsam",
    "sparsamt": "sparsam",
    "sparsamts": "sparsam",
    "sparslantar": "sparslant",
    "sparslantarna": "sparslant",
    "sparslantarnas": "sparslant",
    "sparslantars": "sparslant",
    "sparslanten": "sparslant",
    "sparslantens": "sparslant",
    "sparslants": "sparslant",
    "sparsmakade": "sparsmakad",
    "sparsmakades": "sparsmakad",
    "sparsmakads": "sparsmakad",
    "sparsmakat": "sparsmakad",
    "sparsmakats": "sparsmakad",
    "spartakisten": "spartakist",
    "spartakistens": "spartakist",
    "spartakister": "spartakist",
    "spartakisterna": "spartakist",
    "spartakisternas": "spartakist",
    "spartakisters": "spartakist",
    "spartakists": "spartakist",
    "spartanen": "spartan",
    "spartanens": "spartan",
    "spartaner": "spartan",
    "spartanerna": "spartan",
    "spartanernas": "spartan",
    "spartaners": "spartan",
    "spartans": "spartan",
    "spartanska": "spartansk",
    "spartanskare": "spartansk",
    "spartanskares": "spartansk",
    "spartanskas": "spartansk",
    "spartanskast": "spartansk",
    "spartanskaste": "spartansk",
    "spartanskastes": "spartansk",
    "spartanskasts": "spartansk",
    "spartanske": "spartansk",
    "spartanskes": "spartansk",
    "spartansks": "spartansk",
    "spartanskt": "spartansk",
    "spartanskts": "spartansk",
    "sparvar": "sparv",
    "sparvarna": "sparv",
    "sparvarnas": "sparv",
    "sparvars": "sparv",
    "sparven": "sparv",
    "sparvens": "sparv",
    "sparvfinkar": "sparvfink",
    "sparvfinkarna": "sparvfink",
    "sparvfinkarnas": "sparvfink",
    "sparvfinkars": "sparvfink",
    "sparvfinken": "sparvfink",
    "sparvfinkens": "sparvfink",
    "sparvfinks": "sparvfink",
    "sparvhökar": "sparvhök",
    "sparvhökarna": "sparvhök",
    "sparvhökarnas": "sparvhök",
    "sparvhökars": "sparvhök",
    "sparvhöken": "sparvhök",
    "sparvhökens": "sparvhök",
    "sparvhöks": "sparvhök",
    "sparvs": "sparv",
    "sparvugglan": "sparvuggla",
    "sparvugglans": "sparvuggla",
    "sparvugglas": "sparvuggla",
    "sparvuggle": "sparvuggla",
    "sparvugglor": "sparvuggla",
    "sparvugglorna": "sparvuggla",
    "sparvugglornas": "sparvuggla",
    "sparvugglors": "sparvuggla",
    "spas": "spa",
    "spasmen": "spasm",
    "spasmens": "spasm",
    "spasmer": "spasm",
    "spasmerna": "spasm",
    "spasmernas": "spasm",
    "spasmers": "spasm",
    "spasmodiska": "spasmodisk",
    "spasmodiskare": "spasmodisk",
    "spasmodiskares": "spasmodisk",
    "spasmodiskas": "spasmodisk",
    "spasmodiskast": "spasmodisk",
    "spasmodiskaste": "spasmodisk",
    "spasmodiskastes": "spasmodisk",
    "spasmodiskasts": "spasmodisk",
    "spasmodiske": "spasmodisk",
    "spasmodiskes": "spasmodisk",
    "spasmodisks": "spasmodisk",
    "spasmodiskt": "spasmodisk",
    "spasmodiskts": "spasmodisk",
    "spasms": "spasm",
    "spasticiteten": "spasticitet",
    "spasticitetens": "spasticitet",
    "spasticiteter": "spasticitet",
    "spasticiteterna": "spasticitet",
    "spasticiteternas": "spasticitet",
    "spasticiteters": "spasticitet",
    "spasticitets": "spasticitet",
    "spastikern": "spastiker",
    "spastikerna": "spastiker",
    "spastikernas": "spastiker",
    "spastikerns": "spastiker",
    "spastikers": "spastiker",
    "spastiska": "spastisk",
    "spastiskare": "spastisk",
    "spastiskares": "spastisk",
    "spastiskas": "spastisk",
    "spastiskast": "spastisk",
    "spastiskaste": "spastisk",
    "spastiskastes": "spastisk",
    "spastiskasts": "spastisk",
    "spastiske": "spastisk",
    "spastiskes": "spastisk",
    "spastisks": "spastisk",
    "spastiskt": "spastisk",
    "spastiskts": "spastisk",
    "spat": "spa",
    "spateln": "spatel",
    "spatelns": "spatel",
    "spatels": "spatel",
    "spatiala": "spatial",
    "spatialare": "spatial",
    "spatialares": "spatial",
    "spatialas": "spatial",
    "spatialast": "spatial",
    "spatialaste": "spatial",
    "spatialastes": "spatial",
    "spatialasts": "spatial",
    "spatiale": "spatial",
    "spatiales": "spatial",
    "spatials": "spatial",
    "spatialt": "spatial",
    "spatialts": "spatial",
    "spatie": "spatium",
    "spatier": "spatium",
    "spatierna": "spatium",
    "spatiernas": "spatium",
    "spatiers": "spatium",
    "spatiet": "spatium",
    "spatiets": "spatium",
    "spatiums": "spatium",
    "spatiösa": "spatiös",
    "spatiösare": "spatiös",
    "spatiösares": "spatiös",
    "spatiösas": "spatiös",
    "spatiösast": "spatiös",
    "spatiösaste": "spatiös",
    "spatiösastes": "spatiös",
    "spatiösasts": "spatiös",
    "spatiöse": "spatiös",
    "spatiöses": "spatiös",
    "spatiöst": "spatiös",
    "spatiösts": "spatiös",
    "spatlar": "spatel",
    "spatlarna": "spatel",
    "spatlarnas": "spatel",
    "spatlars": "spatel",
    "spats": "spa",
    "spatserade": "spatsera",
    "spatserades": "spatsera",
    "spatserande": "spatsera",
    "spatseranden": "spatserande",
    "spatserandena": "spatserande",
    "spatserandenas": "spatserande",
    "spatserandens": "spatserande",
    "spatserandes": "spatserande",
    "spatserandet": "spatserande",
    "spatserandets": "spatserande",
    "spatserar": "spatsera",
    "spatseras": "spatsera",
    "spatserat": "spatsera",
    "spatserats": "spatsera",
    "spatseringar": "spatsering",
    "spatseringarna": "spatsering",
    "spatseringarnas": "spatsering",
    "spatseringars": "spatsering",
    "spatseringen": "spatsering",
    "spatseringens": "spatsering",
    "spatserings": "spatsering",
    "spatten": "spatt",
    "spattens": "spatt",
    "spattiga": "spattig",
    "spattigare": "spattig",
    "spattigares": "spattig",
    "spattigas": "spattig",
    "spattigast": "spattig",
    "spattigaste": "spattig",
    "spattigastes": "spattig",
    "spattigasts": "spattig",
    "spattige": "spattig",
    "spattiges": "spattig",
    "spattigheten": "spattighet",
    "spattighetens": "spattighet",
    "spattigheter": "spattighet",
    "spattigheterna": "spattighet",
    "spattigheternas": "spattighet",
    "spattigheters": "spattighet",
    "spattighets": "spattighet",
    "spattigs": "spattig",
    "spattigt": "spattig",
    "spattigts": "spattig",
    "spatts": "spatt",
    "speak-easyn": "speak-easy",
    "speak-easyns": "speak-easy",
    "speak-easys": "speak-easy",
    "speakern": "speaker",
    "speakerna": "speaker",
    "speakernas": "speaker",
    "speakerns": "speaker",
    "speakers": "speaker",
    "speakersarna": "speaker",
    "speakersarnas": "speaker",
    "speakersen": "speaker",
    "speakersens": "speaker",
    "spearingen": "spearing",
    "spearingens": "spearing",
    "spearings": "spearing",
    "speceri": "specerier",
    "speceriaffären": "speceriaffär",
    "speceriaffärens": "speceriaffär",
    "speceriaffärer": "speceriaffär",
    "speceriaffärerna": "speceriaffär",
    "speceriaffärernas": "speceriaffär",
    "speceriaffärers": "speceriaffär",
    "speceriaffärs": "speceriaffär",
    "specerierna": "specerier",
    "speceriernas": "specerier",
    "speceriers": "specerier",
    "specerihandlar": "specerihandlare",
    "specerihandlaren": "specerihandlare",
    "specerihandlarens": "specerihandlare",
    "specerihandlares": "specerihandlare",
    "specerihandlarna": "specerihandlare",
    "specerihandlarnas": "specerihandlare",
    "speceristen": "specerist",
    "speceristens": "specerist",
    "specerister": "specerist",
    "speceristerna": "specerist",
    "speceristernas": "specerist",
    "speceristers": "specerist",
    "specerists": "specerist",
    "specialar": "specialare",
    "specialarbeten": "specialarbete",
    "specialarbetena": "specialarbete",
    "specialarbetenas": "specialarbete",
    "specialarbetens": "specialarbete",
    "specialarbetes": "specialarbete",
    "specialarbetet": "specialarbete",
    "specialarbetets": "specialarbete",
    "specialarbets": "specialarbete",
    "specialaren": "specialare",
    "specialarens": "specialare",
    "specialares": "specialare",
    "specialarna": "specialare",
    "specialarnas": "specialare",
    "specialbegåvningar": "specialbegåvning",
    "specialbegåvningarna": "specialbegåvning",
    "specialbegåvningarnas": "specialbegåvning",
    "specialbegåvningars": "specialbegåvning",
    "specialbegåvningen": "specialbegåvning",
    "specialbegåvningens": "specialbegåvning",
    "specialbegåvnings": "specialbegåvning",
    "specialdammsugar": "specialdammsugare",
    "specialdammsugaren": "specialdammsugare",
    "specialdammsugarens": "specialdammsugare",
    "specialdammsugares": "specialdammsugare",
    "specialdammsugarna": "specialdammsugare",
    "specialdammsugarnas": "specialdammsugare",
    "specialdomstolar": "specialdomstol",
    "specialdomstolarna": "specialdomstol",
    "specialdomstolarnas": "specialdomstol",
    "specialdomstolars": "specialdomstol",
    "specialdomstolen": "specialdomstol",
    "specialdomstolens": "specialdomstol",
    "specialdomstols": "specialdomstol",
    "specialen": "special",
    "specialens": "special",
    "specialer": "special",
    "specialerna": "special",
    "specialernas": "special",
    "specialers": "special",
    "specialintressen": "specialintresse",
    "specialintressena": "specialintresse",
    "specialintressenas": "specialintresse",
    "specialintressens": "specialintresse",
    "specialintresserade": "specialintresserad",
    "specialintresserades": "specialintresserad",
    "specialintresserads": "specialintresserad",
    "specialintresserat": "specialintresserad",
    "specialintresserats": "specialintresserad",
    "specialintresses": "specialintresse",
    "specialintresset": "specialintresse",
    "specialintressets": "specialintresse",
    "specialiserad": "specialisera",
    "specialiserade": "specialisera",
    "specialiserades": "specialisera",
    "specialiserads": "specialisera",
    "specialiserande": "specialisera",
    "specialiseranden": "specialiserande",
    "specialiserandena": "specialiserande",
    "specialiserandenas": "specialiserande",
    "specialiserandens": "specialiserande",
    "specialiserandes": "specialiserande",
    "specialiserandet": "specialiserande",
    "specialiserandets": "specialiserande",
    "specialiserar": "specialisera",
    "specialiseras": "specialisera",
    "specialiserat": "specialisera",
    "specialiserats": "specialisera",
    "specialiserbara": "specialiserbar",
    "specialiserbarare": "specialiserbar",
    "specialiserbarares": "specialiserbar",
    "specialiserbaras": "specialiserbar",
    "specialiserbarast": "specialiserbar",
    "specialiserbaraste": "specialiserbar",
    "specialiserbarastes": "specialiserbar",
    "specialiserbarasts": "specialiserbar",
    "specialiserbare": "specialiserbar",
    "specialiserbares": "specialiserbar",
    "specialiserbarheten": "specialiserbarhet",
    "specialiserbarhetens": "specialiserbarhet",
    "specialiserbarhets": "specialiserbarhet",
    "specialiserbars": "specialiserbar",
    "specialiserbart": "specialiserbar",
    "specialiserbarts": "specialiserbar",
    "specialiseringar": "specialisering",
    "specialiseringarna": "specialisering",
    "specialiseringarnas": "specialisering",
    "specialiseringars": "specialisering",
    "specialiseringen": "specialisering",
    "specialiseringens": "specialisering",
    "specialiserings": "specialisering",
    "specialisten": "specialist",
    "specialistens": "specialist",
    "specialister": "specialist",
    "specialisterna": "specialist",
    "specialisternas": "specialist",
    "specialisters": "specialist",
    "specialistkompetensen": "specialistkompetens",
    "specialistkompetensens": "specialistkompetens",
    "specialistkompetenser": "specialistkompetens",
    "specialistkompetenserna": "specialistkompetens",
    "specialistkompetensernas": "specialistkompetens",
    "specialistkompetensers": "specialistkompetens",
    "specialists": "specialist",
    "specialiteten": "specialitet",
    "specialitetens": "specialitet",
    "specialiteter": "specialitet",
    "specialiteterna": "specialitet",
    "specialiteternas": "specialitet",
    "specialiteters": "specialitet",
    "specialitets": "specialitet",
    "specialkart": "specialkarta",
    "specialkartan": "specialkarta",
    "specialkartans": "specialkarta",
    "specialkartas": "specialkarta",
    "specialkarte": "specialkarta",
    "specialkartor": "specialkarta",
    "specialkartorna": "specialkarta",
    "specialkartornas": "specialkarta",
    "specialkartors": "specialkarta",
    "specialkarts": "specialkarta",
    "specialklassen": "specialklass",
    "specialklassens": "specialklass",
    "specialklasser": "specialklass",
    "specialklasserna": "specialklass",
    "specialklassernas": "specialklass",
    "specialklassers": "specialklass",
    "specialkomponerade": "specialkomponerad",
    "specialkomponerades": "specialkomponerad",
    "specialkomponerads": "specialkomponerad",
    "specialkomponerat": "specialkomponerad",
    "specialkomponerats": "specialkomponerad",
    "speciallärar": "speciallärare",
    "specialläraren": "speciallärare",
    "speciallärarens": "speciallärare",
    "speciallärares": "speciallärare",
    "speciallärarna": "speciallärare",
    "speciallärarnas": "speciallärare",
    "specialnummerna": "specialnummer",
    "specialnummernas": "specialnummer",
    "specialnummers": "specialnummer",
    "specialnumren": "specialnummer",
    "specialnumrens": "specialnummer",
    "specialnumret": "specialnummer",
    "specialnumrets": "specialnummer",
    "specialområden": "specialområde",
    "specialområdena": "specialområde",
    "specialområdenas": "specialområde",
    "specialområdens": "specialområde",
    "specialområdes": "specialområde",
    "specialområdet": "specialområde",
    "specialområdets": "specialområde",
    "specialproblemen": "specialproblem",
    "specialproblemens": "specialproblem",
    "specialproblemet": "specialproblem",
    "specialproblemets": "specialproblem",
    "specialproblems": "specialproblem",
    "specials": "special",
    "specialskolan": "specialskola",
    "specialskolans": "specialskola",
    "specialskolas": "specialskola",
    "specialskole": "specialskola",
    "specialskolor": "specialskola",
    "specialskolorna": "specialskola",
    "specialskolornas": "specialskola",
    "specialskolors": "specialskola",
    "specialstudie": "specialstudium",
    "specialstudier": "specialstudium",
    "specialstudierna": "specialstudium",
    "specialstudiernas": "specialstudium",
    "specialstudiers": "specialstudium",
    "specialstudiet": "specialstudium",
    "specialstudiets": "specialstudium",
    "specialstudiums": "specialstudium",
    "specialstyrkan": "specialstyrka",
    "specialstyrkans": "specialstyrka",
    "specialstyrkas": "specialstyrka",
    "specialstyrke": "specialstyrka",
    "specialstyrkor": "specialstyrka",
    "specialstyrkorna": "specialstyrka",
    "specialstyrkornas": "specialstyrka",
    "specialstyrkors": "specialstyrka",
    "specialstålet": "specialstål",
    "specialstålets": "specialstål",
    "specialståls": "specialstål",
    "specialtillstånden": "specialtillstånd",
    "specialtillståndens": "specialtillstånd",
    "specialtillståndet": "specialtillstånd",
    "specialtillståndets": "specialtillstånd",
    "specialtillstånds": "specialtillstånd",
    "specialtågen": "specialtåg",
    "specialtågens": "specialtåg",
    "specialtåget": "specialtåg",
    "specialtågets": "specialtåg",
    "specialtågs": "specialtåg",
    "specialundervisningar": "specialundervisning",
    "specialundervisningarna": "specialundervisning",
    "specialundervisningarnas": "specialundervisning",
    "specialundervisningars": "specialundervisning",
    "specialundervisningen": "specialundervisning",
    "specialundervisningens": "specialundervisning",
    "specialundervisnings": "specialundervisning",
    "speciella": "speciell",
    "speciellare": "speciell",
    "speciellares": "speciell",
    "speciellas": "speciell",
    "speciellast": "speciell",
    "speciellaste": "speciell",
    "speciellastes": "speciell",
    "speciellasts": "speciell",
    "specielle": "speciell",
    "specielles": "speciell",
    "speciells": "speciell",
    "speciellt": "speciell",
    "speciellts": "speciell",
    "specien": "specie",
    "speciens": "specie",
    "specier": "specie",
    "specierna": "specie",
    "speciernas": "specie",
    "speciers": "specie",
    "species": "specie",
    "speciesen": "species",
    "speciesens": "species",
    "specieset": "species",
    "speciesets": "species",
    "specificerad": "specificera",
    "specificerade": "specificera",
    "specificerades": "specificera",
    "specificerads": "specificera",
    "specificerande": "specificera",
    "specificeranden": "specificerande",
    "specificerandena": "specificerande",
    "specificerandenas": "specificerande",
    "specificerandens": "specificerande",
    "specificerandes": "specificerande",
    "specificerandet": "specificerande",
    "specificerandets": "specificerande",
    "specificerar": "specificera",
    "specificeras": "specificera",
    "specificerat": "specificera",
    "specificerats": "specificera",
    "specificerbara": "specificerbar",
    "specificerbarare": "specificerbar",
    "specificerbarares": "specificerbar",
    "specificerbaras": "specificerbar",
    "specificerbarast": "specificerbar",
    "specificerbaraste": "specificerbar",
    "specificerbarastes": "specificerbar",
    "specificerbarasts": "specificerbar",
    "specificerbare": "specificerbar",
    "specificerbares": "specificerbar",
    "specificerbarheten": "specificerbarhet",
    "specificerbarhetens": "specificerbarhet",
    "specificerbarhets": "specificerbarhet",
    "specificerbars": "specificerbar",
    "specificerbart": "specificerbar",
    "specificerbarts": "specificerbar",
    "specificeringar": "specificering",
    "specificeringarna": "specificering",
    "specificeringarnas": "specificering",
    "specificeringars": "specificering",
    "specificeringen": "specificering",
    "specificeringens": "specificering",
    "specificerings": "specificering",
    "specifika": "specifik",
    "specifikare": "specifik",
    "specifikares": "specifik",
    "specifikas": "specifik",
    "specifikast": "specifik",
    "specifikaste": "specifik",
    "specifikastes": "specifik",
    "specifikasts": "specifik",
    "specifikationen": "specifikation",
    "specifikationens": "specifikation",
    "specifikationer": "specifikation",
    "specifikationerna": "specifikation",
    "specifikationernas": "specifikation",
    "specifikationers": "specifikation",
    "specifikations": "specifikation",
    "specifike": "specifik",
    "specifikes": "specifik",
    "specifiks": "specifik",
    "specifikt": "specifik",
    "specifikts": "specifik",
    "specimenen": "specimen",
    "specimenens": "specimen",
    "specimenet": "specimen",
    "specimenets": "specimen",
    "specimens": "specimen",
    "specimina": "specimen",
    "speciminas": "specimen",
    "speciminerad": "speciminera",
    "speciminerade": "speciminera",
    "speciminerades": "speciminera",
    "speciminerads": "speciminera",
    "speciminerande": "speciminera",
    "specimineranden": "speciminerande",
    "speciminerandena": "speciminerande",
    "speciminerandenas": "speciminerande",
    "speciminerandens": "speciminerande",
    "speciminerandes": "speciminerande",
    "speciminerandet": "speciminerande",
    "speciminerandets": "speciminerande",
    "speciminerar": "speciminera",
    "specimineras": "speciminera",
    "speciminerat": "speciminera",
    "speciminerats": "speciminera",
    "speciminerbara": "speciminerbar",
    "speciminerbarare": "speciminerbar",
    "speciminerbarares": "speciminerbar",
    "speciminerbaras": "speciminerbar",
    "speciminerbarast": "speciminerbar",
    "speciminerbaraste": "speciminerbar",
    "speciminerbarastes": "speciminerbar",
    "speciminerbarasts": "speciminerbar",
    "speciminerbare": "speciminerbar",
    "speciminerbares": "speciminerbar",
    "speciminerbarheten": "speciminerbarhet",
    "speciminerbarhetens": "speciminerbarhet",
    "speciminerbarhets": "speciminerbarhet",
    "speciminerbars": "speciminerbar",
    "speciminerbart": "speciminerbar",
    "speciminerbarts": "speciminerbar",
    "specimineringar": "speciminering",
    "specimineringarna": "speciminering",
    "specimineringarnas": "speciminering",
    "specimineringars": "speciminering",
    "specimineringen": "speciminering",
    "specimineringens": "speciminering",
    "speciminerings": "speciminering",
    "specnazen": "specnaz",
    "specnazens": "specnaz",
    "specsen": "species",
    "specsens": "species",
    "specset": "species",
    "specsets": "species",
    "speditionen": "spedition",
    "speditionens": "spedition",
    "speditioner": "spedition",
    "speditionerna": "spedition",
    "speditionernas": "spedition",
    "speditioners": "spedition",
    "speditions": "spedition",
    "speditören": "speditör",
    "speditörens": "speditör",
    "speditörer": "speditör",
    "speditörerna": "speditör",
    "speditörernas": "speditör",
    "speditörers": "speditör",
    "speditörs": "speditör",
    "speeden": "speed",
    "speedens": "speed",
    "speedet": "speed",
    "speedets": "speed",
    "speeds": "speed",
    "speedwaybanan": "speedwaybana",
    "speedwaybanans": "speedwaybana",
    "speedwaybanas": "speedwaybana",
    "speedwaybane": "speedwaybana",
    "speedwaybanor": "speedwaybana",
    "speedwaybanorna": "speedwaybana",
    "speedwaybanornas": "speedwaybana",
    "speedwaybanors": "speedwaybana",
    "speedwayen": "speedway",
    "speedwayens": "speedway",
    "speedways": "speedway",
    "spefulla": "spefull",
    "spefullare": "spefull",
    "spefullares": "spefull",
    "spefullas": "spefull",
    "spefullast": "spefull",
    "spefullaste": "spefull",
    "spefullastes": "spefull",
    "spefullasts": "spefull",
    "spefulle": "spefull",
    "spefulles": "spefull",
    "spefullheten": "spefullhet",
    "spefullhetens": "spefullhet",
    "spefullheter": "spefullhet",
    "spefullheterna": "spefullhet",
    "spefullheternas": "spefullhet",
    "spefullheters": "spefullhet",
    "spefullhets": "spefullhet",
    "spefulls": "spefull",
    "spefullt": "spefull",
    "spefullts": "spefull",
    "spefyllda": "spefylld",
    "spefylldare": "spefylld",
    "spefylldares": "spefylld",
    "spefylldas": "spefylld",
    "spefylldast": "spefylld",
    "spefylldaste": "spefylld",
    "spefylldastes": "spefylld",
    "spefylldasts": "spefylld",
    "spefyllde": "spefylld",
    "spefylldes": "spefylld",
    "spefylldheten": "spefylldhet",
    "spefylldhetens": "spefylldhet",
    "spefylldhets": "spefylldhet",
    "spefyllds": "spefylld",
    "spefyllt": "spefylld",
    "spefyllts": "spefylld",
    "spefågeln": "spefågel",
    "spefågelns": "spefågel",
    "spefågels": "spefågel",
    "spefåglar": "spefågel",
    "spefåglarna": "spefågel",
    "spefåglarnas": "spefågel",
    "spefåglars": "spefågel",
    "spegelbilden": "spegelbild",
    "spegelbildens": "spegelbild",
    "spegelbilder": "spegelbild",
    "spegelbilderna": "spegelbild",
    "spegelbildernas": "spegelbild",
    "spegelbilders": "spegelbild",
    "spegelbilds": "spegelbild",
    "spegelblanka": "spegelblank",
    "spegelblankare": "spegelblank",
    "spegelblankares": "spegelblank",
    "spegelblankas": "spegelblank",
    "spegelblankast": "spegelblank",
    "spegelblankaste": "spegelblank",
    "spegelblankastes": "spegelblank",
    "spegelblankasts": "spegelblank",
    "spegelblanke": "spegelblank",
    "spegelblankes": "spegelblank",
    "spegelblankheten": "spegelblankhet",
    "spegelblankhetens": "spegelblankhet",
    "spegelblankhets": "spegelblankhet",
    "spegelblanks": "spegelblank",
    "spegelblankt": "spegelblank",
    "spegelblankts": "spegelblank",
    "spegelfäkterier": "spegelfäkteri",
    "spegelfäkterierna": "spegelfäkteri",
    "spegelfäkteriernas": "spegelfäkteri",
    "spegelfäkteriers": "spegelfäkteri",
    "spegelfäkteriet": "spegelfäkteri",
    "spegelfäkteriets": "spegelfäkteri",
    "spegelfäkteris": "spegelfäkteri",
    "spegelfäkterit": "spegelfäkteri",
    "spegelfäkterits": "spegelfäkteri",
    "spegelfäktningar": "spegelfäktning",
    "spegelfäktningarna": "spegelfäktning",
    "spegelfäktningarnas": "spegelfäktning",
    "spegelfäktningars": "spegelfäktning",
    "spegelfäktningen": "spegelfäktning",
    "spegelfäktningens": "spegelfäktning",
    "spegelfäktnings": "spegelfäktning",
    "spegelglasen": "spegelglas",
    "spegelglasens": "spegelglas",
    "spegelglaset": "spegelglas",
    "spegelglasets": "spegelglas",
    "spegelkärn": "spegelkärna",
    "spegelkärnan": "spegelkärna",
    "spegelkärnans": "spegelkärna",
    "spegelkärnas": "spegelkärna",
    "spegelkärne": "spegelkärna",
    "spegelkärnor": "spegelkärna",
    "spegelkärnorna": "spegelkärna",
    "spegelkärnornas": "spegelkärna",
    "spegelkärnors": "spegelkärna",
    "spegelkärns": "spegelkärna",
    "spegelmonogrammen": "spegelmonogram",
    "spegelmonogrammens": "spegelmonogram",
    "spegelmonogrammet": "spegelmonogram",
    "spegelmonogrammets": "spegelmonogram",
    "spegelmonograms": "spegelmonogram",
    "spegeln": "spegel",
    "spegelns": "spegel",
    "spegelreflexkameran": "spegelreflexkamera",
    "spegelreflexkamerans": "spegelreflexkamera",
    "spegelreflexkameras": "spegelreflexkamera",
    "spegelreflexkameror": "spegelreflexkamera",
    "spegelreflexkamerorna": "spegelreflexkamera",
    "spegelreflexkamerornas": "spegelreflexkamera",
    "spegelreflexkamerors": "spegelreflexkamera",
    "spegels": "spegel",
    "spegelskriften": "spegelskrift",
    "spegelskriftens": "spegelskrift",
    "spegelskrifts": "spegelskrift",
    "spegelteleskopen": "spegelteleskop",
    "spegelteleskopens": "spegelteleskop",
    "spegelteleskopet": "spegelteleskop",
    "spegelteleskopets": "spegelteleskop",
    "spegelteleskops": "spegelteleskop",
    "spegeltesten": "spegeltest",
    "spegeltestens": "spegeltest",
    "spegeltester": "spegeltest",
    "spegeltesterna": "spegeltest",
    "spegeltesternas": "spegeltest",
    "spegeltesters": "spegeltest",
    "spegeltestet": "spegeltest",
    "spegeltestets": "spegeltest",
    "spegeltests": "spegeltest",
    "spegelvända": "spegelvänd",
    "spegelvändare": "spegelvänd",
    "spegelvändares": "spegelvänd",
    "spegelvändas": "spegelvänd",
    "spegelvändast": "spegelvänd",
    "spegelvändaste": "spegelvänd",
    "spegelvändastes": "spegelvänd",
    "spegelvändasts": "spegelvänd",
    "spegelvände": "spegelvänd",
    "spegelvändes": "spegelvänd",
    "spegelvänds": "spegelvänd",
    "spegelvänt": "spegelvänd",
    "spegelvänts": "spegelvänd",
    "speglad": "spegla",
    "speglade": "spegla",
    "speglades": "spegla",
    "speglads": "spegla",
    "speglande": "spegla",
    "speglanden": "speglande",
    "speglandena": "speglande",
    "speglandenas": "speglande",
    "speglandens": "speglande",
    "speglandes": "speglande",
    "speglandet": "speglande",
    "speglandets": "speglande",
    "speglar": "spegla",
    "speglarna": "spegel",
    "speglarnas": "spegel",
    "speglars": "spegel",
    "speglas": "spegla",
    "speglat": "spegla",
    "speglats": "spegla",
    "spej": "speja",
    "spejad": "speja",
    "spejade": "speja",
    "spejades": "speja",
    "spejads": "speja",
    "spejande": "speja",
    "spejanden": "spejande",
    "spejandena": "spejande",
    "spejandenas": "spejande",
    "spejandens": "spejande",
    "spejandes": "spejande",
    "spejandet": "spejande",
    "spejandets": "spejande",
    "spejar": "spejare",
    "spejaren": "spejare",
    "spejarens": "spejare",
    "spejares": "spejare",
    "spejarna": "spejare",
    "spejarnas": "spejare",
    "spejas": "speja",
    "spejat": "speja",
    "spejats": "speja",
    "spektakels": "spektakel",
    "spektaklen": "spektakel",
    "spektaklens": "spektakel",
    "spektaklet": "spektakel",
    "spektaklets": "spektakel",
    "spektakulära": "spektakulär",
    "spektakulärare": "spektakulär",
    "spektakulärares": "spektakulär",
    "spektakuläras": "spektakulär",
    "spektakulärast": "spektakulär",
    "spektakuläraste": "spektakulär",
    "spektakulärastes": "spektakulär",
    "spektakulärasts": "spektakulär",
    "spektakuläre": "spektakulär",
    "spektakuläres": "spektakulär",
    "spektakulärs": "spektakulär",
    "spektakulärt": "spektakulär",
    "spektakulärts": "spektakulär",
    "spektra": "spektrum",
    "spektrala": "spektral",
    "spektralanalysen": "spektralanalys",
    "spektralanalysens": "spektralanalys",
    "spektralapparaten": "spektralapparat",
    "spektralapparatens": "spektralapparat",
    "spektralapparater": "spektralapparat",
    "spektralapparaterna": "spektralapparat",
    "spektralapparaternas": "spektralapparat",
    "spektralapparaters": "spektralapparat",
    "spektralapparats": "spektralapparat",
    "spektralare": "spektral",
    "spektralares": "spektral",
    "spektralas": "spektral",
    "spektralast": "spektral",
    "spektralaste": "spektral",
    "spektralastes": "spektral",
    "spektralasts": "spektral",
    "spektrale": "spektral",
    "spektrales": "spektral",
    "spektrallinjen": "spektrallinje",
    "spektrallinjens": "spektrallinje",
    "spektrallinjer": "spektrallinje",
    "spektrallinjerna": "spektrallinje",
    "spektrallinjernas": "spektrallinje",
    "spektrallinjers": "spektrallinje",
    "spektrallinjes": "spektrallinje",
    "spektrals": "spektral",
    "spektralt": "spektral",
    "spektralts": "spektral",
    "spektrana": "spektrum",
    "spektranas": "spektrum",
    "spektras": "spektrum",
    "spektrena": "spektrum",
    "spektrenas": "spektrum",
    "spektrer": "spektrum",
    "spektrers": "spektrum",
    "spektret": "spektrum",
    "spektrets": "spektrum",
    "spektrografen": "spektrograf",
    "spektrografens": "spektrograf",
    "spektrografer": "spektrograf",
    "spektrograferna": "spektrograf",
    "spektrografernas": "spektrograf",
    "spektrografers": "spektrograf",
    "spektrografs": "spektrograf",
    "spektroskopen": "spektroskop",
    "spektroskopens": "spektroskop",
    "spektroskopet": "spektroskop",
    "spektroskopets": "spektroskop",
    "spektroskopien": "spektroskopi",
    "spektroskopiens": "spektroskopi",
    "spektroskopin": "spektroskopi",
    "spektroskopins": "spektroskopi",
    "spektroskopis": "spektroskopi",
    "spektroskops": "spektroskop",
    "spektrumen": "spektrum",
    "spektrumens": "spektrum",
    "spektrumet": "spektrum",
    "spektrumets": "spektrum",
    "spektrums": "spektrum",
    "spekulanten": "spekulant",
    "spekulantens": "spekulant",
    "spekulanter": "spekulant",
    "spekulanterna": "spekulant",
    "spekulanternas": "spekulant",
    "spekulanters": "spekulant",
    "spekulants": "spekulant",
    "spekulationen": "spekulation",
    "spekulationens": "spekulation",
    "spekulationer": "spekulation",
    "spekulationerna": "spekulation",
    "spekulationernas": "spekulation",
    "spekulationers": "spekulation",
    "spekulations": "spekulation",
    "spekulativa": "spekulativ",
    "spekulativare": "spekulativ",
    "spekulativares": "spekulativ",
    "spekulativas": "spekulativ",
    "spekulativast": "spekulativ",
    "spekulativaste": "spekulativ",
    "spekulativastes": "spekulativ",
    "spekulativasts": "spekulativ",
    "spekulative": "spekulativ",
    "spekulatives": "spekulativ",
    "spekulativs": "spekulativ",
    "spekulativt": "spekulativ",
    "spekulativts": "spekulativ",
    "spekulerad": "spekulera",
    "spekulerade": "spekulera",
    "spekulerades": "spekulera",
    "spekulerads": "spekulera",
    "spekulerande": "spekulera",
    "spekuleranden": "spekulerande",
    "spekulerandena": "spekulerande",
    "spekulerandenas": "spekulerande",
    "spekulerandens": "spekulerande",
    "spekulerandes": "spekulerande",
    "spekulerandet": "spekulerande",
    "spekulerandets": "spekulerande",
    "spekulerar": "spekulera",
    "spekuleras": "spekulera",
    "spekulerat": "spekulera",
    "spekulerats": "spekulera",
    "spekulerbara": "spekulerbar",
    "spekulerbarare": "spekulerbar",
    "spekulerbarares": "spekulerbar",
    "spekulerbaras": "spekulerbar",
    "spekulerbarast": "spekulerbar",
    "spekulerbaraste": "spekulerbar",
    "spekulerbarastes": "spekulerbar",
    "spekulerbarasts": "spekulerbar",
    "spekulerbare": "spekulerbar",
    "spekulerbares": "spekulerbar",
    "spekulerbarheten": "spekulerbarhet",
    "spekulerbarhetens": "spekulerbarhet",
    "spekulerbarhets": "spekulerbarhet",
    "spekulerbars": "spekulerbar",
    "spekulerbart": "spekulerbar",
    "spekulerbarts": "spekulerbar",
    "spekuleringar": "spekulering",
    "spekuleringarna": "spekulering",
    "spekuleringarnas": "spekulering",
    "spekuleringars": "spekulering",
    "spekuleringen": "spekulering",
    "spekuleringens": "spekulering",
    "spekulerings": "spekulering",
    "spel": "spela",
    "spelad": "spela",
    "spelade": "spela",
    "spelades": "spela",
    "spelads": "spela",
    "spelande": "spela",
    "spelanden": "spelande",
    "spelandena": "spelande",
    "spelandenas": "spelande",
    "spelandens": "spelande",
    "spelandes": "spelande",
    "spelandet": "spelande",
    "spelandets": "spelande",
    "spelar": "spelare",
    "spelarbyten": "spelarbyte",
    "spelarbytena": "spelarbyte",
    "spelarbytenas": "spelarbyte",
    "spelarbytens": "spelarbyte",
    "spelarbytes": "spelarbyte",
    "spelarbytet": "spelarbyte",
    "spelarbytets": "spelarbyte",
    "spelaren": "spelare",
    "spelarens": "spelare",
    "spelares": "spelare",
    "spelarmässiga": "spelarmässig",
    "spelarmässigare": "spelarmässig",
    "spelarmässigares": "spelarmässig",
    "spelarmässigas": "spelarmässig",
    "spelarmässigast": "spelarmässig",
    "spelarmässigaste": "spelarmässig",
    "spelarmässigastes": "spelarmässig",
    "spelarmässigasts": "spelarmässig",
    "spelarmässige": "spelarmässig",
    "spelarmässiges": "spelarmässig",
    "spelarmässigs": "spelarmässig",
    "spelarmässigt": "spelarmässig",
    "spelarmässigts": "spelarmässig",
    "spelarna": "spelare",
    "spelarnas": "spelare",
    "spelas": "spela",
    "spelat": "spela",
    "spelats": "spela",
    "spelautomaten": "spelautomat",
    "spelautomatens": "spelautomat",
    "spelautomater": "spelautomat",
    "spelautomaterna": "spelautomat",
    "spelautomaternas": "spelautomat",
    "spelautomaters": "spelautomat",
    "spelautomats": "spelautomat",
    "spelbara": "spelbar",
    "spelbarare": "spelbar",
    "spelbarares": "spelbar",
    "spelbaras": "spelbar",
    "spelbarast": "spelbar",
    "spelbaraste": "spelbar",
    "spelbarastes": "spelbar",
    "spelbarasts": "spelbar",
    "spelbare": "spelbar",
    "spelbares": "spelbar",
    "spelbarheten": "spelbarhet",
    "spelbarhetens": "spelbarhet",
    "spelbarhets": "spelbarhet",
    "spelbars": "spelbar",
    "spelbart": "spelbar",
    "spelbarts": "spelbar",
    "spelborden": "spelbord",
    "spelbordens": "spelbord",
    "spelbordet": "spelbord",
    "spelbordets": "spelbord",
    "spelbords": "spelbord",
    "spelbrick": "spelbricka",
    "spelbrickan": "spelbricka",
    "spelbrickans": "spelbricka",
    "spelbrickas": "spelbricka",
    "spelbricke": "spelbricka",
    "spelbrickor": "spelbricka",
    "spelbrickorna": "spelbricka",
    "spelbrickornas": "spelbricka",
    "spelbrickors": "spelbricka",
    "spelbricks": "spelbricka",
    "spelbutiken": "spelbutik",
    "spelbutikens": "spelbutik",
    "spelbutiker": "spelbutik",
    "spelbutikerna": "spelbutik",
    "spelbutikernas": "spelbutik",
    "spelbutikers": "spelbutik",
    "spelbutiks": "spelbutik",
    "speld": "spela",
    "spelda": "spela",
    "speldas": "spela",
    "spelde": "spela",
    "speldes": "spela",
    "speldjävulen": "speldjävul",
    "speldjävulens": "speldjävul",
    "speldjävuls": "speldjävul",
    "speldos": "speldosa",
    "speldosan": "speldosa",
    "speldosans": "speldosa",
    "speldosas": "speldosa",
    "speldose": "speldosa",
    "speldosor": "speldosa",
    "speldosorna": "speldosa",
    "speldosornas": "speldosa",
    "speldosors": "speldosa",
    "speldraman": "speldrama",
    "speldramana": "speldrama",
    "speldramanas": "speldrama",
    "speldramans": "speldrama",
    "speldramas": "speldrama",
    "speldramat": "speldrama",
    "speldramats": "speldrama",
    "speldramer": "speldrama",
    "speldramerna": "speldrama",
    "speldramernas": "speldrama",
    "speldramers": "speldrama",
    "spelds": "spela",
    "spelemannen": "speleman",
    "spelemannens": "speleman",
    "spelemans": "speleman",
    "spelemän": "speleman",
    "spelemännen": "speleman",
    "spelemännens": "speleman",
    "spelemäns": "speleman",
    "spelen": "spel",
    "spelens": "spel",
    "speleologen": "speleolog",
    "speleologens": "speleolog",
    "speleologer": "speleolog",
    "speleologerna": "speleolog",
    "speleologernas": "speleolog",
    "speleologers": "speleolog",
    "speleologien": "speleologi",
    "speleologiens": "speleologi",
    "speleologin": "speleologi",
    "speleologins": "speleologi",
    "speleologis": "speleologi",
    "speleologs": "speleolog",
    "spelet": "spel",
    "spelets": "spel",
    "spelevinkar": "spelevinker",
    "spelevinkarna": "spelevinker",
    "spelevinkarnas": "spelevinker",
    "spelevinkars": "spelevinker",
    "spelevinkern": "spelevinker",
    "spelevinkerns": "spelevinker",
    "spelevinkers": "spelevinker",
    "spelevinkrar": "spelevinker",
    "spelevinkrarna": "spelevinker",
    "spelevinkrarnas": "spelevinker",
    "spelevinkrars": "spelevinker",
    "spelfilmen": "spelfilm",
    "spelfilmens": "spelfilm",
    "spelfilmer": "spelfilm",
    "spelfilmerna": "spelfilm",
    "spelfilmernas": "spelfilm",
    "spelfilmers": "spelfilm",
    "spelfilms": "spelfilm",
    "spelhål": "spelhåla",
    "spelhålan": "spelhåla",
    "spelhålans": "spelhåla",
    "spelhålas": "spelhåla",
    "spelhåle": "spelhåla",
    "spelhålor": "spelhåla",
    "spelhålorna": "spelhåla",
    "spelhålornas": "spelhåla",
    "spelhålors": "spelhåla",
    "spelhåls": "spelhåla",
    "spelkonsolen": "spelkonsol",
    "spelkonsolens": "spelkonsol",
    "spelkonsoler": "spelkonsol",
    "spelkonsolerna": "spelkonsol",
    "spelkonsolernas": "spelkonsol",
    "spelkonsolers": "spelkonsol",
    "spelkonsols": "spelkonsol",
    "spelkorten": "spelkort",
    "spelkortens": "spelkort",
    "spelkortet": "spelkort",
    "spelkortets": "spelkort",
    "spelkorts": "spelkort",
    "spelmanien": "spelmani",
    "spelmaniens": "spelmani",
    "spelmanier": "spelmani",
    "spelmanierna": "spelmani",
    "spelmaniernas": "spelmani",
    "spelmaniers": "spelmani",
    "spelmanin": "spelmani",
    "spelmanins": "spelmani",
    "spelmanis": "spelmani",
    "spelmannen": "spelman",
    "spelmannens": "spelman",
    "spelmans": "spelman",
    "spelmansstämman": "spelmansstämma",
    "spelmansstämmans": "spelmansstämma",
    "spelmansstämmas": "spelmansstämma",
    "spelmansstämme": "spelmansstämma",
    "spelmansstämmo": "spelmansstämma",
    "spelmansstämmor": "spelmansstämma",
    "spelmansstämmorna": "spelmansstämma",
    "spelmansstämmornas": "spelmansstämma",
    "spelmansstämmors": "spelmansstämma",
    "spelmarken": "spelmark",
    "spelmarkens": "spelmark",
    "spelmarker": "spelmark",
    "spelmarkerna": "spelmark",
    "spelmarkernas": "spelmark",
    "spelmarkers": "spelmark",
    "spelmarks": "spelmark",
    "spelmän": "spelman",
    "spelmännen": "spelman",
    "spelmännens": "spelman",
    "spelmäns": "spelman",
    "spelmässiga": "spelmässig",
    "spelmässigare": "spelmässig",
    "spelmässigares": "spelmässig",
    "spelmässigas": "spelmässig",
    "spelmässigast": "spelmässig",
    "spelmässigaste": "spelmässig",
    "spelmässigastes": "spelmässig",
    "spelmässigasts": "spelmässig",
    "spelmässige": "spelmässig",
    "spelmässiges": "spelmässig",
    "spelmässigs": "spelmässig",
    "spelmässigt": "spelmässig",
    "spelmässigts": "spelmässig",
    "spelningar": "spelning",
    "spelningarna": "spelning",
    "spelningarnas": "spelning",
    "spelningars": "spelning",
    "spelningen": "spelning",
    "spelningens": "spelning",
    "spelnings": "spelning",
    "spelomgångar": "spelomgång",
    "spelomgångarna": "spelomgång",
    "spelomgångarnas": "spelomgång",
    "spelomgångars": "spelomgång",
    "spelomgången": "spelomgång",
    "spelomgångens": "spelomgång",
    "spelomgångs": "spelomgång",
    "spelplane": "spelplan",
    "spelplanen": "spelplan",
    "spelplanens": "spelplan",
    "spelplaner": "spelplan",
    "spelplanerna": "spelplan",
    "spelplanernas": "spelplan",
    "spelplaners": "spelplan",
    "spelplans": "spelplan",
    "spelproblemen": "spelproblem",
    "spelproblemens": "spelproblem",
    "spelproblemet": "spelproblem",
    "spelproblemets": "spelproblem",
    "spelproblems": "spelproblem",
    "spelproven": "spelprov",
    "spelprovens": "spelprov",
    "spelprovet": "spelprov",
    "spelprovets": "spelprov",
    "spelprovs": "spelprov",
    "spelrazzian": "spelrazzia",
    "spelrazzians": "spelrazzia",
    "spelrazzias": "spelrazzia",
    "spelrazzior": "spelrazzia",
    "spelrazziorna": "spelrazzia",
    "spelrazziornas": "spelrazzia",
    "spelrazziors": "spelrazzia",
    "spelregeln": "spelregel",
    "spelregelns": "spelregel",
    "spelregels": "spelregel",
    "spelregler": "spelregel",
    "spelreglerna": "spelregel",
    "spelreglernas": "spelregel",
    "spelreglers": "spelregel",
    "spelrummet": "spelrum",
    "spelrummets": "spelrum",
    "spelrums": "spelrum",
    "spels": "spel",
    "spelsugens": "spelsugen",
    "spelsuget": "spelsugen",
    "spelsugets": "spelsugen",
    "spelsugna": "spelsugen",
    "spelsugnare": "spelsugen",
    "spelsugnares": "spelsugen",
    "spelsugnas": "spelsugen",
    "spelsugnast": "spelsugen",
    "spelsugnaste": "spelsugen",
    "spelsugnastes": "spelsugen",
    "spelsugnasts": "spelsugen",
    "spelsugne": "spelsugen",
    "spelsugnes": "spelsugen",
    "spelt": "spela",
    "spelte": "spela",
    "spelteorien": "spelteori",
    "spelteoriens": "spelteori",
    "spelteorin": "spelteori",
    "spelteorins": "spelteori",
    "spelteoris": "spelteori",
    "speltes": "spela",
    "spelts": "spela",
    "spelverken": "spelverk",
    "spelverkens": "spelverk",
    "spelverket": "spelverk",
    "spelverkets": "spelverk",
    "spelverks": "spelverk",
    "spelåren": "spelår",
    "spelårens": "spelår",
    "spelåret": "spelår",
    "spelårets": "spelår",
    "spelårs": "spelår",
    "spelöppningar": "spelöppning",
    "spelöppningarna": "spelöppning",
    "spelöppningarnas": "spelöppning",
    "spelöppningars": "spelöppning",
    "spelöppningen": "spelöppning",
    "spelöppningens": "spelöppning",
    "spelöppnings": "spelöppning",
    "spen": "spene",
    "spenabarnen": "spenabarn",
    "spenabarnens": "spenabarn",
    "spenabarnet": "spenabarn",
    "spenabarnets": "spenabarn",
    "spenabarns": "spenabarn",
    "spenar": "spene",
    "spenarna": "spene",
    "spenarnas": "spene",
    "spenars": "spene",
    "spenaten": "spenat",
    "spenatens": "spenat",
    "spenats": "spenat",
    "spender": "spendera",
    "spenderad": "spendera",
    "spenderade": "spendera",
    "spenderades": "spendera",
    "spenderads": "spendera",
    "spenderande": "spendera",
    "spenderanden": "spenderande",
    "spenderandena": "spenderande",
    "spenderandenas": "spenderande",
    "spenderandens": "spenderande",
    "spenderandes": "spenderande",
    "spenderandet": "spenderande",
    "spenderandets": "spenderande",
    "spenderar": "spendera",
    "spenderas": "spendera",
    "spenderat": "spendera",
    "spenderats": "spendera",
    "spenderbara": "spenderbar",
    "spenderbarare": "spenderbar",
    "spenderbarares": "spenderbar",
    "spenderbaras": "spenderbar",
    "spenderbarast": "spenderbar",
    "spenderbaraste": "spenderbar",
    "spenderbarastes": "spenderbar",
    "spenderbarasts": "spenderbar",
    "spenderbare": "spenderbar",
    "spenderbares": "spenderbar",
    "spenderbarheten": "spenderbarhet",
    "spenderbarhetens": "spenderbarhet",
    "spenderbarhets": "spenderbarhet",
    "spenderbars": "spenderbar",
    "spenderbart": "spenderbar",
    "spenderbarts": "spenderbar",
    "spenderbyxornas": "spenderbyxorna",
    "spenen": "spene",
    "spenens": "spene",
    "spenes": "spene",
    "spenordningar": "spenordning",
    "spenordningarna": "spenordning",
    "spenordningarnas": "spenordning",
    "spenordningars": "spenordning",
    "spenordningen": "spenordning",
    "spenordningens": "spenordning",
    "spenordnings": "spenordning",
    "spens": "spene",
    "spensen": "spens",
    "spensens": "spens",
    "spenser": "spens",
    "spenserna": "spens",
    "spensernas": "spens",
    "spensers": "spens",
    "spensliga": "spenslig",
    "spensligare": "spenslig",
    "spensligares": "spenslig",
    "spensligas": "spenslig",
    "spensligast": "spenslig",
    "spensligaste": "spenslig",
    "spensligastes": "spenslig",
    "spensligasts": "spenslig",
    "spenslige": "spenslig",
    "spensliges": "spenslig",
    "spensligheten": "spenslighet",
    "spenslighetens": "spenslighet",
    "spenslighets": "spenslighet",
    "spensligs": "spenslig",
    "spensligt": "spenslig",
    "spensligts": "spenslig",
    "spermabildningar": "spermabildning",
    "spermabildningarna": "spermabildning",
    "spermabildningarnas": "spermabildning",
    "spermabildningars": "spermabildning",
    "spermabildningen": "spermabildning",
    "spermabildningens": "spermabildning",
    "spermabildnings": "spermabildning",
    "spermacetin": "spermaceti",
    "spermacetins": "spermaceti",
    "spermacetis": "spermaceti",
    "spermadonatorer": "spermadonator",
    "spermadonatorerna": "spermadonator",
    "spermadonatorernas": "spermadonator",
    "spermadonatorers": "spermadonator",
    "spermadonatorn": "spermadonator",
    "spermadonatorns": "spermadonator",
    "spermadonators": "spermadonator",
    "spermakvaliteten": "spermakvalitet",
    "spermakvalitetens": "spermakvalitet",
    "spermakvaliteter": "spermakvalitet",
    "spermakvaliteterna": "spermakvalitet",
    "spermakvaliteternas": "spermakvalitet",
    "spermakvaliteters": "spermakvalitet",
    "spermakvalitets": "spermakvalitet",
    "spermamottagarsäckar": "spermamottagarsäck",
    "spermamottagarsäckarna": "spermamottagarsäck",
    "spermamottagarsäckarnas": "spermamottagarsäck",
    "spermamottagarsäckars": "spermamottagarsäck",
    "spermamottagarsäcken": "spermamottagarsäck",
    "spermamottagarsäckens": "spermamottagarsäck",
    "spermamottagarsäcks": "spermamottagarsäck",
    "sperman": "sperma",
    "spermans": "sperma",
    "spermas": "sperma",
    "spermat": "sperma",
    "spermatoforen": "spermatofor",
    "spermatoforens": "spermatofor",
    "spermatoforer": "spermatofor",
    "spermatoforerna": "spermatofor",
    "spermatoforernas": "spermatofor",
    "spermatoforers": "spermatofor",
    "spermatofors": "spermatofor",
    "spermatozoer": "spermatozo",
    "spermatozoerna": "spermatozo",
    "spermatozoernas": "spermatozo",
    "spermatozoers": "spermatozo",
    "spermatozoiden": "spermatozoid",
    "spermatozoidens": "spermatozoid",
    "spermatozoider": "spermatozoid",
    "spermatozoiderna": "spermatozoid",
    "spermatozoidernas": "spermatozoid",
    "spermatozoiders": "spermatozoid",
    "spermatozoids": "spermatozoid",
    "spermatozon": "spermatozo",
    "spermatozons": "spermatozo",
    "spermatozos": "spermatozo",
    "spermats": "sperma",
    "spermiemitokondrien": "spermiemitokondrie",
    "spermiemitokondriens": "spermiemitokondrie",
    "spermiemitokondrier": "spermiemitokondrie",
    "spermiemitokondrierna": "spermiemitokondrie",
    "spermiemitokondriernas": "spermiemitokondrie",
    "spermiemitokondriers": "spermiemitokondrie",
    "spermiemitokondries": "spermiemitokondrie",
    "spermiemodercellen": "spermiemodercell",
    "spermiemodercellens": "spermiemodercell",
    "spermiemoderceller": "spermiemodercell",
    "spermiemodercellerna": "spermiemodercell",
    "spermiemodercellernas": "spermiemodercell",
    "spermiemodercellers": "spermiemodercell",
    "spermiemodercells": "spermiemodercell",
    "spermien": "spermie",
    "spermiens": "spermie",
    "spermier": "spermie",
    "spermierna": "spermie",
    "spermiernas": "spermie",
    "spermiers": "spermie",
    "spermies": "spermie",
    "spes": "spe",
    "spet": "speta",
    "spetade": "speta",
    "spetades": "speta",
    "spetan": "speta",
    "spetande": "speta",
    "spetanden": "spetande",
    "spetandena": "spetande",
    "spetandenas": "spetande",
    "spetandens": "spetande",
    "spetandes": "spetande",
    "spetandet": "spetande",
    "spetandets": "spetande",
    "spetans": "speta",
    "spetar": "speta",
    "spetas": "speta",
    "spetat": "speta",
    "spetats": "speta",
    "spete": "speta",
    "spetiga": "spetig",
    "spetigare": "spetig",
    "spetigares": "spetig",
    "spetigas": "spetig",
    "spetigast": "spetig",
    "spetigaste": "spetig",
    "spetigastes": "spetig",
    "spetigasts": "spetig",
    "spetige": "spetig",
    "spetiges": "spetig",
    "spetigs": "spetig",
    "spetigt": "spetig",
    "spetigts": "spetig",
    "spetor": "speta",
    "spetorna": "speta",
    "spetornas": "speta",
    "spetors": "speta",
    "spets": "spetsa",
    "spetsad": "spetsa",
    "spetsade": "spetsa",
    "spetsades": "spetsa",
    "spetsads": "spetsa",
    "spetsande": "spetsa",
    "spetsanden": "spetsande",
    "spetsandena": "spetsande",
    "spetsandenas": "spetsande",
    "spetsandens": "spetsande",
    "spetsandes": "spetsande",
    "spetsandet": "spetsande",
    "spetsandets": "spetsande",
    "spetsar": "spetsa",
    "spetsarna": "spets",
    "spetsarnas": "spets",
    "spetsars": "spets",
    "spetsartikeln": "spetsartikel",
    "spetsartikelns": "spetsartikel",
    "spetsartikels": "spetsartikel",
    "spetsartiklar": "spetsartikel",
    "spetsartiklarna": "spetsartikel",
    "spetsartiklarnas": "spetsartikel",
    "spetsartiklars": "spetsartikel",
    "spetsas": "spetsa",
    "spetsat": "spetsa",
    "spetsats": "spetsa",
    "spetsborgar": "spetsborgare",
    "spetsborgaren": "spetsborgare",
    "spetsborgarens": "spetsborgare",
    "spetsborgares": "spetsborgare",
    "spetsborgarna": "spetsborgare",
    "spetsborgarnas": "spetsborgare",
    "spetsbovar": "spetsbov",
    "spetsbovarna": "spetsbov",
    "spetsbovarnas": "spetsbov",
    "spetsbovars": "spetsbov",
    "spetsboven": "spetsbov",
    "spetsbovens": "spetsbov",
    "spetsbovs": "spetsbov",
    "spetsbyx": "spetsbyxa",
    "spetsbyxan": "spetsbyxa",
    "spetsbyxans": "spetsbyxa",
    "spetsbyxas": "spetsbyxa",
    "spetsbyxe": "spetsbyxa",
    "spetsbyxor": "spetsbyxa",
    "spetsbyxorna": "spetsbyxa",
    "spetsbyxornas": "spetsbyxa",
    "spetsbyxors": "spetsbyxa",
    "spetsbåg": "spetsbåge",
    "spetsbågar": "spetsbåge",
    "spetsbågarna": "spetsbåge",
    "spetsbågarnas": "spetsbåge",
    "spetsbågars": "spetsbåge",
    "spetsbågen": "spetsbåge",
    "spetsbågens": "spetsbåge",
    "spetsbåges": "spetsbåge",
    "spetsbågestilen": "spetsbågestil",
    "spetsbågestilens": "spetsbågestil",
    "spetsbågestils": "spetsbågestil",
    "spetsbågs": "spetsbåge",
    "spetsbågsstilen": "spetsbågsstil",
    "spetsbågsstilens": "spetsbågsstil",
    "spetsbågsstils": "spetsbågsstil",
    "spetsdukar": "spetsduk",
    "spetsdukarna": "spetsduk",
    "spetsdukarnas": "spetsduk",
    "spetsdukars": "spetsduk",
    "spetsduken": "spetsduk",
    "spetsdukens": "spetsduk",
    "spetsduks": "spetsduk",
    "spetsen": "spets",
    "spetsens": "spets",
    "spetsfoten": "spetsfot",
    "spetsfotens": "spetsfot",
    "spetsfots": "spetsfot",
    "spetsfundiga": "spetsfundig",
    "spetsfundigare": "spetsfundig",
    "spetsfundigares": "spetsfundig",
    "spetsfundigas": "spetsfundig",
    "spetsfundigast": "spetsfundig",
    "spetsfundigaste": "spetsfundig",
    "spetsfundigastes": "spetsfundig",
    "spetsfundigasts": "spetsfundig",
    "spetsfundige": "spetsfundig",
    "spetsfundiges": "spetsfundig",
    "spetsfundigheten": "spetsfundighet",
    "spetsfundighetens": "spetsfundighet",
    "spetsfundigheter": "spetsfundighet",
    "spetsfundigheterna": "spetsfundighet",
    "spetsfundigheternas": "spetsfundighet",
    "spetsfundigheters": "spetsfundighet",
    "spetsfundighets": "spetsfundighet",
    "spetsfundigs": "spetsfundig",
    "spetsfundigt": "spetsfundig",
    "spetsfundigts": "spetsfundig",
    "spetsgardinen": "spetsgardin",
    "spetsgardinens": "spetsgardin",
    "spetsgardiner": "spetsgardin",
    "spetsgardinerna": "spetsgardin",
    "spetsgardinernas": "spetsgardin",
    "spetsgardiners": "spetsgardin",
    "spetsgardins": "spetsgardin",
    "spetsgaveln": "spetsgavel",
    "spetsgavelns": "spetsgavel",
    "spetsgavels": "spetsgavel",
    "spetsgavlar": "spetsgavel",
    "spetsgavlarna": "spetsgavel",
    "spetsgavlarnas": "spetsgavel",
    "spetsgavlars": "spetsgavel",
    "spetsglasen": "spetsglas",
    "spetsglasens": "spetsglas",
    "spetsglaset": "spetsglas",
    "spetsglasets": "spetsglas",
    "spetshundar": "spetshund",
    "spetshundarna": "spetshund",
    "spetshundarnas": "spetshund",
    "spetshundars": "spetshund",
    "spetshunden": "spetshund",
    "spetshundens": "spetshund",
    "spetshunds": "spetshund",
    "spetsiga": "spetsig",
    "spetsigare": "spetsig",
    "spetsigares": "spetsig",
    "spetsigas": "spetsig",
    "spetsigast": "spetsig",
    "spetsigaste": "spetsig",
    "spetsigastes": "spetsig",
    "spetsigasts": "spetsig",
    "spetsige": "spetsig",
    "spetsiges": "spetsig",
    "spetsigheten": "spetsighet",
    "spetsighetens": "spetsighet",
    "spetsigheter": "spetsighet",
    "spetsigheterna": "spetsighet",
    "spetsigheternas": "spetsighet",
    "spetsigheters": "spetsighet",
    "spetsighets": "spetsighet",
    "spetsigs": "spetsig",
    "spetsigt": "spetsig",
    "spetsigts": "spetsig",
    "spetskompetensen": "spetskompetens",
    "spetskompetensens": "spetskompetens",
    "spetskompetenser": "spetskompetens",
    "spetskompetenserna": "spetskompetens",
    "spetskompetensernas": "spetskompetens",
    "spetskompetensers": "spetskompetens",
    "spetsnazen": "spetsnaz",
    "spetsnazens": "spetsnaz",
    "spetstänger": "spetstång",
    "spetstängerna": "spetstång",
    "spetstängernas": "spetstång",
    "spetstängers": "spetstång",
    "spetstången": "spetstång",
    "spetstångens": "spetstång",
    "spetstångs": "spetstång",
    "spetsunderkläderna": "spetsunderkläder",
    "spetsunderklädernas": "spetsunderkläder",
    "spetsunderkläders": "spetsunderkläder",
    "spetsunderklädes": "spetsunderkläder",
    "spetsunderkläds": "spetsunderkläder",
    "spetsvinkliga": "spetsvinklig",
    "spetsvinkligare": "spetsvinklig",
    "spetsvinkligares": "spetsvinklig",
    "spetsvinkligas": "spetsvinklig",
    "spetsvinkligast": "spetsvinklig",
    "spetsvinkligaste": "spetsvinklig",
    "spetsvinkligastes": "spetsvinklig",
    "spetsvinkligasts": "spetsvinklig",
    "spetsvinklige": "spetsvinklig",
    "spetsvinkliges": "spetsvinklig",
    "spetsvinkligheten": "spetsvinklighet",
    "spetsvinklighetens": "spetsvinklighet",
    "spetsvinklighets": "spetsvinklighet",
    "spetsvinkligs": "spetsvinklig",
    "spetsvinkligt": "spetsvinklig",
    "spetsvinkligts": "spetsvinklig",
    "spett": "spetta",
    "spettad": "spetta",
    "spettade": "spetta",
    "spettades": "spetta",
    "spettads": "spetta",
    "spettande": "spetta",
    "spettanden": "spettande",
    "spettandena": "spettande",
    "spettandenas": "spettande",
    "spettandens": "spettande",
    "spettandes": "spettande",
    "spettandet": "spettande",
    "spettandets": "spettande",
    "spettar": "spetta",
    "spettas": "spetta",
    "spettat": "spetta",
    "spettats": "spetta",
    "spettekak": "spettekaka",
    "spettekakan": "spettekaka",
    "spettekakans": "spettekaka",
    "spettekakas": "spettekaka",
    "spettekake": "spettekaka",
    "spettekakor": "spettekaka",
    "spettekakorna": "spettekaka",
    "spettekakornas": "spettekaka",
    "spettekakors": "spettekaka",
    "spettekaks": "spettekaka",
    "spetten": "spett",
    "spettens": "spett",
    "spettet": "spett",
    "spettets": "spett",
    "spettkak": "spettkaka",
    "spettkakan": "spettkaka",
    "spettkakans": "spettkaka",
    "spettkakas": "spettkaka",
    "spettkake": "spettkaka",
    "spettkakor": "spettkaka",
    "spettkakorna": "spettkaka",
    "spettkakornas": "spettkaka",
    "spettkakors": "spettkaka",
    "spettkaks": "spettkaka",
    "spetts": "spett",
    "spetälska": "spetälsk",
    "spetälskan": "spetälska",
    "spetälskans": "spetälska",
    "spetälskare": "spetälsk",
    "spetälskares": "spetälsk",
    "spetälskas": "spetälska",
    "spetälskast": "spetälsk",
    "spetälskaste": "spetälsk",
    "spetälskastes": "spetälsk",
    "spetälskasts": "spetälsk",
    "spetälske": "spetälsk",
    "spetälskes": "spetälsk",
    "spetälsks": "spetälsk",
    "spetälskt": "spetälsk",
    "spetälskts": "spetälsk",
    "spex": "spexa",
    "spexad": "spexa",
    "spexade": "spexa",
    "spexades": "spexa",
    "spexads": "spexa",
    "spexande": "spexa",
    "spexanden": "spexande",
    "spexandena": "spexande",
    "spexandenas": "spexande",
    "spexandens": "spexande",
    "spexandes": "spexande",
    "spexandet": "spexande",
    "spexandets": "spexande",
    "spexar": "spexa",
    "spexas": "spexa",
    "spexat": "spexa",
    "spexats": "spexa",
    "spexen": "spex",
    "spexens": "spex",
    "spexet": "spex",
    "spexets": "spex",
    "spexiga": "spexig",
    "spexigare": "spexig",
    "spexigares": "spexig",
    "spexigas": "spexig",
    "spexigast": "spexig",
    "spexigaste": "spexig",
    "spexigastes": "spexig",
    "spexigasts": "spexig",
    "spexige": "spexig",
    "spexiges": "spexig",
    "spexigs": "spexig",
    "spexigt": "spexig",
    "spexigts": "spexig",
    "spickens": "spicken",
    "spicket": "spicken",
    "spickets": "spicken",
    "spickna": "spicken",
    "spicknare": "spicken",
    "spicknares": "spicken",
    "spicknas": "spicken",
    "spicknast": "spicken",
    "spicknaste": "spicken",
    "spicknastes": "spicken",
    "spicknasts": "spicken",
    "spickne": "spicken",
    "spicknes": "spicken",
    "spiggar": "spigg",
    "spiggarna": "spigg",
    "spiggarnas": "spigg",
    "spiggars": "spigg",
    "spiggen": "spigg",
    "spiggens": "spigg",
    "spiggs": "spigg",
    "spikad": "spika",
    "spikade": "spikad",
    "spikades": "spikad",
    "spikads": "spikad",
    "spikande": "spika",
    "spikanden": "spikande",
    "spikandena": "spikande",
    "spikandenas": "spikande",
    "spikandens": "spikande",
    "spikandes": "spikande",
    "spikandet": "spikande",
    "spikandets": "spikande",
    "spikar": "spika",
    "spikarna": "spik",
    "spikarnas": "spik",
    "spikars": "spik",
    "spikas": "spika",
    "spikat": "spikad",
    "spikats": "spikad",
    "spikattentaten": "spikattentat",
    "spikattentatens": "spikattentat",
    "spikattentatet": "spikattentat",
    "spikattentatets": "spikattentat",
    "spikattentats": "spikattentat",
    "spikbanden": "spikband",
    "spikbandens": "spikband",
    "spikbandet": "spikband",
    "spikbandets": "spikband",
    "spikbands": "spikband",
    "spiken": "spik",
    "spikens": "spik",
    "spikhuvuden": "spikhuvud",
    "spikhuvudena": "spikhuvud",
    "spikhuvudenas": "spikhuvud",
    "spikhuvudens": "spikhuvud",
    "spikhuvudet": "spikhuvud",
    "spikhuvudets": "spikhuvud",
    "spikhuvuds": "spikhuvud",
    "spikklubb": "spikklubba",
    "spikklubban": "spikklubba",
    "spikklubbans": "spikklubba",
    "spikklubbas": "spikklubba",
    "spikklubbe": "spikklubba",
    "spikklubbor": "spikklubba",
    "spikklubborna": "spikklubba",
    "spikklubbornas": "spikklubba",
    "spikklubbors": "spikklubba",
    "spikklubbs": "spikklubba",
    "spikmatt": "spikmatta",
    "spikmattan": "spikmatta",
    "spikmattans": "spikmatta",
    "spikmattas": "spikmatta",
    "spikmatte": "spikmatta",
    "spikmattor": "spikmatta",
    "spikmattorna": "spikmatta",
    "spikmattornas": "spikmatta",
    "spikmattors": "spikmatta",
    "spikmatts": "spikmatta",
    "spikningar": "spikning",
    "spikningarna": "spikning",
    "spikningarnas": "spikning",
    "spikningars": "spikning",
    "spikningen": "spikning",
    "spikningens": "spikning",
    "spiknings": "spikning",
    "spikpianon": "spikpiano",
    "spikpianona": "spikpiano",
    "spikpianonas": "spikpiano",
    "spikpianons": "spikpiano",
    "spikpianos": "spikpiano",
    "spikpianot": "spikpiano",
    "spikpianots": "spikpiano",
    "spikpistolen": "spikpistol",
    "spikpistolens": "spikpistol",
    "spikpistoler": "spikpistol",
    "spikpistolerna": "spikpistol",
    "spikpistolernas": "spikpistol",
    "spikpistolers": "spikpistol",
    "spikpistols": "spikpistol",
    "spikraka": "spikrak",
    "spikrakare": "spikrak",
    "spikrakares": "spikrak",
    "spikrakas": "spikrak",
    "spikrakast": "spikrak",
    "spikrakaste": "spikrak",
    "spikrakastes": "spikrak",
    "spikrakasts": "spikrak",
    "spikrake": "spikrak",
    "spikrakes": "spikrak",
    "spikrakheten": "spikrakhet",
    "spikrakhetens": "spikrakhet",
    "spikrakhets": "spikrakhet",
    "spikraks": "spikrak",
    "spikrakt": "spikrak",
    "spikrakts": "spikrak",
    "spiks": "spik",
    "spikskall": "spikskalle",
    "spikskallar": "spikskalle",
    "spikskallarna": "spikskalle",
    "spikskallarnas": "spikskalle",
    "spikskallars": "spikskalle",
    "spikskallen": "spikskalle",
    "spikskallens": "spikskalle",
    "spikskalles": "spikskalle",
    "spikskalls": "spikskalle",
    "spikskon": "spiksko",
    "spikskons": "spiksko",
    "spikskor": "spiksko",
    "spikskorna": "spiksko",
    "spikskornas": "spiksko",
    "spikskors": "spiksko",
    "spikskos": "spiksko",
    "spikspetsar": "spikspets",
    "spikspetsarna": "spikspets",
    "spikspetsarnas": "spikspets",
    "spikspetsars": "spikspets",
    "spikspetsen": "spikspets",
    "spikspetsens": "spikspets",
    "spiksäkerheten": "spiksäkerhet",
    "spiksäkerhetens": "spiksäkerhet",
    "spiksäkerhets": "spiksäkerhet",
    "spiksäkers": "spiksäker",
    "spiksäkert": "spiksäker",
    "spiksäkerts": "spiksäker",
    "spiksäkra": "spiksäker",
    "spiksäkrare": "spiksäker",
    "spiksäkrares": "spiksäker",
    "spiksäkras": "spiksäker",
    "spiksäkrast": "spiksäker",
    "spiksäkraste": "spiksäker",
    "spiksäkrastes": "spiksäker",
    "spiksäkrasts": "spiksäker",
    "spiksäkre": "spiksäker",
    "spiksäkres": "spiksäker",
    "spil": "spila",
    "spilad": "spila",
    "spilade": "spila",
    "spilades": "spila",
    "spilads": "spila",
    "spilande": "spila",
    "spilanden": "spilande",
    "spilandena": "spilande",
    "spilandenas": "spilande",
    "spilandens": "spilande",
    "spilandes": "spilande",
    "spilandet": "spilande",
    "spilandets": "spilande",
    "spilar": "spila",
    "spilas": "spila",
    "spilat": "spila",
    "spilats": "spila",
    "spilkumar": "spilkum",
    "spilkumarna": "spilkum",
    "spilkumarnas": "spilkum",
    "spilkumars": "spilkum",
    "spilkumen": "spilkum",
    "spilkumens": "spilkum",
    "spilkums": "spilkum",
    "spill": "spilla",
    "spillande": "spilla",
    "spillanden": "spillande",
    "spillandena": "spillande",
    "spillandenas": "spillande",
    "spillandens": "spillande",
    "spillandes": "spillande",
    "spillandet": "spillande",
    "spillandets": "spillande",
    "spillas": "spilla",
    "spilld": "spilla",
    "spillda": "spilla",
    "spilldas": "spilla",
    "spillde": "spilla",
    "spilldes": "spilla",
    "spillds": "spilla",
    "spiller": "spillra",
    "spilles": "spilla",
    "spillet": "spill",
    "spillets": "spill",
    "spillkråk": "spillkråka",
    "spillkråkan": "spillkråka",
    "spillkråkans": "spillkråka",
    "spillkråkas": "spillkråka",
    "spillkråke": "spillkråka",
    "spillkråkor": "spillkråka",
    "spillkråkorna": "spillkråka",
    "spillkråkornas": "spillkråka",
    "spillkråkors": "spillkråka",
    "spillkråks": "spillkråka",
    "spillningar": "spillning",
    "spillningarna": "spillning",
    "spillningarnas": "spillning",
    "spillningars": "spillning",
    "spillningen": "spillning",
    "spillningens": "spillning",
    "spillnings": "spillning",
    "spilloljan": "spillolja",
    "spilloljans": "spillolja",
    "spilloljas": "spillolja",
    "spillolje": "spillolja",
    "spillran": "spillra",
    "spillrans": "spillra",
    "spillras": "spillra",
    "spillre": "spillra",
    "spillror": "spillra",
    "spillrorna": "spillra",
    "spillrornas": "spillra",
    "spillrors": "spillra",
    "spills": "spilla",
    "spillt": "spilla",
    "spilltiden": "spilltid",
    "spilltidens": "spilltid",
    "spilltids": "spilltid",
    "spillts": "spilla",
    "spillvattens": "spillvatten",
    "spillvattnen": "spillvatten",
    "spillvattnens": "spillvatten",
    "spillvattnet": "spillvatten",
    "spillvattnets": "spillvatten",
    "spillång": "spillånga",
    "spillångan": "spillånga",
    "spillångans": "spillånga",
    "spillångas": "spillånga",
    "spillånge": "spillånga",
    "spillångor": "spillånga",
    "spillångorna": "spillånga",
    "spillångornas": "spillånga",
    "spillångors": "spillånga",
    "spillångs": "spillånga",
    "spilt": "spilta",
    "spiltan": "spilta",
    "spiltans": "spilta",
    "spiltas": "spilta",
    "spilte": "spilta",
    "spiltor": "spilta",
    "spiltorna": "spilta",
    "spiltornas": "spilta",
    "spiltors": "spilta",
    "spilts": "spilta",
    "spilåpip": "spilåpipa",
    "spilåpipan": "spilåpipa",
    "spilåpipans": "spilåpipa",
    "spilåpipas": "spilåpipa",
    "spilåpipe": "spilåpipa",
    "spilåpipor": "spilåpipa",
    "spilåpiporna": "spilåpipa",
    "spilåpipornas": "spilåpipa",
    "spilåpipors": "spilåpipa",
    "spilåpips": "spilåpipa",
    "spin-offen": "spin-off",
    "spin-offens": "spin-off",
    "spin-offer": "spin-off",
    "spin-offerna": "spin-off",
    "spin-offernas": "spin-off",
    "spin-offers": "spin-off",
    "spin-offs": "spin-off",
    "spinala": "spinal",
    "spinalanestesien": "spinalanestesi",
    "spinalanestesiens": "spinalanestesi",
    "spinalanestesier": "spinalanestesi",
    "spinalanestesierna": "spinalanestesi",
    "spinalanestesiernas": "spinalanestesi",
    "spinalanestesiers": "spinalanestesi",
    "spinalanestesin": "spinalanestesi",
    "spinalanestesins": "spinalanestesi",
    "spinalanestesis": "spinalanestesi",
    "spinalare": "spinal",
    "spinalares": "spinal",
    "spinalas": "spinal",
    "spinalast": "spinal",
    "spinalaste": "spinal",
    "spinalastes": "spinal",
    "spinalasts": "spinal",
    "spinale": "spinal",
    "spinales": "spinal",
    "spinalganglien": "spinalganglie",
    "spinalgangliens": "spinalganglie",
    "spinalganglier": "spinalganglie",
    "spinalganglierna": "spinalganglie",
    "spinalgangliernas": "spinalganglie",
    "spinalgangliers": "spinalganglie",
    "spinalganglies": "spinalganglie",
    "spinals": "spinal",
    "spinalt": "spinal",
    "spinalts": "spinal",
    "spindelap": "spindelapa",
    "spindelapan": "spindelapa",
    "spindelapans": "spindelapa",
    "spindelapas": "spindelapa",
    "spindelape": "spindelapa",
    "spindelapor": "spindelapa",
    "spindelaporna": "spindelapa",
    "spindelapornas": "spindelapa",
    "spindelapors": "spindelapa",
    "spindelaps": "spindelapa",
    "spindelarten": "spindelart",
    "spindelartens": "spindelart",
    "spindelarter": "spindelart",
    "spindelarterna": "spindelart",
    "spindelarternas": "spindelart",
    "spindelarters": "spindelart",
    "spindelarts": "spindelart",
    "spindelbultar": "spindelbult",
    "spindelbultarna": "spindelbult",
    "spindelbultarnas": "spindelbult",
    "spindelbultars": "spindelbult",
    "spindelbulten": "spindelbult",
    "spindelbultens": "spindelbult",
    "spindelbults": "spindelbult",
    "spindeldjuren": "spindeldjur",
    "spindeldjurens": "spindeldjur",
    "spindeldjuret": "spindeldjur",
    "spindeldjurets": "spindeldjur",
    "spindeldjurs": "spindeldjur",
    "spindelhonan": "spindelhona",
    "spindelhonans": "spindelhona",
    "spindelhonas": "spindelhona",
    "spindelhone": "spindelhona",
    "spindelhonor": "spindelhona",
    "spindelhonorna": "spindelhona",
    "spindelhonornas": "spindelhona",
    "spindelhonors": "spindelhona",
    "spindeln": "spindel",
    "spindelns": "spindel",
    "spindelnäten": "spindelnät",
    "spindelnätens": "spindelnät",
    "spindelnätet": "spindelnät",
    "spindelnätets": "spindelnät",
    "spindelnäts": "spindelnät",
    "spindels": "spindel",
    "spindeltrådar": "spindeltråd",
    "spindeltrådarna": "spindeltråd",
    "spindeltrådarnas": "spindeltråd",
    "spindeltrådars": "spindeltråd",
    "spindeltråden": "spindeltråd",
    "spindeltrådens": "spindeltråd",
    "spindeltråds": "spindeltråd",
    "spindeltunna": "spindeltunn",
    "spindeltunnare": "spindeltunn",
    "spindeltunnares": "spindeltunn",
    "spindeltunnas": "spindeltunn",
    "spindeltunnast": "spindeltunn",
    "spindeltunnaste": "spindeltunn",
    "spindeltunnastes": "spindeltunn",
    "spindeltunnasts": "spindeltunn",
    "spindeltunne": "spindeltunn",
    "spindeltunnes": "spindeltunn",
    "spindeltunnheten": "spindeltunnhet",
    "spindeltunnhetens": "spindeltunnhet",
    "spindeltunnhets": "spindeltunnhet",
    "spindeltunns": "spindeltunn",
    "spindeltunt": "spindeltunn",
    "spindeltunts": "spindeltunn",
    "spindelvävar": "spindelväv",
    "spindelvävarna": "spindelväv",
    "spindelvävarnas": "spindelväv",
    "spindelvävars": "spindelväv",
    "spindelväven": "spindelväv",
    "spindelvävens": "spindelväv",
    "spindelvävs": "spindelväv",
    "spindelvävsmönstrade": "spindelvävsmönstrad",
    "spindelvävsmönstrades": "spindelvävsmönstrad",
    "spindelvävsmönstrads": "spindelvävsmönstrad",
    "spindelvävsmönstrat": "spindelvävsmönstrad",
    "spindelvävsmönstrats": "spindelvävsmönstrad",
    "spindelvävstunna": "spindelvävstunn",
    "spindelvävstunnare": "spindelvävstunn",
    "spindelvävstunnares": "spindelvävstunn",
    "spindelvävstunnas": "spindelvävstunn",
    "spindelvävstunnast": "spindelvävstunn",
    "spindelvävstunnaste": "spindelvävstunn",
    "spindelvävstunnastes": "spindelvävstunn",
    "spindelvävstunnasts": "spindelvävstunn",
    "spindelvävstunne": "spindelvävstunn",
    "spindelvävstunnes": "spindelvävstunn",
    "spindelvävstunnheten": "spindelvävstunnhet",
    "spindelvävstunnhetens": "spindelvävstunnhet",
    "spindelvävstunnhets": "spindelvävstunnhet",
    "spindelvävstunns": "spindelvävstunn",
    "spindelvävstunt": "spindelvävstunn",
    "spindelvävstunts": "spindelvävstunn",
    "spindlar": "spindel",
    "spindlarna": "spindel",
    "spindlarnas": "spindel",
    "spindlars": "spindel",
    "spinellen": "spinell",
    "spinellens": "spinell",
    "spineller": "spinell",
    "spinellerna": "spinell",
    "spinellernas": "spinell",
    "spinellers": "spinell",
    "spinells": "spinell",
    "spinen": "spin",
    "spinens": "spin",
    "spinet": "spin",
    "spinets": "spin",
    "spinetten": "spinett",
    "spinettens": "spinett",
    "spinetter": "spinett",
    "spinetterna": "spinett",
    "spinetternas": "spinett",
    "spinetters": "spinett",
    "spinetts": "spinett",
    "spinkiga": "spinkig",
    "spinkigare": "spinkig",
    "spinkigares": "spinkig",
    "spinkigas": "spinkig",
    "spinkigast": "spinkig",
    "spinkigaste": "spinkig",
    "spinkigastes": "spinkig",
    "spinkigasts": "spinkig",
    "spinkige": "spinkig",
    "spinkiges": "spinkig",
    "spinkigheten": "spinkighet",
    "spinkighetens": "spinkighet",
    "spinkighets": "spinkighet",
    "spinkigs": "spinkig",
    "spinkigt": "spinkig",
    "spinkigts": "spinkig",
    "spinn": "spinna",
    "spinnakerbommar": "spinnakerbom",
    "spinnakerbommarna": "spinnakerbom",
    "spinnakerbommarnas": "spinnakerbom",
    "spinnakerbommars": "spinnakerbom",
    "spinnakerbommen": "spinnakerbom",
    "spinnakerbommens": "spinnakerbom",
    "spinnakerboms": "spinnakerbom",
    "spinnakern": "spinnaker",
    "spinnakerns": "spinnaker",
    "spinnakers": "spinnaker",
    "spinnakrar": "spinnaker",
    "spinnakrarna": "spinnaker",
    "spinnakrarnas": "spinnaker",
    "spinnakrars": "spinnaker",
    "spinnande": "spinna",
    "spinnanden": "spinnande",
    "spinnandena": "spinnande",
    "spinnandenas": "spinnande",
    "spinnandens": "spinnande",
    "spinnandes": "spinnande",
    "spinnandet": "spinnande",
    "spinnandets": "spinnande",
    "spinnar": "spinnare",
    "spinnaren": "spinnare",
    "spinnarens": "spinnare",
    "spinnares": "spinnare",
    "spinnarfjärilar": "spinnarfjäril",
    "spinnarfjärilarna": "spinnarfjäril",
    "spinnarfjärilarnas": "spinnarfjäril",
    "spinnarfjärilars": "spinnarfjäril",
    "spinnarfjärilen": "spinnarfjäril",
    "spinnarfjärilens": "spinnarfjäril",
    "spinnarfjäriln": "spinnarfjäril",
    "spinnarfjärilns": "spinnarfjäril",
    "spinnarfjärils": "spinnarfjäril",
    "spinnarna": "spinnare",
    "spinnarnas": "spinnare",
    "spinnas": "spinna",
    "spinne": "spinna",
    "spinnen": "spinn",
    "spinnens": "spinn",
    "spinner": "spinna",
    "spinnerier": "spinneri",
    "spinnerierna": "spinneri",
    "spinneriernas": "spinneri",
    "spinneriers": "spinneri",
    "spinneriet": "spinneri",
    "spinneriets": "spinneri",
    "spinneris": "spinneri",
    "spinnerit": "spinneri",
    "spinnerits": "spinneri",
    "spinnes": "spinna",
    "spinnet": "spinn",
    "spinnets": "spinn",
    "spinnfiskes": "spinnfiske",
    "spinnfisket": "spinnfiske",
    "spinnfiskets": "spinnfiske",
    "spinnhusen": "spinnhus",
    "spinnhusens": "spinnhus",
    "spinnhuset": "spinnhus",
    "spinnhusets": "spinnhus",
    "spinnkvalsterna": "spinnkvalster",
    "spinnkvalsternas": "spinnkvalster",
    "spinnkvalsters": "spinnkvalster",
    "spinnkvalstren": "spinnkvalster",
    "spinnkvalstrens": "spinnkvalster",
    "spinnkvalstret": "spinnkvalster",
    "spinnkvalstrets": "spinnkvalster",
    "spinnrockar": "spinnrock",
    "spinnrockarna": "spinnrock",
    "spinnrockarnas": "spinnrock",
    "spinnrockars": "spinnrock",
    "spinnrocken": "spinnrock",
    "spinnrockens": "spinnrock",
    "spinnrocks": "spinnrock",
    "spinnrull": "spinnrulle",
    "spinnrullar": "spinnrulle",
    "spinnrullarna": "spinnrulle",
    "spinnrullarnas": "spinnrulle",
    "spinnrullars": "spinnrulle",
    "spinnrullen": "spinnrulle",
    "spinnrullens": "spinnrulle",
    "spinnrulles": "spinnrulle",
    "spinnrulls": "spinnrulle",
    "spinns": "spinna",
    "spinnsidans": "spinnsidan",
    "spinnspöet": "spinnspö",
    "spinnspöets": "spinnspö",
    "spinnspön": "spinnspö",
    "spinnspöna": "spinnspö",
    "spinnspönas": "spinnspö",
    "spinnspöns": "spinnspö",
    "spinnspös": "spinnspö",
    "spinnspöt": "spinnspö",
    "spinnspöts": "spinnspö",
    "spins": "spin",
    "spionages": "spionage",
    "spionaget": "spionage",
    "spionagets": "spionage",
    "spionen": "spion",
    "spionens": "spion",
    "spioner": "spion",
    "spionerade": "spionera",
    "spionerades": "spionera",
    "spionerande": "spionera",
    "spioneranden": "spionerande",
    "spionerandena": "spionerande",
    "spionerandenas": "spionerande",
    "spionerandens": "spionerande",
    "spionerandes": "spionerande",
    "spionerandet": "spionerande",
    "spionerandets": "spionerande",
    "spionerar": "spionera",
    "spioneras": "spionera",
    "spionerat": "spionera",
    "spionerats": "spionera",
    "spionerier": "spioneri",
    "spionerierna": "spioneri",
    "spioneriernas": "spioneri",
    "spioneriers": "spioneri",
    "spioneriet": "spioneri",
    "spioneriets": "spioneri",
    "spioneringar": "spionering",
    "spioneringarna": "spionering",
    "spioneringarnas": "spionering",
    "spioneringars": "spionering",
    "spioneringen": "spionering",
    "spioneringens": "spionering",
    "spionerings": "spionering",
    "spioneris": "spioneri",
    "spionerit": "spioneri",
    "spionerits": "spioneri",
    "spionerna": "spion",
    "spionernas": "spion",
    "spioners": "spion",
    "spionfallen": "spionfall",
    "spionfallens": "spionfall",
    "spionfallet": "spionfall",
    "spionfallets": "spionfall",
    "spionfalls": "spionfall",
    "spionflygningar": "spionflygning",
    "spionflygningarna": "spionflygning",
    "spionflygningarnas": "spionflygning",
    "spionflygningars": "spionflygning",
    "spionflygningen": "spionflygning",
    "spionflygningens": "spionflygning",
    "spionflygnings": "spionflygning",
    "spionkameran": "spionkamera",
    "spionkamerans": "spionkamera",
    "spionkameras": "spionkamera",
    "spionkameror": "spionkamera",
    "spionkamerorna": "spionkamera",
    "spionkamerornas": "spionkamera",
    "spionkamerors": "spionkamera",
    "spions": "spion",
    "spionskräcken": "spionskräck",
    "spionskräckens": "spionskräck",
    "spionskräcks": "spionskräck",
    "spir": "spira",
    "spirad": "spira",
    "spirade": "spira",
    "spirades": "spira",
    "spirads": "spira",
    "spiralblocken": "spiralblock",
    "spiralblockens": "spiralblock",
    "spiralblocket": "spiralblock",
    "spiralblockets": "spiralblock",
    "spiralblocks": "spiralblock",
    "spiralbottens": "spiralbotten",
    "spiralbottnar": "spiralbotten",
    "spiralbottnarna": "spiralbotten",
    "spiralbottnarnas": "spiralbotten",
    "spiralbottnars": "spiralbotten",
    "spiralbottnen": "spiralbotten",
    "spiralbottnens": "spiralbotten",
    "spiralen": "spiral",
    "spiralens": "spiral",
    "spiraler": "spiral",
    "spiralerna": "spiral",
    "spiralernas": "spiral",
    "spiralers": "spiral",
    "spiralfjädern": "spiralfjäder",
    "spiralfjäderns": "spiralfjäder",
    "spiralfjäders": "spiralfjäder",
    "spiralfjädrar": "spiralfjäder",
    "spiralfjädrarna": "spiralfjäder",
    "spiralfjädrarnas": "spiralfjäder",
    "spiralfjädrars": "spiralfjäder",
    "spiralformade": "spiralformad",
    "spiralformades": "spiralformad",
    "spiralformads": "spiralformad",
    "spiralformat": "spiralformad",
    "spiralformats": "spiralformad",
    "spiralgalaxen": "spiralgalax",
    "spiralgalaxens": "spiralgalax",
    "spiralgalaxer": "spiralgalax",
    "spiralgalaxerna": "spiralgalax",
    "spiralgalaxernas": "spiralgalax",
    "spiralgalaxers": "spiralgalax",
    "spiralgalaxformade": "spiralgalaxformad",
    "spiralgalaxformades": "spiralgalaxformad",
    "spiralgalaxformads": "spiralgalaxformad",
    "spiralgalaxformat": "spiralgalaxformad",
    "spiralgalaxformats": "spiralgalaxformad",
    "spiralkabeln": "spiralkabel",
    "spiralkabelns": "spiralkabel",
    "spiralkabels": "spiralkabel",
    "spiralkablar": "spiralkabel",
    "spiralkablarna": "spiralkabel",
    "spiralkablarnas": "spiralkabel",
    "spiralkablars": "spiralkabel",
    "spiralnebulos": "spiralnebulosa",
    "spiralnebulosan": "spiralnebulosa",
    "spiralnebulosans": "spiralnebulosa",
    "spiralnebulosas": "spiralnebulosa",
    "spiralnebulose": "spiralnebulosa",
    "spiralnebulosor": "spiralnebulosa",
    "spiralnebulosorna": "spiralnebulosa",
    "spiralnebulosornas": "spiralnebulosa",
    "spiralnebulosors": "spiralnebulosa",
    "spiralrörelsen": "spiralrörelse",
    "spiralrörelsens": "spiralrörelse",
    "spiralrörelser": "spiralrörelse",
    "spiralrörelserna": "spiralrörelse",
    "spiralrörelsernas": "spiralrörelse",
    "spiralrörelsers": "spiralrörelse",
    "spiralrörelses": "spiralrörelse",
    "spirals": "spiral",
    "spiraltrapp": "spiraltrappa",
    "spiraltrappan": "spiraltrappa",
    "spiraltrappans": "spiraltrappa",
    "spiraltrappas": "spiraltrappa",
    "spiraltrappe": "spiraltrappa",
    "spiraltrappor": "spiraltrappa",
    "spiraltrapporna": "spiraltrappa",
    "spiraltrappornas": "spiraltrappa",
    "spiraltrappors": "spiraltrappa",
    "spiraltrapps": "spiraltrappa",
    "spiran": "spira",
    "spirande": "spira",
    "spiranden": "spirande",
    "spirandena": "spirande",
    "spirandenas": "spirande",
    "spirandens": "spirande",
    "spirandes": "spirande",
    "spirandet": "spirande",
    "spirandets": "spirande",
    "spirans": "spira",
    "spiranten": "spirant",
    "spirantens": "spirant",
    "spiranter": "spirant",
    "spiranterna": "spirant",
    "spiranternas": "spirant",
    "spiranters": "spirant",
    "spirants": "spirant",
    "spirar": "spira",
    "spiras": "spira",
    "spirat": "spira",
    "spirats": "spira",
    "spire": "spirea",
    "spirean": "spirea",
    "spireans": "spirea",
    "spireas": "spirea",
    "spiree": "spirea",
    "spireor": "spirea",
    "spireorna": "spirea",
    "spireornas": "spirea",
    "spireors": "spirea",
    "spires": "spirea",
    "spirillen": "spirill",
    "spirillens": "spirill",
    "spiriller": "spirill",
    "spirillerna": "spirill",
    "spirillernas": "spirill",
    "spirillers": "spirill",
    "spirills": "spirill",
    "spiritismen": "spiritism",
    "spiritismens": "spiritism",
    "spiritismer": "spiritism",
    "spiritismerna": "spiritism",
    "spiritismernas": "spiritism",
    "spiritismers": "spiritism",
    "spiritisms": "spiritism",
    "spiritisten": "spiritist",
    "spiritistens": "spiritist",
    "spiritister": "spiritist",
    "spiritisterna": "spiritist",
    "spiritisternas": "spiritist",
    "spiritisters": "spiritist",
    "spiritistiska": "spiritistisk",
    "spiritistiskas": "spiritistisk",
    "spiritistiske": "spiritistisk",
    "spiritistiskes": "spiritistisk",
    "spiritistisks": "spiritistisk",
    "spiritistiskt": "spiritistisk",
    "spiritistiskts": "spiritistisk",
    "spiritists": "spiritist",
    "spiritualismen": "spiritualism",
    "spiritualismens": "spiritualism",
    "spiritualismer": "spiritualism",
    "spiritualismerna": "spiritualism",
    "spiritualismernas": "spiritualism",
    "spiritualismers": "spiritualism",
    "spiritualisms": "spiritualism",
    "spiritualisten": "spiritualist",
    "spiritualistens": "spiritualist",
    "spiritualister": "spiritualist",
    "spiritualisterna": "spiritualist",
    "spiritualisternas": "spiritualist",
    "spiritualisters": "spiritualist",
    "spiritualistiska": "spiritualistisk",
    "spiritualistiskas": "spiritualistisk",
    "spiritualistiske": "spiritualistisk",
    "spiritualistiskes": "spiritualistisk",
    "spiritualistisks": "spiritualistisk",
    "spiritualistiskt": "spiritualistisk",
    "spiritualistiskts": "spiritualistisk",
    "spiritualists": "spiritualist",
    "spiritualiteten": "spiritualitet",
    "spiritualitetens": "spiritualitet",
    "spiritualiteter": "spiritualitet",
    "spiritualiteterna": "spiritualitet",
    "spiritualiteternas": "spiritualitet",
    "spiritualiteters": "spiritualitet",
    "spiritualitets": "spiritualitet",
    "spirituella": "spirituell",
    "spirituellare": "spirituell",
    "spirituellares": "spirituell",
    "spirituellas": "spirituell",
    "spirituellast": "spirituell",
    "spirituellaste": "spirituell",
    "spirituellastes": "spirituell",
    "spirituellasts": "spirituell",
    "spirituelle": "spirituell",
    "spirituelles": "spirituell",
    "spirituells": "spirituell",
    "spirituellt": "spirituell",
    "spirituellts": "spirituell",
    "spirituosan": "spirituosa",
    "spirituosans": "spirituosa",
    "spirituosas": "spirituosa",
    "spiritusen": "spiritus",
    "spiritusens": "spiritus",
    "spirituösa": "spirituös",
    "spirituösare": "spirituös",
    "spirituösares": "spirituös",
    "spirituösas": "spirituös",
    "spirituösast": "spirituös",
    "spirituösaste": "spirituös",
    "spirituösastes": "spirituös",
    "spirituösasts": "spirituös",
    "spirituöse": "spirituös",
    "spirituöses": "spirituös",
    "spirituöst": "spirituös",
    "spirituösts": "spirituös",
    "spirlång": "spirlånga",
    "spirlångan": "spirlånga",
    "spirlångans": "spirlånga",
    "spirlångas": "spirlånga",
    "spirlånge": "spirlånga",
    "spirlångor": "spirlånga",
    "spirlångorna": "spirlånga",
    "spirlångornas": "spirlånga",
    "spirlångors": "spirlånga",
    "spirlångs": "spirlånga",
    "spiroketen": "spiroket",
    "spiroketens": "spiroket",
    "spiroketer": "spiroket",
    "spiroketerna": "spiroket",
    "spiroketernas": "spiroket",
    "spiroketers": "spiroket",
    "spirokets": "spiroket",
    "spirometrien": "spirometri",
    "spirometriens": "spirometri",
    "spirometrin": "spirometri",
    "spirometrins": "spirometri",
    "spirometris": "spirometri",
    "spiror": "spira",
    "spirorna": "spira",
    "spirornas": "spira",
    "spirors": "spira",
    "spirs": "spira",
    "spis": "spisa",
    "spisad": "spisa",
    "spisade": "spisa",
    "spisades": "spisa",
    "spisads": "spisa",
    "spisande": "spisa",
    "spisanden": "spisande",
    "spisandena": "spisande",
    "spisandenas": "spisande",
    "spisandens": "spisande",
    "spisandes": "spisande",
    "spisandet": "spisande",
    "spisandets": "spisande",
    "spisar": "spisare",
    "spisaren": "spisare",
    "spisarens": "spisare",
    "spisares": "spisare",
    "spisarna": "spisare",
    "spisarnas": "spisare",
    "spisars": "spis",
    "spisas": "spisa",
    "spisat": "spisa",
    "spisats": "spisa",
    "spisbrödet": "spisbröd",
    "spisbrödets": "spisbröd",
    "spisbröds": "spisbröd",
    "spiselhyll": "spiselhylla",
    "spiselhyllan": "spiselhylla",
    "spiselhyllans": "spiselhylla",
    "spiselhyllas": "spiselhylla",
    "spiselhylle": "spiselhylla",
    "spiselhyllor": "spiselhylla",
    "spiselhyllorna": "spiselhylla",
    "spiselhyllornas": "spiselhylla",
    "spiselhyllors": "spiselhylla",
    "spiselhylls": "spiselhylla",
    "spiselhällar": "spiselhäll",
    "spiselhällarna": "spiselhäll",
    "spiselhällarnas": "spiselhäll",
    "spiselhällars": "spiselhäll",
    "spiselhällen": "spiselhäll",
    "spiselhällens": "spiselhäll",
    "spiselhälls": "spiselhäll",
    "spiselkransar": "spiselkrans",
    "spiselkransarna": "spiselkrans",
    "spiselkransarnas": "spiselkrans",
    "spiselkransars": "spiselkrans",
    "spiselkransen": "spiselkrans",
    "spiselkransens": "spiselkrans",
    "spiselkrokar": "spiselkrok",
    "spiselkrokarna": "spiselkrok",
    "spiselkrokarnas": "spiselkrok",
    "spiselkrokars": "spiselkrok",
    "spiselkroken": "spiselkrok",
    "spiselkrokens": "spiselkrok",
    "spiselkroks": "spiselkrok",
    "spiselmurar": "spiselmur",
    "spiselmurarna": "spiselmur",
    "spiselmurarnas": "spiselmur",
    "spiselmurars": "spiselmur",
    "spiselmuren": "spiselmur",
    "spiselmurens": "spiselmur",
    "spiselmurs": "spiselmur",
    "spiseln": "spisel",
    "spiselns": "spisel",
    "spisels": "spisel",
    "spiselvrån": "spiselvrå",
    "spiselvråns": "spiselvrå",
    "spiselvrår": "spiselvrå",
    "spiselvrårna": "spiselvrå",
    "spiselvrårnas": "spiselvrå",
    "spiselvrårs": "spiselvrå",
    "spiselvrås": "spiselvrå",
    "spiselvärmen": "spiselvärme",
    "spiselvärmens": "spiselvärme",
    "spiselvärmes": "spiselvärme",
    "spisen": "spis",
    "spisens": "spis",
    "spishyll": "spishylla",
    "spishyllan": "spishylla",
    "spishyllans": "spishylla",
    "spishyllas": "spishylla",
    "spishylle": "spishylla",
    "spishyllor": "spishylla",
    "spishyllorna": "spishylla",
    "spishyllornas": "spishylla",
    "spishyllors": "spishylla",
    "spishylls": "spishylla",
    "spishällar": "spishäll",
    "spishällarna": "spishäll",
    "spishällarnas": "spishäll",
    "spishällars": "spishäll",
    "spishällen": "spishäll",
    "spishällens": "spishäll",
    "spishälls": "spishäll",
    "spiskammar": "spiskammare",
    "spiskammaren": "spiskammare",
    "spiskammarens": "spiskammare",
    "spiskammares": "spiskammare",
    "spiskamrar": "spiskammare",
    "spiskamrarna": "spiskammare",
    "spiskamrarnas": "spiskammare",
    "spiskamrars": "spiskammare",
    "spiskransar": "spiskrans",
    "spiskransarna": "spiskrans",
    "spiskransarnas": "spiskrans",
    "spiskransars": "spiskrans",
    "spiskransen": "spiskrans",
    "spiskransens": "spiskrans",
    "spiskrokar": "spiskrok",
    "spiskrokarna": "spiskrok",
    "spiskrokarnas": "spiskrok",
    "spiskrokars": "spiskrok",
    "spiskroken": "spiskrok",
    "spiskrokens": "spiskrok",
    "spiskroks": "spiskrok",
    "spiskup": "spiskupa",
    "spiskupan": "spiskupa",
    "spiskupans": "spiskupa",
    "spiskupas": "spiskupa",
    "spiskupe": "spiskupa",
    "spiskupor": "spiskupa",
    "spiskuporna": "spiskupa",
    "spiskupornas": "spiskupa",
    "spiskupors": "spiskupa",
    "spiskups": "spiskupa",
    "spiskåp": "spiskåpa",
    "spiskåpan": "spiskåpa",
    "spiskåpans": "spiskåpa",
    "spiskåpas": "spiskåpa",
    "spiskåpe": "spiskåpa",
    "spiskåpor": "spiskåpa",
    "spiskåporna": "spiskåpa",
    "spiskåpornas": "spiskåpa",
    "spiskåpors": "spiskåpa",
    "spiskåps": "spiskåpa",
    "spislar": "spisel",
    "spislarna": "spisel",
    "spislarnas": "spisel",
    "spislars": "spisel",
    "spisplatt": "spisplatta",
    "spisplattan": "spisplatta",
    "spisplattans": "spisplatta",
    "spisplattas": "spisplatta",
    "spisplatte": "spisplatta",
    "spisplattor": "spisplatta",
    "spisplattorna": "spisplatta",
    "spisplattornas": "spisplatta",
    "spisplattors": "spisplatta",
    "spisplatts": "spisplatta",
    "spjuten": "spjut",
    "spjutens": "spjut",
    "spjutet": "spjut",
    "spjutets": "spjut",
    "spjutkastningar": "spjutkastning",
    "spjutkastningarna": "spjutkastning",
    "spjutkastningarnas": "spjutkastning",
    "spjutkastningars": "spjutkastning",
    "spjutkastningen": "spjutkastning",
    "spjutkastningens": "spjutkastning",
    "spjutkastnings": "spjutkastning",
    "spjuts": "spjut",
    "spjutspetsar": "spjutspets",
    "spjutspetsarna": "spjutspets",
    "spjutspetsarnas": "spjutspets",
    "spjutspetsars": "spjutspets",
    "spjutspetsen": "spjutspets",
    "spjutspetsens": "spjutspets",
    "spjuvern": "spjuver",
    "spjuverns": "spjuver",
    "spjuvers": "spjuver",
    "spjuvrar": "spjuver",
    "spjuvrarna": "spjuver",
    "spjuvrarnas": "spjuver",
    "spjuvrars": "spjuver",
    "spjäl": "spjäle",
    "spjälad": "spjäla",
    "spjälade": "spjäla",
    "spjälades": "spjäla",
    "spjälads": "spjäla",
    "spjälan": "spjäla",
    "spjälande": "spjäla",
    "spjälanden": "spjälande",
    "spjälandena": "spjälande",
    "spjälandenas": "spjälande",
    "spjälandens": "spjälande",
    "spjälandes": "spjälande",
    "spjälandet": "spjälande",
    "spjälandets": "spjälande",
    "spjälans": "spjäla",
    "spjälar": "spjäle",
    "spjälarna": "spjäle",
    "spjälarnas": "spjäle",
    "spjälars": "spjäle",
    "spjälas": "spjäla",
    "spjälat": "spjäla",
    "spjälats": "spjäla",
    "spjäle": "spjäla",
    "spjälen": "spjäle",
    "spjälens": "spjäle",
    "spjäles": "spjäle",
    "spjälk": "spjälka",
    "spjälkad": "spjälka",
    "spjälkade": "spjälka",
    "spjälkades": "spjälka",
    "spjälkads": "spjälka",
    "spjälkande": "spjälka",
    "spjälkanden": "spjälkande",
    "spjälkandena": "spjälkande",
    "spjälkandenas": "spjälkande",
    "spjälkandens": "spjälkande",
    "spjälkandes": "spjälkande",
    "spjälkandet": "spjälkande",
    "spjälkandets": "spjälkande",
    "spjälkar": "spjälka",
    "spjälkas": "spjälka",
    "spjälkat": "spjälka",
    "spjälkats": "spjälka",
    "spjällbanden": "spjällband",
    "spjällbandens": "spjällband",
    "spjällbandet": "spjällband",
    "spjällbandets": "spjällband",
    "spjällbands": "spjällband",
    "spjällen": "spjäll",
    "spjällens": "spjäll",
    "spjället": "spjäll",
    "spjällets": "spjäll",
    "spjälls": "spjäll",
    "spjällsnör": "spjällsnöre",
    "spjällsnören": "spjällsnöre",
    "spjällsnörena": "spjällsnöre",
    "spjällsnörenas": "spjällsnöre",
    "spjällsnörens": "spjällsnöre",
    "spjällsnöres": "spjällsnöre",
    "spjällsnöret": "spjällsnöre",
    "spjällsnörets": "spjällsnöre",
    "spjällsnörs": "spjällsnöre",
    "spjällåd": "spjällåda",
    "spjällådan": "spjällåda",
    "spjällådans": "spjällåda",
    "spjällådas": "spjällåda",
    "spjällåde": "spjällåda",
    "spjällådor": "spjällåda",
    "spjällådorna": "spjällåda",
    "spjällådornas": "spjällåda",
    "spjällådors": "spjällåda",
    "spjällåds": "spjällåda",
    "spjälor": "spjäla",
    "spjälorna": "spjäla",
    "spjälornas": "spjäla",
    "spjälors": "spjäla",
    "spjäls": "spjäle",
    "spjälsängar": "spjälsäng",
    "spjälsängarna": "spjälsäng",
    "spjälsängarnas": "spjälsäng",
    "spjälsängars": "spjälsäng",
    "spjälsängen": "spjälsäng",
    "spjälsängens": "spjälsäng",
    "spjälsängs": "spjälsäng",
    "spjärn": "spjärna",
    "spjärnad": "spjärna",
    "spjärnade": "spjärna",
    "spjärnades": "spjärna",
    "spjärnads": "spjärna",
    "spjärnande": "spjärna",
    "spjärnanden": "spjärnande",
    "spjärnandena": "spjärnande",
    "spjärnandenas": "spjärnande",
    "spjärnandens": "spjärnande",
    "spjärnandes": "spjärnande",
    "spjärnandet": "spjärnande",
    "spjärnandets": "spjärnande",
    "spjärnar": "spjärna",
    "spjärnas": "spjärna",
    "spjärnat": "spjärna",
    "spjärnats": "spjärna",
    "splatterfilmen": "splatterfilm",
    "splatterfilmens": "splatterfilm",
    "splatterfilmer": "splatterfilm",
    "splatterfilmerna": "splatterfilm",
    "splatterfilmernas": "splatterfilm",
    "splatterfilmers": "splatterfilm",
    "splatterfilms": "splatterfilm",
    "spleenen": "spleen",
    "spleenens": "spleen",
    "spleens": "spleen",
    "splejkar": "splejk",
    "splejkarna": "splejk",
    "splejkarnas": "splejk",
    "splejkars": "splejk",
    "splejken": "splejk",
    "splejkens": "splejk",
    "splejks": "splejk",
    "splint": "splinta",
    "splintad": "splinta",
    "splintade": "splinta",
    "splintades": "splinta",
    "splintads": "splinta",
    "splintande": "splinta",
    "splintanden": "splintande",
    "splintandena": "splintande",
    "splintandenas": "splintande",
    "splintandens": "splintande",
    "splintandes": "splintande",
    "splintandet": "splintande",
    "splintandets": "splintande",
    "splintar": "splinta",
    "splintas": "splinta",
    "splintat": "splinta",
    "splintats": "splinta",
    "splinten": "splint",
    "splintens": "splint",
    "splints": "splint",
    "spliss": "splissa",
    "splissad": "splissa",
    "splissade": "splissa",
    "splissades": "splissa",
    "splissads": "splissa",
    "splissande": "splissa",
    "splissanden": "splissande",
    "splissandena": "splissande",
    "splissandenas": "splissande",
    "splissandens": "splissande",
    "splissandes": "splissande",
    "splissandet": "splissande",
    "splissandets": "splissande",
    "splissar": "splissa",
    "splissarna": "spliss",
    "splissarnas": "spliss",
    "splissars": "spliss",
    "splissas": "splissa",
    "splissat": "splissa",
    "splissats": "splissa",
    "splissen": "spliss",
    "splissens": "spliss",
    "splitcanes": "splitcane",
    "splitet": "split",
    "splitets": "split",
    "splits": "splitsa",
    "splitsad": "splitsa",
    "splitsade": "splitsa",
    "splitsades": "splitsa",
    "splitsads": "splitsa",
    "splitsande": "splitsa",
    "splitsanden": "splitsande",
    "splitsandena": "splitsande",
    "splitsandenas": "splitsande",
    "splitsandens": "splitsande",
    "splitsandes": "splitsande",
    "splitsandet": "splitsande",
    "splitsandets": "splitsande",
    "splitsar": "splitsa",
    "splitsarna": "splits",
    "splitsarnas": "splits",
    "splitsars": "splits",
    "splitsas": "splitsa",
    "splitsat": "splitsa",
    "splitsats": "splitsa",
    "splitsen": "splits",
    "splitsens": "splits",
    "splitter": "splittra",
    "splitterbomben": "splitterbomb",
    "splitterbombens": "splitterbomb",
    "splitterbomber": "splitterbomb",
    "splitterbomberna": "splitterbomb",
    "splitterbombernas": "splitterbomb",
    "splitterbombers": "splitterbomb",
    "splitterbombs": "splitterbomb",
    "splitternya": "splitterny",
    "splitternyare": "splitterny",
    "splitternyares": "splitterny",
    "splitternyas": "splitterny",
    "splitternyast": "splitterny",
    "splitternyaste": "splitterny",
    "splitternyastes": "splitterny",
    "splitternyasts": "splitterny",
    "splitternye": "splitterny",
    "splitternyes": "splitterny",
    "splitternys": "splitterny",
    "splitternytt": "splitterny",
    "splitternytts": "splitterny",
    "splitters": "splitter",
    "splittersåren": "splittersår",
    "splittersårens": "splittersår",
    "splittersåret": "splittersår",
    "splittersårets": "splittersår",
    "splittersårs": "splittersår",
    "splittr": "splittra",
    "splittrad": "splittra",
    "splittrade": "splittrad",
    "splittrades": "splittrad",
    "splittrads": "splittrad",
    "splittran": "splittra",
    "splittrande": "splittra",
    "splittranden": "splittrande",
    "splittrandena": "splittrande",
    "splittrandenas": "splittrande",
    "splittrandens": "splittrande",
    "splittrandes": "splittrande",
    "splittrandet": "splittrande",
    "splittrandets": "splittrande",
    "splittrans": "splittra",
    "splittrar": "splittrare",
    "splittraren": "splittrare",
    "splittrarens": "splittrare",
    "splittrares": "splittrare",
    "splittrarna": "splittrare",
    "splittrarnas": "splittrare",
    "splittras": "splittra",
    "splittrat": "splittrad",
    "splittrats": "splittrad",
    "splittre": "splittra",
    "splittren": "splitter",
    "splittrens": "splitter",
    "splittret": "splitter",
    "splittrets": "splitter",
    "splittringar": "splittring",
    "splittringarna": "splittring",
    "splittringarnas": "splittring",
    "splittringars": "splittring",
    "splittringen": "splittring",
    "splittringens": "splittring",
    "splittrings": "splittring",
    "splittror": "splittra",
    "splittrorna": "splittra",
    "splittrornas": "splittra",
    "splittrors": "splittra",
    "splittrs": "splittra",
    "spoilern": "spoiler",
    "spoilerna": "spoiler",
    "spoilernas": "spoiler",
    "spoilerns": "spoiler",
    "spoilers": "spoiler",
    "spoilersarna": "spoiler",
    "spoilersarnas": "spoiler",
    "spoilersen": "spoiler",
    "spoilersens": "spoiler",
    "spol": "spole",
    "spolad": "spola",
    "spolade": "spola",
    "spolades": "spola",
    "spolads": "spola",
    "spolande": "spola",
    "spolanden": "spolande",
    "spolandena": "spolande",
    "spolandenas": "spolande",
    "spolandens": "spolande",
    "spolandes": "spolande",
    "spolandet": "spolande",
    "spolandets": "spolande",
    "spolar": "spole",
    "spolarna": "spole",
    "spolarnas": "spole",
    "spolars": "spole",
    "spolarvätskan": "spolarvätska",
    "spolarvätskans": "spolarvätska",
    "spolarvätskas": "spolarvätska",
    "spolarvätske": "spolarvätska",
    "spolarvätskor": "spolarvätska",
    "spolarvätskorna": "spolarvätska",
    "spolarvätskornas": "spolarvätska",
    "spolarvätskors": "spolarvätska",
    "spolas": "spola",
    "spolat": "spola",
    "spolats": "spola",
    "spolen": "spole",
    "spolens": "spole",
    "spoles": "spole",
    "spolformade": "spolformad",
    "spolformades": "spolformad",
    "spolformads": "spolformad",
    "spolformat": "spolformad",
    "spolformats": "spolformad",
    "spolformiga": "spolformig",
    "spolformigare": "spolformig",
    "spolformigares": "spolformig",
    "spolformigas": "spolformig",
    "spolformigast": "spolformig",
    "spolformigaste": "spolformig",
    "spolformigastes": "spolformig",
    "spolformigasts": "spolformig",
    "spolformige": "spolformig",
    "spolformiges": "spolformig",
    "spolformigheten": "spolformighet",
    "spolformighetens": "spolformighet",
    "spolformighets": "spolformighet",
    "spolformigs": "spolformig",
    "spolformigt": "spolformig",
    "spolformigts": "spolformig",
    "spolierad": "spoliera",
    "spolierade": "spoliera",
    "spolierades": "spoliera",
    "spolierads": "spoliera",
    "spolierande": "spoliera",
    "spolieranden": "spolierande",
    "spolierandena": "spolierande",
    "spolierandenas": "spolierande",
    "spolierandens": "spolierande",
    "spolierandes": "spolierande",
    "spolierandet": "spolierande",
    "spolierandets": "spolierande",
    "spolierar": "spoliera",
    "spolieras": "spoliera",
    "spolierat": "spoliera",
    "spolierats": "spoliera",
    "spolierbara": "spolierbar",
    "spolierbarare": "spolierbar",
    "spolierbarares": "spolierbar",
    "spolierbaras": "spolierbar",
    "spolierbarast": "spolierbar",
    "spolierbaraste": "spolierbar",
    "spolierbarastes": "spolierbar",
    "spolierbarasts": "spolierbar",
    "spolierbare": "spolierbar",
    "spolierbares": "spolierbar",
    "spolierbarheten": "spolierbarhet",
    "spolierbarhetens": "spolierbarhet",
    "spolierbarhets": "spolierbarhet",
    "spolierbars": "spolierbar",
    "spolierbart": "spolierbar",
    "spolierbarts": "spolierbar",
    "spolieringar": "spoliering",
    "spolieringarna": "spoliering",
    "spolieringarnas": "spoliering",
    "spolieringars": "spoliering",
    "spolieringen": "spoliering",
    "spolieringens": "spoliering",
    "spolierings": "spoliering",
    "spolingar": "spoling",
    "spolingarna": "spoling",
    "spolingarnas": "spoling",
    "spolingars": "spoling",
    "spolingen": "spoling",
    "spolingens": "spoling",
    "spolings": "spoling",
    "spolmaskar": "spolmask",
    "spolmaskarna": "spolmask",
    "spolmaskarnas": "spolmask",
    "spolmaskars": "spolmask",
    "spolmasken": "spolmask",
    "spolmaskens": "spolmask",
    "spolmasks": "spolmask",
    "spols": "spole",
    "spondyliten": "spondylit",
    "spondylitens": "spondylit",
    "spondyliter": "spondylit",
    "spondyliterna": "spondylit",
    "spondyliternas": "spondylit",
    "spondyliters": "spondylit",
    "spondylits": "spondylit",
    "spondylosen": "spondylos",
    "spondylosens": "spondylos",
    "spondéer": "spondé",
    "spondéerna": "spondé",
    "spondéernas": "spondé",
    "spondéers": "spondé",
    "spondén": "spondé",
    "spondéns": "spondé",
    "spondés": "spondé",
    "sponken": "sponk",
    "sponkens": "sponk",
    "sponket": "sponk",
    "sponkets": "sponk",
    "sponks": "sponk",
    "sponsorer": "sponsor",
    "sponsorerna": "sponsor",
    "sponsorernas": "sponsor",
    "sponsorers": "sponsor",
    "sponsormässiga": "sponsormässig",
    "sponsormässigare": "sponsormässig",
    "sponsormässigares": "sponsormässig",
    "sponsormässigas": "sponsormässig",
    "sponsormässigast": "sponsormässig",
    "sponsormässigaste": "sponsormässig",
    "sponsormässigastes": "sponsormässig",
    "sponsormässigasts": "sponsormässig",
    "sponsormässige": "sponsormässig",
    "sponsormässiges": "sponsormässig",
    "sponsormässigs": "sponsormässig",
    "sponsormässigt": "sponsormässig",
    "sponsormässigts": "sponsormässig",
    "sponsorn": "sponsor",
    "sponsorns": "sponsor",
    "sponsors": "sponsor",
    "sponsrad": "sponsra",
    "sponsrade": "sponsra",
    "sponsrades": "sponsra",
    "sponsrads": "sponsra",
    "sponsrande": "sponsra",
    "sponsranden": "sponsrande",
    "sponsrandena": "sponsrande",
    "sponsrandenas": "sponsrande",
    "sponsrandens": "sponsrande",
    "sponsrandes": "sponsrande",
    "sponsrandet": "sponsrande",
    "sponsrandets": "sponsrande",
    "sponsrar": "sponsra",
    "sponsras": "sponsra",
    "sponsrat": "sponsra",
    "sponsrats": "sponsra",
    "spont": "sponta",
    "spontad": "sponta",
    "spontade": "sponta",
    "spontades": "sponta",
    "spontads": "sponta",
    "spontana": "spontan",
    "spontanare": "spontan",
    "spontanares": "spontan",
    "spontanas": "spontan",
    "spontanast": "spontan",
    "spontanaste": "spontan",
    "spontanastes": "spontan",
    "spontanasts": "spontan",
    "spontande": "sponta",
    "spontanden": "spontande",
    "spontandena": "spontande",
    "spontandenas": "spontande",
    "spontandens": "spontande",
    "spontandes": "spontande",
    "spontandet": "spontande",
    "spontandets": "spontande",
    "spontane": "spontan",
    "spontanes": "spontan",
    "spontanismen": "spontanism",
    "spontanismens": "spontanism",
    "spontanismer": "spontanism",
    "spontanismerna": "spontanism",
    "spontanismernas": "spontanism",
    "spontanismers": "spontanism",
    "spontanisms": "spontanism",
    "spontanistiska": "spontanistisk",
    "spontanistiskas": "spontanistisk",
    "spontanistiske": "spontanistisk",
    "spontanistiskes": "spontanistisk",
    "spontanistisks": "spontanistisk",
    "spontanistiskt": "spontanistisk",
    "spontanistiskts": "spontanistisk",
    "spontaniteten": "spontanitet",
    "spontanitetens": "spontanitet",
    "spontaniteter": "spontanitet",
    "spontaniteterna": "spontanitet",
    "spontaniteternas": "spontanitet",
    "spontaniteters": "spontanitet",
    "spontanitets": "spontanitet",
    "spontans": "spontan",
    "spontant": "spontan",
    "spontants": "spontan",
    "spontar": "sponta",
    "spontas": "sponta",
    "spontat": "sponta",
    "spontats": "sponta",
    "sponten": "spont",
    "spontens": "spont",
    "sponter": "spont",
    "sponterna": "spont",
    "sponternas": "spont",
    "sponters": "spont",
    "sponts": "spont",
    "sporadiska": "sporadisk",
    "sporadiskare": "sporadisk",
    "sporadiskares": "sporadisk",
    "sporadiskas": "sporadisk",
    "sporadiskast": "sporadisk",
    "sporadiskaste": "sporadisk",
    "sporadiskastes": "sporadisk",
    "sporadiskasts": "sporadisk",
    "sporadiske": "sporadisk",
    "sporadiskes": "sporadisk",
    "sporadisks": "sporadisk",
    "sporadiskt": "sporadisk",
    "sporadiskts": "sporadisk",
    "sporangie": "sporangium",
    "sporangier": "sporangium",
    "sporangierna": "sporangium",
    "sporangiernas": "sporangium",
    "sporangiers": "sporangium",
    "sporangiet": "sporangium",
    "sporangiets": "sporangium",
    "sporangiums": "sporangium",
    "spord": "spörja",
    "sporda": "spörja",
    "spordas": "spörja",
    "sporde": "spörja",
    "spordes": "spörja",
    "spordjuren": "spordjur",
    "spordjurens": "spordjur",
    "spordjuret": "spordjur",
    "spordjurets": "spordjur",
    "spordjurs": "spordjur",
    "spords": "spörja",
    "sporen": "spor",
    "sporens": "spor",
    "sporer": "spor",
    "sporerna": "spor",
    "sporernas": "spor",
    "sporers": "spor",
    "sporgömmen": "sporgömme",
    "sporgömmena": "sporgömme",
    "sporgömmenas": "sporgömme",
    "sporgömmens": "sporgömme",
    "sporgömmes": "sporgömme",
    "sporgömmet": "sporgömme",
    "sporgömmets": "sporgömme",
    "sporgöms": "sporgömme",
    "sporkapseln": "sporkapsel",
    "sporkapselns": "sporkapsel",
    "sporkapsels": "sporkapsel",
    "sporkapslar": "sporkapsel",
    "sporkapslarna": "sporkapsel",
    "sporkapslarnas": "sporkapsel",
    "sporkapslars": "sporkapsel",
    "sporr": "sporre",
    "sporrad": "sporra",
    "sporrade": "sporra",
    "sporrades": "sporra",
    "sporrads": "sporra",
    "sporrande": "sporra",
    "sporranden": "sporrande",
    "sporrandena": "sporrande",
    "sporrandenas": "sporrande",
    "sporrandens": "sporrande",
    "sporrandes": "sporrande",
    "sporrandet": "sporrande",
    "sporrandets": "sporrande",
    "sporrar": "sporre",
    "sporrarna": "sporre",
    "sporrarnas": "sporre",
    "sporrars": "sporre",
    "sporras": "sporra",
    "sporrat": "sporra",
    "sporrats": "sporra",
    "sporren": "sporre",
    "sporrens": "sporre",
    "sporres": "sporre",
    "sporrs": "sporre",
    "sporrsträcket": "sporrsträck",
    "sporrsträckets": "sporrsträck",
    "sporrsträcks": "sporrsträck",
    "spors": "spor",
    "sporsäckar": "sporsäck",
    "sporsäckarna": "sporsäck",
    "sporsäckarnas": "sporsäck",
    "sporsäckars": "sporsäck",
    "sporsäcken": "sporsäck",
    "sporsäckens": "sporsäck",
    "sporsäcks": "sporsäck",
    "sport": "sporta",
    "sportad": "sporta",
    "sportade": "sporta",
    "sportades": "sporta",
    "sportads": "sporta",
    "sportaffären": "sportaffär",
    "sportaffärens": "sportaffär",
    "sportaffärer": "sportaffär",
    "sportaffärerna": "sportaffär",
    "sportaffärernas": "sportaffär",
    "sportaffärers": "sportaffär",
    "sportaffärs": "sportaffär",
    "sportande": "sporta",
    "sportanden": "sportande",
    "sportandena": "sportande",
    "sportandenas": "sportande",
    "sportandens": "sportande",
    "sportandes": "sportande",
    "sportandet": "sportande",
    "sportandets": "sportande",
    "sportar": "sporta",
    "sportas": "sporta",
    "sportat": "sporta",
    "sportats": "sporta",
    "sportbilar": "sportbil",
    "sportbilarna": "sportbil",
    "sportbilarnas": "sportbil",
    "sportbilars": "sportbil",
    "sportbilen": "sportbil",
    "sportbilens": "sportbil",
    "sportbils": "sportbil",
    "sportdykningar": "sportdykning",
    "sportdykningarna": "sportdykning",
    "sportdykningarnas": "sportdykning",
    "sportdykningars": "sportdykning",
    "sportdykningen": "sportdykning",
    "sportdykningens": "sportdykning",
    "sportdyknings": "sportdykning",
    "sporten": "sport",
    "sportens": "sport",
    "sporter": "sport",
    "sporterna": "sport",
    "sporternas": "sport",
    "sporters": "sport",
    "sportfiskemetoden": "sportfiskemetod",
    "sportfiskemetodens": "sportfiskemetod",
    "sportfiskemetoder": "sportfiskemetod",
    "sportfiskemetoderna": "sportfiskemetod",
    "sportfiskemetodernas": "sportfiskemetod",
    "sportfiskemetoders": "sportfiskemetod",
    "sportfiskemetods": "sportfiskemetod",
    "sportfiskes": "sportfiske",
    "sportfisket": "sportfiske",
    "sportfiskets": "sportfiske",
    "sportflygplanen": "sportflygplan",
    "sportflygplanens": "sportflygplan",
    "sportflygplanet": "sportflygplan",
    "sportflygplanets": "sportflygplan",
    "sportflygplans": "sportflygplan",
    "sportformen": "sportform",
    "sportformens": "sportform",
    "sportformer": "sportform",
    "sportformerna": "sportform",
    "sportformernas": "sportform",
    "sportformers": "sportform",
    "sportforms": "sportform",
    "sportfånar": "sportfåne",
    "sportfånarna": "sportfåne",
    "sportfånarnas": "sportfåne",
    "sportfånars": "sportfåne",
    "sportfånen": "sportfåne",
    "sportfånens": "sportfåne",
    "sportfånes": "sportfåne",
    "sportgrenar": "sportgren",
    "sportgrenarna": "sportgren",
    "sportgrenarnas": "sportgren",
    "sportgrenars": "sportgren",
    "sportgrenen": "sportgren",
    "sportgrenens": "sportgren",
    "sportgrens": "sportgren",
    "sportiga": "sportig",
    "sportigare": "sportig",
    "sportigares": "sportig",
    "sportigas": "sportig",
    "sportigast": "sportig",
    "sportigaste": "sportig",
    "sportigastes": "sportig",
    "sportigasts": "sportig",
    "sportige": "sportig",
    "sportiges": "sportig",
    "sportigheten": "sportighet",
    "sportighetens": "sportighet",
    "sportighets": "sportighet",
    "sportigs": "sportig",
    "sportigt": "sportig",
    "sportigts": "sportig",
    "sportintresserade": "sportintresserad",
    "sportintresserades": "sportintresserad",
    "sportintresserads": "sportintresserad",
    "sportintresserat": "sportintresserad",
    "sportintresserats": "sportintresserad",
    "sportjournalisten": "sportjournalist",
    "sportjournalistens": "sportjournalist",
    "sportjournalister": "sportjournalist",
    "sportjournalisterna": "sportjournalist",
    "sportjournalisternas": "sportjournalist",
    "sportjournalisters": "sportjournalist",
    "sportjournalists": "sportjournalist",
    "sportklubbar": "sportklubb",
    "sportklubbarna": "sportklubb",
    "sportklubbarnas": "sportklubb",
    "sportklubbars": "sportklubb",
    "sportklubben": "sportklubb",
    "sportklubbens": "sportklubb",
    "sportklubbs": "sportklubb",
    "sportlerna": "sportler",
    "sportlernas": "sportler",
    "sportlers": "sportler",
    "sportloven": "sportlov",
    "sportlovens": "sportlov",
    "sportlovet": "sportlov",
    "sportlovets": "sportlov",
    "sportlovs": "sportlov",
    "sportlovsstugan": "sportlovsstuga",
    "sportlovsstugans": "sportlovsstuga",
    "sportlovsstugas": "sportlovsstuga",
    "sportlovsstuge": "sportlovsstuga",
    "sportlovsstugor": "sportlovsstuga",
    "sportlovsstugorna": "sportlovsstuga",
    "sportlovsstugornas": "sportlovsstuga",
    "sportlovsstugors": "sportlovsstuga",
    "sportlovsstugu": "sportlovsstuga",
    "sportmodellen": "sportmodell",
    "sportmodellens": "sportmodell",
    "sportmodeller": "sportmodell",
    "sportmodellerna": "sportmodell",
    "sportmodellernas": "sportmodell",
    "sportmodellers": "sportmodell",
    "sportmodells": "sportmodell",
    "sportmöss": "sportmössa",
    "sportmössan": "sportmössa",
    "sportmössans": "sportmössa",
    "sportmössas": "sportmössa",
    "sportmösse": "sportmössa",
    "sportmössor": "sportmössa",
    "sportmössorna": "sportmössa",
    "sportmössornas": "sportmössa",
    "sportmössors": "sportmössa",
    "sportreportern": "sportreporter",
    "sportreporterns": "sportreporter",
    "sportreporters": "sportreporter",
    "sportreportrar": "sportreporter",
    "sportreportrarna": "sportreporter",
    "sportreportrarnas": "sportreporter",
    "sportreportrars": "sportreporter",
    "sports": "sport",
    "sportsidan": "sportsida",
    "sportsidans": "sportsida",
    "sportsidas": "sportsida",
    "sportside": "sportsida",
    "sportsides": "sportsida",
    "sportsidor": "sportsida",
    "sportsidorna": "sportsida",
    "sportsidornas": "sportsida",
    "sportsidors": "sportsida",
    "sportsliga": "sportslig",
    "sportsligare": "sportslig",
    "sportsligares": "sportslig",
    "sportsligas": "sportslig",
    "sportsligast": "sportslig",
    "sportsligaste": "sportslig",
    "sportsligastes": "sportslig",
    "sportsligasts": "sportslig",
    "sportslige": "sportslig",
    "sportsliges": "sportslig",
    "sportsligheten": "sportslighet",
    "sportslighetens": "sportslighet",
    "sportslighets": "sportslighet",
    "sportsligs": "sportslig",
    "sportsligt": "sportslig",
    "sportsligts": "sportslig",
    "sportsmannamässiga": "sportsmannamässig",
    "sportsmannamässigare": "sportsmannamässig",
    "sportsmannamässigares": "sportsmannamässig",
    "sportsmannamässigas": "sportsmannamässig",
    "sportsmannamässigast": "sportsmannamässig",
    "sportsmannamässigaste": "sportsmannamässig",
    "sportsmannamässigastes": "sportsmannamässig",
    "sportsmannamässigasts": "sportsmannamässig",
    "sportsmannamässige": "sportsmannamässig",
    "sportsmannamässiges": "sportsmannamässig",
    "sportsmannamässigs": "sportsmannamässig",
    "sportsmannamässigt": "sportsmannamässig",
    "sportsmannamässigts": "sportsmannamässig",
    "sportsmannen": "sportsman",
    "sportsmannens": "sportsman",
    "sportsmans": "sportsman",
    "sportsmanshipet": "sportsmanship",
    "sportsmanshipets": "sportsmanship",
    "sportsmanships": "sportsmanship",
    "sportsmän": "sportsman",
    "sportsmännen": "sportsman",
    "sportsmännens": "sportsman",
    "sportsmäns": "sportsman",
    "sportstugan": "sportstuga",
    "sportstugans": "sportstuga",
    "sportstugas": "sportstuga",
    "sportstuge": "sportstuga",
    "sportstugor": "sportstuga",
    "sportstugorna": "sportstuga",
    "sportstugornas": "sportstuga",
    "sportstugors": "sportstuga",
    "sportstugu": "sportstuga",
    "sportvagnar": "sportvagn",
    "sportvagnarna": "sportvagn",
    "sportvagnarnas": "sportvagn",
    "sportvagnars": "sportvagn",
    "sportvagnen": "sportvagn",
    "sportvagnens": "sportvagn",
    "sportvagns": "sportvagn",
    "sporväxten": "sporväxt",
    "sporväxtens": "sporväxt",
    "sporväxter": "sporväxt",
    "sporväxterna": "sporväxt",
    "sporväxternas": "sporväxt",
    "sporväxters": "sporväxt",
    "sporväxts": "sporväxt",
    "spotlighten": "spotlight",
    "spotlightens": "spotlight",
    "spotlights": "spotlight",
    "spotlightsarna": "spotlight",
    "spotlightsarnas": "spotlight",
    "spotlightsen": "spotlight",
    "spotlightsens": "spotlight",
    "spotska": "spotsk",
    "spotskare": "spotsk",
    "spotskares": "spotsk",
    "spotskas": "spotsk",
    "spotskast": "spotsk",
    "spotskaste": "spotsk",
    "spotskastes": "spotsk",
    "spotskasts": "spotsk",
    "spotske": "spotsk",
    "spotskes": "spotsk",
    "spotskheten": "spotskhet",
    "spotskhetens": "spotskhet",
    "spotskhets": "spotskhet",
    "spotsks": "spotsk",
    "spotskt": "spotsk",
    "spotskts": "spotsk",
    "spott": "spotta",
    "spottad": "spotta",
    "spottade": "spotta",
    "spottades": "spotta",
    "spottads": "spotta",
    "spottande": "spotta",
    "spottanden": "spottande",
    "spottandena": "spottande",
    "spottandenas": "spottande",
    "spottandens": "spottande",
    "spottandes": "spottande",
    "spottandet": "spottande",
    "spottandets": "spottande",
    "spottar": "spotta",
    "spottas": "spotta",
    "spottat": "spotta",
    "spottats": "spotta",
    "spottet": "spott",
    "spottets": "spott",
    "spottkörteln": "spottkörtel",
    "spottkörtelns": "spottkörtel",
    "spottkörtels": "spottkörtel",
    "spottkörtlar": "spottkörtel",
    "spottkörtlarna": "spottkörtel",
    "spottkörtlarnas": "spottkörtel",
    "spottkörtlars": "spottkörtel",
    "spottlosk": "spottloska",
    "spottloskan": "spottloska",
    "spottloskans": "spottloska",
    "spottloskas": "spottloska",
    "spottloske": "spottloska",
    "spottloskor": "spottloska",
    "spottloskorna": "spottloska",
    "spottloskornas": "spottloska",
    "spottloskors": "spottloska",
    "spotts": "spott",
    "spottstritar": "spottstrit",
    "spottstritarna": "spottstrit",
    "spottstritarnas": "spottstrit",
    "spottstritars": "spottstrit",
    "spottstriten": "spottstrit",
    "spottstritens": "spottstrit",
    "spottstrits": "spottstrit",
    "spottstyvern": "spottstyver",
    "spottstyverns": "spottstyver",
    "spottstyvers": "spottstyver",
    "spottstyvrar": "spottstyver",
    "spottstyvrarna": "spottstyver",
    "spottstyvrarnas": "spottstyver",
    "spottstyvrars": "spottstyver",
    "spovar": "spov",
    "spovarna": "spov",
    "spovarnas": "spov",
    "spovars": "spov",
    "spoven": "spov",
    "spovens": "spov",
    "spovs": "spov",
    "sprack": "spricka",
    "spracks": "spricka",
    "sprak": "spraka",
    "sprakad": "spraka",
    "sprakade": "spraka",
    "sprakades": "spraka",
    "sprakads": "spraka",
    "sprakande": "spraka",
    "sprakanden": "sprakande",
    "sprakandena": "sprakande",
    "sprakandenas": "sprakande",
    "sprakandens": "sprakande",
    "sprakandes": "sprakande",
    "sprakandet": "sprakande",
    "sprakandets": "sprakande",
    "sprakar": "spraka",
    "sprakas": "spraka",
    "sprakat": "spraka",
    "sprakats": "spraka",
    "sprakfål": "sprakfåle",
    "sprakfålar": "sprakfåle",
    "sprakfålarna": "sprakfåle",
    "sprakfålarnas": "sprakfåle",
    "sprakfålars": "sprakfåle",
    "sprakfålen": "sprakfåle",
    "sprakfålens": "sprakfåle",
    "sprakfåles": "sprakfåle",
    "sprakfåls": "sprakfåle",
    "sprall": "spralla",
    "sprallad": "spralla",
    "sprallade": "spralla",
    "sprallades": "spralla",
    "sprallads": "spralla",
    "sprallande": "spralla",
    "sprallanden": "sprallande",
    "sprallandena": "sprallande",
    "sprallandenas": "sprallande",
    "sprallandens": "sprallande",
    "sprallandes": "sprallande",
    "sprallandet": "sprallande",
    "sprallandets": "sprallande",
    "sprallar": "spralla",
    "sprallas": "spralla",
    "sprallat": "spralla",
    "sprallats": "spralla",
    "spralliga": "sprallig",
    "spralligare": "sprallig",
    "spralligares": "sprallig",
    "spralligas": "sprallig",
    "spralligast": "sprallig",
    "spralligaste": "sprallig",
    "spralligastes": "sprallig",
    "spralligasts": "sprallig",
    "sprallige": "sprallig",
    "spralliges": "sprallig",
    "spralligheten": "sprallighet",
    "sprallighetens": "sprallighet",
    "sprallighets": "sprallighet",
    "spralligs": "sprallig",
    "spralligt": "sprallig",
    "spralligts": "sprallig",
    "sprang": "springa",
    "sprangs": "springa",
    "spratt": "spritta",
    "sprattel": "sprattla",
    "sprattelgubb": "sprattelgubbe",
    "sprattelgubbar": "sprattelgubbe",
    "sprattelgubbarna": "sprattelgubbe",
    "sprattelgubbarnas": "sprattelgubbe",
    "sprattelgubbars": "sprattelgubbe",
    "sprattelgubben": "sprattelgubbe",
    "sprattelgubbens": "sprattelgubbe",
    "sprattelgubbes": "sprattelgubbe",
    "sprattelgubbs": "sprattelgubbe",
    "sprattels": "sprattel",
    "spratten": "spratt",
    "sprattens": "spratt",
    "sprattet": "spratt",
    "sprattets": "spratt",
    "sprattlade": "sprattla",
    "sprattlades": "sprattla",
    "sprattlande": "sprattla",
    "sprattlanden": "sprattlande",
    "sprattlandena": "sprattlande",
    "sprattlandenas": "sprattlande",
    "sprattlandens": "sprattlande",
    "sprattlandes": "sprattlande",
    "sprattlandet": "sprattlande",
    "sprattlandets": "sprattlande",
    "sprattlar": "sprattla",
    "sprattlas": "sprattla",
    "sprattlat": "sprattla",
    "sprattlats": "sprattla",
    "sprattlet": "sprattel",
    "sprattlets": "sprattel",
    "spratts": "spritta",
    "spray": "spraya",
    "sprayad": "spraya",
    "sprayade": "spraya",
    "sprayades": "spraya",
    "sprayads": "spraya",
    "sprayande": "spraya",
    "sprayanden": "sprayande",
    "sprayandena": "sprayande",
    "sprayandenas": "sprayande",
    "sprayandens": "sprayande",
    "sprayandes": "sprayande",
    "sprayandet": "sprayande",
    "sprayandets": "sprayande",
    "sprayar": "spraya",
    "sprayas": "spraya",
    "sprayat": "spraya",
    "sprayats": "spraya",
    "sprayen": "spray",
    "sprayens": "spray",
    "sprayer": "spray",
    "sprayerna": "spray",
    "sprayernas": "spray",
    "sprayers": "spray",
    "sprayflask": "sprayflaska",
    "sprayflaskan": "sprayflaska",
    "sprayflaskans": "sprayflaska",
    "sprayflaskas": "sprayflaska",
    "sprayflaske": "sprayflaska",
    "sprayflaskor": "sprayflaska",
    "sprayflaskorna": "sprayflaska",
    "sprayflaskornas": "sprayflaska",
    "sprayflaskors": "sprayflaska",
    "sprayhooden": "sprayhood",
    "sprayhoodens": "sprayhood",
    "sprayhoods": "sprayhood",
    "spraymunstycken": "spraymunstycke",
    "spraymunstyckena": "spraymunstycke",
    "spraymunstyckenas": "spraymunstycke",
    "spraymunstyckens": "spraymunstycke",
    "spraymunstyckes": "spraymunstycke",
    "spraymunstycket": "spraymunstycke",
    "spraymunstyckets": "spraymunstycke",
    "spraymunstycks": "spraymunstycke",
    "sprays": "spray",
    "spred": "sprida",
    "sprede": "sprida",
    "spredes": "sprida",
    "spreds": "sprida",
    "sprej": "spreja",
    "sprejad": "spreja",
    "sprejade": "spreja",
    "sprejades": "spreja",
    "sprejads": "spreja",
    "sprejande": "spreja",
    "sprejanden": "sprejande",
    "sprejandena": "sprejande",
    "sprejandenas": "sprejande",
    "sprejandens": "sprejande",
    "sprejandes": "sprejande",
    "sprejandet": "sprejande",
    "sprejandets": "sprejande",
    "sprejar": "spreja",
    "sprejas": "spreja",
    "sprejat": "spreja",
    "sprejats": "spreja",
    "sprejen": "sprej",
    "sprejens": "sprej",
    "sprejer": "sprej",
    "sprejerna": "sprej",
    "sprejernas": "sprej",
    "sprejers": "sprej",
    "sprejflask": "sprejflaska",
    "sprejflaskan": "sprejflaska",
    "sprejflaskans": "sprejflaska",
    "sprejflaskas": "sprejflaska",
    "sprejflaske": "sprejflaska",
    "sprejflaskor": "sprejflaska",
    "sprejflaskorna": "sprejflaska",
    "sprejflaskornas": "sprejflaska",
    "sprejflaskors": "sprejflaska",
    "sprejmunstycken": "sprejmunstycke",
    "sprejmunstyckena": "sprejmunstycke",
    "sprejmunstyckenas": "sprejmunstycke",
    "sprejmunstyckens": "sprejmunstycke",
    "sprejmunstyckes": "sprejmunstycke",
    "sprejmunstycket": "sprejmunstycke",
    "sprejmunstyckets": "sprejmunstycke",
    "sprejmunstycks": "sprejmunstycke",
    "sprejs": "sprej",
    "spret": "spreta",
    "spretad": "spreta",
    "spretade": "spreta",
    "spretades": "spreta",
    "spretads": "spreta",
    "spretande": "spreta",
    "spretanden": "spretande",
    "spretandena": "spretande",
    "spretandenas": "spretande",
    "spretandens": "spretande",
    "spretandes": "spretande",
    "spretandet": "spretande",
    "spretandets": "spretande",
    "spretar": "spreta",
    "spretas": "spreta",
    "spretat": "spreta",
    "spretats": "spreta",
    "spretiga": "spretig",
    "spretigare": "spretig",
    "spretigares": "spretig",
    "spretigas": "spretig",
    "spretigast": "spretig",
    "spretigaste": "spretig",
    "spretigastes": "spretig",
    "spretigasts": "spretig",
    "spretige": "spretig",
    "spretiges": "spretig",
    "spretigheten": "spretighet",
    "spretighetens": "spretighet",
    "spretigheter": "spretighet",
    "spretigheterna": "spretighet",
    "spretigheternas": "spretighet",
    "spretigheters": "spretighet",
    "spretighets": "spretighet",
    "spretigs": "spretig",
    "spretigt": "spretig",
    "spretigts": "spretig",
    "sprick": "spricka",
    "sprickan": "spricka",
    "sprickande": "spricka",
    "sprickanden": "sprickande",
    "sprickandena": "sprickande",
    "sprickandenas": "sprickande",
    "sprickandens": "sprickande",
    "sprickandes": "sprickande",
    "sprickandet": "sprickande",
    "sprickandets": "sprickande",
    "sprickans": "spricka",
    "sprickas": "spricka",
    "sprickbildningar": "sprickbildning",
    "sprickbildningarna": "sprickbildning",
    "sprickbildningarnas": "sprickbildning",
    "sprickbildningars": "sprickbildning",
    "sprickbildningen": "sprickbildning",
    "sprickbildningens": "sprickbildning",
    "sprickbildnings": "sprickbildning",
    "sprickdalar": "sprickdal",
    "sprickdalarna": "sprickdal",
    "sprickdalarnas": "sprickdal",
    "sprickdalars": "sprickdal",
    "sprickdalen": "sprickdal",
    "sprickdalens": "sprickdal",
    "sprickdals": "sprickdal",
    "spricke": "spricka",
    "spricker": "spricka",
    "sprickes": "spricka",
    "sprickfärdiga": "sprickfärdig",
    "sprickfärdigare": "sprickfärdig",
    "sprickfärdigares": "sprickfärdig",
    "sprickfärdigas": "sprickfärdig",
    "sprickfärdigast": "sprickfärdig",
    "sprickfärdigaste": "sprickfärdig",
    "sprickfärdigastes": "sprickfärdig",
    "sprickfärdigasts": "sprickfärdig",
    "sprickfärdige": "sprickfärdig",
    "sprickfärdiges": "sprickfärdig",
    "sprickfärdigheten": "sprickfärdighet",
    "sprickfärdighetens": "sprickfärdighet",
    "sprickfärdighets": "sprickfärdighet",
    "sprickfärdigs": "sprickfärdig",
    "sprickfärdigt": "sprickfärdig",
    "sprickfärdigts": "sprickfärdig",
    "sprickiga": "sprickig",
    "sprickigare": "sprickig",
    "sprickigares": "sprickig",
    "sprickigas": "sprickig",
    "sprickigast": "sprickig",
    "sprickigaste": "sprickig",
    "sprickigastes": "sprickig",
    "sprickigasts": "sprickig",
    "sprickige": "sprickig",
    "sprickiges": "sprickig",
    "sprickigheten": "sprickighet",
    "sprickighetens": "sprickighet",
    "sprickighets": "sprickighet",
    "sprickigs": "sprickig",
    "sprickigt": "sprickig",
    "sprickigts": "sprickig",
    "sprickor": "spricka",
    "sprickorna": "spricka",
    "sprickornas": "spricka",
    "sprickors": "spricka",
    "spricks": "spricka",
    "sprid": "sprida",
    "spridande": "sprida",
    "spridanden": "spridande",
    "spridandena": "spridande",
    "spridandenas": "spridande",
    "spridandens": "spridande",
    "spridandes": "spridande",
    "spridandet": "spridande",
    "spridandets": "spridande",
    "spridar": "spridare",
    "spridaren": "spridare",
    "spridarens": "spridare",
    "spridares": "spridare",
    "spridarna": "spridare",
    "spridarnas": "spridare",
    "spridarvagnar": "spridarvagn",
    "spridarvagnarna": "spridarvagn",
    "spridarvagnarnas": "spridarvagn",
    "spridarvagnars": "spridarvagn",
    "spridarvagnen": "spridarvagn",
    "spridarvagnens": "spridarvagn",
    "spridarvagns": "spridarvagn",
    "spridas": "sprida",
    "spridd": "sprida",
    "spridda": "spridd",
    "spriddare": "spridd",
    "spriddares": "spridd",
    "spriddas": "spridd",
    "spriddast": "spridd",
    "spriddaste": "spridd",
    "spriddastes": "spridd",
    "spriddasts": "spridd",
    "spridde": "spridd",
    "spriddes": "spridd",
    "spriddheten": "spriddhet",
    "spriddhetens": "spriddhet",
    "spriddhets": "spriddhet",
    "spridds": "spridd",
    "spride": "sprida",
    "sprider": "sprida",
    "sprides": "sprida",
    "spridit": "sprida",
    "spridits": "sprida",
    "spridningar": "spridning",
    "spridningarna": "spridning",
    "spridningarnas": "spridning",
    "spridningars": "spridning",
    "spridningen": "spridning",
    "spridningens": "spridning",
    "spridnings": "spridning",
    "spridningskäll": "spridningskälla",
    "spridningskällan": "spridningskälla",
    "spridningskällans": "spridningskälla",
    "spridningskällas": "spridningskälla",
    "spridningskälle": "spridningskälla",
    "spridningskällor": "spridningskälla",
    "spridningskällorna": "spridningskälla",
    "spridningskällornas": "spridningskälla",
    "spridningskällors": "spridningskälla",
    "spridningskälls": "spridningskälla",
    "spridningslinsen": "spridningslins",
    "spridningslinsens": "spridningslins",
    "spridningslinser": "spridningslins",
    "spridningslinserna": "spridningslins",
    "spridningslinsernas": "spridningslins",
    "spridningslinsers": "spridningslins",
    "spridningsmåtten": "spridningsmått",
    "spridningsmåttens": "spridningsmått",
    "spridningsmåttet": "spridningsmått",
    "spridningsmåttets": "spridningsmått",
    "spridningsmåtts": "spridningsmått",
    "sprids": "sprida",
    "sprien": "spri",
    "spriens": "spri",
    "spriet": "spri",
    "spriets": "spri",
    "sprin": "spri",
    "sprina": "spri",
    "sprinas": "spri",
    "spring": "springa",
    "springan": "springa",
    "springande": "springa",
    "springanden": "springande",
    "springandena": "springande",
    "springandenas": "springande",
    "springandens": "springande",
    "springandes": "springande",
    "springandet": "springande",
    "springandets": "springande",
    "springans": "springa",
    "springar": "springare",
    "springaren": "springare",
    "springarens": "springare",
    "springares": "springare",
    "springarna": "springare",
    "springarnas": "springare",
    "springas": "springa",
    "springbockar": "springbock",
    "springbockarna": "springbock",
    "springbockarnas": "springbock",
    "springbockars": "springbock",
    "springbocken": "springbock",
    "springbockens": "springbock",
    "springbocks": "springbock",
    "springbrunnar": "springbrunn",
    "springbrunnarna": "springbrunn",
    "springbrunnarnas": "springbrunn",
    "springbrunnars": "springbrunn",
    "springbrunnen": "springbrunn",
    "springbrunnens": "springbrunn",
    "springbrunns": "springbrunn",
    "springe": "springa",
    "springen": "spring",
    "springens": "spring",
    "springer": "springa",
    "springes": "springa",
    "springet": "spring",
    "springets": "spring",
    "springflick": "springflicka",
    "springflickan": "springflicka",
    "springflickans": "springflicka",
    "springflickas": "springflicka",
    "springflicke": "springflicka",
    "springflickor": "springflicka",
    "springflickorna": "springflicka",
    "springflickornas": "springflicka",
    "springflickors": "springflicka",
    "springflicks": "springflicka",
    "springfloden": "springflod",
    "springflodens": "springflod",
    "springflods": "springflod",
    "springkäll": "springkälla",
    "springkällan": "springkälla",
    "springkällans": "springkälla",
    "springkällas": "springkälla",
    "springkälle": "springkälla",
    "springkällor": "springkälla",
    "springkällorna": "springkälla",
    "springkällornas": "springkälla",
    "springkällors": "springkälla",
    "springkälls": "springkälla",
    "springmaskar": "springmask",
    "springmaskarna": "springmask",
    "springmaskarnas": "springmask",
    "springmaskars": "springmask",
    "springmasken": "springmask",
    "springmaskens": "springmask",
    "springmasks": "springmask",
    "springnotan": "springnota",
    "springnotans": "springnota",
    "springnotas": "springnota",
    "springnote": "springnota",
    "springnotor": "springnota",
    "springnotorna": "springnota",
    "springnotornas": "springnota",
    "springnotors": "springnota",
    "springor": "springa",
    "springorna": "springa",
    "springornas": "springa",
    "springors": "springa",
    "springpojk": "springpojke",
    "springpojkar": "springpojke",
    "springpojkarna": "springpojke",
    "springpojkarnas": "springpojke",
    "springpojkars": "springpojke",
    "springpojken": "springpojke",
    "springpojkens": "springpojke",
    "springpojkes": "springpojke",
    "springpojks": "springpojke",
    "springpojksjobben": "springpojksjobb",
    "springpojksjobbens": "springpojksjobb",
    "springpojksjobbet": "springpojksjobb",
    "springpojksjobbets": "springpojksjobb",
    "springpojksjobbs": "springpojksjobb",
    "springs": "springa",
    "springschasar": "springschas",
    "springschasarna": "springschas",
    "springschasarnas": "springschas",
    "springschasars": "springschas",
    "springschasen": "springschas",
    "springschasens": "springschas",
    "springsjasar": "springsjas",
    "springsjasarna": "springsjas",
    "springsjasarnas": "springsjas",
    "springsjasars": "springsjas",
    "springsjasen": "springsjas",
    "springsjasens": "springsjas",
    "springstiletten": "springstilett",
    "springstilettens": "springstilett",
    "springstiletter": "springstilett",
    "springstiletterna": "springstilett",
    "springstiletternas": "springstilett",
    "springstiletters": "springstilett",
    "springstiletts": "springstilett",
    "springvattens": "springvatten",
    "springvattnen": "springvatten",
    "springvattnens": "springvatten",
    "springvattnet": "springvatten",
    "springvattnets": "springvatten",
    "springvikarien": "springvikarie",
    "springvikariens": "springvikarie",
    "springvikarier": "springvikarie",
    "springvikarierna": "springvikarie",
    "springvikariernas": "springvikarie",
    "springvikariers": "springvikarie",
    "springvikaries": "springvikarie",
    "sprinkleranläggningar": "sprinkleranläggning",
    "sprinkleranläggningarna": "sprinkleranläggning",
    "sprinkleranläggningarnas": "sprinkleranläggning",
    "sprinkleranläggningars": "sprinkleranläggning",
    "sprinkleranläggningen": "sprinkleranläggning",
    "sprinkleranläggningens": "sprinkleranläggning",
    "sprinkleranläggnings": "sprinkleranläggning",
    "sprinklern": "sprinkler",
    "sprinklerna": "sprinkler",
    "sprinklernas": "sprinkler",
    "sprinklerns": "sprinkler",
    "sprinklers": "sprinkler",
    "sprinklersarna": "sprinkler",
    "sprinklersarnas": "sprinkler",
    "sprinklersen": "sprinkler",
    "sprinklersens": "sprinkler",
    "sprinklersystemen": "sprinklersystem",
    "sprinklersystemens": "sprinklersystem",
    "sprinklersystemet": "sprinklersystem",
    "sprinklersystemets": "sprinklersystem",
    "sprinklersystems": "sprinklersystem",
    "sprins": "spri",
    "sprint": "sprinta",
    "sprintad": "sprinta",
    "sprintade": "sprinta",
    "sprintades": "sprinta",
    "sprintads": "sprinta",
    "sprintande": "sprinta",
    "sprintanden": "sprintande",
    "sprintandena": "sprintande",
    "sprintandenas": "sprintande",
    "sprintandens": "sprintande",
    "sprintandes": "sprintande",
    "sprintandet": "sprintande",
    "sprintandets": "sprintande",
    "sprintar": "sprinta",
    "sprintarna": "sprint",
    "sprintarnas": "sprint",
    "sprintars": "sprint",
    "sprintas": "sprinta",
    "sprintat": "sprinta",
    "sprintats": "sprinta",
    "sprinten": "sprint",
    "sprintens": "sprint",
    "sprintern": "sprinter",
    "sprinterna": "sprinter",
    "sprinternas": "sprinter",
    "sprinterns": "sprinter",
    "sprinters": "sprinter",
    "sprintersarna": "sprinter",
    "sprintersarnas": "sprinter",
    "sprintersen": "sprinter",
    "sprintersens": "sprinter",
    "sprints": "sprint",
    "spris": "spri",
    "sprit": "sprita",
    "spritad": "sprita",
    "spritade": "sprita",
    "spritades": "sprita",
    "spritads": "sprita",
    "spritande": "sprita",
    "spritanden": "spritande",
    "spritandena": "spritande",
    "spritandenas": "spritande",
    "spritandens": "spritande",
    "spritandes": "spritande",
    "spritandet": "spritande",
    "spritandets": "spritande",
    "spritar": "sprita",
    "spritas": "sprita",
    "spritat": "sprita",
    "spritats": "sprita",
    "spritbegåvade": "spritbegåvad",
    "spritbegåvades": "spritbegåvad",
    "spritbegåvads": "spritbegåvad",
    "spritbegåvat": "spritbegåvad",
    "spritbegåvats": "spritbegåvad",
    "spritdrycken": "spritdryck",
    "spritdryckens": "spritdryck",
    "spritdrycker": "spritdryck",
    "spritdryckerna": "spritdryck",
    "spritdryckernas": "spritdryck",
    "spritdryckers": "spritdryck",
    "spritdrycks": "spritdryck",
    "spriten": "sprit",
    "spritens": "sprit",
    "sprithalten": "sprithalt",
    "sprithaltens": "sprithalt",
    "sprithalter": "sprithalt",
    "sprithalterna": "sprithalt",
    "sprithalternas": "sprithalt",
    "sprithalters": "sprithalt",
    "sprithaltiga": "sprithaltig",
    "sprithaltigare": "sprithaltig",
    "sprithaltigares": "sprithaltig",
    "sprithaltigas": "sprithaltig",
    "sprithaltigast": "sprithaltig",
    "sprithaltigaste": "sprithaltig",
    "sprithaltigastes": "sprithaltig",
    "sprithaltigasts": "sprithaltig",
    "sprithaltige": "sprithaltig",
    "sprithaltiges": "sprithaltig",
    "sprithaltigs": "sprithaltig",
    "sprithaltigt": "sprithaltig",
    "sprithaltigts": "sprithaltig",
    "sprithalts": "sprithalt",
    "spritköken": "spritkök",
    "spritkökens": "spritkök",
    "spritköket": "spritkök",
    "spritkökets": "spritkök",
    "spritköks": "spritkök",
    "spritlukten": "spritlukt",
    "spritluktens": "spritlukt",
    "spritlukts": "spritlukt",
    "spritmissbruket": "spritmissbruk",
    "spritmissbrukets": "spritmissbruk",
    "spritmissbruks": "spritmissbruk",
    "spritpenn": "spritpenna",
    "spritpennan": "spritpenna",
    "spritpennans": "spritpenna",
    "spritpennas": "spritpenna",
    "spritpenne": "spritpenna",
    "spritpennor": "spritpenna",
    "spritpennorna": "spritpenna",
    "spritpennornas": "spritpenna",
    "spritpennors": "spritpenna",
    "spritpenns": "spritpenna",
    "spriträttigheten": "spriträttighet",
    "spriträttighetens": "spriträttighet",
    "spriträttigheter": "spriträttighet",
    "spriträttigheterna": "spriträttighet",
    "spriträttigheternas": "spriträttighet",
    "spriträttigheters": "spriträttighet",
    "spriträttighets": "spriträttighet",
    "sprits": "spritsa",
    "spritsad": "spritsa",
    "spritsade": "spritsa",
    "spritsades": "spritsa",
    "spritsads": "spritsa",
    "spritsande": "spritsa",
    "spritsanden": "spritsande",
    "spritsandena": "spritsande",
    "spritsandenas": "spritsande",
    "spritsandens": "spritsande",
    "spritsandes": "spritsande",
    "spritsandet": "spritsande",
    "spritsandets": "spritsande",
    "spritsar": "spritsa",
    "spritsarna": "sprits",
    "spritsarnas": "sprits",
    "spritsars": "sprits",
    "spritsas": "spritsa",
    "spritsat": "spritsa",
    "spritsats": "spritsa",
    "spritsen": "sprits",
    "spritsens": "sprits",
    "spritspionen": "spritspion",
    "spritspionens": "spritspion",
    "spritspioner": "spritspion",
    "spritspionerna": "spritspion",
    "spritspionernas": "spritspion",
    "spritspioners": "spritspion",
    "spritspions": "spritspion",
    "spritt": "spritta",
    "sprittande": "spritta",
    "sprittanden": "sprittande",
    "sprittandena": "sprittande",
    "sprittandenas": "sprittande",
    "sprittandens": "sprittande",
    "sprittandes": "sprittande",
    "sprittandet": "sprittande",
    "sprittandets": "sprittande",
    "sprittas": "spritta",
    "spritte": "spritta",
    "spritter": "spritta",
    "sprittermometern": "sprittermometer",
    "sprittermometerns": "sprittermometer",
    "sprittermometers": "sprittermometer",
    "sprittermometrar": "sprittermometer",
    "sprittermometrarna": "sprittermometer",
    "sprittermometrarnas": "sprittermometer",
    "sprittermometrars": "sprittermometer",
    "sprittes": "spritta",
    "spritts": "spritta",
    "spritärterna": "spritärter",
    "spritärternas": "spritärter",
    "spritärters": "spritärter",
    "spritärts": "spritärter",
    "sprucke": "spricka",
    "sprucken": "spricka",
    "spruckens": "spricka",
    "spruckes": "spricka",
    "sprucket": "spricka",
    "spruckets": "spricka",
    "spruckit": "spricka",
    "spruckits": "spricka",
    "spruckna": "spricka",
    "sprucknas": "spricka",
    "spruckne": "spricka",
    "sprucknes": "spricka",
    "sprudel": "sprudla",
    "sprudlade": "sprudla",
    "sprudlades": "sprudla",
    "sprudlande": "sprudla",
    "sprudlanden": "sprudlande",
    "sprudlandena": "sprudlande",
    "sprudlandenas": "sprudlande",
    "sprudlandens": "sprudlande",
    "sprudlandes": "sprudlande",
    "sprudlandet": "sprudlande",
    "sprudlandets": "sprudlande",
    "sprudlar": "sprudla",
    "sprudlas": "sprudla",
    "sprudlat": "sprudla",
    "sprudlats": "sprudla",
    "spruen": "sprue",
    "spruens": "sprue",
    "sprues": "sprue",
    "sprunden": "sprund",
    "sprundens": "sprund",
    "sprundet": "sprund",
    "sprundets": "sprund",
    "sprunds": "sprund",
    "sprunge": "springa",
    "sprungen": "springa",
    "sprungens": "springa",
    "sprunges": "springa",
    "sprunget": "springa",
    "sprungets": "springa",
    "sprungit": "springa",
    "sprungits": "springa",
    "sprungna": "springa",
    "sprungnas": "springa",
    "sprungne": "springa",
    "sprungnes": "springa",
    "sprut": "spruta",
    "sprutad": "spruta",
    "sprutade": "spruta",
    "sprutades": "spruta",
    "sprutads": "spruta",
    "sprutan": "spruta",
    "sprutande": "spruta",
    "sprutanden": "sprutande",
    "sprutandena": "sprutande",
    "sprutandenas": "sprutande",
    "sprutandens": "sprutande",
    "sprutandes": "sprutande",
    "sprutandet": "sprutande",
    "sprutandets": "sprutande",
    "sprutans": "spruta",
    "sprutar": "spruta",
    "sprutas": "spruta",
    "sprutat": "spruta",
    "sprutats": "spruta",
    "sprutavrättningar": "sprutavrättning",
    "sprutavrättningarna": "sprutavrättning",
    "sprutavrättningarnas": "sprutavrättning",
    "sprutavrättningars": "sprutavrättning",
    "sprutavrättningen": "sprutavrättning",
    "sprutavrättningens": "sprutavrättning",
    "sprutavrättnings": "sprutavrättning",
    "sprutbyten": "sprutbyte",
    "sprutbytena": "sprutbyte",
    "sprutbytenas": "sprutbyte",
    "sprutbytens": "sprutbyte",
    "sprutbytes": "sprutbyte",
    "sprutbytet": "sprutbyte",
    "sprutbytets": "sprutbyte",
    "sprute": "spruta",
    "spruten": "sprut",
    "sprutens": "sprut",
    "sprutet": "sprut",
    "sprutets": "sprut",
    "sprutlackerad": "sprutlackera",
    "sprutlackerade": "sprutlackera",
    "sprutlackerades": "sprutlackera",
    "sprutlackerads": "sprutlackera",
    "sprutlackerande": "sprutlackera",
    "sprutlackeranden": "sprutlackerande",
    "sprutlackerandena": "sprutlackerande",
    "sprutlackerandenas": "sprutlackerande",
    "sprutlackerandens": "sprutlackerande",
    "sprutlackerandes": "sprutlackerande",
    "sprutlackerandet": "sprutlackerande",
    "sprutlackerandets": "sprutlackerande",
    "sprutlackerar": "sprutlackera",
    "sprutlackeras": "sprutlackera",
    "sprutlackerat": "sprutlackera",
    "sprutlackerats": "sprutlackera",
    "sprutlackerbara": "sprutlackerbar",
    "sprutlackerbarare": "sprutlackerbar",
    "sprutlackerbarares": "sprutlackerbar",
    "sprutlackerbaras": "sprutlackerbar",
    "sprutlackerbarast": "sprutlackerbar",
    "sprutlackerbaraste": "sprutlackerbar",
    "sprutlackerbarastes": "sprutlackerbar",
    "sprutlackerbarasts": "sprutlackerbar",
    "sprutlackerbare": "sprutlackerbar",
    "sprutlackerbares": "sprutlackerbar",
    "sprutlackerbarheten": "sprutlackerbarhet",
    "sprutlackerbarhetens": "sprutlackerbarhet",
    "sprutlackerbarhets": "sprutlackerbarhet",
    "sprutlackerbars": "sprutlackerbar",
    "sprutlackerbart": "sprutlackerbar",
    "sprutlackerbarts": "sprutlackerbar",
    "sprutlackeringar": "sprutlackering",
    "sprutlackeringarna": "sprutlackering",
    "sprutlackeringarnas": "sprutlackering",
    "sprutlackeringars": "sprutlackering",
    "sprutlackeringen": "sprutlackering",
    "sprutlackeringens": "sprutlackering",
    "sprutlackerings": "sprutlackering",
    "sprutmål": "sprutmåla",
    "sprutmålad": "sprutmåla",
    "sprutmålade": "sprutmåla",
    "sprutmålades": "sprutmåla",
    "sprutmålads": "sprutmåla",
    "sprutmålande": "sprutmåla",
    "sprutmålanden": "sprutmålande",
    "sprutmålandena": "sprutmålande",
    "sprutmålandenas": "sprutmålande",
    "sprutmålandens": "sprutmålande",
    "sprutmålandes": "sprutmålande",
    "sprutmålandet": "sprutmålande",
    "sprutmålandets": "sprutmålande",
    "sprutmålar": "sprutmåla",
    "sprutmålas": "sprutmåla",
    "sprutmålat": "sprutmåla",
    "sprutmålats": "sprutmåla",
    "sprutningar": "sprutning",
    "sprutningarna": "sprutning",
    "sprutningarnas": "sprutning",
    "sprutningars": "sprutning",
    "sprutningen": "sprutning",
    "sprutningens": "sprutning",
    "sprutnings": "sprutning",
    "sprutor": "spruta",
    "sprutorna": "spruta",
    "sprutornas": "spruta",
    "sprutors": "spruta",
    "sprutpistolen": "sprutpistol",
    "sprutpistolens": "sprutpistol",
    "sprutpistoler": "sprutpistol",
    "sprutpistolerna": "sprutpistol",
    "sprutpistolernas": "sprutpistol",
    "sprutpistolers": "sprutpistol",
    "sprutpistols": "sprutpistol",
    "spruts": "spruta",
    "sprutspetsar": "sprutspets",
    "sprutspetsarna": "sprutspets",
    "sprutspetsarnas": "sprutspets",
    "sprutspetsars": "sprutspets",
    "sprutspetsen": "sprutspets",
    "sprutspetsens": "sprutspets",
    "sprutte": "spritta",
    "sprutten": "sprutt",
    "spruttens": "sprutt",
    "spruttes": "spritta",
    "spruttit": "spritta",
    "spruttits": "spritta",
    "sprutts": "sprutt",
    "sprututbytesprogrammen": "sprututbytesprogram",
    "sprututbytesprogrammens": "sprututbytesprogram",
    "sprututbytesprogrammet": "sprututbytesprogram",
    "sprututbytesprogrammets": "sprututbytesprogram",
    "sprututbytesprograms": "sprututbytesprogram",
    "sprygeln": "sprygel",
    "sprygelns": "sprygel",
    "sprygels": "sprygel",
    "spryglar": "sprygel",
    "spryglarna": "sprygel",
    "spryglarnas": "sprygel",
    "spryglars": "sprygel",
    "spräck": "spräcka",
    "spräckande": "spräcka",
    "spräckanden": "spräckande",
    "spräckandena": "spräckande",
    "spräckandenas": "spräckande",
    "spräckandens": "spräckande",
    "spräckandes": "spräckande",
    "spräckandet": "spräckande",
    "spräckandets": "spräckande",
    "spräckas": "spräcka",
    "spräcker": "spräcka",
    "spräckes": "spräcka",
    "spräckliga": "spräcklig",
    "spräckligare": "spräcklig",
    "spräckligares": "spräcklig",
    "spräckligas": "spräcklig",
    "spräckligast": "spräcklig",
    "spräckligaste": "spräcklig",
    "spräckligastes": "spräcklig",
    "spräckligasts": "spräcklig",
    "spräcklige": "spräcklig",
    "spräckliges": "spräcklig",
    "spräckligheten": "spräcklighet",
    "spräcklighetens": "spräcklighet",
    "spräcklighets": "spräcklighet",
    "spräckligs": "spräcklig",
    "spräckligt": "spräcklig",
    "spräckligts": "spräcklig",
    "spräcks": "spräcka",
    "spräckt": "spräcka",
    "spräckta": "spräcka",
    "spräcktas": "spräcka",
    "spräckte": "spräcka",
    "spräcktes": "spräcka",
    "spräckts": "spräcka",
    "spräng": "spränga",
    "sprängande": "spränga",
    "spränganden": "sprängande",
    "sprängandena": "sprängande",
    "sprängandenas": "sprängande",
    "sprängandens": "sprängande",
    "sprängandes": "sprängande",
    "sprängandet": "sprängande",
    "sprängandets": "sprängande",
    "sprängarbeten": "sprängarbete",
    "sprängarbetena": "sprängarbete",
    "sprängarbetenas": "sprängarbete",
    "sprängarbetens": "sprängarbete",
    "sprängarbetes": "sprängarbete",
    "sprängarbetet": "sprängarbete",
    "sprängarbetets": "sprängarbete",
    "sprängarbets": "sprängarbete",
    "sprängarbetsplatsen": "sprängarbetsplats",
    "sprängarbetsplatsens": "sprängarbetsplats",
    "sprängarbetsplatser": "sprängarbetsplats",
    "sprängarbetsplatserna": "sprängarbetsplats",
    "sprängarbetsplatsernas": "sprängarbetsplats",
    "sprängarbetsplatsers": "sprängarbetsplats",
    "sprängas": "spränga",
    "sprängattentaten": "sprängattentat",
    "sprängattentatens": "sprängattentat",
    "sprängattentatet": "sprängattentat",
    "sprängattentatets": "sprängattentat",
    "sprängattentats": "sprängattentat",
    "sprängd": "spränga",
    "sprängda": "spränga",
    "sprängdas": "spränga",
    "sprängde": "spränga",
    "sprängdegen": "sprängdeg",
    "sprängdegens": "sprängdeg",
    "sprängdegs": "sprängdeg",
    "sprängdes": "spränga",
    "sprängds": "spränga",
    "spränger": "spränga",
    "spränges": "spränga",
    "sprängfulla": "sprängfull",
    "sprängfullare": "sprängfull",
    "sprängfullares": "sprängfull",
    "sprängfullas": "sprängfull",
    "sprängfullast": "sprängfull",
    "sprängfullaste": "sprängfull",
    "sprängfullastes": "sprängfull",
    "sprängfullasts": "sprängfull",
    "sprängfulle": "sprängfull",
    "sprängfulles": "sprängfull",
    "sprängfullheten": "sprängfullhet",
    "sprängfullhetens": "sprängfullhet",
    "sprängfullhets": "sprängfullhet",
    "sprängfulls": "sprängfull",
    "sprängfullt": "sprängfull",
    "sprängfullts": "sprängfull",
    "sprängfyllda": "sprängfylld",
    "sprängfylldare": "sprängfylld",
    "sprängfylldares": "sprängfylld",
    "sprängfylldas": "sprängfylld",
    "sprängfylldast": "sprängfylld",
    "sprängfylldaste": "sprängfylld",
    "sprängfylldastes": "sprängfylld",
    "sprängfylldasts": "sprängfylld",
    "sprängfyllde": "sprängfylld",
    "sprängfylldes": "sprängfylld",
    "sprängfylldheten": "sprängfylldhet",
    "sprängfylldhetens": "sprängfylldhet",
    "sprängfylldhets": "sprängfylldhet",
    "sprängfyllds": "sprängfylld",
    "sprängfyllt": "sprängfylld",
    "sprängfyllts": "sprängfylld",
    "spränggasen": "spränggas",
    "spränggasens": "spränggas",
    "spränggaser": "spränggas",
    "spränggaserna": "spränggas",
    "spränggasernas": "spränggas",
    "spränggasers": "spränggas",
    "sprängkapseln": "sprängkapsel",
    "sprängkapselns": "sprängkapsel",
    "sprängkapsels": "sprängkapsel",
    "sprängkapslar": "sprängkapsel",
    "sprängkapslarna": "sprängkapsel",
    "sprängkapslarnas": "sprängkapsel",
    "sprängkapslars": "sprängkapsel",
    "sprängkraften": "sprängkraft",
    "sprängkraftens": "sprängkraft",
    "sprängkrafts": "sprängkraft",
    "sprängladdningar": "sprängladdning",
    "sprängladdningarna": "sprängladdning",
    "sprängladdningarnas": "sprängladdning",
    "sprängladdningars": "sprängladdning",
    "sprängladdningen": "sprängladdning",
    "sprängladdningens": "sprängladdning",
    "sprängladdnings": "sprängladdning",
    "spränglistan": "spränglista",
    "spränglistans": "spränglista",
    "spränglistas": "spränglista",
    "sprängliste": "spränglista",
    "spränglistor": "spränglista",
    "spränglistorna": "spränglista",
    "spränglistornas": "spränglista",
    "spränglistors": "spränglista",
    "spränglärda": "spränglärd",
    "spränglärdare": "spränglärd",
    "spränglärdares": "spränglärd",
    "spränglärdas": "spränglärd",
    "spränglärdast": "spränglärd",
    "spränglärdaste": "spränglärd",
    "spränglärdastes": "spränglärd",
    "spränglärdasts": "spränglärd",
    "spränglärde": "spränglärd",
    "spränglärdes": "spränglärd",
    "spränglärdheten": "spränglärdhet",
    "spränglärdhetens": "spränglärdhet",
    "spränglärdhets": "spränglärdhet",
    "spränglärds": "spränglärd",
    "spränglärt": "spränglärd",
    "spränglärts": "spränglärd",
    "sprängningar": "sprängning",
    "sprängningarna": "sprängning",
    "sprängningarnas": "sprängning",
    "sprängningars": "sprängning",
    "sprängningen": "sprängning",
    "sprängningens": "sprängning",
    "sprängnings": "sprängning",
    "sprängningsarbeten": "sprängningsarbete",
    "sprängningsarbetena": "sprängningsarbete",
    "sprängningsarbetenas": "sprängningsarbete",
    "sprängningsarbetens": "sprängningsarbete",
    "sprängningsarbetes": "sprängningsarbete",
    "sprängningsarbetet": "sprängningsarbete",
    "sprängningsarbetets": "sprängningsarbete",
    "sprängningsarbets": "sprängningsarbete",
    "sprängs": "spränga",
    "sprängstoffen": "sprängstoff",
    "sprängstoffens": "sprängstoff",
    "sprängstoffet": "sprängstoff",
    "sprängstoffets": "sprängstoff",
    "sprängstoffs": "sprängstoff",
    "sprängt": "spränga",
    "sprängts": "spränga",
    "sprängverkans": "sprängverkan",
    "sprängämnen": "sprängämne",
    "sprängämnena": "sprängämne",
    "sprängämnenas": "sprängämne",
    "sprängämnens": "sprängämne",
    "sprängämnes": "sprängämne",
    "sprängämnesmolekylen": "sprängämnesmolekyl",
    "sprängämnesmolekylens": "sprängämnesmolekyl",
    "sprängämnesmolekyler": "sprängämnesmolekyl",
    "sprängämnesmolekylerna": "sprängämnesmolekyl",
    "sprängämnesmolekylernas": "sprängämnesmolekyl",
    "sprängämnesmolekylers": "sprängämnesmolekyl",
    "sprängämnesmolekyls": "sprängämnesmolekyl",
    "sprängämnespatronen": "sprängämnespatron",
    "sprängämnespatronens": "sprängämnespatron",
    "sprängämnespatroner": "sprängämnespatron",
    "sprängämnespatronerna": "sprängämnespatron",
    "sprängämnespatronernas": "sprängämnespatron",
    "sprängämnespatroners": "sprängämnespatron",
    "sprängämnespatrons": "sprängämnespatron",
    "sprängämnet": "sprängämne",
    "sprängämnets": "sprängämne",
    "sprätt": "sprätta",
    "sprättad": "sprätta",
    "sprättade": "sprätta",
    "sprättades": "sprätta",
    "sprättads": "sprätta",
    "sprättande": "sprätta",
    "sprättanden": "sprättande",
    "sprättandena": "sprättande",
    "sprättandenas": "sprättande",
    "sprättandens": "sprättande",
    "sprättandes": "sprättande",
    "sprättandet": "sprättande",
    "sprättandets": "sprättande",
    "sprättar": "sprätta",
    "sprättarna": "sprätt",
    "sprättarnas": "sprätt",
    "sprättars": "sprätt",
    "sprättas": "sprätta",
    "sprättat": "sprätta",
    "sprättats": "sprätta",
    "sprättbåg": "sprättbåge",
    "sprättbågar": "sprättbåge",
    "sprättbågarna": "sprättbåge",
    "sprättbågarnas": "sprättbåge",
    "sprättbågars": "sprättbåge",
    "sprättbågen": "sprättbåge",
    "sprättbågens": "sprättbåge",
    "sprättbåges": "sprättbåge",
    "sprättbågs": "sprättbåge",
    "sprätte": "sprätta",
    "sprätten": "sprätt",
    "sprättens": "sprätt",
    "sprätter": "sprätta",
    "sprättes": "sprätta",
    "sprätthökar": "sprätthök",
    "sprätthökarna": "sprätthök",
    "sprätthökarnas": "sprätthök",
    "sprätthökars": "sprätthök",
    "sprätthöken": "sprätthök",
    "sprätthökens": "sprätthök",
    "sprätthöks": "sprätthök",
    "sprättiga": "sprättig",
    "sprättigare": "sprättig",
    "sprättigares": "sprättig",
    "sprättigas": "sprättig",
    "sprättigast": "sprättig",
    "sprättigaste": "sprättig",
    "sprättigastes": "sprättig",
    "sprättigasts": "sprättig",
    "sprättige": "sprättig",
    "sprättiges": "sprättig",
    "sprättigheten": "sprättighet",
    "sprättighetens": "sprättighet",
    "sprättighets": "sprättighet",
    "sprättigs": "sprättig",
    "sprättigt": "sprättig",
    "sprättigts": "sprättig",
    "sprätts": "sprätta",
    "språk": "språka",
    "språkad": "språka",
    "språkade": "språka",
    "språkades": "språkas",
    "språkads": "språka",
    "språkande": "språka",
    "språkanden": "språkande",
    "språkandena": "språkande",
    "språkandenas": "språkande",
    "språkandens": "språkande",
    "språkandes": "språkande",
    "språkandet": "språkande",
    "språkandets": "språkande",
    "språkanvändningar": "språkanvändning",
    "språkanvändningarna": "språkanvändning",
    "språkanvändningarnas": "språkanvändning",
    "språkanvändningars": "språkanvändning",
    "språkanvändningen": "språkanvändning",
    "språkanvändningens": "språkanvändning",
    "språkanvändnings": "språkanvändning",
    "språkar": "språka",
    "språkas": "språka",
    "språkat": "språka",
    "språkats": "språkas",
    "språkbaserade": "språkbaserad",
    "språkbaserades": "språkbaserad",
    "språkbaserads": "språkbaserad",
    "språkbaserat": "språkbaserad",
    "språkbaserats": "språkbaserad",
    "språkbehandlingar": "språkbehandling",
    "språkbehandlingarna": "språkbehandling",
    "språkbehandlingarnas": "språkbehandling",
    "språkbehandlingars": "språkbehandling",
    "språkbehandlingen": "språkbehandling",
    "språkbehandlingens": "språkbehandling",
    "språkbehandlings": "språkbehandling",
    "språkbruket": "språkbruk",
    "språkbrukets": "språkbruk",
    "språkbruks": "språkbruk",
    "språkbråken": "språkbråk",
    "språkbråkens": "språkbråk",
    "språkbråket": "språkbråk",
    "språkbråkets": "språkbråk",
    "språkbråks": "språkbråk",
    "språkcentra": "språkcentrum",
    "språkcentrana": "språkcentrum",
    "språkcentranas": "språkcentrum",
    "språkcentras": "språkcentrum",
    "språkcentrumen": "språkcentrum",
    "språkcentrumens": "språkcentrum",
    "språkcentrumet": "språkcentrum",
    "språkcentrumets": "språkcentrum",
    "språkcentrums": "språkcentrum",
    "språkdräkten": "språkdräkt",
    "språkdräktens": "språkdräkt",
    "språkdräkter": "språkdräkt",
    "språkdräkterna": "språkdräkt",
    "språkdräkternas": "språkdräkt",
    "språkdräkters": "språkdräkt",
    "språkdräkts": "språkdräkt",
    "språken": "språk",
    "språkens": "språk",
    "språket": "språk",
    "språkets": "språk",
    "språkfamiljen": "språkfamilj",
    "språkfamiljens": "språkfamilj",
    "språkfamiljer": "språkfamilj",
    "språkfamiljerna": "språkfamilj",
    "språkfamiljernas": "språkfamilj",
    "språkfamiljers": "språkfamilj",
    "språkfamiljs": "språkfamilj",
    "språkfilosofien": "språkfilosofi",
    "språkfilosofiens": "språkfilosofi",
    "språkfilosofin": "språkfilosofi",
    "språkfilosofins": "språkfilosofi",
    "språkfilosofis": "språkfilosofi",
    "språkformen": "språkform",
    "språkformens": "språkform",
    "språkformer": "språkform",
    "språkformerna": "språkform",
    "språkformernas": "språkform",
    "språkformers": "språkform",
    "språkforms": "språkform",
    "språkforskar": "språkforskare",
    "språkforskaren": "språkforskare",
    "språkforskarens": "språkforskare",
    "språkforskares": "språkforskare",
    "språkforskarna": "språkforskare",
    "språkforskarnas": "språkforskare",
    "språkfärdigheten": "språkfärdighet",
    "språkfärdighetens": "språkfärdighet",
    "språkfärdigheter": "språkfärdighet",
    "språkfärdigheterna": "språkfärdighet",
    "språkfärdigheternas": "språkfärdighet",
    "språkfärdigheters": "språkfärdighet",
    "språkfärdighets": "språkfärdighet",
    "språkförbistringar": "språkförbistring",
    "språkförbistringarna": "språkförbistring",
    "språkförbistringarnas": "språkförbistring",
    "språkförbistringars": "språkförbistring",
    "språkförbistringen": "språkförbistring",
    "språkförbistringens": "språkförbistring",
    "språkförbistrings": "språkförbistring",
    "språkgruppen": "språkgrupp",
    "språkgruppens": "språkgrupp",
    "språkgrupper": "språkgrupp",
    "språkgrupperna": "språkgrupp",
    "språkgruppernas": "språkgrupp",
    "språkgruppers": "språkgrupp",
    "språkgrupps": "språkgrupp",
    "språkhistorian": "språkhistoria",
    "språkhistorians": "språkhistoria",
    "språkhistorias": "språkhistoria",
    "språkhistorien": "språkhistoria",
    "språkhistoriens": "språkhistoria",
    "språkinlärningar": "språkinlärning",
    "språkinlärningarna": "språkinlärning",
    "språkinlärningarnas": "språkinlärning",
    "språkinlärningars": "språkinlärning",
    "språkinlärningen": "språkinlärning",
    "språkinlärningens": "språkinlärning",
    "språkinlärnings": "språkinlärning",
    "språkkontrollanten": "språkkontrollant",
    "språkkontrollantens": "språkkontrollant",
    "språkkontrollanter": "språkkontrollant",
    "språkkontrollanterna": "språkkontrollant",
    "språkkontrollanternas": "språkkontrollant",
    "språkkontrollanters": "språkkontrollant",
    "språkkontrollants": "språkkontrollant",
    "språkkunniga": "språkkunnig",
    "språkkunnigare": "språkkunnig",
    "språkkunnigares": "språkkunnig",
    "språkkunnigas": "språkkunnig",
    "språkkunnigast": "språkkunnig",
    "språkkunnigaste": "språkkunnig",
    "språkkunnigastes": "språkkunnig",
    "språkkunnigasts": "språkkunnig",
    "språkkunnige": "språkkunnig",
    "språkkunniges": "språkkunnig",
    "språkkunnigheten": "språkkunnighet",
    "språkkunnighetens": "språkkunnighet",
    "språkkunnighets": "språkkunnighet",
    "språkkunnigs": "språkkunnig",
    "språkkunnigt": "språkkunnig",
    "språkkunnigts": "språkkunnig",
    "språkkunskapen": "språkkunskap",
    "språkkunskapens": "språkkunskap",
    "språkkunskaper": "språkkunskap",
    "språkkunskaperna": "språkkunskap",
    "språkkunskapernas": "språkkunskap",
    "språkkunskapers": "språkkunskap",
    "språkkunskaps": "språkkunskap",
    "språkkursen": "språkkurs",
    "språkkursens": "språkkurs",
    "språkkurser": "språkkurs",
    "språkkurserna": "språkkurs",
    "språkkursernas": "språkkurs",
    "språkkursers": "språkkurs",
    "språkkänslan": "språkkänsla",
    "språkkänslans": "språkkänsla",
    "språkkänslas": "språkkänsla",
    "språkkänsle": "språkkänsla",
    "språkkänslo": "språkkänsla",
    "språklaboratorie": "språklaboratorium",
    "språklaboratorier": "språklaboratorium",
    "språklaboratorierna": "språklaboratorium",
    "språklaboratoriernas": "språklaboratorium",
    "språklaboratoriers": "språklaboratorium",
    "språklaboratoriet": "språklaboratorium",
    "språklaboratoriets": "språklaboratorium",
    "språklaboratoriums": "språklaboratorium",
    "språklektionen": "språklektion",
    "språklektionens": "språklektion",
    "språklektioner": "språklektion",
    "språklektionerna": "språklektion",
    "språklektionernas": "språklektion",
    "språklektioners": "språklektion",
    "språklektions": "språklektion",
    "språkliga": "språklig",
    "språkligare": "språklig",
    "språkligares": "språklig",
    "språkligas": "språklig",
    "språkligast": "språklig",
    "språkligaste": "språklig",
    "språkligastes": "språklig",
    "språkligasts": "språklig",
    "språklige": "språklig",
    "språkliges": "språklig",
    "språkligheten": "språklighet",
    "språklighetens": "språklighet",
    "språkligheter": "språklighet",
    "språkligheterna": "språklighet",
    "språkligheternas": "språklighet",
    "språkligheters": "språklighet",
    "språklighets": "språklighet",
    "språkligs": "språklig",
    "språkligt": "språklig",
    "språkligts": "språklig",
    "språkljuden": "språkljud",
    "språkljudens": "språkljud",
    "språkljudet": "språkljud",
    "språkljudets": "språkljud",
    "språkljuds": "språkljud",
    "språkläran": "språklära",
    "språklärans": "språklära",
    "språklärar": "språklärare",
    "språkläraren": "språklärare",
    "språklärarens": "språklärare",
    "språklärares": "språklärare",
    "språklärarna": "språklärare",
    "språklärarnas": "språklärare",
    "språkläras": "språklära",
    "språkläre": "språklära",
    "språkläro": "språklära",
    "språkläror": "språklära",
    "språklärorna": "språklära",
    "språklärornas": "språklära",
    "språklärors": "språklära",
    "språkmässiga": "språkmässig",
    "språkmässigare": "språkmässig",
    "språkmässigares": "språkmässig",
    "språkmässigas": "språkmässig",
    "språkmässigast": "språkmässig",
    "språkmässigaste": "språkmässig",
    "språkmässigastes": "språkmässig",
    "språkmässigasts": "språkmässig",
    "språkmässige": "språkmässig",
    "språkmässiges": "språkmässig",
    "språkmässigs": "språkmässig",
    "språkmässigt": "språkmässig",
    "språkmässigts": "språkmässig",
    "språkmönsterna": "språkmönster",
    "språkmönsternas": "språkmönster",
    "språkmönsters": "språkmönster",
    "språkmönstren": "språkmönster",
    "språkmönstrens": "språkmönster",
    "språkmönstret": "språkmönster",
    "språkmönstrets": "språkmönster",
    "språkmöten": "språkmöte",
    "språkmötena": "språkmöte",
    "språkmötenas": "språkmöte",
    "språkmötens": "språkmöte",
    "språkmötes": "språkmöte",
    "språkmötet": "språkmöte",
    "språkmötets": "språkmöte",
    "språkpolisen": "språkpolis",
    "språkpolisens": "språkpolis",
    "språkpoliser": "språkpolis",
    "språkpoliserna": "språkpolis",
    "språkpolisernas": "språkpolis",
    "språkpolisers": "språkpolis",
    "språkproven": "språkprov",
    "språkprovens": "språkprov",
    "språkprovet": "språkprov",
    "språkprovets": "språkprov",
    "språkprovs": "språkprov",
    "språkpsykologien": "språkpsykologi",
    "språkpsykologiens": "språkpsykologi",
    "språkpsykologin": "språkpsykologi",
    "språkpsykologins": "språkpsykologi",
    "språkpsykologis": "språkpsykologi",
    "språkresan": "språkresa",
    "språkresans": "språkresa",
    "språkresas": "språkresa",
    "språkrese": "språkresa",
    "språkresor": "språkresa",
    "språkresorna": "språkresa",
    "språkresornas": "språkresa",
    "språkresors": "språkresa",
    "språkresursen": "språkresurs",
    "språkresursens": "språkresurs",
    "språkresurser": "språkresurs",
    "språkresurserna": "språkresurs",
    "språkresursernas": "språkresurs",
    "språkresursers": "språkresurs",
    "språkriktiga": "språkriktig",
    "språkriktigare": "språkriktig",
    "språkriktigares": "språkriktig",
    "språkriktigas": "språkriktig",
    "språkriktigast": "språkriktig",
    "språkriktigaste": "språkriktig",
    "språkriktigastes": "språkriktig",
    "språkriktigasts": "språkriktig",
    "språkriktige": "språkriktig",
    "språkriktiges": "språkriktig",
    "språkriktigheten": "språkriktighet",
    "språkriktighetens": "språkriktighet",
    "språkriktigheter": "språkriktighet",
    "språkriktigheterna": "språkriktighet",
    "språkriktigheternas": "språkriktighet",
    "språkriktigheters": "språkriktighet",
    "språkriktighets": "språkriktighet",
    "språkriktigs": "språkriktig",
    "språkriktigt": "språkriktig",
    "språkriktigts": "språkriktig",
    "språkrören": "språkrör",
    "språkrörens": "språkrör",
    "språkröret": "språkrör",
    "språkrörets": "språkrör",
    "språkrörs": "språkrör",
    "språks": "språk",
    "språksamheten": "språksamhet",
    "språksamhetens": "språksamhet",
    "språksamhets": "språksamhet",
    "språksamma": "språksam",
    "språksammare": "språksam",
    "språksammares": "språksam",
    "språksammas": "språksam",
    "språksammast": "språksam",
    "språksammaste": "språksam",
    "språksammastes": "språksam",
    "språksammasts": "språksam",
    "språksamme": "språksam",
    "språksammes": "språksam",
    "språksams": "språksam",
    "språksamt": "språksam",
    "språksamts": "språksam",
    "språksläktskapen": "språksläktskap",
    "språksläktskapens": "språksläktskap",
    "språksläktskaps": "språksläktskap",
    "språksociologien": "språksociologi",
    "språksociologiens": "språksociologi",
    "språksociologin": "språksociologi",
    "språksociologins": "språksociologi",
    "språksociologis": "språksociologi",
    "språkstammar": "språkstam",
    "språkstammarna": "språkstam",
    "språkstammarnas": "språkstam",
    "språkstammars": "språkstam",
    "språkstammen": "språkstam",
    "språkstammens": "språkstam",
    "språkstams": "språkstam",
    "språkstriden": "språkstrid",
    "språkstridens": "språkstrid",
    "språkstrider": "språkstrid",
    "språkstriderna": "språkstrid",
    "språkstridernas": "språkstrid",
    "språkstriders": "språkstrid",
    "språkstrids": "språkstrid",
    "språkteckens": "språktecken",
    "språktecknen": "språktecken",
    "språktecknens": "språktecken",
    "språktecknet": "språktecken",
    "språktecknets": "språktecken",
    "språktekniken": "språkteknik",
    "språkteknikens": "språkteknik",
    "språktekniker": "språkteknik",
    "språkteknikerna": "språkteknik",
    "språkteknikernas": "språkteknik",
    "språkteknikers": "språkteknik",
    "språktekniks": "språkteknik",
    "språkteknologien": "språkteknologi",
    "språkteknologiens": "språkteknologi",
    "språkteknologier": "språkteknologi",
    "språkteknologierna": "språkteknologi",
    "språkteknologiernas": "språkteknologi",
    "språkteknologiers": "språkteknologi",
    "språkteknologin": "språkteknologi",
    "språkteknologins": "språkteknologi",
    "språkteknologis": "språkteknologi",
    "språkteorien": "språkteori",
    "språkteoriens": "språkteori",
    "språkteorier": "språkteori",
    "språkteorierna": "språkteori",
    "språkteoriernas": "språkteori",
    "språkteoriers": "språkteori",
    "språkteorin": "språkteori",
    "språkteorins": "språkteori",
    "språkteoris": "språkteori",
    "språkundervisningar": "språkundervisning",
    "språkundervisningarna": "språkundervisning",
    "språkundervisningarnas": "språkundervisning",
    "språkundervisningars": "språkundervisning",
    "språkundervisningen": "språkundervisning",
    "språkundervisningens": "språkundervisning",
    "språkundervisnings": "språkundervisning",
    "språkvetar": "språkvetare",
    "språkvetaren": "språkvetare",
    "språkvetarens": "språkvetare",
    "språkvetares": "språkvetare",
    "språkvetarna": "språkvetare",
    "språkvetarnas": "språkvetare",
    "språkvetenskapen": "språkvetenskap",
    "språkvetenskapens": "språkvetenskap",
    "språkvetenskaper": "språkvetenskap",
    "språkvetenskaperna": "språkvetenskap",
    "språkvetenskapernas": "språkvetenskap",
    "språkvetenskapers": "språkvetenskap",
    "språkvetenskaps": "språkvetenskap",
    "språkvårdar": "språkvårdare",
    "språkvårdaren": "språkvårdare",
    "språkvårdarens": "språkvårdare",
    "språkvårdares": "språkvårdare",
    "språkvårdarna": "språkvårdare",
    "språkvårdarnas": "språkvårdare",
    "språkvården": "språkvård",
    "språkvårdens": "språkvård",
    "språkvårds": "språkvård",
    "språköras": "språköra",
    "språkörat": "språköra",
    "språkörats": "språköra",
    "språngbräd": "språngbräda",
    "språngbrädan": "språngbräda",
    "språngbrädans": "språngbräda",
    "språngbrädas": "språngbräda",
    "språngbräde": "språngbräda",
    "språngbrädor": "språngbräda",
    "språngbrädorna": "språngbräda",
    "språngbrädornas": "språngbräda",
    "språngbrädors": "språngbräda",
    "språngbräds": "språngbräda",
    "sprången": "språng",
    "språngens": "språng",
    "språnget": "språng",
    "språngets": "språng",
    "språngmarschen": "språngmarsch",
    "språngmarschens": "språngmarsch",
    "språngmarscher": "språngmarsch",
    "språngmarscherna": "språngmarsch",
    "språngmarschernas": "språngmarsch",
    "språngmarschers": "språngmarsch",
    "språngmarschs": "språngmarsch",
    "språngs": "språng",
    "språngsegels": "språngsegel",
    "språngseglen": "språngsegel",
    "språngseglens": "språngsegel",
    "språngseglet": "språngsegel",
    "språngseglets": "språngsegel",
    "spröda": "spröd",
    "sprödare": "spröd",
    "sprödares": "spröd",
    "sprödas": "spröd",
    "sprödast": "spröd",
    "sprödaste": "spröd",
    "sprödastes": "spröd",
    "sprödasts": "spröd",
    "spröde": "spröd",
    "sprödes": "spröd",
    "sprödheten": "sprödhet",
    "sprödhetens": "sprödhet",
    "sprödhets": "sprödhet",
    "spröds": "spröd",
    "spröjsade": "spröjsad",
    "spröjsades": "spröjsad",
    "spröjsads": "spröjsad",
    "spröjsar": "spröjs",
    "spröjsarna": "spröjs",
    "spröjsarnas": "spröjs",
    "spröjsars": "spröjs",
    "spröjsat": "spröjsad",
    "spröjsats": "spröjsad",
    "spröjsen": "spröjs",
    "spröjsens": "spröjs",
    "spröt": "spröta",
    "sprötad": "spröta",
    "sprötade": "spröta",
    "sprötades": "spröta",
    "sprötads": "spröta",
    "sprötande": "spröta",
    "sprötanden": "sprötande",
    "sprötandena": "sprötande",
    "sprötandenas": "sprötande",
    "sprötandens": "sprötande",
    "sprötandes": "sprötande",
    "sprötandet": "sprötande",
    "sprötandets": "sprötande",
    "sprötar": "spröta",
    "sprötas": "spröta",
    "sprötat": "spröta",
    "sprötats": "spröta",
    "spröten": "spröt",
    "sprötens": "spröt",
    "sprötet": "spröt",
    "sprötets": "spröt",
    "spröts": "spröt",
    "sprött": "spröd",
    "sprötts": "spröd",
    "spunna": "spinna",
    "spunnas": "spinna",
    "spunne": "spinna",
    "spunnen": "spinna",
    "spunnens": "spinna",
    "spunnes": "spinna",
    "spunnet": "spinna",
    "spunnets": "spinna",
    "spunnit": "spinna",
    "spunnits": "spinna",
    "spurt": "spurta",
    "spurtad": "spurta",
    "spurtade": "spurta",
    "spurtades": "spurta",
    "spurtads": "spurta",
    "spurtande": "spurta",
    "spurtanden": "spurtande",
    "spurtandena": "spurtande",
    "spurtandenas": "spurtande",
    "spurtandens": "spurtande",
    "spurtandes": "spurtande",
    "spurtandet": "spurtande",
    "spurtandets": "spurtande",
    "spurtar": "spurta",
    "spurtas": "spurta",
    "spurtat": "spurta",
    "spurtats": "spurta",
    "spurten": "spurt",
    "spurtens": "spurt",
    "spurter": "spurt",
    "spurterna": "spurt",
    "spurternas": "spurt",
    "spurters": "spurt",
    "spurts": "spurt",
    "sputnikar": "sputnik",
    "sputnikarna": "sputnik",
    "sputnikarnas": "sputnik",
    "sputnikars": "sputnik",
    "sputniken": "sputnik",
    "sputnikens": "sputnik",
    "sputniks": "sputnik",
    "sputums": "sputum",
    "spy": "spya",
    "spyan": "spya",
    "spyans": "spya",
    "spyas": "spya",
    "spybollar": "spyboll",
    "spybollarna": "spyboll",
    "spybollarnas": "spyboll",
    "spybollars": "spyboll",
    "spybollen": "spyboll",
    "spybollens": "spyboll",
    "spybolls": "spyboll",
    "spydd": "spy",
    "spydda": "spy",
    "spyddas": "spy",
    "spydde": "spy",
    "spyddes": "spy",
    "spydds": "spy",
    "spydiga": "spydig",
    "spydigare": "spydig",
    "spydigares": "spydig",
    "spydigas": "spydig",
    "spydigast": "spydig",
    "spydigaste": "spydig",
    "spydigastes": "spydig",
    "spydigasts": "spydig",
    "spydige": "spydig",
    "spydiges": "spydig",
    "spydigheten": "spydighet",
    "spydighetens": "spydighet",
    "spydigheter": "spydighet",
    "spydigheterna": "spydighet",
    "spydigheternas": "spydighet",
    "spydigheters": "spydighet",
    "spydighets": "spydighet",
    "spydigs": "spydig",
    "spydigt": "spydig",
    "spydigts": "spydig",
    "spye": "spya",
    "spyende": "spy",
    "spyenden": "spyende",
    "spyendena": "spyende",
    "spyendenas": "spyende",
    "spyendens": "spyende",
    "spyendes": "spyende",
    "spyendet": "spyende",
    "spyendets": "spyende",
    "spyflug": "spyfluga",
    "spyflugan": "spyfluga",
    "spyflugans": "spyfluga",
    "spyflugas": "spyfluga",
    "spyfluge": "spyfluga",
    "spyflugor": "spyfluga",
    "spyflugorna": "spyfluga",
    "spyflugornas": "spyfluga",
    "spyflugors": "spyfluga",
    "spyflugs": "spyfluga",
    "spyfärdiga": "spyfärdig",
    "spyfärdigare": "spyfärdig",
    "spyfärdigares": "spyfärdig",
    "spyfärdigas": "spyfärdig",
    "spyfärdigast": "spyfärdig",
    "spyfärdigaste": "spyfärdig",
    "spyfärdigastes": "spyfärdig",
    "spyfärdigasts": "spyfärdig",
    "spyfärdige": "spyfärdig",
    "spyfärdiges": "spyfärdig",
    "spyfärdigheten": "spyfärdighet",
    "spyfärdighetens": "spyfärdighet",
    "spyfärdighets": "spyfärdighet",
    "spyfärdigs": "spyfärdig",
    "spyfärdigt": "spyfärdig",
    "spyfärdigts": "spyfärdig",
    "spygatten": "spygatt",
    "spygattens": "spygatt",
    "spygattet": "spygatt",
    "spygattets": "spygatt",
    "spygatts": "spygatt",
    "spyor": "spya",
    "spyorna": "spya",
    "spyornas": "spya",
    "spyors": "spya",
    "spyr": "spy",
    "spys": "spya",
    "spytt": "spy",
    "spytts": "spy",
    "späck": "späcka",
    "späckad": "späcka",
    "späckade": "späcka",
    "späckades": "späcka",
    "späckads": "späcka",
    "späckande": "späcka",
    "späckanden": "späckande",
    "späckandena": "späckande",
    "späckandenas": "späckande",
    "späckandens": "späckande",
    "späckandes": "späckande",
    "späckandet": "späckande",
    "späckandets": "späckande",
    "späckar": "späcka",
    "späckas": "späcka",
    "späckat": "späcka",
    "späckats": "späcka",
    "späcket": "späck",
    "späckets": "späck",
    "späckhuggar": "späckhuggare",
    "späckhuggaren": "späckhuggare",
    "späckhuggarens": "späckhuggare",
    "späckhuggares": "späckhuggare",
    "späckhuggarna": "späckhuggare",
    "späckhuggarnas": "späckhuggare",
    "späcks": "späck",
    "späd": "spä",
    "späda": "späd",
    "spädande": "spä",
    "spädanden": "spädande",
    "spädandena": "spädande",
    "spädandenas": "spädande",
    "spädandens": "spädande",
    "spädandes": "spädande",
    "spädandet": "spädande",
    "spädandets": "spädande",
    "spädare": "späd",
    "spädares": "späd",
    "spädas": "späd",
    "spädast": "späd",
    "spädaste": "späd",
    "spädastes": "späd",
    "spädasts": "späd",
    "spädbarnen": "spädbarn",
    "spädbarnens": "spädbarn",
    "spädbarnet": "spädbarn",
    "spädbarnets": "spädbarn",
    "spädbarns": "spädbarn",
    "spädd": "spä",
    "spädda": "spä",
    "späddas": "spä",
    "spädde": "spä",
    "späddes": "spä",
    "späddrickan": "späddricka",
    "späddrickans": "späddricka",
    "späddrickas": "späddricka",
    "späddrickat": "späddricka",
    "späddrickats": "späddricka",
    "späddrycken": "späddryck",
    "späddryckens": "späddryck",
    "späddrycks": "späddryck",
    "spädds": "spä",
    "späde": "späd",
    "späder": "spä",
    "spädes": "späd",
    "spädgeten": "spädget",
    "spädgetens": "spädget",
    "spädgets": "spädget",
    "spädgetter": "spädget",
    "spädgetterna": "spädget",
    "spädgetternas": "spädget",
    "spädgetters": "spädget",
    "spädgrisar": "spädgris",
    "spädgrisarna": "spädgris",
    "spädgrisarnas": "spädgris",
    "spädgrisars": "spädgris",
    "spädgrisen": "spädgris",
    "spädgrisens": "spädgris",
    "spädheten": "spädhet",
    "spädhetens": "spädhet",
    "spädhets": "spädhet",
    "späds": "späd",
    "späende": "spä",
    "späendes": "spä",
    "späk": "späka",
    "späkande": "späka",
    "späkanden": "späkande",
    "späkandena": "späkande",
    "späkandenas": "späkande",
    "späkandens": "späkande",
    "späkandes": "späkande",
    "späkandet": "späkande",
    "späkandets": "späkande",
    "späkas": "späka",
    "späker": "späka",
    "späkes": "späka",
    "späks": "späka",
    "späkt": "späka",
    "späkta": "späka",
    "späktas": "späka",
    "späkte": "späka",
    "späktes": "späka",
    "späkts": "späka",
    "spänd": "spänna",
    "spända": "spänna",
    "spändare": "spänd",
    "spändares": "spänd",
    "spändas": "spänna",
    "spändast": "spänd",
    "spändaste": "spänd",
    "spändastes": "spänd",
    "spändasts": "spänd",
    "spände": "spänna",
    "spändes": "spänna",
    "spändheten": "spändhet",
    "spändhetens": "spändhet",
    "spändhets": "spändhet",
    "spänds": "spänna",
    "spänger": "spång",
    "spängerna": "spång",
    "spängernas": "spång",
    "spängers": "spång",
    "spänn": "spänna",
    "spännande": "spänna",
    "spännanden": "spännande",
    "spännandena": "spännande",
    "spännandenas": "spännande",
    "spännandens": "spännande",
    "spännandes": "spännande",
    "spännandet": "spännande",
    "spännandets": "spännande",
    "spännarmar": "spännarm",
    "spännarmarna": "spännarm",
    "spännarmarnas": "spännarm",
    "spännarmars": "spännarm",
    "spännarmen": "spännarm",
    "spännarmens": "spännarm",
    "spännarms": "spännarm",
    "spännas": "spänna",
    "spännbanden": "spännband",
    "spännbandens": "spännband",
    "spännbandet": "spännband",
    "spännbandets": "spännband",
    "spännbands": "spännband",
    "spännbetongen": "spännbetong",
    "spännbetongens": "spännbetong",
    "spännbetongs": "spännbetong",
    "spännbuckel": "spännbuckla",
    "spännbucklan": "spännbuckla",
    "spännbucklans": "spännbuckla",
    "spännbucklas": "spännbuckla",
    "spännbuckle": "spännbuckla",
    "spännbucklor": "spännbuckla",
    "spännbucklorna": "spännbuckla",
    "spännbucklornas": "spännbuckla",
    "spännbucklors": "spännbuckla",
    "spännen": "spänne",
    "spännena": "spänne",
    "spännenas": "spänne",
    "spännens": "spänne",
    "spänner": "spänna",
    "spännerna": "spann",
    "spännernas": "spann",
    "spänners": "spann",
    "spännes": "spänne",
    "spännet": "spänne",
    "spännets": "spänne",
    "spänningar": "spänning",
    "spänningarna": "spänning",
    "spänningarnas": "spänning",
    "spänningars": "spänning",
    "spänningen": "spänning",
    "spänningens": "spänning",
    "spännings": "spänning",
    "spänningsdelar": "spänningsdelare",
    "spänningsdelaren": "spänningsdelare",
    "spänningsdelarens": "spänningsdelare",
    "spänningsdelares": "spänningsdelare",
    "spänningsdelarna": "spänningsdelare",
    "spänningsdelarnas": "spänningsdelare",
    "spänningsjusteringar": "spänningsjustering",
    "spänningsjusteringarna": "spänningsjustering",
    "spänningsjusteringarnas": "spänningsjustering",
    "spänningsjusteringars": "spänningsjustering",
    "spänningsjusteringen": "spänningsjustering",
    "spänningsjusteringens": "spänningsjustering",
    "spänningsjusterings": "spänningsjustering",
    "spänningsmässiga": "spänningsmässig",
    "spänningsmässigare": "spänningsmässig",
    "spänningsmässigares": "spänningsmässig",
    "spänningsmässigas": "spänningsmässig",
    "spänningsmässigast": "spänningsmässig",
    "spänningsmässigaste": "spänningsmässig",
    "spänningsmässigastes": "spänningsmässig",
    "spänningsmässigasts": "spänningsmässig",
    "spänningsmässige": "spänningsmässig",
    "spänningsmässiges": "spänningsmässig",
    "spänningsmässigs": "spänningsmässig",
    "spänningsmässigt": "spänningsmässig",
    "spänningsmässigts": "spänningsmässig",
    "spänningsomvandlar": "spänningsomvandlare",
    "spänningsomvandlaren": "spänningsomvandlare",
    "spänningsomvandlarens": "spänningsomvandlare",
    "spänningsomvandlares": "spänningsomvandlare",
    "spänningsomvandlarna": "spänningsomvandlare",
    "spänningsomvandlarnas": "spänningsomvandlare",
    "spänningsregulatorer": "spänningsregulator",
    "spänningsregulatorerna": "spänningsregulator",
    "spänningsregulatorernas": "spänningsregulator",
    "spänningsregulatorers": "spänningsregulator",
    "spänningsregulatorn": "spänningsregulator",
    "spänningsregulatorns": "spänningsregulator",
    "spänningsregulators": "spänningsregulator",
    "spänningssökar": "spänningssökare",
    "spänningssökaren": "spänningssökare",
    "spänningssökarens": "spänningssökare",
    "spänningssökares": "spänningssökare",
    "spänningssökarna": "spänningssökare",
    "spänningssökarnas": "spänningssökare",
    "spännramar": "spännram",
    "spännramarna": "spännram",
    "spännramarnas": "spännram",
    "spännramars": "spännram",
    "spännramen": "spännram",
    "spännramens": "spännram",
    "spännrams": "spännram",
    "spännremmar": "spännrem",
    "spännremmarna": "spännrem",
    "spännremmarnas": "spännrem",
    "spännremmars": "spännrem",
    "spännremmen": "spännrem",
    "spännremmens": "spännrem",
    "spännrems": "spännrem",
    "spänns": "spänne",
    "spännvidden": "spännvidd",
    "spännviddens": "spännvidd",
    "spännvidder": "spännvidd",
    "spännvidderna": "spännvidd",
    "spännviddernas": "spännvidd",
    "spännvidders": "spännvidd",
    "spännvidds": "spännvidd",
    "spännvinkeln": "spännvinkel",
    "spännvinkelns": "spännvinkel",
    "spännvinkels": "spännvinkel",
    "spännvinklar": "spännvinkel",
    "spännvinklarna": "spännvinkel",
    "spännvinklarnas": "spännvinkel",
    "spännvinklars": "spännvinkel",
    "spänsen": "späns",
    "spänsens": "späns",
    "spänser": "späns",
    "spänserna": "späns",
    "spänsernas": "späns",
    "spänsers": "späns",
    "spänst": "spänsta",
    "spänstad": "spänsta",
    "spänstade": "spänsta",
    "spänstades": "spänsta",
    "spänstads": "spänsta",
    "spänstande": "spänsta",
    "spänstanden": "spänstande",
    "spänstandena": "spänstande",
    "spänstandenas": "spänstande",
    "spänstandens": "spänstande",
    "spänstandes": "spänstande",
    "spänstandet": "spänstande",
    "spänstandets": "spänstande",
    "spänstar": "spänsta",
    "spänstas": "spänsta",
    "spänstat": "spänsta",
    "spänstats": "spänsta",
    "spänsten": "spänst",
    "spänstens": "spänst",
    "spänstiga": "spänstig",
    "spänstigare": "spänstig",
    "spänstigares": "spänstig",
    "spänstigas": "spänstig",
    "spänstigast": "spänstig",
    "spänstigaste": "spänstig",
    "spänstigastes": "spänstig",
    "spänstigasts": "spänstig",
    "spänstige": "spänstig",
    "spänstiges": "spänstig",
    "spänstigheten": "spänstighet",
    "spänstighetens": "spänstighet",
    "spänstighets": "spänstighet",
    "spänstigs": "spänstig",
    "spänstigt": "spänstig",
    "spänstigts": "spänstig",
    "spänsts": "spänst",
    "spänt": "spänta",
    "späntad": "spänta",
    "späntade": "spänta",
    "späntades": "spänta",
    "späntads": "spänta",
    "späntande": "spänta",
    "späntanden": "späntande",
    "späntandena": "späntande",
    "späntandenas": "späntande",
    "späntandens": "späntande",
    "späntandes": "späntande",
    "späntandet": "späntande",
    "späntandets": "späntande",
    "späntar": "spänta",
    "späntas": "spänta",
    "späntat": "spänta",
    "späntats": "spänta",
    "spänts": "spänna",
    "spär": "spä",
    "spärr": "spärra",
    "spärrad": "spärra",
    "spärrade": "spärra",
    "spärrades": "spärra",
    "spärrads": "spärra",
    "spärrande": "spärra",
    "spärranden": "spärrande",
    "spärrandena": "spärrande",
    "spärrandenas": "spärrande",
    "spärrandens": "spärrande",
    "spärrandes": "spärrande",
    "spärrandet": "spärrande",
    "spärrandets": "spärrande",
    "spärrar": "spärra",
    "spärrarna": "spärr",
    "spärrarnas": "spärr",
    "spärrars": "spärr",
    "spärras": "spärra",
    "spärrat": "spärra",
    "spärrats": "spärra",
    "spärrballongen": "spärrballong",
    "spärrballongens": "spärrballong",
    "spärrballonger": "spärrballong",
    "spärrballongerna": "spärrballong",
    "spärrballongernas": "spärrballong",
    "spärrballongers": "spärrballong",
    "spärrballongs": "spärrballong",
    "spärrbommar": "spärrbom",
    "spärrbommarna": "spärrbom",
    "spärrbommarnas": "spärrbom",
    "spärrbommars": "spärrbom",
    "spärrbommen": "spärrbom",
    "spärrbommens": "spärrbom",
    "spärrboms": "spärrbom",
    "spärrdioden": "spärrdiod",
    "spärrdiodens": "spärrdiod",
    "spärrdioder": "spärrdiod",
    "spärrdioderna": "spärrdiod",
    "spärrdiodernas": "spärrdiod",
    "spärrdioders": "spärrdiod",
    "spärrdiods": "spärrdiod",
    "spärrelden": "spärreld",
    "spärreldens": "spärreld",
    "spärrelds": "spärreld",
    "spärren": "spärr",
    "spärrens": "spärr",
    "spärrhakar": "spärrhake",
    "spärrhakarna": "spärrhake",
    "spärrhakarnas": "spärrhake",
    "spärrhakars": "spärrhake",
    "spärrhaken": "spärrhake",
    "spärrhakens": "spärrhake",
    "spärrhakes": "spärrhake",
    "spärrkonton": "spärrkonto",
    "spärrkontona": "spärrkonto",
    "spärrkontonas": "spärrkonto",
    "spärrkontons": "spärrkonto",
    "spärrkontos": "spärrkonto",
    "spärrkontot": "spärrkonto",
    "spärrkontots": "spärrkonto",
    "spärrlinjen": "spärrlinje",
    "spärrlinjens": "spärrlinje",
    "spärrlinjer": "spärrlinje",
    "spärrlinjerna": "spärrlinje",
    "spärrlinjernas": "spärrlinje",
    "spärrlinjers": "spärrlinje",
    "spärrlinjes": "spärrlinje",
    "spärrlistan": "spärrlista",
    "spärrlistans": "spärrlista",
    "spärrlistas": "spärrlista",
    "spärrliste": "spärrlista",
    "spärrlistor": "spärrlista",
    "spärrlistorna": "spärrlista",
    "spärrlistornas": "spärrlista",
    "spärrlistors": "spärrlista",
    "spärrs": "spärr",
    "spärrvakten": "spärrvakt",
    "spärrvaktens": "spärrvakt",
    "spärrvakter": "spärrvakt",
    "spärrvakterna": "spärrvakt",
    "spärrvakternas": "spärrvakt",
    "spärrvakters": "spärrvakt",
    "spärrvakts": "spärrvakt",
    "späs": "spä",
    "spätleses": "spätlese",
    "spätt": "spätta",
    "spättan": "spätta",
    "spättans": "spätta",
    "spättas": "spätta",
    "spätte": "spätta",
    "spättor": "spätta",
    "spättorna": "spätta",
    "spättornas": "spätta",
    "spättors": "spätta",
    "spätts": "spätta",
    "spådd": "spå",
    "spådda": "spå",
    "spåddas": "spå",
    "spådde": "spå",
    "spåddes": "spå",
    "spådds": "spå",
    "spådomar": "spådom",
    "spådomarna": "spådom",
    "spådomarnas": "spådom",
    "spådomars": "spådom",
    "spådomen": "spådom",
    "spådomens": "spådom",
    "spådoms": "spådom",
    "spående": "spå",
    "spåenden": "spående",
    "spåendena": "spående",
    "spåendenas": "spående",
    "spåendens": "spående",
    "spåendes": "spående",
    "spåendet": "spående",
    "spåendets": "spående",
    "spåkvinnan": "spåkvinna",
    "spåkvinnans": "spåkvinna",
    "spåkvinnas": "spåkvinna",
    "spåkvinne": "spåkvinna",
    "spåkvinno": "spåkvinna",
    "spåkvinnor": "spåkvinna",
    "spåkvinnorna": "spåkvinna",
    "spåkvinnornas": "spåkvinna",
    "spåkvinnors": "spåkvinna",
    "spåmannen": "spåman",
    "spåmannens": "spåman",
    "spåmans": "spåman",
    "spåmän": "spåman",
    "spåmännen": "spåman",
    "spåmännens": "spåman",
    "spåmäns": "spåman",
    "spån": "spåna",
    "spånad": "spåna",
    "spånade": "spåna",
    "spånaden": "spånad",
    "spånadens": "spånad",
    "spånader": "spånad",
    "spånaderna": "spånad",
    "spånadernas": "spånad",
    "spånaders": "spånad",
    "spånades": "spåna",
    "spånads": "spånad",
    "spånan": "spåna",
    "spånande": "spåna",
    "spånanden": "spånande",
    "spånandena": "spånande",
    "spånandenas": "spånande",
    "spånandens": "spånande",
    "spånandes": "spånande",
    "spånandet": "spånande",
    "spånandets": "spånande",
    "spånans": "spåna",
    "spånar": "spåna",
    "spånas": "spåna",
    "spånat": "spåna",
    "spånats": "spåna",
    "spåne": "spåna",
    "spånen": "spån",
    "spånens": "spån",
    "spånet": "spån",
    "spånets": "spån",
    "spång": "spånga",
    "spångad": "spånga",
    "spångade": "spånga",
    "spångades": "spånga",
    "spångads": "spånga",
    "spångande": "spånga",
    "spånganden": "spångande",
    "spångandena": "spångande",
    "spångandenas": "spångande",
    "spångandens": "spångande",
    "spångandes": "spångande",
    "spångandet": "spångande",
    "spångandets": "spångande",
    "spångar": "spånga",
    "spångarna": "spång",
    "spångarnas": "spång",
    "spångars": "spång",
    "spångas": "spånga",
    "spångat": "spånga",
    "spångats": "spånga",
    "spången": "spång",
    "spångens": "spång",
    "spångs": "spång",
    "spånken": "spånk",
    "spånkens": "spånk",
    "spånket": "spånk",
    "spånkets": "spånk",
    "spånklädda": "spånklädd",
    "spånkläddare": "spånklädd",
    "spånkläddares": "spånklädd",
    "spånkläddas": "spånklädd",
    "spånkläddast": "spånklädd",
    "spånkläddaste": "spånklädd",
    "spånkläddastes": "spånklädd",
    "spånkläddasts": "spånklädd",
    "spånklädde": "spånklädd",
    "spånkläddes": "spånklädd",
    "spånklädds": "spånklädd",
    "spånklätt": "spånklädd",
    "spånklätts": "spånklädd",
    "spånkorgar": "spånkorg",
    "spånkorgarna": "spånkorg",
    "spånkorgarnas": "spånkorg",
    "spånkorgars": "spånkorg",
    "spånkorgen": "spånkorg",
    "spånkorgens": "spånkorg",
    "spånkorgs": "spånkorg",
    "spånks": "spånk",
    "spånor": "spåna",
    "spånorna": "spåna",
    "spånornas": "spåna",
    "spånors": "spåna",
    "spånplatt": "spånplatta",
    "spånplattan": "spånplatta",
    "spånplattans": "spånplatta",
    "spånplattas": "spånplatta",
    "spånplatte": "spånplatta",
    "spånplattor": "spånplatta",
    "spånplattorna": "spånplatta",
    "spånplattornas": "spånplatta",
    "spånplattors": "spånplatta",
    "spånplatts": "spånplatta",
    "spåns": "spåna",
    "spånskivan": "spånskiva",
    "spånskivans": "spånskiva",
    "spånskivas": "spånskiva",
    "spånskive": "spånskiva",
    "spånskivor": "spånskiva",
    "spånskivorna": "spånskiva",
    "spånskivornas": "spånskiva",
    "spånskivors": "spånskiva",
    "spånsugar": "spånsug",
    "spånsugarna": "spånsug",
    "spånsugarnas": "spånsug",
    "spånsugars": "spånsug",
    "spånsugen": "spånsug",
    "spånsugens": "spånsug",
    "spånsugs": "spånsug",
    "spånt": "spånta",
    "spåntad": "spånta",
    "spåntade": "spånta",
    "spåntades": "spånta",
    "spåntads": "spånta",
    "spåntande": "spånta",
    "spåntanden": "spåntande",
    "spåntandena": "spåntande",
    "spåntandenas": "spåntande",
    "spåntandens": "spåntande",
    "spåntandes": "spåntande",
    "spåntandet": "spåntande",
    "spåntandets": "spåntande",
    "spåntar": "spånta",
    "spåntas": "spånta",
    "spåntat": "spånta",
    "spåntats": "spånta",
    "spånten": "spånt",
    "spåntens": "spånt",
    "spånter": "spånt",
    "spånterna": "spånt",
    "spånternas": "spånt",
    "spånters": "spånt",
    "spånts": "spånt",
    "spår": "spåra",
    "spårad": "spåra",
    "spårade": "spåra",
    "spårades": "spåra",
    "spårads": "spåra",
    "spårande": "spåra",
    "spåranden": "spårande",
    "spårandena": "spårande",
    "spårandenas": "spårande",
    "spårandens": "spårande",
    "spårandes": "spårande",
    "spårandet": "spårande",
    "spårandets": "spårande",
    "spårar": "spåra",
    "spåras": "spåra",
    "spårat": "spåra",
    "spårats": "spåra",
    "spårelementen": "spårelement",
    "spårelementens": "spårelement",
    "spårelementet": "spårelement",
    "spårelementets": "spårelement",
    "spårelements": "spårelement",
    "spåren": "spår",
    "spårens": "spår",
    "spåret": "spår",
    "spårets": "spår",
    "spårförsedda": "spårförsedd",
    "spårförseddare": "spårförsedd",
    "spårförseddares": "spårförsedd",
    "spårförseddas": "spårförsedd",
    "spårförseddast": "spårförsedd",
    "spårförseddaste": "spårförsedd",
    "spårförseddastes": "spårförsedd",
    "spårförseddasts": "spårförsedd",
    "spårförsedde": "spårförsedd",
    "spårförseddes": "spårförsedd",
    "spårförsedds": "spårförsedd",
    "spårförsett": "spårförsedd",
    "spårförsetts": "spårförsedd",
    "spårhundar": "spårhund",
    "spårhundarna": "spårhund",
    "spårhundarnas": "spårhund",
    "spårhundars": "spårhund",
    "spårhunden": "spårhund",
    "spårhundens": "spårhund",
    "spårhunds": "spårhund",
    "spårljusen": "spårljus",
    "spårljusens": "spårljus",
    "spårljuset": "spårljus",
    "spårljusets": "spårljus",
    "spårlösa": "spårlös",
    "spårlösare": "spårlös",
    "spårlösares": "spårlös",
    "spårlösas": "spårlös",
    "spårlösast": "spårlös",
    "spårlösaste": "spårlös",
    "spårlösastes": "spårlös",
    "spårlösasts": "spårlös",
    "spårlöse": "spårlös",
    "spårlöses": "spårlös",
    "spårlösheten": "spårlöshet",
    "spårlöshetens": "spårlöshet",
    "spårlöshets": "spårlöshet",
    "spårlöst": "spårlös",
    "spårlösts": "spårlös",
    "spårmejseln": "spårmejsel",
    "spårmejselns": "spårmejsel",
    "spårmejsels": "spårmejsel",
    "spårmejslar": "spårmejsel",
    "spårmejslarna": "spårmejsel",
    "spårmejslarnas": "spårmejsel",
    "spårmejslars": "spårmejsel",
    "spårmetallen": "spårmetall",
    "spårmetallens": "spårmetall",
    "spårmetalls": "spårmetall",
    "spårningar": "spårning",
    "spårningarna": "spårning",
    "spårningarnas": "spårning",
    "spårningars": "spårning",
    "spårningen": "spårning",
    "spårningens": "spårning",
    "spårnings": "spårning",
    "spårs": "spår",
    "spårsäkringar": "spårsäkring",
    "spårsäkringarna": "spårsäkring",
    "spårsäkringarnas": "spårsäkring",
    "spårsäkringars": "spårsäkring",
    "spårsäkringen": "spårsäkring",
    "spårsäkringens": "spårsäkring",
    "spårsäkrings": "spårsäkring",
    "spårvagnar": "spårvagn",
    "spårvagnarna": "spårvagn",
    "spårvagnarnas": "spårvagn",
    "spårvagnars": "spårvagn",
    "spårvagnen": "spårvagn",
    "spårvagnens": "spårvagn",
    "spårvagns": "spårvagn",
    "spårvidden": "spårvidd",
    "spårviddens": "spårvidd",
    "spårvidder": "spårvidd",
    "spårvidderna": "spårvidd",
    "spårviddernas": "spårvidd",
    "spårvidders": "spårvidd",
    "spårvidds": "spårvidd",
    "spårvägar": "spårväg",
    "spårvägarna": "spårväg",
    "spårvägarnas": "spårväg",
    "spårvägars": "spårväg",
    "spårvägen": "spårväg",
    "spårvägens": "spårväg",
    "spårvägs": "spårväg",
    "spårvägschefen": "spårvägschef",
    "spårvägschefens": "spårvägschef",
    "spårvägschefer": "spårvägschef",
    "spårvägscheferna": "spårvägschef",
    "spårvägschefernas": "spårvägschef",
    "spårvägschefers": "spårvägschef",
    "spårvägschefs": "spårvägschef",
    "spårämnen": "spårämne",
    "spårämnena": "spårämne",
    "spårämnenas": "spårämne",
    "spårämnens": "spårämne",
    "spårämnes": "spårämne",
    "spårämnet": "spårämne",
    "spårämnets": "spårämne",
    "spås": "spå",
    "spått": "spå",
    "spåtts": "spå",
    "spö": "spöa",
    "spöad": "spöa",
    "spöade": "spöa",
    "spöades": "spöa",
    "spöads": "spöa",
    "spöande": "spöa",
    "spöanden": "spöande",
    "spöandena": "spöande",
    "spöandenas": "spöande",
    "spöandens": "spöande",
    "spöandes": "spöande",
    "spöandet": "spöande",
    "spöandets": "spöande",
    "spöar": "spöa",
    "spöas": "spöa",
    "spöat": "spöa",
    "spöats": "spöa",
    "spöet": "spö",
    "spöets": "spö",
    "spök": "spöka",
    "spökad": "spöka",
    "spökade": "spöka",
    "spökades": "spöka",
    "spökads": "spöka",
    "spökaktiga": "spökaktig",
    "spökaktigare": "spökaktig",
    "spökaktigares": "spökaktig",
    "spökaktigas": "spökaktig",
    "spökaktigast": "spökaktig",
    "spökaktigaste": "spökaktig",
    "spökaktigastes": "spökaktig",
    "spökaktigasts": "spökaktig",
    "spökaktige": "spökaktig",
    "spökaktiges": "spökaktig",
    "spökaktigheten": "spökaktighet",
    "spökaktighetens": "spökaktighet",
    "spökaktighets": "spökaktighet",
    "spökaktigs": "spökaktig",
    "spökaktigt": "spökaktig",
    "spökaktigts": "spökaktig",
    "spökande": "spöka",
    "spökanden": "spökande",
    "spökandena": "spökande",
    "spökandenas": "spökande",
    "spökandens": "spökande",
    "spökandes": "spökande",
    "spökandet": "spökande",
    "spökandets": "spökande",
    "spökar": "spöka",
    "spökas": "spöka",
    "spökat": "spöka",
    "spökats": "spöka",
    "spökbilden": "spökbild",
    "spökbildens": "spökbild",
    "spökbilder": "spökbild",
    "spökbilderna": "spökbild",
    "spökbildernas": "spökbild",
    "spökbilders": "spökbild",
    "spökbilds": "spökbild",
    "spökdjuren": "spökdjur",
    "spökdjurens": "spökdjur",
    "spökdjuret": "spökdjur",
    "spökdjurets": "spökdjur",
    "spökdjurs": "spökdjur",
    "spökelser": "spökelse",
    "spökelserna": "spökelse",
    "spökelsernas": "spökelse",
    "spökelsers": "spökelse",
    "spökelses": "spökelse",
    "spökelset": "spökelse",
    "spökelsets": "spökelse",
    "spöken": "spöke",
    "spökena": "spöke",
    "spökenas": "spöke",
    "spökens": "spöke",
    "spökerier": "spökeri",
    "spökerierna": "spökeri",
    "spökeriernas": "spökeri",
    "spökeriers": "spökeri",
    "spökeriet": "spökeri",
    "spökeriets": "spökeri",
    "spökeris": "spökeri",
    "spökerit": "spökeri",
    "spökerits": "spökeri",
    "spökes": "spöke",
    "spöket": "spöke",
    "spökets": "spöke",
    "spökfiguren": "spökfigur",
    "spökfigurens": "spökfigur",
    "spökfigurer": "spökfigur",
    "spökfigurerna": "spökfigur",
    "spökfigurernas": "spökfigur",
    "spökfigurers": "spökfigur",
    "spökfigurs": "spökfigur",
    "spökgestalten": "spökgestalt",
    "spökgestaltens": "spökgestalt",
    "spökgestalter": "spökgestalt",
    "spökgestalterna": "spökgestalt",
    "spökgestalternas": "spökgestalt",
    "spökgestalters": "spökgestalt",
    "spökgestalts": "spökgestalt",
    "spökhistorian": "spökhistoria",
    "spökhistorians": "spökhistoria",
    "spökhistorias": "spökhistoria",
    "spökhistorien": "spökhistoria",
    "spökhistoriens": "spökhistoria",
    "spökhistorier": "spökhistoria",
    "spökhistorierna": "spökhistoria",
    "spökhistoriernas": "spökhistoria",
    "spökhistoriers": "spökhistoria",
    "spöklika": "spöklik",
    "spöklikare": "spöklik",
    "spöklikares": "spöklik",
    "spöklikas": "spöklik",
    "spöklikast": "spöklik",
    "spöklikaste": "spöklik",
    "spöklikastes": "spöklik",
    "spöklikasts": "spöklik",
    "spöklike": "spöklik",
    "spöklikes": "spöklik",
    "spöklikheten": "spöklikhet",
    "spöklikhetens": "spöklikhet",
    "spöklikhets": "spöklikhet",
    "spökliks": "spöklik",
    "spöklikt": "spöklik",
    "spöklikts": "spöklik",
    "spökpartikeln": "spökpartikel",
    "spökpartikelns": "spökpartikel",
    "spökpartikels": "spökpartikel",
    "spökpartiklar": "spökpartikel",
    "spökpartiklarna": "spökpartikel",
    "spökpartiklarnas": "spökpartikel",
    "spökpartiklars": "spökpartikel",
    "spöks": "spöke",
    "spökskrivar": "spökskrivare",
    "spökskrivaren": "spökskrivare",
    "spökskrivarens": "spökskrivare",
    "spökskrivares": "spökskrivare",
    "spökskrivarna": "spökskrivare",
    "spökskrivarnas": "spökskrivare",
    "spökstaden": "spökstad",
    "spökstadens": "spökstad",
    "spökstads": "spökstad",
    "spökstan": "spökstad",
    "spökstans": "spökstad",
    "spökstäder": "spökstad",
    "spökstäderna": "spökstad",
    "spökstädernas": "spökstad",
    "spökstäders": "spökstad",
    "spöktim": "spöktimme",
    "spöktimman": "spöktimma",
    "spöktimmans": "spöktimma",
    "spöktimmar": "spöktimme",
    "spöktimmarna": "spöktimme",
    "spöktimmarnas": "spöktimme",
    "spöktimmars": "spöktimme",
    "spöktimmas": "spöktimma",
    "spöktimmen": "spöktimme",
    "spöktimmens": "spöktimme",
    "spöktimmes": "spöktimme",
    "spöktims": "spöktimme",
    "spön": "spö",
    "spöna": "spö",
    "spönas": "spö",
    "spöns": "spö",
    "spöregnet": "spöregn",
    "spöregnets": "spöregn",
    "spöregns": "spöregn",
    "spörj": "spörja",
    "spörjande": "spörja",
    "spörjanden": "spörjande",
    "spörjandena": "spörjande",
    "spörjandenas": "spörjande",
    "spörjandens": "spörjande",
    "spörjandes": "spörjande",
    "spörjandet": "spörjande",
    "spörjandets": "spörjande",
    "spörjas": "spörja",
    "spörjer": "spörja",
    "spörjes": "spörja",
    "spörjs": "spörja",
    "spörsmålen": "spörsmål",
    "spörsmålens": "spörsmål",
    "spörsmålet": "spörsmål",
    "spörsmålets": "spörsmål",
    "spörsmåls": "spörsmål",
    "spös": "spö",
    "spöslitningar": "spöslitning",
    "spöslitningarna": "spöslitning",
    "spöslitningarnas": "spöslitning",
    "spöslitningars": "spöslitning",
    "spöslitningen": "spöslitning",
    "spöslitningens": "spöslitning",
    "spöslitnings": "spöslitning",
    "spöstraffen": "spöstraff",
    "spöstraffens": "spöstraff",
    "spöstraffet": "spöstraff",
    "spöstraffets": "spöstraff",
    "spöstraffs": "spöstraff",
    "spöt": "spö",
    "spöts": "spö",
    "squashbollar": "squashboll",
    "squashbollarna": "squashboll",
    "squashbollarnas": "squashboll",
    "squashbollars": "squashboll",
    "squashbollen": "squashboll",
    "squashbollens": "squashboll",
    "squashbolls": "squashboll",
    "squashen": "squash",
    "squashens": "squash",
    "squasher": "squash",
    "squasherna": "squash",
    "squashernas": "squash",
    "squashers": "squash",
    "squashrackar": "squashrack",
    "squashrackarna": "squashrack",
    "squashrackarnas": "squashrack",
    "squashrackars": "squashrack",
    "squashracken": "squashrack",
    "squashrackens": "squashrack",
    "squashracket": "squashrack",
    "squashracketar": "squashracket",
    "squashracketarna": "squashracket",
    "squashracketarnas": "squashracket",
    "squashracketars": "squashracket",
    "squashracketen": "squashracket",
    "squashracketens": "squashracket",
    "squashrackets": "squashracket",
    "squashracks": "squashrack",
    "squashs": "squash",
    "squawer": "squaw",
    "squawerna": "squaw",
    "squawernas": "squaw",
    "squawers": "squaw",
    "squawn": "squaw",
    "squawns": "squaw",
    "squaws": "squaw",
    "srilankesen": "srilankes",
    "srilankesens": "srilankes",
    "srilankeser": "srilankes",
    "srilankeserna": "srilankes",
    "srilankesernas": "srilankes",
    "srilankesers": "srilankes",
    "srilankesiska": "srilankesisk",
    "srilankesiskan": "srilankesiska",
    "srilankesiskans": "srilankesiska",
    "srilankesiskare": "srilankesisk",
    "srilankesiskares": "srilankesisk",
    "srilankesiskas": "srilankesiska",
    "srilankesiskast": "srilankesisk",
    "srilankesiskaste": "srilankesisk",
    "srilankesiskastes": "srilankesisk",
    "srilankesiskasts": "srilankesisk",
    "srilankesiske": "srilankesiska",
    "srilankesiskes": "srilankesisk",
    "srilankesiskor": "srilankesiska",
    "srilankesiskorna": "srilankesiska",
    "srilankesiskornas": "srilankesiska",
    "srilankesiskors": "srilankesiska",
    "srilankesisks": "srilankesisk",
    "srilankesiskt": "srilankesisk",
    "srilankesiskts": "srilankesisk",
    "stabb": "stabbe",
    "stabbar": "stabbe",
    "stabbarna": "stabbe",
    "stabbarnas": "stabbe",
    "stabbars": "stabbe",
    "stabben": "stabbe",
    "stabbens": "stabbe",
    "stabbes": "stabbe",
    "stabbiga": "stabbig",
    "stabbigare": "stabbig",
    "stabbigares": "stabbig",
    "stabbigas": "stabbig",
    "stabbigast": "stabbig",
    "stabbigaste": "stabbig",
    "stabbigastes": "stabbig",
    "stabbigasts": "stabbig",
    "stabbige": "stabbig",
    "stabbiges": "stabbig",
    "stabbigheten": "stabbighet",
    "stabbighetens": "stabbighet",
    "stabbighets": "stabbighet",
    "stabbigs": "stabbig",
    "stabbigt": "stabbig",
    "stabbigts": "stabbig",
    "stabbs": "stabbe",
    "stabburar": "stabbur",
    "stabburarna": "stabbur",
    "stabburarnas": "stabbur",
    "stabburars": "stabbur",
    "stabburen": "stabbur",
    "stabburens": "stabbur",
    "stabburs": "stabbur",
    "staben": "stab",
    "stabens": "stab",
    "staber": "stab",
    "staberna": "stab",
    "stabernas": "stab",
    "stabers": "stab",
    "stabila": "stabil",
    "stabilare": "stabil",
    "stabilares": "stabil",
    "stabilas": "stabil",
    "stabilast": "stabil",
    "stabilaste": "stabil",
    "stabilastes": "stabil",
    "stabilasts": "stabil",
    "stabile": "stabil",
    "stabiles": "stabil",
    "stabilisatorer": "stabilisator",
    "stabilisatorerna": "stabilisator",
    "stabilisatorernas": "stabilisator",
    "stabilisatorers": "stabilisator",
    "stabilisatorn": "stabilisator",
    "stabilisatorns": "stabilisator",
    "stabilisators": "stabilisator",
    "stabiliserad": "stabilisera",
    "stabiliserade": "stabilisera",
    "stabiliserades": "stabilisera",
    "stabiliserads": "stabilisera",
    "stabiliserande": "stabilisera",
    "stabiliseranden": "stabiliserande",
    "stabiliserandena": "stabiliserande",
    "stabiliserandenas": "stabiliserande",
    "stabiliserandens": "stabiliserande",
    "stabiliserandes": "stabiliserande",
    "stabiliserandet": "stabiliserande",
    "stabiliserandets": "stabiliserande",
    "stabiliserar": "stabilisera",
    "stabiliseras": "stabilisera",
    "stabiliserat": "stabilisera",
    "stabiliserats": "stabilisera",
    "stabiliserbara": "stabiliserbar",
    "stabiliserbarare": "stabiliserbar",
    "stabiliserbarares": "stabiliserbar",
    "stabiliserbaras": "stabiliserbar",
    "stabiliserbarast": "stabiliserbar",
    "stabiliserbaraste": "stabiliserbar",
    "stabiliserbarastes": "stabiliserbar",
    "stabiliserbarasts": "stabiliserbar",
    "stabiliserbare": "stabiliserbar",
    "stabiliserbares": "stabiliserbar",
    "stabiliserbarheten": "stabiliserbarhet",
    "stabiliserbarhetens": "stabiliserbarhet",
    "stabiliserbarhets": "stabiliserbarhet",
    "stabiliserbars": "stabiliserbar",
    "stabiliserbart": "stabiliserbar",
    "stabiliserbarts": "stabiliserbar",
    "stabiliseringar": "stabilisering",
    "stabiliseringarna": "stabilisering",
    "stabiliseringarnas": "stabilisering",
    "stabiliseringars": "stabilisering",
    "stabiliseringen": "stabilisering",
    "stabiliseringens": "stabilisering",
    "stabiliserings": "stabilisering",
    "stabiliseringsfen": "stabiliseringsfena",
    "stabiliseringsfenan": "stabiliseringsfena",
    "stabiliseringsfenans": "stabiliseringsfena",
    "stabiliseringsfenas": "stabiliseringsfena",
    "stabiliseringsfene": "stabiliseringsfena",
    "stabiliseringsfenor": "stabiliseringsfena",
    "stabiliseringsfenorna": "stabiliseringsfena",
    "stabiliseringsfenornas": "stabiliseringsfena",
    "stabiliseringsfenors": "stabiliseringsfena",
    "stabiliseringsfens": "stabiliseringsfena",
    "stabiliseringsproblemen": "stabiliseringsproblem",
    "stabiliseringsproblemens": "stabiliseringsproblem",
    "stabiliseringsproblemet": "stabiliseringsproblem",
    "stabiliseringsproblemets": "stabiliseringsproblem",
    "stabiliseringsproblems": "stabiliseringsproblem",
    "stabiliteten": "stabilitet",
    "stabilitetens": "stabilitet",
    "stabiliteter": "stabilitet",
    "stabiliteterna": "stabilitet",
    "stabiliteternas": "stabilitet",
    "stabiliteters": "stabilitet",
    "stabilitets": "stabilitet",
    "stabilitetspakten": "stabilitetspakt",
    "stabilitetspaktens": "stabilitetspakt",
    "stabilitetspakter": "stabilitetspakt",
    "stabilitetspakterna": "stabilitetspakt",
    "stabilitetspakternas": "stabilitetspakt",
    "stabilitetspakters": "stabilitetspakt",
    "stabilitetspakts": "stabilitetspakt",
    "stabils": "stabil",
    "stabilt": "stabil",
    "stabilts": "stabil",
    "stabs": "stab",
    "stabschefen": "stabschef",
    "stabschefens": "stabschef",
    "stabschefer": "stabschef",
    "stabscheferna": "stabschef",
    "stabschefernas": "stabschef",
    "stabschefers": "stabschef",
    "stabschefs": "stabschef",
    "stabskart": "stabskarta",
    "stabskartan": "stabskarta",
    "stabskartans": "stabskarta",
    "stabskartas": "stabskarta",
    "stabskarte": "stabskarta",
    "stabskartor": "stabskarta",
    "stabskartorna": "stabskarta",
    "stabskartornas": "stabskarta",
    "stabskartors": "stabskarta",
    "stabskarts": "stabskarta",
    "stabsofficerare": "stabsofficer",
    "stabsofficerares": "stabsofficer",
    "stabsofficerarna": "stabsofficer",
    "stabsofficerarnas": "stabsofficer",
    "stabsofficeren": "stabsofficer",
    "stabsofficerens": "stabsofficer",
    "stabsofficern": "stabsofficer",
    "stabsofficerns": "stabsofficer",
    "stabsofficers": "stabsofficer",
    "stack": "sticka",
    "stackad": "stacka",
    "stackade": "stacka",
    "stackades": "stacka",
    "stackads": "stacka",
    "stackande": "stacka",
    "stackanden": "stackande",
    "stackandena": "stackande",
    "stackandenas": "stackande",
    "stackandens": "stackande",
    "stackandes": "stackande",
    "stackandet": "stackande",
    "stackandets": "stackande",
    "stackar": "stackare",
    "stackaren": "stackare",
    "stackarens": "stackare",
    "stackares": "stackare",
    "stackarna": "stackare",
    "stackarnas": "stackare",
    "stackars": "stack",
    "stackas": "stacka",
    "stackat": "stacka",
    "stackaton": "stackato",
    "stackatona": "stackato",
    "stackatonas": "stackato",
    "stackatons": "stackato",
    "stackatos": "stackato",
    "stackatot": "stackato",
    "stackatots": "stackato",
    "stackats": "stacka",
    "stacken": "stack",
    "stackens": "stack",
    "stackmolnen": "stackmoln",
    "stackmolnens": "stackmoln",
    "stackmolnet": "stackmoln",
    "stackmolnets": "stackmoln",
    "stackmolns": "stackmoln",
    "stackmyr": "stackmyra",
    "stackmyran": "stackmyra",
    "stackmyrans": "stackmyra",
    "stackmyras": "stackmyra",
    "stackmyre": "stackmyra",
    "stackmyror": "stackmyra",
    "stackmyrorna": "stackmyra",
    "stackmyrornas": "stackmyra",
    "stackmyrors": "stackmyra",
    "stackmyrs": "stackmyra",
    "stacks": "sticka",
    "stadd": "städja",
    "stadda": "städja",
    "staddas": "städja",
    "stadde": "städja",
    "staddes": "städja",
    "stadds": "städja",
    "staden": "stad",
    "stadens": "stad",
    "stadfäst": "stadfästa",
    "stadfästande": "stadfästa",
    "stadfästanden": "stadfästande",
    "stadfästandena": "stadfästande",
    "stadfästandenas": "stadfästande",
    "stadfästandens": "stadfästande",
    "stadfästandes": "stadfästande",
    "stadfästandet": "stadfästande",
    "stadfästandets": "stadfästande",
    "stadfästas": "stadfästa",
    "stadfäste": "stadfästa",
    "stadfäster": "stadfästa",
    "stadfästes": "stadfästa",
    "stadfästs": "stadfästa",
    "stadgad": "stadga",
    "stadgade": "stadgad",
    "stadgades": "stadgad",
    "stadgads": "stadgad",
    "stadgan": "stadga",
    "stadgande": "stadga",
    "stadganden": "stadgande",
    "stadgandena": "stadgande",
    "stadgandenas": "stadgande",
    "stadgandens": "stadgande",
    "stadgandes": "stadgande",
    "stadgandet": "stadgande",
    "stadgandets": "stadgande",
    "stadgans": "stadga",
    "stadgar": "stadga",
    "stadgarna": "stadgar",
    "stadgarnas": "stadgar",
    "stadgars": "stadgar",
    "stadgas": "stadga",
    "stadgat": "stadgad",
    "stadgats": "stadgad",
    "stadge": "stadgar",
    "stadgemässiga": "stadgemässig",
    "stadgemässigare": "stadgemässig",
    "stadgemässigares": "stadgemässig",
    "stadgemässigas": "stadgemässig",
    "stadgemässigast": "stadgemässig",
    "stadgemässigaste": "stadgemässig",
    "stadgemässigastes": "stadgemässig",
    "stadgemässigasts": "stadgemässig",
    "stadgemässige": "stadgemässig",
    "stadgemässiges": "stadgemässig",
    "stadgemässigs": "stadgemässig",
    "stadgemässigt": "stadgemässig",
    "stadgemässigts": "stadgemässig",
    "stadgor": "stadga",
    "stadgorna": "stadga",
    "stadgornas": "stadga",
    "stadgors": "stadga",
    "stadie": "stadium",
    "stadier": "stadium",
    "stadierna": "stadium",
    "stadiernas": "stadium",
    "stadiers": "stadium",
    "stadiet": "stadium",
    "stadiets": "stadium",
    "stadiga": "stadig",
    "stadigare": "stadig",
    "stadigares": "stadig",
    "stadigas": "stadig",
    "stadigast": "stadig",
    "stadigaste": "stadig",
    "stadigastes": "stadig",
    "stadigasts": "stadig",
    "stadige": "stadig",
    "stadiges": "stadig",
    "stadigs": "stadig",
    "stadigt": "stadig",
    "stadigts": "stadig",
    "stadionen": "stadion",
    "stadionens": "stadion",
    "stadionet": "stadion",
    "stadionets": "stadion",
    "stadions": "stadion",
    "stadiontutan": "stadiontuta",
    "stadiontutans": "stadiontuta",
    "stadiontutas": "stadiontuta",
    "stadiontute": "stadiontuta",
    "stadiontutor": "stadiontuta",
    "stadiontutorna": "stadiontuta",
    "stadiontutornas": "stadiontuta",
    "stadiontutors": "stadiontuta",
    "stadium": "stadion",
    "stadiums": "stadium",
    "stadkanten": "stadkant",
    "stadkantens": "stadkant",
    "stadkanter": "stadkant",
    "stadkanterna": "stadkant",
    "stadkanternas": "stadkant",
    "stadkanters": "stadkant",
    "stadkants": "stadkant",
    "stadnen": "stadion",
    "stadnens": "stadion",
    "stadnet": "stadion",
    "stadnets": "stadion",
    "stads": "stad",
    "stadsarkitekten": "stadsarkitekt",
    "stadsarkitektens": "stadsarkitekt",
    "stadsarkitekter": "stadsarkitekt",
    "stadsarkitekterna": "stadsarkitekt",
    "stadsarkitekternas": "stadsarkitekt",
    "stadsarkitekters": "stadsarkitekt",
    "stadsarkitekts": "stadsarkitekt",
    "stadsarkiven": "stadsarkiv",
    "stadsarkivens": "stadsarkiv",
    "stadsarkivet": "stadsarkiv",
    "stadsarkivets": "stadsarkiv",
    "stadsarkivs": "stadsarkiv",
    "stadsbebyggelsen": "stadsbebyggelse",
    "stadsbebyggelsens": "stadsbebyggelse",
    "stadsbebyggelser": "stadsbebyggelse",
    "stadsbebyggelserna": "stadsbebyggelse",
    "stadsbebyggelsernas": "stadsbebyggelse",
    "stadsbebyggelsers": "stadsbebyggelse",
    "stadsbebyggelses": "stadsbebyggelse",
    "stadsbesöken": "stadsbesök",
    "stadsbesökens": "stadsbesök",
    "stadsbesöket": "stadsbesök",
    "stadsbesökets": "stadsbesök",
    "stadsbesöks": "stadsbesök",
    "stadsbiblioteken": "stadsbibliotek",
    "stadsbibliotekens": "stadsbibliotek",
    "stadsbiblioteket": "stadsbibliotek",
    "stadsbibliotekets": "stadsbibliotek",
    "stadsbiblioteks": "stadsbibliotek",
    "stadsbilden": "stadsbild",
    "stadsbildens": "stadsbild",
    "stadsbilder": "stadsbild",
    "stadsbilderna": "stadsbild",
    "stadsbildernas": "stadsbild",
    "stadsbilders": "stadsbild",
    "stadsbildmässiga": "stadsbildmässig",
    "stadsbildmässigare": "stadsbildmässig",
    "stadsbildmässigares": "stadsbildmässig",
    "stadsbildmässigas": "stadsbildmässig",
    "stadsbildmässigast": "stadsbildmässig",
    "stadsbildmässigaste": "stadsbildmässig",
    "stadsbildmässigastes": "stadsbildmässig",
    "stadsbildmässigasts": "stadsbildmässig",
    "stadsbildmässige": "stadsbildmässig",
    "stadsbildmässiges": "stadsbildmässig",
    "stadsbildmässigs": "stadsbildmässig",
    "stadsbildmässigt": "stadsbildmässig",
    "stadsbildmässigts": "stadsbildmässig",
    "stadsbilds": "stadsbild",
    "stadsbildsmässiga": "stadsbildsmässig",
    "stadsbildsmässigare": "stadsbildsmässig",
    "stadsbildsmässigares": "stadsbildsmässig",
    "stadsbildsmässigas": "stadsbildsmässig",
    "stadsbildsmässigast": "stadsbildsmässig",
    "stadsbildsmässigaste": "stadsbildsmässig",
    "stadsbildsmässigastes": "stadsbildsmässig",
    "stadsbildsmässigasts": "stadsbildsmässig",
    "stadsbildsmässige": "stadsbildsmässig",
    "stadsbildsmässiges": "stadsbildsmässig",
    "stadsbildsmässigs": "stadsbildsmässig",
    "stadsbildsmässigt": "stadsbildsmässig",
    "stadsbildsmässigts": "stadsbildsmässig",
    "stadsbon": "stadsbo",
    "stadsbons": "stadsbo",
    "stadsbor": "stadsbo",
    "stadsborna": "stadsbo",
    "stadsbornas": "stadsbo",
    "stadsbors": "stadsbo",
    "stadsbos": "stadsbo",
    "stadsbuden": "stadsbud",
    "stadsbudens": "stadsbud",
    "stadsbudet": "stadsbud",
    "stadsbudets": "stadsbud",
    "stadsbuds": "stadsbud",
    "stadsbussar": "stadsbuss",
    "stadsbussarna": "stadsbuss",
    "stadsbussarnas": "stadsbuss",
    "stadsbussars": "stadsbuss",
    "stadsbussen": "stadsbuss",
    "stadsbussens": "stadsbuss",
    "stadsbyggnaden": "stadsbyggnad",
    "stadsbyggnadens": "stadsbyggnad",
    "stadsbyggnads": "stadsbyggnad",
    "stadsbyggnadsmässiga": "stadsbyggnadsmässig",
    "stadsbyggnadsmässigare": "stadsbyggnadsmässig",
    "stadsbyggnadsmässigares": "stadsbyggnadsmässig",
    "stadsbyggnadsmässigas": "stadsbyggnadsmässig",
    "stadsbyggnadsmässigast": "stadsbyggnadsmässig",
    "stadsbyggnadsmässigaste": "stadsbyggnadsmässig",
    "stadsbyggnadsmässigastes": "stadsbyggnadsmässig",
    "stadsbyggnadsmässigasts": "stadsbyggnadsmässig",
    "stadsbyggnadsmässige": "stadsbyggnadsmässig",
    "stadsbyggnadsmässiges": "stadsbyggnadsmässig",
    "stadsbyggnadsmässigs": "stadsbyggnadsmässig",
    "stadsbyggnadsmässigt": "stadsbyggnadsmässig",
    "stadsbyggnadsmässigts": "stadsbyggnadsmässig",
    "stadsdelar": "stadsdel",
    "stadsdelarna": "stadsdel",
    "stadsdelarnas": "stadsdel",
    "stadsdelars": "stadsdel",
    "stadsdelen": "stadsdel",
    "stadsdelens": "stadsdel",
    "stadsdels": "stadsdel",
    "stadsdressar": "stadsdress",
    "stadsdressarna": "stadsdress",
    "stadsdressarnas": "stadsdress",
    "stadsdressars": "stadsdress",
    "stadsdressen": "stadsdress",
    "stadsdressens": "stadsdress",
    "stadsdresser": "stadsdress",
    "stadsdresserna": "stadsdress",
    "stadsdressernas": "stadsdress",
    "stadsdressers": "stadsdress",
    "stadsfullmäktige": "stadsfullmäktig",
    "stadsfullmäktigen": "stadsfullmäktig",
    "stadsfullmäktigena": "stadsfullmäktig",
    "stadsfullmäktigenas": "stadsfullmäktig",
    "stadsfullmäktigens": "stadsfullmäktig",
    "stadsfullmäktiges": "stadsfullmäktig",
    "stadsfullmäktigs": "stadsfullmäktig",
    "stadsgasen": "stadsgas",
    "stadsgasens": "stadsgas",
    "stadshotellen": "stadshotell",
    "stadshotellens": "stadshotell",
    "stadshotellet": "stadshotell",
    "stadshotellets": "stadshotell",
    "stadshotells": "stadshotell",
    "stadshusen": "stadshus",
    "stadshusens": "stadshus",
    "stadshuset": "stadshus",
    "stadshusets": "stadshus",
    "stadsjeepar": "stadsjeep",
    "stadsjeeparna": "stadsjeep",
    "stadsjeeparnas": "stadsjeep",
    "stadsjeepars": "stadsjeep",
    "stadsjeepen": "stadsjeep",
    "stadsjeepens": "stadsjeep",
    "stadsjeeps": "stadsjeep",
    "stadsjeepägar": "stadsjeepägare",
    "stadsjeepägaren": "stadsjeepägare",
    "stadsjeepägarens": "stadsjeepägare",
    "stadsjeepägares": "stadsjeepägare",
    "stadsjeepägarna": "stadsjeepägare",
    "stadsjeepägarnas": "stadsjeepägare",
    "stadskläderna": "stadskläder",
    "stadsklädernas": "stadskläder",
    "stadskläders": "stadskläder",
    "stadsklädes": "stadskläder",
    "stadskläds": "stadskläder",
    "stadskärn": "stadskärna",
    "stadskärnan": "stadskärna",
    "stadskärnans": "stadskärna",
    "stadskärnas": "stadskärna",
    "stadskärne": "stadskärna",
    "stadskärnor": "stadskärna",
    "stadskärnorna": "stadskärna",
    "stadskärnornas": "stadskärna",
    "stadskärnors": "stadskärna",
    "stadskärns": "stadskärna",
    "stadslivet": "stadsliv",
    "stadslivets": "stadsliv",
    "stadslivs": "stadsliv",
    "stadsmiljöer": "stadsmiljö",
    "stadsmiljöerna": "stadsmiljö",
    "stadsmiljöernas": "stadsmiljö",
    "stadsmiljöers": "stadsmiljö",
    "stadsmiljömässiga": "stadsmiljömässig",
    "stadsmiljömässigare": "stadsmiljömässig",
    "stadsmiljömässigares": "stadsmiljömässig",
    "stadsmiljömässigas": "stadsmiljömässig",
    "stadsmiljömässigast": "stadsmiljömässig",
    "stadsmiljömässigaste": "stadsmiljömässig",
    "stadsmiljömässigastes": "stadsmiljömässig",
    "stadsmiljömässigasts": "stadsmiljömässig",
    "stadsmiljömässige": "stadsmiljömässig",
    "stadsmiljömässiges": "stadsmiljömässig",
    "stadsmiljömässigs": "stadsmiljömässig",
    "stadsmiljömässigt": "stadsmiljömässig",
    "stadsmiljömässigts": "stadsmiljömässig",
    "stadsmiljön": "stadsmiljö",
    "stadsmiljöns": "stadsmiljö",
    "stadsmiljös": "stadsmiljö",
    "stadsmissionen": "stadsmission",
    "stadsmissionens": "stadsmission",
    "stadsmissioner": "stadsmission",
    "stadsmissionerna": "stadsmission",
    "stadsmissionernas": "stadsmission",
    "stadsmissioners": "stadsmission",
    "stadsmissions": "stadsmission",
    "stadsmurar": "stadsmur",
    "stadsmurarna": "stadsmur",
    "stadsmurarnas": "stadsmur",
    "stadsmurars": "stadsmur",
    "stadsmuren": "stadsmur",
    "stadsmurens": "stadsmur",
    "stadsmurs": "stadsmur",
    "stadsmässiga": "stadsmässig",
    "stadsmässigare": "stadsmässig",
    "stadsmässigares": "stadsmässig",
    "stadsmässigas": "stadsmässig",
    "stadsmässigast": "stadsmässig",
    "stadsmässigaste": "stadsmässig",
    "stadsmässigastes": "stadsmässig",
    "stadsmässigasts": "stadsmässig",
    "stadsmässige": "stadsmässig",
    "stadsmässiges": "stadsmässig",
    "stadsmässigs": "stadsmässig",
    "stadsmässigt": "stadsmässig",
    "stadsmässigts": "stadsmässig",
    "stadsplane": "stadsplan",
    "stadsplanekontoren": "stadsplanekontor",
    "stadsplanekontorens": "stadsplanekontor",
    "stadsplanekontoret": "stadsplanekontor",
    "stadsplanekontorets": "stadsplanekontor",
    "stadsplanekontors": "stadsplanekontor",
    "stadsplanemässiga": "stadsplanemässig",
    "stadsplanemässigare": "stadsplanemässig",
    "stadsplanemässigares": "stadsplanemässig",
    "stadsplanemässigas": "stadsplanemässig",
    "stadsplanemässigast": "stadsplanemässig",
    "stadsplanemässigaste": "stadsplanemässig",
    "stadsplanemässigastes": "stadsplanemässig",
    "stadsplanemässigasts": "stadsplanemässig",
    "stadsplanemässige": "stadsplanemässig",
    "stadsplanemässiges": "stadsplanemässig",
    "stadsplanemässigs": "stadsplanemässig",
    "stadsplanemässigt": "stadsplanemässig",
    "stadsplanemässigts": "stadsplanemässig",
    "stadsplanen": "stadsplan",
    "stadsplanens": "stadsplan",
    "stadsplaner": "stadsplan",
    "stadsplanerad": "stadsplanera",
    "stadsplanerade": "stadsplanera",
    "stadsplanerades": "stadsplanera",
    "stadsplanerads": "stadsplanera",
    "stadsplanerande": "stadsplanera",
    "stadsplaneranden": "stadsplanerande",
    "stadsplanerandena": "stadsplanerande",
    "stadsplanerandenas": "stadsplanerande",
    "stadsplanerandens": "stadsplanerande",
    "stadsplanerandes": "stadsplanerande",
    "stadsplanerandet": "stadsplanerande",
    "stadsplanerandets": "stadsplanerande",
    "stadsplanerar": "stadsplanera",
    "stadsplaneras": "stadsplanera",
    "stadsplanerat": "stadsplanera",
    "stadsplanerats": "stadsplanera",
    "stadsplanerbara": "stadsplanerbar",
    "stadsplanerbarare": "stadsplanerbar",
    "stadsplanerbarares": "stadsplanerbar",
    "stadsplanerbaras": "stadsplanerbar",
    "stadsplanerbarast": "stadsplanerbar",
    "stadsplanerbaraste": "stadsplanerbar",
    "stadsplanerbarastes": "stadsplanerbar",
    "stadsplanerbarasts": "stadsplanerbar",
    "stadsplanerbare": "stadsplanerbar",
    "stadsplanerbares": "stadsplanerbar",
    "stadsplanerbarheten": "stadsplanerbarhet",
    "stadsplanerbarhetens": "stadsplanerbarhet",
    "stadsplanerbarhets": "stadsplanerbarhet",
    "stadsplanerbars": "stadsplanerbar",
    "stadsplanerbart": "stadsplanerbar",
    "stadsplanerbarts": "stadsplanerbar",
    "stadsplaneringar": "stadsplanering",
    "stadsplaneringarna": "stadsplanering",
    "stadsplaneringarnas": "stadsplanering",
    "stadsplaneringars": "stadsplanering",
    "stadsplaneringen": "stadsplanering",
    "stadsplaneringens": "stadsplanering",
    "stadsplanerings": "stadsplanering",
    "stadsplanerna": "stadsplan",
    "stadsplanernas": "stadsplan",
    "stadsplaners": "stadsplan",
    "stadsplans": "stadsplan",
    "stadsportar": "stadsport",
    "stadsportarna": "stadsport",
    "stadsportarnas": "stadsport",
    "stadsportars": "stadsport",
    "stadsporten": "stadsport",
    "stadsportens": "stadsport",
    "stadsports": "stadsport",
    "stadsprivilegie": "stadsprivilegier",
    "stadsprivilegierna": "stadsprivilegier",
    "stadsprivilegiernas": "stadsprivilegier",
    "stadsprivilegiers": "stadsprivilegier",
    "stadsresan": "stadsresa",
    "stadsresans": "stadsresa",
    "stadsresas": "stadsresa",
    "stadsrese": "stadsresa",
    "stadsresor": "stadsresa",
    "stadsresorna": "stadsresa",
    "stadsresornas": "stadsresa",
    "stadsresors": "stadsresa",
    "stadsrättigheterna": "stadsrättigheter",
    "stadsrättigheternas": "stadsrättigheter",
    "stadsrättigheters": "stadsrättigheter",
    "stadsrättighets": "stadsrättigheter",
    "stadssekreterar": "stadssekreterare",
    "stadssekreteraren": "stadssekreterare",
    "stadssekreterarens": "stadssekreterare",
    "stadssekreterares": "stadssekreterare",
    "stadssekreterarna": "stadssekreterare",
    "stadssekreterarnas": "stadssekreterare",
    "stadsskogar": "stadsskog",
    "stadsskogarna": "stadsskog",
    "stadsskogarnas": "stadsskog",
    "stadsskogars": "stadsskog",
    "stadsskogen": "stadsskog",
    "stadsskogens": "stadsskog",
    "stadsskogs": "stadsskog",
    "stadsstaten": "stadsstat",
    "stadsstatens": "stadsstat",
    "stadsstater": "stadsstat",
    "stadsstaterna": "stadsstat",
    "stadsstaternas": "stadsstat",
    "stadsstaters": "stadsstat",
    "stadsstats": "stadsstat",
    "stadsteatern": "stadsteater",
    "stadsteaterns": "stadsteater",
    "stadsteaters": "stadsteater",
    "stadsteatrar": "stadsteater",
    "stadsteatrarna": "stadsteater",
    "stadsteatrarnas": "stadsteater",
    "stadsteatrars": "stadsteater",
    "stadvänd": "stadvända",
    "stadvändande": "stadvända",
    "stadvändanden": "stadvändande",
    "stadvändandena": "stadvändande",
    "stadvändandenas": "stadvändande",
    "stadvändandens": "stadvändande",
    "stadvändandes": "stadvändande",
    "stadvändandet": "stadvändande",
    "stadvändandets": "stadvändande",
    "stadvändas": "stadvända",
    "stadvände": "stadvända",
    "stadvänder": "stadvända",
    "stadvändes": "stadvända",
    "stadvänds": "stadvända",
    "stadvänt": "stadvända",
    "stadvänts": "stadvända",
    "stafetten": "stafett",
    "stafettens": "stafett",
    "stafetter": "stafett",
    "stafetterna": "stafett",
    "stafetternas": "stafett",
    "stafetters": "stafett",
    "stafettläkar": "stafettläkare",
    "stafettläkaren": "stafettläkare",
    "stafettläkarens": "stafettläkare",
    "stafettläkares": "stafettläkare",
    "stafettläkarna": "stafettläkare",
    "stafettläkarnas": "stafettläkare",
    "stafettlöpningar": "stafettlöpning",
    "stafettlöpningarna": "stafettlöpning",
    "stafettlöpningarnas": "stafettlöpning",
    "stafettlöpningars": "stafettlöpning",
    "stafettlöpningen": "stafettlöpning",
    "stafettlöpningens": "stafettlöpning",
    "stafettlöpnings": "stafettlöpning",
    "stafetts": "stafett",
    "staffagefiguren": "staffagefigur",
    "staffagefigurens": "staffagefigur",
    "staffagefigurer": "staffagefigur",
    "staffagefigurerna": "staffagefigur",
    "staffagefigurernas": "staffagefigur",
    "staffagefigurers": "staffagefigur",
    "staffagefigurs": "staffagefigur",
    "staffages": "staffage",
    "staffaget": "staffage",
    "staffagets": "staffage",
    "stafferad": "staffera",
    "stafferade": "staffera",
    "stafferades": "staffera",
    "stafferads": "staffera",
    "stafferande": "staffera",
    "stafferanden": "stafferande",
    "stafferandena": "stafferande",
    "stafferandenas": "stafferande",
    "stafferandens": "stafferande",
    "stafferandes": "stafferande",
    "stafferandet": "stafferande",
    "stafferandets": "stafferande",
    "stafferar": "staffera",
    "stafferas": "staffera",
    "stafferat": "staffera",
    "stafferats": "staffera",
    "stafferbara": "stafferbar",
    "stafferbarare": "stafferbar",
    "stafferbarares": "stafferbar",
    "stafferbaras": "stafferbar",
    "stafferbarast": "stafferbar",
    "stafferbaraste": "stafferbar",
    "stafferbarastes": "stafferbar",
    "stafferbarasts": "stafferbar",
    "stafferbare": "stafferbar",
    "stafferbares": "stafferbar",
    "stafferbarheten": "stafferbarhet",
    "stafferbarhetens": "stafferbarhet",
    "stafferbarhets": "stafferbarhet",
    "stafferbars": "stafferbar",
    "stafferbart": "stafferbar",
    "stafferbarts": "stafferbar",
    "stafferingar": "staffering",
    "stafferingarna": "staffering",
    "stafferingarnas": "staffering",
    "stafferingars": "staffering",
    "stafferingen": "staffering",
    "stafferingens": "staffering",
    "stafferings": "staffering",
    "stafflier": "staffli",
    "stafflierna": "staffli",
    "staffliernas": "staffli",
    "staffliers": "staffli",
    "staffliet": "staffli",
    "staffliets": "staffli",
    "stafflimålningar": "stafflimålning",
    "stafflimålningarna": "stafflimålning",
    "stafflimålningarnas": "stafflimålning",
    "stafflimålningars": "stafflimålning",
    "stafflimålningen": "stafflimålning",
    "stafflimålningens": "stafflimålning",
    "stafflimålnings": "stafflimålning",
    "stafflin": "staffli",
    "stafflina": "staffli",
    "stafflinas": "staffli",
    "stafflins": "staffli",
    "stafflis": "staffli",
    "stafflit": "staffli",
    "stafflits": "staffli",
    "stafylokocken": "stafylokock",
    "stafylokockens": "stafylokock",
    "stafylokocker": "stafylokock",
    "stafylokockerna": "stafylokock",
    "stafylokockernas": "stafylokock",
    "stafylokockers": "stafylokock",
    "stafylokocks": "stafylokock",
    "stag": "staga",
    "stagad": "staga",
    "stagade": "staga",
    "stagades": "staga",
    "stagads": "staga",
    "stagande": "staga",
    "staganden": "stagande",
    "stagandena": "stagande",
    "stagandenas": "stagande",
    "stagandens": "stagande",
    "stagandes": "stagande",
    "stagandet": "stagande",
    "stagandets": "stagande",
    "stagar": "staga",
    "stagas": "staga",
    "stagat": "staga",
    "stagats": "staga",
    "stagen": "stag",
    "stagens": "stag",
    "staget": "stag",
    "stagets": "stag",
    "stagflationen": "stagflation",
    "stagflationens": "stagflation",
    "stagflationer": "stagflation",
    "stagflationerna": "stagflation",
    "stagflationernas": "stagflation",
    "stagflationers": "stagflation",
    "stagflations": "stagflation",
    "staggar": "stagg",
    "staggarna": "stagg",
    "staggarnas": "stagg",
    "staggars": "stagg",
    "staggen": "stagg",
    "staggens": "stagg",
    "staggs": "stagg",
    "stagnationen": "stagnation",
    "stagnationens": "stagnation",
    "stagnationer": "stagnation",
    "stagnationerna": "stagnation",
    "stagnationernas": "stagnation",
    "stagnationers": "stagnation",
    "stagnations": "stagnation",
    "stagnerad": "stagnera",
    "stagnerade": "stagnera",
    "stagnerades": "stagnera",
    "stagnerads": "stagnera",
    "stagnerande": "stagnera",
    "stagneranden": "stagnerande",
    "stagnerandena": "stagnerande",
    "stagnerandenas": "stagnerande",
    "stagnerandens": "stagnerande",
    "stagnerandes": "stagnerande",
    "stagnerandet": "stagnerande",
    "stagnerandets": "stagnerande",
    "stagnerar": "stagnera",
    "stagneras": "stagnera",
    "stagnerat": "stagnera",
    "stagnerats": "stagnera",
    "stagneringar": "stagnering",
    "stagneringarna": "stagnering",
    "stagneringarnas": "stagnering",
    "stagneringars": "stagnering",
    "stagneringen": "stagnering",
    "stagneringens": "stagnering",
    "stagnerings": "stagnering",
    "stags": "stag",
    "stagsegels": "stagsegel",
    "stagseglen": "stagsegel",
    "stagseglens": "stagsegel",
    "stagseglet": "stagsegel",
    "stagseglets": "stagsegel",
    "stagvänd": "stagvända",
    "stagvändande": "stagvända",
    "stagvändanden": "stagvändande",
    "stagvändandena": "stagvändande",
    "stagvändandenas": "stagvändande",
    "stagvändandens": "stagvändande",
    "stagvändandes": "stagvändande",
    "stagvändandet": "stagvändande",
    "stagvändandets": "stagvändande",
    "stagvändas": "stagvända",
    "stagvände": "stagvända",
    "stagvänder": "stagvända",
    "stagvändes": "stagvända",
    "stagvänds": "stagvända",
    "stagvänt": "stagvända",
    "stagvänts": "stagvända",
    "stak": "stake",
    "stakad": "staka",
    "stakade": "staka",
    "stakades": "staka",
    "stakads": "staka",
    "stakande": "staka",
    "stakanden": "stakande",
    "stakandena": "stakande",
    "stakandenas": "stakande",
    "stakandens": "stakande",
    "stakandes": "stakande",
    "stakandet": "stakande",
    "stakandets": "stakande",
    "stakar": "stake",
    "stakarna": "stake",
    "stakarnas": "stake",
    "stakars": "stake",
    "stakas": "staka",
    "stakat": "staka",
    "stakats": "staka",
    "staken": "stake",
    "stakens": "stake",
    "stakes": "stake",
    "staketen": "staket",
    "staketens": "staket",
    "staketet": "staket",
    "staketets": "staket",
    "stakets": "staket",
    "staketstolpeen": "staketstolpe",
    "staketstolpeens": "staketstolpe",
    "staketstolpeet": "staketstolpe",
    "staketstolpeets": "staketstolpe",
    "staketstolpes": "staketstolpe",
    "staks": "stake",
    "stal": "stjäla",
    "stalagmiten": "stalagmit",
    "stalagmitens": "stalagmit",
    "stalagmiter": "stalagmit",
    "stalagmiterna": "stalagmit",
    "stalagmiternas": "stalagmit",
    "stalagmiters": "stalagmit",
    "stalagmits": "stalagmit",
    "stalaktiten": "stalaktit",
    "stalaktitens": "stalaktit",
    "stalaktiter": "stalaktit",
    "stalaktiterna": "stalaktit",
    "stalaktiternas": "stalaktit",
    "stalaktiters": "stalaktit",
    "stalaktits": "stalaktit",
    "stalinismen": "stalinism",
    "stalinismens": "stalinism",
    "stalinismer": "stalinism",
    "stalinismerna": "stalinism",
    "stalinismernas": "stalinism",
    "stalinismers": "stalinism",
    "stalinisms": "stalinism",
    "stalinisten": "stalinist",
    "stalinistens": "stalinist",
    "stalinister": "stalinist",
    "stalinisterna": "stalinist",
    "stalinisternas": "stalinist",
    "stalinisters": "stalinist",
    "stalinistiska": "stalinistisk",
    "stalinistiskare": "stalinistisk",
    "stalinistiskares": "stalinistisk",
    "stalinistiskas": "stalinistisk",
    "stalinistiskast": "stalinistisk",
    "stalinistiskaste": "stalinistisk",
    "stalinistiskastes": "stalinistisk",
    "stalinistiskasts": "stalinistisk",
    "stalinistiske": "stalinistisk",
    "stalinistiskes": "stalinistisk",
    "stalinistisks": "stalinistisk",
    "stalinistiskt": "stalinistisk",
    "stalinistiskts": "stalinistisk",
    "stalinists": "stalinist",
    "stalkad": "stalka",
    "stalkade": "stalka",
    "stalkades": "stalka",
    "stalkads": "stalka",
    "stalkande": "stalka",
    "stalkanden": "stalkande",
    "stalkandena": "stalkande",
    "stalkandenas": "stalkande",
    "stalkandens": "stalkande",
    "stalkandes": "stalkande",
    "stalkandet": "stalkande",
    "stalkandets": "stalkande",
    "stalkar": "stalkare",
    "stalkaren": "stalkare",
    "stalkarens": "stalkare",
    "stalkares": "stalkare",
    "stalkarna": "stalkare",
    "stalkarnas": "stalkare",
    "stalkas": "stalka",
    "stalkat": "stalka",
    "stalkats": "stalka",
    "stalkern": "stalker",
    "stalkerns": "stalker",
    "stalkers": "stalker",
    "stalkersarna": "stalker",
    "stalkersarnas": "stalker",
    "stalkersen": "stalker",
    "stalkersens": "stalker",
    "stalkingen": "stalking",
    "stalkingens": "stalking",
    "stalkings": "stalking",
    "stalkningen": "stalkning",
    "stalkningens": "stalkning",
    "stalknings": "stalkning",
    "stalkrar": "stalker",
    "stalkrarna": "stalker",
    "stalkrarnas": "stalker",
    "stalkrars": "stalker",
    "stall": "stalla",
    "stallad": "stalla",
    "stallade": "stalla",
    "stallades": "stalla",
    "stallads": "stalla",
    "stallande": "stalla",
    "stallanden": "stallande",
    "stallandena": "stallande",
    "stallandenas": "stallande",
    "stallandens": "stallande",
    "stallandes": "stallande",
    "stallandet": "stallande",
    "stallandets": "stallande",
    "stallar": "stalla",
    "stallarna": "stall",
    "stallarnas": "stall",
    "stallars": "stall",
    "stallas": "stalla",
    "stallat": "stalla",
    "stallats": "stalla",
    "stallback": "stallbacke",
    "stallbackar": "stallbacke",
    "stallbackarna": "stallbacke",
    "stallbackarnas": "stallbacke",
    "stallbackars": "stallbacke",
    "stallbacken": "stallbacke",
    "stallbackens": "stallbacke",
    "stallbackes": "stallbacke",
    "stallbacks": "stallbacke",
    "stallbrodern": "stallbroder",
    "stallbroderns": "stallbroder",
    "stallbroders": "stallbroder",
    "stallbröder": "stallbroder",
    "stallbröderna": "stallbroder",
    "stallbrödernas": "stallbroder",
    "stallbröders": "stallbroder",
    "stallen": "stall",
    "stallens": "stall",
    "stallet": "stall",
    "stallets": "stall",
    "stallknektar": "stallknekt",
    "stallknektarna": "stallknekt",
    "stallknektarnas": "stallknekt",
    "stallknektars": "stallknekt",
    "stallknekten": "stallknekt",
    "stallknektens": "stallknekt",
    "stallknekts": "stallknekt",
    "stalls": "stall",
    "stalltipsen": "stalltips",
    "stalltipsens": "stalltips",
    "stalltipset": "stalltips",
    "stalltipsets": "stalltips",
    "stallykt": "stallykta",
    "stallyktan": "stallykta",
    "stallyktans": "stallykta",
    "stallyktas": "stallykta",
    "stallykte": "stallykta",
    "stallyktor": "stallykta",
    "stallyktorna": "stallykta",
    "stallyktornas": "stallykta",
    "stallyktors": "stallykta",
    "stallykts": "stallykta",
    "stals": "stjäla",
    "stamaktien": "stamaktie",
    "stamaktiens": "stamaktie",
    "stamaktier": "stamaktie",
    "stamaktierna": "stamaktie",
    "stamaktiernas": "stamaktie",
    "stamaktiers": "stamaktie",
    "stamakties": "stamaktie",
    "stamanställde": "stamanställd",
    "stamanställdes": "stamanställd",
    "stamanställds": "stamanställd",
    "stamanställt": "stamanställd",
    "stamanställts": "stamanställd",
    "stambanan": "stambana",
    "stambanans": "stambana",
    "stambanas": "stambana",
    "stambane": "stambana",
    "stambanor": "stambana",
    "stambanorna": "stambana",
    "stambanornas": "stambana",
    "stambanors": "stambana",
    "stamboken": "stambok",
    "stambokens": "stambok",
    "stamboks": "stambok",
    "stamborden": "stambord",
    "stambordens": "stambord",
    "stambordet": "stambord",
    "stambordets": "stambord",
    "stambords": "stambord",
    "stamböcker": "stambok",
    "stamböckerna": "stambok",
    "stamböckernas": "stambok",
    "stamböckers": "stambok",
    "stamcellen": "stamcell",
    "stamcellens": "stamcell",
    "stamceller": "stamcell",
    "stamcellerna": "stamcell",
    "stamcellernas": "stamcell",
    "stamcellers": "stamcell",
    "stamcells": "stamcell",
    "stamfader": "stamfar",
    "stamfadern": "stamfar",
    "stamfaderns": "stamfar",
    "stamfaders": "stamfar",
    "stamfars": "stamfar",
    "stamfasder": "stamfar",
    "stamfäder": "stamfar",
    "stamfäderna": "stamfar",
    "stamfädernas": "stamfar",
    "stamfäders": "stamfar",
    "stamgästen": "stamgäst",
    "stamgästens": "stamgäst",
    "stamgäster": "stamgäst",
    "stamgästerna": "stamgäst",
    "stamgästernas": "stamgäst",
    "stamgästers": "stamgäst",
    "stamgästs": "stamgäst",
    "stamhövdingar": "stamhövding",
    "stamhövdingarna": "stamhövding",
    "stamhövdingarnas": "stamhövding",
    "stamhövdingars": "stamhövding",
    "stamhövdingen": "stamhövding",
    "stamhövdingens": "stamhövding",
    "stamhövdings": "stamhövding",
    "stamkrigar": "stamkrigare",
    "stamkrigaren": "stamkrigare",
    "stamkrigarens": "stamkrigare",
    "stamkrigares": "stamkrigare",
    "stamkrigarna": "stamkrigare",
    "stamkrigarnas": "stamkrigare",
    "stamkunden": "stamkund",
    "stamkundens": "stamkund",
    "stamkunder": "stamkund",
    "stamkunderna": "stamkund",
    "stamkundernas": "stamkund",
    "stamkunders": "stamkund",
    "stamkunds": "stamkund",
    "stamlinjen": "stamlinje",
    "stamlinjens": "stamlinje",
    "stamlinjer": "stamlinje",
    "stamlinjerna": "stamlinje",
    "stamlinjernas": "stamlinje",
    "stamlinjers": "stamlinje",
    "stamlinjes": "stamlinje",
    "stamlokusen": "stamlokus",
    "stamlokusens": "stamlokus",
    "stamlokuset": "stamlokus",
    "stamlokusets": "stamlokus",
    "stammad": "stamma",
    "stammade": "stamma",
    "stammades": "stamma",
    "stammads": "stamma",
    "stammande": "stamma",
    "stammanden": "stammande",
    "stammandena": "stammande",
    "stammandenas": "stammande",
    "stammandens": "stammande",
    "stammandes": "stammande",
    "stammandet": "stammande",
    "stammandets": "stammande",
    "stammar": "stammare",
    "stammaren": "stammare",
    "stammarens": "stammare",
    "stammares": "stammare",
    "stammarna": "stammare",
    "stammarnas": "stammare",
    "stammars": "stam",
    "stammas": "stamma",
    "stammat": "stamma",
    "stammats": "stamma",
    "stammen": "stam",
    "stammens": "stam",
    "stammodern": "stammoder",
    "stammoderns": "stammoder",
    "stammoders": "stammoder",
    "stammödrar": "stammoder",
    "stammödrarna": "stammoder",
    "stammödrarnas": "stammoder",
    "stammödrars": "stammoder",
    "stamningar": "stamning",
    "stamningarna": "stamning",
    "stamningarnas": "stamning",
    "stamningars": "stamning",
    "stamningen": "stamning",
    "stamningens": "stamning",
    "stamnings": "stamning",
    "stamorten": "stamort",
    "stamortens": "stamort",
    "stamorter": "stamort",
    "stamorterna": "stamort",
    "stamorternas": "stamort",
    "stamorters": "stamort",
    "stamorts": "stamort",
    "stamp": "stampa",
    "stampad": "stampa",
    "stampade": "stampa",
    "stampades": "stampa",
    "stampads": "stampa",
    "stampande": "stampa",
    "stampanden": "stampande",
    "stampandena": "stampande",
    "stampandenas": "stampande",
    "stampandens": "stampande",
    "stampandes": "stampande",
    "stampandet": "stampande",
    "stampandets": "stampande",
    "stampar": "stampa",
    "stamparna": "stamp",
    "stamparnas": "stamp",
    "stampars": "stamp",
    "stampas": "stampa",
    "stampat": "stampa",
    "stampats": "stampa",
    "stampen": "stamp",
    "stampens": "stampen",
    "stampet": "stamp",
    "stampets": "stamp",
    "stampkvarnar": "stampkvarn",
    "stampkvarnarna": "stampkvarn",
    "stampkvarnarnas": "stampkvarn",
    "stampkvarnars": "stampkvarn",
    "stampkvarnen": "stampkvarn",
    "stampkvarnens": "stampkvarn",
    "stampkvarns": "stampkvarn",
    "stamps": "stamp",
    "stams": "stam",
    "stamsamhällen": "stamsamhälle",
    "stamsamhällena": "stamsamhälle",
    "stamsamhällenas": "stamsamhälle",
    "stamsamhällens": "stamsamhälle",
    "stamsamhälles": "stamsamhälle",
    "stamsamhället": "stamsamhälle",
    "stamsamhällets": "stamsamhälle",
    "stamsamhälls": "stamsamhälle",
    "stamtavel": "stamtavla",
    "stamtavlan": "stamtavla",
    "stamtavlans": "stamtavla",
    "stamtavlas": "stamtavla",
    "stamtavle": "stamtavla",
    "stamtavlor": "stamtavla",
    "stamtavlorna": "stamtavla",
    "stamtavlornas": "stamtavla",
    "stamtavlors": "stamtavla",
    "stamtonen": "stamton",
    "stamtonens": "stamton",
    "stamtoner": "stamton",
    "stamtonerna": "stamton",
    "stamtonernas": "stamton",
    "stamtoners": "stamton",
    "stamtons": "stamton",
    "stamträden": "stamträd",
    "stamträdens": "stamträd",
    "stamträdet": "stamträd",
    "stamträdets": "stamträd",
    "stamträds": "stamträd",
    "stamvörtstyrkan": "stamvörtstyrka",
    "stamvörtstyrkans": "stamvörtstyrka",
    "stamvörtstyrkas": "stamvörtstyrka",
    "stamvörtstyrke": "stamvörtstyrka",
    "stan": "stad",
    "stand-inen": "stand-in",
    "stand-inens": "stand-in",
    "stand-iner": "stand-in",
    "stand-inerna": "stand-in",
    "stand-inernas": "stand-in",
    "stand-iners": "stand-in",
    "stand-ins": "stand-in",
    "standardavvikelsen": "standardavvikelse",
    "standardavvikelsens": "standardavvikelse",
    "standardavvikelser": "standardavvikelse",
    "standardavvikelserna": "standardavvikelse",
    "standardavvikelsernas": "standardavvikelse",
    "standardavvikelsers": "standardavvikelse",
    "standardavvikelses": "standardavvikelse",
    "standarden": "standard",
    "standardens": "standard",
    "standarder": "standard",
    "standarderna": "standard",
    "standardernas": "standard",
    "standarders": "standard",
    "standardformulären": "standardformulär",
    "standardformulärens": "standardformulär",
    "standardformuläret": "standardformulär",
    "standardformulärets": "standardformulär",
    "standardformulärs": "standardformulär",
    "standardhycklerier": "standardhyckleri",
    "standardhycklerierna": "standardhyckleri",
    "standardhyckleriernas": "standardhyckleri",
    "standardhyckleriers": "standardhyckleri",
    "standardhyckleriet": "standardhyckleri",
    "standardhyckleriets": "standardhyckleri",
    "standardhyckleris": "standardhyckleri",
    "standardhycklerit": "standardhyckleri",
    "standardhycklerits": "standardhyckleri",
    "standardhöjningar": "standardhöjning",
    "standardhöjningarna": "standardhöjning",
    "standardhöjningarnas": "standardhöjning",
    "standardhöjningars": "standardhöjning",
    "standardhöjningen": "standardhöjning",
    "standardhöjningens": "standardhöjning",
    "standardhöjnings": "standardhöjning",
    "standardiserad": "standardisera",
    "standardiserade": "standardisera",
    "standardiserades": "standardisera",
    "standardiserads": "standardisera",
    "standardiserande": "standardisera",
    "standardiseranden": "standardiserande",
    "standardiserandena": "standardiserande",
    "standardiserandenas": "standardiserande",
    "standardiserandens": "standardiserande",
    "standardiserandes": "standardiserande",
    "standardiserandet": "standardiserande",
    "standardiserandets": "standardiserande",
    "standardiserar": "standardisera",
    "standardiseras": "standardisera",
    "standardiserat": "standardisera",
    "standardiserats": "standardisera",
    "standardiserbara": "standardiserbar",
    "standardiserbarare": "standardiserbar",
    "standardiserbarares": "standardiserbar",
    "standardiserbaras": "standardiserbar",
    "standardiserbarast": "standardiserbar",
    "standardiserbaraste": "standardiserbar",
    "standardiserbarastes": "standardiserbar",
    "standardiserbarasts": "standardiserbar",
    "standardiserbare": "standardiserbar",
    "standardiserbares": "standardiserbar",
    "standardiserbarheten": "standardiserbarhet",
    "standardiserbarhetens": "standardiserbarhet",
    "standardiserbarhets": "standardiserbarhet",
    "standardiserbars": "standardiserbar",
    "standardiserbart": "standardiserbar",
    "standardiserbarts": "standardiserbar",
    "standardiseringar": "standardisering",
    "standardiseringarna": "standardisering",
    "standardiseringarnas": "standardisering",
    "standardiseringars": "standardisering",
    "standardiseringen": "standardisering",
    "standardiseringens": "standardisering",
    "standardiserings": "standardisering",
    "standardislams": "standardislam",
    "standardklyschan": "standardklyscha",
    "standardklyschans": "standardklyscha",
    "standardklyschas": "standardklyscha",
    "standardklysche": "standardklyscha",
    "standardklyschor": "standardklyscha",
    "standardklyschorna": "standardklyscha",
    "standardklyschornas": "standardklyscha",
    "standardklyschors": "standardklyscha",
    "standardlösningar": "standardlösning",
    "standardlösningarna": "standardlösning",
    "standardlösningarnas": "standardlösning",
    "standardlösningars": "standardlösning",
    "standardlösningen": "standardlösning",
    "standardlösningens": "standardlösning",
    "standardlösnings": "standardlösning",
    "standardmässiga": "standardmässig",
    "standardmässigare": "standardmässig",
    "standardmässigares": "standardmässig",
    "standardmässigas": "standardmässig",
    "standardmässigast": "standardmässig",
    "standardmässigaste": "standardmässig",
    "standardmässigastes": "standardmässig",
    "standardmässigasts": "standardmässig",
    "standardmässige": "standardmässig",
    "standardmässiges": "standardmässig",
    "standardmässigs": "standardmässig",
    "standardmässigt": "standardmässig",
    "standardmässigts": "standardmässig",
    "standardproven": "standardprov",
    "standardprovens": "standardprov",
    "standardprovet": "standardprov",
    "standardprovets": "standardprov",
    "standardprovs": "standardprov",
    "standards": "standard",
    "standardsvaren": "standardsvar",
    "standardsvarens": "standardsvar",
    "standardsvaret": "standardsvar",
    "standardsvarets": "standardsvar",
    "standardsvars": "standardsvar",
    "standardverken": "standardverk",
    "standardverkens": "standardverk",
    "standardverket": "standardverk",
    "standardverkets": "standardverk",
    "standardverks": "standardverk",
    "standaren": "standar",
    "standarens": "standar",
    "standaret": "standar",
    "standarets": "standar",
    "standars": "standar",
    "standertar": "standert",
    "standertarna": "standert",
    "standertarnas": "standert",
    "standertars": "standert",
    "standerten": "standert",
    "standertens": "standert",
    "standerts": "standert",
    "stank": "stinka",
    "stanken": "stank",
    "stankens": "stank",
    "stanker": "stank",
    "stankerna": "stank",
    "stankernas": "stank",
    "stankers": "stank",
    "stanks": "stinka",
    "stann": "stanna",
    "stannad": "stanna",
    "stannade": "stanna",
    "stannades": "stanna",
    "stannads": "stanna",
    "stannande": "stanna",
    "stannanden": "stannande",
    "stannandena": "stannande",
    "stannandenas": "stannande",
    "stannandens": "stannande",
    "stannandes": "stannande",
    "stannandet": "stannande",
    "stannandets": "stannande",
    "stannar": "stanna",
    "stannas": "stanna",
    "stannat": "stanna",
    "stannats": "stanna",
    "stannfågeln": "stannfågel",
    "stannfågelns": "stannfågel",
    "stannfågels": "stannfågel",
    "stannfåglar": "stannfågel",
    "stannfåglarna": "stannfågel",
    "stannfåglarnas": "stannfågel",
    "stannfåglars": "stannfågel",
    "stanningar": "stanning",
    "stanningarna": "stanning",
    "stanningarnas": "stanning",
    "stanningars": "stanning",
    "stanningen": "stanning",
    "stanningens": "stanning",
    "stannings": "stanning",
    "stanniolen": "stanniol",
    "stanniolens": "stanniol",
    "stanniols": "stanniol",
    "stannplanen": "stannplan",
    "stannplanens": "stannplan",
    "stannplanet": "stannplan",
    "stannplanets": "stannplan",
    "stannplans": "stannplan",
    "stans": "stansa",
    "stansad": "stansa",
    "stansade": "stansa",
    "stansades": "stansa",
    "stansads": "stansa",
    "stansande": "stansa",
    "stansanden": "stansande",
    "stansandena": "stansande",
    "stansandenas": "stansande",
    "stansandens": "stansande",
    "stansandes": "stansande",
    "stansandet": "stansande",
    "stansandets": "stansande",
    "stansar": "stansa",
    "stansarna": "stans",
    "stansarnas": "stans",
    "stansars": "stans",
    "stansas": "stansa",
    "stansat": "stansa",
    "stansats": "stansa",
    "stansen": "stans",
    "stansens": "stans",
    "stanser": "stans",
    "stanserna": "stans",
    "stansernas": "stans",
    "stansers": "stans",
    "stapel": "stapla",
    "stapelavlöpningar": "stapelavlöpning",
    "stapelavlöpningarna": "stapelavlöpning",
    "stapelavlöpningarnas": "stapelavlöpning",
    "stapelavlöpningars": "stapelavlöpning",
    "stapelavlöpningen": "stapelavlöpning",
    "stapelavlöpningens": "stapelavlöpning",
    "stapelavlöpnings": "stapelavlöpning",
    "stapelbäddar": "stapelbädd",
    "stapelbäddarna": "stapelbädd",
    "stapelbäddarnas": "stapelbädd",
    "stapelbäddars": "stapelbädd",
    "stapelbädden": "stapelbädd",
    "stapelbäddens": "stapelbädd",
    "stapelbädds": "stapelbädd",
    "stapeldiagrammen": "stapeldiagram",
    "stapeldiagrammens": "stapeldiagram",
    "stapeldiagrammet": "stapeldiagram",
    "stapeldiagrammets": "stapeldiagram",
    "stapeldiagrams": "stapeldiagram",
    "stapeln": "stapel",
    "stapelns": "stapel",
    "stapelplatsen": "stapelplats",
    "stapelplatsens": "stapelplats",
    "stapelplatser": "stapelplats",
    "stapelplatserna": "stapelplats",
    "stapelplatsernas": "stapelplats",
    "stapelplatsers": "stapelplats",
    "stapels": "stapel",
    "stapelstaden": "stapelstad",
    "stapelstadens": "stapelstad",
    "stapelstads": "stapelstad",
    "stapelstan": "stapelstad",
    "stapelstans": "stapelstad",
    "stapelstäder": "stapelstad",
    "stapelstäderna": "stapelstad",
    "stapelstädernas": "stapelstad",
    "stapelstäders": "stapelstad",
    "stapelvar": "stapelvara",
    "stapelvaran": "stapelvara",
    "stapelvarans": "stapelvara",
    "stapelvaras": "stapelvara",
    "stapelvare": "stapelvara",
    "stapelvaror": "stapelvara",
    "stapelvarorna": "stapelvara",
    "stapelvarornas": "stapelvara",
    "stapelvarors": "stapelvara",
    "stapelvars": "stapelvara",
    "staplad": "stapla",
    "staplade": "stapla",
    "staplades": "stapla",
    "staplads": "stapla",
    "staplande": "stapla",
    "staplanden": "staplande",
    "staplandena": "staplande",
    "staplandenas": "staplande",
    "staplandens": "staplande",
    "staplandes": "staplande",
    "staplandet": "staplande",
    "staplandets": "staplande",
    "staplar": "stapla",
    "staplarna": "stapel",
    "staplarnas": "stapel",
    "staplars": "stapel",
    "staplas": "stapla",
    "staplat": "stapla",
    "staplats": "stapla",
    "stappel": "stappla",
    "stapplad": "stappla",
    "stapplade": "stappla",
    "stapplades": "stappla",
    "stapplads": "stappla",
    "stapplande": "stappla",
    "stapplanden": "stapplande",
    "stapplandena": "stapplande",
    "stapplandenas": "stapplande",
    "stapplandens": "stapplande",
    "stapplandes": "stapplande",
    "stapplandet": "stapplande",
    "stapplandets": "stapplande",
    "stapplar": "stappla",
    "stapplas": "stappla",
    "stapplat": "stappla",
    "stapplats": "stappla",
    "star": "stare",
    "starar": "stare",
    "stararna": "stare",
    "stararnas": "stare",
    "starars": "stare",
    "starbåtar": "starbåt",
    "starbåtarna": "starbåt",
    "starbåtarnas": "starbåt",
    "starbåtars": "starbåt",
    "starbåten": "starbåt",
    "starbåtens": "starbåt",
    "starbåts": "starbåt",
    "staren": "stare",
    "starens": "stare",
    "stares": "stare",
    "starka": "stark",
    "starkare": "stark",
    "starkares": "stark",
    "starkas": "stark",
    "starkast": "stark",
    "starkaste": "stark",
    "starkastes": "stark",
    "starkasts": "stark",
    "starke": "stark",
    "starkes": "stark",
    "starkheten": "starkhet",
    "starkhetens": "starkhet",
    "starkhets": "starkhet",
    "starkspriten": "starksprit",
    "starkspritens": "starksprit",
    "starksprits": "starksprit",
    "starkströmmar": "starkström",
    "starkströmmarna": "starkström",
    "starkströmmarnas": "starkström",
    "starkströmmars": "starkström",
    "starkströmmen": "starkström",
    "starkströmmens": "starkström",
    "starkströms": "starkström",
    "starkt": "stark",
    "starkts": "stark",
    "starkvar": "starkvara",
    "starkvaran": "starkvara",
    "starkvarans": "starkvara",
    "starkvaras": "starkvara",
    "starkvaror": "starkvara",
    "starkvarorna": "starkvara",
    "starkvarornas": "starkvara",
    "starkvarors": "starkvara",
    "starkvaru": "starkvara",
    "starkviner": "starkvin",
    "starkvinerna": "starkvin",
    "starkvinernas": "starkvin",
    "starkviners": "starkvin",
    "starkvinet": "starkvin",
    "starkvinets": "starkvin",
    "starkvins": "starkvin",
    "starkölen": "starköl",
    "starkölens": "starköl",
    "starkölet": "starköl",
    "starkölets": "starköl",
    "starköls": "starköl",
    "starrbligade": "starrbliga",
    "starrbligades": "starrbliga",
    "starrbligande": "starrbliga",
    "starrbliganden": "starrbligande",
    "starrbligandena": "starrbligande",
    "starrbligandenas": "starrbligande",
    "starrbligandens": "starrbligande",
    "starrbligandes": "starrbligande",
    "starrbligandet": "starrbligande",
    "starrbligandets": "starrbligande",
    "starrbligar": "starrbliga",
    "starrbligas": "starrbliga",
    "starrbligat": "starrbliga",
    "starrbligats": "starrbliga",
    "starren": "starr",
    "starrens": "starr",
    "starroperationen": "starroperation",
    "starroperationens": "starroperation",
    "starroperationer": "starroperation",
    "starroperationerna": "starroperation",
    "starroperationernas": "starroperation",
    "starroperationers": "starroperation",
    "starroperations": "starroperation",
    "starrs": "starr",
    "stars": "stare",
    "start": "starta",
    "startad": "starta",
    "startade": "starta",
    "startades": "starta",
    "startads": "starta",
    "startande": "starta",
    "startanden": "startande",
    "startandena": "startande",
    "startandenas": "startande",
    "startandens": "startande",
    "startandes": "startande",
    "startandet": "startande",
    "startandets": "startande",
    "startar": "starta",
    "startas": "starta",
    "startat": "starta",
    "startats": "starta",
    "startavgiften": "startavgift",
    "startavgiftens": "startavgift",
    "startavgifter": "startavgift",
    "startavgifterna": "startavgift",
    "startavgifternas": "startavgift",
    "startavgifters": "startavgift",
    "startavgifts": "startavgift",
    "startbanan": "startbana",
    "startbanans": "startbana",
    "startbanas": "startbana",
    "startbane": "startbana",
    "startbanor": "startbana",
    "startbanorna": "startbana",
    "startbanornas": "startbana",
    "startbanors": "startbana",
    "startbatterier": "startbatteri",
    "startbatterierna": "startbatteri",
    "startbatteriernas": "startbatteri",
    "startbatteriers": "startbatteri",
    "startbatteriet": "startbatteri",
    "startbatteriets": "startbatteri",
    "startbatteris": "startbatteri",
    "startbatterit": "startbatteri",
    "startbatterits": "startbatteri",
    "startberedda": "startberedd",
    "startbereddare": "startberedd",
    "startbereddares": "startberedd",
    "startbereddas": "startberedd",
    "startbereddast": "startberedd",
    "startbereddaste": "startberedd",
    "startbereddastes": "startberedd",
    "startbereddasts": "startberedd",
    "startberedde": "startberedd",
    "startbereddes": "startberedd",
    "startberedds": "startberedd",
    "startberett": "startberedd",
    "startberetts": "startberedd",
    "startblocken": "startblock",
    "startblockens": "startblock",
    "startblocket": "startblock",
    "startblockets": "startblock",
    "startblocks": "startblock",
    "starten": "start",
    "startenergien": "startenergi",
    "startenergiens": "startenergi",
    "startenergin": "startenergi",
    "startenergins": "startenergi",
    "startenergis": "startenergi",
    "startens": "start",
    "starter": "start",
    "startern": "starter",
    "starterna": "starter",
    "starternas": "starter",
    "starterns": "starter",
    "starters": "starter",
    "startfälten": "startfält",
    "startfältens": "startfält",
    "startfältet": "startfält",
    "startfältets": "startfält",
    "startfälts": "startfält",
    "startgeneratorer": "startgenerator",
    "startgeneratorerna": "startgenerator",
    "startgeneratorernas": "startgenerator",
    "startgeneratorers": "startgenerator",
    "startgeneratorn": "startgenerator",
    "startgeneratorns": "startgenerator",
    "startgenerators": "startgenerator",
    "startgropar": "startgrop",
    "startgroparna": "startgrop",
    "startgroparnas": "startgrop",
    "startgropars": "startgrop",
    "startgropen": "startgrop",
    "startgropens": "startgrop",
    "startgrops": "startgrop",
    "startkabeln": "startkabel",
    "startkabelns": "startkabel",
    "startkabels": "startkabel",
    "startkablar": "startkabel",
    "startkablarna": "startkabel",
    "startkablarnas": "startkabel",
    "startkablars": "startkabel",
    "startkapitalet": "startkapital",
    "startkapitalets": "startkapital",
    "startkapitals": "startkapital",
    "startlinjen": "startlinje",
    "startlinjens": "startlinje",
    "startlinjer": "startlinje",
    "startlinjerna": "startlinje",
    "startlinjernas": "startlinje",
    "startlinjers": "startlinje",
    "startlinjes": "startlinje",
    "startmotorer": "startmotor",
    "startmotorerna": "startmotor",
    "startmotorernas": "startmotor",
    "startmotorers": "startmotor",
    "startmotorn": "startmotor",
    "startmotorns": "startmotor",
    "startmotors": "startmotor",
    "startnyckeln": "startnyckel",
    "startnyckelns": "startnyckel",
    "startnyckels": "startnyckel",
    "startnycklar": "startnyckel",
    "startnycklarna": "startnyckel",
    "startnycklarnas": "startnyckel",
    "startnycklars": "startnyckel",
    "startpallar": "startpall",
    "startpallarna": "startpall",
    "startpallarnas": "startpall",
    "startpallars": "startpall",
    "startpallen": "startpall",
    "startpallens": "startpall",
    "startpalls": "startpall",
    "startpistolen": "startpistol",
    "startpistolens": "startpistol",
    "startpistoler": "startpistol",
    "startpistolerna": "startpistol",
    "startpistolernas": "startpistol",
    "startpistolers": "startpistol",
    "startpistols": "startpistol",
    "startproblemen": "startproblem",
    "startproblemens": "startproblem",
    "startproblemet": "startproblem",
    "startproblemets": "startproblem",
    "startproblems": "startproblem",
    "startpunkten": "startpunkt",
    "startpunktens": "startpunkt",
    "startpunkter": "startpunkt",
    "startpunkterna": "startpunkt",
    "startpunkternas": "startpunkt",
    "startpunkters": "startpunkt",
    "startpunkts": "startpunkt",
    "starts": "start",
    "startskjuten": "startskjut",
    "startskjutens": "startskjut",
    "startskjutet": "startskjut",
    "startskjutets": "startskjut",
    "startskjuts": "startskjut",
    "startskotten": "startskott",
    "startskottens": "startskott",
    "startskottet": "startskott",
    "startskottets": "startskott",
    "startskotts": "startskott",
    "startsnör": "startsnöre",
    "startsnören": "startsnöre",
    "startsnörena": "startsnöre",
    "startsnörenas": "startsnöre",
    "startsnörens": "startsnöre",
    "startsnöres": "startsnöre",
    "startsnöret": "startsnöre",
    "startsnörets": "startsnöre",
    "startsnörs": "startsnöre",
    "startspjällen": "startspjäll",
    "startspjällens": "startspjäll",
    "startspjället": "startspjäll",
    "startspjällets": "startspjäll",
    "startspjälls": "startspjäll",
    "startsträck": "startsträcka",
    "startsträckan": "startsträcka",
    "startsträckans": "startsträcka",
    "startsträckas": "startsträcka",
    "startsträcke": "startsträcka",
    "startsträckor": "startsträcka",
    "startsträckorna": "startsträcka",
    "startsträckornas": "startsträcka",
    "startsträckors": "startsträcka",
    "startsträcks": "startsträcka",
    "startsystemen": "startsystem",
    "startsystemens": "startsystem",
    "startsystemet": "startsystem",
    "startsystemets": "startsystem",
    "startsystems": "startsystem",
    "startvevar": "startvev",
    "startvevarna": "startvev",
    "startvevarnas": "startvev",
    "startvevars": "startvev",
    "startveven": "startvev",
    "startvevens": "startvev",
    "startvevs": "startvev",
    "stasen": "stas",
    "stasens": "stas",
    "staser": "stas",
    "staserna": "stas",
    "stasernas": "stas",
    "stasers": "stas",
    "stass": "stassa",
    "stassad": "stassa",
    "stassade": "stassa",
    "stassades": "stassa",
    "stassads": "stassa",
    "stassande": "stassa",
    "stassanden": "stassande",
    "stassandena": "stassande",
    "stassandenas": "stassande",
    "stassandens": "stassande",
    "stassandes": "stassande",
    "stassandet": "stassande",
    "stassandets": "stassande",
    "stassar": "stassa",
    "stassas": "stassa",
    "stassat": "stassa",
    "stassats": "stassa",
    "stassen": "stass",
    "stassens": "stass",
    "statar": "statare",
    "stataren": "statare",
    "statarens": "statare",
    "statares": "statare",
    "statarna": "statare",
    "statarnas": "statare",
    "staten": "stat",
    "statens": "stat",
    "stater": "stat",
    "staterade": "statera",
    "staterades": "statera",
    "staterande": "statera",
    "stateranden": "staterande",
    "staterandena": "staterande",
    "staterandenas": "staterande",
    "staterandens": "staterande",
    "staterandes": "staterande",
    "staterandet": "staterande",
    "staterandets": "staterande",
    "staterar": "statera",
    "stateras": "statera",
    "staterat": "statera",
    "staterats": "statera",
    "stateringar": "statering",
    "stateringarna": "statering",
    "stateringarnas": "statering",
    "stateringars": "statering",
    "stateringen": "statering",
    "stateringens": "statering",
    "staterings": "statering",
    "staterna": "stat",
    "staternas": "stat",
    "staters": "stat",
    "statiken": "statik",
    "statikens": "statik",
    "statiks": "statik",
    "stationen": "station",
    "stationens": "station",
    "stationer": "station",
    "stationerad": "stationera",
    "stationerade": "stationera",
    "stationerades": "stationera",
    "stationerads": "stationera",
    "stationerande": "stationera",
    "stationeranden": "stationerande",
    "stationerandena": "stationerande",
    "stationerandenas": "stationerande",
    "stationerandens": "stationerande",
    "stationerandes": "stationerande",
    "stationerandet": "stationerande",
    "stationerandets": "stationerande",
    "stationerar": "stationera",
    "stationeras": "stationera",
    "stationerat": "stationera",
    "stationerats": "stationera",
    "stationerbara": "stationerbar",
    "stationerbarare": "stationerbar",
    "stationerbarares": "stationerbar",
    "stationerbaras": "stationerbar",
    "stationerbarast": "stationerbar",
    "stationerbaraste": "stationerbar",
    "stationerbarastes": "stationerbar",
    "stationerbarasts": "stationerbar",
    "stationerbare": "stationerbar",
    "stationerbares": "stationerbar",
    "stationerbarheten": "stationerbarhet",
    "stationerbarhetens": "stationerbarhet",
    "stationerbarhets": "stationerbarhet",
    "stationerbars": "stationerbar",
    "stationerbart": "stationerbar",
    "stationerbarts": "stationerbar",
    "stationeringar": "stationering",
    "stationeringarna": "stationering",
    "stationeringarnas": "stationering",
    "stationeringars": "stationering",
    "stationeringen": "stationering",
    "stationeringens": "stationering",
    "stationerings": "stationering",
    "stationerna": "station",
    "stationernas": "station",
    "stationers": "station",
    "stations": "station",
    "stationsbyggnaden": "stationsbyggnad",
    "stationsbyggnadens": "stationsbyggnad",
    "stationsbyggnader": "stationsbyggnad",
    "stationsbyggnaderna": "stationsbyggnad",
    "stationsbyggnadernas": "stationsbyggnad",
    "stationsbyggnaders": "stationsbyggnad",
    "stationsbyggnads": "stationsbyggnad",
    "stationshusen": "stationshus",
    "stationshusens": "stationshus",
    "stationshuset": "stationshus",
    "stationshusets": "stationshus",
    "stationsinspektorer": "stationsinspektor",
    "stationsinspektorerna": "stationsinspektor",
    "stationsinspektorernas": "stationsinspektor",
    "stationsinspektorers": "stationsinspektor",
    "stationsinspektorn": "stationsinspektor",
    "stationsinspektorns": "stationsinspektor",
    "stationsinspektors": "stationsinspektor",
    "stationssamhällen": "stationssamhälle",
    "stationssamhällena": "stationssamhälle",
    "stationssamhällenas": "stationssamhälle",
    "stationssamhällens": "stationssamhälle",
    "stationssamhälles": "stationssamhälle",
    "stationssamhället": "stationssamhälle",
    "stationssamhällets": "stationssamhälle",
    "stationssamhälls": "stationssamhälle",
    "stationsvagnar": "stationsvagn",
    "stationsvagnarna": "stationsvagn",
    "stationsvagnarnas": "stationsvagn",
    "stationsvagnars": "stationsvagn",
    "stationsvagnen": "stationsvagn",
    "stationsvagnens": "stationsvagn",
    "stationsvagns": "stationsvagn",
    "stationära": "stationär",
    "stationärare": "stationär",
    "stationärares": "stationär",
    "stationäras": "stationär",
    "stationärast": "stationär",
    "stationäraste": "stationär",
    "stationärastes": "stationär",
    "stationärasts": "stationär",
    "stationäre": "stationär",
    "stationäres": "stationär",
    "stationärs": "stationär",
    "stationärt": "stationär",
    "stationärts": "stationär",
    "statiska": "statisk",
    "statiskare": "statisk",
    "statiskares": "statisk",
    "statiskas": "statisk",
    "statiskast": "statisk",
    "statiskaste": "statisk",
    "statiskastes": "statisk",
    "statiskasts": "statisk",
    "statiske": "statisk",
    "statiskes": "statisk",
    "statisks": "statisk",
    "statiskt": "statisk",
    "statiskts": "statisk",
    "statisten": "statist",
    "statistens": "statist",
    "statister": "statist",
    "statisterna": "statist",
    "statisternas": "statist",
    "statisters": "statist",
    "statistiken": "statistik",
    "statistikens": "statistik",
    "statistiker": "statistik",
    "statistikern": "statistiker",
    "statistikerna": "statistiker",
    "statistikernas": "statistiker",
    "statistikerns": "statistiker",
    "statistikers": "statistiker",
    "statistikmässiga": "statistikmässig",
    "statistikmässigare": "statistikmässig",
    "statistikmässigares": "statistikmässig",
    "statistikmässigas": "statistikmässig",
    "statistikmässigast": "statistikmässig",
    "statistikmässigaste": "statistikmässig",
    "statistikmässigastes": "statistikmässig",
    "statistikmässigasts": "statistikmässig",
    "statistikmässige": "statistikmässig",
    "statistikmässiges": "statistikmässig",
    "statistikmässigs": "statistikmässig",
    "statistikmässigt": "statistikmässig",
    "statistikmässigts": "statistikmässig",
    "statistiks": "statistik",
    "statistiska": "statistisk",
    "statistiskare": "statistisk",
    "statistiskares": "statistisk",
    "statistiskas": "statistisk",
    "statistiskast": "statistisk",
    "statistiskaste": "statistisk",
    "statistiskastes": "statistisk",
    "statistiskasts": "statistisk",
    "statistiske": "statistisk",
    "statistiskes": "statistisk",
    "statistisks": "statistisk",
    "statistiskt": "statistisk",
    "statistiskts": "statistisk",
    "statists": "statist",
    "stativa": "stativ",
    "stativare": "stativ",
    "stativares": "stativ",
    "stativas": "stativ",
    "stativast": "stativ",
    "stativaste": "stativ",
    "stativastes": "stativ",
    "stativasts": "stativ",
    "stative": "stativ",
    "stativen": "stativ",
    "stativens": "stativ",
    "stativer": "stativ",
    "stativerna": "stativ",
    "stativernas": "stativ",
    "stativers": "stativ",
    "statives": "stativ",
    "stativet": "stativ",
    "stativets": "stativ",
    "stativs": "stativ",
    "stativt": "stativ",
    "stativts": "stativ",
    "statliga": "statlig",
    "statligare": "statlig",
    "statligares": "statlig",
    "statligas": "statlig",
    "statligast": "statlig",
    "statligaste": "statlig",
    "statligastes": "statlig",
    "statligasts": "statlig",
    "statlige": "statlig",
    "statliges": "statlig",
    "statligheten": "statlighet",
    "statlighetens": "statlighet",
    "statlighets": "statlighet",
    "statligs": "statlig",
    "statligt": "statlig",
    "statligts": "statlig",
    "statministerkandidaten": "statministerkandidat",
    "statministerkandidatens": "statministerkandidat",
    "statministerkandidater": "statministerkandidat",
    "statministerkandidaterna": "statministerkandidat",
    "statministerkandidaternas": "statministerkandidat",
    "statministerkandidaters": "statministerkandidat",
    "statministerkandidats": "statministerkandidat",
    "statorer": "stator",
    "statorerna": "stator",
    "statorernas": "stator",
    "statorers": "stator",
    "statorn": "stator",
    "statorns": "stator",
    "stators": "stator",
    "stats": "stat",
    "statsangelägenheten": "statsangelägenhet",
    "statsangelägenhetens": "statsangelägenhet",
    "statsangelägenheter": "statsangelägenhet",
    "statsangelägenheterna": "statsangelägenhet",
    "statsangelägenheternas": "statsangelägenhet",
    "statsangelägenheters": "statsangelägenhet",
    "statsangelägenhets": "statsangelägenhet",
    "statsanslagen": "statsanslag",
    "statsanslagens": "statsanslag",
    "statsanslaget": "statsanslag",
    "statsanslagets": "statsanslag",
    "statsanslags": "statsanslag",
    "statsbanketten": "statsbankett",
    "statsbankettens": "statsbankett",
    "statsbanketter": "statsbankett",
    "statsbanketterna": "statsbankett",
    "statsbanketternas": "statsbankett",
    "statsbanketters": "statsbankett",
    "statsbanketts": "statsbankett",
    "statsbegravningar": "statsbegravning",
    "statsbegravningarna": "statsbegravning",
    "statsbegravningarnas": "statsbegravning",
    "statsbegravningars": "statsbegravning",
    "statsbegravningen": "statsbegravning",
    "statsbegravningens": "statsbegravning",
    "statsbegravnings": "statsbegravning",
    "statsbesöken": "statsbesök",
    "statsbesökens": "statsbesök",
    "statsbesöket": "statsbesök",
    "statsbesökets": "statsbesök",
    "statsbesöks": "statsbesök",
    "statsbidragen": "statsbidrag",
    "statsbidragens": "statsbidrag",
    "statsbidraget": "statsbidrag",
    "statsbidragets": "statsbidrag",
    "statsbidrags": "statsbidrag",
    "statsbildningar": "statsbildning",
    "statsbildningarna": "statsbildning",
    "statsbildningarnas": "statsbildning",
    "statsbildningars": "statsbildning",
    "statsbildningen": "statsbildning",
    "statsbildningens": "statsbildning",
    "statsbildnings": "statsbildning",
    "statsbudgetar": "statsbudget",
    "statsbudgetarna": "statsbudget",
    "statsbudgetarnas": "statsbudget",
    "statsbudgetars": "statsbudget",
    "statsbudgeten": "statsbudget",
    "statsbudgetens": "statsbudget",
    "statsbudgeter": "statsbudget",
    "statsbudgeterna": "statsbudget",
    "statsbudgeternas": "statsbudget",
    "statsbudgeters": "statsbudget",
    "statsbudgets": "statsbudget",
    "statsbyggen": "statsbygge",
    "statsbyggena": "statsbygge",
    "statsbyggenas": "statsbygge",
    "statsbyggens": "statsbygge",
    "statsbygges": "statsbygge",
    "statsbygget": "statsbygge",
    "statsbyggets": "statsbygge",
    "statschefen": "statschef",
    "statschefens": "statschef",
    "statschefer": "statschef",
    "statscheferna": "statschef",
    "statschefernas": "statschef",
    "statschefers": "statschef",
    "statschefs": "statschef",
    "statsdepartementen": "statsdepartement",
    "statsdepartementens": "statsdepartement",
    "statsdepartementet": "statsdepartement",
    "statsdepartementets": "statsdepartement",
    "statsdepartements": "statsdepartement",
    "statsfinans": "statsfinanser",
    "statsfinanserna": "statsfinanser",
    "statsfinansernas": "statsfinanser",
    "statsfinansers": "statsfinanser",
    "statsfinansiella": "statsfinansiell",
    "statsfinansiellare": "statsfinansiell",
    "statsfinansiellares": "statsfinansiell",
    "statsfinansiellas": "statsfinansiell",
    "statsfinansiellast": "statsfinansiell",
    "statsfinansiellaste": "statsfinansiell",
    "statsfinansiellastes": "statsfinansiell",
    "statsfinansiellasts": "statsfinansiell",
    "statsfinansielle": "statsfinansiell",
    "statsfinansielles": "statsfinansiell",
    "statsfinansiells": "statsfinansiell",
    "statsfinansiellt": "statsfinansiell",
    "statsfinansiellts": "statsfinansiell",
    "statsfruar": "statsfru",
    "statsfruarna": "statsfru",
    "statsfruarnas": "statsfru",
    "statsfruars": "statsfru",
    "statsfrun": "statsfru",
    "statsfruns": "statsfru",
    "statsfrus": "statsfru",
    "statsförfattningar": "statsförfattning",
    "statsförfattningarna": "statsförfattning",
    "statsförfattningarnas": "statsförfattning",
    "statsförfattningars": "statsförfattning",
    "statsförfattningen": "statsförfattning",
    "statsförfattningens": "statsförfattning",
    "statsförfattnings": "statsförfattning",
    "statsförvaltningar": "statsförvaltning",
    "statsförvaltningarna": "statsförvaltning",
    "statsförvaltningarnas": "statsförvaltning",
    "statsförvaltningars": "statsförvaltning",
    "statsförvaltningen": "statsförvaltning",
    "statsförvaltningens": "statsförvaltning",
    "statsförvaltnings": "statsförvaltning",
    "statsgeologen": "statsgeolog",
    "statsgeologens": "statsgeolog",
    "statsgeologer": "statsgeolog",
    "statsgeologerna": "statsgeolog",
    "statsgeologernas": "statsgeolog",
    "statsgeologers": "statsgeolog",
    "statsgeologs": "statsgeolog",
    "statshemligheten": "statshemlighet",
    "statshemlighetens": "statshemlighet",
    "statshemligheter": "statshemlighet",
    "statshemligheterna": "statshemlighet",
    "statshemligheternas": "statshemlighet",
    "statshemligheters": "statshemlighet",
    "statshemlighets": "statshemlighet",
    "statskassan": "statskassa",
    "statskassans": "statskassa",
    "statskassas": "statskassa",
    "statskasse": "statskassa",
    "statskunskapen": "statskunskap",
    "statskunskapens": "statskunskap",
    "statskunskaps": "statskunskap",
    "statskuppen": "statskupp",
    "statskuppens": "statskupp",
    "statskupper": "statskupp",
    "statskupperna": "statskupp",
    "statskuppernas": "statskupp",
    "statskuppers": "statskupp",
    "statskupps": "statskupp",
    "statskvinnamässiga": "statskvinnamässig",
    "statskvinnamässigare": "statskvinnamässig",
    "statskvinnamässigares": "statskvinnamässig",
    "statskvinnamässigas": "statskvinnamässig",
    "statskvinnamässigast": "statskvinnamässig",
    "statskvinnamässigaste": "statskvinnamässig",
    "statskvinnamässigastes": "statskvinnamässig",
    "statskvinnamässigasts": "statskvinnamässig",
    "statskvinnamässige": "statskvinnamässig",
    "statskvinnamässiges": "statskvinnamässig",
    "statskvinnamässigs": "statskvinnamässig",
    "statskvinnamässigt": "statskvinnamässig",
    "statskvinnamässigts": "statskvinnamässig",
    "statskvinnan": "statskvinna",
    "statskvinnans": "statskvinna",
    "statskvinnas": "statskvinna",
    "statskvinne": "statskvinna",
    "statskvinno": "statskvinna",
    "statskvinnomässiga": "statskvinnomässig",
    "statskvinnomässigare": "statskvinnomässig",
    "statskvinnomässigares": "statskvinnomässig",
    "statskvinnomässigas": "statskvinnomässig",
    "statskvinnomässigast": "statskvinnomässig",
    "statskvinnomässigaste": "statskvinnomässig",
    "statskvinnomässigastes": "statskvinnomässig",
    "statskvinnomässigasts": "statskvinnomässig",
    "statskvinnomässige": "statskvinnomässig",
    "statskvinnomässiges": "statskvinnomässig",
    "statskvinnomässigs": "statskvinnomässig",
    "statskvinnomässigt": "statskvinnomässig",
    "statskvinnomässigts": "statskvinnomässig",
    "statskvinnor": "statskvinna",
    "statskvinnorna": "statskvinna",
    "statskvinnornas": "statskvinna",
    "statskvinnors": "statskvinna",
    "statskyrkan": "statskyrka",
    "statskyrkans": "statskyrka",
    "statskyrkas": "statskyrka",
    "statslösa": "statslös",
    "statslösare": "statslös",
    "statslösares": "statslös",
    "statslösas": "statslös",
    "statslösast": "statslös",
    "statslösaste": "statslös",
    "statslösastes": "statslös",
    "statslösasts": "statslös",
    "statslöse": "statslös",
    "statslöses": "statslös",
    "statslösheten": "statslöshet",
    "statslöshetens": "statslöshet",
    "statslöshets": "statslöshet",
    "statslöst": "statslös",
    "statslösts": "statslös",
    "statsmakten": "statsmakt",
    "statsmaktens": "statsmakt",
    "statsmakter": "statsmakt",
    "statsmakterna": "statsmakt",
    "statsmakternas": "statsmakt",
    "statsmakters": "statsmakt",
    "statsmakts": "statsmakt",
    "statsmannamässiga": "statsmannamässig",
    "statsmannamässigare": "statsmannamässig",
    "statsmannamässigares": "statsmannamässig",
    "statsmannamässigas": "statsmannamässig",
    "statsmannamässigast": "statsmannamässig",
    "statsmannamässigaste": "statsmannamässig",
    "statsmannamässigastes": "statsmannamässig",
    "statsmannamässigasts": "statsmannamässig",
    "statsmannamässige": "statsmannamässig",
    "statsmannamässiges": "statsmannamässig",
    "statsmannamässigs": "statsmannamässig",
    "statsmannamässigt": "statsmannamässig",
    "statsmannamässigts": "statsmannamässig",
    "statsmannen": "statsman",
    "statsmannens": "statsman",
    "statsmans": "statsman",
    "statsministern": "statsminister",
    "statsministerns": "statsminister",
    "statsministers": "statsminister",
    "statsministrar": "statsminister",
    "statsministrarna": "statsminister",
    "statsministrarnas": "statsminister",
    "statsministrars": "statsminister",
    "statsmän": "statsman",
    "statsmännen": "statsman",
    "statsmännens": "statsman",
    "statsmäns": "statsman",
    "statsnyttan": "statsnytta",
    "statsnyttans": "statsnytta",
    "statsnyttas": "statsnytta",
    "statsnytte": "statsnytta",
    "statsnytto": "statsnytta",
    "statsnyttor": "statsnytta",
    "statsnyttorna": "statsnytta",
    "statsnyttornas": "statsnytta",
    "statsnyttors": "statsnytta",
    "statsobligationen": "statsobligation",
    "statsobligationens": "statsobligation",
    "statsobligationer": "statsobligation",
    "statsobligationerna": "statsobligation",
    "statsobligationernas": "statsobligation",
    "statsobligationers": "statsobligation",
    "statsobligations": "statsobligation",
    "statsrevisorer": "statsrevisor",
    "statsrevisorerna": "statsrevisor",
    "statsrevisorernas": "statsrevisor",
    "statsrevisorers": "statsrevisor",
    "statsrevisorn": "statsrevisor",
    "statsrevisorns": "statsrevisor",
    "statsrevisors": "statsrevisor",
    "statsrätten": "statsrätt",
    "statsrättens": "statsrätt",
    "statsrätts": "statsrätt",
    "statsråden": "statsråd",
    "statsrådens": "statsråd",
    "statsrådet": "statsråd",
    "statsrådets": "statsråd",
    "statsråds": "statsråd",
    "statsrådsberedningar": "statsrådsberedning",
    "statsrådsberedningarna": "statsrådsberedning",
    "statsrådsberedningarnas": "statsrådsberedning",
    "statsrådsberedningars": "statsrådsberedning",
    "statsrådsberedningen": "statsrådsberedning",
    "statsrådsberedningens": "statsrådsberedning",
    "statsrådsberednings": "statsrådsberedning",
    "statsrådslunchen": "statsrådslunch",
    "statsrådslunchens": "statsrådslunch",
    "statsrådsluncher": "statsrådslunch",
    "statsrådsluncherna": "statsrådslunch",
    "statsrådslunchernas": "statsrådslunch",
    "statsrådslunchers": "statsrådslunch",
    "statsrådslunchs": "statsrådslunch",
    "statsrådsmiddagar": "statsrådsmiddag",
    "statsrådsmiddagarna": "statsrådsmiddag",
    "statsrådsmiddagarnas": "statsrådsmiddag",
    "statsrådsmiddagars": "statsrådsmiddag",
    "statsrådsmiddagen": "statsrådsmiddag",
    "statsrådsmiddagens": "statsrådsmiddag",
    "statsrådsmiddags": "statsrådsmiddag",
    "statssekreterar": "statssekreterare",
    "statssekreteraren": "statssekreterare",
    "statssekreterarens": "statssekreterare",
    "statssekreterares": "statssekreterare",
    "statssekreterarna": "statssekreterare",
    "statssekreterarnas": "statssekreterare",
    "statsskicken": "statsskick",
    "statsskickens": "statsskick",
    "statsskicket": "statsskick",
    "statsskickets": "statsskick",
    "statsskicks": "statsskick",
    "statsskulden": "statsskuld",
    "statsskuldens": "statsskuld",
    "statsskulder": "statsskuld",
    "statsskulderna": "statsskuld",
    "statsskuldernas": "statsskuld",
    "statsskulders": "statsskuld",
    "statsskulds": "statsskuld",
    "statstjänstemannen": "statstjänsteman",
    "statstjänstemannens": "statstjänsteman",
    "statstjänstemans": "statstjänsteman",
    "statstjänstemän": "statstjänsteman",
    "statstjänstemännen": "statstjänsteman",
    "statstjänstemännens": "statstjänsteman",
    "statstjänstemäns": "statstjänsteman",
    "statsverket": "statsverk",
    "statsverkets": "statsverk",
    "statsverks": "statsverk",
    "statsverkspropositionen": "statsverksproposition",
    "statsverkspropositionens": "statsverksproposition",
    "statsverkspropositioner": "statsverksproposition",
    "statsverkspropositionerna": "statsverksproposition",
    "statsverkspropositionernas": "statsverksproposition",
    "statsverkspropositioners": "statsverksproposition",
    "statsverkspropositions": "statsverksproposition",
    "statsvetar": "statsvetare",
    "statsvetaren": "statsvetare",
    "statsvetarens": "statsvetare",
    "statsvetares": "statsvetare",
    "statsvetarna": "statsvetare",
    "statsvetarnas": "statsvetare",
    "statsvetenskapen": "statsvetenskap",
    "statsvetenskapens": "statsvetenskap",
    "statsvetenskaper": "statsvetenskap",
    "statsvetenskaperna": "statsvetenskap",
    "statsvetenskapernas": "statsvetenskap",
    "statsvetenskapers": "statsvetenskap",
    "statsvetenskaps": "statsvetenskap",
    "statsvälvningar": "statsvälvning",
    "statsvälvningarna": "statsvälvning",
    "statsvälvningarnas": "statsvälvning",
    "statsvälvningars": "statsvälvning",
    "statsvälvningen": "statsvälvning",
    "statsvälvningens": "statsvälvning",
    "statsvälvnings": "statsvälvning",
    "statsöverhuvuden": "statsöverhuvud",
    "statsöverhuvudena": "statsöverhuvud",
    "statsöverhuvudenas": "statsöverhuvud",
    "statsöverhuvudens": "statsöverhuvud",
    "statsöverhuvudet": "statsöverhuvud",
    "statsöverhuvudets": "statsöverhuvud",
    "statsöverhuvuds": "statsöverhuvud",
    "statt": "städja",
    "statts": "städja",
    "statuariska": "statuarisk",
    "statuariskare": "statuarisk",
    "statuariskares": "statuarisk",
    "statuariskas": "statuarisk",
    "statuariskast": "statuarisk",
    "statuariskaste": "statuarisk",
    "statuariskastes": "statuarisk",
    "statuariskasts": "statuarisk",
    "statuariske": "statuarisk",
    "statuariskes": "statuarisk",
    "statuarisks": "statuarisk",
    "statuariskt": "statuarisk",
    "statuariskts": "statuarisk",
    "statuerad": "statuera",
    "statuerade": "statuera",
    "statuerades": "statuera",
    "statuerads": "statuera",
    "statuerande": "statuera",
    "statueranden": "statuerande",
    "statuerandena": "statuerande",
    "statuerandenas": "statuerande",
    "statuerandens": "statuerande",
    "statuerandes": "statuerande",
    "statuerandet": "statuerande",
    "statuerandets": "statuerande",
    "statuerar": "statuera",
    "statueras": "statuera",
    "statuerat": "statuera",
    "statuerats": "statuera",
    "statuerbara": "statuerbar",
    "statuerbarare": "statuerbar",
    "statuerbarares": "statuerbar",
    "statuerbaras": "statuerbar",
    "statuerbarast": "statuerbar",
    "statuerbaraste": "statuerbar",
    "statuerbarastes": "statuerbar",
    "statuerbarasts": "statuerbar",
    "statuerbare": "statuerbar",
    "statuerbares": "statuerbar",
    "statuerbarheten": "statuerbarhet",
    "statuerbarhetens": "statuerbarhet",
    "statuerbarhets": "statuerbarhet",
    "statuerbars": "statuerbar",
    "statuerbart": "statuerbar",
    "statuerbarts": "statuerbar",
    "statueringar": "statuering",
    "statueringarna": "statuering",
    "statueringarnas": "statuering",
    "statueringars": "statuering",
    "statueringen": "statuering",
    "statueringens": "statuering",
    "statuerings": "statuering",
    "staturen": "statur",
    "staturens": "statur",
    "staturer": "statur",
    "staturerna": "statur",
    "staturernas": "statur",
    "staturers": "statur",
    "staturs": "statur",
    "statusen": "status",
    "statusens": "status",
    "statusmässiga": "statusmässig",
    "statusmässigare": "statusmässig",
    "statusmässigares": "statusmässig",
    "statusmässigas": "statusmässig",
    "statusmässigast": "statusmässig",
    "statusmässigaste": "statusmässig",
    "statusmässigastes": "statusmässig",
    "statusmässigasts": "statusmässig",
    "statusmässige": "statusmässig",
    "statusmässiges": "statusmässig",
    "statusmässigs": "statusmässig",
    "statusmässigt": "statusmässig",
    "statusmässigts": "statusmässig",
    "statussymbolen": "statussymbol",
    "statussymbolens": "statussymbol",
    "statussymboler": "statussymbol",
    "statussymbolerna": "statussymbol",
    "statussymbolernas": "statussymbol",
    "statussymbolers": "statussymbol",
    "statussymbols": "statussymbol",
    "statuten": "statut",
    "statutens": "statut",
    "statuter": "statut",
    "statuterna": "statut",
    "statuternas": "statut",
    "statuters": "statut",
    "statuts": "statut",
    "statyer": "staty",
    "statyerna": "staty",
    "statyernas": "staty",
    "statyers": "staty",
    "statyetten": "statyett",
    "statyettens": "statyett",
    "statyetter": "statyett",
    "statyetterna": "statyett",
    "statyetternas": "statyett",
    "statyetters": "statyett",
    "statyetts": "statyett",
    "statyn": "staty",
    "statyns": "staty",
    "statys": "staty",
    "stav": "stava",
    "stavad": "stava",
    "stavade": "stava",
    "stavades": "stava",
    "stavads": "stava",
    "stavande": "stava",
    "stavanden": "stavande",
    "stavandena": "stavande",
    "stavandenas": "stavande",
    "stavandens": "stavande",
    "stavandes": "stavande",
    "stavandet": "stavande",
    "stavandets": "stavande",
    "stavar": "stava",
    "stavarna": "stav",
    "stavarnas": "stav",
    "stavars": "stav",
    "stavas": "stava",
    "stavat": "stava",
    "stavats": "stava",
    "stavbrotten": "stavbrott",
    "stavbrottens": "stavbrott",
    "stavbrottet": "stavbrott",
    "stavbrottets": "stavbrott",
    "stavbrotts": "stavbrott",
    "stavelsen": "stavelse",
    "stavelsens": "stavelse",
    "stavelser": "stavelse",
    "stavelserna": "stavelse",
    "stavelsernas": "stavelse",
    "stavelsers": "stavelse",
    "stavelses": "stavelse",
    "stavelseskriften": "stavelseskrift",
    "stavelseskriftens": "stavelseskrift",
    "stavelseskrifter": "stavelseskrift",
    "stavelseskrifterna": "stavelseskrift",
    "stavelseskrifternas": "stavelseskrift",
    "stavelseskrifters": "stavelseskrift",
    "stavelseskrifts": "stavelseskrift",
    "staven": "stav",
    "stavens": "stav",
    "stavformiga": "stavformig",
    "stavformigas": "stavformig",
    "stavformige": "stavformig",
    "stavformiges": "stavformig",
    "stavformigs": "stavformig",
    "stavformigt": "stavformig",
    "stavformigts": "stavformig",
    "stavhoppen": "stavhopp",
    "stavhoppens": "stavhopp",
    "stavhoppet": "stavhopp",
    "stavhoppets": "stavhopp",
    "stavhopps": "stavhopp",
    "staviga": "stavig",
    "stavigare": "stavig",
    "stavigares": "stavig",
    "stavigas": "stavig",
    "stavigast": "stavig",
    "stavigaste": "stavig",
    "stavigastes": "stavig",
    "stavigasts": "stavig",
    "stavige": "stavig",
    "staviges": "stavig",
    "stavigs": "stavig",
    "stavigt": "stavig",
    "stavigts": "stavig",
    "stavkyrk": "stavkyrka",
    "stavkyrkan": "stavkyrka",
    "stavkyrkans": "stavkyrka",
    "stavkyrkas": "stavkyrka",
    "stavkyrke": "stavkyrka",
    "stavkyrko": "stavkyrka",
    "stavkyrkor": "stavkyrka",
    "stavkyrkorna": "stavkyrka",
    "stavkyrkornas": "stavkyrka",
    "stavkyrkors": "stavkyrka",
    "stavkyrks": "stavkyrka",
    "stavlamp": "stavlampa",
    "stavlampan": "stavlampa",
    "stavlampans": "stavlampa",
    "stavlampas": "stavlampa",
    "stavlampe": "stavlampa",
    "stavlampor": "stavlampa",
    "stavlamporna": "stavlampa",
    "stavlampornas": "stavlampa",
    "stavlampors": "stavlampa",
    "stavlamps": "stavlampa",
    "stavningar": "stavning",
    "stavningarna": "stavning",
    "stavningarnas": "stavning",
    "stavningars": "stavning",
    "stavningen": "stavning",
    "stavningens": "stavning",
    "stavnings": "stavning",
    "stavningsreformen": "stavningsreform",
    "stavningsreformens": "stavningsreform",
    "stavningsreformer": "stavningsreform",
    "stavningsreformerna": "stavningsreform",
    "stavningsreformernas": "stavningsreform",
    "stavningsreformers": "stavningsreform",
    "stavningsreforms": "stavningsreform",
    "stavrimmen": "stavrim",
    "stavrimmens": "stavrim",
    "stavrimmet": "stavrim",
    "stavrimmets": "stavrim",
    "stavrims": "stavrim",
    "stavs": "stav",
    "stearindoften": "stearindoft",
    "stearindoftens": "stearindoft",
    "stearindofter": "stearindoft",
    "stearindofterna": "stearindoft",
    "stearindofternas": "stearindoft",
    "stearindofters": "stearindoft",
    "stearindofts": "stearindoft",
    "stearinen": "stearin",
    "stearinens": "stearin",
    "stearinet": "stearin",
    "stearinets": "stearin",
    "stearinljusen": "stearinljus",
    "stearinljusens": "stearinljus",
    "stearinljuset": "stearinljus",
    "stearinljusets": "stearinljus",
    "stearins": "stearin",
    "stearinsyran": "stearinsyra",
    "stearinsyrans": "stearinsyra",
    "stearinsyras": "stearinsyra",
    "stearinsyre": "stearinsyra",
    "steeplechasen": "steeplechase",
    "steeplechasens": "steeplechase",
    "steeplechaser": "steeplechase",
    "steeplechaserna": "steeplechase",
    "steeplechasernas": "steeplechase",
    "steeplechasers": "steeplechase",
    "steeplechases": "steeplechase",
    "steg": "stiga",
    "stegad": "stega",
    "stegade": "stega",
    "stegades": "stega",
    "stegads": "stega",
    "stegande": "stega",
    "steganden": "stegande",
    "stegandena": "stegande",
    "stegandenas": "stegande",
    "stegandens": "stegande",
    "stegandes": "stegande",
    "stegandet": "stegande",
    "stegandets": "stegande",
    "stegar": "stege",
    "stegarna": "stege",
    "stegarnas": "stege",
    "stegars": "stege",
    "stegas": "stega",
    "stegat": "stega",
    "stegats": "stega",
    "stegbilar": "stegbil",
    "stegbilarna": "stegbil",
    "stegbilarnas": "stegbil",
    "stegbilars": "stegbil",
    "stegbilen": "stegbil",
    "stegbilens": "stegbil",
    "stegbils": "stegbil",
    "stegbåtar": "stegbåt",
    "stegbåtarna": "stegbåt",
    "stegbåtarnas": "stegbåt",
    "stegbåtars": "stegbåt",
    "stegbåten": "stegbåt",
    "stegbåtens": "stegbåt",
    "stegbåts": "stegbåt",
    "stegel": "stegla",
    "stegels": "stegel",
    "stegen": "stege",
    "stegens": "stege",
    "steges": "stege",
    "steget": "steg",
    "stegets": "steg",
    "steglad": "stegla",
    "steglade": "stegla",
    "steglades": "stegla",
    "steglads": "stegla",
    "steglande": "stegla",
    "steglanden": "steglande",
    "steglandena": "steglande",
    "steglandenas": "steglande",
    "steglandens": "steglande",
    "steglandes": "steglande",
    "steglandet": "steglande",
    "steglandets": "steglande",
    "steglar": "stegla",
    "steglas": "stegla",
    "steglat": "stegla",
    "steglats": "stegla",
    "steglen": "stegel",
    "steglens": "stegel",
    "steglet": "stegel",
    "steglets": "stegel",
    "steglits": "steglitsa",
    "steglitsan": "steglitsa",
    "steglitsans": "steglitsa",
    "steglitsas": "steglitsa",
    "steglitse": "steglitsa",
    "steglitsen": "steglits",
    "steglitsens": "steglits",
    "steglitser": "steglits",
    "steglitserna": "steglits",
    "steglitsernas": "steglits",
    "steglitsers": "steglits",
    "steglitsor": "steglitsa",
    "steglitsorna": "steglitsa",
    "steglitsornas": "steglitsa",
    "steglitsors": "steglitsa",
    "steglösa": "steglös",
    "steglösare": "steglös",
    "steglösares": "steglös",
    "steglösas": "steglös",
    "steglösast": "steglös",
    "steglösaste": "steglös",
    "steglösastes": "steglös",
    "steglösasts": "steglös",
    "steglöse": "steglös",
    "steglöses": "steglös",
    "steglösheten": "steglöshet",
    "steglöshetens": "steglöshet",
    "steglöshets": "steglöshet",
    "steglöst": "steglös",
    "steglösts": "steglös",
    "stegpallar": "stegpall",
    "stegpallarna": "stegpall",
    "stegpallarnas": "stegpall",
    "stegpallars": "stegpall",
    "stegpallen": "stegpall",
    "stegpallens": "stegpall",
    "stegpalls": "stegpall",
    "stegpinn": "stegpinne",
    "stegpinnar": "stegpinne",
    "stegpinnarna": "stegpinne",
    "stegpinnarnas": "stegpinne",
    "stegpinnars": "stegpinne",
    "stegpinnen": "stegpinne",
    "stegpinnens": "stegpinne",
    "stegpinnes": "stegpinne",
    "stegpinns": "stegpinne",
    "stegrad": "stegra",
    "stegrade": "stegra",
    "stegrades": "stegra",
    "stegrads": "stegra",
    "stegrande": "stegra",
    "stegranden": "stegrande",
    "stegrandena": "stegrande",
    "stegrandenas": "stegrande",
    "stegrandens": "stegrande",
    "stegrandes": "stegrande",
    "stegrandet": "stegrande",
    "stegrandets": "stegrande",
    "stegrar": "stegra",
    "stegras": "stegra",
    "stegrat": "stegra",
    "stegrats": "stegra",
    "stegringar": "stegring",
    "stegringarna": "stegring",
    "stegringarnas": "stegring",
    "stegringars": "stegring",
    "stegringen": "stegring",
    "stegringens": "stegring",
    "stegrings": "stegring",
    "stegräknar": "stegräknare",
    "stegräknaren": "stegräknare",
    "stegräknarens": "stegräknare",
    "stegräknares": "stegräknare",
    "stegräknarna": "stegräknare",
    "stegräknarnas": "stegräknare",
    "stegräknartävlingar": "stegräknartävling",
    "stegräknartävlingarna": "stegräknartävling",
    "stegräknartävlingarnas": "stegräknartävling",
    "stegräknartävlingars": "stegräknartävling",
    "stegräknartävlingen": "stegräknartävling",
    "stegräknartävlingens": "stegräknartävling",
    "stegräknartävlings": "stegräknartävling",
    "stegs": "stiga",
    "stegvisa": "stegvis",
    "stegvisare": "stegvis",
    "stegvisares": "stegvis",
    "stegvisas": "stegvis",
    "stegvisast": "stegvis",
    "stegvisaste": "stegvis",
    "stegvisastes": "stegvis",
    "stegvisasts": "stegvis",
    "stegvise": "stegvis",
    "stegvises": "stegvis",
    "stegvist": "stegvis",
    "stegvists": "stegvis",
    "stek": "steka",
    "stekande": "steka",
    "stekanden": "stekande",
    "stekandena": "stekande",
    "stekandenas": "stekande",
    "stekandens": "stekande",
    "stekandes": "stekande",
    "stekandet": "stekande",
    "stekandets": "stekande",
    "stekar": "stek",
    "stekarna": "stek",
    "stekarnas": "stek",
    "stekars": "stek",
    "stekas": "steka",
    "stekburgar": "stekburgare",
    "stekburgaren": "stekburgare",
    "stekburgarens": "stekburgare",
    "stekburgares": "stekburgare",
    "stekburgarna": "stekburgare",
    "stekburgarnas": "stekburgare",
    "stekeln": "stekel",
    "stekelns": "stekel",
    "stekels": "stekel",
    "steken": "stek",
    "stekens": "stek",
    "steker": "steka",
    "stekes": "steka",
    "steket": "stek",
    "stekets": "stek",
    "stekfläsket": "stekfläsk",
    "stekfläskets": "stekfläsk",
    "stekfläsks": "stekfläsk",
    "stekheta": "stekhet",
    "stekhetare": "stekhet",
    "stekhetares": "stekhet",
    "stekhetas": "stekhet",
    "stekhetast": "stekhet",
    "stekhetaste": "stekhet",
    "stekhetastes": "stekhet",
    "stekhetasts": "stekhet",
    "stekhete": "stekhet",
    "stekhetes": "stekhet",
    "stekhets": "stekhet",
    "stekhett": "stekhet",
    "stekhetts": "stekhet",
    "stekhusen": "stekhus",
    "stekhusens": "stekhus",
    "stekhuset": "stekhus",
    "stekhusets": "stekhus",
    "steklar": "stekel",
    "steklarna": "stekel",
    "steklarnas": "stekel",
    "steklars": "stekel",
    "stekpann": "stekpanna",
    "stekpannan": "stekpanna",
    "stekpannans": "stekpanna",
    "stekpannas": "stekpanna",
    "stekpanne": "stekpanna",
    "stekpannor": "stekpanna",
    "stekpannorna": "stekpanna",
    "stekpannornas": "stekpanna",
    "stekpannors": "stekpanna",
    "stekpanns": "stekpanna",
    "steks": "steka",
    "stekspad": "stekspade",
    "stekspadar": "stekspade",
    "stekspadarna": "stekspade",
    "stekspadarnas": "stekspade",
    "stekspadars": "stekspade",
    "stekspaden": "stekspade",
    "stekspadens": "stekspade",
    "stekspades": "stekspade",
    "stekspads": "stekspade",
    "stekspetten": "stekspett",
    "stekspettens": "stekspett",
    "stekspettet": "stekspett",
    "stekspettets": "stekspett",
    "stekspetts": "stekspett",
    "stekt": "steka",
    "stekta": "steka",
    "stektas": "steka",
    "stekte": "steka",
    "stektes": "steka",
    "stekts": "steka",
    "stekytan": "stekyta",
    "stekytans": "stekyta",
    "stekytas": "stekyta",
    "stekyte": "stekyta",
    "stekytor": "stekyta",
    "stekytorna": "stekyta",
    "stekytornas": "stekyta",
    "stekytors": "stekyta",
    "stel": "stele",
    "stela": "stel",
    "stelar": "stele",
    "stelare": "stel",
    "stelares": "stel",
    "stelarna": "stele",
    "stelarnas": "stele",
    "stelars": "stele",
    "stelas": "stel",
    "stelast": "stel",
    "stelaste": "stel",
    "stelastes": "stel",
    "stelasts": "stel",
    "stelbenta": "stelbent",
    "stelbentare": "stelbent",
    "stelbentares": "stelbent",
    "stelbentas": "stelbent",
    "stelbentast": "stelbent",
    "stelbentaste": "stelbent",
    "stelbentastes": "stelbent",
    "stelbentasts": "stelbent",
    "stelbente": "stelbent",
    "stelbentes": "stelbent",
    "stelbentheten": "stelbenthet",
    "stelbenthetens": "stelbenthet",
    "stelbentheter": "stelbenthet",
    "stelbentheterna": "stelbenthet",
    "stelbentheternas": "stelbenthet",
    "stelbentheters": "stelbenthet",
    "stelbenthets": "stelbenthet",
    "stelbents": "stelbent",
    "stele": "stel",
    "stelen": "stele",
    "stelens": "stele",
    "steles": "stele",
    "stelfrusens": "stelfrusen",
    "stelfruset": "stelfrusen",
    "stelfrusets": "stelfrusen",
    "stelfrusna": "stelfrusen",
    "stelfrusnare": "stelfrusen",
    "stelfrusnares": "stelfrusen",
    "stelfrusnas": "stelfrusen",
    "stelfrusnast": "stelfrusen",
    "stelfrusnaste": "stelfrusen",
    "stelfrusnastes": "stelfrusen",
    "stelfrusnasts": "stelfrusen",
    "stelfrusne": "stelfrusen",
    "stelfrusnes": "stelfrusen",
    "stelheten": "stelhet",
    "stelhetens": "stelhet",
    "stelheter": "stelhet",
    "stelheterna": "stelhet",
    "stelheternas": "stelhet",
    "stelheters": "stelhet",
    "stelhets": "stelhet",
    "stelkrampen": "stelkramp",
    "stelkrampens": "stelkramp",
    "stelkramps": "stelkramp",
    "stellara": "stellar",
    "stellarare": "stellar",
    "stellarares": "stellar",
    "stellaras": "stellar",
    "stellarast": "stellar",
    "stellaraste": "stellar",
    "stellarastes": "stellar",
    "stellarastronomien": "stellarastronomi",
    "stellarastronomiens": "stellarastronomi",
    "stellarastronomin": "stellarastronomi",
    "stellarastronomins": "stellarastronomi",
    "stellarastronomis": "stellarastronomi",
    "stellarasts": "stellar",
    "stellare": "stellar",
    "stellares": "stellar",
    "stellariska": "stellarisk",
    "stellariskare": "stellarisk",
    "stellariskares": "stellarisk",
    "stellariskas": "stellarisk",
    "stellariskast": "stellarisk",
    "stellariskaste": "stellarisk",
    "stellariskastes": "stellarisk",
    "stellariskasts": "stellarisk",
    "stellariske": "stellarisk",
    "stellariskes": "stellarisk",
    "stellarisks": "stellarisk",
    "stellariskt": "stellarisk",
    "stellariskts": "stellarisk",
    "stellars": "stellar",
    "stellart": "stellar",
    "stellarts": "stellar",
    "stelnad": "stelna",
    "stelnade": "stelna",
    "stelnades": "stelna",
    "stelnads": "stelna",
    "stelnande": "stelna",
    "stelnanden": "stelnande",
    "stelnandena": "stelnande",
    "stelnandenas": "stelnande",
    "stelnandens": "stelnande",
    "stelnandes": "stelnande",
    "stelnandet": "stelnande",
    "stelnandets": "stelnande",
    "stelnar": "stelna",
    "stelnas": "stelna",
    "stelnat": "stelna",
    "stelnats": "stelna",
    "stels": "stele",
    "stelt": "stel",
    "stelts": "stel",
    "sten": "stena",
    "stenad": "stena",
    "stenade": "stena",
    "stenades": "stena",
    "stenads": "stena",
    "stenande": "stena",
    "stenanden": "stenande",
    "stenandena": "stenande",
    "stenandenas": "stenande",
    "stenandens": "stenande",
    "stenandes": "stenande",
    "stenandet": "stenande",
    "stenandets": "stenande",
    "stenansamlingar": "stenansamling",
    "stenansamlingarna": "stenansamling",
    "stenansamlingarnas": "stenansamling",
    "stenansamlingars": "stenansamling",
    "stenansamlingen": "stenansamling",
    "stenansamlingens": "stenansamling",
    "stenansamlings": "stenansamling",
    "stenansikten": "stenansikte",
    "stenansiktena": "stenansikte",
    "stenansiktenas": "stenansikte",
    "stenansiktens": "stenansikte",
    "stenansiktes": "stenansikte",
    "stenansiktet": "stenansikte",
    "stenansiktets": "stenansikte",
    "stenansikts": "stenansikte",
    "stenar": "stena",
    "stenarna": "sten",
    "stenarnas": "sten",
    "stenars": "sten",
    "stenas": "stena",
    "stenat": "stena",
    "stenats": "stena",
    "stenattacken": "stenattack",
    "stenattackens": "stenattack",
    "stenattacker": "stenattack",
    "stenattackerna": "stenattack",
    "stenattackernas": "stenattack",
    "stenattackers": "stenattack",
    "stenattacks": "stenattack",
    "stenbitar": "stenbit",
    "stenbitarna": "stenbit",
    "stenbitarnas": "stenbit",
    "stenbitars": "stenbit",
    "stenbiten": "stenbit",
    "stenbitens": "stenbit",
    "stenbits": "stenbit",
    "stenblocken": "stenblock",
    "stenblockens": "stenblock",
    "stenblocket": "stenblock",
    "stenblockets": "stenblock",
    "stenblocks": "stenblock",
    "stenbockar": "stenbock",
    "stenbockarna": "stenbock",
    "stenbockarnas": "stenbock",
    "stenbockars": "stenbock",
    "stenbocken": "stenbock",
    "stenbockens": "stenbock",
    "stenbocks": "stenbock",
    "stenbottens": "stenbotten",
    "stenbottnar": "stenbotten",
    "stenbottnarna": "stenbotten",
    "stenbottnarnas": "stenbotten",
    "stenbottnars": "stenbotten",
    "stenbottnen": "stenbotten",
    "stenbottnens": "stenbotten",
    "stenbrotten": "stenbrott",
    "stenbrottens": "stenbrott",
    "stenbrottet": "stenbrott",
    "stenbrottets": "stenbrott",
    "stenbrotts": "stenbrott",
    "stenbräck": "stenbräcka",
    "stenbräckan": "stenbräcka",
    "stenbräckans": "stenbräcka",
    "stenbräckas": "stenbräcka",
    "stenbräcke": "stenbräcka",
    "stenbräckor": "stenbräcka",
    "stenbräckorna": "stenbräcka",
    "stenbräckornas": "stenbräcka",
    "stenbräckors": "stenbräcka",
    "stenbräcks": "stenbräcka",
    "stenbumlingar": "stenbumling",
    "stenbumlingarna": "stenbumling",
    "stenbumlingarnas": "stenbumling",
    "stenbumlingars": "stenbumling",
    "stenbumlingen": "stenbumling",
    "stenbumlingens": "stenbumling",
    "stenbumlings": "stenbumling",
    "stenbären": "stenbär",
    "stenbärens": "stenbär",
    "stenbäret": "stenbär",
    "stenbärets": "stenbär",
    "stenbärs": "stenbär",
    "stencilen": "stencil",
    "stencilens": "stencil",
    "stenciler": "stencil",
    "stencilerad": "stencilera",
    "stencilerade": "stencilera",
    "stencilerades": "stencilera",
    "stencilerads": "stencilera",
    "stencilerande": "stencilera",
    "stencileranden": "stencilerande",
    "stencilerandena": "stencilerande",
    "stencilerandenas": "stencilerande",
    "stencilerandens": "stencilerande",
    "stencilerandes": "stencilerande",
    "stencilerandet": "stencilerande",
    "stencilerandets": "stencilerande",
    "stencilerar": "stencilera",
    "stencileras": "stencilera",
    "stencilerat": "stencilera",
    "stencilerats": "stencilera",
    "stencilerbara": "stencilerbar",
    "stencilerbarare": "stencilerbar",
    "stencilerbarares": "stencilerbar",
    "stencilerbaras": "stencilerbar",
    "stencilerbarast": "stencilerbar",
    "stencilerbaraste": "stencilerbar",
    "stencilerbarastes": "stencilerbar",
    "stencilerbarasts": "stencilerbar",
    "stencilerbare": "stencilerbar",
    "stencilerbares": "stencilerbar",
    "stencilerbarheten": "stencilerbarhet",
    "stencilerbarhetens": "stencilerbarhet",
    "stencilerbarhets": "stencilerbarhet",
    "stencilerbars": "stencilerbar",
    "stencilerbart": "stencilerbar",
    "stencilerbarts": "stencilerbar",
    "stencileringar": "stencilering",
    "stencileringarna": "stencilering",
    "stencileringarnas": "stencilering",
    "stencileringars": "stencilering",
    "stencileringen": "stencilering",
    "stencileringens": "stencilering",
    "stencilerings": "stencilering",
    "stencilerna": "stencil",
    "stencilernas": "stencil",
    "stencilers": "stencil",
    "stencils": "stencil",
    "stendammlungan": "stendammlunga",
    "stendammlungans": "stendammlunga",
    "stendammlungas": "stendammlunga",
    "stendöda": "stendöd",
    "stendödare": "stendöd",
    "stendödares": "stendöd",
    "stendödas": "stendöd",
    "stendödast": "stendöd",
    "stendödaste": "stendöd",
    "stendödastes": "stendöd",
    "stendödasts": "stendöd",
    "stendöde": "stendöd",
    "stendödes": "stendöd",
    "stendödheten": "stendödhet",
    "stendödhetens": "stendödhet",
    "stendödhets": "stendödhet",
    "stendöds": "stendöd",
    "stendösar": "stendös",
    "stendösarna": "stendös",
    "stendösarnas": "stendös",
    "stendösars": "stendös",
    "stendösen": "stendös",
    "stendösens": "stendös",
    "stendött": "stendöd",
    "stendötts": "stendöd",
    "stendöva": "stendöv",
    "stendövare": "stendöv",
    "stendövares": "stendöv",
    "stendövas": "stendöv",
    "stendövast": "stendöv",
    "stendövaste": "stendöv",
    "stendövastes": "stendöv",
    "stendövasts": "stendöv",
    "stendöve": "stendöv",
    "stendöves": "stendöv",
    "stendövheten": "stendövhet",
    "stendövhetens": "stendövhet",
    "stendövhets": "stendövhet",
    "stendövs": "stendöv",
    "stendövt": "stendöv",
    "stendövts": "stendöv",
    "stenen": "sten",
    "stenens": "sten",
    "stenflis": "stenflisa",
    "stenflisan": "stenflisa",
    "stenflisans": "stenflisa",
    "stenflisas": "stenflisa",
    "stenflise": "stenflisa",
    "stenflisor": "stenflisa",
    "stenflisorna": "stenflisa",
    "stenflisornas": "stenflisa",
    "stenflisors": "stenflisa",
    "stenfotar": "stenfot",
    "stenfotarna": "stenfot",
    "stenfotarnas": "stenfot",
    "stenfotars": "stenfot",
    "stenfoten": "stenfot",
    "stenfotens": "stenfot",
    "stenfots": "stenfot",
    "stenfrukten": "stenfrukt",
    "stenfruktens": "stenfrukt",
    "stenfrukter": "stenfrukt",
    "stenfrukterna": "stenfrukt",
    "stenfrukternas": "stenfrukt",
    "stenfrukters": "stenfrukt",
    "stenfrukts": "stenfrukt",
    "stenfästningar": "stenfästning",
    "stenfästningarna": "stenfästning",
    "stenfästningarnas": "stenfästning",
    "stenfästningars": "stenfästning",
    "stenfästningen": "stenfästning",
    "stenfästningens": "stenfästning",
    "stenfästnings": "stenfästning",
    "stenfötter": "stenfot",
    "stenfötterna": "stenfot",
    "stenfötternas": "stenfot",
    "stenfötters": "stenfot",
    "stengeten": "stenget",
    "stengetens": "stenget",
    "stengets": "stenget",
    "stengetter": "stenget",
    "stengetterna": "stenget",
    "stengetternas": "stenget",
    "stengetters": "stenget",
    "stengodset": "stengods",
    "stengodsets": "stengods",
    "stengolven": "stengolv",
    "stengolvens": "stengolv",
    "stengolvet": "stengolv",
    "stengolvets": "stengolv",
    "stengolvs": "stengolv",
    "stenhallonen": "stenhallon",
    "stenhallonens": "stenhallon",
    "stenhallonet": "stenhallon",
    "stenhallonets": "stenhallon",
    "stenhallons": "stenhallon",
    "stenhuggar": "stenhuggare",
    "stenhuggaren": "stenhuggare",
    "stenhuggarens": "stenhuggare",
    "stenhuggares": "stenhuggare",
    "stenhuggarna": "stenhuggare",
    "stenhuggarnas": "stenhuggare",
    "stenhuggerier": "stenhuggeri",
    "stenhuggerierna": "stenhuggeri",
    "stenhuggeriernas": "stenhuggeri",
    "stenhuggeriers": "stenhuggeri",
    "stenhuggeriet": "stenhuggeri",
    "stenhuggeriets": "stenhuggeri",
    "stenhuggeris": "stenhuggeri",
    "stenhuggerit": "stenhuggeri",
    "stenhuggerits": "stenhuggeri",
    "stenhällar": "stenhäll",
    "stenhällarna": "stenhäll",
    "stenhällarnas": "stenhäll",
    "stenhällars": "stenhäll",
    "stenhällen": "stenhäll",
    "stenhällens": "stenhäll",
    "stenhälls": "stenhäll",
    "stenhårda": "stenhård",
    "stenhårdare": "stenhård",
    "stenhårdares": "stenhård",
    "stenhårdas": "stenhård",
    "stenhårdast": "stenhård",
    "stenhårdaste": "stenhård",
    "stenhårdastes": "stenhård",
    "stenhårdasts": "stenhård",
    "stenhårde": "stenhård",
    "stenhårdes": "stenhård",
    "stenhårdheten": "stenhårdhet",
    "stenhårdhetens": "stenhårdhet",
    "stenhårdhets": "stenhårdhet",
    "stenhårds": "stenhård",
    "stenhårt": "stenhård",
    "stenhårts": "stenhård",
    "steniga": "stenig",
    "stenigare": "stenig",
    "stenigares": "stenig",
    "stenigas": "stenig",
    "stenigast": "stenig",
    "stenigaste": "stenig",
    "stenigastes": "stenig",
    "stenigasts": "stenig",
    "stenige": "stenig",
    "steniges": "stenig",
    "stenigs": "stenig",
    "stenigt": "stenig",
    "stenigts": "stenig",
    "stenkak": "stenkaka",
    "stenkakan": "stenkaka",
    "stenkakans": "stenkaka",
    "stenkakas": "stenkaka",
    "stenkake": "stenkaka",
    "stenkakor": "stenkaka",
    "stenkakorna": "stenkaka",
    "stenkakornas": "stenkaka",
    "stenkakors": "stenkaka",
    "stenkaks": "stenkaka",
    "stenkastanden": "stenkastande",
    "stenkastandena": "stenkastande",
    "stenkastandenas": "stenkastande",
    "stenkastandens": "stenkastande",
    "stenkastandes": "stenkastande",
    "stenkastandet": "stenkastande",
    "stenkastandets": "stenkastande",
    "stenkasten": "stenkast",
    "stenkastens": "stenkast",
    "stenkastet": "stenkast",
    "stenkastets": "stenkast",
    "stenkastningar": "stenkastning",
    "stenkastningarna": "stenkastning",
    "stenkastningarnas": "stenkastning",
    "stenkastningars": "stenkastning",
    "stenkastningen": "stenkastning",
    "stenkastningens": "stenkastning",
    "stenkastnings": "stenkastning",
    "stenkasts": "stenkast",
    "stenkist": "stenkista",
    "stenkistan": "stenkista",
    "stenkistans": "stenkista",
    "stenkistas": "stenkista",
    "stenkiste": "stenkista",
    "stenkistor": "stenkista",
    "stenkistorna": "stenkista",
    "stenkistornas": "stenkista",
    "stenkistors": "stenkista",
    "stenknäckar": "stenknäck",
    "stenknäckarna": "stenknäck",
    "stenknäckarnas": "stenknäck",
    "stenknäckars": "stenknäck",
    "stenknäcken": "stenknäck",
    "stenknäckens": "stenknäck",
    "stenknäcks": "stenknäck",
    "stenkolen": "stenkol",
    "stenkolens": "stenkol",
    "stenkolet": "stenkol",
    "stenkolets": "stenkol",
    "stenkollen": "stenkoll",
    "stenkollens": "stenkoll",
    "stenkolls": "stenkoll",
    "stenkols": "stenkol",
    "stenkolsbitar": "stenkolsbit",
    "stenkolsbitarna": "stenkolsbit",
    "stenkolsbitarnas": "stenkolsbit",
    "stenkolsbitars": "stenkolsbit",
    "stenkolsbiten": "stenkolsbit",
    "stenkolsbitens": "stenkolsbit",
    "stenkolsbits": "stenkolsbit",
    "stenkolsperioden": "stenkolsperiod",
    "stenkolsperiodens": "stenkolsperiod",
    "stenkolsperiods": "stenkolsperiod",
    "stenkolstjäran": "stenkolstjära",
    "stenkolstjärans": "stenkolstjära",
    "stenkolstjäras": "stenkolstjära",
    "stenkolstjäre": "stenkolstjära",
    "stenkumlen": "stenkummel",
    "stenkumlens": "stenkummel",
    "stenkumlet": "stenkummel",
    "stenkumlets": "stenkummel",
    "stenkummels": "stenkummel",
    "stenlagda": "stenlagd",
    "stenlagdare": "stenlagd",
    "stenlagdares": "stenlagd",
    "stenlagdas": "stenlagd",
    "stenlagdast": "stenlagd",
    "stenlagdaste": "stenlagd",
    "stenlagdastes": "stenlagd",
    "stenlagdasts": "stenlagd",
    "stenlagde": "stenlagd",
    "stenlagdes": "stenlagd",
    "stenlagds": "stenlagd",
    "stenlagt": "stenlagd",
    "stenlagts": "stenlagd",
    "stenlungan": "stenlunga",
    "stenlungans": "stenlunga",
    "stenlungas": "stenlunga",
    "stenläggningar": "stenläggning",
    "stenläggningarna": "stenläggning",
    "stenläggningarnas": "stenläggning",
    "stenläggningars": "stenläggning",
    "stenläggningen": "stenläggning",
    "stenläggningens": "stenläggning",
    "stenläggnings": "stenläggning",
    "stenmurar": "stenmur",
    "stenmurarna": "stenmur",
    "stenmurarnas": "stenmur",
    "stenmurars": "stenmur",
    "stenmuren": "stenmur",
    "stenmurens": "stenmur",
    "stenmurs": "stenmur",
    "stenografen": "stenograf",
    "stenografens": "stenograf",
    "stenografer": "stenograf",
    "stenograferad": "stenografera",
    "stenograferade": "stenografera",
    "stenograferades": "stenografera",
    "stenograferads": "stenografera",
    "stenograferande": "stenografera",
    "stenograferanden": "stenograferande",
    "stenograferandena": "stenograferande",
    "stenograferandenas": "stenograferande",
    "stenograferandens": "stenograferande",
    "stenograferandes": "stenograferande",
    "stenograferandet": "stenograferande",
    "stenograferandets": "stenograferande",
    "stenograferar": "stenografera",
    "stenograferas": "stenografera",
    "stenograferat": "stenografera",
    "stenograferats": "stenografera",
    "stenograferbara": "stenograferbar",
    "stenograferbarare": "stenograferbar",
    "stenograferbarares": "stenograferbar",
    "stenograferbaras": "stenograferbar",
    "stenograferbarast": "stenograferbar",
    "stenograferbaraste": "stenograferbar",
    "stenograferbarastes": "stenograferbar",
    "stenograferbarasts": "stenograferbar",
    "stenograferbare": "stenograferbar",
    "stenograferbares": "stenograferbar",
    "stenograferbarheten": "stenograferbarhet",
    "stenograferbarhetens": "stenograferbarhet",
    "stenograferbarhets": "stenograferbarhet",
    "stenograferbars": "stenograferbar",
    "stenograferbart": "stenograferbar",
    "stenograferbarts": "stenograferbar",
    "stenograferingar": "stenografering",
    "stenograferingarna": "stenografering",
    "stenograferingarnas": "stenografering",
    "stenograferingars": "stenografering",
    "stenograferingen": "stenografering",
    "stenograferingens": "stenografering",
    "stenograferings": "stenografering",
    "stenograferna": "stenograf",
    "stenografernas": "stenograf",
    "stenografers": "stenograf",
    "stenografien": "stenografi",
    "stenografiens": "stenografi",
    "stenografin": "stenografi",
    "stenografins": "stenografi",
    "stenografis": "stenografi",
    "stenografs": "stenograf",
    "stenogrammen": "stenogram",
    "stenogrammens": "stenogram",
    "stenogrammet": "stenogram",
    "stenogrammets": "stenogram",
    "stenograms": "stenogram",
    "stenosen": "stenos",
    "stenosens": "stenos",
    "stenoser": "stenos",
    "stenoserna": "stenos",
    "stenosernas": "stenos",
    "stenosers": "stenos",
    "stenotopen": "stenotop",
    "stenotopens": "stenotop",
    "stenotoper": "stenotop",
    "stenotoperna": "stenotop",
    "stenotopernas": "stenotop",
    "stenotopers": "stenotop",
    "stenotops": "stenotop",
    "stenpartier": "stenparti",
    "stenpartierna": "stenparti",
    "stenpartiernas": "stenparti",
    "stenpartiers": "stenparti",
    "stenpartiet": "stenparti",
    "stenpartiets": "stenparti",
    "stenpartis": "stenparti",
    "stenpartit": "stenparti",
    "stenpartits": "stenparti",
    "stenplatt": "stenplatta",
    "stenplattan": "stenplatta",
    "stenplattans": "stenplatta",
    "stenplattas": "stenplatta",
    "stenplatte": "stenplatta",
    "stenplattor": "stenplatta",
    "stenplattorna": "stenplatta",
    "stenplattornas": "stenplatta",
    "stenplattors": "stenplatta",
    "stenplatts": "stenplatta",
    "stenrika": "stenrik",
    "stenrikare": "stenrik",
    "stenrikares": "stenrik",
    "stenrikas": "stenrik",
    "stenrikast": "stenrik",
    "stenrikaste": "stenrik",
    "stenrikastes": "stenrik",
    "stenrikasts": "stenrik",
    "stenrike": "stenrik",
    "stenrikes": "stenrik",
    "stenriks": "stenrik",
    "stenrikt": "stenrik",
    "stenrikts": "stenrik",
    "stenrös": "stenröse",
    "stenrösen": "stenröse",
    "stenrösena": "stenröse",
    "stenrösenas": "stenröse",
    "stenrösens": "stenröse",
    "stenröses": "stenröse",
    "stenröset": "stenröse",
    "stenrösets": "stenröse",
    "stensaltet": "stensalt",
    "stensaltets": "stensalt",
    "stensalts": "stensalt",
    "stensatta": "stensatt",
    "stensattare": "stensatt",
    "stensattares": "stensatt",
    "stensattas": "stensatt",
    "stensattast": "stensatt",
    "stensattaste": "stensatt",
    "stensattastes": "stensatt",
    "stensattasts": "stensatt",
    "stensatte": "stensatt",
    "stensattes": "stensatt",
    "stensatts": "stensatt",
    "stenskotten": "stenskott",
    "stenskottens": "stenskott",
    "stenskottet": "stenskott",
    "stenskottets": "stenskott",
    "stenskotts": "stenskott",
    "stenskottsskydden": "stenskottsskydd",
    "stenskottsskyddens": "stenskottsskydd",
    "stenskottsskyddet": "stenskottsskydd",
    "stenskottsskyddets": "stenskottsskydd",
    "stenskottsskydds": "stenskottsskydd",
    "stenskvätt": "stenskvätta",
    "stenskvättan": "stenskvätta",
    "stenskvättans": "stenskvätta",
    "stenskvättas": "stenskvätta",
    "stenskvätte": "stenskvätta",
    "stenskvättor": "stenskvätta",
    "stenskvättorna": "stenskvätta",
    "stenskvättornas": "stenskvätta",
    "stenskvättors": "stenskvätta",
    "stenskvätts": "stenskvätta",
    "stensoppar": "stensopp",
    "stensopparna": "stensopp",
    "stensopparnas": "stensopp",
    "stensoppars": "stensopp",
    "stensoppen": "stensopp",
    "stensoppens": "stensopp",
    "stensopps": "stensopp",
    "stenstilen": "stenstil",
    "stenstilens": "stenstil",
    "stenstils": "stenstil",
    "stensättar": "stensättare",
    "stensättaren": "stensättare",
    "stensättarens": "stensättare",
    "stensättares": "stensättare",
    "stensättarna": "stensättare",
    "stensättarnas": "stensättare",
    "stensättningar": "stensättning",
    "stensättningarna": "stensättning",
    "stensättningarnas": "stensättning",
    "stensättningars": "stensättning",
    "stensättningen": "stensättning",
    "stensättningens": "stensättning",
    "stensättnings": "stensättning",
    "stensöt": "stensöta",
    "stensötan": "stensöta",
    "stensötans": "stensöta",
    "stensötas": "stensöta",
    "stensöte": "stensöta",
    "stensötor": "stensöta",
    "stensötorna": "stensöta",
    "stensötornas": "stensöta",
    "stensötors": "stensöta",
    "stensöts": "stensöta",
    "stentavel": "stentavla",
    "stentavlan": "stentavla",
    "stentavlans": "stentavla",
    "stentavlas": "stentavla",
    "stentavle": "stentavla",
    "stentavlor": "stentavla",
    "stentavlorna": "stentavla",
    "stentavlornas": "stentavla",
    "stentavlors": "stentavla",
    "stentorsrösten": "stentorsröst",
    "stentorsröstens": "stentorsröst",
    "stentorsröster": "stentorsröst",
    "stentorsrösterna": "stentorsröst",
    "stentorsrösternas": "stentorsröst",
    "stentorsrösters": "stentorsröst",
    "stentorsrösts": "stentorsröst",
    "stentorsstämman": "stentorsstämma",
    "stentorsstämmans": "stentorsstämma",
    "stentorsstämmas": "stentorsstämma",
    "stentorsstämme": "stentorsstämma",
    "stentorsstämmo": "stentorsstämma",
    "stentorsstämmor": "stentorsstämma",
    "stentorsstämmorna": "stentorsstämma",
    "stentorsstämmornas": "stentorsstämma",
    "stentorsstämmors": "stentorsstämma",
    "stentrapp": "stentrappa",
    "stentrappan": "stentrappa",
    "stentrappans": "stentrappa",
    "stentrappas": "stentrappa",
    "stentrappe": "stentrappa",
    "stentrappor": "stentrappa",
    "stentrapporna": "stentrappa",
    "stentrappornas": "stentrappa",
    "stentrappors": "stentrappa",
    "stentrapps": "stentrappa",
    "stenverktygen": "stenverktyg",
    "stenverktygens": "stenverktyg",
    "stenverktyget": "stenverktyg",
    "stenverktygets": "stenverktyg",
    "stenverktygs": "stenverktyg",
    "stenväggar": "stenvägg",
    "stenväggarna": "stenvägg",
    "stenväggarnas": "stenvägg",
    "stenväggars": "stenvägg",
    "stenväggen": "stenvägg",
    "stenväggens": "stenvägg",
    "stenväggs": "stenvägg",
    "stenyx": "stenyxa",
    "stenyxan": "stenyxa",
    "stenyxans": "stenyxa",
    "stenyxas": "stenyxa",
    "stenyxe": "stenyxa",
    "stenyxor": "stenyxa",
    "stenyxorna": "stenyxa",
    "stenyxornas": "stenyxa",
    "stenyxors": "stenyxa",
    "stenåldern": "stenålder",
    "stenålderns": "stenålder",
    "stenålders": "stenålder",
    "stenåldersfynden": "stenåldersfynd",
    "stenåldersfyndens": "stenåldersfynd",
    "stenåldersfyndet": "stenåldersfynd",
    "stenåldersfyndets": "stenåldersfynd",
    "stenåldersfynds": "stenåldersfynd",
    "stenåldershjärn": "stenåldershjärna",
    "stenåldershjärnan": "stenåldershjärna",
    "stenåldershjärnans": "stenåldershjärna",
    "stenåldershjärnas": "stenåldershjärna",
    "stenåldershjärne": "stenåldershjärna",
    "stenåldershjärnor": "stenåldershjärna",
    "stenåldershjärnorna": "stenåldershjärna",
    "stenåldershjärnornas": "stenåldershjärna",
    "stenåldershjärnors": "stenåldershjärna",
    "stenåldershjärns": "stenåldershjärna",
    "stenåldersmässiga": "stenåldersmässig",
    "stenåldersmässigare": "stenåldersmässig",
    "stenåldersmässigares": "stenåldersmässig",
    "stenåldersmässigas": "stenåldersmässig",
    "stenåldersmässigast": "stenåldersmässig",
    "stenåldersmässigaste": "stenåldersmässig",
    "stenåldersmässigastes": "stenåldersmässig",
    "stenåldersmässigasts": "stenåldersmässig",
    "stenåldersmässige": "stenåldersmässig",
    "stenåldersmässiges": "stenåldersmässig",
    "stenåldersmässigs": "stenåldersmässig",
    "stenåldersmässigt": "stenåldersmässig",
    "stenåldersmässigts": "stenåldersmässig",
    "stenåldersnivåer": "stenåldersnivå",
    "stenåldersnivåerna": "stenåldersnivå",
    "stenåldersnivåernas": "stenåldersnivå",
    "stenåldersnivåers": "stenåldersnivå",
    "stenåldersnivån": "stenåldersnivå",
    "stenåldersnivåns": "stenåldersnivå",
    "stenåldersnivås": "stenåldersnivå",
    "stenåldersyx": "stenåldersyxa",
    "stenåldersyxan": "stenåldersyxa",
    "stenåldersyxans": "stenåldersyxa",
    "stenåldersyxas": "stenåldersyxa",
    "stenåldersyxe": "stenåldersyxa",
    "stenåldersyxor": "stenåldersyxa",
    "stenåldersyxorna": "stenåldersyxa",
    "stenåldersyxornas": "stenåldersyxa",
    "stenåldersyxors": "stenåldersyxa",
    "stenökenn": "stenöken",
    "stenökenns": "stenöken",
    "stenökens": "stenöken",
    "stenöknar": "stenöken",
    "stenöknarna": "stenöken",
    "stenöknarnas": "stenöken",
    "stenöknars": "stenöken",
    "stepen": "step",
    "stepens": "step",
    "stepp": "steppa",
    "steppad": "steppa",
    "steppade": "steppa",
    "steppades": "steppa",
    "steppads": "steppa",
    "steppande": "steppa",
    "steppanden": "steppande",
    "steppandena": "steppande",
    "steppandenas": "steppande",
    "steppandens": "steppande",
    "steppandes": "steppande",
    "steppandet": "steppande",
    "steppandets": "steppande",
    "steppar": "steppa",
    "steppas": "steppa",
    "steppat": "steppa",
    "steppats": "steppa",
    "steppen": "stepp",
    "steppens": "stepp",
    "stepps": "stepp",
    "steps": "step",
    "steradianen": "steradian",
    "steradianens": "steradian",
    "steradianer": "steradian",
    "steradianerna": "steradian",
    "steradianernas": "steradian",
    "steradianers": "steradian",
    "steradians": "steradian",
    "sterbhusen": "sterbhus",
    "sterbhusens": "sterbhus",
    "sterbhuset": "sterbhus",
    "sterbhusets": "sterbhus",
    "stereoanläggningar": "stereoanläggning",
    "stereoanläggningarna": "stereoanläggning",
    "stereoanläggningarnas": "stereoanläggning",
    "stereoanläggningars": "stereoanläggning",
    "stereoanläggningen": "stereoanläggning",
    "stereoanläggningens": "stereoanläggning",
    "stereoanläggnings": "stereoanläggning",
    "stereobilden": "stereobild",
    "stereobildens": "stereobild",
    "stereobilder": "stereobild",
    "stereobilderna": "stereobild",
    "stereobildernas": "stereobild",
    "stereobilders": "stereobild",
    "stereobilds": "stereobild",
    "stereofonien": "stereofoni",
    "stereofoniens": "stereofoni",
    "stereofonin": "stereofoni",
    "stereofonins": "stereofoni",
    "stereofonis": "stereofoni",
    "stereofoniska": "stereofonisk",
    "stereofoniskare": "stereofonisk",
    "stereofoniskares": "stereofonisk",
    "stereofoniskas": "stereofonisk",
    "stereofoniskast": "stereofonisk",
    "stereofoniskaste": "stereofonisk",
    "stereofoniskastes": "stereofonisk",
    "stereofoniskasts": "stereofonisk",
    "stereofoniske": "stereofonisk",
    "stereofoniskes": "stereofonisk",
    "stereofonisks": "stereofonisk",
    "stereofoniskt": "stereofonisk",
    "stereofoniskts": "stereofonisk",
    "stereofotograferad": "stereofotografera",
    "stereofotograferade": "stereofotografera",
    "stereofotograferades": "stereofotografera",
    "stereofotograferads": "stereofotografera",
    "stereofotograferande": "stereofotografera",
    "stereofotograferanden": "stereofotograferande",
    "stereofotograferandena": "stereofotograferande",
    "stereofotograferandenas": "stereofotograferande",
    "stereofotograferandens": "stereofotograferande",
    "stereofotograferandes": "stereofotograferande",
    "stereofotograferandet": "stereofotograferande",
    "stereofotograferandets": "stereofotograferande",
    "stereofotograferar": "stereofotografera",
    "stereofotograferas": "stereofotografera",
    "stereofotograferat": "stereofotografera",
    "stereofotograferats": "stereofotografera",
    "stereofotograferbara": "stereofotograferbar",
    "stereofotograferbarare": "stereofotograferbar",
    "stereofotograferbarares": "stereofotograferbar",
    "stereofotograferbaras": "stereofotograferbar",
    "stereofotograferbarast": "stereofotograferbar",
    "stereofotograferbaraste": "stereofotograferbar",
    "stereofotograferbarastes": "stereofotograferbar",
    "stereofotograferbarasts": "stereofotograferbar",
    "stereofotograferbare": "stereofotograferbar",
    "stereofotograferbares": "stereofotograferbar",
    "stereofotograferbarheten": "stereofotograferbarhet",
    "stereofotograferbarhetens": "stereofotograferbarhet",
    "stereofotograferbarhets": "stereofotograferbarhet",
    "stereofotograferbars": "stereofotograferbar",
    "stereofotograferbart": "stereofotograferbar",
    "stereofotograferbarts": "stereofotograferbar",
    "stereofotograferingar": "stereofotografering",
    "stereofotograferingarna": "stereofotografering",
    "stereofotograferingarnas": "stereofotografering",
    "stereofotograferingars": "stereofotografering",
    "stereofotograferingen": "stereofotografering",
    "stereofotograferingens": "stereofotografering",
    "stereofotograferings": "stereofotografering",
    "stereoisomerien": "stereoisomeri",
    "stereoisomeriens": "stereoisomeri",
    "stereoisomerin": "stereoisomeri",
    "stereoisomerins": "stereoisomeri",
    "stereoisomeris": "stereoisomeri",
    "stereokemien": "stereokemi",
    "stereokemiens": "stereokemi",
    "stereokemin": "stereokemi",
    "stereokemins": "stereokemi",
    "stereokemis": "stereokemi",
    "stereometrien": "stereometri",
    "stereometriens": "stereometri",
    "stereometrin": "stereometri",
    "stereometrins": "stereometri",
    "stereometris": "stereometri",
    "stereon": "stereo",
    "stereons": "stereo",
    "stereos": "stereo",
    "stereoseendes": "stereoseende",
    "stereoseendet": "stereoseende",
    "stereoseendets": "stereoseende",
    "stereoskopen": "stereoskop",
    "stereoskopens": "stereoskop",
    "stereoskopet": "stereoskop",
    "stereoskopets": "stereoskop",
    "stereoskopien": "stereoskopi",
    "stereoskopiens": "stereoskopi",
    "stereoskopin": "stereoskopi",
    "stereoskopins": "stereoskopi",
    "stereoskopis": "stereoskopi",
    "stereoskops": "stereoskop",
    "stereotypa": "stereotyp",
    "stereotypare": "stereotyp",
    "stereotypares": "stereotyp",
    "stereotypas": "stereotyp",
    "stereotypast": "stereotyp",
    "stereotypaste": "stereotyp",
    "stereotypastes": "stereotyp",
    "stereotypasts": "stereotyp",
    "stereotype": "stereotyp",
    "stereotypen": "stereotyp",
    "stereotypens": "stereotyp",
    "stereotyper": "stereotyp",
    "stereotyperad": "stereotypera",
    "stereotyperade": "stereotypera",
    "stereotyperades": "stereotypera",
    "stereotyperads": "stereotypera",
    "stereotyperande": "stereotypera",
    "stereotyperanden": "stereotyperande",
    "stereotyperandena": "stereotyperande",
    "stereotyperandenas": "stereotyperande",
    "stereotyperandens": "stereotyperande",
    "stereotyperandes": "stereotyperande",
    "stereotyperandet": "stereotyperande",
    "stereotyperandets": "stereotyperande",
    "stereotyperar": "stereotypera",
    "stereotyperas": "stereotypera",
    "stereotyperat": "stereotypera",
    "stereotyperats": "stereotypera",
    "stereotyperbara": "stereotyperbar",
    "stereotyperbarare": "stereotyperbar",
    "stereotyperbarares": "stereotyperbar",
    "stereotyperbaras": "stereotyperbar",
    "stereotyperbarast": "stereotyperbar",
    "stereotyperbaraste": "stereotyperbar",
    "stereotyperbarastes": "stereotyperbar",
    "stereotyperbarasts": "stereotyperbar",
    "stereotyperbare": "stereotyperbar",
    "stereotyperbares": "stereotyperbar",
    "stereotyperbarheten": "stereotyperbarhet",
    "stereotyperbarhetens": "stereotyperbarhet",
    "stereotyperbarhets": "stereotyperbarhet",
    "stereotyperbars": "stereotyperbar",
    "stereotyperbart": "stereotyperbar",
    "stereotyperbarts": "stereotyperbar",
    "stereotyperingar": "stereotypering",
    "stereotyperingarna": "stereotypering",
    "stereotyperingarnas": "stereotypering",
    "stereotyperingars": "stereotypering",
    "stereotyperingen": "stereotypering",
    "stereotyperingens": "stereotypering",
    "stereotyperings": "stereotypering",
    "stereotyperna": "stereotyp",
    "stereotypernas": "stereotyp",
    "stereotypers": "stereotyp",
    "stereotypes": "stereotyp",
    "stereotypien": "stereotypi",
    "stereotypiens": "stereotypi",
    "stereotypier": "stereotypi",
    "stereotypierna": "stereotypi",
    "stereotypiernas": "stereotypi",
    "stereotypiers": "stereotypi",
    "stereotypin": "stereotypi",
    "stereotypins": "stereotypi",
    "stereotypis": "stereotypi",
    "stereotyps": "stereotyp",
    "stereotypt": "stereotyp",
    "stereotypts": "stereotyp",
    "sterila": "steril",
    "sterilare": "steril",
    "sterilares": "steril",
    "sterilas": "steril",
    "sterilast": "steril",
    "sterilaste": "steril",
    "sterilastes": "steril",
    "sterilasts": "steril",
    "sterile": "steril",
    "steriles": "steril",
    "steriliserad": "sterilisera",
    "steriliserade": "sterilisera",
    "steriliserades": "sterilisera",
    "steriliserads": "sterilisera",
    "steriliserande": "sterilisera",
    "steriliseranden": "steriliserande",
    "steriliserandena": "steriliserande",
    "steriliserandenas": "steriliserande",
    "steriliserandens": "steriliserande",
    "steriliserandes": "steriliserande",
    "steriliserandet": "steriliserande",
    "steriliserandets": "steriliserande",
    "steriliserar": "sterilisera",
    "steriliseras": "sterilisera",
    "steriliserat": "sterilisera",
    "steriliserats": "sterilisera",
    "steriliserbara": "steriliserbar",
    "steriliserbarare": "steriliserbar",
    "steriliserbarares": "steriliserbar",
    "steriliserbaras": "steriliserbar",
    "steriliserbarast": "steriliserbar",
    "steriliserbaraste": "steriliserbar",
    "steriliserbarastes": "steriliserbar",
    "steriliserbarasts": "steriliserbar",
    "steriliserbare": "steriliserbar",
    "steriliserbares": "steriliserbar",
    "steriliserbarheten": "steriliserbarhet",
    "steriliserbarhetens": "steriliserbarhet",
    "steriliserbarhets": "steriliserbarhet",
    "steriliserbars": "steriliserbar",
    "steriliserbart": "steriliserbar",
    "steriliserbarts": "steriliserbar",
    "steriliseringar": "sterilisering",
    "steriliseringarna": "sterilisering",
    "steriliseringarnas": "sterilisering",
    "steriliseringars": "sterilisering",
    "steriliseringen": "sterilisering",
    "steriliseringens": "sterilisering",
    "steriliserings": "sterilisering",
    "steriliteten": "sterilitet",
    "sterilitetens": "sterilitet",
    "steriliteter": "sterilitet",
    "steriliteterna": "sterilitet",
    "steriliteternas": "sterilitet",
    "steriliteters": "sterilitet",
    "sterilitets": "sterilitet",
    "sterils": "steril",
    "sterilt": "steril",
    "sterilts": "steril",
    "sterinen": "sterin",
    "sterinens": "sterin",
    "steriner": "sterin",
    "sterinerna": "sterin",
    "sterinernas": "sterin",
    "steriners": "sterin",
    "sterins": "sterin",
    "steriska": "sterisk",
    "steriskare": "sterisk",
    "steriskares": "sterisk",
    "steriskas": "sterisk",
    "steriskast": "sterisk",
    "steriskaste": "sterisk",
    "steriskastes": "sterisk",
    "steriskasts": "sterisk",
    "steriske": "sterisk",
    "steriskes": "sterisk",
    "sterisks": "sterisk",
    "steriskt": "sterisk",
    "steriskts": "sterisk",
    "sterlingen": "sterling",
    "sterlingens": "sterling",
    "sterlings": "sterling",
    "sternalpunktionen": "sternalpunktion",
    "sternalpunktionens": "sternalpunktion",
    "sternalpunktioner": "sternalpunktion",
    "sternalpunktionerna": "sternalpunktion",
    "sternalpunktionernas": "sternalpunktion",
    "sternalpunktioners": "sternalpunktion",
    "sternalpunktions": "sternalpunktion",
    "sternums": "sternum",
    "steroiden": "steroid",
    "steroidens": "steroid",
    "steroider": "steroid",
    "steroiderna": "steroid",
    "steroidernas": "steroid",
    "steroiders": "steroid",
    "steroids": "steroid",
    "sterolen": "sterol",
    "sterolens": "sterol",
    "steroler": "sterol",
    "sterolerna": "sterol",
    "sterolernas": "sterol",
    "sterolers": "sterol",
    "sterols": "sterol",
    "stetoskopen": "stetoskop",
    "stetoskopens": "stetoskop",
    "stetoskopet": "stetoskop",
    "stetoskopets": "stetoskop",
    "stetoskops": "stetoskop",
    "stewardar": "steward",
    "stewardarna": "steward",
    "stewardarnas": "steward",
    "stewardars": "steward",
    "stewarden": "steward",
    "stewardens": "steward",
    "stewarder": "steward",
    "stewarderna": "steward",
    "stewardernas": "steward",
    "stewarders": "steward",
    "stewards": "steward",
    "stewartar": "stewart",
    "stewartarna": "stewart",
    "stewartarnas": "stewart",
    "stewartars": "stewart",
    "stewarten": "stewart",
    "stewartens": "stewart",
    "stewarter": "stewart",
    "stewarterna": "stewart",
    "stewarternas": "stewart",
    "stewarters": "stewart",
    "stewarts": "stewart",
    "sti": "stia",
    "stian": "stia",
    "stians": "stia",
    "stias": "stia",
    "stick": "sticka",
    "stickad": "sticka",
    "stickade": "sticka",
    "stickades": "sticka",
    "stickads": "sticka",
    "stickan": "sticka",
    "stickande": "sticka",
    "stickanden": "stickande",
    "stickandena": "stickande",
    "stickandenas": "stickande",
    "stickandens": "stickande",
    "stickandes": "stickande",
    "stickandet": "stickande",
    "stickandets": "stickande",
    "stickans": "sticka",
    "stickar": "sticka",
    "stickas": "sticka",
    "stickat": "sticka",
    "stickats": "sticka",
    "sticke": "sticka",
    "stickelbären": "stickelbär",
    "stickelbärens": "stickelbär",
    "stickelbäret": "stickelbär",
    "stickelbärets": "stickelbär",
    "stickelbärs": "stickelbär",
    "stickelhåriga": "stickelhårig",
    "stickelhårigare": "stickelhårig",
    "stickelhårigares": "stickelhårig",
    "stickelhårigas": "stickelhårig",
    "stickelhårigast": "stickelhårig",
    "stickelhårigaste": "stickelhårig",
    "stickelhårigastes": "stickelhårig",
    "stickelhårigasts": "stickelhårig",
    "stickelhårige": "stickelhårig",
    "stickelhåriges": "stickelhårig",
    "stickelhårigs": "stickelhårig",
    "stickelhårigt": "stickelhårig",
    "stickelhårigts": "stickelhårig",
    "stickeln": "stickel",
    "stickelns": "stickel",
    "stickels": "stickel",
    "sticken": "stick",
    "stickens": "stick",
    "sticker": "sticka",
    "stickertar": "stickert",
    "stickertarna": "stickert",
    "stickertarnas": "stickert",
    "stickertars": "stickert",
    "stickerten": "stickert",
    "stickertens": "stickert",
    "stickerts": "stickert",
    "stickes": "sticka",
    "sticket": "stick",
    "stickets": "stick",
    "stickiga": "stickig",
    "stickigare": "stickig",
    "stickigares": "stickig",
    "stickigas": "stickig",
    "stickigast": "stickig",
    "stickigaste": "stickig",
    "stickigastes": "stickig",
    "stickigasts": "stickig",
    "stickige": "stickig",
    "stickiges": "stickig",
    "stickigheten": "stickighet",
    "stickighetens": "stickighet",
    "stickighets": "stickighet",
    "stickigs": "stickig",
    "stickigt": "stickig",
    "stickigts": "stickig",
    "stickkontakten": "stickkontakt",
    "stickkontaktens": "stickkontakt",
    "stickkontakter": "stickkontakt",
    "stickkontakterna": "stickkontakt",
    "stickkontakternas": "stickkontakt",
    "stickkontakters": "stickkontakt",
    "stickkontakts": "stickkontakt",
    "sticklar": "stickel",
    "sticklarna": "stickel",
    "sticklarnas": "stickel",
    "sticklars": "stickel",
    "sticklingar": "stickling",
    "sticklingarna": "stickling",
    "sticklingarnas": "stickling",
    "sticklingars": "stickling",
    "sticklingen": "stickling",
    "sticklingens": "stickling",
    "sticklings": "stickling",
    "stickmaskinen": "stickmaskin",
    "stickmaskinens": "stickmaskin",
    "stickmaskiner": "stickmaskin",
    "stickmaskinerna": "stickmaskin",
    "stickmaskinernas": "stickmaskin",
    "stickmaskiners": "stickmaskin",
    "stickmaskins": "stickmaskin",
    "stickningar": "stickning",
    "stickningarna": "stickning",
    "stickningarnas": "stickning",
    "stickningars": "stickning",
    "stickningen": "stickning",
    "stickningens": "stickning",
    "sticknings": "stickning",
    "stickor": "sticka",
    "stickorden": "stickord",
    "stickordens": "stickord",
    "stickordet": "stickord",
    "stickordets": "stickord",
    "stickords": "stickord",
    "stickorna": "sticka",
    "stickornas": "sticka",
    "stickors": "sticka",
    "stickproppar": "stickpropp",
    "stickpropparna": "stickpropp",
    "stickpropparnas": "stickpropp",
    "stickproppars": "stickpropp",
    "stickproppen": "stickpropp",
    "stickproppens": "stickpropp",
    "stickpropps": "stickpropp",
    "stickproven": "stickprov",
    "stickprovens": "stickprov",
    "stickprovet": "stickprov",
    "stickprovets": "stickprov",
    "stickprovs": "stickprov",
    "stickprovsmässiga": "stickprovsmässig",
    "stickprovsmässigare": "stickprovsmässig",
    "stickprovsmässigares": "stickprovsmässig",
    "stickprovsmässigas": "stickprovsmässig",
    "stickprovsmässigast": "stickprovsmässig",
    "stickprovsmässigaste": "stickprovsmässig",
    "stickprovsmässigastes": "stickprovsmässig",
    "stickprovsmässigasts": "stickprovsmässig",
    "stickprovsmässige": "stickprovsmässig",
    "stickprovsmässiges": "stickprovsmässig",
    "stickprovsmässigs": "stickprovsmässig",
    "stickprovsmässigt": "stickprovsmässig",
    "stickprovsmässigts": "stickprovsmässig",
    "stickprovsundersökningar": "stickprovsundersökning",
    "stickprovsundersökningarna": "stickprovsundersökning",
    "stickprovsundersökningarnas": "stickprovsundersökning",
    "stickprovsundersökningars": "stickprovsundersökning",
    "stickprovsundersökningen": "stickprovsundersökning",
    "stickprovsundersökningens": "stickprovsundersökning",
    "stickprovsundersöknings": "stickprovsundersökning",
    "stickrepliken": "stickreplik",
    "stickreplikens": "stickreplik",
    "stickrepliker": "stickreplik",
    "stickreplikerna": "stickreplik",
    "stickreplikernas": "stickreplik",
    "stickreplikers": "stickreplik",
    "stickrepliks": "stickreplik",
    "sticks": "sticka",
    "stickspåren": "stickspår",
    "stickspårens": "stickspår",
    "stickspåret": "stickspår",
    "stickspårets": "stickspår",
    "stickspårs": "stickspår",
    "sticksågar": "sticksåg",
    "sticksågarna": "sticksåg",
    "sticksågarnas": "sticksåg",
    "sticksågars": "sticksåg",
    "sticksågen": "sticksåg",
    "sticksågens": "sticksåg",
    "sticksågs": "sticksåg",
    "stickvapens": "stickvapen",
    "stickvapnen": "stickvapen",
    "stickvapnens": "stickvapen",
    "stickvapnet": "stickvapen",
    "stickvapnets": "stickvapen",
    "stie": "stia",
    "stift": "stifta",
    "stiftad": "stifta",
    "stiftade": "stifta",
    "stiftades": "stifta",
    "stiftads": "stifta",
    "stiftande": "stifta",
    "stiftanden": "stiftande",
    "stiftandena": "stiftande",
    "stiftandenas": "stiftande",
    "stiftandens": "stiftande",
    "stiftandes": "stiftande",
    "stiftandet": "stiftande",
    "stiftandets": "stiftande",
    "stiftar": "stifta",
    "stiftas": "stifta",
    "stiftat": "stifta",
    "stiftats": "stifta",
    "stiftelsen": "stiftelse",
    "stiftelsens": "stiftelse",
    "stiftelser": "stiftelse",
    "stiftelserna": "stiftelse",
    "stiftelsernas": "stiftelse",
    "stiftelsers": "stiftelse",
    "stiftelses": "stiftelse",
    "stiften": "stift",
    "stiftens": "stift",
    "stiftet": "stift",
    "stiftets": "stift",
    "stifts": "stift",
    "stiftsbandet": "stiftsband",
    "stiftsbandets": "stiftsband",
    "stiftsbands": "stiftsband",
    "stiftsfrökens": "stiftsfröken",
    "stiftsfröknar": "stiftsfröken",
    "stiftsfröknarna": "stiftsfröken",
    "stiftsfröknarnas": "stiftsfröken",
    "stiftsfröknars": "stiftsfröken",
    "stiftsfröknen": "stiftsfröken",
    "stiftsfröknens": "stiftsfröken",
    "stiftsjungfrun": "stiftsjungfru",
    "stiftsjungfruns": "stiftsjungfru",
    "stiftsjungfrur": "stiftsjungfru",
    "stiftsjungfrurna": "stiftsjungfru",
    "stiftsjungfrurnas": "stiftsjungfru",
    "stiftsjungfrurs": "stiftsjungfru",
    "stiftsjungfrus": "stiftsjungfru",
    "stiftsstaden": "stiftsstad",
    "stiftsstadens": "stiftsstad",
    "stiftsstads": "stiftsstad",
    "stiftsstan": "stiftsstad",
    "stiftsstans": "stiftsstad",
    "stiftsstäder": "stiftsstad",
    "stiftsstäderna": "stiftsstad",
    "stiftsstädernas": "stiftsstad",
    "stiftsstäders": "stiftsstad",
    "stifttanden": "stifttand",
    "stifttandens": "stifttand",
    "stifttands": "stifttand",
    "stifttänder": "stifttand",
    "stifttänderna": "stifttand",
    "stifttändernas": "stifttand",
    "stifttänders": "stifttand",
    "stig": "stiga",
    "stigande": "stiga",
    "stiganden": "stigande",
    "stigandena": "stigande",
    "stigandenas": "stigande",
    "stigandens": "stigande",
    "stigandes": "stigande",
    "stigandet": "stigande",
    "stigandets": "stigande",
    "stigar": "stig",
    "stigarcentralen": "stigarcentral",
    "stigarcentralens": "stigarcentral",
    "stigarcentraler": "stigarcentral",
    "stigarcentralerna": "stigarcentral",
    "stigarcentralernas": "stigarcentral",
    "stigarcentralers": "stigarcentral",
    "stigarcentrals": "stigarcentral",
    "stigarledningar": "stigarledning",
    "stigarledningarna": "stigarledning",
    "stigarledningarnas": "stigarledning",
    "stigarledningars": "stigarledning",
    "stigarledningen": "stigarledning",
    "stigarledningens": "stigarledning",
    "stigarlednings": "stigarledning",
    "stigarna": "stig",
    "stigarnas": "stig",
    "stigars": "stig",
    "stigas": "stiga",
    "stigbygeln": "stigbygel",
    "stigbygelns": "stigbygel",
    "stigbygels": "stigbygel",
    "stigbyglar": "stigbygel",
    "stigbyglarna": "stigbygel",
    "stigbyglarnas": "stigbygel",
    "stigbyglars": "stigbygel",
    "stige": "stiga",
    "stigen": "stiga",
    "stigens": "stiga",
    "stiger": "stiga",
    "stiges": "stiga",
    "stiget": "stiga",
    "stigets": "stiga",
    "stigfinnar": "stigfinnare",
    "stigfinnaren": "stigfinnare",
    "stigfinnarens": "stigfinnare",
    "stigfinnares": "stigfinnare",
    "stigfinnarna": "stigfinnare",
    "stigfinnarnas": "stigfinnare",
    "stigit": "stiga",
    "stigits": "stiga",
    "stigläders": "stigläder",
    "stiglädren": "stigläder",
    "stiglädrens": "stigläder",
    "stiglädret": "stigläder",
    "stiglädrets": "stigläder",
    "stiglösa": "stiglös",
    "stiglösare": "stiglös",
    "stiglösares": "stiglös",
    "stiglösas": "stiglös",
    "stiglösast": "stiglös",
    "stiglösaste": "stiglös",
    "stiglösastes": "stiglös",
    "stiglösasts": "stiglös",
    "stiglöse": "stiglös",
    "stiglöses": "stiglös",
    "stiglösheten": "stiglöshet",
    "stiglöshetens": "stiglöshet",
    "stiglöshets": "stiglöshet",
    "stiglöst": "stiglös",
    "stiglösts": "stiglös",
    "stigman": "stigma",
    "stigmana": "stigma",
    "stigmanas": "stigma",
    "stigmannen": "stigman",
    "stigmannens": "stigman",
    "stigmans": "stigman",
    "stigmas": "stigma",
    "stigmat": "stigma",
    "stigmata": "stigma",
    "stigmatana": "stigma",
    "stigmatanas": "stigma",
    "stigmatas": "stigma",
    "stigmatiserad": "stigmatisera",
    "stigmatiserade": "stigmatisera",
    "stigmatiserades": "stigmatisera",
    "stigmatiserads": "stigmatisera",
    "stigmatiserande": "stigmatisera",
    "stigmatiseranden": "stigmatiserande",
    "stigmatiserandena": "stigmatiserande",
    "stigmatiserandenas": "stigmatiserande",
    "stigmatiserandens": "stigmatiserande",
    "stigmatiserandes": "stigmatiserande",
    "stigmatiserandet": "stigmatiserande",
    "stigmatiserandets": "stigmatiserande",
    "stigmatiserar": "stigmatisera",
    "stigmatiseras": "stigmatisera",
    "stigmatiserat": "stigmatisera",
    "stigmatiserats": "stigmatisera",
    "stigmatiserbara": "stigmatiserbar",
    "stigmatiserbarare": "stigmatiserbar",
    "stigmatiserbarares": "stigmatiserbar",
    "stigmatiserbaras": "stigmatiserbar",
    "stigmatiserbarast": "stigmatiserbar",
    "stigmatiserbaraste": "stigmatiserbar",
    "stigmatiserbarastes": "stigmatiserbar",
    "stigmatiserbarasts": "stigmatiserbar",
    "stigmatiserbare": "stigmatiserbar",
    "stigmatiserbares": "stigmatiserbar",
    "stigmatiserbarheten": "stigmatiserbarhet",
    "stigmatiserbarhetens": "stigmatiserbarhet",
    "stigmatiserbarhets": "stigmatiserbarhet",
    "stigmatiserbars": "stigmatiserbar",
    "stigmatiserbart": "stigmatiserbar",
    "stigmatiserbarts": "stigmatiserbar",
    "stigmatiseringar": "stigmatisering",
    "stigmatiseringarna": "stigmatisering",
    "stigmatiseringarnas": "stigmatisering",
    "stigmatiseringars": "stigmatisering",
    "stigmatiseringen": "stigmatisering",
    "stigmatiseringens": "stigmatisering",
    "stigmatiserings": "stigmatisering",
    "stigmats": "stigma",
    "stigmän": "stigman",
    "stigmännen": "stigman",
    "stigmännens": "stigman",
    "stigmäns": "stigman",
    "stigna": "stiga",
    "stignas": "stiga",
    "stigne": "stiga",
    "stignes": "stiga",
    "stigningar": "stigning",
    "stigningarna": "stigning",
    "stigningarnas": "stigning",
    "stigningars": "stigning",
    "stigningen": "stigning",
    "stigningens": "stigning",
    "stignings": "stigning",
    "stigorten": "stigort",
    "stigortens": "stigort",
    "stigorter": "stigort",
    "stigorterna": "stigort",
    "stigorternas": "stigort",
    "stigorters": "stigort",
    "stigorts": "stigort",
    "stigs": "stiga",
    "stikiska": "stikisk",
    "stikiskare": "stikisk",
    "stikiskares": "stikisk",
    "stikiskas": "stikisk",
    "stikiskast": "stikisk",
    "stikiskaste": "stikisk",
    "stikiskastes": "stikisk",
    "stikiskasts": "stikisk",
    "stikiske": "stikisk",
    "stikiskes": "stikisk",
    "stikisks": "stikisk",
    "stikiskt": "stikisk",
    "stikiskts": "stikisk",
    "stil": "stila",
    "stilad": "stila",
    "stilade": "stila",
    "stilades": "stila",
    "stilads": "stila",
    "stilande": "stila",
    "stilanden": "stilande",
    "stilandena": "stilande",
    "stilandenas": "stilande",
    "stilandens": "stilande",
    "stilandes": "stilande",
    "stilandet": "stilande",
    "stilandets": "stilande",
    "stilar": "stila",
    "stilarna": "stil",
    "stilarnas": "stil",
    "stilars": "stil",
    "stilarten": "stilart",
    "stilartens": "stilart",
    "stilarter": "stilart",
    "stilarterna": "stilart",
    "stilarternas": "stilart",
    "stilarters": "stilart",
    "stilarts": "stilart",
    "stilas": "stila",
    "stilat": "stila",
    "stilats": "stila",
    "stilbildar": "stilbildare",
    "stilbildaren": "stilbildare",
    "stilbildarens": "stilbildare",
    "stilbildares": "stilbildare",
    "stilbildarna": "stilbildare",
    "stilbildarnas": "stilbildare",
    "stilblom": "stilblomma",
    "stilblomman": "stilblomma",
    "stilblommans": "stilblomma",
    "stilblommas": "stilblomma",
    "stilblomme": "stilblomma",
    "stilblommor": "stilblomma",
    "stilblommorna": "stilblomma",
    "stilblommornas": "stilblomma",
    "stilblommors": "stilblomma",
    "stilbloms": "stilblomma",
    "stilbrytningar": "stilbrytning",
    "stilbrytningarna": "stilbrytning",
    "stilbrytningarnas": "stilbrytning",
    "stilbrytningars": "stilbrytning",
    "stilbrytningen": "stilbrytning",
    "stilbrytningens": "stilbrytning",
    "stilbrytnings": "stilbrytning",
    "stildragen": "stildrag",
    "stildragens": "stildrag",
    "stildraget": "stildrag",
    "stildragets": "stildrag",
    "stildrags": "stildrag",
    "stilen": "stil",
    "stilenliga": "stilenlig",
    "stilenligare": "stilenlig",
    "stilenligares": "stilenlig",
    "stilenligas": "stilenlig",
    "stilenligast": "stilenlig",
    "stilenligaste": "stilenlig",
    "stilenligastes": "stilenlig",
    "stilenligasts": "stilenlig",
    "stilenlige": "stilenlig",
    "stilenliges": "stilenlig",
    "stilenligheten": "stilenlighet",
    "stilenlighetens": "stilenlighet",
    "stilenlighets": "stilenlighet",
    "stilenligs": "stilenlig",
    "stilenligt": "stilenlig",
    "stilenligts": "stilenlig",
    "stilens": "stil",
    "stiletten": "stilett",
    "stilettens": "stilett",
    "stiletter": "stilett",
    "stiletterna": "stilett",
    "stiletternas": "stilett",
    "stiletters": "stilett",
    "stilettkäppar": "stilettkäpp",
    "stilettkäpparna": "stilettkäpp",
    "stilettkäpparnas": "stilettkäpp",
    "stilettkäppars": "stilettkäpp",
    "stilettkäppen": "stilettkäpp",
    "stilettkäppens": "stilettkäpp",
    "stilettkäpps": "stilettkäpp",
    "stiletts": "stilett",
    "stilfiguren": "stilfigur",
    "stilfigurens": "stilfigur",
    "stilfigurer": "stilfigur",
    "stilfigurerna": "stilfigur",
    "stilfigurernas": "stilfigur",
    "stilfigurers": "stilfigur",
    "stilfigurs": "stilfigur",
    "stilfulla": "stilfull",
    "stilfullare": "stilfull",
    "stilfullares": "stilfull",
    "stilfullas": "stilfull",
    "stilfullast": "stilfull",
    "stilfullaste": "stilfull",
    "stilfullastes": "stilfull",
    "stilfullasts": "stilfull",
    "stilfulle": "stilfull",
    "stilfulles": "stilfull",
    "stilfullheten": "stilfullhet",
    "stilfullhetens": "stilfullhet",
    "stilfullheter": "stilfullhet",
    "stilfullheterna": "stilfullhet",
    "stilfullheternas": "stilfullhet",
    "stilfullheters": "stilfullhet",
    "stilfullhets": "stilfullhet",
    "stilfulls": "stilfull",
    "stilfullt": "stilfull",
    "stilfullts": "stilfull",
    "stiliga": "stilig",
    "stiligare": "stilig",
    "stiligares": "stilig",
    "stiligas": "stilig",
    "stiligast": "stilig",
    "stiligaste": "stilig",
    "stiligastes": "stilig",
    "stiligasts": "stilig",
    "stilige": "stilig",
    "stiliges": "stilig",
    "stiligheten": "stilighet",
    "stilighetens": "stilighet",
    "stilighets": "stilighet",
    "stiligs": "stilig",
    "stiligt": "stilig",
    "stiligts": "stilig",
    "stiliserad": "stilisera",
    "stiliserade": "stilisera",
    "stiliserades": "stilisera",
    "stiliserads": "stilisera",
    "stiliserande": "stilisera",
    "stiliseranden": "stiliserande",
    "stiliserandena": "stiliserande",
    "stiliserandenas": "stiliserande",
    "stiliserandens": "stiliserande",
    "stiliserandes": "stiliserande",
    "stiliserandet": "stiliserande",
    "stiliserandets": "stiliserande",
    "stiliserar": "stilisera",
    "stiliseras": "stilisera",
    "stiliserat": "stilisera",
    "stiliserats": "stilisera",
    "stiliserbara": "stiliserbar",
    "stiliserbarare": "stiliserbar",
    "stiliserbarares": "stiliserbar",
    "stiliserbaras": "stiliserbar",
    "stiliserbarast": "stiliserbar",
    "stiliserbaraste": "stiliserbar",
    "stiliserbarastes": "stiliserbar",
    "stiliserbarasts": "stiliserbar",
    "stiliserbare": "stiliserbar",
    "stiliserbares": "stiliserbar",
    "stiliserbarheten": "stiliserbarhet",
    "stiliserbarhetens": "stiliserbarhet",
    "stiliserbarhets": "stiliserbarhet",
    "stiliserbars": "stiliserbar",
    "stiliserbart": "stiliserbar",
    "stiliserbarts": "stiliserbar",
    "stiliseringar": "stilisering",
    "stiliseringarna": "stilisering",
    "stiliseringarnas": "stilisering",
    "stiliseringars": "stilisering",
    "stiliseringen": "stilisering",
    "stiliseringens": "stilisering",
    "stiliserings": "stilisering",
    "stilisten": "stilist",
    "stilistens": "stilist",
    "stilister": "stilist",
    "stilisterna": "stilist",
    "stilisternas": "stilist",
    "stilisters": "stilist",
    "stilistiken": "stilistik",
    "stilistikens": "stilistik",
    "stilistikern": "stilistiker",
    "stilistikerna": "stilistiker",
    "stilistikernas": "stilistiker",
    "stilistikerns": "stilistiker",
    "stilistikers": "stilistiker",
    "stilistiks": "stilistik",
    "stilistiska": "stilistisk",
    "stilistiskare": "stilistisk",
    "stilistiskares": "stilistisk",
    "stilistiskas": "stilistisk",
    "stilistiskast": "stilistisk",
    "stilistiskaste": "stilistisk",
    "stilistiskastes": "stilistisk",
    "stilistiskasts": "stilistisk",
    "stilistiske": "stilistisk",
    "stilistiskes": "stilistisk",
    "stilistisks": "stilistisk",
    "stilistiskt": "stilistisk",
    "stilistiskts": "stilistisk",
    "stilists": "stilist",
    "stilkänslan": "stilkänsla",
    "stilkänslans": "stilkänsla",
    "stilkänslas": "stilkänsla",
    "stilkänsle": "stilkänsla",
    "stilkänslo": "stilkänsla",
    "still": "stilla",
    "stillad": "stilla",
    "stillade": "stilla",
    "stillades": "stilla",
    "stillads": "stilla",
    "stillande": "stilla",
    "stillanden": "stillande",
    "stillandena": "stillande",
    "stillandenas": "stillande",
    "stillandens": "stillande",
    "stillandes": "stillande",
    "stillandet": "stillande",
    "stillandets": "stillande",
    "stillar": "stilla",
    "stillas": "stilla",
    "stillasittandes": "stillasittande",
    "stillasittandet": "stillasittande",
    "stillasittandets": "stillasittande",
    "stillaståendes": "stillastående",
    "stillaståendet": "stillastående",
    "stillaståendets": "stillastående",
    "stillat": "stilla",
    "stillats": "stilla",
    "stillbilden": "stillbild",
    "stillbildens": "stillbild",
    "stillbilder": "stillbild",
    "stillbilderna": "stillbild",
    "stillbildernas": "stillbild",
    "stillbilders": "stillbild",
    "stillbilds": "stillbild",
    "stilldrinkar": "stilldrink",
    "stilldrinkarna": "stilldrink",
    "stilldrinkarnas": "stilldrink",
    "stilldrinkars": "stilldrink",
    "stilldrinken": "stilldrink",
    "stilldrinkens": "stilldrink",
    "stilldrinks": "stilldrink",
    "stillebenen": "stilleben",
    "stillebenens": "stilleben",
    "stillebenet": "stilleben",
    "stillebenets": "stilleben",
    "stillebens": "stilleben",
    "stillestånden": "stillestånd",
    "stilleståndens": "stillestånd",
    "stilleståndet": "stillestånd",
    "stilleståndets": "stillestånd",
    "stillestånds": "stillestånd",
    "stillfilmen": "stillfilm",
    "stillfilmens": "stillfilm",
    "stillfilmer": "stillfilm",
    "stillfilmerna": "stillfilm",
    "stillfilmernas": "stillfilm",
    "stillfilmers": "stillfilm",
    "stillfilms": "stillfilm",
    "stillheten": "stillhet",
    "stillhetens": "stillhet",
    "stillheter": "stillhet",
    "stillheterna": "stillhet",
    "stillheternas": "stillhet",
    "stillheters": "stillhet",
    "stillhets": "stillhet",
    "stilln": "stillna",
    "stillnad": "stillna",
    "stillnade": "stillna",
    "stillnades": "stillna",
    "stillnads": "stillna",
    "stillnande": "stillna",
    "stillnanden": "stillnande",
    "stillnandena": "stillnande",
    "stillnandenas": "stillnande",
    "stillnandens": "stillnande",
    "stillnandes": "stillnande",
    "stillnandet": "stillnande",
    "stillnandets": "stillnande",
    "stillnar": "stillna",
    "stillnas": "stillna",
    "stillnat": "stillna",
    "stillnats": "stillna",
    "stillsamheten": "stillsamhet",
    "stillsamhetens": "stillsamhet",
    "stillsamhets": "stillsamhet",
    "stillsamma": "stillsam",
    "stillsammare": "stillsam",
    "stillsammares": "stillsam",
    "stillsammas": "stillsam",
    "stillsammast": "stillsam",
    "stillsammaste": "stillsam",
    "stillsammastes": "stillsam",
    "stillsammasts": "stillsam",
    "stillsamme": "stillsam",
    "stillsammes": "stillsam",
    "stillsams": "stillsam",
    "stillsamt": "stillsam",
    "stillsamts": "stillsam",
    "stilmässiga": "stilmässig",
    "stilmässigare": "stilmässig",
    "stilmässigares": "stilmässig",
    "stilmässigas": "stilmässig",
    "stilmässigast": "stilmässig",
    "stilmässigaste": "stilmässig",
    "stilmässigastes": "stilmässig",
    "stilmässigasts": "stilmässig",
    "stilmässige": "stilmässig",
    "stilmässiges": "stilmässig",
    "stilmässigs": "stilmässig",
    "stilmässigt": "stilmässig",
    "stilmässigts": "stilmässig",
    "stilmöbeln": "stilmöbel",
    "stilmöbelns": "stilmöbel",
    "stilmöbels": "stilmöbel",
    "stilmöbler": "stilmöbel",
    "stilmöblerna": "stilmöbel",
    "stilmöblernas": "stilmöbel",
    "stilmöblers": "stilmöbel",
    "stilrena": "stilren",
    "stilrenare": "stilren",
    "stilrenares": "stilren",
    "stilrenas": "stilren",
    "stilrenast": "stilren",
    "stilrenaste": "stilren",
    "stilrenastes": "stilren",
    "stilrenasts": "stilren",
    "stilrene": "stilren",
    "stilrenes": "stilren",
    "stilrens": "stilren",
    "stilrent": "stilren",
    "stilrents": "stilren",
    "stilriktningar": "stilriktning",
    "stilriktningarna": "stilriktning",
    "stilriktningarnas": "stilriktning",
    "stilriktningars": "stilriktning",
    "stilriktningen": "stilriktning",
    "stilriktningens": "stilriktning",
    "stilriktnings": "stilriktning",
    "stils": "stil",
    "stilsorten": "stilsort",
    "stilsortens": "stilsort",
    "stilsorter": "stilsort",
    "stilsorterna": "stilsort",
    "stilsorternas": "stilsort",
    "stilsorters": "stilsort",
    "stilsorts": "stilsort",
    "stiltjen": "stiltje",
    "stiltjens": "stiltje",
    "stiltjes": "stiltje",
    "stiltonar": "stilton",
    "stiltonarna": "stilton",
    "stiltonarnas": "stilton",
    "stiltonars": "stilton",
    "stiltonen": "stilton",
    "stiltonens": "stilton",
    "stiltons": "stilton",
    "stilvalen": "stilval",
    "stilvalens": "stilval",
    "stilvalet": "stilval",
    "stilvalets": "stilval",
    "stilvals": "stilval",
    "stimmade": "stimma",
    "stimmades": "stimma",
    "stimmande": "stimma",
    "stimmanden": "stimmande",
    "stimmandena": "stimmande",
    "stimmandenas": "stimmande",
    "stimmandens": "stimmande",
    "stimmandes": "stimmande",
    "stimmandet": "stimmande",
    "stimmandets": "stimmande",
    "stimmar": "stimma",
    "stimmas": "stimma",
    "stimmat": "stimma",
    "stimmats": "stimma",
    "stimmen": "stim",
    "stimmens": "stim",
    "stimmet": "stim",
    "stimmets": "stim",
    "stimmiga": "stimmig",
    "stimmigare": "stimmig",
    "stimmigares": "stimmig",
    "stimmigas": "stimmig",
    "stimmigast": "stimmig",
    "stimmigaste": "stimmig",
    "stimmigastes": "stimmig",
    "stimmigasts": "stimmig",
    "stimmige": "stimmig",
    "stimmiges": "stimmig",
    "stimmigheten": "stimmighet",
    "stimmighetens": "stimmighet",
    "stimmighets": "stimmighet",
    "stimmigs": "stimmig",
    "stimmigt": "stimmig",
    "stimmigts": "stimmig",
    "stims": "stim",
    "stimulansen": "stimulans",
    "stimulansens": "stimulans",
    "stimulanser": "stimulans",
    "stimulanserna": "stimulans",
    "stimulansernas": "stimulans",
    "stimulansers": "stimulans",
    "stimulansåtgärden": "stimulansåtgärd",
    "stimulansåtgärdens": "stimulansåtgärd",
    "stimulansåtgärder": "stimulansåtgärd",
    "stimulansåtgärderna": "stimulansåtgärd",
    "stimulansåtgärdernas": "stimulansåtgärd",
    "stimulansåtgärders": "stimulansåtgärd",
    "stimulansåtgärds": "stimulansåtgärd",
    "stimulantian": "stimulantia",
    "stimulantiana": "stimulantia",
    "stimulantianas": "stimulantia",
    "stimulantians": "stimulantia",
    "stimulantias": "stimulantia",
    "stimulatorer": "stimulator",
    "stimulatorerna": "stimulator",
    "stimulatorernas": "stimulator",
    "stimulatorers": "stimulator",
    "stimulatorn": "stimulator",
    "stimulatorns": "stimulator",
    "stimulators": "stimulator",
    "stimulerad": "stimulera",
    "stimulerade": "stimulera",
    "stimulerades": "stimulera",
    "stimulerads": "stimulera",
    "stimulerande": "stimulera",
    "stimuleranden": "stimulerande",
    "stimulerandena": "stimulerande",
    "stimulerandenas": "stimulerande",
    "stimulerandens": "stimulerande",
    "stimulerandes": "stimulerande",
    "stimulerandet": "stimulerande",
    "stimulerandets": "stimulerande",
    "stimulerar": "stimulera",
    "stimuleras": "stimulera",
    "stimulerat": "stimulera",
    "stimulerats": "stimulera",
    "stimulerbara": "stimulerbar",
    "stimulerbarare": "stimulerbar",
    "stimulerbarares": "stimulerbar",
    "stimulerbaras": "stimulerbar",
    "stimulerbarast": "stimulerbar",
    "stimulerbaraste": "stimulerbar",
    "stimulerbarastes": "stimulerbar",
    "stimulerbarasts": "stimulerbar",
    "stimulerbare": "stimulerbar",
    "stimulerbares": "stimulerbar",
    "stimulerbarheten": "stimulerbarhet",
    "stimulerbarhetens": "stimulerbarhet",
    "stimulerbarhets": "stimulerbarhet",
    "stimulerbars": "stimulerbar",
    "stimulerbart": "stimulerbar",
    "stimulerbarts": "stimulerbar",
    "stimuleringar": "stimulering",
    "stimuleringarna": "stimulering",
    "stimuleringarnas": "stimulering",
    "stimuleringars": "stimulering",
    "stimuleringen": "stimulering",
    "stimuleringens": "stimulering",
    "stimulerings": "stimulering",
    "stimuli": "stimulus",
    "stimulina": "stimulus",
    "stimulinas": "stimulus",
    "stimulis": "stimulus",
    "stimulusen": "stimulus",
    "stimulusens": "stimulus",
    "stimuluset": "stimulus",
    "stimulusets": "stimulus",
    "sting": "stinga",
    "stingande": "stinga",
    "stinganden": "stingande",
    "stingandena": "stingande",
    "stingandenas": "stingande",
    "stingandens": "stingande",
    "stingandes": "stingande",
    "stingandet": "stingande",
    "stingandets": "stingande",
    "stingas": "stinga",
    "stinge": "stinga",
    "stingen": "sting",
    "stingens": "sting",
    "stinger": "stinga",
    "stinges": "stinga",
    "stinget": "sting",
    "stingets": "sting",
    "stingpinn": "stingpinne",
    "stingpinnar": "stingpinne",
    "stingpinnarna": "stingpinne",
    "stingpinnarnas": "stingpinne",
    "stingpinnars": "stingpinne",
    "stingpinnen": "stingpinne",
    "stingpinnens": "stingpinne",
    "stingpinnes": "stingpinne",
    "stingpinns": "stingpinne",
    "stings": "sting",
    "stingsliga": "stingslig",
    "stingsligare": "stingslig",
    "stingsligares": "stingslig",
    "stingsligas": "stingslig",
    "stingsligast": "stingslig",
    "stingsligaste": "stingslig",
    "stingsligastes": "stingslig",
    "stingsligasts": "stingslig",
    "stingslige": "stingslig",
    "stingsliges": "stingslig",
    "stingsligheten": "stingslighet",
    "stingslighetens": "stingslighet",
    "stingsligheter": "stingslighet",
    "stingsligheterna": "stingslighet",
    "stingsligheternas": "stingslighet",
    "stingsligheters": "stingslighet",
    "stingslighets": "stingslighet",
    "stingsligs": "stingslig",
    "stingsligt": "stingslig",
    "stingsligts": "stingslig",
    "stink": "stinka",
    "stinkande": "stinka",
    "stinkanden": "stinkande",
    "stinkandena": "stinkande",
    "stinkandenas": "stinkande",
    "stinkandens": "stinkande",
    "stinkandes": "stinkande",
    "stinkandet": "stinkande",
    "stinkandets": "stinkande",
    "stinkas": "stinka",
    "stinkbomben": "stinkbomb",
    "stinkbombens": "stinkbomb",
    "stinkbomber": "stinkbomb",
    "stinkbomberna": "stinkbomb",
    "stinkbombernas": "stinkbomb",
    "stinkbombers": "stinkbomb",
    "stinkbombs": "stinkbomb",
    "stinkdjuren": "stinkdjur",
    "stinkdjurens": "stinkdjur",
    "stinkdjuret": "stinkdjur",
    "stinkdjurets": "stinkdjur",
    "stinkdjurs": "stinkdjur",
    "stinke": "stinka",
    "stinker": "stinka",
    "stinkes": "stinka",
    "stinkflyen": "stinkfly",
    "stinkflyens": "stinkfly",
    "stinkflyet": "stinkfly",
    "stinkflyets": "stinkfly",
    "stinkflyn": "stinkfly",
    "stinkflyna": "stinkfly",
    "stinkflynas": "stinkfly",
    "stinkflyns": "stinkfly",
    "stinkflys": "stinkfly",
    "stinkflyt": "stinkfly",
    "stinkflyts": "stinkfly",
    "stinks": "stinka",
    "stinksvampar": "stinksvamp",
    "stinksvamparna": "stinksvamp",
    "stinksvamparnas": "stinksvamp",
    "stinksvampars": "stinksvamp",
    "stinksvampen": "stinksvamp",
    "stinksvampens": "stinksvamp",
    "stinksvamps": "stinksvamp",
    "stinna": "stinn",
    "stinnare": "stinn",
    "stinnares": "stinn",
    "stinnas": "stinn",
    "stinnast": "stinn",
    "stinnaste": "stinn",
    "stinnastes": "stinn",
    "stinnasts": "stinn",
    "stinne": "stinn",
    "stinnes": "stinn",
    "stinnheten": "stinnhet",
    "stinnhetens": "stinnhet",
    "stinnhets": "stinnhet",
    "stinns": "stinn",
    "stinsar": "stins",
    "stinsarna": "stins",
    "stinsarnas": "stins",
    "stinsars": "stins",
    "stinsen": "stins",
    "stinsens": "stins",
    "stint": "stinta",
    "stintan": "stinta",
    "stintans": "stinta",
    "stintas": "stinta",
    "stinte": "stinta",
    "stintor": "stinta",
    "stintorna": "stinta",
    "stintornas": "stinta",
    "stintors": "stinta",
    "stints": "stinta",
    "stior": "stia",
    "stiorna": "stia",
    "stiornas": "stia",
    "stiors": "stia",
    "stipeln": "stipel",
    "stipelns": "stipel",
    "stipels": "stipel",
    "stipendiaten": "stipendiat",
    "stipendiatens": "stipendiat",
    "stipendiater": "stipendiat",
    "stipendiaterna": "stipendiat",
    "stipendiaternas": "stipendiat",
    "stipendiaters": "stipendiat",
    "stipendiats": "stipendiat",
    "stipendie": "stipendium",
    "stipendier": "stipendium",
    "stipendierad": "stipendiera",
    "stipendierade": "stipendiera",
    "stipendierades": "stipendiera",
    "stipendierads": "stipendiera",
    "stipendierande": "stipendiera",
    "stipendieranden": "stipendierande",
    "stipendierandena": "stipendierande",
    "stipendierandenas": "stipendierande",
    "stipendierandens": "stipendierande",
    "stipendierandes": "stipendierande",
    "stipendierandet": "stipendierande",
    "stipendierandets": "stipendierande",
    "stipendierar": "stipendiera",
    "stipendieras": "stipendiera",
    "stipendierat": "stipendiera",
    "stipendierats": "stipendiera",
    "stipendierbara": "stipendierbar",
    "stipendierbarare": "stipendierbar",
    "stipendierbarares": "stipendierbar",
    "stipendierbaras": "stipendierbar",
    "stipendierbarast": "stipendierbar",
    "stipendierbaraste": "stipendierbar",
    "stipendierbarastes": "stipendierbar",
    "stipendierbarasts": "stipendierbar",
    "stipendierbare": "stipendierbar",
    "stipendierbares": "stipendierbar",
    "stipendierbarheten": "stipendierbarhet",
    "stipendierbarhetens": "stipendierbarhet",
    "stipendierbarhets": "stipendierbarhet",
    "stipendierbars": "stipendierbar",
    "stipendierbart": "stipendierbar",
    "stipendierbarts": "stipendierbar",
    "stipendieringar": "stipendiering",
    "stipendieringarna": "stipendiering",
    "stipendieringarnas": "stipendiering",
    "stipendieringars": "stipendiering",
    "stipendieringen": "stipendiering",
    "stipendieringens": "stipendiering",
    "stipendierings": "stipendiering",
    "stipendierna": "stipendium",
    "stipendiernas": "stipendium",
    "stipendiers": "stipendium",
    "stipendiet": "stipendium",
    "stipendiets": "stipendium",
    "stipendiums": "stipendium",
    "stipler": "stipel",
    "stiplerna": "stipel",
    "stiplernas": "stipel",
    "stiplers": "stipel",
    "stipulationen": "stipulation",
    "stipulationens": "stipulation",
    "stipulationer": "stipulation",
    "stipulationerna": "stipulation",
    "stipulationernas": "stipulation",
    "stipulationers": "stipulation",
    "stipulations": "stipulation",
    "stipulerad": "stipulera",
    "stipulerade": "stipulera",
    "stipulerades": "stipulera",
    "stipulerads": "stipulera",
    "stipulerande": "stipulera",
    "stipuleranden": "stipulerande",
    "stipulerandena": "stipulerande",
    "stipulerandenas": "stipulerande",
    "stipulerandens": "stipulerande",
    "stipulerandes": "stipulerande",
    "stipulerandet": "stipulerande",
    "stipulerandets": "stipulerande",
    "stipulerar": "stipulera",
    "stipuleras": "stipulera",
    "stipulerat": "stipulera",
    "stipulerats": "stipulera",
    "stipulerbara": "stipulerbar",
    "stipulerbarare": "stipulerbar",
    "stipulerbarares": "stipulerbar",
    "stipulerbaras": "stipulerbar",
    "stipulerbarast": "stipulerbar",
    "stipulerbaraste": "stipulerbar",
    "stipulerbarastes": "stipulerbar",
    "stipulerbarasts": "stipulerbar",
    "stipulerbare": "stipulerbar",
    "stipulerbares": "stipulerbar",
    "stipulerbarheten": "stipulerbarhet",
    "stipulerbarhetens": "stipulerbarhet",
    "stipulerbarhets": "stipulerbarhet",
    "stipulerbars": "stipulerbar",
    "stipulerbart": "stipulerbar",
    "stipulerbarts": "stipulerbar",
    "stipuleringar": "stipulering",
    "stipuleringarna": "stipulering",
    "stipuleringarnas": "stipulering",
    "stipuleringars": "stipulering",
    "stipuleringen": "stipulering",
    "stipuleringens": "stipulering",
    "stipulerings": "stipulering",
    "stirlingmotorer": "stirlingmotor",
    "stirlingmotorerna": "stirlingmotor",
    "stirlingmotorernas": "stirlingmotor",
    "stirlingmotorers": "stirlingmotor",
    "stirlingmotorn": "stirlingmotor",
    "stirlingmotorns": "stirlingmotor",
    "stirlingmotors": "stirlingmotor",
    "stirr": "stirra",
    "stirrad": "stirra",
    "stirrade": "stirra",
    "stirrades": "stirra",
    "stirrads": "stirra",
    "stirrande": "stirra",
    "stirranden": "stirrande",
    "stirrandena": "stirrande",
    "stirrandenas": "stirrande",
    "stirrandens": "stirrande",
    "stirrandes": "stirrande",
    "stirrandet": "stirrande",
    "stirrandets": "stirrande",
    "stirrar": "stirra",
    "stirrarna": "stirr",
    "stirrarnas": "stirr",
    "stirrars": "stirr",
    "stirras": "stirra",
    "stirrat": "stirra",
    "stirrats": "stirra",
    "stirren": "stirr",
    "stirrens": "stirr",
    "stirriga": "stirrig",
    "stirrigare": "stirrig",
    "stirrigares": "stirrig",
    "stirrigas": "stirrig",
    "stirrigast": "stirrig",
    "stirrigaste": "stirrig",
    "stirrigastes": "stirrig",
    "stirrigasts": "stirrig",
    "stirrige": "stirrig",
    "stirriges": "stirrig",
    "stirrigheten": "stirrighet",
    "stirrighetens": "stirrighet",
    "stirrighets": "stirrighet",
    "stirrigs": "stirrig",
    "stirrigt": "stirrig",
    "stirrigts": "stirrig",
    "stirrs": "stirr",
    "stis": "stia",
    "stjäl": "stjäla",
    "stjälande": "stjäla",
    "stjälanden": "stjälande",
    "stjälandena": "stjälande",
    "stjälandenas": "stjälande",
    "stjälandens": "stjälande",
    "stjälandes": "stjälande",
    "stjälandet": "stjälande",
    "stjälandets": "stjälande",
    "stjälas": "stjäla",
    "stjälbara": "stjälbar",
    "stjälbarare": "stjälbar",
    "stjälbarares": "stjälbar",
    "stjälbaras": "stjälbar",
    "stjälbarast": "stjälbar",
    "stjälbaraste": "stjälbar",
    "stjälbarastes": "stjälbar",
    "stjälbarasts": "stjälbar",
    "stjälbare": "stjälbar",
    "stjälbares": "stjälbar",
    "stjälbars": "stjälbar",
    "stjälbart": "stjälbar",
    "stjälbarts": "stjälbar",
    "stjäle": "stjäla",
    "stjäles": "stjäla",
    "stjälkar": "stjälk",
    "stjälkarna": "stjälk",
    "stjälkarnas": "stjälk",
    "stjälkars": "stjälk",
    "stjälken": "stjälk",
    "stjälkens": "stjälk",
    "stjälks": "stjälk",
    "stjälkstygnen": "stjälkstygn",
    "stjälkstygnens": "stjälkstygn",
    "stjälkstygnet": "stjälkstygn",
    "stjälkstygnets": "stjälkstygn",
    "stjälkstygns": "stjälkstygn",
    "stjälp": "stjälpa",
    "stjälpande": "stjälpa",
    "stjälpanden": "stjälpande",
    "stjälpandena": "stjälpande",
    "stjälpandenas": "stjälpande",
    "stjälpandens": "stjälpande",
    "stjälpandes": "stjälpande",
    "stjälpandet": "stjälpande",
    "stjälpandets": "stjälpande",
    "stjälpas": "stjälpa",
    "stjälper": "stjälpa",
    "stjälpes": "stjälpa",
    "stjälps": "stjälpa",
    "stjälpt": "stjälpa",
    "stjälpta": "stjälpa",
    "stjälptas": "stjälpa",
    "stjälpte": "stjälpa",
    "stjälptes": "stjälpa",
    "stjälpts": "stjälpa",
    "stjäls": "stjäla",
    "stjärn": "stjärna",
    "stjärnan": "stjärna",
    "stjärnans": "stjärna",
    "stjärnarkitekten": "stjärnarkitekt",
    "stjärnarkitektens": "stjärnarkitekt",
    "stjärnarkitekter": "stjärnarkitekt",
    "stjärnarkitekterna": "stjärnarkitekt",
    "stjärnarkitekternas": "stjärnarkitekt",
    "stjärnarkitekters": "stjärnarkitekt",
    "stjärnarkitekts": "stjärnarkitekt",
    "stjärnas": "stjärna",
    "stjärnassociationen": "stjärnassociation",
    "stjärnassociationens": "stjärnassociation",
    "stjärnassociationer": "stjärnassociation",
    "stjärnassociationerna": "stjärnassociation",
    "stjärnassociationernas": "stjärnassociation",
    "stjärnassociationers": "stjärnassociation",
    "stjärnassociations": "stjärnassociation",
    "stjärnbaneret": "stjärnbaner",
    "stjärnbanerets": "stjärnbaner",
    "stjärnbaners": "stjärnbaner",
    "stjärnbeströdda": "stjärnbeströdd",
    "stjärnbeströddare": "stjärnbeströdd",
    "stjärnbeströddares": "stjärnbeströdd",
    "stjärnbeströddas": "stjärnbeströdd",
    "stjärnbeströddast": "stjärnbeströdd",
    "stjärnbeströddaste": "stjärnbeströdd",
    "stjärnbeströddastes": "stjärnbeströdd",
    "stjärnbeströddasts": "stjärnbeströdd",
    "stjärnbeströdde": "stjärnbeströdd",
    "stjärnbeströddes": "stjärnbeströdd",
    "stjärnbeströdds": "stjärnbeströdd",
    "stjärnbestrött": "stjärnbeströdd",
    "stjärnbeströtts": "stjärnbeströdd",
    "stjärnbetäckningar": "stjärnbetäckning",
    "stjärnbetäckningarna": "stjärnbetäckning",
    "stjärnbetäckningarnas": "stjärnbetäckning",
    "stjärnbetäckningars": "stjärnbetäckning",
    "stjärnbetäckningen": "stjärnbetäckning",
    "stjärnbetäckningens": "stjärnbetäckning",
    "stjärnbetäcknings": "stjärnbetäckning",
    "stjärnbilden": "stjärnbild",
    "stjärnbildens": "stjärnbild",
    "stjärnbilder": "stjärnbild",
    "stjärnbilderna": "stjärnbild",
    "stjärnbildernas": "stjärnbild",
    "stjärnbilders": "stjärnbild",
    "stjärnbilds": "stjärnbild",
    "stjärnblom": "stjärnblomma",
    "stjärnblomman": "stjärnblomma",
    "stjärnblommans": "stjärnblomma",
    "stjärnblommas": "stjärnblomma",
    "stjärnblomme": "stjärnblomma",
    "stjärnblommor": "stjärnblomma",
    "stjärnblommorna": "stjärnblomma",
    "stjärnblommornas": "stjärnblomma",
    "stjärnblommors": "stjärnblomma",
    "stjärnbloms": "stjärnblomma",
    "stjärndygnen": "stjärndygn",
    "stjärndygnens": "stjärndygn",
    "stjärndygnet": "stjärndygn",
    "stjärndygnets": "stjärndygn",
    "stjärndygns": "stjärndygn",
    "stjärne": "stjärna",
    "stjärnen": "stjärn",
    "stjärnens": "stjärn",
    "stjärnevalven": "stjärnevalv",
    "stjärnevalvens": "stjärnevalv",
    "stjärnevalvet": "stjärnevalv",
    "stjärnevalvets": "stjärnevalv",
    "stjärnevalvs": "stjärnevalv",
    "stjärnevärlden": "stjärnevärld",
    "stjärnevärldens": "stjärnevärld",
    "stjärnevärlds": "stjärnevärld",
    "stjärnfallen": "stjärnfall",
    "stjärnfallens": "stjärnfall",
    "stjärnfallet": "stjärnfall",
    "stjärnfallets": "stjärnfall",
    "stjärnfalls": "stjärnfall",
    "stjärnfallsregnen": "stjärnfallsregn",
    "stjärnfallsregnens": "stjärnfallsregn",
    "stjärnfallsregnet": "stjärnfallsregn",
    "stjärnfallsregnets": "stjärnfallsregn",
    "stjärnfallsregns": "stjärnfallsregn",
    "stjärnfiguren": "stjärnfigur",
    "stjärnfigurens": "stjärnfigur",
    "stjärnfigurer": "stjärnfigur",
    "stjärnfigurerna": "stjärnfigur",
    "stjärnfigurernas": "stjärnfigur",
    "stjärnfigurers": "stjärnfigur",
    "stjärnfigurs": "stjärnfigur",
    "stjärnformiga": "stjärnformig",
    "stjärnformigare": "stjärnformig",
    "stjärnformigares": "stjärnformig",
    "stjärnformigas": "stjärnformig",
    "stjärnformigast": "stjärnformig",
    "stjärnformigaste": "stjärnformig",
    "stjärnformigastes": "stjärnformig",
    "stjärnformigasts": "stjärnformig",
    "stjärnformige": "stjärnformig",
    "stjärnformiges": "stjärnformig",
    "stjärnformigheten": "stjärnformighet",
    "stjärnformighetens": "stjärnformighet",
    "stjärnformighets": "stjärnformighet",
    "stjärnformigs": "stjärnformig",
    "stjärnformigt": "stjärnformig",
    "stjärnformigts": "stjärnformig",
    "stjärngoss": "stjärngosse",
    "stjärngossar": "stjärngosse",
    "stjärngossarna": "stjärngosse",
    "stjärngossarnas": "stjärngosse",
    "stjärngossars": "stjärngosse",
    "stjärngossen": "stjärngosse",
    "stjärngossens": "stjärngosse",
    "stjärngosses": "stjärngosse",
    "stjärngrann": "stjärngranne",
    "stjärngrannar": "stjärngranne",
    "stjärngrannarna": "stjärngranne",
    "stjärngrannarnas": "stjärngranne",
    "stjärngrannars": "stjärngranne",
    "stjärngrannen": "stjärngranne",
    "stjärngrannens": "stjärngranne",
    "stjärngrannes": "stjärngranne",
    "stjärngranns": "stjärngranne",
    "stjärnhimlar": "stjärnhimmel",
    "stjärnhimlarna": "stjärnhimmel",
    "stjärnhimlarnas": "stjärnhimmel",
    "stjärnhimlars": "stjärnhimmel",
    "stjärnhimlen": "stjärnhimmel",
    "stjärnhimlens": "stjärnhimmel",
    "stjärnhimmelen": "stjärnhimmel",
    "stjärnhimmelens": "stjärnhimmel",
    "stjärnhimmeln": "stjärnhimmel",
    "stjärnhimmelns": "stjärnhimmel",
    "stjärnhimmels": "stjärnhimmel",
    "stjärnhopar": "stjärnhop",
    "stjärnhoparna": "stjärnhop",
    "stjärnhoparnas": "stjärnhop",
    "stjärnhopars": "stjärnhop",
    "stjärnhopen": "stjärnhop",
    "stjärnhopens": "stjärnhop",
    "stjärnhops": "stjärnhop",
    "stjärnhusen": "stjärnhus",
    "stjärnhusens": "stjärnhus",
    "stjärnhuset": "stjärnhus",
    "stjärnhusets": "stjärnhus",
    "stjärnkart": "stjärnkarta",
    "stjärnkartan": "stjärnkarta",
    "stjärnkartans": "stjärnkarta",
    "stjärnkartas": "stjärnkarta",
    "stjärnkarte": "stjärnkarta",
    "stjärnkartor": "stjärnkarta",
    "stjärnkartorna": "stjärnkarta",
    "stjärnkartornas": "stjärnkarta",
    "stjärnkartors": "stjärnkarta",
    "stjärnkarts": "stjärnkarta",
    "stjärnklara": "stjärnklar",
    "stjärnklarare": "stjärnklar",
    "stjärnklarares": "stjärnklar",
    "stjärnklaras": "stjärnklar",
    "stjärnklarast": "stjärnklar",
    "stjärnklaraste": "stjärnklar",
    "stjärnklarastes": "stjärnklar",
    "stjärnklarasts": "stjärnklar",
    "stjärnklare": "stjärnklar",
    "stjärnklares": "stjärnklar",
    "stjärnklars": "stjärnklar",
    "stjärnklart": "stjärnklar",
    "stjärnklarts": "stjärnklar",
    "stjärnkockar": "stjärnkock",
    "stjärnkockarna": "stjärnkock",
    "stjärnkockarnas": "stjärnkock",
    "stjärnkockars": "stjärnkock",
    "stjärnkocken": "stjärnkock",
    "stjärnkockens": "stjärnkock",
    "stjärnkocks": "stjärnkock",
    "stjärnkonstellationen": "stjärnkonstellation",
    "stjärnkonstellationens": "stjärnkonstellation",
    "stjärnkonstellationer": "stjärnkonstellation",
    "stjärnkonstellationerna": "stjärnkonstellation",
    "stjärnkonstellationernas": "stjärnkonstellation",
    "stjärnkonstellationers": "stjärnkonstellation",
    "stjärnkonstellations": "stjärnkonstellation",
    "stjärnkopplingar": "stjärnkoppling",
    "stjärnkopplingarna": "stjärnkoppling",
    "stjärnkopplingarnas": "stjärnkoppling",
    "stjärnkopplingars": "stjärnkoppling",
    "stjärnkopplingen": "stjärnkoppling",
    "stjärnkopplingens": "stjärnkoppling",
    "stjärnkopplings": "stjärnkoppling",
    "stjärnkrögar": "stjärnkrögare",
    "stjärnkrögaren": "stjärnkrögare",
    "stjärnkrögarens": "stjärnkrögare",
    "stjärnkrögares": "stjärnkrögare",
    "stjärnkrögarna": "stjärnkrögare",
    "stjärnkrögarnas": "stjärnkrögare",
    "stjärnkuskar": "stjärnkusk",
    "stjärnkuskarna": "stjärnkusk",
    "stjärnkuskarnas": "stjärnkusk",
    "stjärnkuskars": "stjärnkusk",
    "stjärnkusken": "stjärnkusk",
    "stjärnkuskens": "stjärnkusk",
    "stjärnkusks": "stjärnkusk",
    "stjärnköttet": "stjärnkött",
    "stjärnköttets": "stjärnkött",
    "stjärnkötts": "stjärnkött",
    "stjärnlika": "stjärnlik",
    "stjärnlikare": "stjärnlik",
    "stjärnlikares": "stjärnlik",
    "stjärnlikas": "stjärnlik",
    "stjärnlikast": "stjärnlik",
    "stjärnlikaste": "stjärnlik",
    "stjärnlikastes": "stjärnlik",
    "stjärnlikasts": "stjärnlik",
    "stjärnlike": "stjärnlik",
    "stjärnlikes": "stjärnlik",
    "stjärnlikheten": "stjärnlikhet",
    "stjärnlikhetens": "stjärnlikhet",
    "stjärnlikhets": "stjärnlikhet",
    "stjärnliks": "stjärnlik",
    "stjärnlikt": "stjärnlik",
    "stjärnlikts": "stjärnlik",
    "stjärnljusa": "stjärnljus",
    "stjärnljusare": "stjärnljus",
    "stjärnljusares": "stjärnljus",
    "stjärnljusas": "stjärnljus",
    "stjärnljusast": "stjärnljus",
    "stjärnljusaste": "stjärnljus",
    "stjärnljusastes": "stjärnljus",
    "stjärnljusasts": "stjärnljus",
    "stjärnljuse": "stjärnljus",
    "stjärnljusen": "stjärnljus",
    "stjärnljusens": "stjärnljus",
    "stjärnljuses": "stjärnljus",
    "stjärnljuset": "stjärnljus",
    "stjärnljusets": "stjärnljus",
    "stjärnljust": "stjärnljus",
    "stjärnljusts": "stjärnljus",
    "stjärnmejseln": "stjärnmejsel",
    "stjärnmejselns": "stjärnmejsel",
    "stjärnmejsels": "stjärnmejsel",
    "stjärnmejslar": "stjärnmejsel",
    "stjärnmejslarna": "stjärnmejsel",
    "stjärnmejslarnas": "stjärnmejsel",
    "stjärnmejslars": "stjärnmejsel",
    "stjärnmotorer": "stjärnmotor",
    "stjärnmotorerna": "stjärnmotor",
    "stjärnmotorernas": "stjärnmotor",
    "stjärnmotorers": "stjärnmotor",
    "stjärnmotorn": "stjärnmotor",
    "stjärnmotorns": "stjärnmotor",
    "stjärnmotors": "stjärnmotor",
    "stjärnmålvakten": "stjärnmålvakt",
    "stjärnmålvaktens": "stjärnmålvakt",
    "stjärnmålvakter": "stjärnmålvakt",
    "stjärnmålvakterna": "stjärnmålvakt",
    "stjärnmålvakternas": "stjärnmålvakt",
    "stjärnmålvakters": "stjärnmålvakt",
    "stjärnmålvakts": "stjärnmålvakt",
    "stjärnor": "stjärna",
    "stjärnorna": "stjärna",
    "stjärnornas": "stjärna",
    "stjärnors": "stjärna",
    "stjärnparen": "stjärnpar",
    "stjärnparens": "stjärnpar",
    "stjärnparet": "stjärnpar",
    "stjärnparets": "stjärnpar",
    "stjärnpars": "stjärnpar",
    "stjärns": "stjärna",
    "stjärnskotten": "stjärnskott",
    "stjärnskottens": "stjärnskott",
    "stjärnskottet": "stjärnskott",
    "stjärnskottets": "stjärnskott",
    "stjärnskotts": "stjärnskott",
    "stjärnskådespelar": "stjärnskådespelare",
    "stjärnskådespelaren": "stjärnskådespelare",
    "stjärnskådespelarens": "stjärnskådespelare",
    "stjärnskådespelares": "stjärnskådespelare",
    "stjärnskådespelarna": "stjärnskådespelare",
    "stjärnskådespelarnas": "stjärnskådespelare",
    "stjärnsmällar": "stjärnsmäll",
    "stjärnsmällarna": "stjärnsmäll",
    "stjärnsmällarnas": "stjärnsmäll",
    "stjärnsmällars": "stjärnsmäll",
    "stjärnsmällen": "stjärnsmäll",
    "stjärnsmällens": "stjärnsmäll",
    "stjärnsmälls": "stjärnsmäll",
    "stjärnspäckade": "stjärnspäckad",
    "stjärnspäckades": "stjärnspäckad",
    "stjärnspäckads": "stjärnspäckad",
    "stjärnspäckat": "stjärnspäckad",
    "stjärnspäckats": "stjärnspäckad",
    "stjärnstatusen": "stjärnstatus",
    "stjärnstatusens": "stjärnstatus",
    "stjärnsystemen": "stjärnsystem",
    "stjärnsystemens": "stjärnsystem",
    "stjärnsystemet": "stjärnsystem",
    "stjärnsystemets": "stjärnsystem",
    "stjärnsystems": "stjärnsystem",
    "stjärntiden": "stjärntid",
    "stjärntidens": "stjärntid",
    "stjärntids": "stjärntid",
    "stjärntripletten": "stjärntriplett",
    "stjärntriplettens": "stjärntriplett",
    "stjärntripletter": "stjärntriplett",
    "stjärntripletterna": "stjärntriplett",
    "stjärntripletternas": "stjärntriplett",
    "stjärntripletters": "stjärntriplett",
    "stjärntripletts": "stjärntriplett",
    "stjärntydar": "stjärntydare",
    "stjärntydaren": "stjärntydare",
    "stjärntydarens": "stjärntydare",
    "stjärntydares": "stjärntydare",
    "stjärntydarna": "stjärntydare",
    "stjärntydarnas": "stjärntydare",
    "stjärnvalven": "stjärnvalv",
    "stjärnvalvens": "stjärnvalv",
    "stjärnvalvet": "stjärnvalv",
    "stjärnvalvets": "stjärnvalv",
    "stjärnvalvs": "stjärnvalv",
    "stjärnögda": "stjärnögd",
    "stjärnögdare": "stjärnögd",
    "stjärnögdares": "stjärnögd",
    "stjärnögdas": "stjärnögd",
    "stjärnögdast": "stjärnögd",
    "stjärnögdaste": "stjärnögd",
    "stjärnögdastes": "stjärnögd",
    "stjärnögdasts": "stjärnögd",
    "stjärnögde": "stjärnögd",
    "stjärnögdes": "stjärnögd",
    "stjärnögdheten": "stjärnögdhet",
    "stjärnögdhetens": "stjärnögdhet",
    "stjärnögdhets": "stjärnögdhet",
    "stjärnögds": "stjärnögd",
    "stjärnögt": "stjärnögd",
    "stjärnögts": "stjärnögd",
    "stjärtar": "stjärt",
    "stjärtarna": "stjärt",
    "stjärtarnas": "stjärt",
    "stjärtars": "stjärt",
    "stjärtdelar": "stjärtdel",
    "stjärtdelarna": "stjärtdel",
    "stjärtdelarnas": "stjärtdel",
    "stjärtdelars": "stjärtdel",
    "stjärtdelen": "stjärtdel",
    "stjärtdelens": "stjärtdel",
    "stjärtdels": "stjärtdel",
    "stjärten": "stjärt",
    "stjärtens": "stjärt",
    "stjärterummet": "stjärterum",
    "stjärterummets": "stjärterum",
    "stjärterums": "stjärterum",
    "stjärtfen": "stjärtfena",
    "stjärtfenan": "stjärtfena",
    "stjärtfenans": "stjärtfena",
    "stjärtfenas": "stjärtfena",
    "stjärtfene": "stjärtfena",
    "stjärtfenor": "stjärtfena",
    "stjärtfenorna": "stjärtfena",
    "stjärtfenornas": "stjärtfena",
    "stjärtfenors": "stjärtfena",
    "stjärtfens": "stjärtfena",
    "stjärtfjädern": "stjärtfjäder",
    "stjärtfjäderns": "stjärtfjäder",
    "stjärtfjäders": "stjärtfjäder",
    "stjärtfjädrar": "stjärtfjäder",
    "stjärtfjädrarna": "stjärtfjäder",
    "stjärtfjädrarnas": "stjärtfjäder",
    "stjärtfjädrars": "stjärtfjäder",
    "stjärtgoss": "stjärtgosse",
    "stjärtgossar": "stjärtgosse",
    "stjärtgossarna": "stjärtgosse",
    "stjärtgossarnas": "stjärtgosse",
    "stjärtgossars": "stjärtgosse",
    "stjärtgossen": "stjärtgosse",
    "stjärtgossens": "stjärtgosse",
    "stjärtgosses": "stjärtgosse",
    "stjärtgympan": "stjärtgympa",
    "stjärtgympans": "stjärtgympa",
    "stjärtgympas": "stjärtgympa",
    "stjärtmesar": "stjärtmes",
    "stjärtmesarna": "stjärtmes",
    "stjärtmesarnas": "stjärtmes",
    "stjärtmesars": "stjärtmes",
    "stjärtmesen": "stjärtmes",
    "stjärtmesens": "stjärtmes",
    "stjärts": "stjärt",
    "stjärtskulptören": "stjärtskulptör",
    "stjärtskulptörens": "stjärtskulptör",
    "stjärtskulptörer": "stjärtskulptör",
    "stjärtskulptörerna": "stjärtskulptör",
    "stjärtskulptörernas": "stjärtskulptör",
    "stjärtskulptörers": "stjärtskulptör",
    "stjärtskulptörs": "stjärtskulptör",
    "stjärttrakten": "stjärttrakt",
    "stjärttraktens": "stjärttrakt",
    "stjärttrakter": "stjärttrakt",
    "stjärttrakterna": "stjärttrakt",
    "stjärttrakternas": "stjärttrakt",
    "stjärttrakters": "stjärttrakt",
    "stjärttrakts": "stjärttrakt",
    "sto": "stoa",
    "stoan": "stoa",
    "stoans": "stoa",
    "stoas": "stoa",
    "stock": "stocka",
    "stock-caren": "stock-car",
    "stock-carens": "stock-car",
    "stock-cars": "stock-car",
    "stockad": "stocka",
    "stockade": "stocka",
    "stockades": "stocka",
    "stockads": "stocka",
    "stockande": "stocka",
    "stockanden": "stockande",
    "stockandena": "stockande",
    "stockandenas": "stockande",
    "stockandens": "stockande",
    "stockandes": "stockande",
    "stockandet": "stockande",
    "stockandets": "stockande",
    "stockankar": "stockankare",
    "stockankaren": "stockankare",
    "stockankarens": "stockankare",
    "stockankares": "stockankare",
    "stockankaret": "stockankare",
    "stockankarets": "stockankare",
    "stockankarna": "stockankare",
    "stockankarnas": "stockankare",
    "stockar": "stocka",
    "stockarna": "stock",
    "stockarnas": "stock",
    "stockars": "stock",
    "stockas": "stocka",
    "stockat": "stocka",
    "stockats": "stocka",
    "stockbåtar": "stockbåt",
    "stockbåtarna": "stockbåt",
    "stockbåtarnas": "stockbåt",
    "stockbåtars": "stockbåt",
    "stockbåten": "stockbåt",
    "stockbåtens": "stockbåt",
    "stockbåts": "stockbåt",
    "stockdumheten": "stockdumhet",
    "stockdumhetens": "stockdumhet",
    "stockdumhets": "stockdumhet",
    "stockdumma": "stockdum",
    "stockdummare": "stockdum",
    "stockdummares": "stockdum",
    "stockdummas": "stockdum",
    "stockdummast": "stockdum",
    "stockdummaste": "stockdum",
    "stockdummastes": "stockdum",
    "stockdummasts": "stockdum",
    "stockdumme": "stockdum",
    "stockdummes": "stockdum",
    "stockdums": "stockdum",
    "stockdumt": "stockdum",
    "stockdumts": "stockdum",
    "stockeldar": "stockeld",
    "stockeldarna": "stockeld",
    "stockeldarnas": "stockeld",
    "stockeldars": "stockeld",
    "stockelden": "stockeld",
    "stockeldens": "stockeld",
    "stockelds": "stockeld",
    "stocken": "stock",
    "stockens": "stock",
    "stockfiskar": "stockfisk",
    "stockfiskarna": "stockfisk",
    "stockfiskarnas": "stockfisk",
    "stockfiskars": "stockfisk",
    "stockfisken": "stockfisk",
    "stockfiskens": "stockfisk",
    "stockfisks": "stockfisk",
    "stockholmar": "stockholmare",
    "stockholmaren": "stockholmare",
    "stockholmarens": "stockholmare",
    "stockholmares": "stockholmare",
    "stockholmarna": "stockholmare",
    "stockholmarnas": "stockholmare",
    "stockholmsk": "stockholmska",
    "stockholmskan": "stockholmska",
    "stockholmskans": "stockholmska",
    "stockholmskas": "stockholmska",
    "stockholmske": "stockholmska",
    "stockholmskor": "stockholmska",
    "stockholmskorna": "stockholmska",
    "stockholmskornas": "stockholmska",
    "stockholmskors": "stockholmska",
    "stockholmsmässiga": "stockholmsmässig",
    "stockholmsmässigares": "stockholmsmässig",
    "stockholmsmässigast": "stockholmsmässig",
    "stockholmsmässigastes": "stockholmsmässig",
    "stockholmsmässige": "stockholmsmässig",
    "stockholmsmässigs": "stockholmsmässig",
    "stockholmsmässigts": "stockholmsmässig",
    "stockkonservativa": "stockkonservativ",
    "stockkonservativare": "stockkonservativ",
    "stockkonservativares": "stockkonservativ",
    "stockkonservativas": "stockkonservativ",
    "stockkonservativast": "stockkonservativ",
    "stockkonservativaste": "stockkonservativ",
    "stockkonservativastes": "stockkonservativ",
    "stockkonservativasts": "stockkonservativ",
    "stockkonservative": "stockkonservativ",
    "stockkonservatives": "stockkonservativ",
    "stockkonservativs": "stockkonservativ",
    "stockkonservativt": "stockkonservativ",
    "stockkonservativts": "stockkonservativ",
    "stockningar": "stockning",
    "stockningarna": "stockning",
    "stockningarnas": "stockning",
    "stockningars": "stockning",
    "stockningen": "stockning",
    "stockningens": "stockning",
    "stocknings": "stockning",
    "stockrosen": "stockros",
    "stockrosens": "stockros",
    "stockrosor": "stockros",
    "stockrosorna": "stockros",
    "stockrosornas": "stockros",
    "stockrosors": "stockros",
    "stocks": "stock",
    "stod": "stå",
    "stode": "stå",
    "stoden": "stod",
    "stodens": "stod",
    "stoder": "stod",
    "stoderna": "stod",
    "stodernas": "stod",
    "stoders": "stod",
    "stodes": "stå",
    "stods": "stod",
    "stoe": "stoa",
    "stoet": "sto",
    "stoets": "sto",
    "stoffen": "stoff",
    "stoffens": "stoff",
    "stoffer": "stoff",
    "stofferad": "stoffera",
    "stofferade": "stoffera",
    "stofferades": "stoffera",
    "stofferads": "stoffera",
    "stofferande": "stoffera",
    "stofferanden": "stofferande",
    "stofferandena": "stofferande",
    "stofferandenas": "stofferande",
    "stofferandens": "stofferande",
    "stofferandes": "stofferande",
    "stofferandet": "stofferande",
    "stofferandets": "stofferande",
    "stofferar": "stoffera",
    "stofferas": "stoffera",
    "stofferat": "stoffera",
    "stofferats": "stoffera",
    "stofferbara": "stofferbar",
    "stofferbarare": "stofferbar",
    "stofferbarares": "stofferbar",
    "stofferbaras": "stofferbar",
    "stofferbarast": "stofferbar",
    "stofferbaraste": "stofferbar",
    "stofferbarastes": "stofferbar",
    "stofferbarasts": "stofferbar",
    "stofferbare": "stofferbar",
    "stofferbares": "stofferbar",
    "stofferbarheten": "stofferbarhet",
    "stofferbarhetens": "stofferbarhet",
    "stofferbarhets": "stofferbarhet",
    "stofferbars": "stofferbar",
    "stofferbart": "stofferbar",
    "stofferbarts": "stofferbar",
    "stofferingar": "stoffering",
    "stofferingarna": "stoffering",
    "stofferingarnas": "stoffering",
    "stofferingars": "stoffering",
    "stofferingen": "stoffering",
    "stofferingens": "stoffering",
    "stofferings": "stoffering",
    "stofferna": "stoff",
    "stoffernas": "stoff",
    "stoffers": "stoff",
    "stoffet": "stoff",
    "stoffets": "stoff",
    "stoffs": "stoff",
    "stofilen": "stofil",
    "stofilens": "stofil",
    "stofiler": "stofil",
    "stofilerna": "stofil",
    "stofilernas": "stofil",
    "stofilers": "stofil",
    "stofils": "stofil",
    "stoften": "stoft",
    "stoftens": "stoft",
    "stoftet": "stoft",
    "stoftets": "stoft",
    "stofthydd": "stofthydda",
    "stofthyddan": "stofthydda",
    "stofthyddans": "stofthydda",
    "stofthyddas": "stofthydda",
    "stofthydde": "stofthydda",
    "stofthyddor": "stofthydda",
    "stofthyddorna": "stofthydda",
    "stofthyddornas": "stofthydda",
    "stofthyddors": "stofthydda",
    "stofthydds": "stofthydda",
    "stoftkornen": "stoftkorn",
    "stoftkornens": "stoftkorn",
    "stoftkornet": "stoftkorn",
    "stoftkornets": "stoftkorn",
    "stoftkorns": "stoftkorn",
    "stoftmolnen": "stoftmoln",
    "stoftmolnens": "stoftmoln",
    "stoftmolnet": "stoftmoln",
    "stoftmolnets": "stoftmoln",
    "stoftmolns": "stoftmoln",
    "stoftmängden": "stoftmängd",
    "stoftmängdens": "stoftmängd",
    "stoftmängder": "stoftmängd",
    "stoftmängderna": "stoftmängd",
    "stoftmängdernas": "stoftmängd",
    "stoftmängders": "stoftmängd",
    "stoftmängds": "stoftmängd",
    "stoftpartikeln": "stoftpartikel",
    "stoftpartikelns": "stoftpartikel",
    "stoftpartikels": "stoftpartikel",
    "stoftpartiklar": "stoftpartikel",
    "stoftpartiklarna": "stoftpartikel",
    "stoftpartiklarnas": "stoftpartikel",
    "stoftpartiklars": "stoftpartikel",
    "stofts": "stoft",
    "stoftslöjan": "stoftslöja",
    "stoftslöjans": "stoftslöja",
    "stoftslöjas": "stoftslöja",
    "stoftslöje": "stoftslöja",
    "stoftslöjor": "stoftslöja",
    "stoftslöjorna": "stoftslöja",
    "stoftslöjornas": "stoftslöja",
    "stoftslöjors": "stoftslöja",
    "stoicismen": "stoicism",
    "stoicismens": "stoicism",
    "stoicismer": "stoicism",
    "stoicismerna": "stoicism",
    "stoicismernas": "stoicism",
    "stoicismers": "stoicism",
    "stoicisms": "stoicism",
    "stoicistiska": "stoicistisk",
    "stoicistiskas": "stoicistisk",
    "stoicistiske": "stoicistisk",
    "stoicistiskes": "stoicistisk",
    "stoicistisks": "stoicistisk",
    "stoicistiskt": "stoicistisk",
    "stoicistiskts": "stoicistisk",
    "stoikern": "stoiker",
    "stoikerna": "stoiker",
    "stoikernas": "stoiker",
    "stoikerns": "stoiker",
    "stoikers": "stoiker",
    "stoiska": "stoisk",
    "stoiskare": "stoisk",
    "stoiskares": "stoisk",
    "stoiskas": "stoisk",
    "stoiskast": "stoisk",
    "stoiskaste": "stoisk",
    "stoiskastes": "stoisk",
    "stoiskasts": "stoisk",
    "stoiske": "stoisk",
    "stoiskes": "stoisk",
    "stoiskheten": "stoiskhet",
    "stoiskhetens": "stoiskhet",
    "stoiskhets": "stoiskhet",
    "stoisks": "stoisk",
    "stoiskt": "stoisk",
    "stoiskts": "stoisk",
    "stoj": "stoja",
    "stojad": "stoja",
    "stojade": "stoja",
    "stojades": "stoja",
    "stojads": "stoja",
    "stojande": "stoja",
    "stojanden": "stojande",
    "stojandena": "stojande",
    "stojandenas": "stojande",
    "stojandens": "stojande",
    "stojandes": "stojande",
    "stojandet": "stojande",
    "stojandets": "stojande",
    "stojar": "stoja",
    "stojas": "stoja",
    "stojat": "stoja",
    "stojats": "stoja",
    "stojet": "stoj",
    "stojets": "stoj",
    "stojiga": "stojig",
    "stojigare": "stojig",
    "stojigares": "stojig",
    "stojigas": "stojig",
    "stojigast": "stojig",
    "stojigaste": "stojig",
    "stojigastes": "stojig",
    "stojigasts": "stojig",
    "stojige": "stojig",
    "stojiges": "stojig",
    "stojigs": "stojig",
    "stojigt": "stojig",
    "stojigts": "stojig",
    "stojs": "stoj",
    "stokastiska": "stokastisk",
    "stokastiskare": "stokastisk",
    "stokastiskares": "stokastisk",
    "stokastiskas": "stokastisk",
    "stokastiskast": "stokastisk",
    "stokastiskaste": "stokastisk",
    "stokastiskastes": "stokastisk",
    "stokastiskasts": "stokastisk",
    "stokastiske": "stokastisk",
    "stokastiskes": "stokastisk",
    "stokastisks": "stokastisk",
    "stokastiskt": "stokastisk",
    "stokastiskts": "stokastisk",
    "stol": "stola",
    "stolan": "stola",
    "stolans": "stola",
    "stolar": "stol",
    "stolarna": "stol",
    "stolarnas": "stol",
    "stolars": "stol",
    "stolas": "stola",
    "stole": "stola",
    "stolen": "stol",
    "stolens": "stol",
    "stolgångar": "stolgång",
    "stolgångarna": "stolgång",
    "stolgångarnas": "stolgång",
    "stolgångars": "stolgång",
    "stolgången": "stolgång",
    "stolgångens": "stolgång",
    "stolgångs": "stolgång",
    "stoll": "stolle",
    "stollan": "stolla",
    "stollans": "stolla",
    "stollar": "stolle",
    "stollarna": "stolle",
    "stollarnas": "stolle",
    "stollars": "stolle",
    "stollas": "stolla",
    "stolle": "stolla",
    "stollen": "stolle",
    "stollens": "stolle",
    "stollerier": "stolleri",
    "stollerierna": "stolleri",
    "stolleriernas": "stolleri",
    "stolleriers": "stolleri",
    "stolleriet": "stolleri",
    "stolleriets": "stolleri",
    "stolleris": "stolleri",
    "stollerit": "stolleri",
    "stollerits": "stolleri",
    "stolles": "stolle",
    "stolliga": "stollig",
    "stolligare": "stollig",
    "stolligares": "stollig",
    "stolligas": "stollig",
    "stolligast": "stollig",
    "stolligaste": "stollig",
    "stolligastes": "stollig",
    "stolligasts": "stollig",
    "stollige": "stollig",
    "stolliges": "stollig",
    "stolligheten": "stollighet",
    "stollighetens": "stollighet",
    "stolligheter": "stollighet",
    "stolligheterna": "stollighet",
    "stolligheternas": "stollighet",
    "stolligheters": "stollighet",
    "stollighets": "stollighet",
    "stolligs": "stollig",
    "stolligt": "stollig",
    "stolligts": "stollig",
    "stollor": "stolla",
    "stollorna": "stolla",
    "stollornas": "stolla",
    "stollors": "stolla",
    "stolls": "stolle",
    "stolor": "stola",
    "stolorna": "stola",
    "stolornas": "stola",
    "stolors": "stola",
    "stolp": "stolpe",
    "stolpad": "stolpa",
    "stolpade": "stolpa",
    "stolpades": "stolpa",
    "stolpads": "stolpa",
    "stolpande": "stolpa",
    "stolpanden": "stolpande",
    "stolpandena": "stolpande",
    "stolpandenas": "stolpande",
    "stolpandens": "stolpande",
    "stolpandes": "stolpande",
    "stolpandet": "stolpande",
    "stolpandets": "stolpande",
    "stolpar": "stolpe",
    "stolparna": "stolpe",
    "stolparnas": "stolpe",
    "stolpars": "stolpe",
    "stolpas": "stolpa",
    "stolpat": "stolpa",
    "stolpats": "stolpa",
    "stolpbodar": "stolpbod",
    "stolpbodarna": "stolpbod",
    "stolpbodarnas": "stolpbod",
    "stolpbodars": "stolpbod",
    "stolpboden": "stolpbod",
    "stolpbodens": "stolpbod",
    "stolpbods": "stolpbod",
    "stolpdiagrammen": "stolpdiagram",
    "stolpdiagrammens": "stolpdiagram",
    "stolpdiagrammet": "stolpdiagram",
    "stolpdiagrammets": "stolpdiagram",
    "stolpdiagrams": "stolpdiagram",
    "stolpen": "stolpe",
    "stolpens": "stolpe",
    "stolpes": "stolpe",
    "stolpillerna": "stolpiller",
    "stolpillernas": "stolpiller",
    "stolpillers": "stolpiller",
    "stolpillren": "stolpiller",
    "stolpillrens": "stolpiller",
    "stolpillret": "stolpiller",
    "stolpillrets": "stolpiller",
    "stolpraden": "stolprad",
    "stolpradens": "stolprad",
    "stolprader": "stolprad",
    "stolpraderna": "stolprad",
    "stolpradernas": "stolprad",
    "stolpraders": "stolprad",
    "stolprads": "stolprad",
    "stolps": "stolpe",
    "stolpskon": "stolpsko",
    "stolpskons": "stolpsko",
    "stolpskor": "stolpsko",
    "stolpskorna": "stolpsko",
    "stolpskornas": "stolpsko",
    "stolpskors": "stolpsko",
    "stolpskos": "stolpsko",
    "stolpskotten": "stolpskott",
    "stolpskottens": "stolpskott",
    "stolpskottet": "stolpskott",
    "stolpskottets": "stolpskott",
    "stolpskotts": "stolpskott",
    "stols": "stola",
    "stolsitsar": "stolsits",
    "stolsitsarna": "stolsits",
    "stolsitsarnas": "stolsits",
    "stolsitsars": "stolsits",
    "stolsitsen": "stolsits",
    "stolsitsens": "stolsits",
    "stolsraden": "stolsrad",
    "stolsradens": "stolsrad",
    "stolsrader": "stolsrad",
    "stolsraderna": "stolsrad",
    "stolsradernas": "stolsrad",
    "stolsraders": "stolsrad",
    "stolsrads": "stolsrad",
    "stolsryggar": "stolsrygg",
    "stolsryggarna": "stolsrygg",
    "stolsryggarnas": "stolsrygg",
    "stolsryggars": "stolsrygg",
    "stolsryggen": "stolsrygg",
    "stolsryggens": "stolsrygg",
    "stolsryggs": "stolsrygg",
    "stolta": "stolt",
    "stoltare": "stolt",
    "stoltares": "stolt",
    "stoltas": "stolt",
    "stoltast": "stolt",
    "stoltaste": "stolt",
    "stoltastes": "stolt",
    "stoltasts": "stolt",
    "stolte": "stolt",
    "stoltes": "stolt",
    "stoltheten": "stolthet",
    "stolthetens": "stolthet",
    "stoltheter": "stolthet",
    "stoltheterna": "stolthet",
    "stoltheternas": "stolthet",
    "stoltheters": "stolthet",
    "stolthets": "stolthet",
    "stolts": "stolt",
    "stoltserade": "stoltsera",
    "stoltserades": "stoltsera",
    "stoltserande": "stoltsera",
    "stoltseranden": "stoltserande",
    "stoltserandena": "stoltserande",
    "stoltserandenas": "stoltserande",
    "stoltserandens": "stoltserande",
    "stoltserandes": "stoltserande",
    "stoltserandet": "stoltserande",
    "stoltserandets": "stoltserande",
    "stoltserar": "stoltsera",
    "stoltseras": "stoltsera",
    "stoltserat": "stoltsera",
    "stoltserats": "stoltsera",
    "stoltseringar": "stoltsering",
    "stoltseringarna": "stoltsering",
    "stoltseringarnas": "stoltsering",
    "stoltseringars": "stoltsering",
    "stoltseringen": "stoltsering",
    "stoltseringens": "stoltsering",
    "stoltserings": "stoltsering",
    "stom": "stomme",
    "stomatiten": "stomatit",
    "stomatitens": "stomatit",
    "stomatiter": "stomatit",
    "stomatiterna": "stomatit",
    "stomatiternas": "stomatit",
    "stomatiters": "stomatit",
    "stomatits": "stomatit",
    "stomien": "stomi",
    "stomiens": "stomi",
    "stomier": "stomi",
    "stomierna": "stomi",
    "stomiernas": "stomi",
    "stomiers": "stomi",
    "stomin": "stomi",
    "stomins": "stomi",
    "stomis": "stomi",
    "stomjölken": "stomjölk",
    "stomjölkens": "stomjölk",
    "stomjölks": "stomjölk",
    "stommar": "stomme",
    "stommarna": "stomme",
    "stommarnas": "stomme",
    "stommars": "stomme",
    "stommen": "stomme",
    "stommens": "stomme",
    "stommes": "stomme",
    "stompar": "stomp",
    "stomparna": "stomp",
    "stomparnas": "stomp",
    "stompars": "stomp",
    "stompen": "stomp",
    "stompens": "stomp",
    "stomps": "stomp",
    "stoms": "stomme",
    "ston": "sto",
    "stona": "sto",
    "stonas": "sto",
    "stons": "sto",
    "stoor": "stoa",
    "stoorna": "stoa",
    "stoornas": "stoa",
    "stoors": "stoa",
    "stopen": "stop",
    "stopens": "stop",
    "stopet": "stop",
    "stopets": "stop",
    "stopp": "stoppa",
    "stoppad": "stoppa",
    "stoppade": "stoppa",
    "stoppades": "stoppa",
    "stoppads": "stoppa",
    "stoppande": "stoppa",
    "stoppanden": "stoppande",
    "stoppandena": "stoppande",
    "stoppandenas": "stoppande",
    "stoppandens": "stoppande",
    "stoppandes": "stoppande",
    "stoppandet": "stoppande",
    "stoppandets": "stoppande",
    "stoppar": "stoppa",
    "stopparna": "stopp",
    "stopparnas": "stopp",
    "stoppars": "stopp",
    "stoppas": "stoppa",
    "stoppat": "stoppa",
    "stoppats": "stoppa",
    "stoppbollar": "stoppboll",
    "stoppbollarna": "stoppboll",
    "stoppbollarnas": "stoppboll",
    "stoppbollars": "stoppboll",
    "stoppbollen": "stoppboll",
    "stoppbollens": "stoppboll",
    "stoppbolls": "stoppboll",
    "stoppen": "stopp",
    "stoppens": "stopp",
    "stoppern": "stopper",
    "stopperns": "stopper",
    "stoppers": "stopper",
    "stoppersarna": "stopper",
    "stoppersarnas": "stopper",
    "stoppersen": "stopper",
    "stoppersens": "stopper",
    "stoppet": "stopp",
    "stoppets": "stopp",
    "stopplikten": "stopplikt",
    "stoppliktens": "stopplikt",
    "stopplikts": "stopplikt",
    "stoppljusen": "stoppljus",
    "stoppljusens": "stoppljus",
    "stoppljuset": "stoppljus",
    "stoppljusets": "stoppljus",
    "stopplykt": "stopplykta",
    "stopplyktan": "stopplykta",
    "stopplyktans": "stopplykta",
    "stopplyktas": "stopplykta",
    "stopplykte": "stopplykta",
    "stopplyktor": "stopplykta",
    "stopplyktorna": "stopplykta",
    "stopplyktornas": "stopplykta",
    "stopplyktors": "stopplykta",
    "stopplykts": "stopplykta",
    "stoppningar": "stoppning",
    "stoppningarna": "stoppning",
    "stoppningarnas": "stoppning",
    "stoppningars": "stoppning",
    "stoppningen": "stoppning",
    "stoppningens": "stoppning",
    "stoppnings": "stoppning",
    "stoppnålar": "stoppnål",
    "stoppnålarna": "stoppnål",
    "stoppnålarnas": "stoppnål",
    "stoppnålars": "stoppnål",
    "stoppnålen": "stoppnål",
    "stoppnålens": "stoppnål",
    "stoppnåls": "stoppnål",
    "stopprisen": "stoppris",
    "stopprisens": "stoppris",
    "stoppriser": "stoppris",
    "stoppriserna": "stoppris",
    "stopprisernas": "stoppris",
    "stopprisers": "stoppris",
    "stoppriset": "stoppris",
    "stopprisets": "stoppris",
    "stopps": "stopp",
    "stoppuren": "stoppur",
    "stoppurens": "stoppur",
    "stoppuret": "stoppur",
    "stoppurets": "stoppur",
    "stoppurs": "stoppur",
    "stops": "stop",
    "stora": "stor",
    "storartade": "storartad",
    "storartades": "storartad",
    "storartads": "storartad",
    "storartat": "storartad",
    "storartats": "storartad",
    "storas": "stor",
    "storasyskonen": "storasyskon",
    "storasyskonens": "storasyskon",
    "storasyskonet": "storasyskon",
    "storasyskonets": "storasyskon",
    "storasyskons": "storasyskon",
    "storasysterattityden": "storasysterattityd",
    "storasysterattitydens": "storasysterattityd",
    "storasysterattityder": "storasysterattityd",
    "storasysterattityderna": "storasysterattityd",
    "storasysterattitydernas": "storasysterattityd",
    "storasysterattityders": "storasysterattityd",
    "storasysterattityds": "storasysterattityd",
    "storasystern": "storasyster",
    "storasysterns": "storasyster",
    "storasysters": "storasyster",
    "storasystrar": "storasyster",
    "storasystrarna": "storasyster",
    "storasystrarnas": "storasyster",
    "storasystrars": "storasyster",
    "storbanden": "storband",
    "storbandens": "storband",
    "storbandet": "storband",
    "storbandets": "storband",
    "storbands": "storband",
    "storbandsmässiga": "storbandsmässig",
    "storbandsmässigare": "storbandsmässig",
    "storbandsmässigares": "storbandsmässig",
    "storbandsmässigas": "storbandsmässig",
    "storbandsmässigast": "storbandsmässig",
    "storbandsmässigaste": "storbandsmässig",
    "storbandsmässigastes": "storbandsmässig",
    "storbandsmässigasts": "storbandsmässig",
    "storbandsmässige": "storbandsmässig",
    "storbandsmässiges": "storbandsmässig",
    "storbandsmässigs": "storbandsmässig",
    "storbandsmässigt": "storbandsmässig",
    "storbandsmässigts": "storbandsmässig",
    "storblommiga": "storblommig",
    "storblommigare": "storblommig",
    "storblommigares": "storblommig",
    "storblommigas": "storblommig",
    "storblommigast": "storblommig",
    "storblommigaste": "storblommig",
    "storblommigastes": "storblommig",
    "storblommigasts": "storblommig",
    "storblommige": "storblommig",
    "storblommiges": "storblommig",
    "storblommigs": "storblommig",
    "storblommigt": "storblommig",
    "storblommigts": "storblommig",
    "storbolagen": "storbolag",
    "storbolagens": "storbolag",
    "storbolaget": "storbolag",
    "storbolagets": "storbolag",
    "storbolags": "storbolag",
    "storbolagsägar": "storbolagsägare",
    "storbolagsägaren": "storbolagsägare",
    "storbolagsägarens": "storbolagsägare",
    "storbolagsägares": "storbolagsägare",
    "storbolagsägarna": "storbolagsägare",
    "storbolagsägarnas": "storbolagsägare",
    "storbond": "storbonde",
    "storbonden": "storbonde",
    "storbondens": "storbonde",
    "storbondes": "storbonde",
    "storbonds": "storbonde",
    "storbranden": "storbrand",
    "storbrandens": "storbrand",
    "storbrands": "storbrand",
    "storbritanniska": "storbritannisk",
    "storbritanniskare": "storbritannisk",
    "storbritanniskares": "storbritannisk",
    "storbritanniskas": "storbritannisk",
    "storbritanniskast": "storbritannisk",
    "storbritanniskaste": "storbritannisk",
    "storbritanniskastes": "storbritannisk",
    "storbritanniskasts": "storbritannisk",
    "storbritanniske": "storbritannisk",
    "storbritanniskes": "storbritannisk",
    "storbritannisks": "storbritannisk",
    "storbritanniskt": "storbritannisk",
    "storbritanniskts": "storbritannisk",
    "storbränder": "storbrand",
    "storbränderna": "storbrand",
    "storbrändernas": "storbrand",
    "storbränders": "storbrand",
    "storbrättade": "storbrättad",
    "storbrättades": "storbrättad",
    "storbrättads": "storbrättad",
    "storbrättat": "storbrättad",
    "storbrättats": "storbrättad",
    "storbråken": "storbråk",
    "storbråkens": "storbråk",
    "storbråket": "storbråk",
    "storbråkets": "storbråk",
    "storbråks": "storbråk",
    "storbyar": "storby",
    "storbyarna": "storby",
    "storbyarnas": "storby",
    "storbyars": "storby",
    "storbyn": "storby",
    "storbyns": "storby",
    "storbys": "storby",
    "storbystade": "storbystad",
    "storbystades": "storbystad",
    "storbystads": "storbystad",
    "storbystat": "storbystad",
    "storbystats": "storbystad",
    "storbåtar": "storbåt",
    "storbåtarna": "storbåt",
    "storbåtarnas": "storbåt",
    "storbåtars": "storbåt",
    "storbåten": "storbåt",
    "storbåtens": "storbåt",
    "storbåts": "storbåt",
    "storbönder": "storbonde",
    "storbönderna": "storbonde",
    "storböndernas": "storbonde",
    "storbönders": "storbonde",
    "storcirkeln": "storcirkel",
    "storcirkelns": "storcirkel",
    "storcirkels": "storcirkel",
    "storcirkelseglingar": "storcirkelsegling",
    "storcirkelseglingarna": "storcirkelsegling",
    "storcirkelseglingarnas": "storcirkelsegling",
    "storcirkelseglingars": "storcirkelsegling",
    "storcirkelseglingen": "storcirkelsegling",
    "storcirkelseglingens": "storcirkelsegling",
    "storcirkelseglings": "storcirkelsegling",
    "storcirklar": "storcirkel",
    "storcirklarna": "storcirkel",
    "storcirklarnas": "storcirkel",
    "storcirklars": "storcirkel",
    "stordatorer": "stordator",
    "stordatorerna": "stordator",
    "stordatorernas": "stordator",
    "stordatorers": "stordator",
    "stordatorn": "stordator",
    "stordatorns": "stordator",
    "stordators": "stordator",
    "stordian": "stordia",
    "stordians": "stordia",
    "stordias": "stordia",
    "stordior": "stordia",
    "stordiorna": "stordia",
    "stordiornas": "stordia",
    "stordiors": "stordia",
    "stordriften": "stordrift",
    "stordriftens": "stordrift",
    "stordrifts": "stordrift",
    "stordåden": "stordåd",
    "stordådens": "stordåd",
    "stordådet": "stordåd",
    "stordådets": "stordåd",
    "stordåds": "stordåd",
    "store": "stor",
    "storebrors": "storebror",
    "storen": "store",
    "storens": "store",
    "storer": "store",
    "storerna": "store",
    "storernas": "store",
    "storers": "store",
    "stores": "store",
    "storfamiljen": "storfamilj",
    "storfamiljens": "storfamilj",
    "storfamiljer": "storfamilj",
    "storfamiljerna": "storfamilj",
    "storfamiljernas": "storfamilj",
    "storfamiljers": "storfamilj",
    "storfamiljs": "storfamilj",
    "storfamiljshusen": "storfamiljshus",
    "storfamiljshusens": "storfamiljshus",
    "storfamiljshuset": "storfamiljshus",
    "storfamiljshusets": "storfamiljshus",
    "storfinansen": "storfinans",
    "storfinansens": "storfinans",
    "storfrämmandes": "storfrämmande",
    "storfrämmandet": "storfrämmande",
    "storfrämmandets": "storfrämmande",
    "storfurstar": "storfurste",
    "storfurstarna": "storfurste",
    "storfurstarnas": "storfurste",
    "storfurstars": "storfurste",
    "storfursten": "storfurste",
    "storfurstendömen": "storfurstendöme",
    "storfurstendömena": "storfurstendöme",
    "storfurstendömenas": "storfurstendöme",
    "storfurstendömens": "storfurstendöme",
    "storfurstendömes": "storfurstendöme",
    "storfurstendömet": "storfurstendöme",
    "storfurstendömets": "storfurstendöme",
    "storfurstens": "storfurste",
    "storfurstes": "storfurste",
    "storföretagen": "storföretag",
    "storföretagens": "storföretag",
    "storföretaget": "storföretag",
    "storföretagets": "storföretag",
    "storföretags": "storföretag",
    "storförpackningar": "storförpackning",
    "storförpackningarna": "storförpackning",
    "storförpackningarnas": "storförpackning",
    "storförpackningars": "storförpackning",
    "storförpackningen": "storförpackning",
    "storförpackningens": "storförpackning",
    "storförpacknings": "storförpackning",
    "storgodsägar": "storgodsägare",
    "storgodsägaren": "storgodsägare",
    "storgodsägarens": "storgodsägare",
    "storgodsägares": "storgodsägare",
    "storgodsägarna": "storgodsägare",
    "storgodsägarnas": "storgodsägare",
    "storgrälen": "storgräl",
    "storgrälens": "storgräl",
    "storgrälet": "storgräl",
    "storgrälets": "storgräl",
    "storgräls": "storgräl",
    "storgrät": "storgråta",
    "storgräte": "storgråta",
    "storgrätes": "storgråta",
    "storgräts": "storgråta",
    "storgråt": "storgråta",
    "storgråtande": "storgråta",
    "storgråtanden": "storgråtande",
    "storgråtandena": "storgråtande",
    "storgråtandenas": "storgråtande",
    "storgråtandens": "storgråtande",
    "storgråtandes": "storgråtande",
    "storgråtandet": "storgråtande",
    "storgråtandets": "storgråtande",
    "storgråtas": "storgråta",
    "storgråte": "storgråta",
    "storgråter": "storgråta",
    "storgråtes": "storgråta",
    "storgråtit": "storgråta",
    "storgråtits": "storgråta",
    "storgråts": "storgråta",
    "storhandlade": "storhandla",
    "storhandlades": "storhandla",
    "storhandlande": "storhandla",
    "storhandlanden": "storhandlande",
    "storhandlandena": "storhandlande",
    "storhandlandenas": "storhandlande",
    "storhandlandens": "storhandlande",
    "storhandlandes": "storhandlande",
    "storhandlandet": "storhandlande",
    "storhandlandets": "storhandlande",
    "storhandlar": "storhandla",
    "storhandlas": "storhandla",
    "storhandlat": "storhandla",
    "storhandlats": "storhandla",
    "storhandlingar": "storhandling",
    "storhandlingarna": "storhandling",
    "storhandlingarnas": "storhandling",
    "storhandlingars": "storhandling",
    "storhandlingen": "storhandling",
    "storhandlingens": "storhandling",
    "storhandlings": "storhandling",
    "storhertigar": "storhertig",
    "storhertigarna": "storhertig",
    "storhertigarnas": "storhertig",
    "storhertigars": "storhertig",
    "storhertigen": "storhertig",
    "storhertigens": "storhertig",
    "storhertigs": "storhertig",
    "storheten": "storhet",
    "storhetens": "storhet",
    "storheter": "storhet",
    "storheterna": "storhet",
    "storheternas": "storhet",
    "storheters": "storhet",
    "storhets": "storhet",
    "storhetsvansinnes": "storhetsvansinne",
    "storhetsvansinnet": "storhetsvansinne",
    "storhetsvansinnets": "storhetsvansinne",
    "storhjärnan": "storhjärna",
    "storhjärnans": "storhjärna",
    "storhjärnas": "storhjärna",
    "storhushållen": "storhushåll",
    "storhushållens": "storhushåll",
    "storhushållet": "storhushåll",
    "storhushållets": "storhushåll",
    "storhushålls": "storhushåll",
    "storindustrien": "storindustri",
    "storindustriens": "storindustri",
    "storindustrier": "storindustri",
    "storindustrierna": "storindustri",
    "storindustriernas": "storindustri",
    "storindustriers": "storindustri",
    "storindustrin": "storindustri",
    "storindustrins": "storindustri",
    "storindustris": "storindustri",
    "storkar": "stork",
    "storkarna": "stork",
    "storkarnas": "stork",
    "storkars": "stork",
    "storken": "stork",
    "storkens": "stork",
    "storkn": "storkna",
    "storknad": "storkna",
    "storknade": "storkna",
    "storknades": "storkna",
    "storknads": "storkna",
    "storknande": "storkna",
    "storknanden": "storknande",
    "storknandena": "storknande",
    "storknandenas": "storknande",
    "storknandens": "storknande",
    "storknandes": "storknande",
    "storknandet": "storknande",
    "storknandets": "storknande",
    "storknar": "storkna",
    "storknas": "storkna",
    "storknat": "storkna",
    "storknats": "storkna",
    "storkommunen": "storkommun",
    "storkommunens": "storkommun",
    "storkommuner": "storkommun",
    "storkommunerna": "storkommun",
    "storkommunernas": "storkommun",
    "storkommuners": "storkommun",
    "storkommuns": "storkommun",
    "storkorsen": "storkors",
    "storkorsens": "storkors",
    "storkorset": "storkors",
    "storkorsets": "storkors",
    "storkrigen": "storkrig",
    "storkrigens": "storkrig",
    "storkriget": "storkrig",
    "storkrigets": "storkrig",
    "storkrigs": "storkrig",
    "storks": "stork",
    "storkukade": "storkukad",
    "storkukades": "storkukad",
    "storkukads": "storkukad",
    "storkukat": "storkukad",
    "storkukats": "storkukad",
    "storköken": "storkök",
    "storkökens": "storkök",
    "storköket": "storkök",
    "storkökets": "storkök",
    "storköks": "storkök",
    "storköksmaten": "storköksmat",
    "storköksmatens": "storköksmat",
    "storköksmats": "storköksmat",
    "storlekar": "storlek",
    "storlekarna": "storlek",
    "storlekarnas": "storlek",
    "storlekars": "storlek",
    "storleken": "storlek",
    "storlekens": "storlek",
    "storleks": "storlek",
    "storleksmässiga": "storleksmässig",
    "storleksmässigare": "storleksmässig",
    "storleksmässigares": "storleksmässig",
    "storleksmässigas": "storleksmässig",
    "storleksmässigast": "storleksmässig",
    "storleksmässigaste": "storleksmässig",
    "storleksmässigastes": "storleksmässig",
    "storleksmässigasts": "storleksmässig",
    "storleksmässige": "storleksmässig",
    "storleksmässiges": "storleksmässig",
    "storleksmässigs": "storleksmässig",
    "storleksmässigt": "storleksmässig",
    "storleksmässigts": "storleksmässig",
    "storleksnummerna": "storleksnummer",
    "storleksnummernas": "storleksnummer",
    "storleksnummers": "storleksnummer",
    "storleksnumren": "storleksnummer",
    "storleksnumrens": "storleksnummer",
    "storleksnumret": "storleksnummer",
    "storleksnumrets": "storleksnummer",
    "storleksordningar": "storleksordning",
    "storleksordningarna": "storleksordning",
    "storleksordningarnas": "storleksordning",
    "storleksordningars": "storleksordning",
    "storleksordningen": "storleksordning",
    "storleksordningens": "storleksordning",
    "storleksordnings": "storleksordning",
    "storm": "storma",
    "stormad": "storma",
    "stormade": "storma",
    "stormades": "storma",
    "stormads": "storma",
    "stormakten": "stormakt",
    "stormaktens": "stormakt",
    "stormakter": "stormakt",
    "stormakterna": "stormakt",
    "stormakternas": "stormakt",
    "stormakters": "stormakt",
    "stormakts": "stormakt",
    "stormaktspolitiken": "stormaktspolitik",
    "stormaktspolitikens": "stormaktspolitik",
    "stormaktspolitiks": "stormaktspolitik",
    "stormaktspolitiska": "stormaktspolitisk",
    "stormaktspolitiskare": "stormaktspolitisk",
    "stormaktspolitiskares": "stormaktspolitisk",
    "stormaktspolitiskas": "stormaktspolitisk",
    "stormaktspolitiskast": "stormaktspolitisk",
    "stormaktspolitiskaste": "stormaktspolitisk",
    "stormaktspolitiskastes": "stormaktspolitisk",
    "stormaktspolitiskasts": "stormaktspolitisk",
    "stormaktspolitiske": "stormaktspolitisk",
    "stormaktspolitiskes": "stormaktspolitisk",
    "stormaktspolitisks": "stormaktspolitisk",
    "stormaktspolitiskt": "stormaktspolitisk",
    "stormaktspolitiskts": "stormaktspolitisk",
    "stormaktsspelen": "stormaktsspel",
    "stormaktsspelens": "stormaktsspel",
    "stormaktsspelet": "stormaktsspel",
    "stormaktsspelets": "stormaktsspel",
    "stormaktsspels": "stormaktsspel",
    "stormaktsvälden": "stormaktsvälde",
    "stormaktsväldena": "stormaktsvälde",
    "stormaktsväldenas": "stormaktsvälde",
    "stormaktsväldens": "stormaktsvälde",
    "stormaktsväldes": "stormaktsvälde",
    "stormaktsväldet": "stormaktsvälde",
    "stormaktsväldets": "stormaktsvälde",
    "stormande": "storma",
    "stormanden": "stormande",
    "stormandena": "stormande",
    "stormandenas": "stormande",
    "stormandens": "stormande",
    "stormandes": "stormande",
    "stormandet": "stormande",
    "stormandets": "stormande",
    "stormannen": "storman",
    "stormannens": "storman",
    "stormans": "storman",
    "stormar": "storma",
    "stormarknaden": "stormarknad",
    "stormarknadens": "stormarknad",
    "stormarknader": "stormarknad",
    "stormarknaderna": "stormarknad",
    "stormarknadernas": "stormarknad",
    "stormarknaders": "stormarknad",
    "stormarknads": "stormarknad",
    "stormarna": "storm",
    "stormarnas": "storm",
    "stormars": "storm",
    "stormas": "storma",
    "stormasten": "stormast",
    "stormastens": "stormast",
    "stormaster": "stormast",
    "stormasterna": "stormast",
    "stormasternas": "stormast",
    "stormasters": "stormast",
    "stormasts": "stormast",
    "stormat": "storma",
    "stormats": "storma",
    "stormavdelningar": "stormavdelning",
    "stormavdelningarna": "stormavdelning",
    "stormavdelningarnas": "stormavdelning",
    "stormavdelningars": "stormavdelning",
    "stormavdelningen": "stormavdelning",
    "stormavdelningens": "stormavdelning",
    "stormavdelnings": "stormavdelning",
    "stormbåtar": "stormbåt",
    "stormbåtarna": "stormbåt",
    "stormbåtarnas": "stormbåt",
    "stormbåtars": "stormbåt",
    "stormbåten": "stormbåt",
    "stormbåtens": "stormbåt",
    "stormbåts": "stormbåt",
    "stormelden": "stormeld",
    "stormeldens": "stormeld",
    "stormelds": "stormeld",
    "stormen": "storm",
    "stormens": "storm",
    "stormfloden": "stormflod",
    "stormflodens": "stormflod",
    "stormfloder": "stormflod",
    "stormfloderna": "stormflod",
    "stormflodernas": "stormflod",
    "stormfloders": "stormflod",
    "stormflods": "stormflod",
    "stormfågeln": "stormfågel",
    "stormfågelns": "stormfågel",
    "stormfågels": "stormfågel",
    "stormfåglar": "stormfågel",
    "stormfåglarna": "stormfågel",
    "stormfåglarnas": "stormfågel",
    "stormfåglars": "stormfågel",
    "stormförtjusta": "stormförtjust",
    "stormförtjustare": "stormförtjust",
    "stormförtjustares": "stormförtjust",
    "stormförtjustas": "stormförtjust",
    "stormförtjustast": "stormförtjust",
    "stormförtjustaste": "stormförtjust",
    "stormförtjustastes": "stormförtjust",
    "stormförtjustasts": "stormförtjust",
    "stormförtjuste": "stormförtjust",
    "stormförtjustes": "stormförtjust",
    "stormförtjusts": "stormförtjust",
    "stormhattar": "stormhatt",
    "stormhattarna": "stormhatt",
    "stormhattarnas": "stormhatt",
    "stormhattars": "stormhatt",
    "stormhatten": "stormhatt",
    "stormhattens": "stormhatt",
    "stormhatts": "stormhatt",
    "stormhinderna": "stormhinder",
    "stormhindernas": "stormhinder",
    "stormhinders": "stormhinder",
    "stormhindren": "stormhinder",
    "stormhindrens": "stormhinder",
    "stormhindret": "stormhinder",
    "stormhindrets": "stormhinder",
    "stormiga": "stormig",
    "stormigare": "stormig",
    "stormigares": "stormig",
    "stormigas": "stormig",
    "stormigast": "stormig",
    "stormigaste": "stormig",
    "stormigastes": "stormig",
    "stormigasts": "stormig",
    "stormige": "stormig",
    "stormiges": "stormig",
    "stormigheten": "stormighet",
    "stormighetens": "stormighet",
    "stormighets": "stormighet",
    "stormigs": "stormig",
    "stormigt": "stormig",
    "stormigts": "stormig",
    "stormlykt": "stormlykta",
    "stormlyktan": "stormlykta",
    "stormlyktans": "stormlykta",
    "stormlyktas": "stormlykta",
    "stormlykte": "stormlykta",
    "stormlyktor": "stormlykta",
    "stormlyktorna": "stormlykta",
    "stormlyktornas": "stormlykta",
    "stormlyktors": "stormlykta",
    "stormlykts": "stormlykta",
    "stormningar": "stormning",
    "stormningarna": "stormning",
    "stormningarnas": "stormning",
    "stormningars": "stormning",
    "stormningen": "stormning",
    "stormningens": "stormning",
    "stormnings": "stormning",
    "stormogulen": "stormogul",
    "stormogulens": "stormogul",
    "stormoguler": "stormogul",
    "stormogulerna": "stormogul",
    "stormogulernas": "stormogul",
    "stormogulers": "stormogul",
    "stormoguls": "stormogul",
    "stormpunkten": "stormpunkt",
    "stormpunktens": "stormpunkt",
    "stormpunkter": "stormpunkt",
    "stormpunkterna": "stormpunkt",
    "stormpunkternas": "stormpunkt",
    "stormpunkters": "stormpunkt",
    "stormpunkts": "stormpunkt",
    "stormrika": "stormrik",
    "stormrikare": "stormrik",
    "stormrikares": "stormrik",
    "stormrikas": "stormrik",
    "stormrikast": "stormrik",
    "stormrikaste": "stormrik",
    "stormrikastes": "stormrik",
    "stormrikasts": "stormrik",
    "stormrike": "stormrik",
    "stormrikes": "stormrik",
    "stormrikheten": "stormrikhet",
    "stormrikhetens": "stormrikhet",
    "stormrikhets": "stormrikhet",
    "stormriks": "stormrik",
    "stormrikt": "stormrik",
    "stormrikts": "stormrik",
    "storms": "storm",
    "stormskäll": "stormskälla",
    "stormskällande": "stormskälla",
    "stormskällanden": "stormskällande",
    "stormskällandena": "stormskällande",
    "stormskällandenas": "stormskällande",
    "stormskällandens": "stormskällande",
    "stormskällandes": "stormskällande",
    "stormskällandet": "stormskällande",
    "stormskällandets": "stormskällande",
    "stormskällde": "stormskälla",
    "stormskäller": "stormskälla",
    "stormskällt": "stormskälla",
    "stormsval": "stormsvala",
    "stormsvalan": "stormsvala",
    "stormsvalans": "stormsvala",
    "stormsvalas": "stormsvala",
    "stormsvale": "stormsvala",
    "stormsvalor": "stormsvala",
    "stormsvalorna": "stormsvala",
    "stormsvalornas": "stormsvala",
    "stormsvalors": "stormsvala",
    "stormsvals": "stormsvala",
    "stormsäkerheten": "stormsäkerhet",
    "stormsäkerhetens": "stormsäkerhet",
    "stormsäkerhets": "stormsäkerhet",
    "stormsäkers": "stormsäker",
    "stormsäkert": "stormsäker",
    "stormsäkerts": "stormsäker",
    "stormsäkra": "stormsäker",
    "stormsäkrad": "stormsäkra",
    "stormsäkrade": "stormsäkra",
    "stormsäkrades": "stormsäkra",
    "stormsäkrads": "stormsäkra",
    "stormsäkrande": "stormsäkra",
    "stormsäkranden": "stormsäkrande",
    "stormsäkrandena": "stormsäkrande",
    "stormsäkrandenas": "stormsäkrande",
    "stormsäkrandens": "stormsäkrande",
    "stormsäkrandes": "stormsäkrande",
    "stormsäkrandet": "stormsäkrande",
    "stormsäkrandets": "stormsäkrande",
    "stormsäkrar": "stormsäkra",
    "stormsäkrare": "stormsäker",
    "stormsäkrares": "stormsäker",
    "stormsäkras": "stormsäkra",
    "stormsäkrast": "stormsäker",
    "stormsäkraste": "stormsäker",
    "stormsäkrastes": "stormsäker",
    "stormsäkrasts": "stormsäker",
    "stormsäkrat": "stormsäkra",
    "stormsäkrats": "stormsäkra",
    "stormsäkre": "stormsäker",
    "stormsäkres": "stormsäker",
    "stormtaken": "stormtak",
    "stormtakens": "stormtak",
    "stormtaket": "stormtak",
    "stormtakets": "stormtak",
    "stormtaks": "stormtak",
    "stormtrivdes": "stormtrivas",
    "stormtrivs": "stormtrivas",
    "stormtrivts": "stormtrivas",
    "stormuftier": "stormufti",
    "stormuftierna": "stormufti",
    "stormuftiernas": "stormufti",
    "stormuftiers": "stormufti",
    "stormuftin": "stormufti",
    "stormuftins": "stormufti",
    "stormuftis": "stormufti",
    "stormunnade": "stormunnad",
    "stormunnades": "stormunnad",
    "stormunnads": "stormunnad",
    "stormunnat": "stormunnad",
    "stormunnats": "stormunnad",
    "stormvarningar": "stormvarning",
    "stormvarningarna": "stormvarning",
    "stormvarningarnas": "stormvarning",
    "stormvarningars": "stormvarning",
    "stormvarningen": "stormvarning",
    "stormvarningens": "stormvarning",
    "stormvarnings": "stormvarning",
    "stormän": "storman",
    "stormännen": "storman",
    "stormännens": "storman",
    "stormäns": "storman",
    "stormästar": "stormästare",
    "stormästaren": "stormästare",
    "stormästarens": "stormästare",
    "stormästares": "stormästare",
    "stormästarna": "stormästare",
    "stormästarnas": "stormästare",
    "stormöten": "stormöte",
    "stormötena": "stormöte",
    "stormötenas": "stormöte",
    "stormötens": "stormöte",
    "stormötes": "stormöte",
    "stormötet": "stormöte",
    "stormötets": "stormöte",
    "storoffensiven": "storoffensiv",
    "storoffensivens": "storoffensiv",
    "storoffensiver": "storoffensiv",
    "storoffensiverna": "storoffensiv",
    "storoffensivernas": "storoffensiv",
    "storoffensivers": "storoffensiv",
    "storoffensivs": "storoffensiv",
    "storordiga": "storordig",
    "storordigare": "storordig",
    "storordigares": "storordig",
    "storordigas": "storordig",
    "storordigast": "storordig",
    "storordigaste": "storordig",
    "storordigastes": "storordig",
    "storordigasts": "storordig",
    "storordige": "storordig",
    "storordiges": "storordig",
    "storordigheten": "storordighet",
    "storordighetens": "storordighet",
    "storordighets": "storordighet",
    "storordigs": "storordig",
    "storordigt": "storordig",
    "storordigts": "storordig",
    "storpipiga": "storpipig",
    "storpipigare": "storpipig",
    "storpipigares": "storpipig",
    "storpipigas": "storpipig",
    "storpipigast": "storpipig",
    "storpipigaste": "storpipig",
    "storpipigastes": "storpipig",
    "storpipigasts": "storpipig",
    "storpipige": "storpipig",
    "storpipiges": "storpipig",
    "storpipigs": "storpipig",
    "storpipigt": "storpipig",
    "storpipigts": "storpipig",
    "storpolitiska": "storpolitisk",
    "storpolitiskare": "storpolitisk",
    "storpolitiskares": "storpolitisk",
    "storpolitiskas": "storpolitisk",
    "storpolitiskast": "storpolitisk",
    "storpolitiskaste": "storpolitisk",
    "storpolitiskastes": "storpolitisk",
    "storpolitiskasts": "storpolitisk",
    "storpolitiske": "storpolitisk",
    "storpolitiskes": "storpolitisk",
    "storpolitisks": "storpolitisk",
    "storpolitiskt": "storpolitisk",
    "storpolitiskts": "storpolitisk",
    "storryska": "storrysk",
    "storryskare": "storrysk",
    "storryskares": "storrysk",
    "storryskas": "storrysk",
    "storryskast": "storrysk",
    "storryskaste": "storrysk",
    "storryskastes": "storrysk",
    "storryskasts": "storrysk",
    "storryske": "storrysk",
    "storryskes": "storrysk",
    "storrysks": "storrysk",
    "storryskt": "storrysk",
    "storryskts": "storrysk",
    "stors": "stor",
    "storsatsade": "storsatsa",
    "storsatsades": "storsatsa",
    "storsatsande": "storsatsa",
    "storsatsanden": "storsatsande",
    "storsatsandena": "storsatsande",
    "storsatsandenas": "storsatsande",
    "storsatsandens": "storsatsande",
    "storsatsandes": "storsatsande",
    "storsatsandet": "storsatsande",
    "storsatsandets": "storsatsande",
    "storsatsar": "storsatsa",
    "storsatsas": "storsatsa",
    "storsatsat": "storsatsa",
    "storsatsats": "storsatsa",
    "storsatsningar": "storsatsning",
    "storsatsningarna": "storsatsning",
    "storsatsningarnas": "storsatsning",
    "storsatsningars": "storsatsning",
    "storsatsningen": "storsatsning",
    "storsatsningens": "storsatsning",
    "storsatsnings": "storsatsning",
    "storsegelbommar": "storsegelbom",
    "storsegelbommarna": "storsegelbom",
    "storsegelbommarnas": "storsegelbom",
    "storsegelbommars": "storsegelbom",
    "storsegelbommen": "storsegelbom",
    "storsegelbommens": "storsegelbom",
    "storsegelboms": "storsegelbom",
    "storsegels": "storsegel",
    "storseglen": "storsegel",
    "storseglens": "storsegel",
    "storseglet": "storsegel",
    "storseglets": "storsegel",
    "storsinta": "storsint",
    "storsintare": "storsint",
    "storsintares": "storsint",
    "storsintas": "storsint",
    "storsintast": "storsint",
    "storsintaste": "storsint",
    "storsintastes": "storsint",
    "storsintasts": "storsint",
    "storsinte": "storsint",
    "storsintes": "storsint",
    "storsintheten": "storsinthet",
    "storsinthetens": "storsinthet",
    "storsinthets": "storsinthet",
    "storsints": "storsint",
    "storsjöfiskes": "storsjöfiske",
    "storsjöfisket": "storsjöfiske",
    "storsjöfiskets": "storsjöfiske",
    "storsjöodjuren": "storsjöodjur",
    "storsjöodjurens": "storsjöodjur",
    "storsjöodjuret": "storsjöodjur",
    "storsjöodjurets": "storsjöodjur",
    "storsjöodjurs": "storsjöodjur",
    "storskaliga": "storskalig",
    "storskaligare": "storskalig",
    "storskaligares": "storskalig",
    "storskaligas": "storskalig",
    "storskaligast": "storskalig",
    "storskaligaste": "storskalig",
    "storskaligastes": "storskalig",
    "storskaligasts": "storskalig",
    "storskalige": "storskalig",
    "storskaliges": "storskalig",
    "storskaligheten": "storskalighet",
    "storskalighetens": "storskalighet",
    "storskalighets": "storskalighet",
    "storskaligs": "storskalig",
    "storskaligt": "storskalig",
    "storskaligts": "storskalig",
    "storskiftes": "storskifte",
    "storskiftet": "storskifte",
    "storskiftets": "storskifte",
    "storskogar": "storskog",
    "storskogarna": "storskog",
    "storskogarnas": "storskog",
    "storskogars": "storskog",
    "storskogen": "storskog",
    "storskogens": "storskog",
    "storskogs": "storskog",
    "storskoten": "storskot",
    "storskotens": "storskot",
    "storskotet": "storskot",
    "storskotets": "storskot",
    "storskots": "storskot",
    "storskotssken": "storskotsskena",
    "storskotsskenan": "storskotsskena",
    "storskotsskenans": "storskotsskena",
    "storskotsskenas": "storskotsskena",
    "storskotsskene": "storskotsskena",
    "storskotsskenor": "storskotsskena",
    "storskotsskenorna": "storskotsskena",
    "storskotsskenornas": "storskotsskena",
    "storskotsskenors": "storskotsskena",
    "storskotsskens": "storskotsskena",
    "storslagens": "storslagen",
    "storslaget": "storslagen",
    "storslagets": "storslagen",
    "storslagna": "storslagen",
    "storslagnare": "storslagen",
    "storslagnares": "storslagen",
    "storslagnas": "storslagen",
    "storslagnast": "storslagen",
    "storslagnaste": "storslagen",
    "storslagnastes": "storslagen",
    "storslagnasts": "storslagen",
    "storslagne": "storslagen",
    "storslagnes": "storslagen",
    "storslalomen": "storslalom",
    "storslalomens": "storslalom",
    "storslaloms": "storslalom",
    "storslammar": "storslam",
    "storslammarna": "storslam",
    "storslammarnas": "storslam",
    "storslammars": "storslam",
    "storslammen": "storslam",
    "storslammens": "storslam",
    "storslams": "storslam",
    "storspovar": "storspov",
    "storspovarna": "storspov",
    "storspovarnas": "storspov",
    "storspovars": "storspov",
    "storspoven": "storspov",
    "storspovens": "storspov",
    "storspovs": "storspov",
    "storstaden": "storstad",
    "storstadens": "storstad",
    "storstads": "storstad",
    "storstadsbon": "storstadsbo",
    "storstadsbons": "storstadsbo",
    "storstadsbor": "storstadsbo",
    "storstadsborna": "storstadsbo",
    "storstadsbornas": "storstadsbo",
    "storstadsbors": "storstadsbo",
    "storstadsbos": "storstadsbo",
    "storstadsmässiga": "storstadsmässig",
    "storstadsmässigare": "storstadsmässig",
    "storstadsmässigares": "storstadsmässig",
    "storstadsmässigas": "storstadsmässig",
    "storstadsmässigast": "storstadsmässig",
    "storstadsmässigaste": "storstadsmässig",
    "storstadsmässigastes": "storstadsmässig",
    "storstadsmässigasts": "storstadsmässig",
    "storstadsmässige": "storstadsmässig",
    "storstadsmässiges": "storstadsmässig",
    "storstadsmässigs": "storstadsmässig",
    "storstadsmässigt": "storstadsmässig",
    "storstadsmässigts": "storstadsmässig",
    "storstadsskymningen": "storstadsskymning",
    "storstadsskymningens": "storstadsskymning",
    "storstadsskymnings": "storstadsskymning",
    "storstan": "storstad",
    "storstans": "storstad",
    "storstilade": "storstilad",
    "storstilades": "storstilad",
    "storstilads": "storstilad",
    "storstilat": "storstilad",
    "storstilats": "storstilad",
    "storstilta": "storstilt",
    "storstiltare": "storstilt",
    "storstiltares": "storstilt",
    "storstiltas": "storstilt",
    "storstiltast": "storstilt",
    "storstiltaste": "storstilt",
    "storstiltastes": "storstilt",
    "storstiltasts": "storstilt",
    "storstilte": "storstilt",
    "storstiltes": "storstilt",
    "storstiltheten": "storstilthet",
    "storstilthetens": "storstilthet",
    "storstilthets": "storstilthet",
    "storstilts": "storstilt",
    "storstjärnan": "storstjärna",
    "storstjärnans": "storstjärna",
    "storstjärnas": "storstjärna",
    "storstjärne": "storstjärna",
    "storstjärnor": "storstjärna",
    "storstjärnorna": "storstjärna",
    "storstjärnornas": "storstjärna",
    "storstjärnors": "storstjärna",
    "storstrejken": "storstrejk",
    "storstrejkens": "storstrejk",
    "storstrejker": "storstrejk",
    "storstrejkerna": "storstrejk",
    "storstrejkernas": "storstrejk",
    "storstrejkers": "storstrejk",
    "storstrejks": "storstrejk",
    "storstugan": "storstuga",
    "storstugans": "storstuga",
    "storstugas": "storstuga",
    "storstuge": "storstuga",
    "storstugor": "storstuga",
    "storstugorna": "storstuga",
    "storstugornas": "storstuga",
    "storstugors": "storstuga",
    "storstugu": "storstuga",
    "storstäder": "storstad",
    "storstäderna": "storstad",
    "storstädernas": "storstad",
    "storstäders": "storstad",
    "storstädningar": "storstädning",
    "storstädningarna": "storstädning",
    "storstädningarnas": "storstädning",
    "storstädningars": "storstädning",
    "storstädningen": "storstädning",
    "storstädningens": "storstädning",
    "storstädnings": "storstädning",
    "storstövel": "storstövlar",
    "storstövels": "storstövlar",
    "storstövlarna": "storstövlar",
    "storstövlarnas": "storstövlar",
    "storstövlars": "storstövlar",
    "storsvenska": "storsvensk",
    "storsvenskar": "storsvensk",
    "storsvenskare": "storsvensk",
    "storsvenskares": "storsvensk",
    "storsvenskarna": "storsvensk",
    "storsvenskarnas": "storsvensk",
    "storsvenskars": "storsvensk",
    "storsvenskas": "storsvensk",
    "storsvenskast": "storsvensk",
    "storsvenskaste": "storsvensk",
    "storsvenskastes": "storsvensk",
    "storsvenskasts": "storsvensk",
    "storsvenske": "storsvensk",
    "storsvensken": "storsvensk",
    "storsvenskens": "storsvensk",
    "storsvenskes": "storsvensk",
    "storsvensks": "storsvensk",
    "storsvenskt": "storsvensk",
    "storsvenskts": "storsvensk",
    "storsyskonen": "storsyskon",
    "storsyskonens": "storsyskon",
    "storsyskonet": "storsyskon",
    "storsyskonets": "storsyskon",
    "storsyskons": "storsyskon",
    "storsäljar": "storsäljare",
    "storsäljaren": "storsäljare",
    "storsäljarens": "storsäljare",
    "storsäljares": "storsäljare",
    "storsäljarna": "storsäljare",
    "storsäljarnas": "storsäljare",
    "stort": "stor",
    "stortavel": "stortavla",
    "stortavlan": "stortavla",
    "stortavlans": "stortavla",
    "stortavlas": "stortavla",
    "stortavle": "stortavla",
    "stortavlor": "stortavla",
    "stortavlorna": "stortavla",
    "stortavlornas": "stortavla",
    "stortavlors": "stortavla",
    "stortinget": "storting",
    "stortingets": "storting",
    "stortings": "storting",
    "stortoppar": "stortopp",
    "stortopparna": "stortopp",
    "stortopparnas": "stortopp",
    "stortoppars": "stortopp",
    "stortoppen": "stortopp",
    "stortoppens": "stortopp",
    "stortopps": "stortopp",
    "stortröjan": "stortröja",
    "stortröjans": "stortröja",
    "stortröjas": "stortröja",
    "stortröje": "stortröja",
    "stortröjor": "stortröja",
    "stortröjorna": "stortröja",
    "stortröjornas": "stortröja",
    "stortröjors": "stortröja",
    "storts": "stor",
    "stortån": "stortå",
    "stortånageln": "stortånagel",
    "stortånagelns": "stortånagel",
    "stortånagels": "stortånagel",
    "stortånaglar": "stortånagel",
    "stortånaglarna": "stortånagel",
    "stortånaglarnas": "stortånagel",
    "stortånaglars": "stortånagel",
    "stortåns": "stortå",
    "stortår": "stortå",
    "stortårna": "stortå",
    "stortårnas": "stortå",
    "stortårs": "stortå",
    "stortås": "stortå",
    "storverken": "storverk",
    "storverkens": "storverk",
    "storverket": "storverk",
    "storverkets": "storverk",
    "storverks": "storverk",
    "storviltet": "storvilt",
    "storviltets": "storvilt",
    "storviltjägar": "storviltjägare",
    "storviltjägaren": "storviltjägare",
    "storviltjägarens": "storviltjägare",
    "storviltjägares": "storviltjägare",
    "storviltjägarna": "storviltjägare",
    "storviltjägarnas": "storviltjägare",
    "storvilts": "storvilt",
    "storvinsten": "storvinst",
    "storvinstens": "storvinst",
    "storvinster": "storvinst",
    "storvinsterna": "storvinst",
    "storvinsternas": "storvinst",
    "storvinsters": "storvinst",
    "storvinsts": "storvinst",
    "storvulens": "storvulen",
    "storvulet": "storvulen",
    "storvulets": "storvulen",
    "storvulna": "storvulen",
    "storvulnare": "storvulen",
    "storvulnares": "storvulen",
    "storvulnas": "storvulen",
    "storvulnast": "storvulen",
    "storvulnaste": "storvulen",
    "storvulnastes": "storvulen",
    "storvulnasts": "storvulen",
    "storvulne": "storvulen",
    "storvulnes": "storvulen",
    "storvuxens": "storvuxen",
    "storvuxet": "storvuxen",
    "storvuxets": "storvuxen",
    "storvuxna": "storvuxen",
    "storvuxnare": "storvuxen",
    "storvuxnares": "storvuxen",
    "storvuxnas": "storvuxen",
    "storvuxnast": "storvuxen",
    "storvuxnaste": "storvuxen",
    "storvuxnastes": "storvuxen",
    "storvuxnasts": "storvuxen",
    "storvuxne": "storvuxen",
    "storvuxnes": "storvuxen",
    "storvästar": "storväst",
    "storvästarna": "storväst",
    "storvästarnas": "storväst",
    "storvästars": "storväst",
    "storvästen": "storväst",
    "storvästens": "storväst",
    "storvästs": "storväst",
    "storväxta": "storväxt",
    "storväxtare": "storväxt",
    "storväxtares": "storväxt",
    "storväxtas": "storväxt",
    "storväxtast": "storväxt",
    "storväxtaste": "storväxt",
    "storväxtastes": "storväxt",
    "storväxtasts": "storväxt",
    "storväxte": "storväxt",
    "storväxtes": "storväxt",
    "storväxtheten": "storväxthet",
    "storväxthetens": "storväxthet",
    "storväxthets": "storväxthet",
    "storväxts": "storväxt",
    "storyer": "story",
    "storyerna": "story",
    "storyernas": "story",
    "storyers": "story",
    "storymässiga": "storymässig",
    "storymässigare": "storymässig",
    "storymässigares": "storymässig",
    "storymässigas": "storymässig",
    "storymässigast": "storymässig",
    "storymässigaste": "storymässig",
    "storymässigastes": "storymässig",
    "storymässigasts": "storymässig",
    "storymässige": "storymässig",
    "storymässiges": "storymässig",
    "storymässigs": "storymässig",
    "storymässigt": "storymässig",
    "storymässigts": "storymässig",
    "storyn": "story",
    "storyns": "story",
    "storys": "story",
    "storögda": "storögd",
    "storögdare": "storögd",
    "storögdares": "storögd",
    "storögdas": "storögd",
    "storögdast": "storögd",
    "storögdaste": "storögd",
    "storögdastes": "storögd",
    "storögdasts": "storögd",
    "storögde": "storögd",
    "storögdes": "storögd",
    "storögdheten": "storögdhet",
    "storögdhetens": "storögdhet",
    "storögdhets": "storögdhet",
    "storögds": "storögd",
    "storögt": "storögd",
    "storögts": "storögd",
    "stos": "stoa",
    "stot": "sto",
    "stots": "sto",
    "stoutar": "stout",
    "stoutarna": "stout",
    "stoutarnas": "stout",
    "stoutars": "stout",
    "stouten": "stout",
    "stoutens": "stout",
    "stouter": "stout",
    "stouterna": "stout",
    "stouternas": "stout",
    "stouters": "stout",
    "stouts": "stout",
    "strabismen": "strabism",
    "strabismens": "strabism",
    "strabismer": "strabism",
    "strabismerna": "strabism",
    "strabismernas": "strabism",
    "strabismers": "strabism",
    "strabisms": "strabism",
    "stradivarier": "stradivarius",
    "stradivarierna": "stradivarius",
    "stradivariernas": "stradivarius",
    "stradivariers": "stradivarius",
    "stradivariusar": "stradivarius",
    "stradivariusarna": "stradivarius",
    "stradivariusarnas": "stradivarius",
    "stradivariusars": "stradivarius",
    "stradivariusen": "stradivarius",
    "stradivariusens": "stradivarius",
    "straff": "straffa",
    "straffad": "straffa",
    "straffade": "straffa",
    "straffades": "straffa",
    "straffads": "straffa",
    "straffande": "straffa",
    "straffanden": "straffande",
    "straffandena": "straffande",
    "straffandenas": "straffande",
    "straffandens": "straffande",
    "straffandes": "straffande",
    "straffandet": "straffande",
    "straffandets": "straffande",
    "straffar": "straffa",
    "straffarbeten": "straffarbete",
    "straffarbetena": "straffarbete",
    "straffarbetenas": "straffarbete",
    "straffarbetens": "straffarbete",
    "straffarbetes": "straffarbete",
    "straffarbetet": "straffarbete",
    "straffarbetets": "straffarbete",
    "straffarbets": "straffarbete",
    "straffarna": "straff",
    "straffarnas": "straff",
    "straffars": "straff",
    "straffas": "straffa",
    "straffat": "straffa",
    "straffats": "straffa",
    "straffbara": "straffbar",
    "straffbarare": "straffbar",
    "straffbarares": "straffbar",
    "straffbaras": "straffbar",
    "straffbarast": "straffbar",
    "straffbaraste": "straffbar",
    "straffbarastes": "straffbar",
    "straffbarasts": "straffbar",
    "straffbare": "straffbar",
    "straffbares": "straffbar",
    "straffbarheten": "straffbarhet",
    "straffbarhetens": "straffbarhet",
    "straffbarhets": "straffbarhet",
    "straffbars": "straffbar",
    "straffbart": "straffbar",
    "straffbarts": "straffbar",
    "straffbeskatt": "straffbeskatta",
    "straffbeskattad": "straffbeskatta",
    "straffbeskattade": "straffbeskatta",
    "straffbeskattades": "straffbeskatta",
    "straffbeskattads": "straffbeskatta",
    "straffbeskattande": "straffbeskatta",
    "straffbeskattandes": "straffbeskatta",
    "straffbeskattar": "straffbeskatta",
    "straffbeskattas": "straffbeskatta",
    "straffbeskattat": "straffbeskatta",
    "straffbeskattats": "straffbeskatta",
    "straffdomar": "straffdom",
    "straffdomarna": "straffdom",
    "straffdomarnas": "straffdom",
    "straffdomars": "straffdom",
    "straffdomen": "straffdom",
    "straffdomens": "straffdom",
    "straffdoms": "straffdom",
    "straffen": "straff",
    "straffens": "straff",
    "straffet": "straff",
    "straffets": "straff",
    "straffexpeditionen": "straffexpedition",
    "straffexpeditionens": "straffexpedition",
    "straffexpeditioner": "straffexpedition",
    "straffexpeditionerna": "straffexpedition",
    "straffexpeditionernas": "straffexpedition",
    "straffexpeditioners": "straffexpedition",
    "straffexpeditions": "straffexpedition",
    "straffkasten": "straffkast",
    "straffkastens": "straffkast",
    "straffkastet": "straffkast",
    "straffkastets": "straffkast",
    "straffkasts": "straffkast",
    "strafflagar": "strafflag",
    "strafflagarna": "strafflag",
    "strafflagarnas": "strafflag",
    "strafflagars": "strafflag",
    "strafflagen": "strafflag",
    "strafflagens": "strafflag",
    "strafflags": "strafflag",
    "straffnivåer": "straffnivå",
    "straffnivåerna": "straffnivå",
    "straffnivåernas": "straffnivå",
    "straffnivåers": "straffnivå",
    "straffnivån": "straffnivå",
    "straffnivåns": "straffnivå",
    "straffnivås": "straffnivå",
    "straffområden": "straffområde",
    "straffområdena": "straffområde",
    "straffområdenas": "straffområde",
    "straffområdens": "straffområde",
    "straffområdes": "straffområde",
    "straffområdet": "straffområde",
    "straffområdets": "straffområde",
    "straffpåföljden": "straffpåföljd",
    "straffpåföljdens": "straffpåföljd",
    "straffpåföljder": "straffpåföljd",
    "straffpåföljderna": "straffpåföljd",
    "straffpåföljdernas": "straffpåföljd",
    "straffpåföljders": "straffpåföljd",
    "straffpåföljds": "straffpåföljd",
    "straffredskapen": "straffredskap",
    "straffredskapens": "straffredskap",
    "straffredskapet": "straffredskap",
    "straffredskapets": "straffredskap",
    "straffredskaps": "straffredskap",
    "straffregisterna": "straffregister",
    "straffregisternas": "straffregister",
    "straffregisters": "straffregister",
    "straffregistren": "straffregister",
    "straffregistrens": "straffregister",
    "straffregistret": "straffregister",
    "straffregistrets": "straffregister",
    "straffria": "straffri",
    "straffriare": "straffri",
    "straffriares": "straffri",
    "straffrias": "straffri",
    "straffriast": "straffri",
    "straffriaste": "straffri",
    "straffriastes": "straffri",
    "straffriasts": "straffri",
    "straffrie": "straffri",
    "straffries": "straffri",
    "straffris": "straffri",
    "straffritt": "straffri",
    "straffritts": "straffri",
    "straffrätten": "straffrätt",
    "straffrättens": "straffrätt",
    "straffrätts": "straffrätt",
    "straffrättsliga": "straffrättslig",
    "straffrättsligas": "straffrättslig",
    "straffrättslige": "straffrättslig",
    "straffrättsliges": "straffrättslig",
    "straffrättsligs": "straffrättslig",
    "straffrättsligt": "straffrättslig",
    "straffrättsligts": "straffrättslig",
    "straffs": "straff",
    "straffskalan": "straffskala",
    "straffskalans": "straffskala",
    "straffskalas": "straffskala",
    "straffskale": "straffskala",
    "straffskalor": "straffskala",
    "straffskalorna": "straffskala",
    "straffskalornas": "straffskala",
    "straffskalors": "straffskala",
    "straffångar": "straffånge",
    "straffångarna": "straffånge",
    "straffångarnas": "straffånge",
    "straffångars": "straffånge",
    "straffången": "straffånge",
    "straffångens": "straffånge",
    "straffånges": "straffånge",
    "strafförelägganden": "strafföreläggande",
    "strafföreläggandena": "strafföreläggande",
    "strafföreläggandenas": "strafföreläggande",
    "strafföreläggandens": "strafföreläggande",
    "strafföreläggandes": "strafföreläggande",
    "strafföreläggandet": "strafföreläggande",
    "strafföreläggandets": "strafföreläggande",
    "straka": "strak",
    "strakare": "strak",
    "strakares": "strak",
    "strakas": "strak",
    "strakast": "strak",
    "strakaste": "strak",
    "strakastes": "strak",
    "strakasts": "strak",
    "strakbenta": "strakbent",
    "strakbentare": "strakbent",
    "strakbentares": "strakbent",
    "strakbentas": "strakbent",
    "strakbentast": "strakbent",
    "strakbentaste": "strakbent",
    "strakbentastes": "strakbent",
    "strakbentasts": "strakbent",
    "strakbente": "strakbent",
    "strakbentes": "strakbent",
    "strakbentheten": "strakbenthet",
    "strakbenthetens": "strakbenthet",
    "strakbenthets": "strakbenthet",
    "strakbents": "strakbent",
    "strake": "strak",
    "strakes": "strak",
    "strakheten": "strakhet",
    "strakhetens": "strakhet",
    "strakhets": "strakhet",
    "straks": "strak",
    "strakt": "strak",
    "strakts": "strak",
    "stram": "strama",
    "strama": "stram",
    "stramad": "strama",
    "stramade": "strama",
    "stramades": "strama",
    "stramads": "strama",
    "stramaljen": "stramalj",
    "stramaljens": "stramalj",
    "stramaljer": "stramalj",
    "stramaljerna": "stramalj",
    "stramaljernas": "stramalj",
    "stramaljers": "stramalj",
    "stramaljs": "stramalj",
    "stramande": "strama",
    "stramanden": "stramande",
    "stramandena": "stramande",
    "stramandenas": "stramande",
    "stramandens": "stramande",
    "stramandes": "stramande",
    "stramandet": "stramande",
    "stramandets": "stramande",
    "stramar": "strama",
    "stramare": "stram",
    "stramares": "stram",
    "stramas": "strama",
    "stramast": "stram",
    "stramaste": "stram",
    "stramastes": "stram",
    "stramasts": "stram",
    "stramat": "strama",
    "stramats": "strama",
    "strame": "stram",
    "strames": "stram",
    "stramheten": "stramhet",
    "stramhetens": "stramhet",
    "stramhets": "stramhet",
    "strams": "stram",
    "stramt": "stram",
    "stramts": "stram",
    "strand": "stranda",
    "strandad": "stranda",
    "strandade": "stranda",
    "strandades": "stranda",
    "strandads": "stranda",
    "strandande": "stranda",
    "strandanden": "strandande",
    "strandandena": "strandande",
    "strandandenas": "strandande",
    "strandandens": "strandande",
    "strandandes": "strandande",
    "strandandet": "strandande",
    "strandandets": "strandande",
    "strandar": "stranda",
    "strandartikeln": "strandartikel",
    "strandartikelns": "strandartikel",
    "strandartikels": "strandartikel",
    "strandartiklar": "strandartikel",
    "strandartiklarna": "strandartikel",
    "strandartiklarnas": "strandartikel",
    "strandartiklars": "strandartikel",
    "strandas": "stranda",
    "strandat": "stranda",
    "strandats": "stranda",
    "stranden": "strand",
    "strandens": "strand",
    "strandfavoriten": "strandfavorit",
    "strandfavoritens": "strandfavorit",
    "strandfavoriter": "strandfavorit",
    "strandfavoriterna": "strandfavorit",
    "strandfavoriternas": "strandfavorit",
    "strandfavoriters": "strandfavorit",
    "strandfavorits": "strandfavorit",
    "strandflat": "strandflate",
    "strandflatar": "strandflate",
    "strandflatarna": "strandflate",
    "strandflatarnas": "strandflate",
    "strandflatars": "strandflate",
    "strandflaten": "strandflate",
    "strandflatens": "strandflate",
    "strandflates": "strandflate",
    "strandflats": "strandflate",
    "strandfynden": "strandfynd",
    "strandfyndens": "strandfynd",
    "strandfyndet": "strandfynd",
    "strandfyndets": "strandfynd",
    "strandfynds": "strandfynd",
    "strandhuggen": "strandhugg",
    "strandhuggens": "strandhugg",
    "strandhugget": "strandhugg",
    "strandhuggets": "strandhugg",
    "strandhuggs": "strandhugg",
    "strandkanten": "strandkant",
    "strandkantens": "strandkant",
    "strandkanter": "strandkant",
    "strandkanterna": "strandkant",
    "strandkanternas": "strandkant",
    "strandkanters": "strandkant",
    "strandkants": "strandkant",
    "strandlinjen": "strandlinje",
    "strandlinjens": "strandlinje",
    "strandlinjer": "strandlinje",
    "strandlinjerna": "strandlinje",
    "strandlinjernas": "strandlinje",
    "strandlinjers": "strandlinje",
    "strandlinjes": "strandlinje",
    "strandmiljöer": "strandmiljö",
    "strandmiljöerna": "strandmiljö",
    "strandmiljöernas": "strandmiljö",
    "strandmiljöers": "strandmiljö",
    "strandmiljön": "strandmiljö",
    "strandmiljöns": "strandmiljö",
    "strandmiljös": "strandmiljö",
    "strandpipar": "strandpipare",
    "strandpiparen": "strandpipare",
    "strandpiparens": "strandpipare",
    "strandpipares": "strandpipare",
    "strandpiparna": "strandpipare",
    "strandpiparnas": "strandpipare",
    "strandpromenaden": "strandpromenad",
    "strandpromenadens": "strandpromenad",
    "strandpromenader": "strandpromenad",
    "strandpromenaderna": "strandpromenad",
    "strandpromenadernas": "strandpromenad",
    "strandpromenaders": "strandpromenad",
    "strandpromenads": "strandpromenad",
    "strandrestaurangen": "strandrestaurang",
    "strandrestaurangens": "strandrestaurang",
    "strandrestauranger": "strandrestaurang",
    "strandrestaurangerna": "strandrestaurang",
    "strandrestaurangernas": "strandrestaurang",
    "strandrestaurangers": "strandrestaurang",
    "strandrestaurangs": "strandrestaurang",
    "strandrågen": "strandråg",
    "strandrågens": "strandråg",
    "strandrågs": "strandråg",
    "strands": "strand",
    "strandsatt": "strandsätta",
    "strandsatta": "strandsätta",
    "strandsattas": "strandsätta",
    "strandsatte": "strandsätta",
    "strandsattes": "strandsätta",
    "strandsatts": "strandsätta",
    "strandskat": "strandskata",
    "strandskatan": "strandskata",
    "strandskatans": "strandskata",
    "strandskatas": "strandskata",
    "strandskate": "strandskata",
    "strandskator": "strandskata",
    "strandskatorna": "strandskata",
    "strandskatornas": "strandskata",
    "strandskators": "strandskata",
    "strandskats": "strandskata",
    "strandsluttningar": "strandsluttning",
    "strandsluttningarna": "strandsluttning",
    "strandsluttningarnas": "strandsluttning",
    "strandsluttningars": "strandsluttning",
    "strandsluttningen": "strandsluttning",
    "strandsluttningens": "strandsluttning",
    "strandsluttnings": "strandsluttning",
    "strandsnäck": "strandsnäcka",
    "strandsnäckan": "strandsnäcka",
    "strandsnäckans": "strandsnäcka",
    "strandsnäckas": "strandsnäcka",
    "strandsnäcke": "strandsnäcka",
    "strandsnäckor": "strandsnäcka",
    "strandsnäckorna": "strandsnäcka",
    "strandsnäckornas": "strandsnäcka",
    "strandsnäckors": "strandsnäcka",
    "strandsnäcks": "strandsnäcka",
    "strandstaten": "strandstat",
    "strandstatens": "strandstat",
    "strandstater": "strandstat",
    "strandstaterna": "strandstat",
    "strandstaternas": "strandstat",
    "strandstaters": "strandstat",
    "strandstats": "strandstat",
    "strandsätt": "strandsätta",
    "strandsättande": "strandsätta",
    "strandsättanden": "strandsättande",
    "strandsättandena": "strandsättande",
    "strandsättandenas": "strandsättande",
    "strandsättandens": "strandsättande",
    "strandsättandes": "strandsättande",
    "strandsättandet": "strandsättande",
    "strandsättandets": "strandsättande",
    "strandsättas": "strandsätta",
    "strandsätter": "strandsätta",
    "strandsättes": "strandsätta",
    "strandsätts": "strandsätta",
    "strandtomten": "strandtomt",
    "strandtomtens": "strandtomt",
    "strandtomter": "strandtomt",
    "strandtomterna": "strandtomt",
    "strandtomternas": "strandtomt",
    "strandtomters": "strandtomt",
    "strandtomts": "strandtomt",
    "strandtypen": "strandtyp",
    "strandtypens": "strandtyp",
    "strandtyper": "strandtyp",
    "strandtyperna": "strandtyp",
    "strandtypernas": "strandtyp",
    "strandtypers": "strandtyp",
    "strandtyps": "strandtyp",
    "strandvallar": "strandvall",
    "strandvallarna": "strandvall",
    "strandvallarnas": "strandvall",
    "strandvallars": "strandvall",
    "strandvallen": "strandvall",
    "strandvallens": "strandvall",
    "strandvalls": "strandvall",
    "strandväxten": "strandväxt",
    "strandväxtens": "strandväxt",
    "strandväxter": "strandväxt",
    "strandväxterna": "strandväxt",
    "strandväxternas": "strandväxt",
    "strandväxters": "strandväxt",
    "strandväxts": "strandväxt",
    "strandängar": "strandäng",
    "strandängarna": "strandäng",
    "strandängarnas": "strandäng",
    "strandängars": "strandäng",
    "strandängen": "strandäng",
    "strandängens": "strandäng",
    "strandängs": "strandäng",
    "strandörten": "strandört",
    "strandörtens": "strandört",
    "strandörter": "strandört",
    "strandörterna": "strandört",
    "strandörternas": "strandört",
    "strandörters": "strandört",
    "strandörts": "strandört",
    "strangulationen": "strangulation",
    "strangulationens": "strangulation",
    "strangulationer": "strangulation",
    "strangulationerna": "strangulation",
    "strangulationernas": "strangulation",
    "strangulationers": "strangulation",
    "strangulations": "strangulation",
    "strangulerad": "strangulera",
    "strangulerade": "strangulera",
    "strangulerades": "strangulera",
    "strangulerads": "strangulera",
    "strangulerande": "strangulera",
    "stranguleranden": "strangulerande",
    "strangulerandena": "strangulerande",
    "strangulerandenas": "strangulerande",
    "strangulerandens": "strangulerande",
    "strangulerandes": "strangulerande",
    "strangulerandet": "strangulerande",
    "strangulerandets": "strangulerande",
    "strangulerar": "strangulera",
    "stranguleras": "strangulera",
    "strangulerat": "strangulera",
    "strangulerats": "strangulera",
    "strangulerbara": "strangulerbar",
    "strangulerbarare": "strangulerbar",
    "strangulerbarares": "strangulerbar",
    "strangulerbaras": "strangulerbar",
    "strangulerbarast": "strangulerbar",
    "strangulerbaraste": "strangulerbar",
    "strangulerbarastes": "strangulerbar",
    "strangulerbarasts": "strangulerbar",
    "strangulerbare": "strangulerbar",
    "strangulerbares": "strangulerbar",
    "strangulerbarheten": "strangulerbarhet",
    "strangulerbarhetens": "strangulerbarhet",
    "strangulerbarhets": "strangulerbarhet",
    "strangulerbars": "strangulerbar",
    "strangulerbart": "strangulerbar",
    "strangulerbarts": "strangulerbar",
    "stranguleringar": "strangulering",
    "stranguleringarna": "strangulering",
    "stranguleringarnas": "strangulering",
    "stranguleringars": "strangulering",
    "stranguleringen": "strangulering",
    "stranguleringens": "strangulering",
    "strangulerings": "strangulering",
    "strapatsen": "strapats",
    "strapatsens": "strapats",
    "strapatser": "strapats",
    "strapatserna": "strapats",
    "strapatsernas": "strapats",
    "strapatsers": "strapats",
    "strassen": "strass",
    "strassens": "strass",
    "strata": "stratum",
    "stratana": "stratum",
    "stratanas": "stratum",
    "stratas": "stratum",
    "strategen": "strateg",
    "strategens": "strateg",
    "strateger": "strateg",
    "strategerna": "strateg",
    "strategernas": "strateg",
    "strategers": "strateg",
    "strategidokumenten": "strategidokument",
    "strategidokumentens": "strategidokument",
    "strategidokumentet": "strategidokument",
    "strategidokumentets": "strategidokument",
    "strategidokuments": "strategidokument",
    "strategien": "strategi",
    "strategiens": "strategi",
    "strategier": "strategi",
    "strategierna": "strategi",
    "strategiernas": "strategi",
    "strategiers": "strategi",
    "strategin": "strategi",
    "strategins": "strategi",
    "strategis": "strategi",
    "strategiska": "strategisk",
    "strategiskare": "strategisk",
    "strategiskares": "strategisk",
    "strategiskas": "strategisk",
    "strategiskast": "strategisk",
    "strategiskaste": "strategisk",
    "strategiskastes": "strategisk",
    "strategiskasts": "strategisk",
    "strategiske": "strategisk",
    "strategiskes": "strategisk",
    "strategisks": "strategisk",
    "strategiskt": "strategisk",
    "strategiskts": "strategisk",
    "strategs": "strateg",
    "stratifierad": "stratifiera",
    "stratifierade": "stratifiera",
    "stratifierades": "stratifiera",
    "stratifierads": "stratifiera",
    "stratifierande": "stratifiera",
    "stratifieranden": "stratifierande",
    "stratifierandena": "stratifierande",
    "stratifierandenas": "stratifierande",
    "stratifierandens": "stratifierande",
    "stratifierandes": "stratifierande",
    "stratifierandet": "stratifierande",
    "stratifierandets": "stratifierande",
    "stratifierar": "stratifiera",
    "stratifieras": "stratifiera",
    "stratifierat": "stratifiera",
    "stratifierats": "stratifiera",
    "stratifierbara": "stratifierbar",
    "stratifierbarare": "stratifierbar",
    "stratifierbarares": "stratifierbar",
    "stratifierbaras": "stratifierbar",
    "stratifierbarast": "stratifierbar",
    "stratifierbaraste": "stratifierbar",
    "stratifierbarastes": "stratifierbar",
    "stratifierbarasts": "stratifierbar",
    "stratifierbare": "stratifierbar",
    "stratifierbares": "stratifierbar",
    "stratifierbarheten": "stratifierbarhet",
    "stratifierbarhetens": "stratifierbarhet",
    "stratifierbarhets": "stratifierbarhet",
    "stratifierbars": "stratifierbar",
    "stratifierbart": "stratifierbar",
    "stratifierbarts": "stratifierbar",
    "stratifieringar": "stratifiering",
    "stratifieringarna": "stratifiering",
    "stratifieringarnas": "stratifiering",
    "stratifieringars": "stratifiering",
    "stratifieringen": "stratifiering",
    "stratifieringens": "stratifiering",
    "stratifierings": "stratifiering",
    "stratigrafien": "stratigrafi",
    "stratigrafiens": "stratigrafi",
    "stratigrafin": "stratigrafi",
    "stratigrafins": "stratigrafi",
    "stratigrafis": "stratigrafi",
    "stratosfären": "stratosfär",
    "stratosfärens": "stratosfär",
    "stratosfärs": "stratosfär",
    "stratumet": "stratum",
    "stratumets": "stratum",
    "stratums": "stratum",
    "stratusen": "stratus",
    "stratusens": "stratus",
    "streak": "streaka",
    "streakad": "streaka",
    "streakade": "streaka",
    "streakades": "streaka",
    "streakads": "streaka",
    "streakande": "streaka",
    "streakanden": "streakande",
    "streakandena": "streakande",
    "streakandenas": "streakande",
    "streakandens": "streakande",
    "streakandes": "streakande",
    "streakandet": "streakande",
    "streakandets": "streakande",
    "streakar": "streaka",
    "streakas": "streaka",
    "streakat": "streaka",
    "streakats": "streaka",
    "streamern": "streamer",
    "streamerns": "streamer",
    "streamers": "streamer",
    "streamersarna": "streamer",
    "streamersarnas": "streamer",
    "streamersen": "streamer",
    "streamersens": "streamer",
    "strebern": "streber",
    "streberns": "streber",
    "strebers": "streber",
    "strebrar": "streber",
    "strebrarna": "streber",
    "strebrarnas": "streber",
    "strebrars": "streber",
    "streck": "strecka",
    "streckad": "strecka",
    "streckade": "strecka",
    "streckades": "strecka",
    "streckads": "strecka",
    "streckande": "strecka",
    "streckanden": "streckande",
    "streckandena": "streckande",
    "streckandenas": "streckande",
    "streckandens": "streckande",
    "streckandes": "streckande",
    "streckandet": "streckande",
    "streckandets": "streckande",
    "streckar": "strecka",
    "streckas": "strecka",
    "streckat": "strecka",
    "streckats": "strecka",
    "strecken": "streck",
    "streckens": "streck",
    "strecket": "streck",
    "streckets": "streck",
    "streckgubb": "streckgubbe",
    "streckgubbar": "streckgubbe",
    "streckgubbarna": "streckgubbe",
    "streckgubbarnas": "streckgubbe",
    "streckgubbars": "streckgubbe",
    "streckgubben": "streckgubbe",
    "streckgubbens": "streckgubbe",
    "streckgubbes": "streckgubbe",
    "streckgubbs": "streckgubbe",
    "streckkoden": "streckkod",
    "streckkodens": "streckkod",
    "streckkoder": "streckkod",
    "streckkoderna": "streckkod",
    "streckkodernas": "streckkod",
    "streckkoders": "streckkod",
    "streckkodläsar": "streckkodläsare",
    "streckkodläsaren": "streckkodläsare",
    "streckkodläsarens": "streckkodläsare",
    "streckkodläsares": "streckkodläsare",
    "streckkodläsarna": "streckkodläsare",
    "streckkodläsarnas": "streckkodläsare",
    "streckkods": "streckkod",
    "streckkodsläsar": "streckkodsläsare",
    "streckkodsläsaren": "streckkodsläsare",
    "streckkodsläsarens": "streckkodsläsare",
    "streckkodsläsares": "streckkodsläsare",
    "streckkodsläsarna": "streckkodsläsare",
    "streckkodsläsarnas": "streckkodsläsare",
    "streckprickade": "streckprickad",
    "streckprickades": "streckprickad",
    "streckprickads": "streckprickad",
    "streckprickat": "streckprickad",
    "streckprickats": "streckprickad",
    "strecks": "streck",
    "stred": "strida",
    "strede": "strida",
    "stredes": "strida",
    "streds": "strida",
    "stregan": "strega",
    "stregans": "strega",
    "stregas": "strega",
    "strejk": "strejka",
    "strejkad": "strejka",
    "strejkade": "strejka",
    "strejkades": "strejka",
    "strejkads": "strejka",
    "strejkande": "strejka",
    "strejkanden": "strejkande",
    "strejkandena": "strejkande",
    "strejkandenas": "strejkande",
    "strejkandens": "strejkande",
    "strejkandes": "strejkande",
    "strejkandet": "strejkande",
    "strejkandets": "strejkande",
    "strejkar": "strejka",
    "strejkas": "strejka",
    "strejkat": "strejka",
    "strejkats": "strejka",
    "strejkbrytar": "strejkbrytare",
    "strejkbrytaren": "strejkbrytare",
    "strejkbrytarens": "strejkbrytare",
    "strejkbrytares": "strejkbrytare",
    "strejkbrytarna": "strejkbrytare",
    "strejkbrytarnas": "strejkbrytare",
    "strejken": "strejk",
    "strejkens": "strejk",
    "strejker": "strejk",
    "strejkerna": "strejk",
    "strejkernas": "strejk",
    "strejkers": "strejk",
    "strejks": "strejk",
    "strejkvakten": "strejkvakt",
    "strejkvaktens": "strejkvakt",
    "strejkvakter": "strejkvakt",
    "strejkvakterna": "strejkvakt",
    "strejkvakternas": "strejkvakt",
    "strejkvakters": "strejkvakt",
    "strejkvakts": "strejkvakt",
    "strejkvarsels": "strejkvarsel",
    "strejkvarslen": "strejkvarsel",
    "strejkvarslens": "strejkvarsel",
    "strejkvarslet": "strejkvarsel",
    "strejkvarslets": "strejkvarsel",
    "streptokocken": "streptokock",
    "streptokockens": "streptokock",
    "streptokocker": "streptokock",
    "streptokockerna": "streptokock",
    "streptokockernas": "streptokock",
    "streptokockers": "streptokock",
    "streptokocks": "streptokock",
    "streptomycinen": "streptomycin",
    "streptomycinens": "streptomycin",
    "streptomyciner": "streptomycin",
    "streptomycinerna": "streptomycin",
    "streptomycinernas": "streptomycin",
    "streptomyciners": "streptomycin",
    "streptomycinet": "streptomycin",
    "streptomycinets": "streptomycin",
    "streptomycins": "streptomycin",
    "stress": "stressa",
    "stressad": "stressa",
    "stressade": "stressa",
    "stressades": "stressa",
    "stressads": "stressa",
    "stressande": "stressa",
    "stressanden": "stressande",
    "stressandena": "stressande",
    "stressandenas": "stressande",
    "stressandens": "stressande",
    "stressandes": "stressande",
    "stressandet": "stressande",
    "stressandets": "stressande",
    "stressar": "stressa",
    "stressas": "stressa",
    "stressat": "stressa",
    "stressats": "stressa",
    "stressen": "stress",
    "stressens": "stress",
    "stresshormonen": "stresshormon",
    "stresshormonens": "stresshormon",
    "stresshormoner": "stresshormon",
    "stresshormonerna": "stresshormon",
    "stresshormonernas": "stresshormon",
    "stresshormoners": "stresshormon",
    "stresshormonet": "stresshormon",
    "stresshormonets": "stresshormon",
    "stresshormons": "stresshormon",
    "stressiga": "stressig",
    "stressigare": "stressig",
    "stressigares": "stressig",
    "stressigas": "stressig",
    "stressigast": "stressig",
    "stressigaste": "stressig",
    "stressigastes": "stressig",
    "stressigasts": "stressig",
    "stressige": "stressig",
    "stressiges": "stressig",
    "stressigheten": "stressighet",
    "stressighetens": "stressighet",
    "stressighets": "stressighet",
    "stressigs": "stressig",
    "stressigt": "stressig",
    "stressigts": "stressig",
    "stresståliga": "stresstålig",
    "stresståligare": "stresstålig",
    "stresståligares": "stresstålig",
    "stresståligas": "stresstålig",
    "stresståligast": "stresstålig",
    "stresståligaste": "stresstålig",
    "stresståligastes": "stresstålig",
    "stresståligasts": "stresstålig",
    "stresstålige": "stresstålig",
    "stresståliges": "stresstålig",
    "stresståligheten": "stresstålighet",
    "stresstålighetens": "stresstålighet",
    "stresstålighets": "stresstålighet",
    "stresståligs": "stresstålig",
    "stresståligt": "stresstålig",
    "stresståligts": "stresstålig",
    "stret": "streta",
    "stretad": "streta",
    "stretade": "streta",
    "stretades": "streta",
    "stretads": "streta",
    "stretande": "streta",
    "stretanden": "stretande",
    "stretandena": "stretande",
    "stretandenas": "stretande",
    "stretandens": "stretande",
    "stretandes": "stretande",
    "stretandet": "stretande",
    "stretandets": "stretande",
    "stretar": "streta",
    "stretas": "streta",
    "stretat": "streta",
    "stretats": "streta",
    "stretch": "stretcha",
    "stretchad": "stretcha",
    "stretchade": "stretcha",
    "stretchades": "stretcha",
    "stretchads": "stretcha",
    "stretchande": "stretcha",
    "stretchanden": "stretchande",
    "stretchandena": "stretchande",
    "stretchandenas": "stretchande",
    "stretchandens": "stretchande",
    "stretchandes": "stretchande",
    "stretchandet": "stretchande",
    "stretchandets": "stretchande",
    "stretchar": "stretcha",
    "stretchas": "stretcha",
    "stretchat": "stretcha",
    "stretchats": "stretcha",
    "stretchnylonen": "stretchnylon",
    "stretchnylonens": "stretchnylon",
    "stretchnyloner": "stretchnylon",
    "stretchnylonerna": "stretchnylon",
    "stretchnylonernas": "stretchnylon",
    "stretchnyloners": "stretchnylon",
    "stretchnylonet": "stretchnylon",
    "stretchnylonets": "stretchnylon",
    "stretchnylons": "stretchnylon",
    "stretiga": "stretig",
    "stretigare": "stretig",
    "stretigares": "stretig",
    "stretigas": "stretig",
    "stretigast": "stretig",
    "stretigaste": "stretig",
    "stretigastes": "stretig",
    "stretigasts": "stretig",
    "stretige": "stretig",
    "stretiges": "stretig",
    "stretigs": "stretig",
    "stretigt": "stretig",
    "stretigts": "stretig",
    "strid": "strida",
    "strida": "strid",
    "stridande": "strida",
    "stridanden": "stridande",
    "stridandena": "stridande",
    "stridandenas": "stridande",
    "stridandens": "stridande",
    "stridandes": "stridande",
    "stridandet": "stridande",
    "stridandets": "stridande",
    "stridare": "strid",
    "stridares": "strid",
    "stridas": "strida",
    "stridast": "strid",
    "stridaste": "strid",
    "stridastes": "strid",
    "stridasts": "strid",
    "stridbara": "stridbar",
    "stridbarare": "stridbar",
    "stridbarares": "stridbar",
    "stridbaras": "stridbar",
    "stridbarast": "stridbar",
    "stridbaraste": "stridbar",
    "stridbarastes": "stridbar",
    "stridbarasts": "stridbar",
    "stridbare": "stridbar",
    "stridbares": "stridbar",
    "stridbarheten": "stridbarhet",
    "stridbarhetens": "stridbarhet",
    "stridbarhets": "stridbarhet",
    "stridbars": "stridbar",
    "stridbart": "stridbar",
    "stridbarts": "stridbar",
    "stridde": "strida",
    "striddes": "strida",
    "stride": "strida",
    "striden": "strid",
    "stridens": "strid",
    "strider": "strida",
    "striderna": "strid",
    "stridernas": "strid",
    "striders": "strid",
    "strides": "strida",
    "stridheten": "stridhet",
    "stridhetens": "stridhet",
    "stridhets": "stridhet",
    "stridiga": "stridig",
    "stridigare": "stridig",
    "stridigares": "stridig",
    "stridigas": "stridig",
    "stridigast": "stridig",
    "stridigaste": "stridig",
    "stridigastes": "stridig",
    "stridigasts": "stridig",
    "stridige": "stridig",
    "stridiges": "stridig",
    "stridigheten": "stridighet",
    "stridighetens": "stridighet",
    "stridigheter": "stridighet",
    "stridigheterna": "stridighet",
    "stridigheternas": "stridighet",
    "stridigheters": "stridighet",
    "stridighets": "stridighet",
    "stridigs": "stridig",
    "stridigt": "stridig",
    "stridigts": "stridig",
    "stridit": "strida",
    "stridits": "strida",
    "strids": "strida",
    "stridsberedskapen": "stridsberedskap",
    "stridsberedskapens": "stridsberedskap",
    "stridsberedskaps": "stridsberedskap",
    "stridsdomar": "stridsdomare",
    "stridsdomaren": "stridsdomare",
    "stridsdomarens": "stridsdomare",
    "stridsdomares": "stridsdomare",
    "stridsdomarna": "stridsdomare",
    "stridsdomarnas": "stridsdomare",
    "stridsdugliga": "stridsduglig",
    "stridsdugligare": "stridsduglig",
    "stridsdugligares": "stridsduglig",
    "stridsdugligas": "stridsduglig",
    "stridsdugligast": "stridsduglig",
    "stridsdugligaste": "stridsduglig",
    "stridsdugligastes": "stridsduglig",
    "stridsdugligasts": "stridsduglig",
    "stridsduglige": "stridsduglig",
    "stridsdugliges": "stridsduglig",
    "stridsdugligheten": "stridsduglighet",
    "stridsduglighetens": "stridsduglighet",
    "stridsduglighets": "stridsduglighet",
    "stridsdugligs": "stridsduglig",
    "stridsdugligt": "stridsduglig",
    "stridsdugligts": "stridsduglig",
    "stridsflygen": "stridsflyg",
    "stridsflygens": "stridsflyg",
    "stridsflyget": "stridsflyg",
    "stridsflygets": "stridsflyg",
    "stridsflygplanen": "stridsflygplan",
    "stridsflygplanens": "stridsflygplan",
    "stridsflygplanet": "stridsflygplan",
    "stridsflygplanets": "stridsflygplan",
    "stridsflygplans": "stridsflygplan",
    "stridsflygs": "stridsflyg",
    "stridsformerad": "stridsformera",
    "stridsformerade": "stridsformera",
    "stridsformerades": "stridsformera",
    "stridsformerads": "stridsformera",
    "stridsformerande": "stridsformera",
    "stridsformeranden": "stridsformerande",
    "stridsformerandena": "stridsformerande",
    "stridsformerandenas": "stridsformerande",
    "stridsformerandens": "stridsformerande",
    "stridsformerandes": "stridsformerande",
    "stridsformerandet": "stridsformerande",
    "stridsformerandets": "stridsformerande",
    "stridsformerar": "stridsformera",
    "stridsformeras": "stridsformera",
    "stridsformerat": "stridsformera",
    "stridsformerats": "stridsformera",
    "stridsformerbara": "stridsformerbar",
    "stridsformerbarare": "stridsformerbar",
    "stridsformerbarares": "stridsformerbar",
    "stridsformerbaras": "stridsformerbar",
    "stridsformerbarast": "stridsformerbar",
    "stridsformerbaraste": "stridsformerbar",
    "stridsformerbarastes": "stridsformerbar",
    "stridsformerbarasts": "stridsformerbar",
    "stridsformerbare": "stridsformerbar",
    "stridsformerbares": "stridsformerbar",
    "stridsformerbarheten": "stridsformerbarhet",
    "stridsformerbarhetens": "stridsformerbarhet",
    "stridsformerbarhets": "stridsformerbarhet",
    "stridsformerbars": "stridsformerbar",
    "stridsformerbart": "stridsformerbar",
    "stridsformerbarts": "stridsformerbar",
    "stridsformeringar": "stridsformering",
    "stridsformeringarna": "stridsformering",
    "stridsformeringarnas": "stridsformering",
    "stridsformeringars": "stridsformering",
    "stridsformeringen": "stridsformering",
    "stridsformeringens": "stridsformering",
    "stridsformerings": "stridsformering",
    "stridsfrågan": "stridsfråga",
    "stridsfrågans": "stridsfråga",
    "stridsfrågas": "stridsfråga",
    "stridsfråge": "stridsfråga",
    "stridsfrågor": "stridsfråga",
    "stridsfrågorna": "stridsfråga",
    "stridsfrågornas": "stridsfråga",
    "stridsfrågors": "stridsfråga",
    "stridsgasen": "stridsgas",
    "stridsgasens": "stridsgas",
    "stridsgaser": "stridsgas",
    "stridsgaserna": "stridsgas",
    "stridsgasernas": "stridsgas",
    "stridsgasers": "stridsgas",
    "stridsgrupperad": "stridsgruppera",
    "stridsgrupperade": "stridsgruppera",
    "stridsgrupperades": "stridsgruppera",
    "stridsgrupperads": "stridsgruppera",
    "stridsgrupperande": "stridsgruppera",
    "stridsgrupperanden": "stridsgrupperande",
    "stridsgrupperandena": "stridsgrupperande",
    "stridsgrupperandenas": "stridsgrupperande",
    "stridsgrupperandens": "stridsgrupperande",
    "stridsgrupperandes": "stridsgrupperande",
    "stridsgrupperandet": "stridsgrupperande",
    "stridsgrupperandets": "stridsgrupperande",
    "stridsgrupperar": "stridsgruppera",
    "stridsgrupperas": "stridsgruppera",
    "stridsgrupperat": "stridsgruppera",
    "stridsgrupperats": "stridsgruppera",
    "stridsgrupperbara": "stridsgrupperbar",
    "stridsgrupperbarare": "stridsgrupperbar",
    "stridsgrupperbarares": "stridsgrupperbar",
    "stridsgrupperbaras": "stridsgrupperbar",
    "stridsgrupperbarast": "stridsgrupperbar",
    "stridsgrupperbaraste": "stridsgrupperbar",
    "stridsgrupperbarastes": "stridsgrupperbar",
    "stridsgrupperbarasts": "stridsgrupperbar",
    "stridsgrupperbare": "stridsgrupperbar",
    "stridsgrupperbares": "stridsgrupperbar",
    "stridsgrupperbarheten": "stridsgrupperbarhet",
    "stridsgrupperbarhetens": "stridsgrupperbarhet",
    "stridsgrupperbarhets": "stridsgrupperbarhet",
    "stridsgrupperbars": "stridsgrupperbar",
    "stridsgrupperbart": "stridsgrupperbar",
    "stridsgrupperbarts": "stridsgrupperbar",
    "stridsgrupperingar": "stridsgruppering",
    "stridsgrupperingarna": "stridsgruppering",
    "stridsgrupperingarnas": "stridsgruppering",
    "stridsgrupperingars": "stridsgruppering",
    "stridsgrupperingen": "stridsgruppering",
    "stridsgrupperingens": "stridsgruppering",
    "stridsgrupperings": "stridsgruppering",
    "stridsklubb": "stridsklubba",
    "stridsklubban": "stridsklubba",
    "stridsklubbans": "stridsklubba",
    "stridsklubbas": "stridsklubba",
    "stridsklubbe": "stridsklubba",
    "stridsklubbor": "stridsklubba",
    "stridsklubborna": "stridsklubba",
    "stridsklubbornas": "stridsklubba",
    "stridsklubbors": "stridsklubba",
    "stridsklubbs": "stridsklubba",
    "stridskrafterna": "stridskrafter",
    "stridskrafternas": "stridskrafter",
    "stridskrafters": "stridskrafter",
    "stridskrafts": "stridskrafter",
    "stridsledningar": "stridsledning",
    "stridsledningarna": "stridsledning",
    "stridsledningarnas": "stridsledning",
    "stridsledningars": "stridsledning",
    "stridsledningen": "stridsledning",
    "stridsledningens": "stridsledning",
    "stridslednings": "stridsledning",
    "stridsledningscentralen": "stridsledningscentral",
    "stridsledningscentralens": "stridsledningscentral",
    "stridsledningscentraler": "stridsledningscentral",
    "stridsledningscentralerna": "stridsledningscentral",
    "stridsledningscentralernas": "stridsledningscentral",
    "stridsledningscentralers": "stridsledningscentral",
    "stridsledningscentrals": "stridsledningscentral",
    "stridslystens": "stridslysten",
    "stridslystet": "stridslysten",
    "stridslystets": "stridslysten",
    "stridslystna": "stridslysten",
    "stridslystnare": "stridslysten",
    "stridslystnares": "stridslysten",
    "stridslystnas": "stridslysten",
    "stridslystnast": "stridslysten",
    "stridslystnaste": "stridslysten",
    "stridslystnastes": "stridslysten",
    "stridslystnasts": "stridslysten",
    "stridslystne": "stridslysten",
    "stridslystnes": "stridslysten",
    "stridsmedels": "stridsmedel",
    "stridsmedlen": "stridsmedel",
    "stridsmedlens": "stridsmedel",
    "stridsmedlet": "stridsmedel",
    "stridsmedlets": "stridsmedel",
    "stridsmunderade": "stridsmunderad",
    "stridsmunderades": "stridsmunderad",
    "stridsmunderads": "stridsmunderad",
    "stridsmunderat": "stridsmunderad",
    "stridsmunderats": "stridsmunderad",
    "stridsmunderingar": "stridsmundering",
    "stridsmunderingarna": "stridsmundering",
    "stridsmunderingarnas": "stridsmundering",
    "stridsmunderingars": "stridsmundering",
    "stridsmunderingen": "stridsmundering",
    "stridsmunderingens": "stridsmundering",
    "stridsmunderings": "stridsmundering",
    "stridsmässiga": "stridsmässig",
    "stridsmässigare": "stridsmässig",
    "stridsmässigares": "stridsmässig",
    "stridsmässigas": "stridsmässig",
    "stridsmässigast": "stridsmässig",
    "stridsmässigaste": "stridsmässig",
    "stridsmässigastes": "stridsmässig",
    "stridsmässigasts": "stridsmässig",
    "stridsmässige": "stridsmässig",
    "stridsmässiges": "stridsmässig",
    "stridsmässigs": "stridsmässig",
    "stridsmässigt": "stridsmässig",
    "stridsmässigts": "stridsmässig",
    "stridsplatsen": "stridsplats",
    "stridsplatsens": "stridsplats",
    "stridsplatser": "stridsplats",
    "stridsplatserna": "stridsplats",
    "stridsplatsernas": "stridsplats",
    "stridsplatsers": "stridsplats",
    "stridsropen": "stridsrop",
    "stridsropens": "stridsrop",
    "stridsropet": "stridsrop",
    "stridsropets": "stridsrop",
    "stridsrops": "stridsrop",
    "stridssel": "stridssele",
    "stridsselar": "stridssele",
    "stridsselarna": "stridssele",
    "stridsselarnas": "stridssele",
    "stridsselars": "stridssele",
    "stridsselen": "stridssele",
    "stridsselens": "stridssele",
    "stridsseles": "stridssele",
    "stridssels": "stridssele",
    "stridsskjutningar": "stridsskjutning",
    "stridsskjutningarna": "stridsskjutning",
    "stridsskjutningarnas": "stridsskjutning",
    "stridsskjutningars": "stridsskjutning",
    "stridsskjutningen": "stridsskjutning",
    "stridsskjutningens": "stridsskjutning",
    "stridsskjutnings": "stridsskjutning",
    "stridsskriften": "stridsskrift",
    "stridsskriftens": "stridsskrift",
    "stridsskrifter": "stridsskrift",
    "stridsskrifterna": "stridsskrift",
    "stridsskrifternas": "stridsskrift",
    "stridsskrifters": "stridsskrift",
    "stridsskrifts": "stridsskrift",
    "stridsspetsar": "stridsspets",
    "stridsspetsarna": "stridsspets",
    "stridsspetsarnas": "stridsspets",
    "stridsspetsars": "stridsspets",
    "stridsspetsen": "stridsspets",
    "stridsspetsens": "stridsspets",
    "stridsställningar": "stridsställning",
    "stridsställningarna": "stridsställning",
    "stridsställningarnas": "stridsställning",
    "stridsställningars": "stridsställning",
    "stridsställningen": "stridsställning",
    "stridsställningens": "stridsställning",
    "stridsställnings": "stridsställning",
    "stridstuppar": "stridstupp",
    "stridstupparna": "stridstupp",
    "stridstupparnas": "stridstupp",
    "stridstuppars": "stridstupp",
    "stridstuppen": "stridstupp",
    "stridstuppens": "stridstupp",
    "stridstupps": "stridstupp",
    "stridsuppställningar": "stridsuppställning",
    "stridsuppställningarna": "stridsuppställning",
    "stridsuppställningarnas": "stridsuppställning",
    "stridsuppställningars": "stridsuppställning",
    "stridsuppställningen": "stridsuppställning",
    "stridsuppställningens": "stridsuppställning",
    "stridsuppställnings": "stridsuppställning",
    "stridsutrustade": "stridsutrustad",
    "stridsutrustades": "stridsutrustad",
    "stridsutrustads": "stridsutrustad",
    "stridsutrustat": "stridsutrustad",
    "stridsutrustats": "stridsutrustad",
    "stridsvagnar": "stridsvagn",
    "stridsvagnarna": "stridsvagn",
    "stridsvagnarnas": "stridsvagn",
    "stridsvagnars": "stridsvagn",
    "stridsvagnen": "stridsvagn",
    "stridsvagnens": "stridsvagn",
    "stridsvagns": "stridsvagn",
    "stridsvagnsdrivningar": "stridsvagnsdrivning",
    "stridsvagnsdrivningarna": "stridsvagnsdrivning",
    "stridsvagnsdrivningarnas": "stridsvagnsdrivning",
    "stridsvagnsdrivningars": "stridsvagnsdrivning",
    "stridsvagnsdrivningen": "stridsvagnsdrivning",
    "stridsvagnsdrivningens": "stridsvagnsdrivning",
    "stridsvagnsdrivnings": "stridsvagnsdrivning",
    "stridsvagnshinderna": "stridsvagnshinder",
    "stridsvagnshindernas": "stridsvagnshinder",
    "stridsvagnshinders": "stridsvagnshinder",
    "stridsvagnshindren": "stridsvagnshinder",
    "stridsvagnshindrens": "stridsvagnshinder",
    "stridsvagnshindret": "stridsvagnshinder",
    "stridsvagnshindrets": "stridsvagnshinder",
    "stridsvanan": "stridsvana",
    "stridsvanans": "stridsvana",
    "stridsvanas": "stridsvana",
    "stridsvane": "stridsvana",
    "stridsvanor": "stridsvana",
    "stridsvanorna": "stridsvana",
    "stridsvanornas": "stridsvana",
    "stridsvanors": "stridsvana",
    "stridsvärnen": "stridsvärn",
    "stridsvärnens": "stridsvärn",
    "stridsvärnet": "stridsvärn",
    "stridsvärnets": "stridsvärn",
    "stridsvärns": "stridsvärn",
    "stridsyx": "stridsyxa",
    "stridsyxan": "stridsyxa",
    "stridsyxans": "stridsyxa",
    "stridsyxas": "stridsyxa",
    "stridsyxe": "stridsyxa",
    "stridsyxor": "stridsyxa",
    "stridsyxorna": "stridsyxa",
    "stridsyxornas": "stridsyxa",
    "stridsyxors": "stridsyxa",
    "stridszonen": "stridszon",
    "stridszonens": "stridszon",
    "stridszoner": "stridszon",
    "stridszonerna": "stridszon",
    "stridszonernas": "stridszon",
    "stridszoners": "stridszon",
    "stridszons": "stridszon",
    "stridsäpplen": "stridsäpple",
    "stridsäpplena": "stridsäpple",
    "stridsäpplenas": "stridsäpple",
    "stridsäpplens": "stridsäpple",
    "stridsäpples": "stridsäpple",
    "stridsäpplet": "stridsäpple",
    "stridsäpplets": "stridsäpple",
    "stridsäppls": "stridsäpple",
    "stridsåtgärden": "stridsåtgärd",
    "stridsåtgärdens": "stridsåtgärd",
    "stridsåtgärder": "stridsåtgärd",
    "stridsåtgärderna": "stridsåtgärd",
    "stridsåtgärdernas": "stridsåtgärd",
    "stridsåtgärders": "stridsåtgärd",
    "stridsåtgärds": "stridsåtgärd",
    "stridulationen": "stridulation",
    "stridulationens": "stridulation",
    "stridulationer": "stridulation",
    "stridulationerna": "stridulation",
    "stridulationernas": "stridulation",
    "stridulationers": "stridulation",
    "stridulations": "stridulation",
    "strigel": "strigla",
    "strigeln": "strigel",
    "strigelns": "strigel",
    "strigels": "strigel",
    "striglad": "strigla",
    "striglade": "strigla",
    "striglades": "strigla",
    "striglads": "strigla",
    "striglande": "strigla",
    "striglanden": "striglande",
    "striglandena": "striglande",
    "striglandenas": "striglande",
    "striglandens": "striglande",
    "striglandes": "striglande",
    "striglandet": "striglande",
    "striglandets": "striglande",
    "striglar": "strigla",
    "striglarna": "strigel",
    "striglarnas": "strigel",
    "striglars": "strigel",
    "striglas": "strigla",
    "striglat": "strigla",
    "striglats": "strigla",
    "strikear": "strike",
    "strikearna": "strike",
    "strikearnas": "strike",
    "strikears": "strike",
    "strikeen": "strike",
    "strikeens": "strike",
    "strikes": "strike",
    "strikta": "strikt",
    "striktare": "strikt",
    "striktares": "strikt",
    "striktas": "strikt",
    "striktast": "strikt",
    "striktaste": "strikt",
    "striktastes": "strikt",
    "striktasts": "strikt",
    "strikte": "strikt",
    "striktes": "strikt",
    "striktheten": "strikthet",
    "strikthetens": "strikthet",
    "strikthets": "strikthet",
    "striktionen": "striktion",
    "striktionens": "striktion",
    "striktioner": "striktion",
    "striktionerna": "striktion",
    "striktionernas": "striktion",
    "striktioners": "striktion",
    "striktions": "striktion",
    "strikts": "strikt",
    "stril": "strila",
    "strilad": "strila",
    "strilade": "strila",
    "strilades": "strila",
    "strilads": "strila",
    "strilande": "strila",
    "strilanden": "strilande",
    "strilandena": "strilande",
    "strilandenas": "strilande",
    "strilandens": "strilande",
    "strilandes": "strilande",
    "strilandet": "strilande",
    "strilandets": "strilande",
    "strilar": "strila",
    "strilarna": "stril",
    "strilarnas": "stril",
    "strilars": "stril",
    "strilas": "strila",
    "strilat": "strila",
    "strilats": "strila",
    "strilen": "stril",
    "strilens": "stril",
    "strils": "stril",
    "strim": "strimma",
    "striml": "strimla",
    "strimlad": "strimla",
    "strimlade": "strimla",
    "strimlades": "strimla",
    "strimlads": "strimla",
    "strimlan": "strimla",
    "strimlande": "strimla",
    "strimlanden": "strimlande",
    "strimlandena": "strimlande",
    "strimlandenas": "strimlande",
    "strimlandens": "strimlande",
    "strimlandes": "strimlande",
    "strimlandet": "strimlande",
    "strimlandets": "strimlande",
    "strimlans": "strimla",
    "strimlar": "strimla",
    "strimlas": "strimla",
    "strimlat": "strimla",
    "strimlats": "strimla",
    "strimle": "strimla",
    "strimlor": "strimla",
    "strimlorna": "strimla",
    "strimlornas": "strimla",
    "strimlors": "strimla",
    "strimls": "strimla",
    "strimmade": "strimmad",
    "strimmades": "strimmad",
    "strimmads": "strimmad",
    "strimman": "strimma",
    "strimmans": "strimma",
    "strimmas": "strimma",
    "strimmat": "strimmad",
    "strimmats": "strimmad",
    "strimme": "strimma",
    "strimmel": "strimla",
    "strimmiga": "strimmig",
    "strimmigare": "strimmig",
    "strimmigares": "strimmig",
    "strimmigas": "strimmig",
    "strimmigast": "strimmig",
    "strimmigaste": "strimmig",
    "strimmigastes": "strimmig",
    "strimmigasts": "strimmig",
    "strimmige": "strimmig",
    "strimmiges": "strimmig",
    "strimmigheten": "strimmighet",
    "strimmighetens": "strimmighet",
    "strimmighets": "strimmighet",
    "strimmigs": "strimmig",
    "strimmigt": "strimmig",
    "strimmigts": "strimmig",
    "strimmor": "strimma",
    "strimmorna": "strimma",
    "strimmornas": "strimma",
    "strimmors": "strimma",
    "strims": "strimma",
    "stringensen": "stringens",
    "stringensens": "stringens",
    "stringenta": "stringent",
    "stringentare": "stringent",
    "stringentares": "stringent",
    "stringentas": "stringent",
    "stringentast": "stringent",
    "stringentaste": "stringent",
    "stringentastes": "stringent",
    "stringentasts": "stringent",
    "stringente": "stringent",
    "stringentes": "stringent",
    "stringentheten": "stringenthet",
    "stringenthetens": "stringenthet",
    "stringenthets": "stringenthet",
    "stringents": "stringent",
    "strip": "stripa",
    "strip-teasen": "strip-tease",
    "strip-teasens": "strip-tease",
    "strip-teases": "strip-tease",
    "stripad": "stripa",
    "stripade": "stripa",
    "stripades": "stripa",
    "stripads": "stripa",
    "stripan": "stripa",
    "stripande": "stripa",
    "stripanden": "stripande",
    "stripandena": "stripande",
    "stripandenas": "stripande",
    "stripandens": "stripande",
    "stripandes": "stripande",
    "stripandet": "stripande",
    "stripandets": "stripande",
    "stripans": "stripa",
    "stripar": "stripa",
    "stripas": "stripa",
    "stripat": "stripa",
    "stripats": "stripa",
    "stripe": "stripa",
    "stripiga": "stripig",
    "stripigare": "stripig",
    "stripigares": "stripig",
    "stripigas": "stripig",
    "stripigast": "stripig",
    "stripigaste": "stripig",
    "stripigastes": "stripig",
    "stripigasts": "stripig",
    "stripige": "stripig",
    "stripiges": "stripig",
    "stripigs": "stripig",
    "stripigt": "stripig",
    "stripigts": "stripig",
    "stripor": "stripa",
    "striporna": "stripa",
    "stripornas": "stripa",
    "stripors": "stripa",
    "stripp": "strippa",
    "strippad": "strippa",
    "strippade": "strippa",
    "strippades": "strippa",
    "strippads": "strippa",
    "strippan": "strippa",
    "strippande": "strippa",
    "strippanden": "strippande",
    "strippandena": "strippande",
    "strippandenas": "strippande",
    "strippandens": "strippande",
    "strippandes": "strippande",
    "strippandet": "strippande",
    "strippandets": "strippande",
    "strippans": "strippa",
    "strippar": "strippa",
    "strippas": "strippa",
    "strippat": "strippa",
    "strippats": "strippa",
    "strippe": "strippa",
    "strippen": "stripp",
    "strippens": "stripp",
    "strippningar": "strippning",
    "strippningarna": "strippning",
    "strippningarnas": "strippning",
    "strippningars": "strippning",
    "strippningen": "strippning",
    "strippningens": "strippning",
    "strippnings": "strippning",
    "strippor": "strippa",
    "stripporna": "strippa",
    "strippornas": "strippa",
    "strippors": "strippa",
    "stripps": "strippa",
    "strippshowen": "strippshow",
    "strippshowens": "strippshow",
    "strippshower": "strippshow",
    "strippshowerna": "strippshow",
    "strippshowernas": "strippshow",
    "strippshowers": "strippshow",
    "strippshows": "strippshow",
    "strips": "stripa",
    "stripteasen": "striptease",
    "stripteasens": "striptease",
    "stripteases": "striptease",
    "stritar": "strit",
    "stritarna": "strit",
    "stritarnas": "strit",
    "stritars": "strit",
    "striten": "strit",
    "stritens": "strit",
    "strits": "strit",
    "stritt": "strida",
    "stritts": "strida",
    "stroboskopen": "stroboskop",
    "stroboskopens": "stroboskop",
    "stroboskopet": "stroboskop",
    "stroboskopets": "stroboskop",
    "stroboskopien": "stroboskopi",
    "stroboskopiens": "stroboskopi",
    "stroboskopier": "stroboskopi",
    "stroboskopierna": "stroboskopi",
    "stroboskopiernas": "stroboskopi",
    "stroboskopiers": "stroboskopi",
    "stroboskopin": "stroboskopi",
    "stroboskopins": "stroboskopi",
    "stroboskopis": "stroboskopi",
    "stroboskops": "stroboskop",
    "strofen": "strof",
    "strofens": "strof",
    "strofer": "strof",
    "stroferna": "strof",
    "strofernas": "strof",
    "strofers": "strof",
    "strofiska": "strofisk",
    "strofiskare": "strofisk",
    "strofiskares": "strofisk",
    "strofiskas": "strofisk",
    "strofiskast": "strofisk",
    "strofiskaste": "strofisk",
    "strofiskastes": "strofisk",
    "strofiskasts": "strofisk",
    "strofiske": "strofisk",
    "strofiskes": "strofisk",
    "strofisks": "strofisk",
    "strofiskt": "strofisk",
    "strofiskts": "strofisk",
    "strofparen": "strofpar",
    "strofparens": "strofpar",
    "strofparet": "strofpar",
    "strofparets": "strofpar",
    "strofpars": "strofpar",
    "strofs": "strof",
    "strokebehandlingar": "strokebehandling",
    "strokebehandlingarna": "strokebehandling",
    "strokebehandlingarnas": "strokebehandling",
    "strokebehandlingars": "strokebehandling",
    "strokebehandlingen": "strokebehandling",
    "strokebehandlingens": "strokebehandling",
    "strokebehandlings": "strokebehandling",
    "strokekrisen": "strokekris",
    "strokekrisens": "strokekris",
    "strokekriser": "strokekris",
    "strokekriserna": "strokekris",
    "strokekrisernas": "strokekris",
    "strokekrisers": "strokekris",
    "stroken": "stroke",
    "strokens": "stroke",
    "strokes": "stroke",
    "strokesarna": "stroke",
    "strokesarnas": "stroke",
    "strokesen": "stroke",
    "strokesens": "stroke",
    "stroket": "stroke",
    "strokets": "stroke",
    "stronga": "strong",
    "strongare": "strong",
    "strongares": "strong",
    "strongas": "strong",
    "strongast": "strong",
    "strongaste": "strong",
    "strongastes": "strong",
    "strongasts": "strong",
    "stronge": "strong",
    "stronges": "strong",
    "strongheten": "stronghet",
    "stronghetens": "stronghet",
    "stronghets": "stronghet",
    "strongs": "strong",
    "strongt": "strong",
    "strongts": "strong",
    "strontiet": "strontium",
    "strontiets": "strontium",
    "strontiumet": "strontium",
    "strontiumets": "strontium",
    "strontiumföreningar": "strontiumförening",
    "strontiumföreningarna": "strontiumförening",
    "strontiumföreningarnas": "strontiumförening",
    "strontiumföreningars": "strontiumförening",
    "strontiumföreningen": "strontiumförening",
    "strontiumföreningens": "strontiumförening",
    "strontiumförenings": "strontiumförening",
    "strontiums": "strontium",
    "stroppar": "stropp",
    "stropparna": "stropp",
    "stropparnas": "stropp",
    "stroppars": "stropp",
    "stroppen": "stropp",
    "stroppens": "stropp",
    "stroppiga": "stroppig",
    "stroppigare": "stroppig",
    "stroppigares": "stroppig",
    "stroppigas": "stroppig",
    "stroppigast": "stroppig",
    "stroppigaste": "stroppig",
    "stroppigastes": "stroppig",
    "stroppigasts": "stroppig",
    "stroppige": "stroppig",
    "stroppiges": "stroppig",
    "stroppigheten": "stroppighet",
    "stroppighetens": "stroppighet",
    "stroppighets": "stroppighet",
    "stroppigs": "stroppig",
    "stroppigt": "stroppig",
    "stroppigts": "stroppig",
    "stropps": "stropp",
    "stros": "strosa",
    "strosad": "strosa",
    "strosade": "strosa",
    "strosades": "strosa",
    "strosads": "strosa",
    "strosande": "strosa",
    "strosanden": "strosande",
    "strosandena": "strosande",
    "strosandenas": "strosande",
    "strosandens": "strosande",
    "strosandes": "strosande",
    "strosandet": "strosande",
    "strosandets": "strosande",
    "strosar": "strosa",
    "strosas": "strosa",
    "strosat": "strosa",
    "strosats": "strosa",
    "strossar": "stross",
    "strossarna": "stross",
    "strossarnas": "stross",
    "strossars": "stross",
    "strossen": "stross",
    "strossens": "stross",
    "strudeln": "strudel",
    "strudelns": "strudel",
    "strudels": "strudel",
    "strudlar": "strudel",
    "strudlarna": "strudel",
    "strudlarnas": "strudel",
    "strudlars": "strudel",
    "struke": "stryka",
    "struken": "stryka",
    "strukens": "stryka",
    "strukes": "stryka",
    "struket": "stryka",
    "strukets": "stryka",
    "strukit": "stryka",
    "strukits": "stryka",
    "strukna": "stryka",
    "struknas": "stryka",
    "strukne": "stryka",
    "struknes": "stryka",
    "strukturalismen": "strukturalism",
    "strukturalismens": "strukturalism",
    "strukturalismer": "strukturalism",
    "strukturalismerna": "strukturalism",
    "strukturalismernas": "strukturalism",
    "strukturalismers": "strukturalism",
    "strukturalisms": "strukturalism",
    "strukturalisten": "strukturalist",
    "strukturalistens": "strukturalist",
    "strukturalister": "strukturalist",
    "strukturalisterna": "strukturalist",
    "strukturalisternas": "strukturalist",
    "strukturalisters": "strukturalist",
    "strukturalistiska": "strukturalistisk",
    "strukturalistiskas": "strukturalistisk",
    "strukturalistiske": "strukturalistisk",
    "strukturalistiskes": "strukturalistisk",
    "strukturalistisks": "strukturalistisk",
    "strukturalistiskt": "strukturalistisk",
    "strukturalistiskts": "strukturalistisk",
    "strukturalists": "strukturalist",
    "strukturarbetslösheten": "strukturarbetslöshet",
    "strukturarbetslöshetens": "strukturarbetslöshet",
    "strukturarbetslösheter": "strukturarbetslöshet",
    "strukturarbetslösheterna": "strukturarbetslöshet",
    "strukturarbetslösheternas": "strukturarbetslöshet",
    "strukturarbetslösheters": "strukturarbetslöshet",
    "strukturarbetslöshets": "strukturarbetslöshet",
    "strukturella": "strukturell",
    "strukturellare": "strukturell",
    "strukturellares": "strukturell",
    "strukturellas": "strukturell",
    "strukturellast": "strukturell",
    "strukturellaste": "strukturell",
    "strukturellastes": "strukturell",
    "strukturellasts": "strukturell",
    "strukturelle": "strukturell",
    "strukturelles": "strukturell",
    "strukturells": "strukturell",
    "strukturellt": "strukturell",
    "strukturellts": "strukturell",
    "strukturen": "struktur",
    "strukturens": "struktur",
    "strukturer": "struktur",
    "strukturerad": "strukturera",
    "strukturerade": "strukturera",
    "strukturerades": "strukturera",
    "strukturerads": "strukturera",
    "strukturerande": "strukturera",
    "struktureranden": "strukturerande",
    "strukturerandena": "strukturerande",
    "strukturerandenas": "strukturerande",
    "strukturerandens": "strukturerande",
    "strukturerandes": "strukturerande",
    "strukturerandet": "strukturerande",
    "strukturerandets": "strukturerande",
    "strukturerar": "strukturera",
    "struktureras": "strukturera",
    "strukturerat": "strukturera",
    "strukturerats": "strukturera",
    "strukturerbara": "strukturerbar",
    "strukturerbarare": "strukturerbar",
    "strukturerbarares": "strukturerbar",
    "strukturerbaras": "strukturerbar",
    "strukturerbarast": "strukturerbar",
    "strukturerbaraste": "strukturerbar",
    "strukturerbarastes": "strukturerbar",
    "strukturerbarasts": "strukturerbar",
    "strukturerbare": "strukturerbar",
    "strukturerbares": "strukturerbar",
    "strukturerbarheten": "strukturerbarhet",
    "strukturerbarhetens": "strukturerbarhet",
    "strukturerbarhets": "strukturerbarhet",
    "strukturerbars": "strukturerbar",
    "strukturerbart": "strukturerbar",
    "strukturerbarts": "strukturerbar",
    "struktureringar": "strukturering",
    "struktureringarna": "strukturering",
    "struktureringarnas": "strukturering",
    "struktureringars": "strukturering",
    "struktureringen": "strukturering",
    "struktureringens": "strukturering",
    "strukturerings": "strukturering",
    "strukturerna": "struktur",
    "strukturernas": "struktur",
    "strukturers": "struktur",
    "strukturformeln": "strukturformel",
    "strukturformelns": "strukturformel",
    "strukturformels": "strukturformel",
    "strukturformler": "strukturformel",
    "strukturformlerna": "strukturformel",
    "strukturformlernas": "strukturformel",
    "strukturformlers": "strukturformel",
    "strukturförändringar": "strukturförändring",
    "strukturförändringarna": "strukturförändring",
    "strukturförändringarnas": "strukturförändring",
    "strukturförändringars": "strukturförändring",
    "strukturförändringen": "strukturförändring",
    "strukturförändringens": "strukturförändring",
    "strukturförändrings": "strukturförändring",
    "strukturmodellen": "strukturmodell",
    "strukturmodellens": "strukturmodell",
    "strukturmodeller": "strukturmodell",
    "strukturmodellerna": "strukturmodell",
    "strukturmodellernas": "strukturmodell",
    "strukturmodellers": "strukturmodell",
    "strukturmodells": "strukturmodell",
    "strukturomvandlingar": "strukturomvandling",
    "strukturomvandlingarna": "strukturomvandling",
    "strukturomvandlingarnas": "strukturomvandling",
    "strukturomvandlingars": "strukturomvandling",
    "strukturomvandlingen": "strukturomvandling",
    "strukturomvandlingens": "strukturomvandling",
    "strukturomvandlings": "strukturomvandling",
    "strukturrationaliserad": "strukturrationalisera",
    "strukturrationaliserade": "strukturrationalisera",
    "strukturrationaliserades": "strukturrationalisera",
    "strukturrationaliserads": "strukturrationalisera",
    "strukturrationaliserande": "strukturrationalisera",
    "strukturrationaliseranden": "strukturrationaliserande",
    "strukturrationaliserandena": "strukturrationaliserande",
    "strukturrationaliserandenas": "strukturrationaliserande",
    "strukturrationaliserandens": "strukturrationaliserande",
    "strukturrationaliserandes": "strukturrationaliserande",
    "strukturrationaliserandet": "strukturrationaliserande",
    "strukturrationaliserandets": "strukturrationaliserande",
    "strukturrationaliserar": "strukturrationalisera",
    "strukturrationaliseras": "strukturrationalisera",
    "strukturrationaliserat": "strukturrationalisera",
    "strukturrationaliserats": "strukturrationalisera",
    "strukturrationaliserbara": "strukturrationaliserbar",
    "strukturrationaliserbarare": "strukturrationaliserbar",
    "strukturrationaliserbarares": "strukturrationaliserbar",
    "strukturrationaliserbaras": "strukturrationaliserbar",
    "strukturrationaliserbarast": "strukturrationaliserbar",
    "strukturrationaliserbaraste": "strukturrationaliserbar",
    "strukturrationaliserbarastes": "strukturrationaliserbar",
    "strukturrationaliserbarasts": "strukturrationaliserbar",
    "strukturrationaliserbare": "strukturrationaliserbar",
    "strukturrationaliserbares": "strukturrationaliserbar",
    "strukturrationaliserbarheten": "strukturrationaliserbarhet",
    "strukturrationaliserbarhetens": "strukturrationaliserbarhet",
    "strukturrationaliserbarhets": "strukturrationaliserbarhet",
    "strukturrationaliserbars": "strukturrationaliserbar",
    "strukturrationaliserbart": "strukturrationaliserbar",
    "strukturrationaliserbarts": "strukturrationaliserbar",
    "strukturrationaliseringar": "strukturrationalisering",
    "strukturrationaliseringarna": "strukturrationalisering",
    "strukturrationaliseringarnas": "strukturrationalisering",
    "strukturrationaliseringars": "strukturrationalisering",
    "strukturrationaliseringen": "strukturrationalisering",
    "strukturrationaliseringens": "strukturrationalisering",
    "strukturrationaliserings": "strukturrationalisering",
    "strukturs": "struktur",
    "strul": "strula",
    "strulad": "strula",
    "strulade": "strula",
    "strulades": "strula",
    "strulads": "strula",
    "strulande": "strula",
    "strulanden": "strulande",
    "strulandena": "strulande",
    "strulandenas": "strulande",
    "strulandens": "strulande",
    "strulandes": "strulande",
    "strulandet": "strulande",
    "strulandets": "strulande",
    "strular": "strula",
    "strulas": "strula",
    "strulat": "strula",
    "strulats": "strula",
    "strulet": "strul",
    "strulets": "strul",
    "struliga": "strulig",
    "struligare": "strulig",
    "struligares": "strulig",
    "struligas": "strulig",
    "struligast": "strulig",
    "struligaste": "strulig",
    "struligastes": "strulig",
    "struligasts": "strulig",
    "strulige": "strulig",
    "struliges": "strulig",
    "struligheten": "strulighet",
    "strulighetens": "strulighet",
    "struligheter": "strulighet",
    "struligheterna": "strulighet",
    "struligheternas": "strulighet",
    "struligheters": "strulighet",
    "strulighets": "strulighet",
    "struligs": "strulig",
    "struligt": "strulig",
    "struligts": "strulig",
    "struls": "strul",
    "strumaartade": "strumaartad",
    "strumaartades": "strumaartad",
    "strumaartads": "strumaartad",
    "strumaartat": "strumaartad",
    "strumaartats": "strumaartad",
    "struman": "struma",
    "strumans": "struma",
    "strumas": "struma",
    "strump": "strumpa",
    "strumpan": "strumpa",
    "strumpans": "strumpa",
    "strumpas": "strumpa",
    "strumpbyx": "strumpbyxa",
    "strumpbyxan": "strumpbyxa",
    "strumpbyxans": "strumpbyxa",
    "strumpbyxas": "strumpbyxa",
    "strumpbyxe": "strumpbyxa",
    "strumpbyxor": "strumpbyxa",
    "strumpbyxorna": "strumpbyxa",
    "strumpbyxornas": "strumpbyxa",
    "strumpbyxors": "strumpbyxa",
    "strumpe": "strumpa",
    "strumpebanden": "strumpeband",
    "strumpebandens": "strumpeband",
    "strumpebandet": "strumpeband",
    "strumpebandets": "strumpeband",
    "strumpebands": "strumpeband",
    "strumpebandsordens": "strumpebandsorden",
    "strumpebandsordnar": "strumpebandsorden",
    "strumpebandsordnarna": "strumpebandsorden",
    "strumpebandsordnarnas": "strumpebandsorden",
    "strumpebandsordnars": "strumpebandsorden",
    "strumpebandsordnen": "strumpebandsorden",
    "strumpebandsordnens": "strumpebandsorden",
    "strumpfoten": "strumpfot",
    "strumpfotens": "strumpfot",
    "strumpfots": "strumpfot",
    "strumpfötter": "strumpfot",
    "strumpfötterna": "strumpfot",
    "strumpfötternas": "strumpfot",
    "strumpfötters": "strumpfot",
    "strumphälar": "strumphäl",
    "strumphälarna": "strumphäl",
    "strumphälarnas": "strumphäl",
    "strumphälars": "strumphäl",
    "strumphälen": "strumphäl",
    "strumphälens": "strumphäl",
    "strumphäls": "strumphäl",
    "strumphållar": "strumphållare",
    "strumphållaren": "strumphållare",
    "strumphållarens": "strumphållare",
    "strumphållares": "strumphållare",
    "strumphållarna": "strumphållare",
    "strumphållarnas": "strumphållare",
    "strumpor": "strumpa",
    "strumporna": "strumpa",
    "strumpornas": "strumpa",
    "strumpors": "strumpa",
    "strumps": "strumpa",
    "strumpstick": "strumpsticka",
    "strumpstickan": "strumpsticka",
    "strumpstickans": "strumpsticka",
    "strumpstickas": "strumpsticka",
    "strumpsticke": "strumpsticka",
    "strumpstickor": "strumpsticka",
    "strumpstickorna": "strumpsticka",
    "strumpstickornas": "strumpsticka",
    "strumpstickors": "strumpsticka",
    "strumpsticks": "strumpsticka",
    "strunt": "strunta",
    "struntade": "strunta",
    "struntades": "strunta",
    "struntande": "strunta",
    "struntanden": "struntande",
    "struntandena": "struntande",
    "struntandenas": "struntande",
    "struntandens": "struntande",
    "struntandes": "struntande",
    "struntandet": "struntande",
    "struntandets": "struntande",
    "struntar": "strunta",
    "struntas": "strunta",
    "struntat": "strunta",
    "struntats": "strunta",
    "struntet": "strunt",
    "struntets": "strunt",
    "struntfina": "struntfin",
    "struntfinare": "struntfin",
    "struntfinares": "struntfin",
    "struntfinas": "struntfin",
    "struntfinast": "struntfin",
    "struntfinaste": "struntfin",
    "struntfinastes": "struntfin",
    "struntfinasts": "struntfin",
    "struntfine": "struntfin",
    "struntfines": "struntfin",
    "struntfins": "struntfin",
    "struntfint": "struntfin",
    "struntfints": "struntfin",
    "struntförnäma": "struntförnäm",
    "struntförnämare": "struntförnäm",
    "struntförnämares": "struntförnäm",
    "struntförnämas": "struntförnäm",
    "struntförnämast": "struntförnäm",
    "struntförnämaste": "struntförnäm",
    "struntförnämastes": "struntförnäm",
    "struntförnämasts": "struntförnäm",
    "struntförnäme": "struntförnäm",
    "struntförnämes": "struntförnäm",
    "struntförnämheten": "struntförnämhet",
    "struntförnämhetens": "struntförnämhet",
    "struntförnämhets": "struntförnämhet",
    "struntförnäms": "struntförnäm",
    "struntförnämt": "struntförnäm",
    "struntförnämts": "struntförnäm",
    "struntpratet": "struntprat",
    "struntpratets": "struntprat",
    "struntprats": "struntprat",
    "strunts": "strunt",
    "struntsumman": "struntsumma",
    "struntsummans": "struntsumma",
    "struntsummas": "struntsumma",
    "struntsumme": "struntsumma",
    "struntsummor": "struntsumma",
    "struntsummorna": "struntsumma",
    "struntsummornas": "struntsumma",
    "struntsummors": "struntsumma",
    "struntviktiga": "struntviktig",
    "struntviktigare": "struntviktig",
    "struntviktigares": "struntviktig",
    "struntviktigas": "struntviktig",
    "struntviktigast": "struntviktig",
    "struntviktigaste": "struntviktig",
    "struntviktigastes": "struntviktig",
    "struntviktigasts": "struntviktig",
    "struntviktige": "struntviktig",
    "struntviktiges": "struntviktig",
    "struntviktigheten": "struntviktighet",
    "struntviktighetens": "struntviktighet",
    "struntviktighets": "struntviktighet",
    "struntviktigs": "struntviktig",
    "struntviktigt": "struntviktig",
    "struntviktigts": "struntviktig",
    "strup": "strupe",
    "strupar": "strupe",
    "struparna": "strupe",
    "struparnas": "strupe",
    "strupars": "strupe",
    "strupcancern": "strupcancer",
    "strupcancerns": "strupcancer",
    "strupcancers": "strupcancer",
    "strupcancrar": "strupcancer",
    "strupcancrarna": "strupcancer",
    "strupcancrarnas": "strupcancer",
    "strupcancrars": "strupcancer",
    "strupen": "strupe",
    "strupens": "strupe",
    "strupes": "strupe",
    "struphuvuden": "struphuvud",
    "struphuvudena": "struphuvud",
    "struphuvudenas": "struphuvud",
    "struphuvudens": "struphuvud",
    "struphuvudet": "struphuvud",
    "struphuvudets": "struphuvud",
    "struphuvuds": "struphuvud",
    "struplocken": "struplock",
    "struplockens": "struplock",
    "struplocket": "struplock",
    "struplockets": "struplock",
    "struplocks": "struplock",
    "strups": "strupe",
    "strupsångar": "strupsångare",
    "strupsångaren": "strupsångare",
    "strupsångarens": "strupsångare",
    "strupsångares": "strupsångare",
    "strupsångarna": "strupsångare",
    "strupsångarnas": "strupsångare",
    "strutar": "strut",
    "strutarna": "strut",
    "strutarnas": "strut",
    "strutars": "strut",
    "struten": "strut",
    "strutens": "strut",
    "struts": "strut",
    "strutsar": "struts",
    "strutsarna": "struts",
    "strutsarnas": "struts",
    "strutsars": "struts",
    "strutsen": "struts",
    "strutsens": "struts",
    "strutsfjädern": "strutsfjäder",
    "strutsfjäderns": "strutsfjäder",
    "strutsfjäders": "strutsfjäder",
    "strutsfjädrar": "strutsfjäder",
    "strutsfjädrarna": "strutsfjäder",
    "strutsfjädrarnas": "strutsfjäder",
    "strutsfjädrars": "strutsfjäder",
    "strutsmag": "strutsmage",
    "strutsmagar": "strutsmage",
    "strutsmagarna": "strutsmage",
    "strutsmagarnas": "strutsmage",
    "strutsmagars": "strutsmage",
    "strutsmagen": "strutsmage",
    "strutsmagens": "strutsmage",
    "strutsmages": "strutsmage",
    "strutsmags": "strutsmage",
    "strutsplymen": "strutsplym",
    "strutsplymens": "strutsplym",
    "strutsplymer": "strutsplym",
    "strutsplymerna": "strutsplym",
    "strutsplymernas": "strutsplym",
    "strutsplymers": "strutsplym",
    "strutsplyms": "strutsplym",
    "strutspolitiken": "strutspolitik",
    "strutspolitikens": "strutspolitik",
    "strutspolitiks": "strutspolitik",
    "strutsäggen": "strutsägg",
    "strutsäggens": "strutsägg",
    "strutsägget": "strutsägg",
    "strutsäggets": "strutsägg",
    "strutsäggs": "strutsägg",
    "strutt": "strutta",
    "struttad": "strutta",
    "struttade": "strutta",
    "struttades": "strutta",
    "struttads": "strutta",
    "struttande": "strutta",
    "struttanden": "struttande",
    "struttandena": "struttande",
    "struttandenas": "struttande",
    "struttandens": "struttande",
    "struttandes": "struttande",
    "struttandet": "struttande",
    "struttandets": "struttande",
    "struttar": "strutta",
    "struttas": "strutta",
    "struttat": "strutta",
    "struttats": "strutta",
    "struttiga": "struttig",
    "struttigare": "struttig",
    "struttigares": "struttig",
    "struttigas": "struttig",
    "struttigast": "struttig",
    "struttigaste": "struttig",
    "struttigastes": "struttig",
    "struttigasts": "struttig",
    "struttige": "struttig",
    "struttiges": "struttig",
    "struttigheten": "struttighet",
    "struttighetens": "struttighet",
    "struttighets": "struttighet",
    "struttigs": "struttig",
    "struttigt": "struttig",
    "struttigts": "struttig",
    "struv": "struva",
    "struvan": "struva",
    "struvans": "struva",
    "struvas": "struva",
    "struve": "struva",
    "struvor": "struva",
    "struvorna": "struva",
    "struvornas": "struva",
    "struvors": "struva",
    "struvs": "struva",
    "stryk": "stryka",
    "strykande": "stryka",
    "strykanden": "strykande",
    "strykandena": "strykande",
    "strykandenas": "strykande",
    "strykandens": "strykande",
    "strykandes": "strykande",
    "strykandet": "strykande",
    "strykandets": "strykande",
    "strykar": "strykare",
    "strykaren": "strykare",
    "strykarens": "strykare",
    "strykares": "strykare",
    "strykarkatten": "strykarkatt",
    "strykarkattens": "strykarkatt",
    "strykarkatter": "strykarkatt",
    "strykarkatterna": "strykarkatt",
    "strykarkatternas": "strykarkatt",
    "strykarkatters": "strykarkatt",
    "strykarkatts": "strykarkatt",
    "strykarna": "strykare",
    "strykarnas": "strykare",
    "strykas": "stryka",
    "strykbräd": "strykbräda",
    "strykbrädan": "strykbräda",
    "strykbrädans": "strykbräda",
    "strykbrädas": "strykbräda",
    "strykbräde": "strykbräda",
    "strykbräden": "strykbräde",
    "strykbrädena": "strykbräde",
    "strykbrädenas": "strykbräde",
    "strykbrädens": "strykbräde",
    "strykbrädes": "strykbräde",
    "strykbrädet": "strykbräde",
    "strykbrädets": "strykbräde",
    "strykbrädor": "strykbräda",
    "strykbrädorna": "strykbräda",
    "strykbrädornas": "strykbräda",
    "strykbrädors": "strykbräda",
    "strykbräds": "strykbräda",
    "stryke": "stryka",
    "stryker": "stryka",
    "strykerskan": "strykerska",
    "strykerskans": "strykerska",
    "strykerskas": "strykerska",
    "strykerske": "strykerska",
    "strykerskor": "strykerska",
    "strykerskorna": "strykerska",
    "strykerskornas": "strykerska",
    "strykerskors": "strykerska",
    "strykes": "stryka",
    "stryket": "stryk",
    "strykets": "stryk",
    "strykfria": "strykfri",
    "strykfriare": "strykfri",
    "strykfriares": "strykfri",
    "strykfrias": "strykfri",
    "strykfriast": "strykfri",
    "strykfriaste": "strykfri",
    "strykfriastes": "strykfri",
    "strykfriasts": "strykfri",
    "strykfrie": "strykfri",
    "strykfries": "strykfri",
    "strykfris": "strykfri",
    "strykfritt": "strykfri",
    "strykfritts": "strykfri",
    "strykfågeln": "strykfågel",
    "strykfågelns": "strykfågel",
    "strykfågels": "strykfågel",
    "strykfåglar": "strykfågel",
    "strykfåglarna": "strykfågel",
    "strykfåglarnas": "strykfågel",
    "strykfåglars": "strykfågel",
    "strykjärnen": "strykjärn",
    "strykjärnens": "strykjärn",
    "strykjärnet": "strykjärn",
    "strykjärnets": "strykjärn",
    "strykjärns": "strykjärn",
    "strykkapp": "strykkappa",
    "strykkappan": "strykkappa",
    "strykkappans": "strykkappa",
    "strykkappas": "strykkappa",
    "strykkappe": "strykkappa",
    "strykkappor": "strykkappa",
    "strykkapporna": "strykkappa",
    "strykkappornas": "strykkappa",
    "strykkappors": "strykkappa",
    "strykkapps": "strykkappa",
    "stryknindosen": "stryknindos",
    "stryknindosens": "stryknindos",
    "stryknindoser": "stryknindos",
    "stryknindoserna": "stryknindos",
    "stryknindosernas": "stryknindos",
    "stryknindosers": "stryknindos",
    "strykninen": "stryknin",
    "strykninens": "stryknin",
    "strykninet": "stryknin",
    "strykninets": "stryknin",
    "strykningar": "strykning",
    "strykningarna": "strykning",
    "strykningarnas": "strykning",
    "strykningars": "strykning",
    "strykningen": "strykning",
    "strykningens": "strykning",
    "stryknings": "strykning",
    "stryknins": "stryknin",
    "strykpojk": "strykpojke",
    "strykpojkar": "strykpojke",
    "strykpojkarna": "strykpojke",
    "strykpojkarnas": "strykpojke",
    "strykpojkars": "strykpojke",
    "strykpojken": "strykpojke",
    "strykpojkens": "strykpojke",
    "strykpojkes": "strykpojke",
    "strykpojks": "strykpojke",
    "strykrummen": "strykrum",
    "strykrummens": "strykrum",
    "strykrummet": "strykrum",
    "strykrummets": "strykrum",
    "strykrums": "strykrum",
    "strykrädda": "strykrädd",
    "strykräddare": "strykrädd",
    "strykräddares": "strykrädd",
    "strykräddas": "strykrädd",
    "strykräddast": "strykrädd",
    "strykräddaste": "strykrädd",
    "strykräddastes": "strykrädd",
    "strykräddasts": "strykrädd",
    "strykrädde": "strykrädd",
    "strykräddes": "strykrädd",
    "strykräddheten": "strykräddhet",
    "strykräddhetens": "strykräddhet",
    "strykräddhets": "strykräddhet",
    "strykrädds": "strykrädd",
    "stryks": "stryka",
    "strykstick": "stryksticka",
    "strykstickan": "stryksticka",
    "strykstickans": "stryksticka",
    "strykstickas": "stryksticka",
    "stryksticke": "stryksticka",
    "strykstickor": "stryksticka",
    "strykstickorna": "stryksticka",
    "strykstickornas": "stryksticka",
    "strykstickors": "stryksticka",
    "stryksticks": "stryksticka",
    "stryktipset": "stryktips",
    "stryktipsets": "stryktips",
    "stryktvättar": "stryktvätt",
    "stryktvättarna": "stryktvätt",
    "stryktvättarnas": "stryktvätt",
    "stryktvättars": "stryktvätt",
    "stryktvätten": "stryktvätt",
    "stryktvättens": "stryktvätt",
    "stryktvätts": "stryktvätt",
    "stryktäcka": "stryktäck",
    "stryktäckare": "stryktäck",
    "stryktäckares": "stryktäck",
    "stryktäckas": "stryktäck",
    "stryktäckast": "stryktäck",
    "stryktäckaste": "stryktäck",
    "stryktäckastes": "stryktäck",
    "stryktäckasts": "stryktäck",
    "stryktäcke": "stryktäck",
    "stryktäckes": "stryktäck",
    "stryktäckheten": "stryktäckhet",
    "stryktäckhetens": "stryktäckhet",
    "stryktäckhets": "stryktäckhet",
    "stryktäcks": "stryktäck",
    "stryktäckt": "stryktäck",
    "stryktäckts": "stryktäck",
    "stryktåliga": "stryktålig",
    "stryktåligare": "stryktålig",
    "stryktåligares": "stryktålig",
    "stryktåligas": "stryktålig",
    "stryktåligast": "stryktålig",
    "stryktåligaste": "stryktålig",
    "stryktåligastes": "stryktålig",
    "stryktåligasts": "stryktålig",
    "stryktålige": "stryktålig",
    "stryktåliges": "stryktålig",
    "stryktåligheten": "stryktålighet",
    "stryktålighetens": "stryktålighet",
    "stryktålighets": "stryktålighet",
    "stryktåligs": "stryktålig",
    "stryktåligt": "stryktålig",
    "stryktåligts": "stryktålig",
    "stryp": "strypa",
    "strypande": "strypa",
    "strypanden": "strypande",
    "strypandena": "strypande",
    "strypandenas": "strypande",
    "strypandens": "strypande",
    "strypandes": "strypande",
    "strypandet": "strypande",
    "strypandets": "strypande",
    "strypar": "strypare",
    "stryparen": "strypare",
    "stryparens": "strypare",
    "strypares": "strypare",
    "stryparna": "strypare",
    "stryparnas": "strypare",
    "strypas": "strypa",
    "strype": "strypa",
    "stryper": "strypa",
    "strypes": "strypa",
    "strypmärken": "strypmärke",
    "strypmärkena": "strypmärke",
    "strypmärkenas": "strypmärke",
    "strypmärkens": "strypmärke",
    "strypmärkes": "strypmärke",
    "strypmärket": "strypmärke",
    "strypmärkets": "strypmärke",
    "strypningar": "strypning",
    "strypningarna": "strypning",
    "strypningarnas": "strypning",
    "strypningars": "strypning",
    "strypningen": "strypning",
    "strypningens": "strypning",
    "strypnings": "strypning",
    "stryps": "strypa",
    "strypsjukan": "strypsjuka",
    "strypsjukans": "strypsjuka",
    "strypsjukas": "strypsjuka",
    "strypsjuke": "strypsjuka",
    "strypsjuks": "strypsjuka",
    "strypt": "strypa",
    "strypta": "strypa",
    "stryptas": "strypa",
    "strypte": "strypa",
    "stryptes": "strypa",
    "strypts": "strypa",
    "sträck": "sträcka",
    "sträckan": "sträcka",
    "sträckande": "sträcka",
    "sträckanden": "sträckande",
    "sträckandena": "sträckande",
    "sträckandenas": "sträckande",
    "sträckandens": "sträckande",
    "sträckandes": "sträckande",
    "sträckandet": "sträckande",
    "sträckandets": "sträckande",
    "sträckans": "sträcka",
    "sträckar": "sträckare",
    "sträckaren": "sträckare",
    "sträckarens": "sträckare",
    "sträckares": "sträckare",
    "sträckarmuskeln": "sträckarmuskel",
    "sträckarmuskelns": "sträckarmuskel",
    "sträckarmuskels": "sträckarmuskel",
    "sträckarmuskler": "sträckarmuskel",
    "sträckarmusklerna": "sträckarmuskel",
    "sträckarmusklernas": "sträckarmuskel",
    "sträckarmusklers": "sträckarmuskel",
    "sträckarna": "sträckare",
    "sträckarnas": "sträckare",
    "sträckas": "sträcka",
    "sträckbänkar": "sträckbänk",
    "sträckbänkarna": "sträckbänk",
    "sträckbänkarnas": "sträckbänk",
    "sträckbänkars": "sträckbänk",
    "sträckbänken": "sträckbänk",
    "sträckbänkens": "sträckbänk",
    "sträckbänks": "sträckbänk",
    "sträcke": "sträcka",
    "sträcken": "sträck",
    "sträckens": "sträck",
    "sträcker": "sträcka",
    "sträckes": "sträcka",
    "sträcket": "sträck",
    "sträckets": "sträck",
    "sträckförbanden": "sträckförband",
    "sträckförbandens": "sträckförband",
    "sträckförbandet": "sträckförband",
    "sträckförbandets": "sträckförband",
    "sträckförbands": "sträckförband",
    "sträckläs": "sträckläsa",
    "sträckläsande": "sträckläsa",
    "sträckläsanden": "sträckläsande",
    "sträckläsandena": "sträckläsande",
    "sträckläsandenas": "sträckläsande",
    "sträckläsandens": "sträckläsande",
    "sträckläsandes": "sträckläsande",
    "sträckläsandet": "sträckläsande",
    "sträckläsandets": "sträckläsande",
    "sträckläsas": "sträckläsa",
    "sträckläser": "sträckläsa",
    "sträckläses": "sträckläsa",
    "sträckläst": "sträckläsa",
    "sträcklästa": "sträckläsa",
    "sträcklästas": "sträckläsa",
    "sträckläste": "sträckläsa",
    "sträcklästes": "sträckläsa",
    "sträcklästs": "sträckläsa",
    "sträckningar": "sträckning",
    "sträckningarna": "sträckning",
    "sträckningarnas": "sträckning",
    "sträckningars": "sträckning",
    "sträckningen": "sträckning",
    "sträckningens": "sträckning",
    "sträcknings": "sträckning",
    "sträckor": "sträcka",
    "sträckorna": "sträcka",
    "sträckornas": "sträcka",
    "sträckors": "sträcka",
    "sträcks": "sträcka",
    "sträckt": "sträcka",
    "sträckta": "sträcka",
    "sträcktas": "sträcka",
    "sträckte": "sträcka",
    "sträcktes": "sträcka",
    "sträckts": "sträcka",
    "stränder": "strand",
    "stränderna": "strand",
    "strändernas": "strand",
    "stränders": "strand",
    "sträng": "stränga",
    "stränga": "sträng",
    "strängad": "stränga",
    "strängade": "stränga",
    "strängades": "stränga",
    "strängads": "stränga",
    "strängande": "stränga",
    "stränganden": "strängande",
    "strängandena": "strängande",
    "strängandenas": "strängande",
    "strängandens": "strängande",
    "strängandes": "strängande",
    "strängandet": "strängande",
    "strängandets": "strängande",
    "strängar": "stränga",
    "strängare": "sträng",
    "strängares": "sträng",
    "strängarna": "sträng",
    "strängarnas": "sträng",
    "strängars": "sträng",
    "strängas": "stränga",
    "strängast": "sträng",
    "strängaste": "sträng",
    "strängastes": "sträng",
    "strängasts": "sträng",
    "strängat": "stränga",
    "strängats": "stränga",
    "stränge": "sträng",
    "strängen": "sträng",
    "strängens": "sträng",
    "stränges": "sträng",
    "strängheten": "stränghet",
    "stränghetens": "stränghet",
    "stränghets": "stränghet",
    "stränginstrumenten": "stränginstrument",
    "stränginstrumentens": "stränginstrument",
    "stränginstrumentet": "stränginstrument",
    "stränginstrumentets": "stränginstrument",
    "stränginstruments": "stränginstrument",
    "strängt": "sträng",
    "strängts": "sträng",
    "sträv": "sträva",
    "sträva": "sträv",
    "strävad": "sträva",
    "strävade": "sträva",
    "strävades": "sträva",
    "strävads": "sträva",
    "strävan": "sträva",
    "strävande": "sträva",
    "strävanden": "strävande",
    "strävandena": "strävande",
    "strävandenas": "strävande",
    "strävandens": "strävande",
    "strävandes": "strävande",
    "strävandet": "strävande",
    "strävandets": "strävande",
    "strävans": "strävan",
    "strävar": "sträva",
    "strävare": "sträv",
    "strävares": "sträv",
    "strävas": "sträva",
    "strävast": "sträv",
    "strävaste": "sträv",
    "strävastes": "sträv",
    "strävasts": "sträv",
    "strävat": "sträva",
    "strävats": "sträva",
    "strävbåg": "strävbåge",
    "strävbågar": "strävbåge",
    "strävbågarna": "strävbåge",
    "strävbågarnas": "strävbåge",
    "strävbågars": "strävbåge",
    "strävbågen": "strävbåge",
    "strävbågens": "strävbåge",
    "strävbåges": "strävbåge",
    "strävbågs": "strävbåge",
    "sträve": "sträva",
    "sträves": "sträv",
    "strävheten": "strävhet",
    "strävhetens": "strävhet",
    "strävhets": "strävhet",
    "strävhåriga": "strävhårig",
    "strävhårigare": "strävhårig",
    "strävhårigares": "strävhårig",
    "strävhårigas": "strävhårig",
    "strävhårigast": "strävhårig",
    "strävhårigaste": "strävhårig",
    "strävhårigastes": "strävhårig",
    "strävhårigasts": "strävhårig",
    "strävhårige": "strävhårig",
    "strävhåriges": "strävhårig",
    "strävhårigheten": "strävhårighet",
    "strävhårighetens": "strävhårighet",
    "strävhårighets": "strävhårighet",
    "strävhårigs": "strävhårig",
    "strävhårigt": "strävhårig",
    "strävhårigts": "strävhårig",
    "sträviga": "strävig",
    "strävigare": "strävig",
    "strävigares": "strävig",
    "strävigas": "strävig",
    "strävigast": "strävig",
    "strävigaste": "strävig",
    "strävigastes": "strävig",
    "strävigasts": "strävig",
    "strävige": "strävig",
    "sträviges": "strävig",
    "strävigs": "strävig",
    "strävigt": "strävig",
    "strävigts": "strävig",
    "strävor": "sträva",
    "strävorna": "sträva",
    "strävornas": "sträva",
    "strävors": "sträva",
    "strävpelar": "strävpelare",
    "strävpelaren": "strävpelare",
    "strävpelarens": "strävpelare",
    "strävpelares": "strävpelare",
    "strävpelarna": "strävpelare",
    "strävpelarnas": "strävpelare",
    "strävs": "sträva",
    "strävsamheten": "strävsamhet",
    "strävsamhetens": "strävsamhet",
    "strävsamhets": "strävsamhet",
    "strävsamma": "strävsam",
    "strävsammare": "strävsam",
    "strävsammares": "strävsam",
    "strävsammas": "strävsam",
    "strävsammast": "strävsam",
    "strävsammaste": "strävsam",
    "strävsammastes": "strävsam",
    "strävsammasts": "strävsam",
    "strävsamme": "strävsam",
    "strävsammes": "strävsam",
    "strävsams": "strävsam",
    "strävsamt": "strävsam",
    "strävsamts": "strävsam",
    "strävt": "sträv",
    "strävts": "sträv",
    "stråbassjukdomar": "stråbassjukdom",
    "stråbassjukdomarna": "stråbassjukdom",
    "stråbassjukdomarnas": "stråbassjukdom",
    "stråbassjukdomars": "stråbassjukdom",
    "stråbassjukdomen": "stråbassjukdom",
    "stråbassjukdomens": "stråbassjukdom",
    "stråbassjukdoms": "stråbassjukdom",
    "strådöden": "strådöd",
    "strådödens": "strådöd",
    "strådöds": "strådöd",
    "strået": "strå",
    "stråets": "strå",
    "stråfoders": "stråfoder",
    "stråfodret": "stråfoder",
    "stråfodrets": "stråfoder",
    "stråhattar": "stråhatt",
    "stråhattarna": "stråhatt",
    "stråhattarnas": "stråhatt",
    "stråhattars": "stråhatt",
    "stråhatten": "stråhatt",
    "stråhattens": "stråhatt",
    "stråhatts": "stråhatt",
    "stråk": "stråke",
    "stråkar": "stråke",
    "stråkarna": "stråke",
    "stråkarnas": "stråke",
    "stråkars": "stråke",
    "stråkdragen": "stråkdrag",
    "stråkdragens": "stråkdrag",
    "stråkdraget": "stråkdrag",
    "stråkdragets": "stråkdrag",
    "stråkdrags": "stråkdrag",
    "stråken": "stråke",
    "stråkens": "stråke",
    "stråkes": "stråke",
    "stråket": "stråk",
    "stråkets": "stråk",
    "stråkinstrumenten": "stråkinstrument",
    "stråkinstrumentens": "stråkinstrument",
    "stråkinstrumentet": "stråkinstrument",
    "stråkinstrumentets": "stråkinstrument",
    "stråkinstruments": "stråkinstrument",
    "stråkkvartetten": "stråkkvartett",
    "stråkkvartettens": "stråkkvartett",
    "stråkkvartetter": "stråkkvartett",
    "stråkkvartetterna": "stråkkvartett",
    "stråkkvartetternas": "stråkkvartett",
    "stråkkvartetters": "stråkkvartett",
    "stråkkvartetts": "stråkkvartett",
    "stråks": "stråke",
    "strål": "stråle",
    "strålad": "stråla",
    "strålade": "stråla",
    "strålades": "stråla",
    "strålads": "stråla",
    "strålande": "stråla",
    "strålanden": "strålande",
    "strålandena": "strålande",
    "strålandenas": "strålande",
    "strålandens": "strålande",
    "strålandes": "strålande",
    "strålandet": "strålande",
    "strålandets": "strålande",
    "strålar": "stråle",
    "strålarna": "stråle",
    "strålarnas": "stråle",
    "strålars": "stråle",
    "strålas": "stråla",
    "strålat": "stråla",
    "strålats": "stråla",
    "strålbehandlingar": "strålbehandling",
    "strålbehandlingarna": "strålbehandling",
    "strålbehandlingarnas": "strålbehandling",
    "strålbehandlingars": "strålbehandling",
    "strålbehandlingen": "strålbehandling",
    "strålbehandlingens": "strålbehandling",
    "strålbehandlings": "strålbehandling",
    "strålbenen": "strålben",
    "strålbenens": "strålben",
    "strålbenet": "strålben",
    "strålbenets": "strålben",
    "strålbens": "strålben",
    "strålblom": "strålblomma",
    "strålblomman": "strålblomma",
    "strålblommans": "strålblomma",
    "strålblommas": "strålblomma",
    "strålblomme": "strålblomma",
    "strålblommor": "strålblomma",
    "strålblommorna": "strålblomma",
    "strålblommornas": "strålblomma",
    "strålblommors": "strålblomma",
    "strålbloms": "strålblomma",
    "stråldjuren": "stråldjur",
    "stråldjurens": "stråldjur",
    "stråldjuret": "stråldjur",
    "stråldjurets": "stråldjur",
    "stråldjurs": "stråldjur",
    "stråldosen": "stråldos",
    "stråldosens": "stråldos",
    "stråldoser": "stråldos",
    "stråldoserna": "stråldos",
    "stråldosernas": "stråldos",
    "stråldosers": "stråldos",
    "strålen": "stråle",
    "strålens": "stråle",
    "stråles": "stråle",
    "strålfeniga": "strålfenig",
    "strålfenigare": "strålfenig",
    "strålfenigares": "strålfenig",
    "strålfenigas": "strålfenig",
    "strålfenigast": "strålfenig",
    "strålfenigaste": "strålfenig",
    "strålfenigastes": "strålfenig",
    "strålfenigasts": "strålfenig",
    "strålfenige": "strålfenig",
    "strålfeniges": "strålfenig",
    "strålfenigs": "strålfenig",
    "strålfenigt": "strålfenig",
    "strålfenigts": "strålfenig",
    "strålglansen": "strålglans",
    "strålglansens": "strålglans",
    "strålgångsmätar": "strålgångsmätare",
    "strålgångsmätaren": "strålgångsmätare",
    "strålgångsmätarens": "strålgångsmätare",
    "strålgångsmätares": "strålgångsmätare",
    "strålgångsmätarna": "strålgångsmätare",
    "strålgångsmätarnas": "strålgångsmätare",
    "strålkastar": "strålkastare",
    "strålkastaren": "strålkastare",
    "strålkastarens": "strålkastare",
    "strålkastares": "strålkastare",
    "strålkastarljusen": "strålkastarljus",
    "strålkastarljusens": "strålkastarljus",
    "strålkastarljuset": "strålkastarljus",
    "strålkastarljusets": "strålkastarljus",
    "strålkastarna": "strålkastare",
    "strålkastarnas": "strålkastare",
    "strålknipp": "strålknippe",
    "strålknippen": "strålknippe",
    "strålknippena": "strålknippe",
    "strålknippenas": "strålknippe",
    "strålknippens": "strålknippe",
    "strålknippes": "strålknippe",
    "strålknippet": "strålknippe",
    "strålknippets": "strålknippe",
    "strålknipps": "strålknippe",
    "strålknivar": "strålkniv",
    "strålknivarna": "strålkniv",
    "strålknivarnas": "strålkniv",
    "strålknivars": "strålkniv",
    "strålkniven": "strålkniv",
    "strålknivens": "strålkniv",
    "strålknivs": "strålkniv",
    "strålkonserverad": "strålkonservera",
    "strålkonserverade": "strålkonservera",
    "strålkonserverades": "strålkonservera",
    "strålkonserverads": "strålkonservera",
    "strålkonserverande": "strålkonservera",
    "strålkonserveranden": "strålkonserverande",
    "strålkonserverandena": "strålkonserverande",
    "strålkonserverandenas": "strålkonserverande",
    "strålkonserverandens": "strålkonserverande",
    "strålkonserverandes": "strålkonserverande",
    "strålkonserverandet": "strålkonserverande",
    "strålkonserverandets": "strålkonserverande",
    "strålkonserverar": "strålkonservera",
    "strålkonserveras": "strålkonservera",
    "strålkonserverat": "strålkonservera",
    "strålkonserverats": "strålkonservera",
    "strålkonserverbara": "strålkonserverbar",
    "strålkonserverbarare": "strålkonserverbar",
    "strålkonserverbarares": "strålkonserverbar",
    "strålkonserverbaras": "strålkonserverbar",
    "strålkonserverbarast": "strålkonserverbar",
    "strålkonserverbaraste": "strålkonserverbar",
    "strålkonserverbarastes": "strålkonserverbar",
    "strålkonserverbarasts": "strålkonserverbar",
    "strålkonserverbare": "strålkonserverbar",
    "strålkonserverbares": "strålkonserverbar",
    "strålkonserverbarheten": "strålkonserverbarhet",
    "strålkonserverbarhetens": "strålkonserverbarhet",
    "strålkonserverbarhets": "strålkonserverbarhet",
    "strålkonserverbars": "strålkonserverbar",
    "strålkonserverbart": "strålkonserverbar",
    "strålkonserverbarts": "strålkonserverbar",
    "strålkonserveringar": "strålkonservering",
    "strålkonserveringarna": "strålkonservering",
    "strålkonserveringarnas": "strålkonservering",
    "strålkonserveringars": "strålkonservering",
    "strålkonserveringen": "strålkonservering",
    "strålkonserveringens": "strålkonservering",
    "strålkonserverings": "strålkonservering",
    "strålkroppar": "strålkropp",
    "strålkropparna": "strålkropp",
    "strålkropparnas": "strålkropp",
    "strålkroppars": "strålkropp",
    "strålkroppen": "strålkropp",
    "strålkroppens": "strålkropp",
    "strålkropps": "strålkropp",
    "strålningar": "strålning",
    "strålningarna": "strålning",
    "strålningarnas": "strålning",
    "strålningars": "strålning",
    "strålningen": "strålning",
    "strålningens": "strålning",
    "strålnings": "strålning",
    "strålningsarbeten": "strålningsarbete",
    "strålningsarbetena": "strålningsarbete",
    "strålningsarbetenas": "strålningsarbete",
    "strålningsarbetens": "strålningsarbete",
    "strålningsarbetes": "strålningsarbete",
    "strålningsarbetet": "strålningsarbete",
    "strålningsarbetets": "strålningsarbete",
    "strålningsarbets": "strålningsarbete",
    "strålningsbiologien": "strålningsbiologi",
    "strålningsbiologiens": "strålningsbiologi",
    "strålningsbiologin": "strålningsbiologi",
    "strålningsbiologins": "strålningsbiologi",
    "strålningsbiologis": "strålningsbiologi",
    "strålningsbälten": "strålningsbälte",
    "strålningsbältena": "strålningsbälte",
    "strålningsbältenas": "strålningsbälte",
    "strålningsbältens": "strålningsbälte",
    "strålningsbältes": "strålningsbälte",
    "strålningsbältet": "strålningsbälte",
    "strålningsbältets": "strålningsbälte",
    "strålningsdosen": "strålningsdos",
    "strålningsdosens": "strålningsdos",
    "strålningsdoser": "strålningsdos",
    "strålningsdoserna": "strålningsdos",
    "strålningsdosernas": "strålningsdos",
    "strålningsdosers": "strålningsdos",
    "strålningseffekten": "strålningseffekt",
    "strålningseffektens": "strålningseffekt",
    "strålningseffekter": "strålningseffekt",
    "strålningseffekterna": "strålningseffekt",
    "strålningseffekternas": "strålningseffekt",
    "strålningseffekters": "strålningseffekt",
    "strålningseffekts": "strålningseffekt",
    "strålningsegenskapen": "strålningsegenskap",
    "strålningsegenskapens": "strålningsegenskap",
    "strålningsegenskaper": "strålningsegenskap",
    "strålningsegenskaperna": "strålningsegenskap",
    "strålningsegenskapernas": "strålningsegenskap",
    "strålningsegenskapers": "strålningsegenskap",
    "strålningsegenskaps": "strålningsegenskap",
    "strålningser": "strålningsera",
    "strålningseran": "strålningsera",
    "strålningserans": "strålningsera",
    "strålningseras": "strålningsera",
    "strålningsere": "strålningsera",
    "strålningseror": "strålningsera",
    "strålningserorna": "strålningsera",
    "strålningserornas": "strålningsera",
    "strålningserors": "strålningsera",
    "strålningsers": "strålningsera",
    "strålningskemien": "strålningskemi",
    "strålningskemiens": "strålningskemi",
    "strålningskemin": "strålningskemi",
    "strålningskemins": "strålningskemi",
    "strålningskemis": "strålningskemi",
    "strålningskommittéer": "strålningskommitté",
    "strålningskommittéerna": "strålningskommitté",
    "strålningskommittéernas": "strålningskommitté",
    "strålningskommittéers": "strålningskommitté",
    "strålningskommittén": "strålningskommitté",
    "strålningskommitténs": "strålningskommitté",
    "strålningskommittés": "strålningskommitté",
    "strålningskvanta": "strålningskvantum",
    "strålningskvantana": "strålningskvantum",
    "strålningskvantanas": "strålningskvantum",
    "strålningskvantas": "strålningskvantum",
    "strålningskvantumen": "strålningskvantum",
    "strålningskvantumens": "strålningskvantum",
    "strålningskvantumet": "strålningskvantum",
    "strålningskvantumets": "strålningskvantum",
    "strålningskvantums": "strålningskvantum",
    "strålningsspektra": "strålningsspektrum",
    "strålningsspektrana": "strålningsspektrum",
    "strålningsspektranas": "strålningsspektrum",
    "strålningsspektras": "strålningsspektrum",
    "strålningsspektrena": "strålningsspektrum",
    "strålningsspektrenas": "strålningsspektrum",
    "strålningsspektrer": "strålningsspektrum",
    "strålningsspektrers": "strålningsspektrum",
    "strålningsspektret": "strålningsspektrum",
    "strålningsspektrets": "strålningsspektrum",
    "strålningsspektrumen": "strålningsspektrum",
    "strålningsspektrumens": "strålningsspektrum",
    "strålningsspektrumet": "strålningsspektrum",
    "strålningsspektrumets": "strålningsspektrum",
    "strålningsspektrums": "strålningsspektrum",
    "strålningssäkerheten": "strålningssäkerhet",
    "strålningssäkerhetens": "strålningssäkerhet",
    "strålningssäkerhets": "strålningssäkerhet",
    "strålningssäkers": "strålningssäker",
    "strålningssäkert": "strålningssäker",
    "strålningssäkerts": "strålningssäker",
    "strålningssäkra": "strålningssäker",
    "strålningssäkrare": "strålningssäker",
    "strålningssäkrares": "strålningssäker",
    "strålningssäkras": "strålningssäker",
    "strålningssäkrast": "strålningssäker",
    "strålningssäkraste": "strålningssäker",
    "strålningssäkrastes": "strålningssäker",
    "strålningssäkrasts": "strålningssäker",
    "strålningssäkre": "strålningssäker",
    "strålningssäkres": "strålningssäker",
    "strålningstrycket": "strålningstryck",
    "strålningstryckets": "strålningstryck",
    "strålningstrycks": "strålningstryck",
    "strålorsakade": "strålorsakad",
    "strålorsakades": "strålorsakad",
    "strålorsakads": "strålorsakad",
    "strålorsakat": "strålorsakad",
    "strålorsakats": "strålorsakad",
    "strålput": "strålputa",
    "strålputan": "strålputa",
    "strålputans": "strålputa",
    "strålputas": "strålputa",
    "strålpute": "strålputa",
    "strålputor": "strålputa",
    "strålputorna": "strålputa",
    "strålputornas": "strålputa",
    "strålputors": "strålputa",
    "strålputs": "strålputa",
    "strålrisken": "strålrisk",
    "strålriskens": "strålrisk",
    "strålrisker": "strålrisk",
    "strålriskerna": "strålrisk",
    "strålriskernas": "strålrisk",
    "strålriskers": "strålrisk",
    "strålrisks": "strålrisk",
    "stråls": "stråle",
    "strålsjukan": "strålsjuka",
    "strålsjukans": "strålsjuka",
    "strålsjukas": "strålsjuka",
    "strålsjuke": "strålsjuka",
    "strålsjuks": "strålsjuka",
    "strålskadan": "strålskada",
    "strålskadans": "strålskada",
    "strålskadas": "strålskada",
    "strålskade": "strålskada",
    "strålskador": "strålskada",
    "strålskadorna": "strålskada",
    "strålskadornas": "strålskada",
    "strålskadors": "strålskada",
    "strålskyddet": "strålskydd",
    "strålskyddets": "strålskydd",
    "strålskydds": "strålskydd",
    "strålskyddsarbeten": "strålskyddsarbete",
    "strålskyddsarbetena": "strålskyddsarbete",
    "strålskyddsarbetenas": "strålskyddsarbete",
    "strålskyddsarbetens": "strålskyddsarbete",
    "strålskyddsarbetes": "strålskyddsarbete",
    "strålskyddsarbetet": "strålskyddsarbete",
    "strålskyddsarbetets": "strålskyddsarbete",
    "strålskyddsarbets": "strålskyddsarbete",
    "strålskyddsinstituten": "strålskyddsinstitut",
    "strålskyddsinstitutens": "strålskyddsinstitut",
    "strålskyddsinstitutet": "strålskyddsinstitut",
    "strålskyddsinstitutets": "strålskyddsinstitut",
    "strålskyddsinstituts": "strålskyddsinstitut",
    "strålsvampen": "strålsvamp",
    "strålsvampens": "strålsvamp",
    "strålsvamps": "strålsvamp",
    "stråmatt": "stråmatta",
    "stråmattan": "stråmatta",
    "stråmattans": "stråmatta",
    "stråmattas": "stråmatta",
    "stråmatte": "stråmatta",
    "stråmattor": "stråmatta",
    "stråmattorna": "stråmatta",
    "stråmattornas": "stråmatta",
    "stråmattors": "stråmatta",
    "stråmatts": "stråmatta",
    "strån": "strå",
    "stråna": "strå",
    "strånas": "strå",
    "stråns": "strå",
    "strårötan": "stråröta",
    "strårötans": "stråröta",
    "strårötas": "stråröta",
    "stråröte": "stråröta",
    "strås": "strå",
    "stråsäden": "stråsäd",
    "stråsädens": "stråsäd",
    "stråsädes": "stråsäd",
    "stråsäds": "stråsäd",
    "stråt": "strå",
    "stråten": "stråt",
    "stråtens": "stråt",
    "stråtrövar": "stråtrövare",
    "stråtrövaren": "stråtrövare",
    "stråtrövarens": "stråtrövare",
    "stråtrövares": "stråtrövare",
    "stråtrövarna": "stråtrövare",
    "stråtrövarnas": "stråtrövare",
    "stråts": "stråt",
    "ströar": "ströare",
    "ströaren": "ströare",
    "ströarens": "ströare",
    "ströares": "ströare",
    "ströarna": "ströare",
    "ströarnas": "ströare",
    "ströbrödet": "ströbröd",
    "ströbrödets": "ströbröd",
    "ströbröds": "ströbröd",
    "strödd": "strö",
    "strödda": "strö",
    "ströddas": "strö",
    "strödde": "strö",
    "ströddes": "strö",
    "strödds": "strö",
    "ströende": "strö",
    "ströenden": "ströende",
    "ströendena": "ströende",
    "ströendenas": "ströende",
    "ströendens": "ströende",
    "ströendes": "ströende",
    "ströendet": "ströende",
    "ströendets": "ströende",
    "ströet": "strö",
    "ströets": "strö",
    "strögen": "strög",
    "strögens": "strög",
    "ströget": "strög",
    "strögets": "strög",
    "strögs": "strög",
    "ströjobben": "ströjobb",
    "ströjobbens": "ströjobb",
    "ströjobbet": "ströjobb",
    "ströjobbets": "ströjobb",
    "ströjobbs": "ströjobb",
    "strök": "stryka",
    "ströke": "stryka",
    "strökes": "stryka",
    "ströks": "stryka",
    "strökunden": "strökund",
    "strökundens": "strökund",
    "strökunder": "strökund",
    "strökunderna": "strökund",
    "strökundernas": "strökund",
    "strökunders": "strökund",
    "strökunds": "strökund",
    "strökursen": "strökurs",
    "strökursens": "strökurs",
    "strökurser": "strökurs",
    "strökurserna": "strökurs",
    "strökursernas": "strökurs",
    "strökursers": "strökurs",
    "ströma": "ström",
    "strömare": "ström",
    "strömares": "ström",
    "strömas": "ström",
    "strömast": "ström",
    "strömaste": "ström",
    "strömastes": "ström",
    "strömasts": "ström",
    "strömavbrotten": "strömavbrott",
    "strömavbrottens": "strömavbrott",
    "strömavbrottet": "strömavbrott",
    "strömavbrottets": "strömavbrott",
    "strömavbrotts": "strömavbrott",
    "strömavtagar": "strömavtagare",
    "strömavtagaren": "strömavtagare",
    "strömavtagarens": "strömavtagare",
    "strömavtagares": "strömavtagare",
    "strömavtagarna": "strömavtagare",
    "strömavtagarnas": "strömavtagare",
    "strömbrytar": "strömbrytare",
    "strömbrytaren": "strömbrytare",
    "strömbrytarens": "strömbrytare",
    "strömbrytares": "strömbrytare",
    "strömbrytarna": "strömbrytare",
    "strömbrytarnas": "strömbrytare",
    "ströme": "ström",
    "strömes": "ström",
    "strömfår": "strömfåra",
    "strömfåran": "strömfåra",
    "strömfårans": "strömfåra",
    "strömfåras": "strömfåra",
    "strömfåre": "strömfåra",
    "strömfåror": "strömfåra",
    "strömfårorna": "strömfåra",
    "strömfårornas": "strömfåra",
    "strömfårors": "strömfåra",
    "strömfårs": "strömfåra",
    "strömförträngningar": "strömförträngning",
    "strömförträngningarna": "strömförträngning",
    "strömförträngningarnas": "strömförträngning",
    "strömförträngningars": "strömförträngning",
    "strömförträngningen": "strömförträngning",
    "strömförträngningens": "strömförträngning",
    "strömförträngnings": "strömförträngning",
    "strömhoppen": "strömhopp",
    "strömhoppens": "strömhopp",
    "strömhoppet": "strömhopp",
    "strömhoppets": "strömhopp",
    "strömhopps": "strömhopp",
    "strömhppen": "strömhopp",
    "strömhppens": "strömhopp",
    "strömhppet": "strömhopp",
    "strömhppets": "strömhopp",
    "strömkantringar": "strömkantring",
    "strömkantringarna": "strömkantring",
    "strömkantringarnas": "strömkantring",
    "strömkantringars": "strömkantring",
    "strömkantringen": "strömkantring",
    "strömkantringens": "strömkantring",
    "strömkantrings": "strömkantring",
    "strömkarlen": "strömkarl",
    "strömkarlens": "strömkarl",
    "strömkarls": "strömkarl",
    "strömkretsar": "strömkrets",
    "strömkretsarna": "strömkrets",
    "strömkretsarnas": "strömkrets",
    "strömkretsars": "strömkrets",
    "strömkretsen": "strömkrets",
    "strömkretsens": "strömkrets",
    "strömkäll": "strömkälla",
    "strömkällan": "strömkälla",
    "strömkällans": "strömkälla",
    "strömkällas": "strömkälla",
    "strömkälle": "strömkälla",
    "strömkällor": "strömkälla",
    "strömkällorna": "strömkälla",
    "strömkällornas": "strömkälla",
    "strömkällors": "strömkälla",
    "strömkälls": "strömkälla",
    "strömledningar": "strömledning",
    "strömledningarna": "strömledning",
    "strömledningarnas": "strömledning",
    "strömledningars": "strömledning",
    "strömledningen": "strömledning",
    "strömledningens": "strömledning",
    "strömlednings": "strömledning",
    "strömlinjeformade": "strömlinjeformad",
    "strömlinjeformades": "strömlinjeformad",
    "strömlinjeformads": "strömlinjeformad",
    "strömlinjeformat": "strömlinjeformad",
    "strömlinjeformats": "strömlinjeformad",
    "strömmade": "strömma",
    "strömmades": "strömma",
    "strömmande": "strömma",
    "strömmanden": "strömmande",
    "strömmandena": "strömmande",
    "strömmandenas": "strömmande",
    "strömmandens": "strömmande",
    "strömmandes": "strömmande",
    "strömmandet": "strömmande",
    "strömmandets": "strömmande",
    "strömmar": "strömma",
    "strömmarna": "ström",
    "strömmarnas": "ström",
    "strömmars": "ström",
    "strömmas": "strömma",
    "strömmat": "strömma",
    "strömmats": "strömma",
    "strömmen": "ström",
    "strömmens": "ström",
    "strömmingar": "strömming",
    "strömmingarna": "strömming",
    "strömmingarnas": "strömming",
    "strömmingars": "strömming",
    "strömmingen": "strömming",
    "strömmingens": "strömming",
    "strömmings": "strömming",
    "strömmingsfiléer": "strömmingsfilé",
    "strömmingsfiléerna": "strömmingsfilé",
    "strömmingsfiléernas": "strömmingsfilé",
    "strömmingsfiléers": "strömmingsfilé",
    "strömmingsfilén": "strömmingsfilé",
    "strömmingsfiléns": "strömmingsfilé",
    "strömmingsfilés": "strömmingsfilé",
    "strömmingsfiskes": "strömmingsfiske",
    "strömmingsfisket": "strömmingsfiske",
    "strömmingsfiskets": "strömmingsfiske",
    "strömmingsflundran": "strömmingsflundra",
    "strömmingsflundrans": "strömmingsflundra",
    "strömmingsflundras": "strömmingsflundra",
    "strömmingsflundre": "strömmingsflundra",
    "strömmingsflundror": "strömmingsflundra",
    "strömmingsflundrorna": "strömmingsflundra",
    "strömmingsflundrornas": "strömmingsflundra",
    "strömmingsflundrors": "strömmingsflundra",
    "strömmätar": "strömmätare",
    "strömmätaren": "strömmätare",
    "strömmätarens": "strömmätare",
    "strömmätares": "strömmätare",
    "strömmätarna": "strömmätare",
    "strömmätarnas": "strömmätare",
    "strömningar": "strömning",
    "strömningarna": "strömning",
    "strömningarnas": "strömning",
    "strömningars": "strömning",
    "strömningen": "strömning",
    "strömningens": "strömning",
    "strömnings": "strömning",
    "strömningsmotståndet": "strömningsmotstånd",
    "strömningsmotståndets": "strömningsmotstånd",
    "strömningsmotstånds": "strömningsmotstånd",
    "strömringar": "strömring",
    "strömringarna": "strömring",
    "strömringarnas": "strömring",
    "strömringars": "strömring",
    "strömringen": "strömring",
    "strömringens": "strömring",
    "strömrings": "strömring",
    "ströms": "ström",
    "strömstar": "strömstare",
    "strömstarar": "strömstare",
    "strömstararna": "strömstare",
    "strömstararnas": "strömstare",
    "strömstarars": "strömstare",
    "strömstaren": "strömstare",
    "strömstarens": "strömstare",
    "strömstares": "strömstare",
    "strömstars": "strömstare",
    "strömstyrkan": "strömstyrka",
    "strömstyrkans": "strömstyrka",
    "strömstyrkas": "strömstyrka",
    "strömstyrke": "strömstyrka",
    "strömstyrkor": "strömstyrka",
    "strömstyrkorna": "strömstyrka",
    "strömstyrkornas": "strömstyrka",
    "strömstyrkors": "strömstyrka",
    "strömställar": "strömställare",
    "strömställaren": "strömställare",
    "strömställarens": "strömställare",
    "strömställares": "strömställare",
    "strömställarna": "strömställare",
    "strömställarnas": "strömställare",
    "strömt": "ström",
    "strömts": "ström",
    "strömuttagen": "strömuttag",
    "strömuttagens": "strömuttag",
    "strömuttaget": "strömuttag",
    "strömuttagets": "strömuttag",
    "strömuttags": "strömuttag",
    "strömvirveln": "strömvirvel",
    "strömvirvelns": "strömvirvel",
    "strömvirvels": "strömvirvel",
    "strömvirvlar": "strömvirvel",
    "strömvirvlarna": "strömvirvel",
    "strömvirvlarnas": "strömvirvel",
    "strömvirvlars": "strömvirvel",
    "strömvärmen": "strömvärme",
    "strömvärmens": "strömvärme",
    "strömvärmes": "strömvärme",
    "strömvärmet": "strömvärme",
    "strömvärmets": "strömvärme",
    "ströp": "strypa",
    "ströpe": "strypa",
    "ströpes": "strypa",
    "ströppel": "ströppla",
    "ströpplad": "ströppla",
    "ströpplade": "ströppla",
    "ströpplades": "ströppla",
    "ströpplads": "ströppla",
    "ströpplande": "ströppla",
    "ströpplanden": "ströpplande",
    "ströpplandena": "ströpplande",
    "ströpplandenas": "ströpplande",
    "ströpplandens": "ströpplande",
    "ströpplandes": "ströpplande",
    "ströpplandet": "ströpplande",
    "ströpplandets": "ströpplande",
    "ströpplar": "ströppla",
    "ströpplas": "ströppla",
    "ströpplat": "ströppla",
    "ströpplats": "ströppla",
    "ströps": "strypa",
    "strör": "strö",
    "strös": "strö",
    "strösockers": "strösocker",
    "strösockret": "strösocker",
    "strösockrets": "strösocker",
    "strösseln": "strössel",
    "strösselns": "strössel",
    "strössels": "strössel",
    "strösslet": "strössel",
    "strösslets": "strössel",
    "ströt": "strö",
    "ströts": "strö",
    "strött": "strö",
    "strötts": "strö",
    "ströv": "ströva",
    "strövad": "ströva",
    "strövade": "ströva",
    "strövades": "ströva",
    "strövads": "ströva",
    "strövande": "ströva",
    "strövanden": "strövande",
    "strövandena": "strövande",
    "strövandenas": "strövande",
    "strövandens": "strövande",
    "strövandes": "strövande",
    "strövandet": "strövande",
    "strövandets": "strövande",
    "strövar": "ströva",
    "strövas": "ströva",
    "strövat": "ströva",
    "strövats": "ströva",
    "strövområden": "strövområde",
    "strövområdena": "strövområde",
    "strövområdenas": "strövområde",
    "strövområdens": "strövområde",
    "strövområdes": "strövområde",
    "strövområdet": "strövområde",
    "strövområdets": "strövområde",
    "strövtågen": "strövtåg",
    "strövtågens": "strövtåg",
    "strövtåget": "strövtåg",
    "strövtågets": "strövtåg",
    "strövtågs": "strövtåg",
    "stubb": "stubbe",
    "stubbad": "stubba",
    "stubbade": "stubba",
    "stubbades": "stubba",
    "stubbads": "stubba",
    "stubbande": "stubba",
    "stubbanden": "stubbande",
    "stubbandena": "stubbande",
    "stubbandenas": "stubbande",
    "stubbandens": "stubbande",
    "stubbandes": "stubbande",
    "stubbandet": "stubbande",
    "stubbandets": "stubbande",
    "stubbar": "stubbe",
    "stubbarna": "stubbe",
    "stubbarnas": "stubbe",
    "stubbars": "stubbe",
    "stubbas": "stubba",
    "stubbat": "stubba",
    "stubbats": "stubba",
    "stubben": "stubbe",
    "stubbens": "stubbe",
    "stubbes": "stubbe",
    "stubbiga": "stubbig",
    "stubbigare": "stubbig",
    "stubbigares": "stubbig",
    "stubbigas": "stubbig",
    "stubbigast": "stubbig",
    "stubbigaste": "stubbig",
    "stubbigastes": "stubbig",
    "stubbigasts": "stubbig",
    "stubbige": "stubbig",
    "stubbiges": "stubbig",
    "stubbigheten": "stubbighet",
    "stubbighetens": "stubbighet",
    "stubbighets": "stubbighet",
    "stubbigs": "stubbig",
    "stubbigt": "stubbig",
    "stubbigts": "stubbig",
    "stubbs": "stubbe",
    "stubinen": "stubin",
    "stubinens": "stubin",
    "stubiner": "stubin",
    "stubinerna": "stubin",
    "stubinernas": "stubin",
    "stubiners": "stubin",
    "stubins": "stubin",
    "stuckaturen": "stuckatur",
    "stuckaturens": "stuckatur",
    "stuckaturer": "stuckatur",
    "stuckaturerna": "stuckatur",
    "stuckaturernas": "stuckatur",
    "stuckaturers": "stuckatur",
    "stuckaturs": "stuckatur",
    "stuckatören": "stuckatör",
    "stuckatörens": "stuckatör",
    "stuckatörer": "stuckatör",
    "stuckatörerna": "stuckatör",
    "stuckatörernas": "stuckatör",
    "stuckatörers": "stuckatör",
    "stuckatörs": "stuckatör",
    "stucke": "sticka",
    "stucken": "stuck",
    "stuckens": "stucken",
    "stucker": "stuck",
    "stuckerna": "stuck",
    "stuckernas": "stuck",
    "stuckers": "stuck",
    "stuckes": "sticka",
    "stucket": "stucken",
    "stuckets": "stucken",
    "stuckit": "sticka",
    "stuckits": "sticka",
    "stuckna": "stucken",
    "stucknare": "stucken",
    "stucknares": "stucken",
    "stucknas": "stucken",
    "stucknast": "stucken",
    "stucknaste": "stucken",
    "stucknastes": "stucken",
    "stucknasts": "stucken",
    "stuckne": "stucken",
    "stucknes": "stucken",
    "stucks": "stuck",
    "studentbetygen": "studentbetyg",
    "studentbetygens": "studentbetyg",
    "studentbetyget": "studentbetyg",
    "studentbetygets": "studentbetyg",
    "studentbetygs": "studentbetyg",
    "studenten": "student",
    "studentens": "student",
    "studenter": "student",
    "studenterna": "student",
    "studenternas": "student",
    "studenters": "student",
    "studentexamens": "studentexamen",
    "studentexamina": "studentexamen",
    "studentexaminas": "studentexamen",
    "studenthemmen": "studenthem",
    "studenthemmens": "studenthem",
    "studenthemmet": "studenthem",
    "studenthemmets": "studenthem",
    "studenthems": "studenthem",
    "studentikosa": "studentikos",
    "studentikosare": "studentikos",
    "studentikosares": "studentikos",
    "studentikosas": "studentikos",
    "studentikosast": "studentikos",
    "studentikosaste": "studentikos",
    "studentikosastes": "studentikos",
    "studentikosasts": "studentikos",
    "studentikose": "studentikos",
    "studentikoses": "studentikos",
    "studentikost": "studentikos",
    "studentikosts": "studentikos",
    "studentinflytanden": "studentinflytande",
    "studentinflytandena": "studentinflytande",
    "studentinflytandenas": "studentinflytande",
    "studentinflytandens": "studentinflytande",
    "studentinflytandes": "studentinflytande",
    "studentinflytandet": "studentinflytande",
    "studentinflytandets": "studentinflytande",
    "studentkåren": "studentkår",
    "studentkårens": "studentkår",
    "studentkårer": "studentkår",
    "studentkårerna": "studentkår",
    "studentkårernas": "studentkår",
    "studentkårers": "studentkår",
    "studentkårs": "studentkår",
    "studentlivet": "studentliv",
    "studentlivets": "studentliv",
    "studentlivs": "studentliv",
    "studentmöss": "studentmössa",
    "studentmössan": "studentmössa",
    "studentmössans": "studentmössa",
    "studentmössas": "studentmössa",
    "studentmösse": "studentmössa",
    "studentmössor": "studentmössa",
    "studentmössorna": "studentmössa",
    "studentmössornas": "studentmössa",
    "studentmössors": "studentmössa",
    "studentnationen": "studentnation",
    "studentnationens": "studentnation",
    "studentnationer": "studentnation",
    "studentnationerna": "studentnation",
    "studentnationernas": "studentnation",
    "studentnationers": "studentnation",
    "studentnations": "studentnation",
    "studentrevolten": "studentrevolt",
    "studentrevoltens": "studentrevolt",
    "studentrevolter": "studentrevolt",
    "studentrevolterna": "studentrevolt",
    "studentrevolternas": "studentrevolt",
    "studentrevolters": "studentrevolt",
    "studentrevolts": "studentrevolt",
    "studentrummen": "studentrum",
    "studentrummens": "studentrum",
    "studentrummet": "studentrum",
    "studentrummets": "studentrum",
    "studentrums": "studentrum",
    "students": "student",
    "studentsången": "studentsång",
    "studentsångens": "studentsång",
    "studentsånger": "studentsång",
    "studentsångerna": "studentsång",
    "studentsångernas": "studentsång",
    "studentsångers": "studentsång",
    "studentsångs": "studentsång",
    "studentteatern": "studentteater",
    "studentteaterns": "studentteater",
    "studentteaters": "studentteater",
    "studentteatrar": "studentteater",
    "studentteatrarna": "studentteater",
    "studentteatrarnas": "studentteater",
    "studentteatrars": "studentteater",
    "studenttillströmningen": "studenttillströmning",
    "studenttillströmningens": "studenttillströmning",
    "studenttillströmnings": "studenttillströmning",
    "studerad": "studera",
    "studerade": "studerad",
    "studerades": "studerad",
    "studerads": "studerad",
    "studerande": "studera",
    "studeranden": "studerande",
    "studerandena": "studerande",
    "studerandenas": "studerande",
    "studerandens": "studerande",
    "studerandes": "studerande",
    "studerandet": "studerande",
    "studerandets": "studerande",
    "studerar": "studera",
    "studeras": "studera",
    "studerat": "studerad",
    "studerats": "studerad",
    "studerbara": "studerbar",
    "studerbarare": "studerbar",
    "studerbarares": "studerbar",
    "studerbaras": "studerbar",
    "studerbarast": "studerbar",
    "studerbaraste": "studerbar",
    "studerbarastes": "studerbar",
    "studerbarasts": "studerbar",
    "studerbare": "studerbar",
    "studerbares": "studerbar",
    "studerbarheten": "studerbarhet",
    "studerbarhetens": "studerbarhet",
    "studerbarhets": "studerbarhet",
    "studerbars": "studerbar",
    "studerbart": "studerbar",
    "studerbarts": "studerbar",
    "studeringar": "studering",
    "studeringarna": "studering",
    "studeringarnas": "studering",
    "studeringars": "studering",
    "studeringen": "studering",
    "studeringens": "studering",
    "studerings": "studering",
    "studerkammar": "studerkammare",
    "studerkammaren": "studerkammare",
    "studerkammarens": "studerkammare",
    "studerkammares": "studerkammare",
    "studerkamrar": "studerkammare",
    "studerkamrarna": "studerkammare",
    "studerkamrarnas": "studerkammare",
    "studerkamrars": "studerkammare",
    "studie": "studium",
    "studiebesöken": "studiebesök",
    "studiebesökens": "studiebesök",
    "studiebesöket": "studiebesök",
    "studiebesökets": "studiebesök",
    "studiebesöks": "studiebesök",
    "studiebidragen": "studiebidrag",
    "studiebidragens": "studiebidrag",
    "studiebidraget": "studiebidrag",
    "studiebidragets": "studiebidrag",
    "studiebidrags": "studiebidrag",
    "studiecirkeln": "studiecirkel",
    "studiecirkelns": "studiecirkel",
    "studiecirkels": "studiecirkel",
    "studiecirklar": "studiecirkel",
    "studiecirklarna": "studiecirkel",
    "studiecirklarnas": "studiecirkel",
    "studiecirklars": "studiecirkel",
    "studiedagar": "studiedag",
    "studiedagarna": "studiedag",
    "studiedagarnas": "studiedag",
    "studiedagars": "studiedag",
    "studiedagen": "studiedag",
    "studiedagens": "studiedag",
    "studiedags": "studiedag",
    "studieförbunden": "studieförbund",
    "studieförbundens": "studieförbund",
    "studieförbundet": "studieförbund",
    "studieförbundets": "studieförbund",
    "studieförbunds": "studieförbund",
    "studiegruppen": "studiegrupp",
    "studiegruppens": "studiegrupp",
    "studiegrupper": "studiegrupp",
    "studiegrupperna": "studiegrupp",
    "studiegruppernas": "studiegrupp",
    "studiegruppers": "studiegrupp",
    "studiegrupps": "studiegrupp",
    "studiehjälpen": "studiehjälp",
    "studiehjälpens": "studiehjälp",
    "studiehjälps": "studiehjälp",
    "studielånen": "studielån",
    "studielånens": "studielån",
    "studielånet": "studielån",
    "studielånets": "studielån",
    "studielåns": "studielån",
    "studiemedels": "studiemedel",
    "studiemedlen": "studiemedel",
    "studiemedlens": "studiemedel",
    "studiemedlet": "studiemedel",
    "studiemedlets": "studiemedel",
    "studiemässiga": "studiemässig",
    "studiemässigare": "studiemässig",
    "studiemässigares": "studiemässig",
    "studiemässigas": "studiemässig",
    "studiemässigast": "studiemässig",
    "studiemässigaste": "studiemässig",
    "studiemässigastes": "studiemässig",
    "studiemässigasts": "studiemässig",
    "studiemässige": "studiemässig",
    "studiemässiges": "studiemässig",
    "studiemässigs": "studiemässig",
    "studiemässigt": "studiemässig",
    "studiemässigts": "studiemässig",
    "studien": "studie",
    "studiens": "studie",
    "studieobjekten": "studieobjekt",
    "studieobjektens": "studieobjekt",
    "studieobjektet": "studieobjekt",
    "studieobjektets": "studieobjekt",
    "studieobjekts": "studieobjekt",
    "studieorienterad": "studieorientera",
    "studieorienterade": "studieorientera",
    "studieorienterades": "studieorientera",
    "studieorienterads": "studieorientera",
    "studieorienterande": "studieorientera",
    "studieorienteranden": "studieorienterande",
    "studieorienterandena": "studieorienterande",
    "studieorienterandenas": "studieorienterande",
    "studieorienterandens": "studieorienterande",
    "studieorienterandes": "studieorienterande",
    "studieorienterandet": "studieorienterande",
    "studieorienterandets": "studieorienterande",
    "studieorienterar": "studieorientera",
    "studieorienteras": "studieorientera",
    "studieorienterat": "studieorientera",
    "studieorienterats": "studieorientera",
    "studieorienterbara": "studieorienterbar",
    "studieorienterbarare": "studieorienterbar",
    "studieorienterbarares": "studieorienterbar",
    "studieorienterbaras": "studieorienterbar",
    "studieorienterbarast": "studieorienterbar",
    "studieorienterbaraste": "studieorienterbar",
    "studieorienterbarastes": "studieorienterbar",
    "studieorienterbarasts": "studieorienterbar",
    "studieorienterbare": "studieorienterbar",
    "studieorienterbares": "studieorienterbar",
    "studieorienterbarheten": "studieorienterbarhet",
    "studieorienterbarhetens": "studieorienterbarhet",
    "studieorienterbarhets": "studieorienterbarhet",
    "studieorienterbars": "studieorienterbar",
    "studieorienterbart": "studieorienterbar",
    "studieorienterbarts": "studieorienterbar",
    "studieorienteringar": "studieorientering",
    "studieorienteringarna": "studieorientering",
    "studieorienteringarnas": "studieorientering",
    "studieorienteringars": "studieorientering",
    "studieorienteringen": "studieorientering",
    "studieorienteringens": "studieorientering",
    "studieorienterings": "studieorientering",
    "studiepenningar": "studiepenning",
    "studiepenningarna": "studiepenning",
    "studiepenningarnas": "studiepenning",
    "studiepenningars": "studiepenning",
    "studiepenningen": "studiepenning",
    "studiepenningens": "studiepenning",
    "studiepennings": "studiepenning",
    "studieplatsen": "studieplats",
    "studieplatsens": "studieplats",
    "studieplatser": "studieplats",
    "studieplatserna": "studieplats",
    "studieplatsernas": "studieplats",
    "studieplatsers": "studieplats",
    "studier": "studium",
    "studierektoren": "studierektor",
    "studierektorens": "studierektor",
    "studierektorer": "studierektor",
    "studierektorerna": "studierektor",
    "studierektorernas": "studierektor",
    "studierektorers": "studierektor",
    "studierektorn": "studierektor",
    "studierektorns": "studierektor",
    "studierektors": "studierektor",
    "studieresan": "studieresa",
    "studieresans": "studieresa",
    "studieresas": "studieresa",
    "studierese": "studieresa",
    "studieresor": "studieresa",
    "studieresorna": "studieresa",
    "studieresornas": "studieresa",
    "studieresors": "studieresa",
    "studierna": "studium",
    "studiernas": "studium",
    "studiers": "studium",
    "studies": "studie",
    "studieskulden": "studieskuld",
    "studieskuldens": "studieskuld",
    "studieskulder": "studieskuld",
    "studieskulderna": "studieskuld",
    "studieskuldernas": "studieskuld",
    "studieskulders": "studieskuld",
    "studieskulds": "studieskuld",
    "studiestödet": "studiestöd",
    "studiestödets": "studiestöd",
    "studiestöds": "studiestöd",
    "studiet": "studium",
    "studietiden": "studietid",
    "studietidens": "studietid",
    "studietider": "studietid",
    "studietiderna": "studietid",
    "studietidernas": "studietid",
    "studietiders": "studietid",
    "studietids": "studietid",
    "studietraditionen": "studietradition",
    "studietraditionens": "studietradition",
    "studietraditioner": "studietradition",
    "studietraditionerna": "studietradition",
    "studietraditionernas": "studietradition",
    "studietraditioners": "studietradition",
    "studietraditions": "studietradition",
    "studiets": "studium",
    "studievägledar": "studievägledare",
    "studievägledaren": "studievägledare",
    "studievägledarens": "studievägledare",
    "studievägledares": "studievägledare",
    "studievägledarna": "studievägledare",
    "studievägledarnas": "studievägledare",
    "studieåren": "studieår",
    "studieårens": "studieår",
    "studieåret": "studieår",
    "studieårets": "studieår",
    "studieårs": "studieår",
    "studiomannen": "studioman",
    "studiomannens": "studioman",
    "studiomans": "studioman",
    "studiomusikern": "studiomusiker",
    "studiomusikerna": "studiomusiker",
    "studiomusikernas": "studiomusiker",
    "studiomusikerns": "studiomusiker",
    "studiomusikers": "studiomusiker",
    "studiomän": "studioman",
    "studiomännen": "studioman",
    "studiomännens": "studioman",
    "studiomäns": "studioman",
    "studiomässiga": "studiomässig",
    "studiomässigare": "studiomässig",
    "studiomässigares": "studiomässig",
    "studiomässigas": "studiomässig",
    "studiomässigast": "studiomässig",
    "studiomässigaste": "studiomässig",
    "studiomässigastes": "studiomässig",
    "studiomässigasts": "studiomässig",
    "studiomässige": "studiomässig",
    "studiomässiges": "studiomässig",
    "studiomässigs": "studiomässig",
    "studiomässigt": "studiomässig",
    "studiomässigts": "studiomässig",
    "studion": "studio",
    "studions": "studio",
    "studior": "studio",
    "studiorna": "studio",
    "studiornas": "studio",
    "studiors": "studio",
    "studios": "studio",
    "studiosamtalen": "studiosamtal",
    "studiosamtalens": "studiosamtal",
    "studiosamtalet": "studiosamtal",
    "studiosamtalets": "studiosamtal",
    "studiosamtals": "studiosamtal",
    "studiosi": "studiosus",
    "studiosina": "studiosus",
    "studiosinas": "studiosus",
    "studiosis": "studiosus",
    "studiums": "studium",
    "studs": "studsa",
    "studsad": "studsa",
    "studsade": "studsa",
    "studsades": "studsa",
    "studsads": "studsa",
    "studsande": "studsa",
    "studsanden": "studsande",
    "studsandena": "studsande",
    "studsandenas": "studsande",
    "studsandens": "studsande",
    "studsandes": "studsande",
    "studsandet": "studsande",
    "studsandets": "studsande",
    "studsar": "studsare",
    "studsaren": "studsare",
    "studsarens": "studsare",
    "studsares": "studsare",
    "studsarna": "studsare",
    "studsarnas": "studsare",
    "studsars": "studs",
    "studsas": "studsa",
    "studsat": "studsa",
    "studsats": "studsa",
    "studsen": "studs",
    "studsens": "studs",
    "studsmatt": "studsmatta",
    "studsmattan": "studsmatta",
    "studsmattans": "studsmatta",
    "studsmattas": "studsmatta",
    "studsmatte": "studsmatta",
    "studsmattor": "studsmatta",
    "studsmattorna": "studsmatta",
    "studsmattornas": "studsmatta",
    "studsmattors": "studsmatta",
    "studsmatts": "studsmatta",
    "stuffen": "stuff",
    "stuffens": "stuff",
    "stuffer": "stuff",
    "stufferna": "stuff",
    "stuffernas": "stuff",
    "stuffers": "stuff",
    "stuffs": "stuff",
    "stug": "stuga",
    "stugan": "stuga",
    "stugans": "stuga",
    "stugas": "stuga",
    "stugbyar": "stugby",
    "stugbyarna": "stugby",
    "stugbyarnas": "stugby",
    "stugbyars": "stugby",
    "stugbyn": "stugby",
    "stugbyns": "stugby",
    "stugbys": "stugby",
    "stugdörrar": "stugdörr",
    "stugdörrarna": "stugdörr",
    "stugdörrarnas": "stugdörr",
    "stugdörrars": "stugdörr",
    "stugdörren": "stugdörr",
    "stugdörrens": "stugdörr",
    "stugdörrs": "stugdörr",
    "stugfönsterna": "stugfönster",
    "stugfönsternas": "stugfönster",
    "stugfönsters": "stugfönster",
    "stugfönstren": "stugfönster",
    "stugfönstrens": "stugfönster",
    "stugfönstret": "stugfönster",
    "stugfönstrets": "stugfönster",
    "stugköpen": "stugköp",
    "stugköpens": "stugköp",
    "stugköpet": "stugköp",
    "stugköpets": "stugköp",
    "stugköps": "stugköp",
    "stugor": "stuga",
    "stugorna": "stuga",
    "stugornas": "stuga",
    "stugors": "stuga",
    "stugsittar": "stugsittare",
    "stugsittaren": "stugsittare",
    "stugsittarens": "stugsittare",
    "stugsittares": "stugsittare",
    "stugsittarna": "stugsittare",
    "stugsittarnas": "stugsittare",
    "stugu": "stuga",
    "stugvärmen": "stugvärme",
    "stugvärmens": "stugvärme",
    "stugvärmes": "stugvärme",
    "stuk": "stuka",
    "stukad": "stuka",
    "stukade": "stuka",
    "stukades": "stuka",
    "stukads": "stuka",
    "stukande": "stuka",
    "stukanden": "stukande",
    "stukandena": "stukande",
    "stukandenas": "stukande",
    "stukandens": "stukande",
    "stukandes": "stukande",
    "stukandet": "stukande",
    "stukandets": "stukande",
    "stukar": "stuka",
    "stukas": "stuka",
    "stukat": "stuka",
    "stukats": "stuka",
    "stule": "stjäla",
    "stulen": "stjäla",
    "stulens": "stjäla",
    "stules": "stjäla",
    "stulet": "stjäla",
    "stulets": "stjäla",
    "stulit": "stjäla",
    "stulits": "stjäla",
    "stulna": "stjäla",
    "stulnas": "stjäla",
    "stulne": "stjäla",
    "stulnes": "stjäla",
    "stult": "stulta",
    "stultad": "stulta",
    "stultade": "stulta",
    "stultades": "stulta",
    "stultads": "stulta",
    "stultan": "stulta",
    "stultande": "stulta",
    "stultanden": "stultande",
    "stultandena": "stultande",
    "stultandenas": "stultande",
    "stultandens": "stultande",
    "stultandes": "stultande",
    "stultandet": "stultande",
    "stultandets": "stultande",
    "stultans": "stulta",
    "stultar": "stulta",
    "stultas": "stulta",
    "stultat": "stulta",
    "stultats": "stulta",
    "stulte": "stulta",
    "stultor": "stulta",
    "stultorna": "stulta",
    "stultornas": "stulta",
    "stultors": "stulta",
    "stults": "stulta",
    "stumfilmen": "stumfilm",
    "stumfilmens": "stumfilm",
    "stumfilmer": "stumfilm",
    "stumfilmerna": "stumfilm",
    "stumfilmernas": "stumfilm",
    "stumfilmers": "stumfilm",
    "stumfilms": "stumfilm",
    "stumfilmsmässiga": "stumfilmsmässig",
    "stumfilmsmässigare": "stumfilmsmässig",
    "stumfilmsmässigares": "stumfilmsmässig",
    "stumfilmsmässigas": "stumfilmsmässig",
    "stumfilmsmässigast": "stumfilmsmässig",
    "stumfilmsmässigaste": "stumfilmsmässig",
    "stumfilmsmässigastes": "stumfilmsmässig",
    "stumfilmsmässigasts": "stumfilmsmässig",
    "stumfilmsmässige": "stumfilmsmässig",
    "stumfilmsmässiges": "stumfilmsmässig",
    "stumfilmsmässigs": "stumfilmsmässig",
    "stumfilmsmässigt": "stumfilmsmässig",
    "stumfilmsmässigts": "stumfilmsmässig",
    "stumheten": "stumhet",
    "stumhetens": "stumhet",
    "stumheter": "stumhet",
    "stumheterna": "stumhet",
    "stumheternas": "stumhet",
    "stumheters": "stumhet",
    "stumhets": "stumhet",
    "stumma": "stum",
    "stummare": "stum",
    "stummares": "stum",
    "stummas": "stum",
    "stummast": "stum",
    "stummaste": "stum",
    "stummastes": "stum",
    "stummasts": "stum",
    "stumme": "stum",
    "stummes": "stum",
    "stump": "stumpa",
    "stumpan": "stumpa",
    "stumpans": "stumpa",
    "stumpar": "stump",
    "stumparna": "stump",
    "stumparnas": "stump",
    "stumpars": "stump",
    "stumpas": "stumpa",
    "stumpe": "stumpa",
    "stumpen": "stump",
    "stumpens": "stump",
    "stumpor": "stumpa",
    "stumporna": "stumpa",
    "stumpornas": "stumpa",
    "stumpors": "stumpa",
    "stumps": "stumpa",
    "stums": "stum",
    "stumt": "stum",
    "stumts": "stum",
    "stund": "stunda",
    "stundad": "stunda",
    "stundade": "stunda",
    "stundades": "stunda",
    "stundads": "stunda",
    "stundande": "stunda",
    "stundanden": "stundande",
    "stundandena": "stundande",
    "stundandenas": "stundande",
    "stundandens": "stundande",
    "stundandes": "stundande",
    "stundandet": "stundande",
    "stundandets": "stundande",
    "stundar": "stunda",
    "stundas": "stunda",
    "stundat": "stunda",
    "stundats": "stunda",
    "stunden": "stund",
    "stundens": "stund",
    "stunder": "stund",
    "stunderna": "stund",
    "stundernas": "stund",
    "stunders": "stund",
    "stundliga": "stundlig",
    "stundligare": "stundlig",
    "stundligares": "stundlig",
    "stundligas": "stundlig",
    "stundligast": "stundlig",
    "stundligaste": "stundlig",
    "stundligastes": "stundlig",
    "stundligasts": "stundlig",
    "stundlige": "stundlig",
    "stundliges": "stundlig",
    "stundligheten": "stundlighet",
    "stundlighetens": "stundlighet",
    "stundlighets": "stundlighet",
    "stundligs": "stundlig",
    "stundligt": "stundlig",
    "stundligts": "stundlig",
    "stunds": "stund",
    "stundvisa": "stundvis",
    "stundvisare": "stundvis",
    "stundvisares": "stundvis",
    "stundvisas": "stundvis",
    "stundvisast": "stundvis",
    "stundvisaste": "stundvis",
    "stundvisastes": "stundvis",
    "stundvisasts": "stundvis",
    "stundvise": "stundvis",
    "stundvises": "stundvis",
    "stundvist": "stundvis",
    "stundvists": "stundvis",
    "stunge": "stinga",
    "stungen": "stinga",
    "stungens": "stinga",
    "stunges": "stinga",
    "stunget": "stinga",
    "stungets": "stinga",
    "stungit": "stinga",
    "stungits": "stinga",
    "stungna": "stinga",
    "stungnas": "stinga",
    "stungne": "stinga",
    "stungnes": "stinga",
    "stunke": "stinka",
    "stunkes": "stinka",
    "stunkit": "stinka",
    "stunkits": "stinka",
    "stunsen": "stuns",
    "stunsens": "stuns",
    "stuntmannen": "stuntman",
    "stuntmannens": "stuntman",
    "stuntmans": "stuntman",
    "stuntmän": "stuntman",
    "stuntmännen": "stuntman",
    "stuntmännens": "stuntman",
    "stuntmäns": "stuntman",
    "stunttricken": "stunttrick",
    "stunttrickens": "stunttrick",
    "stunttricket": "stunttrick",
    "stunttrickets": "stunttrick",
    "stunttricks": "stunttrick",
    "stup": "stupa",
    "stupad": "stupa",
    "stupade": "stupa",
    "stupades": "stupa",
    "stupads": "stupa",
    "stupan": "stupa",
    "stupande": "stupa",
    "stupanden": "stupande",
    "stupandena": "stupande",
    "stupandenas": "stupande",
    "stupandens": "stupande",
    "stupandes": "stupande",
    "stupandet": "stupande",
    "stupandets": "stupande",
    "stupans": "stupa",
    "stupar": "stupa",
    "stupas": "stupa",
    "stupat": "stupa",
    "stupats": "stupa",
    "stupe": "stupa",
    "stupen": "stup",
    "stupens": "stup",
    "stupes": "stupa",
    "stupet": "stup",
    "stupets": "stup",
    "stupfulla": "stupfull",
    "stupfullare": "stupfull",
    "stupfullares": "stupfull",
    "stupfullas": "stupfull",
    "stupfullast": "stupfull",
    "stupfullaste": "stupfull",
    "stupfullastes": "stupfull",
    "stupfullasts": "stupfull",
    "stupfulle": "stupfull",
    "stupfulles": "stupfull",
    "stupfullheten": "stupfullhet",
    "stupfullhetens": "stupfullhet",
    "stupfullhets": "stupfullhet",
    "stupfulls": "stupfull",
    "stupfullt": "stupfull",
    "stupfullts": "stupfull",
    "stupida": "stupid",
    "stupidare": "stupid",
    "stupidares": "stupid",
    "stupidas": "stupid",
    "stupidast": "stupid",
    "stupidaste": "stupid",
    "stupidastes": "stupid",
    "stupidasts": "stupid",
    "stupide": "stupid",
    "stupides": "stupid",
    "stupiditeten": "stupiditet",
    "stupiditetens": "stupiditet",
    "stupiditeter": "stupiditet",
    "stupiditeterna": "stupiditet",
    "stupiditeternas": "stupiditet",
    "stupiditeters": "stupiditet",
    "stupiditets": "stupiditet",
    "stupids": "stupid",
    "stupor": "stupa",
    "stuporna": "stupa",
    "stupornas": "stupa",
    "stupors": "stupor",
    "stupränn": "stupränna",
    "stuprännan": "stupränna",
    "stuprännans": "stupränna",
    "stuprännas": "stupränna",
    "stupränne": "stupränna",
    "stuprännor": "stupränna",
    "stuprännorna": "stupränna",
    "stuprännornas": "stupränna",
    "stuprännors": "stupränna",
    "stupränns": "stupränna",
    "stuprören": "stuprör",
    "stuprörens": "stuprör",
    "stupröret": "stuprör",
    "stuprörets": "stuprör",
    "stuprörs": "stuprör",
    "stuprörsmodellen": "stuprörsmodell",
    "stuprörsmodellens": "stuprörsmodell",
    "stuprörsmodeller": "stuprörsmodell",
    "stuprörsmodellerna": "stuprörsmodell",
    "stuprörsmodellernas": "stuprörsmodell",
    "stuprörsmodellers": "stuprörsmodell",
    "stuprörsmodells": "stuprörsmodell",
    "stups": "stupa",
    "stupstockar": "stupstock",
    "stupstockarna": "stupstock",
    "stupstockarnas": "stupstock",
    "stupstockars": "stupstock",
    "stupstocken": "stupstock",
    "stupstockens": "stupstock",
    "stupstocks": "stupstock",
    "stur": "stura",
    "sturad": "stura",
    "sturade": "stura",
    "sturades": "stura",
    "sturads": "stura",
    "sturande": "stura",
    "sturanden": "sturande",
    "sturandena": "sturande",
    "sturandenas": "sturande",
    "sturandens": "sturande",
    "sturandes": "sturande",
    "sturandet": "sturande",
    "sturandets": "sturande",
    "sturar": "stura",
    "sturas": "stura",
    "sturat": "stura",
    "sturats": "stura",
    "sturiga": "sturig",
    "sturigare": "sturig",
    "sturigares": "sturig",
    "sturigas": "sturig",
    "sturigast": "sturig",
    "sturigaste": "sturig",
    "sturigastes": "sturig",
    "sturigasts": "sturig",
    "sturige": "sturig",
    "sturiges": "sturig",
    "sturigs": "sturig",
    "sturigt": "sturig",
    "sturigts": "sturig",
    "sturska": "stursk",
    "sturskades": "sturskas",
    "sturskare": "stursk",
    "sturskares": "stursk",
    "sturskas": "stursk",
    "sturskast": "stursk",
    "sturskaste": "stursk",
    "sturskastes": "stursk",
    "sturskasts": "stursk",
    "sturskats": "sturskas",
    "sturske": "stursk",
    "sturskes": "stursk",
    "sturskheten": "sturskhet",
    "sturskhetens": "sturskhet",
    "sturskhets": "sturskhet",
    "stursks": "stursk",
    "sturskt": "stursk",
    "sturskts": "stursk",
    "stussar": "stuss",
    "stussarna": "stuss",
    "stussarnas": "stuss",
    "stussars": "stuss",
    "stussen": "stuss",
    "stussens": "stuss",
    "stutar": "stut",
    "stutarna": "stut",
    "stutarnas": "stut",
    "stutars": "stut",
    "stuten": "stut",
    "stutens": "stut",
    "stuterier": "stuteri",
    "stuterierna": "stuteri",
    "stuteriernas": "stuteri",
    "stuteriers": "stuteri",
    "stuteriet": "stuteri",
    "stuteriets": "stuteri",
    "stuteris": "stuteri",
    "stuterit": "stuteri",
    "stuterits": "stuteri",
    "stuts": "stut",
    "stuv": "stuva",
    "stuvad": "stuva",
    "stuvade": "stuva",
    "stuvades": "stuva",
    "stuvads": "stuva",
    "stuvande": "stuva",
    "stuvanden": "stuvande",
    "stuvandena": "stuvande",
    "stuvandenas": "stuvande",
    "stuvandens": "stuvande",
    "stuvandes": "stuvande",
    "stuvandet": "stuvande",
    "stuvandets": "stuvande",
    "stuvar": "stuvare",
    "stuvaren": "stuvare",
    "stuvarens": "stuvare",
    "stuvares": "stuvare",
    "stuvarna": "stuvare",
    "stuvarnas": "stuvare",
    "stuvars": "stuv",
    "stuvas": "stuva",
    "stuvat": "stuva",
    "stuvats": "stuva",
    "stuvbitar": "stuvbit",
    "stuvbitarna": "stuvbit",
    "stuvbitarnas": "stuvbit",
    "stuvbitars": "stuvbit",
    "stuvbiten": "stuvbit",
    "stuvbitens": "stuvbit",
    "stuvbits": "stuvbit",
    "stuven": "stuv",
    "stuvens": "stuv",
    "stuveriarbetar": "stuveriarbetare",
    "stuveriarbetaren": "stuveriarbetare",
    "stuveriarbetarens": "stuveriarbetare",
    "stuveriarbetares": "stuveriarbetare",
    "stuveriarbetarna": "stuveriarbetare",
    "stuveriarbetarnas": "stuveriarbetare",
    "stuverier": "stuveri",
    "stuverierna": "stuveri",
    "stuveriernas": "stuveri",
    "stuveriers": "stuveri",
    "stuveriet": "stuveri",
    "stuveriets": "stuveri",
    "stuveris": "stuveri",
    "stuverit": "stuveri",
    "stuverits": "stuveri",
    "stuvningar": "stuvning",
    "stuvningarna": "stuvning",
    "stuvningarnas": "stuvning",
    "stuvningars": "stuvning",
    "stuvningen": "stuvning",
    "stuvningens": "stuvning",
    "stuvnings": "stuvning",
    "stuvs": "stuv",
    "stybben": "stybb",
    "stybbens": "stybb",
    "stybbet": "stybb",
    "stybbets": "stybb",
    "stybbs": "stybb",
    "styck": "stycke",
    "styckad": "stycka",
    "styckade": "stycka",
    "styckades": "stycka",
    "styckads": "stycka",
    "styckande": "stycka",
    "styckanden": "styckande",
    "styckandena": "styckande",
    "styckandenas": "styckande",
    "styckandens": "styckande",
    "styckandes": "styckande",
    "styckandet": "styckande",
    "styckandets": "styckande",
    "styckar": "stycka",
    "styckas": "stycka",
    "styckat": "stycka",
    "styckats": "stycka",
    "styckebruken": "styckebruk",
    "styckebrukens": "styckebruk",
    "styckebruket": "styckebruk",
    "styckebrukets": "styckebruk",
    "styckebruks": "styckebruk",
    "styckegodset": "styckegods",
    "styckegodsets": "styckegods",
    "stycken": "stycke",
    "styckena": "stycke",
    "styckenas": "stycke",
    "styckens": "stycke",
    "styckes": "stycke",
    "stycket": "stycke",
    "styckets": "stycke",
    "styckjunkar": "styckjunkare",
    "styckjunkaren": "styckjunkare",
    "styckjunkarens": "styckjunkare",
    "styckjunkares": "styckjunkare",
    "styckjunkarna": "styckjunkare",
    "styckjunkarnas": "styckjunkare",
    "styckmorden": "styckmord",
    "styckmordens": "styckmord",
    "styckmordet": "styckmord",
    "styckmordets": "styckmord",
    "styckmords": "styckmord",
    "styckmästar": "styckmästare",
    "styckmästaren": "styckmästare",
    "styckmästarens": "styckmästare",
    "styckmästares": "styckmästare",
    "styckmästarna": "styckmästare",
    "styckmästarnas": "styckmästare",
    "styckna": "styck",
    "stycknas": "styck",
    "styckningar": "styckning",
    "styckningarna": "styckning",
    "styckningarnas": "styckning",
    "styckningars": "styckning",
    "styckningen": "styckning",
    "styckningens": "styckning",
    "stycknings": "styckning",
    "styckningsscheman": "styckningsschema",
    "styckningsschemana": "styckningsschema",
    "styckningsschemanas": "styckningsschema",
    "styckningsschemans": "styckningsschema",
    "styckningsschemas": "styckningsschema",
    "styckningsschemat": "styckningsschema",
    "styckningsschemats": "styckningsschema",
    "stycks": "stycke",
    "styckverket": "styckverk",
    "styckverkets": "styckverk",
    "styckverks": "styckverk",
    "stygga": "stygg",
    "styggar": "stygger",
    "styggare": "stygg",
    "styggares": "stygg",
    "styggarna": "stygger",
    "styggarnas": "stygger",
    "styggars": "stygger",
    "styggas": "stygg",
    "styggast": "stygg",
    "styggaste": "stygg",
    "styggastes": "stygg",
    "styggasts": "stygg",
    "stygge": "stygg",
    "styggelsen": "styggelse",
    "styggelsens": "styggelse",
    "styggelser": "styggelse",
    "styggelserna": "styggelse",
    "styggelsernas": "styggelse",
    "styggelsers": "styggelse",
    "styggelses": "styggelse",
    "styggen": "stygger",
    "styggens": "stygger",
    "styggern": "stygger",
    "styggerns": "stygger",
    "styggers": "stygger",
    "stygges": "stygg",
    "styggheten": "stygghet",
    "stygghetens": "stygghet",
    "stygghets": "stygghet",
    "styggingar": "stygging",
    "styggingarna": "stygging",
    "styggingarnas": "stygging",
    "styggingars": "stygging",
    "styggingen": "stygging",
    "styggingens": "stygging",
    "styggings": "stygging",
    "styggs": "stygg",
    "styggt": "stygg",
    "styggts": "stygg",
    "stygnen": "stygn",
    "stygnens": "stygn",
    "stygnet": "stygn",
    "stygnets": "stygn",
    "stygns": "stygn",
    "styliten": "stylit",
    "stylitens": "stylit",
    "styliter": "stylit",
    "styliterna": "stylit",
    "styliternas": "stylit",
    "styliters": "stylit",
    "stylits": "stylit",
    "stylobaten": "stylobat",
    "stylobatens": "stylobat",
    "stylobater": "stylobat",
    "stylobaterna": "stylobat",
    "stylobaternas": "stylobat",
    "stylobaters": "stylobat",
    "stylobats": "stylobat",
    "stylt": "stylta",
    "styltad": "stylta",
    "styltade": "stylta",
    "styltades": "stylta",
    "styltads": "stylta",
    "styltan": "stylta",
    "styltande": "stylta",
    "styltanden": "styltande",
    "styltandena": "styltande",
    "styltandenas": "styltande",
    "styltandens": "styltande",
    "styltandes": "styltande",
    "styltandet": "styltande",
    "styltandets": "styltande",
    "styltans": "stylta",
    "styltar": "stylta",
    "styltas": "stylta",
    "styltat": "stylta",
    "styltats": "stylta",
    "stylte": "stylta",
    "styltor": "stylta",
    "styltorna": "stylta",
    "styltornas": "stylta",
    "styltors": "stylta",
    "styltroten": "styltrot",
    "styltrotens": "styltrot",
    "styltrots": "styltrot",
    "styltrötter": "styltrot",
    "styltrötterna": "styltrot",
    "styltrötternas": "styltrot",
    "styltrötters": "styltrot",
    "stylts": "stylta",
    "stymp": "stympa",
    "stympad": "stympa",
    "stympade": "stympa",
    "stympades": "stympa",
    "stympads": "stympa",
    "stympande": "stympa",
    "stympanden": "stympande",
    "stympandena": "stympande",
    "stympandenas": "stympande",
    "stympandens": "stympande",
    "stympandes": "stympande",
    "stympandet": "stympande",
    "stympandets": "stympande",
    "stympar": "stympare",
    "stymparen": "stympare",
    "stymparens": "stympare",
    "stympares": "stympare",
    "stymparna": "stympare",
    "stymparnas": "stympare",
    "stympas": "stympa",
    "stympat": "stympa",
    "stympats": "stympa",
    "styngen": "styng",
    "styngens": "styng",
    "stynget": "styng",
    "styngets": "styng",
    "styngs": "styng",
    "styr": "styra",
    "styrande": "styra",
    "styranden": "styrande",
    "styrandena": "styrande",
    "styrandenas": "styrande",
    "styrandens": "styrande",
    "styrandes": "styrande",
    "styrandet": "styrande",
    "styrandets": "styrande",
    "styras": "styra",
    "styrbara": "styrbar",
    "styrbarare": "styrbar",
    "styrbarares": "styrbar",
    "styrbaras": "styrbar",
    "styrbarast": "styrbar",
    "styrbaraste": "styrbar",
    "styrbarastes": "styrbar",
    "styrbarasts": "styrbar",
    "styrbare": "styrbar",
    "styrbares": "styrbar",
    "styrbarheten": "styrbarhet",
    "styrbarhetens": "styrbarhet",
    "styrbarhets": "styrbarhet",
    "styrbars": "styrbar",
    "styrbart": "styrbar",
    "styrbarts": "styrbar",
    "styrbords": "styrbord",
    "styrcentra": "styrcentrum",
    "styrcentrana": "styrcentrum",
    "styrcentranas": "styrcentrum",
    "styrcentras": "styrcentrum",
    "styrcentrumen": "styrcentrum",
    "styrcentrumens": "styrcentrum",
    "styrcentrumet": "styrcentrum",
    "styrcentrumets": "styrcentrum",
    "styrcentrums": "styrcentrum",
    "styrd": "styra",
    "styrda": "styra",
    "styrdas": "styra",
    "styrde": "styra",
    "styrdes": "styra",
    "styrds": "styra",
    "styrelseformen": "styrelseform",
    "styrelseformens": "styrelseform",
    "styrelseformer": "styrelseform",
    "styrelseformerna": "styrelseform",
    "styrelseformernas": "styrelseform",
    "styrelseformers": "styrelseform",
    "styrelseforms": "styrelseform",
    "styrelseledamoten": "styrelseledamot",
    "styrelseledamotens": "styrelseledamot",
    "styrelseledamots": "styrelseledamot",
    "styrelseledamöter": "styrelseledamot",
    "styrelseledamöterna": "styrelseledamot",
    "styrelseledamöternas": "styrelseledamot",
    "styrelseledamöters": "styrelseledamot",
    "styrelsen": "styrelse",
    "styrelsens": "styrelse",
    "styrelseordföranden": "styrelseordförande",
    "styrelseordförandena": "styrelseordförande",
    "styrelseordförandenas": "styrelseordförande",
    "styrelseordförandens": "styrelseordförande",
    "styrelseordförandes": "styrelseordförande",
    "styrelseposten": "styrelsepost",
    "styrelsepostens": "styrelsepost",
    "styrelseposter": "styrelsepost",
    "styrelseposterna": "styrelsepost",
    "styrelseposternas": "styrelsepost",
    "styrelseposters": "styrelsepost",
    "styrelseposts": "styrelsepost",
    "styrelser": "styrelse",
    "styrelserna": "styrelse",
    "styrelsernas": "styrelse",
    "styrelsers": "styrelse",
    "styrelserummen": "styrelserum",
    "styrelserummens": "styrelserum",
    "styrelserummet": "styrelserum",
    "styrelserummets": "styrelserum",
    "styrelserums": "styrelserum",
    "styrelses": "styrelse",
    "styrelseuppdragen": "styrelseuppdrag",
    "styrelseuppdragens": "styrelseuppdrag",
    "styrelseuppdraget": "styrelseuppdrag",
    "styrelseuppdragets": "styrelseuppdrag",
    "styrelseuppdrags": "styrelseuppdrag",
    "styren": "styre",
    "styrena": "styre",
    "styrenas": "styre",
    "styrenen": "styren",
    "styrenens": "styren",
    "styrenet": "styren",
    "styrenets": "styren",
    "styrenplasten": "styrenplast",
    "styrenplastens": "styrenplast",
    "styrenplasts": "styrenplast",
    "styrens": "styren",
    "styres": "styre",
    "styresmannen": "styresman",
    "styresmannens": "styresman",
    "styresmans": "styresman",
    "styresmän": "styresman",
    "styresmännen": "styresman",
    "styresmännens": "styresman",
    "styresmäns": "styresman",
    "styret": "styre",
    "styrets": "styre",
    "styrfarten": "styrfart",
    "styrfartens": "styrfart",
    "styrfarts": "styrfart",
    "styrfjädern": "styrfjäder",
    "styrfjäderns": "styrfjäder",
    "styrfjäders": "styrfjäder",
    "styrfjädrar": "styrfjäder",
    "styrfjädrarna": "styrfjäder",
    "styrfjädrarnas": "styrfjäder",
    "styrfjädrars": "styrfjäder",
    "styrhjulen": "styrhjul",
    "styrhjulens": "styrhjul",
    "styrhjulet": "styrhjul",
    "styrhjulets": "styrhjul",
    "styrhjuls": "styrhjul",
    "styrinrättningar": "styrinrättning",
    "styrinrättningarna": "styrinrättning",
    "styrinrättningarnas": "styrinrättning",
    "styrinrättningars": "styrinrättning",
    "styrinrättningen": "styrinrättning",
    "styrinrättningens": "styrinrättning",
    "styrinrättnings": "styrinrättning",
    "styrk": "styrka",
    "styrkan": "styrka",
    "styrkande": "styrka",
    "styrkanden": "styrkande",
    "styrkandena": "styrkande",
    "styrkandenas": "styrkande",
    "styrkandens": "styrkande",
    "styrkandes": "styrkande",
    "styrkandet": "styrkande",
    "styrkandets": "styrkande",
    "styrkans": "styrka",
    "styrkas": "styrka",
    "styrke": "styrka",
    "styrkeförhållanden": "styrkeförhållande",
    "styrkeförhållandena": "styrkeförhållande",
    "styrkeförhållandenas": "styrkeförhållande",
    "styrkeförhållandens": "styrkeförhållande",
    "styrkeförhållandes": "styrkeförhållande",
    "styrkeförhållandet": "styrkeförhållande",
    "styrkeförhållandets": "styrkeförhållande",
    "styrkeledar": "styrkeledare",
    "styrkeledaren": "styrkeledare",
    "styrkeledarens": "styrkeledare",
    "styrkeledares": "styrkeledare",
    "styrkeledarna": "styrkeledare",
    "styrkeledarnas": "styrkeledare",
    "styrker": "styrka",
    "styrkes": "styrka",
    "styrketräningar": "styrketräning",
    "styrketräningarna": "styrketräning",
    "styrketräningarnas": "styrketräning",
    "styrketräningars": "styrketräning",
    "styrketräningen": "styrketräning",
    "styrketräningens": "styrketräning",
    "styrketränings": "styrketräning",
    "styrketårar": "styrketår",
    "styrketårarna": "styrketår",
    "styrketårarnas": "styrketår",
    "styrketårars": "styrketår",
    "styrketåren": "styrketår",
    "styrketårens": "styrketår",
    "styrketårs": "styrketår",
    "styrkor": "styrka",
    "styrkorna": "styrka",
    "styrkornas": "styrka",
    "styrkors": "styrka",
    "styrks": "styrka",
    "styrkt": "styrka",
    "styrkta": "styrka",
    "styrktas": "styrka",
    "styrkte": "styrka",
    "styrktes": "styrka",
    "styrkts": "styrka",
    "styrlastigheten": "styrlastighet",
    "styrlastighetens": "styrlastighet",
    "styrlastigheter": "styrlastighet",
    "styrlastigheterna": "styrlastighet",
    "styrlastigheternas": "styrlastighet",
    "styrlastigheters": "styrlastighet",
    "styrlastighets": "styrlastighet",
    "styrlin": "styrlina",
    "styrlinan": "styrlina",
    "styrlinans": "styrlina",
    "styrlinas": "styrlina",
    "styrline": "styrlina",
    "styrlinor": "styrlina",
    "styrlinorna": "styrlina",
    "styrlinornas": "styrlina",
    "styrlinors": "styrlina",
    "styrlins": "styrlina",
    "styrmannen": "styrman",
    "styrmannens": "styrman",
    "styrmans": "styrman",
    "styrmän": "styrman",
    "styrmännen": "styrman",
    "styrmännens": "styrman",
    "styrmäns": "styrman",
    "styrningar": "styrning",
    "styrningarna": "styrning",
    "styrningarnas": "styrning",
    "styrningars": "styrning",
    "styrningen": "styrning",
    "styrningens": "styrning",
    "styrnings": "styrning",
    "styrolen": "styrol",
    "styrolens": "styrol",
    "styrols": "styrol",
    "styrs": "styra",
    "styrseln": "styrsel",
    "styrselns": "styrsel",
    "styrsels": "styrsel",
    "styrsignalen": "styrsignal",
    "styrsignalens": "styrsignal",
    "styrsignaler": "styrsignal",
    "styrsignalerna": "styrsignal",
    "styrsignalernas": "styrsignal",
    "styrsignalers": "styrsignal",
    "styrsignals": "styrsignal",
    "styrstavar": "styrstav",
    "styrstavarna": "styrstav",
    "styrstavarnas": "styrstav",
    "styrstavars": "styrstav",
    "styrstaven": "styrstav",
    "styrstavens": "styrstav",
    "styrstavs": "styrstav",
    "styrstänger": "styrstång",
    "styrstängerna": "styrstång",
    "styrstängernas": "styrstång",
    "styrstängers": "styrstång",
    "styrstången": "styrstång",
    "styrstångens": "styrstång",
    "styrstångs": "styrstång",
    "styrsystemen": "styrsystem",
    "styrsystemens": "styrsystem",
    "styrsystemet": "styrsystem",
    "styrsystemets": "styrsystem",
    "styrsystems": "styrsystem",
    "styrt": "styra",
    "styrteckens": "styrtecken",
    "styrtecknen": "styrtecken",
    "styrtecknens": "styrtecken",
    "styrtecknet": "styrtecken",
    "styrtecknets": "styrtecken",
    "styrts": "styra",
    "styrväxeln": "styrväxel",
    "styrväxelns": "styrväxel",
    "styrväxels": "styrväxel",
    "styrväxlar": "styrväxel",
    "styrväxlarna": "styrväxel",
    "styrväxlarnas": "styrväxel",
    "styrväxlars": "styrväxel",
    "styv": "styva",
    "styva": "styv",
    "styvad": "styva",
    "styvade": "styva",
    "styvades": "styva",
    "styvads": "styva",
    "styvande": "styva",
    "styvanden": "styvande",
    "styvandena": "styvande",
    "styvandenas": "styvande",
    "styvandens": "styvande",
    "styvandes": "styvande",
    "styvandet": "styvande",
    "styvandets": "styvande",
    "styvar": "styva",
    "styvare": "styv",
    "styvares": "styv",
    "styvas": "styva",
    "styvast": "styv",
    "styvaste": "styv",
    "styvastes": "styv",
    "styvasts": "styv",
    "styvat": "styva",
    "styvats": "styva",
    "styvbarnen": "styvbarn",
    "styvbarnens": "styvbarn",
    "styvbarnet": "styvbarn",
    "styvbarnets": "styvbarn",
    "styvbarns": "styvbarn",
    "styvdottern": "styvdotter",
    "styvdotterns": "styvdotter",
    "styvdotters": "styvdotter",
    "styvdöttrar": "styvdotter",
    "styvdöttrarna": "styvdotter",
    "styvdöttrarnas": "styvdotter",
    "styvdöttrars": "styvdotter",
    "styve": "styv",
    "styvern": "styver",
    "styverna": "styver",
    "styvernas": "styver",
    "styverns": "styver",
    "styvers": "styver",
    "styves": "styv",
    "styvfader": "styvfar",
    "styvfadern": "styvfar",
    "styvfaderns": "styvfar",
    "styvfaders": "styvfar",
    "styvfars": "styvfar",
    "styvfasder": "styvfar",
    "styvfäder": "styvfar",
    "styvfäderna": "styvfar",
    "styvfädernas": "styvfar",
    "styvfäders": "styvfar",
    "styvföräldern": "styvförälder",
    "styvförälderns": "styvförälder",
    "styvförälders": "styvförälder",
    "styvföräldrar": "styvförälder",
    "styvföräldrarna": "styvförälder",
    "styvföräldrarnas": "styvförälder",
    "styvföräldrars": "styvförälder",
    "styvheten": "styvhet",
    "styvhetens": "styvhet",
    "styvheter": "styvhet",
    "styvheterna": "styvhet",
    "styvheternas": "styvhet",
    "styvheters": "styvhet",
    "styvhets": "styvhet",
    "styvmoder": "styvmor",
    "styvmoderliga": "styvmoderlig",
    "styvmoderligare": "styvmoderlig",
    "styvmoderligares": "styvmoderlig",
    "styvmoderligas": "styvmoderlig",
    "styvmoderligast": "styvmoderlig",
    "styvmoderligaste": "styvmoderlig",
    "styvmoderligastes": "styvmoderlig",
    "styvmoderligasts": "styvmoderlig",
    "styvmoderlige": "styvmoderlig",
    "styvmoderliges": "styvmoderlig",
    "styvmoderligheten": "styvmoderlighet",
    "styvmoderlighetens": "styvmoderlighet",
    "styvmoderlighets": "styvmoderlighet",
    "styvmoderligs": "styvmoderlig",
    "styvmoderligt": "styvmoderlig",
    "styvmoderligts": "styvmoderlig",
    "styvmodern": "styvmor",
    "styvmoderns": "styvmor",
    "styvmoders": "styvmor",
    "styvmors": "styvmor",
    "styvmorsviolen": "styvmorsviol",
    "styvmorsviolens": "styvmorsviol",
    "styvmorsvioler": "styvmorsviol",
    "styvmorsviolerna": "styvmorsviol",
    "styvmorsviolernas": "styvmorsviol",
    "styvmorsviolers": "styvmorsviol",
    "styvmorsviols": "styvmorsviol",
    "styvmödrar": "styvmor",
    "styvmödrarna": "styvmor",
    "styvmödrarnas": "styvmor",
    "styvmödrars": "styvmor",
    "styvn": "styvna",
    "styvnackade": "styvnackad",
    "styvnackades": "styvnackad",
    "styvnackads": "styvnackad",
    "styvnackat": "styvnackad",
    "styvnackats": "styvnackad",
    "styvnad": "styvna",
    "styvnade": "styvna",
    "styvnaden": "styvnad",
    "styvnadens": "styvnad",
    "styvnader": "styvnad",
    "styvnaderna": "styvnad",
    "styvnadernas": "styvnad",
    "styvnaders": "styvnad",
    "styvnades": "styvna",
    "styvnads": "styvnad",
    "styvnande": "styvna",
    "styvnanden": "styvnande",
    "styvnandena": "styvnande",
    "styvnandenas": "styvnande",
    "styvnandens": "styvnande",
    "styvnandes": "styvnande",
    "styvnandet": "styvnande",
    "styvnandets": "styvnande",
    "styvnar": "styvna",
    "styvnas": "styvna",
    "styvnat": "styvna",
    "styvnats": "styvna",
    "styvs": "styv",
    "styvsinta": "styvsint",
    "styvsintare": "styvsint",
    "styvsintares": "styvsint",
    "styvsintas": "styvsint",
    "styvsintast": "styvsint",
    "styvsintaste": "styvsint",
    "styvsintastes": "styvsint",
    "styvsintasts": "styvsint",
    "styvsinte": "styvsint",
    "styvsintes": "styvsint",
    "styvsintheten": "styvsinthet",
    "styvsinthetens": "styvsinthet",
    "styvsinthets": "styvsinthet",
    "styvsints": "styvsint",
    "styvsonen": "styvson",
    "styvsonens": "styvson",
    "styvsons": "styvson",
    "styvsyskonen": "styvsyskon",
    "styvsyskonens": "styvsyskon",
    "styvsyskonet": "styvsyskon",
    "styvsyskonets": "styvsyskon",
    "styvsyskons": "styvsyskon",
    "styvsöner": "styvson",
    "styvsönerna": "styvson",
    "styvsönernas": "styvson",
    "styvsöners": "styvson",
    "styvt": "styv",
    "styvts": "styv",
    "stäck": "stäcka",
    "stäckande": "stäcka",
    "stäckanden": "stäckande",
    "stäckandena": "stäckande",
    "stäckandenas": "stäckande",
    "stäckandens": "stäckande",
    "stäckandes": "stäckande",
    "stäckandet": "stäckande",
    "stäckandets": "stäckande",
    "stäckas": "stäcka",
    "stäcker": "stäcka",
    "stäckes": "stäcka",
    "stäcks": "stäcka",
    "stäckt": "stäcka",
    "stäckta": "stäcka",
    "stäcktas": "stäcka",
    "stäckte": "stäcka",
    "stäcktes": "stäcka",
    "stäckts": "stäcka",
    "städ": "städja",
    "städad": "städa",
    "städade": "städad",
    "städades": "städad",
    "städads": "städad",
    "städande": "städa",
    "städanden": "städande",
    "städandena": "städande",
    "städandenas": "städande",
    "städandens": "städande",
    "städandes": "städande",
    "städandet": "städande",
    "städandets": "städande",
    "städar": "städare",
    "städaren": "städare",
    "städarens": "städare",
    "städares": "städare",
    "städarna": "städare",
    "städarnas": "städare",
    "städas": "städa",
    "städat": "städad",
    "städats": "städad",
    "städbolagen": "städbolag",
    "städbolagens": "städbolag",
    "städbolaget": "städbolag",
    "städbolagets": "städbolag",
    "städbolags": "städbolag",
    "städen": "städ",
    "städens": "städ",
    "städer": "städja",
    "städerna": "stad",
    "städernas": "stad",
    "städers": "stad",
    "städerskan": "städerska",
    "städerskans": "städerska",
    "städerskas": "städerska",
    "städerske": "städerska",
    "städerskor": "städerska",
    "städerskorna": "städerska",
    "städerskornas": "städerska",
    "städerskors": "städerska",
    "städes": "städja",
    "städet": "städ",
    "städets": "städ",
    "städfynden": "städfynd",
    "städfyndens": "städfynd",
    "städfyndet": "städfynd",
    "städfyndets": "städfynd",
    "städfynds": "städfynd",
    "städgrälen": "städgräl",
    "städgrälens": "städgräl",
    "städgrälet": "städgräl",
    "städgrälets": "städgräl",
    "städgräls": "städgräl",
    "städj": "städja",
    "städjande": "städja",
    "städjanden": "städjande",
    "städjandena": "städjande",
    "städjandenas": "städjande",
    "städjandens": "städjande",
    "städjandes": "städjande",
    "städjandet": "städjande",
    "städjandets": "städjande",
    "städjas": "städja",
    "städjer": "städja",
    "städningar": "städning",
    "städningarna": "städning",
    "städningarnas": "städning",
    "städningars": "städning",
    "städningen": "städning",
    "städningens": "städning",
    "städnings": "städning",
    "städredskapen": "städredskap",
    "städredskapens": "städredskap",
    "städredskapet": "städredskap",
    "städredskapets": "städredskap",
    "städredskaps": "städredskap",
    "städs": "städja",
    "städsel": "städsla",
    "städsels": "städsel",
    "städskåpen": "städskåp",
    "städskåpens": "städskåp",
    "städskåpet": "städskåp",
    "städskåpets": "städskåp",
    "städskåps": "städskåp",
    "städslad": "städsla",
    "städslade": "städsla",
    "städslades": "städsla",
    "städslads": "städsla",
    "städslande": "städsla",
    "städslanden": "städslande",
    "städslandena": "städslande",
    "städslandenas": "städslande",
    "städslandens": "städslande",
    "städslandes": "städslande",
    "städslandet": "städslande",
    "städslandets": "städslande",
    "städslar": "städsla",
    "städslas": "städsla",
    "städslat": "städsla",
    "städslats": "städsla",
    "städslen": "städsel",
    "städslens": "städsel",
    "städslet": "städsel",
    "städslets": "städsel",
    "städvagnar": "städvagn",
    "städvagnarna": "städvagn",
    "städvagnarnas": "städvagn",
    "städvagnars": "städvagn",
    "städvagnen": "städvagn",
    "städvagnens": "städvagn",
    "städvagns": "städvagn",
    "ställ": "ställa",
    "ställande": "ställa",
    "ställanden": "ställande",
    "ställandena": "ställande",
    "ställandenas": "ställande",
    "ställandens": "ställande",
    "ställandes": "ställande",
    "ställandet": "ställande",
    "ställandets": "ställande",
    "ställas": "ställa",
    "ställbara": "ställbar",
    "ställbaras": "ställbar",
    "ställbare": "ställbar",
    "ställbares": "ställbar",
    "ställbars": "ställbar",
    "ställbart": "ställbar",
    "ställbarts": "ställbar",
    "ställd": "ställa",
    "ställda": "ställd",
    "ställdare": "ställd",
    "ställdares": "ställd",
    "ställdas": "ställd",
    "ställdast": "ställd",
    "ställdaste": "ställd",
    "ställdastes": "ställd",
    "ställdasts": "ställd",
    "ställde": "ställd",
    "ställdes": "ställd",
    "ställds": "ställd",
    "ställen": "ställe",
    "ställena": "ställe",
    "ställenas": "ställe",
    "ställens": "ställe",
    "ställer": "ställa",
    "ställes": "ställe",
    "stället": "ställe",
    "ställets": "ställe",
    "ställföreträdar": "ställföreträdare",
    "ställföreträdaren": "ställföreträdare",
    "ställföreträdarens": "ställföreträdare",
    "ställföreträdares": "ställföreträdare",
    "ställföreträdarna": "ställföreträdare",
    "ställföreträdarnas": "ställföreträdare",
    "ställmuttern": "ställmutter",
    "ställmutterns": "ställmutter",
    "ställmutters": "ställmutter",
    "ställmuttrar": "ställmutter",
    "ställmuttrarna": "ställmutter",
    "ställmuttrarnas": "ställmutter",
    "ställmuttrars": "ställmutter",
    "ställningar": "ställning",
    "ställningarna": "ställningar",
    "ställningarnas": "ställningar",
    "ställningars": "ställningar",
    "ställningen": "ställning",
    "ställningens": "ställning",
    "ställnings": "ställningar",
    "ställningskrigen": "ställningskrig",
    "ställningskrigens": "ställningskrig",
    "ställningskriget": "ställningskrig",
    "ställningskrigets": "ställningskrig",
    "ställningskrigs": "ställningskrig",
    "ställningsstegen": "ställningssteg",
    "ställningsstegens": "ställningssteg",
    "ställningssteget": "ställningssteg",
    "ställningsstegets": "ställningssteg",
    "ställningsstegs": "ställningssteg",
    "ställningstaganden": "ställningstagande",
    "ställningstagandena": "ställningstagande",
    "ställningstagandenas": "ställningstagande",
    "ställningstagandens": "ställningstagande",
    "ställningstagandes": "ställningstagande",
    "ställningstagandet": "ställningstagande",
    "ställningstagandets": "ställningstagande",
    "ställs": "ställa",
    "ställt": "ställd",
    "ställts": "ställd",
    "ställverken": "ställverk",
    "ställverkens": "ställverk",
    "ställverket": "ställverk",
    "ställverkets": "ställverk",
    "ställverks": "ställverk",
    "stäm": "stämma",
    "stämbanden": "stämband",
    "stämbandens": "stämband",
    "stämbandet": "stämband",
    "stämbandets": "stämband",
    "stämbands": "stämband",
    "stämd": "stämma",
    "stämda": "stämma",
    "stämdas": "stämma",
    "stämde": "stämma",
    "stämdes": "stämma",
    "stämds": "stämma",
    "stämgaffeln": "stämgaffel",
    "stämgaffelns": "stämgaffel",
    "stämgaffels": "stämgaffel",
    "stämgafflar": "stämgaffel",
    "stämgafflarna": "stämgaffel",
    "stämgafflarnas": "stämgaffel",
    "stämgafflars": "stämgaffel",
    "stämjärnen": "stämjärn",
    "stämjärnens": "stämjärn",
    "stämjärnet": "stämjärn",
    "stämjärnets": "stämjärn",
    "stämjärns": "stämjärn",
    "stämläppar": "stämläpp",
    "stämläpparna": "stämläpp",
    "stämläpparnas": "stämläpp",
    "stämläppars": "stämläpp",
    "stämläppen": "stämläpp",
    "stämläppens": "stämläpp",
    "stämläpps": "stämläpp",
    "stämman": "stämma",
    "stämmande": "stämma",
    "stämmanden": "stämmande",
    "stämmandena": "stämmande",
    "stämmandenas": "stämmande",
    "stämmandens": "stämmande",
    "stämmandes": "stämmande",
    "stämmandet": "stämmande",
    "stämmandets": "stämmande",
    "stämmans": "stämma",
    "stämmas": "stämma",
    "stämme": "stämma",
    "stämmer": "stämma",
    "stämmo": "stämma",
    "stämmor": "stämma",
    "stämmorna": "stämma",
    "stämmornas": "stämma",
    "stämmors": "stämma",
    "stämningar": "stämning",
    "stämningarna": "stämning",
    "stämningarnas": "stämning",
    "stämningars": "stämning",
    "stämningen": "stämning",
    "stämningens": "stämning",
    "stämnings": "stämning",
    "stämningsansökans": "stämningsansökan",
    "stämningshöjar": "stämningshöjare",
    "stämningshöjaren": "stämningshöjare",
    "stämningshöjarens": "stämningshöjare",
    "stämningshöjares": "stämningshöjare",
    "stämningshöjarna": "stämningshöjare",
    "stämningshöjarnas": "stämningshöjare",
    "stämningslägen": "stämningsläge",
    "stämningslägena": "stämningsläge",
    "stämningslägenas": "stämningsläge",
    "stämningslägens": "stämningsläge",
    "stämningsläges": "stämningsläge",
    "stämningsläget": "stämningsläge",
    "stämningslägets": "stämningsläge",
    "stämpelavgiften": "stämpelavgift",
    "stämpelavgiftens": "stämpelavgift",
    "stämpelavgifter": "stämpelavgift",
    "stämpelavgifterna": "stämpelavgift",
    "stämpelavgifternas": "stämpelavgift",
    "stämpelavgifters": "stämpelavgift",
    "stämpelavgifts": "stämpelavgift",
    "stämpeldyn": "stämpeldyna",
    "stämpeldynan": "stämpeldyna",
    "stämpeldynans": "stämpeldyna",
    "stämpeldynas": "stämpeldyna",
    "stämpeldyne": "stämpeldyna",
    "stämpeldynor": "stämpeldyna",
    "stämpeldynorna": "stämpeldyna",
    "stämpeldynornas": "stämpeldyna",
    "stämpeldynors": "stämpeldyna",
    "stämpeldyns": "stämpeldyna",
    "stämpelklock": "stämpelklocka",
    "stämpelklockan": "stämpelklocka",
    "stämpelklockans": "stämpelklocka",
    "stämpelklockas": "stämpelklocka",
    "stämpelklocke": "stämpelklocka",
    "stämpelklockor": "stämpelklocka",
    "stämpelklockorna": "stämpelklocka",
    "stämpelklockornas": "stämpelklocka",
    "stämpelklockors": "stämpelklocka",
    "stämpelklocks": "stämpelklocka",
    "stämpeln": "stämpel",
    "stämpelns": "stämpel",
    "stämpels": "stämpel",
    "stämpeluren": "stämpelur",
    "stämpelurens": "stämpelur",
    "stämpeluret": "stämpelur",
    "stämpelurets": "stämpelur",
    "stämpelurs": "stämpelur",
    "stämplad": "stämpla",
    "stämplade": "stämpla",
    "stämplades": "stämpla",
    "stämplads": "stämpla",
    "stämplande": "stämpla",
    "stämplanden": "stämplande",
    "stämplandena": "stämplande",
    "stämplandenas": "stämplande",
    "stämplandens": "stämplande",
    "stämplandes": "stämplande",
    "stämplandet": "stämplande",
    "stämplandets": "stämplande",
    "stämplar": "stämpla",
    "stämplarna": "stämpel",
    "stämplarnas": "stämpel",
    "stämplars": "stämpel",
    "stämplas": "stämpla",
    "stämplat": "stämpla",
    "stämplats": "stämpla",
    "stämplingar": "stämpling",
    "stämplingarna": "stämpling",
    "stämplingarnas": "stämpling",
    "stämplingars": "stämpling",
    "stämplingen": "stämpling",
    "stämplingens": "stämpling",
    "stämplings": "stämpling",
    "stäms": "stämma",
    "stämt": "stämma",
    "stämts": "stämma",
    "ständchenen": "ständchen",
    "ständchenens": "ständchen",
    "ständchens": "ständchen",
    "ständer": "stånd",
    "ständerna": "stånd",
    "ständernas": "stånd",
    "ständers": "stånd",
    "ständiga": "ständig",
    "ständigare": "ständig",
    "ständigares": "ständig",
    "ständigas": "ständig",
    "ständigast": "ständig",
    "ständigaste": "ständig",
    "ständigastes": "ständig",
    "ständigasts": "ständig",
    "ständige": "ständig",
    "ständiges": "ständig",
    "ständigheten": "ständighet",
    "ständighetens": "ständighet",
    "ständighets": "ständighet",
    "ständigs": "ständig",
    "ständigt": "ständig",
    "ständigts": "ständig",
    "stäng": "stänga",
    "stängande": "stänga",
    "stänganden": "stängande",
    "stängandena": "stängande",
    "stängandenas": "stängande",
    "stängandens": "stängande",
    "stängandes": "stängande",
    "stängandet": "stängande",
    "stängandets": "stängande",
    "stängas": "stänga",
    "stängd": "stänga",
    "stängda": "stänga",
    "stängdas": "stänga",
    "stängde": "stänga",
    "stängdes": "stänga",
    "stängds": "stänga",
    "stängeln": "stängel",
    "stängelns": "stängel",
    "stängels": "stängel",
    "stängen": "stänge",
    "stängena": "stänge",
    "stängenas": "stänge",
    "stängens": "stänge",
    "stänger": "stänga",
    "stängerna": "stång",
    "stängernas": "stång",
    "stängers": "stång",
    "stänges": "stänge",
    "stänget": "stänge",
    "stängets": "stänge",
    "stänglar": "stängel",
    "stänglarna": "stängel",
    "stänglarnas": "stängel",
    "stänglars": "stängel",
    "stängningar": "stängning",
    "stängningarna": "stängning",
    "stängningarnas": "stängning",
    "stängningars": "stängning",
    "stängningen": "stängning",
    "stängningens": "stängning",
    "stängnings": "stängning",
    "stängningsdagset": "stängningsdags",
    "stängningsdagsets": "stängningsdags",
    "stängs": "stänge",
    "stängsels": "stängsel",
    "stängslad": "stängsla",
    "stängslade": "stängsla",
    "stängslades": "stängsla",
    "stängslads": "stängsla",
    "stängslande": "stängsla",
    "stängslanden": "stängslande",
    "stängslandena": "stängslande",
    "stängslandenas": "stängslande",
    "stängslandens": "stängslande",
    "stängslandes": "stängslande",
    "stängslandet": "stängslande",
    "stängslandets": "stängslande",
    "stängslar": "stängsla",
    "stängslas": "stängsla",
    "stängslat": "stängsla",
    "stängslats": "stängsla",
    "stängslen": "stängsel",
    "stängslens": "stängsel",
    "stängslet": "stängsel",
    "stängslets": "stängsel",
    "stängt": "stänga",
    "stängts": "stänga",
    "stänk": "stänka",
    "stänkande": "stänka",
    "stänkanden": "stänkande",
    "stänkandena": "stänkande",
    "stänkandenas": "stänkande",
    "stänkandens": "stänkande",
    "stänkandes": "stänkande",
    "stänkandet": "stänkande",
    "stänkandets": "stänkande",
    "stänkas": "stänka",
    "stänken": "stänk",
    "stänkens": "stänk",
    "stänker": "stänka",
    "stänkes": "stänka",
    "stänket": "stänk",
    "stänkets": "stänk",
    "stänks": "stänka",
    "stänkskydden": "stänkskydd",
    "stänkskyddens": "stänkskydd",
    "stänkskyddet": "stänkskydd",
    "stänkskyddets": "stänkskydd",
    "stänkskydds": "stänkskydd",
    "stänkskärmar": "stänkskärm",
    "stänkskärmarna": "stänkskärm",
    "stänkskärmarnas": "stänkskärm",
    "stänkskärmars": "stänkskärm",
    "stänkskärmen": "stänkskärm",
    "stänkskärmens": "stänkskärm",
    "stänkskärms": "stänkskärm",
    "stänkt": "stänka",
    "stänkta": "stänka",
    "stänktas": "stänka",
    "stänkte": "stänka",
    "stänktes": "stänka",
    "stänkts": "stänka",
    "stäppantilopen": "stäppantilop",
    "stäppantilopens": "stäppantilop",
    "stäppantiloper": "stäppantilop",
    "stäppantiloperna": "stäppantilop",
    "stäppantilopernas": "stäppantilop",
    "stäppantilopers": "stäppantilop",
    "stäppantilops": "stäppantilop",
    "stäppen": "stäpp",
    "stäppens": "stäpp",
    "stäpper": "stäpp",
    "stäpperna": "stäpp",
    "stäppernas": "stäpp",
    "stäppers": "stäpp",
    "stäpps": "stäpp",
    "stärbhusen": "stärbhus",
    "stärbhusens": "stärbhus",
    "stärbhuset": "stärbhus",
    "stärbhusets": "stärbhus",
    "stärk": "stärka",
    "stärkande": "stärka",
    "stärkanden": "stärkande",
    "stärkandena": "stärkande",
    "stärkandenas": "stärkande",
    "stärkandens": "stärkande",
    "stärkandes": "stärkande",
    "stärkandet": "stärkande",
    "stärkandets": "stärkande",
    "stärkas": "stärka",
    "stärkelseklisters": "stärkelseklister",
    "stärkelseklistret": "stärkelseklister",
    "stärkelseklistrets": "stärkelseklister",
    "stärkelsen": "stärkelse",
    "stärkelsens": "stärkelse",
    "stärkelser": "stärkelse",
    "stärkelserika": "stärkelserik",
    "stärkelserikare": "stärkelserik",
    "stärkelserikares": "stärkelserik",
    "stärkelserikas": "stärkelserik",
    "stärkelserikast": "stärkelserik",
    "stärkelserikaste": "stärkelserik",
    "stärkelserikastes": "stärkelserik",
    "stärkelserikasts": "stärkelserik",
    "stärkelserike": "stärkelserik",
    "stärkelserikes": "stärkelserik",
    "stärkelserikheten": "stärkelserikhet",
    "stärkelserikhetens": "stärkelserikhet",
    "stärkelserikhets": "stärkelserikhet",
    "stärkelseriks": "stärkelserik",
    "stärkelserikt": "stärkelserik",
    "stärkelserikts": "stärkelserik",
    "stärkelserna": "stärkelse",
    "stärkelsernas": "stärkelse",
    "stärkelsers": "stärkelse",
    "stärkelses": "stärkelse",
    "stärkelset": "stärkelse",
    "stärkelsets": "stärkelse",
    "stärker": "stärka",
    "stärkes": "stärka",
    "stärks": "stärka",
    "stärksakerna": "stärksaker",
    "stärksakernas": "stärksaker",
    "stärksakers": "stärksaker",
    "stärksaks": "stärksaker",
    "stärkt": "stärka",
    "stärkta": "stärka",
    "stärktas": "stärka",
    "stärkte": "stärka",
    "stärktes": "stärka",
    "stärkts": "stärka",
    "stätt": "stätta",
    "stättan": "stätta",
    "stättans": "stätta",
    "stättas": "stätta",
    "stätte": "stätta",
    "stättor": "stätta",
    "stättorna": "stätta",
    "stättornas": "stätta",
    "stättors": "stätta",
    "stätts": "stätta",
    "stäv": "stäva",
    "stävad": "stäva",
    "stävade": "stäva",
    "stävades": "stäva",
    "stävads": "stäva",
    "stävan": "stäva",
    "stävande": "stäva",
    "stävanden": "stävande",
    "stävandena": "stävande",
    "stävandenas": "stävande",
    "stävandens": "stävande",
    "stävandes": "stävande",
    "stävandet": "stävande",
    "stävandets": "stävande",
    "stävans": "stäva",
    "stävar": "stäva",
    "stävarna": "stäv",
    "stävarnas": "stäv",
    "stävars": "stäv",
    "stävas": "stäva",
    "stävat": "stäva",
    "stävats": "stäva",
    "stäve": "stäva",
    "stäven": "stäv",
    "stävens": "stäv",
    "stäver": "stav",
    "stäverna": "stav",
    "stävernas": "stav",
    "stävers": "stav",
    "stävet": "stäv",
    "stävets": "stäv",
    "stävj": "stävja",
    "stävjad": "stävja",
    "stävjade": "stävja",
    "stävjades": "stävja",
    "stävjads": "stävja",
    "stävjande": "stävja",
    "stävjanden": "stävjande",
    "stävjandena": "stävjande",
    "stävjandenas": "stävjande",
    "stävjandens": "stävjande",
    "stävjandes": "stävjande",
    "stävjandet": "stävjande",
    "stävjandets": "stävjande",
    "stävjar": "stävja",
    "stävjas": "stävja",
    "stävjat": "stävja",
    "stävjats": "stävja",
    "stävor": "stäva",
    "stävorna": "stäva",
    "stävornas": "stäva",
    "stävors": "stäva",
    "stävs": "stäva",
    "stående": "stå",
    "ståenden": "stående",
    "ståendena": "stående",
    "ståendenas": "stående",
    "ståendens": "stående",
    "ståendes": "stående",
    "ståendet": "stående",
    "ståendets": "stående",
    "ståfelan": "ståfela",
    "ståfelans": "ståfela",
    "ståfelas": "ståfela",
    "ståfelor": "ståfela",
    "ståfelorna": "ståfela",
    "ståfelornas": "ståfela",
    "ståfelors": "ståfela",
    "ståfräsar": "ståfräs",
    "ståfräsarna": "ståfräs",
    "ståfräsarnas": "ståfräs",
    "ståfräsars": "ståfräs",
    "ståfräsen": "ståfräs",
    "ståfräsens": "ståfräs",
    "ståhejet": "ståhej",
    "ståhejets": "ståhej",
    "ståhejs": "ståhej",
    "stålarna": "stålar",
    "stålarnas": "stålar",
    "stålars": "stålar",
    "stålartade": "stålartad",
    "stålartades": "stålartad",
    "stålartads": "stålartad",
    "stålartat": "stålartad",
    "stålartats": "stålartad",
    "stålbaden": "stålbad",
    "stålbadens": "stålbad",
    "stålbadet": "stålbad",
    "stålbadets": "stålbad",
    "stålbads": "stålbad",
    "stålblåa": "stålblå",
    "stålblåare": "stålblå",
    "stålblåares": "stålblå",
    "stålblåas": "stålblå",
    "stålblåast": "stålblå",
    "stålblåaste": "stålblå",
    "stålblåastes": "stålblå",
    "stålblåasts": "stålblå",
    "stålblåe": "stålblå",
    "stålblåes": "stålblå",
    "stålblås": "stålblå",
    "stålblått": "stålblå",
    "stålblåtts": "stålblå",
    "stålborst": "stålborste",
    "stålborstar": "stålborste",
    "stålborstarna": "stålborste",
    "stålborstarnas": "stålborste",
    "stålborstars": "stålborste",
    "stålborsten": "stålborste",
    "stålborstens": "stålborste",
    "stålborstes": "stålborste",
    "stålbågade": "stålbågad",
    "stålbågades": "stålbågad",
    "stålbågads": "stålbågad",
    "stålbågat": "stålbågad",
    "stålbågats": "stålbågad",
    "stålen": "stål",
    "stålens": "stål",
    "stålet": "stål",
    "stålets": "stål",
    "stålfjädern": "stålfjäder",
    "stålfjäderns": "stålfjäder",
    "stålfjäders": "stålfjäder",
    "stålfjädrar": "stålfjäder",
    "stålfjädrarna": "stålfjäder",
    "stålfjädrarnas": "stålfjäder",
    "stålfjädrars": "stålfjäder",
    "stålframställningar": "stålframställning",
    "stålframställningarna": "stålframställning",
    "stålframställningarnas": "stålframställning",
    "stålframställningars": "stålframställning",
    "stålframställningen": "stålframställning",
    "stålframställningens": "stålframställning",
    "stålframställnings": "stålframställning",
    "stålhättade": "stålhättad",
    "stålhättades": "stålhättad",
    "stålhättads": "stålhättad",
    "stålhättat": "stålhättad",
    "stålhättats": "stålhättad",
    "stålhårda": "stålhård",
    "stålhårdare": "stålhård",
    "stålhårdares": "stålhård",
    "stålhårdas": "stålhård",
    "stålhårdast": "stålhård",
    "stålhårdaste": "stålhård",
    "stålhårdastes": "stålhård",
    "stålhårdasts": "stålhård",
    "stålhårde": "stålhård",
    "stålhårdes": "stålhård",
    "stålhårdheten": "stålhårdhet",
    "stålhårdhetens": "stålhårdhet",
    "stålhårdhets": "stålhårdhet",
    "stålhårds": "stålhård",
    "stålhårt": "stålhård",
    "stålhårts": "stålhård",
    "stålkonstruktionen": "stålkonstruktion",
    "stålkonstruktionens": "stålkonstruktion",
    "stålkonstruktioner": "stålkonstruktion",
    "stålkonstruktionerna": "stålkonstruktion",
    "stålkonstruktionernas": "stålkonstruktion",
    "stålkonstruktioners": "stålkonstruktion",
    "stålkonstruktions": "stålkonstruktion",
    "stållegeringar": "stållegering",
    "stållegeringarna": "stållegering",
    "stållegeringarnas": "stållegering",
    "stållegeringars": "stållegering",
    "stållegeringen": "stållegering",
    "stållegeringens": "stållegering",
    "stållegerings": "stållegering",
    "stålmannen": "stålman",
    "stålmannens": "stålman",
    "stålmans": "stålman",
    "stålmän": "stålman",
    "stålmännen": "stålman",
    "stålmännens": "stålman",
    "stålmäns": "stålman",
    "stålpipan": "stålpipa",
    "stålpipans": "stålpipa",
    "stålpipas": "stålpipa",
    "stålpipe": "stålpipa",
    "stålpipor": "stålpipa",
    "stålpiporna": "stålpipa",
    "stålpipornas": "stålpipa",
    "stålpipors": "stålpipa",
    "stålramar": "stålram",
    "stålramarna": "stålram",
    "stålramarnas": "stålram",
    "stålramars": "stålram",
    "stålramen": "stålram",
    "stålramens": "stålram",
    "stålrams": "stålram",
    "stålringar": "stålring",
    "stålringarna": "stålring",
    "stålringarnas": "stålring",
    "stålringars": "stålring",
    "stålringen": "stålring",
    "stålringens": "stålring",
    "stålrings": "stålring",
    "stålrundkul": "stålrundkula",
    "stålrundkulan": "stålrundkula",
    "stålrundkulans": "stålrundkula",
    "stålrundkulas": "stålrundkula",
    "stålrundkule": "stålrundkula",
    "stålrundkulor": "stålrundkula",
    "stålrundkulorna": "stålrundkula",
    "stålrundkulornas": "stålrundkula",
    "stålrundkulors": "stålrundkula",
    "stålrundkuls": "stålrundkula",
    "stålrören": "stålrör",
    "stålrörens": "stålrör",
    "stålröret": "stålrör",
    "stålrörets": "stålrör",
    "stålrörs": "stålrör",
    "stålrörsstolar": "stålrörsstol",
    "stålrörsstolarna": "stålrörsstol",
    "stålrörsstolarnas": "stålrörsstol",
    "stålrörsstolars": "stålrörsstol",
    "stålrörsstolen": "stålrörsstol",
    "stålrörsstolens": "stålrörsstol",
    "stålrörsstols": "stålrörsstol",
    "ståls": "stål",
    "stålskeletten": "stålskelett",
    "stålskelettens": "stålskelett",
    "stålskelettet": "stålskelett",
    "stålskelettets": "stålskelett",
    "stålskeletts": "stålskelett",
    "stålsken": "stålskena",
    "stålskenan": "stålskena",
    "stålskenans": "stålskena",
    "stålskenas": "stålskena",
    "stålskene": "stålskena",
    "stålskenor": "stålskena",
    "stålskenorna": "stålskena",
    "stålskenornas": "stålskena",
    "stålskenors": "stålskena",
    "stålskens": "stålskena",
    "stålsköldar": "stålsköld",
    "stålsköldarna": "stålsköld",
    "stålsköldarnas": "stålsköld",
    "stålsköldars": "stålsköld",
    "stålskölden": "stålsköld",
    "stålsköldens": "stålsköld",
    "stålskölds": "stålsköld",
    "stålspikar": "stålspik",
    "stålspikarna": "stålspik",
    "stålspikarnas": "stålspik",
    "stålspikars": "stålspik",
    "stålspiken": "stålspik",
    "stålspikens": "stålspik",
    "stålspiks": "stålspik",
    "stålsticken": "stålstick",
    "stålstickens": "stålstick",
    "stålsticket": "stålstick",
    "stålstickets": "stålstick",
    "stålsticks": "stålstick",
    "stålstommar": "stålstomme",
    "stålstommarna": "stålstomme",
    "stålstommarnas": "stålstomme",
    "stålstommars": "stålstomme",
    "stålstommen": "stålstomme",
    "stålstommens": "stålstomme",
    "stålstommes": "stålstomme",
    "ståltrycken": "ståltryck",
    "ståltryckens": "ståltryck",
    "ståltrycket": "ståltryck",
    "ståltryckets": "ståltryck",
    "ståltrycks": "ståltryck",
    "ståltråden": "ståltråd",
    "ståltrådens": "ståltråd",
    "ståltråds": "ståltråd",
    "stålullen": "stålull",
    "stålullens": "stålull",
    "stålulls": "stålull",
    "stålvajern": "stålvajer",
    "stålvajerns": "stålvajer",
    "stålvajers": "stålvajer",
    "stålvajrar": "stålvajer",
    "stålvajrarna": "stålvajer",
    "stålvajrarnas": "stålvajer",
    "stålvajrars": "stålvajer",
    "stålverken": "stålverk",
    "stålverkens": "stålverk",
    "stålverket": "stålverk",
    "stålverkets": "stålverk",
    "stålverks": "stålverk",
    "stålvita": "stålvit",
    "stålvitare": "stålvit",
    "stålvitares": "stålvit",
    "stålvitas": "stålvit",
    "stålvitast": "stålvit",
    "stålvitaste": "stålvit",
    "stålvitastes": "stålvit",
    "stålvitasts": "stålvit",
    "stålvite": "stålvit",
    "stålvites": "stålvit",
    "stålvits": "stålvit",
    "stålvitt": "stålvit",
    "stålvitts": "stålvit",
    "stålwirar": "stålwire",
    "stålwirarna": "stålwire",
    "stålwirarnas": "stålwire",
    "stålwirars": "stålwire",
    "stålwiren": "stålwire",
    "stålwirens": "stålwire",
    "stålwires": "stålwire",
    "stånd": "stånda",
    "ståndad": "stånda",
    "ståndade": "stånda",
    "ståndades": "stånda",
    "ståndads": "stånda",
    "ståndaktiga": "ståndaktig",
    "ståndaktigare": "ståndaktig",
    "ståndaktigares": "ståndaktig",
    "ståndaktigas": "ståndaktig",
    "ståndaktigast": "ståndaktig",
    "ståndaktigaste": "ståndaktig",
    "ståndaktigastes": "ståndaktig",
    "ståndaktigasts": "ståndaktig",
    "ståndaktige": "ståndaktig",
    "ståndaktiges": "ståndaktig",
    "ståndaktigheten": "ståndaktighet",
    "ståndaktighetens": "ståndaktighet",
    "ståndaktighets": "ståndaktighet",
    "ståndaktigs": "ståndaktig",
    "ståndaktigt": "ståndaktig",
    "ståndaktigts": "ståndaktig",
    "ståndande": "stånda",
    "ståndanden": "ståndande",
    "ståndandena": "ståndande",
    "ståndandenas": "ståndande",
    "ståndandens": "ståndande",
    "ståndandes": "ståndande",
    "ståndandet": "ståndande",
    "ståndandets": "ståndande",
    "ståndar": "ståndare",
    "ståndaren": "ståndare",
    "ståndarens": "ståndare",
    "ståndares": "ståndare",
    "ståndarna": "ståndare",
    "ståndarnas": "ståndare",
    "ståndas": "stånda",
    "ståndat": "stånda",
    "ståndats": "stånda",
    "stånden": "stånd",
    "ståndens": "stånd",
    "ståndet": "stånd",
    "ståndets": "stånd",
    "ståndkrag": "ståndkrage",
    "ståndkragar": "ståndkrage",
    "ståndkragarna": "ståndkrage",
    "ståndkragarnas": "ståndkrage",
    "ståndkragars": "ståndkrage",
    "ståndkragen": "ståndkrage",
    "ståndkragens": "ståndkrage",
    "ståndkrages": "ståndkrage",
    "ståndkrags": "ståndkrage",
    "ståndkrokar": "ståndkrok",
    "ståndkrokarna": "ståndkrok",
    "ståndkrokarnas": "ståndkrok",
    "ståndkrokars": "ståndkrok",
    "ståndkroken": "ståndkrok",
    "ståndkrokens": "ståndkrok",
    "ståndkroks": "ståndkrok",
    "ståndmanar": "ståndman",
    "ståndmanarna": "ståndman",
    "ståndmanarnas": "ståndman",
    "ståndmanars": "ståndman",
    "ståndmanen": "ståndman",
    "ståndmanens": "ståndman",
    "ståndmans": "ståndman",
    "ståndmässiga": "ståndmässig",
    "ståndmässigare": "ståndmässig",
    "ståndmässigares": "ståndmässig",
    "ståndmässigas": "ståndmässig",
    "ståndmässigast": "ståndmässig",
    "ståndmässigaste": "ståndmässig",
    "ståndmässigastes": "ståndmässig",
    "ståndmässigasts": "ståndmässig",
    "ståndmässige": "ståndmässig",
    "ståndmässiges": "ståndmässig",
    "ståndmässigheten": "ståndmässighet",
    "ståndmässighetens": "ståndmässighet",
    "ståndmässighets": "ståndmässighet",
    "ståndmässigs": "ståndmässig",
    "ståndmässigt": "ståndmässig",
    "ståndmässigts": "ståndmässig",
    "ståndorten": "ståndort",
    "ståndortens": "ståndort",
    "ståndorter": "ståndort",
    "ståndorterna": "ståndort",
    "ståndorternas": "ståndort",
    "ståndorters": "ståndort",
    "ståndorts": "ståndort",
    "ståndpunkten": "ståndpunkt",
    "ståndpunktens": "ståndpunkt",
    "ståndpunkter": "ståndpunkt",
    "ståndpunkterna": "ståndpunkt",
    "ståndpunkternas": "ståndpunkt",
    "ståndpunkters": "ståndpunkt",
    "ståndpunkts": "ståndpunkt",
    "ståndrätten": "ståndrätt",
    "ståndrättens": "ståndrätt",
    "ståndrätter": "ståndrätt",
    "ståndrätterna": "ståndrätt",
    "ståndrätternas": "ståndrätt",
    "ståndrätters": "ståndrätt",
    "ståndrätts": "ståndrätt",
    "stånds": "stånd",
    "ståndscirkulationen": "ståndscirkulation",
    "ståndscirkulationens": "ståndscirkulation",
    "ståndscirkulationer": "ståndscirkulation",
    "ståndscirkulationerna": "ståndscirkulation",
    "ståndscirkulationernas": "ståndscirkulation",
    "ståndscirkulationers": "ståndscirkulation",
    "ståndscirkulations": "ståndscirkulation",
    "ståndsmässiga": "ståndsmässig",
    "ståndsmässigare": "ståndsmässig",
    "ståndsmässigares": "ståndsmässig",
    "ståndsmässigas": "ståndsmässig",
    "ståndsmässigast": "ståndsmässig",
    "ståndsmässigaste": "ståndsmässig",
    "ståndsmässigastes": "ståndsmässig",
    "ståndsmässigasts": "ståndsmässig",
    "ståndsmässige": "ståndsmässig",
    "ståndsmässiges": "ståndsmässig",
    "ståndsmässigheten": "ståndsmässighet",
    "ståndsmässighetens": "ståndsmässighet",
    "ståndsmässighets": "ståndsmässighet",
    "ståndsmässigs": "ståndsmässig",
    "ståndsmässigt": "ståndsmässig",
    "ståndsmässigts": "ståndsmässig",
    "ståndspersonen": "ståndsperson",
    "ståndspersonens": "ståndsperson",
    "ståndspersoner": "ståndsperson",
    "ståndspersonerna": "ståndsperson",
    "ståndspersonernas": "ståndsperson",
    "ståndspersoners": "ståndsperson",
    "ståndspersons": "ståndsperson",
    "stång": "stånga",
    "stångad": "stånga",
    "stångade": "stånga",
    "stångades": "stångas",
    "stångads": "stånga",
    "stångande": "stånga",
    "stånganden": "stångande",
    "stångandena": "stångande",
    "stångandenas": "stångande",
    "stångandens": "stångande",
    "stångandes": "stångande",
    "stångandet": "stångande",
    "stångandets": "stångande",
    "stångar": "stånga",
    "stångas": "stånga",
    "stångat": "stånga",
    "stångats": "stångas",
    "stången": "stång",
    "stångens": "stång",
    "stånghammar": "stånghammare",
    "stånghammaren": "stånghammare",
    "stånghammarens": "stånghammare",
    "stånghammares": "stånghammare",
    "stånghamrar": "stånghammare",
    "stånghamrarna": "stånghammare",
    "stånghamrarnas": "stånghammare",
    "stånghamrars": "stånghammare",
    "stångjärnet": "stångjärn",
    "stångjärnets": "stångjärn",
    "stångjärns": "stångjärn",
    "stångjärnshammar": "stångjärnshammare",
    "stångjärnshammaren": "stångjärnshammare",
    "stångjärnshammarens": "stångjärnshammare",
    "stångjärnshammares": "stångjärnshammare",
    "stångjärnshamrar": "stångjärnshammare",
    "stångjärnshamrarna": "stångjärnshammare",
    "stångjärnshamrarnas": "stångjärnshammare",
    "stångjärnshamrars": "stångjärnshammare",
    "stångkorvar": "stångkorv",
    "stångkorvarna": "stångkorv",
    "stångkorvarnas": "stångkorv",
    "stångkorvars": "stångkorv",
    "stångkorven": "stångkorv",
    "stångkorvens": "stångkorv",
    "stångkorvs": "stångkorv",
    "stångpisk": "stångpiska",
    "stångpiskan": "stångpiska",
    "stångpiskans": "stångpiska",
    "stångpiskas": "stångpiska",
    "stångpiske": "stångpiska",
    "stångpiskor": "stångpiska",
    "stångpiskorna": "stångpiska",
    "stångpiskornas": "stångpiska",
    "stångpiskors": "stångpiska",
    "stångryttar": "stångryttare",
    "stångryttaren": "stångryttare",
    "stångryttarens": "stångryttare",
    "stångryttares": "stångryttare",
    "stångryttarna": "stångryttare",
    "stångryttarnas": "stångryttare",
    "stångs": "stång",
    "stångstörtningar": "stångstörtning",
    "stångstörtningarna": "stångstörtning",
    "stångstörtningarnas": "stångstörtning",
    "stångstörtningars": "stångstörtning",
    "stångstörtningen": "stångstörtning",
    "stångstörtningens": "stångstörtning",
    "stångstörtnings": "stångstörtning",
    "stånk": "stånka",
    "stånkad": "stånka",
    "stånkade": "stånka",
    "stånkades": "stånka",
    "stånkads": "stånka",
    "stånkan": "stånka",
    "stånkande": "stånka",
    "stånkanden": "stånkande",
    "stånkandena": "stånkande",
    "stånkandenas": "stånkande",
    "stånkandens": "stånkande",
    "stånkandes": "stånkande",
    "stånkandet": "stånkande",
    "stånkandets": "stånkande",
    "stånkans": "stånka",
    "stånkar": "stånka",
    "stånkas": "stånka",
    "stånkat": "stånka",
    "stånkats": "stånka",
    "stånke": "stånka",
    "stånket": "stånk",
    "stånkets": "stånk",
    "stånkor": "stånka",
    "stånkorna": "stånka",
    "stånkornas": "stånka",
    "stånkors": "stånka",
    "stånks": "stånka",
    "ståplatsen": "ståplats",
    "ståplatsens": "ståplats",
    "ståplatser": "ståplats",
    "ståplatserna": "ståplats",
    "ståplatsernas": "ståplats",
    "ståplatsers": "ståplats",
    "står": "stå",
    "stås": "stå",
    "ståt": "ståta",
    "ståtad": "ståta",
    "ståtade": "ståta",
    "ståtades": "ståta",
    "ståtads": "ståta",
    "ståtande": "ståta",
    "ståtanden": "ståtande",
    "ståtandena": "ståtande",
    "ståtandenas": "ståtande",
    "ståtandens": "ståtande",
    "ståtandes": "ståtande",
    "ståtandet": "ståtande",
    "ståtandets": "ståtande",
    "ståtar": "ståta",
    "ståtas": "ståta",
    "ståtat": "ståta",
    "ståtats": "ståta",
    "ståten": "ståt",
    "ståtens": "ståt",
    "ståthållar": "ståthållare",
    "ståthållaren": "ståthållare",
    "ståthållarens": "ståthållare",
    "ståthållares": "ståthållare",
    "ståthållarna": "ståthållare",
    "ståthållarnas": "ståthållare",
    "ståtliga": "ståtlig",
    "ståtligare": "ståtlig",
    "ståtligares": "ståtlig",
    "ståtligas": "ståtlig",
    "ståtligast": "ståtlig",
    "ståtligaste": "ståtlig",
    "ståtligastes": "ståtlig",
    "ståtligasts": "ståtlig",
    "ståtlige": "ståtlig",
    "ståtliges": "ståtlig",
    "ståtligheten": "ståtlighet",
    "ståtlighetens": "ståtlighet",
    "ståtlighets": "ståtlighet",
    "ståtligs": "ståtlig",
    "ståtligt": "ståtlig",
    "ståtligts": "ståtlig",
    "ståts": "ståt",
    "stått": "stå",
    "ståtts": "stå",
    "ståuppar": "ståuppare",
    "ståupparen": "ståuppare",
    "ståupparens": "ståuppare",
    "ståuppares": "ståuppare",
    "ståupparna": "ståuppare",
    "ståupparnas": "ståuppare",
    "ståuppföreställningar": "ståuppföreställning",
    "ståuppföreställningarna": "ståuppföreställning",
    "ståuppföreställningarnas": "ståuppföreställning",
    "ståuppföreställningars": "ståuppföreställning",
    "ståuppföreställningen": "ståuppföreställning",
    "ståuppföreställningens": "ståuppföreställning",
    "ståuppföreställnings": "ståuppföreställning",
    "ståuppkomikern": "ståuppkomiker",
    "ståuppkomikerna": "ståuppkomiker",
    "ståuppkomikernas": "ståuppkomiker",
    "ståuppkomikerns": "ståuppkomiker",
    "ståuppkomikers": "ståuppkomiker",
    "stöd": "stödja",
    "stöda": "stödja",
    "stödande": "stödja",
    "stödandes": "stödja",
    "stödas": "stödja",
    "stödd": "stödja",
    "stödda": "stödja",
    "stöddas": "stödja",
    "stödde": "stödja",
    "stöddes": "stödja",
    "stöddiga": "stöddig",
    "stöddigare": "stöddig",
    "stöddigares": "stöddig",
    "stöddigas": "stöddig",
    "stöddigast": "stöddig",
    "stöddigaste": "stöddig",
    "stöddigastes": "stöddig",
    "stöddigasts": "stöddig",
    "stöddige": "stöddig",
    "stöddiges": "stöddig",
    "stöddigheten": "stöddighet",
    "stöddighetens": "stöddighet",
    "stöddighets": "stöddighet",
    "stöddigs": "stöddig",
    "stöddigt": "stöddig",
    "stöddigts": "stöddig",
    "stödds": "stödja",
    "stöden": "stöd",
    "stödens": "stöd",
    "stöder": "stödja",
    "stödes": "stödja",
    "stödet": "stöd",
    "stödets": "stöd",
    "stödfestivalen": "stödfestival",
    "stödfestivalens": "stödfestival",
    "stödfestivaler": "stödfestival",
    "stödfestivalerna": "stödfestival",
    "stödfestivalernas": "stödfestival",
    "stödfestivalers": "stödfestival",
    "stödfestivals": "stödfestival",
    "stödgalan": "stödgala",
    "stödgalans": "stödgala",
    "stödgalas": "stödgala",
    "stödgalor": "stödgala",
    "stödgalorna": "stödgala",
    "stödgalornas": "stödgala",
    "stödgalors": "stödgala",
    "stödhjulen": "stödhjul",
    "stödhjulens": "stödhjul",
    "stödhjulet": "stödhjul",
    "stödhjulets": "stödhjul",
    "stödhjuls": "stödhjul",
    "stödinsatsen": "stödinsats",
    "stödinsatsens": "stödinsats",
    "stödinsatser": "stödinsats",
    "stödinsatserna": "stödinsats",
    "stödinsatsernas": "stödinsats",
    "stödinsatsers": "stödinsats",
    "stödjande": "stödja",
    "stödjanden": "stödjande",
    "stödjandena": "stödjande",
    "stödjandenas": "stödjande",
    "stödjandens": "stödjande",
    "stödjandes": "stödjande",
    "stödjandet": "stödjande",
    "stödjandets": "stödjande",
    "stödjas": "stödja",
    "stödje": "stödja",
    "stödjecellen": "stödjecell",
    "stödjecellens": "stödjecell",
    "stödjeceller": "stödjecell",
    "stödjecellerna": "stödjecell",
    "stödjecellernas": "stödjecell",
    "stödjecellers": "stödjecell",
    "stödjecells": "stödjecell",
    "stödjepunkten": "stödjepunkt",
    "stödjepunktens": "stödjepunkt",
    "stödjepunkter": "stödjepunkt",
    "stödjepunkterna": "stödjepunkt",
    "stödjepunkternas": "stödjepunkt",
    "stödjepunkters": "stödjepunkt",
    "stödjepunkts": "stödjepunkt",
    "stödjer": "stödja",
    "stödjevävnaden": "stödjevävnad",
    "stödjevävnadens": "stödjevävnad",
    "stödjevävnader": "stödjevävnad",
    "stödjevävnaderna": "stödjevävnad",
    "stödjevävnadernas": "stödjevävnad",
    "stödjevävnaders": "stödjevävnad",
    "stödjevävnads": "stödjevävnad",
    "stödjordbruken": "stödjordbruk",
    "stödjordbrukens": "stödjordbruk",
    "stödjordbruket": "stödjordbruk",
    "stödjordbrukets": "stödjordbruk",
    "stödjordbruks": "stödjordbruk",
    "stödköp": "stödköpa",
    "stödköpande": "stödköpa",
    "stödköpanden": "stödköpande",
    "stödköpandena": "stödköpande",
    "stödköpandenas": "stödköpande",
    "stödköpandens": "stödköpande",
    "stödköpandes": "stödköpande",
    "stödköpandet": "stödköpande",
    "stödköpandets": "stödköpande",
    "stödköpas": "stödköpa",
    "stödköpen": "stödköp",
    "stödköpens": "stödköp",
    "stödköper": "stödköpa",
    "stödköpes": "stödköpa",
    "stödköpet": "stödköp",
    "stödköpets": "stödköp",
    "stödköps": "stödköpa",
    "stödköpt": "stödköpa",
    "stödköpta": "stödköpa",
    "stödköptas": "stödköpa",
    "stödköpte": "stödköpa",
    "stödköptes": "stödköpa",
    "stödköpts": "stödköpa",
    "stödområden": "stödområde",
    "stödområdena": "stödområde",
    "stödområdenas": "stödområde",
    "stödområdens": "stödområde",
    "stödområdes": "stödområde",
    "stödområdet": "stödområde",
    "stödområdets": "stödområde",
    "stödpapperen": "stödpapper",
    "stödpapperens": "stödpapper",
    "stödpapperet": "stödpapper",
    "stödpapperets": "stödpapper",
    "stödpapperna": "stödpapper",
    "stödpappernas": "stödpapper",
    "stödpappers": "stödpapper",
    "stödpappren": "stödpapper",
    "stödpapprens": "stödpapper",
    "stödpappret": "stödpapper",
    "stödpapprets": "stödpapper",
    "stöds": "stödja",
    "stödsamtalen": "stödsamtal",
    "stödsamtalens": "stödsamtal",
    "stödsamtalet": "stödsamtal",
    "stödsamtalets": "stödsamtal",
    "stödsamtals": "stödsamtal",
    "stödundervisningar": "stödundervisning",
    "stödundervisningarna": "stödundervisning",
    "stödundervisningarnas": "stödundervisning",
    "stödundervisningars": "stödundervisning",
    "stödundervisningen": "stödundervisning",
    "stödundervisningens": "stödundervisning",
    "stödundervisnings": "stödundervisning",
    "stödåtgärden": "stödåtgärd",
    "stödåtgärdens": "stödåtgärd",
    "stödåtgärder": "stödåtgärd",
    "stödåtgärderna": "stödåtgärd",
    "stödåtgärdernas": "stödåtgärd",
    "stödåtgärders": "stödåtgärd",
    "stödåtgärds": "stödåtgärd",
    "stök": "stöka",
    "stökad": "stöka",
    "stökade": "stöka",
    "stökades": "stöka",
    "stökads": "stöka",
    "stökande": "stöka",
    "stökanden": "stökande",
    "stökandena": "stökande",
    "stökandenas": "stökande",
    "stökandens": "stökande",
    "stökandes": "stökande",
    "stökandet": "stökande",
    "stökandets": "stökande",
    "stökar": "stöka",
    "stökas": "stöka",
    "stökat": "stöka",
    "stökats": "stöka",
    "stöket": "stök",
    "stökets": "stök",
    "stökiga": "stökig",
    "stökigare": "stökig",
    "stökigares": "stökig",
    "stökigas": "stökig",
    "stökigast": "stökig",
    "stökigaste": "stökig",
    "stökigastes": "stökig",
    "stökigasts": "stökig",
    "stökige": "stökig",
    "stökiges": "stökig",
    "stökigheten": "stökighet",
    "stökighetens": "stökighet",
    "stökigheter": "stökighet",
    "stökigheterna": "stökighet",
    "stökigheternas": "stökighet",
    "stökigheters": "stökighet",
    "stökighets": "stökighet",
    "stökigs": "stökig",
    "stökigt": "stökig",
    "stökigts": "stökig",
    "stökiometrien": "stökiometri",
    "stökiometriens": "stökiometri",
    "stökiometrin": "stökiometri",
    "stökiometrins": "stökiometri",
    "stökiometris": "stökiometri",
    "stöks": "stök",
    "stölden": "stöld",
    "stöldens": "stöld",
    "stölder": "stöld",
    "stölderna": "stöld",
    "stöldernas": "stöld",
    "stölders": "stöld",
    "stöldgodset": "stöldgods",
    "stöldgodsets": "stöldgods",
    "stöldligan": "stöldliga",
    "stöldligans": "stöldliga",
    "stöldligas": "stöldliga",
    "stöldlige": "stöldliga",
    "stöldligor": "stöldliga",
    "stöldligorna": "stöldliga",
    "stöldligornas": "stöldliga",
    "stöldligors": "stöldliga",
    "stöldräden": "stöldräd",
    "stöldrädens": "stöldräd",
    "stöldräder": "stöldräd",
    "stöldräderna": "stöldräd",
    "stöldrädernas": "stöldräd",
    "stöldräders": "stöldräd",
    "stöldräds": "stöldräd",
    "stölds": "stöld",
    "stöldsäkerheten": "stöldsäkerhet",
    "stöldsäkerhetens": "stöldsäkerhet",
    "stöldsäkerhets": "stöldsäkerhet",
    "stöldsäkers": "stöldsäker",
    "stöldsäkert": "stöldsäker",
    "stöldsäkerts": "stöldsäker",
    "stöldsäkra": "stöldsäker",
    "stöldsäkrare": "stöldsäker",
    "stöldsäkrares": "stöldsäker",
    "stöldsäkras": "stöldsäker",
    "stöldsäkrast": "stöldsäker",
    "stöldsäkraste": "stöldsäker",
    "stöldsäkrastes": "stöldsäker",
    "stöldsäkrasts": "stöldsäker",
    "stöldsäkre": "stöldsäker",
    "stöldsäkres": "stöldsäker",
    "stöldturnéer": "stöldturné",
    "stöldturnéerna": "stöldturné",
    "stöldturnéernas": "stöldturné",
    "stöldturnéers": "stöldturné",
    "stöldturnén": "stöldturné",
    "stöldturnéns": "stöldturné",
    "stöldturnés": "stöldturné",
    "stölen": "stöl",
    "stölens": "stöl",
    "stöls": "stöl",
    "stön": "stöna",
    "stönad": "stöna",
    "stönade": "stöna",
    "stönades": "stöna",
    "stönads": "stöna",
    "stönande": "stöna",
    "stönanden": "stönande",
    "stönandena": "stönande",
    "stönandenas": "stönande",
    "stönandens": "stönande",
    "stönandes": "stönande",
    "stönandet": "stönande",
    "stönandets": "stönande",
    "stönar": "stöna",
    "stönas": "stöna",
    "stönat": "stöna",
    "stönats": "stöna",
    "stönen": "stön",
    "stönens": "stön",
    "stönet": "stön",
    "stönets": "stön",
    "stöns": "stön",
    "stöp": "stupa",
    "stöpande": "stöpa",
    "stöpanden": "stöpande",
    "stöpandena": "stöpande",
    "stöpandenas": "stöpande",
    "stöpandens": "stöpande",
    "stöpandes": "stöpande",
    "stöpandet": "stöpande",
    "stöpandets": "stöpande",
    "stöpas": "stöpa",
    "stöpe": "stupa",
    "stöper": "stöpa",
    "stöpes": "stupa",
    "stöpisen": "stöpis",
    "stöpisens": "stöpis",
    "stöppel": "stöppla",
    "stöpplad": "stöppla",
    "stöpplade": "stöppla",
    "stöpplades": "stöppla",
    "stöpplads": "stöppla",
    "stöpplande": "stöppla",
    "stöpplanden": "stöpplande",
    "stöpplandena": "stöpplande",
    "stöpplandenas": "stöpplande",
    "stöpplandens": "stöpplande",
    "stöpplandes": "stöpplande",
    "stöpplandet": "stöpplande",
    "stöpplandets": "stöpplande",
    "stöpplar": "stöpplare",
    "stöpplaren": "stöpplare",
    "stöpplarens": "stöpplare",
    "stöpplares": "stöpplare",
    "stöpplarna": "stöpplare",
    "stöpplarnas": "stöpplare",
    "stöpplas": "stöppla",
    "stöpplat": "stöppla",
    "stöpplats": "stöppla",
    "stöps": "stupa",
    "stöpt": "stöpa",
    "stöpta": "stöpa",
    "stöptas": "stöpa",
    "stöpte": "stöpa",
    "stöptes": "stöpa",
    "stöpts": "stöpa",
    "stör": "störa",
    "störad": "störa",
    "störade": "störa",
    "störades": "störa",
    "störads": "störa",
    "störande": "störa",
    "störanden": "störande",
    "störandena": "störande",
    "störandenas": "störande",
    "störandens": "störande",
    "störandes": "störande",
    "störandet": "störande",
    "störandets": "störande",
    "störar": "störa",
    "störarna": "stör",
    "störarnas": "stör",
    "störars": "stör",
    "störas": "störa",
    "störat": "störa",
    "störatomen": "störatom",
    "störatomens": "störatom",
    "störatomer": "störatom",
    "störatomerna": "störatom",
    "störatomernas": "störatom",
    "störatomers": "störatom",
    "störatoms": "störatom",
    "störats": "störa",
    "störbön": "störböna",
    "störbönan": "störböna",
    "störbönans": "störböna",
    "störbönas": "störböna",
    "störböne": "störböna",
    "störbönor": "störböna",
    "störbönorna": "störböna",
    "störbönornas": "störböna",
    "störbönors": "störböna",
    "störböns": "störböna",
    "störd": "störa",
    "störda": "störa",
    "stördas": "störa",
    "störde": "störa",
    "stördes": "störa",
    "störds": "störa",
    "stören": "stör",
    "störens": "stör",
    "störes": "störa",
    "störningar": "störning",
    "störningarna": "störning",
    "störningarnas": "störning",
    "störningars": "störning",
    "störningen": "störning",
    "störningens": "störning",
    "störnings": "störning",
    "större": "stor",
    "störres": "stor",
    "störs": "störa",
    "störskydden": "störskydd",
    "störskyddens": "störskydd",
    "störskyddet": "störskydd",
    "störskyddets": "störskydd",
    "störskydds": "störskydd",
    "störst": "stor",
    "största": "stor",
    "störstas": "stor",
    "störste": "stor",
    "störstes": "stor",
    "störsts": "stor",
    "stört": "störta",
    "störtad": "störta",
    "störtade": "störta",
    "störtades": "störta",
    "störtads": "störta",
    "störtande": "störta",
    "störtanden": "störtande",
    "störtandena": "störtande",
    "störtandenas": "störtande",
    "störtandens": "störtande",
    "störtandes": "störtande",
    "störtandet": "störtande",
    "störtandets": "störtande",
    "störtar": "störta",
    "störtas": "störta",
    "störtat": "störta",
    "störtats": "störta",
    "störtblöd": "störtblöda",
    "störtblödande": "störtblöda",
    "störtblödandes": "störtblöda",
    "störtblödas": "störtblöda",
    "störtblödd": "störtblöda",
    "störtblödda": "störtblöda",
    "störtblöddas": "störtblöda",
    "störtblödde": "störtblöda",
    "störtblöddes": "störtblöda",
    "störtblödds": "störtblöda",
    "störtblöder": "störtblöda",
    "störtblödes": "störtblöda",
    "störtblöds": "störtblöda",
    "störtblött": "störtblöda",
    "störtblötts": "störtblöda",
    "störtfloden": "störtflod",
    "störtflodens": "störtflod",
    "störtfloder": "störtflod",
    "störtfloderna": "störtflod",
    "störtflodernas": "störtflod",
    "störtfloders": "störtflod",
    "störtflods": "störtflod",
    "störtförbannade": "störtförbannad",
    "störtförbannades": "störtförbannad",
    "störtförbannads": "störtförbannad",
    "störtförbannat": "störtförbannad",
    "störtförbannats": "störtförbannad",
    "störthjälmar": "störthjälm",
    "störthjälmarna": "störthjälm",
    "störthjälmarnas": "störthjälm",
    "störthjälmars": "störthjälm",
    "störthjälmen": "störthjälm",
    "störthjälmens": "störthjälm",
    "störthjälms": "störthjälm",
    "störtkära": "störtkär",
    "störtkärare": "störtkär",
    "störtkärares": "störtkär",
    "störtkäras": "störtkär",
    "störtkärast": "störtkär",
    "störtkäraste": "störtkär",
    "störtkärastes": "störtkär",
    "störtkärasts": "störtkär",
    "störtkäre": "störtkär",
    "störtkäres": "störtkär",
    "störtkärs": "störtkär",
    "störtkärt": "störtkär",
    "störtkärts": "störtkär",
    "störtloppen": "störtlopp",
    "störtloppens": "störtlopp",
    "störtloppet": "störtlopp",
    "störtloppets": "störtlopp",
    "störtlopps": "störtlopp",
    "störts": "störa",
    "stöt": "stöta",
    "stötande": "stöta",
    "stötanden": "stötande",
    "stötandena": "stötande",
    "stötandenas": "stötande",
    "stötandens": "stötande",
    "stötandes": "stötande",
    "stötandet": "stötande",
    "stötandets": "stötande",
    "stötar": "stöt",
    "stötarna": "stöt",
    "stötarnas": "stöt",
    "stötars": "stöt",
    "stötas": "stöta",
    "stötdämpar": "stötdämpare",
    "stötdämparen": "stötdämpare",
    "stötdämparens": "stötdämpare",
    "stötdämpares": "stötdämpare",
    "stötdämparna": "stötdämpare",
    "stötdämparnas": "stötdämpare",
    "stöten": "stöt",
    "stötens": "stöt",
    "stöter": "stöta",
    "stötes": "stöta",
    "stötestenar": "stötesten",
    "stötestenarna": "stötesten",
    "stötestenarnas": "stötesten",
    "stötestenars": "stötesten",
    "stötestenen": "stötesten",
    "stötestenens": "stötesten",
    "stötestens": "stötesten",
    "stötfångar": "stötfångare",
    "stötfångaren": "stötfångare",
    "stötfångarens": "stötfångare",
    "stötfångares": "stötfångare",
    "stötfångarna": "stötfångare",
    "stötfångarnas": "stötfångare",
    "stöts": "stöta",
    "stötsidan": "stötsida",
    "stötsidans": "stötsida",
    "stötsidas": "stötsida",
    "stötside": "stötsida",
    "stötsides": "stötsida",
    "stötsidor": "stötsida",
    "stötsidorna": "stötsida",
    "stötsidornas": "stötsida",
    "stötsidors": "stötsida",
    "stötskydden": "stötskydd",
    "stötskyddens": "stötskydd",
    "stötskyddet": "stötskydd",
    "stötskyddets": "stötskydd",
    "stötskydds": "stötskydd",
    "stött": "stötta",
    "stötta": "stött",
    "stöttad": "stötta",
    "stöttade": "stötta",
    "stöttades": "stötta",
    "stöttads": "stötta",
    "stöttan": "stötta",
    "stöttande": "stötta",
    "stöttanden": "stöttande",
    "stöttandena": "stöttande",
    "stöttandenas": "stöttande",
    "stöttandens": "stöttande",
    "stöttandes": "stöttande",
    "stöttandet": "stöttande",
    "stöttandets": "stöttande",
    "stöttans": "stötta",
    "stöttar": "stötta",
    "stöttare": "stött",
    "stöttares": "stött",
    "stöttas": "stötta",
    "stöttast": "stött",
    "stöttaste": "stött",
    "stöttastes": "stött",
    "stöttasts": "stött",
    "stöttat": "stötta",
    "stöttats": "stötta",
    "stötte": "stötta",
    "stöttepelar": "stöttepelare",
    "stöttepelaren": "stöttepelare",
    "stöttepelarens": "stöttepelare",
    "stöttepelares": "stöttepelare",
    "stöttepelarna": "stöttepelare",
    "stöttepelarnas": "stöttepelare",
    "stöttes": "stött",
    "stöttheten": "stötthet",
    "stötthetens": "stötthet",
    "stötthets": "stötthet",
    "stöttor": "stötta",
    "stöttorna": "stötta",
    "stöttornas": "stötta",
    "stöttors": "stötta",
    "stötts": "stötta",
    "stöttåliga": "stöttålig",
    "stöttåligare": "stöttålig",
    "stöttåligares": "stöttålig",
    "stöttåligas": "stöttålig",
    "stöttåligast": "stöttålig",
    "stöttåligaste": "stöttålig",
    "stöttåligastes": "stöttålig",
    "stöttåligasts": "stöttålig",
    "stöttålige": "stöttålig",
    "stöttåliges": "stöttålig",
    "stöttåligheten": "stöttålighet",
    "stöttålighetens": "stöttålighet",
    "stöttålighets": "stöttålighet",
    "stöttåligs": "stöttålig",
    "stöttåligt": "stöttålig",
    "stöttåligts": "stöttålig",
    "stötvisa": "stötvis",
    "stötvisare": "stötvis",
    "stötvisares": "stötvis",
    "stötvisas": "stötvis",
    "stötvisast": "stötvis",
    "stötvisaste": "stötvis",
    "stötvisastes": "stötvis",
    "stötvisasts": "stötvis",
    "stötvise": "stötvis",
    "stötvises": "stötvis",
    "stötvist": "stötvis",
    "stötvists": "stötvis",
    "stötvågen": "stötvåg",
    "stötvågens": "stötvåg",
    "stötvågor": "stötvåg",
    "stötvågorna": "stötvåg",
    "stötvågornas": "stötvåg",
    "stötvågors": "stötvåg",
    "stötvågs": "stötvåg",
    "stövar": "stövare",
    "stövaren": "stövare",
    "stövarens": "stövare",
    "stövares": "stövare",
    "stövarna": "stövare",
    "stövarnas": "stövare",
    "stövelklackar": "stövelklack",
    "stövelklackarna": "stövelklack",
    "stövelklackarnas": "stövelklack",
    "stövelklackars": "stövelklack",
    "stövelklacken": "stövelklack",
    "stövelklackens": "stövelklack",
    "stövelklacks": "stövelklack",
    "stövelknektar": "stövelknekt",
    "stövelknektarna": "stövelknekt",
    "stövelknektarnas": "stövelknekt",
    "stövelknektars": "stövelknekt",
    "stövelknekten": "stövelknekt",
    "stövelknektens": "stövelknekt",
    "stövelknekts": "stövelknekt",
    "stöveln": "stövel",
    "stövelns": "stövel",
    "stövels": "stövel",
    "stövelskaften": "stövelskaft",
    "stövelskaftens": "stövelskaft",
    "stövelskaftet": "stövelskaft",
    "stövelskaftets": "stövelskaft",
    "stövelskafts": "stövelskaft",
    "stövelspetsar": "stövelspets",
    "stövelspetsarna": "stövelspets",
    "stövelspetsarnas": "stövelspets",
    "stövelspetsars": "stövelspets",
    "stövelspetsen": "stövelspets",
    "stövelspetsens": "stövelspets",
    "stöveltrampet": "stöveltramp",
    "stöveltrampets": "stöveltramp",
    "stöveltramps": "stöveltramp",
    "stövet": "stöv",
    "stövets": "stöv",
    "stövlad": "stövla",
    "stövlade": "stövla",
    "stövlades": "stövla",
    "stövlads": "stövla",
    "stövlande": "stövla",
    "stövlanden": "stövlande",
    "stövlandena": "stövlande",
    "stövlandenas": "stövlande",
    "stövlandens": "stövlande",
    "stövlandes": "stövlande",
    "stövlandet": "stövlande",
    "stövlandets": "stövlande",
    "stövlar": "stövla",
    "stövlarna": "stövel",
    "stövlarnas": "stövel",
    "stövlars": "stövel",
    "stövlas": "stövla",
    "stövlat": "stövla",
    "stövlats": "stövla",
    "stövletten": "stövlett",
    "stövlettens": "stövlett",
    "stövletter": "stövlett",
    "stövletterna": "stövlett",
    "stövletternas": "stövlett",
    "stövletters": "stövlett",
    "stövletts": "stövlett",
    "stövs": "stöv",
    "suahilin": "suahili",
    "suahilins": "suahili",
    "suahilis": "suahili",
    "subalpina": "subalpin",
    "subalpinare": "subalpin",
    "subalpinares": "subalpin",
    "subalpinas": "subalpin",
    "subalpinast": "subalpin",
    "subalpinaste": "subalpin",
    "subalpinastes": "subalpin",
    "subalpinasts": "subalpin",
    "subalpine": "subalpin",
    "subalpines": "subalpin",
    "subalpins": "subalpin",
    "subalpint": "subalpin",
    "subalpints": "subalpin",
    "subalternen": "subaltern",
    "subalternens": "subaltern",
    "subalterner": "subaltern",
    "subalternerna": "subaltern",
    "subalternernas": "subaltern",
    "subalterners": "subaltern",
    "subalterns": "subaltern",
    "subantarktiska": "subantarktisk",
    "subantarktiskare": "subantarktisk",
    "subantarktiskares": "subantarktisk",
    "subantarktiskas": "subantarktisk",
    "subantarktiskast": "subantarktisk",
    "subantarktiskaste": "subantarktisk",
    "subantarktiskastes": "subantarktisk",
    "subantarktiskasts": "subantarktisk",
    "subantarktiske": "subantarktisk",
    "subantarktiskes": "subantarktisk",
    "subantarktisks": "subantarktisk",
    "subantarktiskt": "subantarktisk",
    "subantarktiskts": "subantarktisk",
    "subarktiska": "subarktisk",
    "subarktiskare": "subarktisk",
    "subarktiskares": "subarktisk",
    "subarktiskas": "subarktisk",
    "subarktiskast": "subarktisk",
    "subarktiskaste": "subarktisk",
    "subarktiskastes": "subarktisk",
    "subarktiskasts": "subarktisk",
    "subarktiske": "subarktisk",
    "subarktiskes": "subarktisk",
    "subarktisks": "subarktisk",
    "subarktiskt": "subarktisk",
    "subarktiskts": "subarktisk",
    "subb": "subba",
    "subban": "subba",
    "subbans": "subba",
    "subbas": "subba",
    "subbe": "subba",
    "subbiga": "subbig",
    "subbigare": "subbig",
    "subbigares": "subbig",
    "subbigas": "subbig",
    "subbigast": "subbig",
    "subbigaste": "subbig",
    "subbigastes": "subbig",
    "subbigasts": "subbig",
    "subbige": "subbig",
    "subbiges": "subbig",
    "subbigheten": "subbighet",
    "subbighetens": "subbighet",
    "subbighets": "subbighet",
    "subbigs": "subbig",
    "subbigt": "subbig",
    "subbigts": "subbig",
    "subbor": "subba",
    "subborna": "subba",
    "subbornas": "subba",
    "subbors": "subba",
    "subbs": "subba",
    "subdominanten": "subdominant",
    "subdominantens": "subdominant",
    "subdominanter": "subdominant",
    "subdominanterna": "subdominant",
    "subdominanternas": "subdominant",
    "subdominanters": "subdominant",
    "subdominants": "subdominant",
    "subjekten": "subjekt",
    "subjektens": "subjekt",
    "subjektet": "subjekt",
    "subjektets": "subjekt",
    "subjektiva": "subjektiv",
    "subjektivare": "subjektiv",
    "subjektivares": "subjektiv",
    "subjektivas": "subjektiv",
    "subjektivast": "subjektiv",
    "subjektivaste": "subjektiv",
    "subjektivastes": "subjektiv",
    "subjektivasts": "subjektiv",
    "subjektive": "subjektiv",
    "subjektives": "subjektiv",
    "subjektivismen": "subjektivism",
    "subjektivismens": "subjektivism",
    "subjektivismer": "subjektivism",
    "subjektivismerna": "subjektivism",
    "subjektivismernas": "subjektivism",
    "subjektivismers": "subjektivism",
    "subjektivisms": "subjektivism",
    "subjektivistiska": "subjektivistisk",
    "subjektivistiskas": "subjektivistisk",
    "subjektivistiske": "subjektivistisk",
    "subjektivistiskes": "subjektivistisk",
    "subjektivistisks": "subjektivistisk",
    "subjektivistiskt": "subjektivistisk",
    "subjektivistiskts": "subjektivistisk",
    "subjektiviteten": "subjektivitet",
    "subjektivitetens": "subjektivitet",
    "subjektiviteter": "subjektivitet",
    "subjektiviteterna": "subjektivitet",
    "subjektiviteternas": "subjektivitet",
    "subjektiviteters": "subjektivitet",
    "subjektivitets": "subjektivitet",
    "subjektivs": "subjektiv",
    "subjektivt": "subjektiv",
    "subjektivts": "subjektiv",
    "subjekts": "subjekt",
    "subjunktionen": "subjunktion",
    "subjunktionens": "subjunktion",
    "subjunktioner": "subjunktion",
    "subjunktionerna": "subjunktion",
    "subjunktionernas": "subjunktion",
    "subjunktioners": "subjunktion",
    "subjunktions": "subjunktion",
    "subkontinenten": "subkontinent",
    "subkontinentens": "subkontinent",
    "subkontinenter": "subkontinent",
    "subkontinenterna": "subkontinent",
    "subkontinenternas": "subkontinent",
    "subkontinenters": "subkontinent",
    "subkontinents": "subkontinent",
    "subkulturen": "subkultur",
    "subkulturens": "subkultur",
    "subkulturer": "subkultur",
    "subkulturerna": "subkultur",
    "subkulturernas": "subkultur",
    "subkulturers": "subkultur",
    "subkulturs": "subkultur",
    "subkutana": "subkutan",
    "subkutanare": "subkutan",
    "subkutanares": "subkutan",
    "subkutanas": "subkutan",
    "subkutanast": "subkutan",
    "subkutanaste": "subkutan",
    "subkutanastes": "subkutan",
    "subkutanasts": "subkutan",
    "subkutane": "subkutan",
    "subkutanes": "subkutan",
    "subkutans": "subkutan",
    "subkutant": "subkutan",
    "subkutants": "subkutan",
    "sublima": "sublim",
    "sublimare": "sublim",
    "sublimares": "sublim",
    "sublimas": "sublim",
    "sublimast": "sublim",
    "sublimaste": "sublim",
    "sublimastes": "sublim",
    "sublimasts": "sublim",
    "sublimaten": "sublimat",
    "sublimatens": "sublimat",
    "sublimatet": "sublimat",
    "sublimatets": "sublimat",
    "sublimationen": "sublimation",
    "sublimationens": "sublimation",
    "sublimationer": "sublimation",
    "sublimationerna": "sublimation",
    "sublimationernas": "sublimation",
    "sublimationers": "sublimation",
    "sublimations": "sublimation",
    "sublimats": "sublimat",
    "sublime": "sublim",
    "sublimerad": "sublimera",
    "sublimerade": "sublimera",
    "sublimerades": "sublimera",
    "sublimerads": "sublimera",
    "sublimerande": "sublimera",
    "sublimeranden": "sublimerande",
    "sublimerandena": "sublimerande",
    "sublimerandenas": "sublimerande",
    "sublimerandens": "sublimerande",
    "sublimerandes": "sublimerande",
    "sublimerandet": "sublimerande",
    "sublimerandets": "sublimerande",
    "sublimerar": "sublimera",
    "sublimeras": "sublimera",
    "sublimerat": "sublimera",
    "sublimerats": "sublimera",
    "sublimerbara": "sublimerbar",
    "sublimerbarare": "sublimerbar",
    "sublimerbarares": "sublimerbar",
    "sublimerbaras": "sublimerbar",
    "sublimerbarast": "sublimerbar",
    "sublimerbaraste": "sublimerbar",
    "sublimerbarastes": "sublimerbar",
    "sublimerbarasts": "sublimerbar",
    "sublimerbare": "sublimerbar",
    "sublimerbares": "sublimerbar",
    "sublimerbarheten": "sublimerbarhet",
    "sublimerbarhetens": "sublimerbarhet",
    "sublimerbarhets": "sublimerbarhet",
    "sublimerbars": "sublimerbar",
    "sublimerbart": "sublimerbar",
    "sublimerbarts": "sublimerbar",
    "sublimeringar": "sublimering",
    "sublimeringarna": "sublimering",
    "sublimeringarnas": "sublimering",
    "sublimeringars": "sublimering",
    "sublimeringen": "sublimering",
    "sublimeringens": "sublimering",
    "sublimerings": "sublimering",
    "sublimes": "sublim",
    "sublimheten": "sublimhet",
    "sublimhetens": "sublimhet",
    "sublimhets": "sublimhet",
    "subliminala": "subliminal",
    "subliminalare": "subliminal",
    "subliminalares": "subliminal",
    "subliminalas": "subliminal",
    "subliminalast": "subliminal",
    "subliminalaste": "subliminal",
    "subliminalastes": "subliminal",
    "subliminalasts": "subliminal",
    "subliminale": "subliminal",
    "subliminales": "subliminal",
    "subliminals": "subliminal",
    "subliminalt": "subliminal",
    "subliminalts": "subliminal",
    "sublims": "sublim",
    "sublimt": "sublim",
    "sublimts": "sublim",
    "submarina": "submarin",
    "submarinare": "submarin",
    "submarinares": "submarin",
    "submarinas": "submarin",
    "submarinast": "submarin",
    "submarinaste": "submarin",
    "submarinastes": "submarin",
    "submarinasts": "submarin",
    "submarine": "submarin",
    "submarines": "submarin",
    "submarins": "submarin",
    "submarint": "submarin",
    "submarints": "submarin",
    "subordinationen": "subordination",
    "subordinationens": "subordination",
    "subordinationer": "subordination",
    "subordinationerna": "subordination",
    "subordinationernas": "subordination",
    "subordinationers": "subordination",
    "subordinations": "subordination",
    "subordinerad": "subordinera",
    "subordinerade": "subordinera",
    "subordinerades": "subordinera",
    "subordinerads": "subordinera",
    "subordinerande": "subordinera",
    "subordineranden": "subordinerande",
    "subordinerandena": "subordinerande",
    "subordinerandenas": "subordinerande",
    "subordinerandens": "subordinerande",
    "subordinerandes": "subordinerande",
    "subordinerandet": "subordinerande",
    "subordinerandets": "subordinerande",
    "subordinerar": "subordinera",
    "subordineras": "subordinera",
    "subordinerat": "subordinera",
    "subordinerats": "subordinera",
    "subordinerbara": "subordinerbar",
    "subordinerbarare": "subordinerbar",
    "subordinerbarares": "subordinerbar",
    "subordinerbaras": "subordinerbar",
    "subordinerbarast": "subordinerbar",
    "subordinerbaraste": "subordinerbar",
    "subordinerbarastes": "subordinerbar",
    "subordinerbarasts": "subordinerbar",
    "subordinerbare": "subordinerbar",
    "subordinerbares": "subordinerbar",
    "subordinerbarheten": "subordinerbarhet",
    "subordinerbarhetens": "subordinerbarhet",
    "subordinerbarhets": "subordinerbarhet",
    "subordinerbars": "subordinerbar",
    "subordinerbart": "subordinerbar",
    "subordinerbarts": "subordinerbar",
    "subordineringar": "subordinering",
    "subordineringarna": "subordinering",
    "subordineringarnas": "subordinering",
    "subordineringars": "subordinering",
    "subordineringen": "subordinering",
    "subordineringens": "subordinering",
    "subordinerings": "subordinering",
    "subretten": "subrett",
    "subrettens": "subrett",
    "subretter": "subrett",
    "subretterna": "subrett",
    "subretternas": "subrett",
    "subretters": "subrett",
    "subretts": "subrett",
    "subsidie": "subsidier",
    "subsidierad": "subsidiera",
    "subsidierade": "subsidiera",
    "subsidierades": "subsidiera",
    "subsidierads": "subsidiera",
    "subsidierande": "subsidiera",
    "subsidieranden": "subsidierande",
    "subsidierandena": "subsidierande",
    "subsidierandenas": "subsidierande",
    "subsidierandens": "subsidierande",
    "subsidierandes": "subsidierande",
    "subsidierandet": "subsidierande",
    "subsidierandets": "subsidierande",
    "subsidierar": "subsidiera",
    "subsidieras": "subsidiera",
    "subsidierat": "subsidiera",
    "subsidierats": "subsidiera",
    "subsidierbara": "subsidierbar",
    "subsidierbarare": "subsidierbar",
    "subsidierbarares": "subsidierbar",
    "subsidierbaras": "subsidierbar",
    "subsidierbarast": "subsidierbar",
    "subsidierbaraste": "subsidierbar",
    "subsidierbarastes": "subsidierbar",
    "subsidierbarasts": "subsidierbar",
    "subsidierbare": "subsidierbar",
    "subsidierbares": "subsidierbar",
    "subsidierbarheten": "subsidierbarhet",
    "subsidierbarhetens": "subsidierbarhet",
    "subsidierbarhets": "subsidierbarhet",
    "subsidierbars": "subsidierbar",
    "subsidierbart": "subsidierbar",
    "subsidierbarts": "subsidierbar",
    "subsidieringar": "subsidiering",
    "subsidieringarna": "subsidiering",
    "subsidieringarnas": "subsidiering",
    "subsidieringars": "subsidiering",
    "subsidieringen": "subsidiering",
    "subsidieringens": "subsidiering",
    "subsidierings": "subsidiering",
    "subsidierna": "subsidier",
    "subsidiernas": "subsidier",
    "subsidiers": "subsidier",
    "subsidiära": "subsidiär",
    "subsidiärare": "subsidiär",
    "subsidiärares": "subsidiär",
    "subsidiäras": "subsidiär",
    "subsidiärast": "subsidiär",
    "subsidiäraste": "subsidiär",
    "subsidiärastes": "subsidiär",
    "subsidiärasts": "subsidiär",
    "subsidiäre": "subsidiär",
    "subsidiäres": "subsidiär",
    "subsidiärs": "subsidiär",
    "subsidiärt": "subsidiär",
    "subsidiärts": "subsidiär",
    "subskribenten": "subskribent",
    "subskribentens": "subskribent",
    "subskribenter": "subskribent",
    "subskribenterna": "subskribent",
    "subskribenternas": "subskribent",
    "subskribenters": "subskribent",
    "subskribents": "subskribent",
    "subskriberad": "subskribera",
    "subskriberade": "subskribera",
    "subskriberades": "subskribera",
    "subskriberads": "subskribera",
    "subskriberande": "subskribera",
    "subskriberanden": "subskriberande",
    "subskriberandena": "subskriberande",
    "subskriberandenas": "subskriberande",
    "subskriberandens": "subskriberande",
    "subskriberandes": "subskriberande",
    "subskriberandet": "subskriberande",
    "subskriberandets": "subskriberande",
    "subskriberar": "subskribera",
    "subskriberas": "subskribera",
    "subskriberat": "subskribera",
    "subskriberats": "subskribera",
    "subskriberbara": "subskriberbar",
    "subskriberbarare": "subskriberbar",
    "subskriberbarares": "subskriberbar",
    "subskriberbaras": "subskriberbar",
    "subskriberbarast": "subskriberbar",
    "subskriberbaraste": "subskriberbar",
    "subskriberbarastes": "subskriberbar",
    "subskriberbarasts": "subskriberbar",
    "subskriberbare": "subskriberbar",
    "subskriberbares": "subskriberbar",
    "subskriberbarheten": "subskriberbarhet",
    "subskriberbarhetens": "subskriberbarhet",
    "subskriberbarhets": "subskriberbarhet",
    "subskriberbars": "subskriberbar",
    "subskriberbart": "subskriberbar",
    "subskriberbarts": "subskriberbar",
    "subskriberingar": "subskribering",
    "subskriberingarna": "subskribering",
    "subskriberingarnas": "subskribering",
    "subskriberingars": "subskribering",
    "subskriberingen": "subskribering",
    "subskriberingens": "subskribering",
    "subskriberings": "subskribering",
    "substansen": "substans",
    "substansens": "substans",
    "substanser": "substans",
    "substanserna": "substans",
    "substansernas": "substans",
    "substansers": "substans",
    "substantiella": "substantiell",
    "substantiellare": "substantiell",
    "substantiellares": "substantiell",
    "substantiellas": "substantiell",
    "substantiellast": "substantiell",
    "substantiellaste": "substantiell",
    "substantiellastes": "substantiell",
    "substantiellasts": "substantiell",
    "substantielle": "substantiell",
    "substantielles": "substantiell",
    "substantiells": "substantiell",
    "substantiellt": "substantiell",
    "substantiellts": "substantiell",
    "substantiven": "substantiv",
    "substantivens": "substantiv",
    "substantiverad": "substantivera",
    "substantiverade": "substantivera",
    "substantiverades": "substantivera",
    "substantiverads": "substantivera",
    "substantiverande": "substantivera",
    "substantiveranden": "substantiverande",
    "substantiverandena": "substantiverande",
    "substantiverandenas": "substantiverande",
    "substantiverandens": "substantiverande",
    "substantiverandes": "substantiverande",
    "substantiverandet": "substantiverande",
    "substantiverandets": "substantiverande",
    "substantiverar": "substantivera",
    "substantiveras": "substantivera",
    "substantiverat": "substantivera",
    "substantiverats": "substantivera",
    "substantiverbara": "substantiverbar",
    "substantiverbarare": "substantiverbar",
    "substantiverbarares": "substantiverbar",
    "substantiverbaras": "substantiverbar",
    "substantiverbarast": "substantiverbar",
    "substantiverbaraste": "substantiverbar",
    "substantiverbarastes": "substantiverbar",
    "substantiverbarasts": "substantiverbar",
    "substantiverbare": "substantiverbar",
    "substantiverbares": "substantiverbar",
    "substantiverbarheten": "substantiverbarhet",
    "substantiverbarhetens": "substantiverbarhet",
    "substantiverbarhets": "substantiverbarhet",
    "substantiverbars": "substantiverbar",
    "substantiverbart": "substantiverbar",
    "substantiverbarts": "substantiverbar",
    "substantiveringar": "substantivering",
    "substantiveringarna": "substantivering",
    "substantiveringarnas": "substantivering",
    "substantiveringars": "substantivering",
    "substantiveringen": "substantivering",
    "substantiveringens": "substantivering",
    "substantiverings": "substantivering",
    "substantivet": "substantiv",
    "substantivets": "substantiv",
    "substantivs": "substantiv",
    "substantivsjukan": "substantivsjuka",
    "substantivsjukans": "substantivsjuka",
    "substantivsjukas": "substantivsjuka",
    "substantivsjuke": "substantivsjuka",
    "substantivsjuks": "substantivsjuka",
    "substituerad": "substituera",
    "substituerade": "substituera",
    "substituerades": "substituera",
    "substituerads": "substituera",
    "substituerande": "substituera",
    "substitueranden": "substituerande",
    "substituerandena": "substituerande",
    "substituerandenas": "substituerande",
    "substituerandens": "substituerande",
    "substituerandes": "substituerande",
    "substituerandet": "substituerande",
    "substituerandets": "substituerande",
    "substituerar": "substituera",
    "substitueras": "substituera",
    "substituerat": "substituera",
    "substituerats": "substituera",
    "substituerbara": "substituerbar",
    "substituerbarare": "substituerbar",
    "substituerbarares": "substituerbar",
    "substituerbaras": "substituerbar",
    "substituerbarast": "substituerbar",
    "substituerbaraste": "substituerbar",
    "substituerbarastes": "substituerbar",
    "substituerbarasts": "substituerbar",
    "substituerbare": "substituerbar",
    "substituerbares": "substituerbar",
    "substituerbarheten": "substituerbarhet",
    "substituerbarhetens": "substituerbarhet",
    "substituerbarhets": "substituerbarhet",
    "substituerbars": "substituerbar",
    "substituerbart": "substituerbar",
    "substituerbarts": "substituerbar",
    "substitueringar": "substituering",
    "substitueringarna": "substituering",
    "substitueringarnas": "substituering",
    "substitueringars": "substituering",
    "substitueringen": "substituering",
    "substitueringens": "substituering",
    "substituerings": "substituering",
    "substituten": "substitut",
    "substitutens": "substitut",
    "substitutet": "substitut",
    "substitutets": "substitut",
    "substitutionen": "substitution",
    "substitutionens": "substitution",
    "substitutioner": "substitution",
    "substitutionerna": "substitution",
    "substitutionernas": "substitution",
    "substitutioners": "substitution",
    "substitutions": "substitution",
    "substituts": "substitut",
    "substraten": "substrat",
    "substratens": "substrat",
    "substratet": "substrat",
    "substratets": "substrat",
    "substrats": "substrat",
    "subsumerad": "subsumera",
    "subsumerade": "subsumera",
    "subsumerades": "subsumera",
    "subsumerads": "subsumera",
    "subsumerande": "subsumera",
    "subsumeranden": "subsumerande",
    "subsumerandena": "subsumerande",
    "subsumerandenas": "subsumerande",
    "subsumerandens": "subsumerande",
    "subsumerandes": "subsumerande",
    "subsumerandet": "subsumerande",
    "subsumerandets": "subsumerande",
    "subsumerar": "subsumera",
    "subsumeras": "subsumera",
    "subsumerat": "subsumera",
    "subsumerats": "subsumera",
    "subsumerbara": "subsumerbar",
    "subsumerbarare": "subsumerbar",
    "subsumerbarares": "subsumerbar",
    "subsumerbaras": "subsumerbar",
    "subsumerbarast": "subsumerbar",
    "subsumerbaraste": "subsumerbar",
    "subsumerbarastes": "subsumerbar",
    "subsumerbarasts": "subsumerbar",
    "subsumerbare": "subsumerbar",
    "subsumerbares": "subsumerbar",
    "subsumerbarheten": "subsumerbarhet",
    "subsumerbarhetens": "subsumerbarhet",
    "subsumerbarhets": "subsumerbarhet",
    "subsumerbars": "subsumerbar",
    "subsumerbart": "subsumerbar",
    "subsumerbarts": "subsumerbar",
    "subsumeringar": "subsumering",
    "subsumeringarna": "subsumering",
    "subsumeringarnas": "subsumering",
    "subsumeringars": "subsumering",
    "subsumeringen": "subsumering",
    "subsumeringens": "subsumering",
    "subsumerings": "subsumering",
    "subtila": "subtil",
    "subtilare": "subtil",
    "subtilares": "subtil",
    "subtilas": "subtil",
    "subtilast": "subtil",
    "subtilaste": "subtil",
    "subtilastes": "subtil",
    "subtilasts": "subtil",
    "subtile": "subtil",
    "subtiles": "subtil",
    "subtiliteten": "subtilitet",
    "subtilitetens": "subtilitet",
    "subtiliteter": "subtilitet",
    "subtiliteterna": "subtilitet",
    "subtiliteternas": "subtilitet",
    "subtiliteters": "subtilitet",
    "subtilitets": "subtilitet",
    "subtils": "subtil",
    "subtilt": "subtil",
    "subtilts": "subtil",
    "subtraherad": "subtrahera",
    "subtraherade": "subtrahera",
    "subtraherades": "subtrahera",
    "subtraherads": "subtrahera",
    "subtraherande": "subtrahera",
    "subtraheranden": "subtraherande",
    "subtraherandena": "subtraherande",
    "subtraherandenas": "subtraherande",
    "subtraherandens": "subtraherande",
    "subtraherandes": "subtraherande",
    "subtraherandet": "subtraherande",
    "subtraherandets": "subtraherande",
    "subtraherar": "subtrahera",
    "subtraheras": "subtrahera",
    "subtraherat": "subtrahera",
    "subtraherats": "subtrahera",
    "subtraherbara": "subtraherbar",
    "subtraherbarare": "subtraherbar",
    "subtraherbarares": "subtraherbar",
    "subtraherbaras": "subtraherbar",
    "subtraherbarast": "subtraherbar",
    "subtraherbaraste": "subtraherbar",
    "subtraherbarastes": "subtraherbar",
    "subtraherbarasts": "subtraherbar",
    "subtraherbare": "subtraherbar",
    "subtraherbares": "subtraherbar",
    "subtraherbarheten": "subtraherbarhet",
    "subtraherbarhetens": "subtraherbarhet",
    "subtraherbarhets": "subtraherbarhet",
    "subtraherbars": "subtraherbar",
    "subtraherbart": "subtraherbar",
    "subtraherbarts": "subtraherbar",
    "subtraheringar": "subtrahering",
    "subtraheringarna": "subtrahering",
    "subtraheringarnas": "subtrahering",
    "subtraheringars": "subtrahering",
    "subtraheringen": "subtrahering",
    "subtraheringens": "subtrahering",
    "subtraherings": "subtrahering",
    "subtraktionen": "subtraktion",
    "subtraktionens": "subtraktion",
    "subtraktioner": "subtraktion",
    "subtraktionerna": "subtraktion",
    "subtraktionernas": "subtraktion",
    "subtraktioners": "subtraktion",
    "subtraktions": "subtraktion",
    "subtropiska": "subtropisk",
    "subtropiskare": "subtropisk",
    "subtropiskares": "subtropisk",
    "subtropiskas": "subtropisk",
    "subtropiskast": "subtropisk",
    "subtropiskaste": "subtropisk",
    "subtropiskastes": "subtropisk",
    "subtropiskasts": "subtropisk",
    "subtropiske": "subtropisk",
    "subtropiskes": "subtropisk",
    "subtropisks": "subtropisk",
    "subtropiskt": "subtropisk",
    "subtropiskts": "subtropisk",
    "subventionen": "subvention",
    "subventionens": "subvention",
    "subventioner": "subvention",
    "subventionerad": "subventionera",
    "subventionerade": "subventionera",
    "subventionerades": "subventionera",
    "subventionerads": "subventionera",
    "subventionerande": "subventionera",
    "subventioneranden": "subventionerande",
    "subventionerandena": "subventionerande",
    "subventionerandenas": "subventionerande",
    "subventionerandens": "subventionerande",
    "subventionerandes": "subventionerande",
    "subventionerandet": "subventionerande",
    "subventionerandets": "subventionerande",
    "subventionerar": "subventionera",
    "subventioneras": "subventionera",
    "subventionerat": "subventionera",
    "subventionerats": "subventionera",
    "subventionerbara": "subventionerbar",
    "subventionerbarare": "subventionerbar",
    "subventionerbarares": "subventionerbar",
    "subventionerbaras": "subventionerbar",
    "subventionerbarast": "subventionerbar",
    "subventionerbaraste": "subventionerbar",
    "subventionerbarastes": "subventionerbar",
    "subventionerbarasts": "subventionerbar",
    "subventionerbare": "subventionerbar",
    "subventionerbares": "subventionerbar",
    "subventionerbarheten": "subventionerbarhet",
    "subventionerbarhetens": "subventionerbarhet",
    "subventionerbarhets": "subventionerbarhet",
    "subventionerbars": "subventionerbar",
    "subventionerbart": "subventionerbar",
    "subventionerbarts": "subventionerbar",
    "subventioneringar": "subventionering",
    "subventioneringarna": "subventionering",
    "subventioneringarnas": "subventionering",
    "subventioneringars": "subventionering",
    "subventioneringen": "subventionering",
    "subventioneringens": "subventionering",
    "subventionerings": "subventionering",
    "subventionerna": "subvention",
    "subventionernas": "subvention",
    "subventioners": "subvention",
    "subventions": "subvention",
    "subversiva": "subversiv",
    "subversivare": "subversiv",
    "subversivares": "subversiv",
    "subversivas": "subversiv",
    "subversivast": "subversiv",
    "subversivaste": "subversiv",
    "subversivastes": "subversiv",
    "subversivasts": "subversiv",
    "subversive": "subversiv",
    "subversives": "subversiv",
    "subversivs": "subversiv",
    "subversivt": "subversiv",
    "subversivts": "subversiv",
    "succederad": "succedera",
    "succederade": "succedera",
    "succederades": "succedera",
    "succederads": "succedera",
    "succederande": "succedera",
    "succederanden": "succederande",
    "succederandena": "succederande",
    "succederandenas": "succederande",
    "succederandens": "succederande",
    "succederandes": "succederande",
    "succederandet": "succederande",
    "succederandets": "succederande",
    "succederar": "succedera",
    "succederas": "succedera",
    "succederat": "succedera",
    "succederats": "succedera",
    "succederbara": "succederbar",
    "succederbarare": "succederbar",
    "succederbarares": "succederbar",
    "succederbaras": "succederbar",
    "succederbarast": "succederbar",
    "succederbaraste": "succederbar",
    "succederbarastes": "succederbar",
    "succederbarasts": "succederbar",
    "succederbare": "succederbar",
    "succederbares": "succederbar",
    "succederbarheten": "succederbarhet",
    "succederbarhetens": "succederbarhet",
    "succederbarhets": "succederbarhet",
    "succederbars": "succederbar",
    "succederbart": "succederbar",
    "succederbarts": "succederbar",
    "succederingar": "succedering",
    "succederingarna": "succedering",
    "succederingarnas": "succedering",
    "succederingars": "succedering",
    "succederingen": "succedering",
    "succederingens": "succedering",
    "succederings": "succedering",
    "successionen": "succession",
    "successionens": "succession",
    "successioner": "succession",
    "successionerna": "succession",
    "successionernas": "succession",
    "successioners": "succession",
    "successions": "succession",
    "successionsordningar": "successionsordning",
    "successionsordningarna": "successionsordning",
    "successionsordningarnas": "successionsordning",
    "successionsordningars": "successionsordning",
    "successionsordningen": "successionsordning",
    "successionsordningens": "successionsordning",
    "successionsordnings": "successionsordning",
    "successiva": "successiv",
    "successivare": "successiv",
    "successivares": "successiv",
    "successivas": "successiv",
    "successivast": "successiv",
    "successivaste": "successiv",
    "successivastes": "successiv",
    "successivasts": "successiv",
    "successive": "successiv",
    "successives": "successiv",
    "successivs": "successiv",
    "successivt": "successiv",
    "successivts": "successiv",
    "succeésen": "succeés",
    "succeésens": "succeés",
    "succeéser": "succeés",
    "succeéserna": "succeés",
    "succeésernas": "succeés",
    "succeésers": "succeés",
    "succéer": "succé",
    "succéerna": "succé",
    "succéernas": "succé",
    "succéers": "succé",
    "succén": "succé",
    "succéns": "succé",
    "succés": "succé",
    "suck": "sucka",
    "suckad": "sucka",
    "suckade": "sucka",
    "suckades": "sucka",
    "suckads": "sucka",
    "suckande": "sucka",
    "suckanden": "suckande",
    "suckandena": "suckande",
    "suckandenas": "suckande",
    "suckandens": "suckande",
    "suckandes": "suckande",
    "suckandet": "suckande",
    "suckandets": "suckande",
    "suckans": "suckan",
    "suckar": "sucka",
    "suckarna": "suck",
    "suckarnas": "suck",
    "suckars": "suck",
    "suckas": "sucka",
    "suckat": "sucka",
    "suckaten": "suckat",
    "suckatens": "suckat",
    "suckatet": "suckat",
    "suckatets": "suckat",
    "suckats": "suckat",
    "sucken": "suck",
    "suckens": "suck",
    "sucks": "suck",
    "suckulenta": "suckulent",
    "suckulentare": "suckulent",
    "suckulentares": "suckulent",
    "suckulentas": "suckulent",
    "suckulentast": "suckulent",
    "suckulentaste": "suckulent",
    "suckulentastes": "suckulent",
    "suckulentasts": "suckulent",
    "suckulente": "suckulent",
    "suckulenten": "suckulent",
    "suckulentens": "suckulent",
    "suckulenter": "suckulent",
    "suckulenterna": "suckulent",
    "suckulenternas": "suckulent",
    "suckulenters": "suckulent",
    "suckulentes": "suckulent",
    "suckulents": "suckulent",
    "sudanesen": "sudanes",
    "sudanesens": "sudanes",
    "sudaneser": "sudanes",
    "sudaneserna": "sudanes",
    "sudanesernas": "sudanes",
    "sudanesers": "sudanes",
    "sudanesiska": "sudanesisk",
    "sudanesiskan": "sudanesiska",
    "sudanesiskans": "sudanesiska",
    "sudanesiskare": "sudanesisk",
    "sudanesiskares": "sudanesisk",
    "sudanesiskas": "sudanesiska",
    "sudanesiskast": "sudanesisk",
    "sudanesiskaste": "sudanesisk",
    "sudanesiskastes": "sudanesisk",
    "sudanesiskasts": "sudanesisk",
    "sudanesiske": "sudanesiska",
    "sudanesiskes": "sudanesisk",
    "sudanesiskor": "sudanesiska",
    "sudanesiskorna": "sudanesiska",
    "sudanesiskornas": "sudanesiska",
    "sudanesiskors": "sudanesiska",
    "sudanesisks": "sudanesisk",
    "sudanesiskt": "sudanesisk",
    "sudanesiskts": "sudanesisk",
    "sudd": "sudda",
    "suddad": "sudda",
    "suddade": "sudda",
    "suddades": "sudda",
    "suddads": "sudda",
    "suddande": "sudda",
    "suddanden": "suddande",
    "suddandena": "suddande",
    "suddandenas": "suddande",
    "suddandens": "suddande",
    "suddandes": "suddande",
    "suddandet": "suddande",
    "suddandets": "suddande",
    "suddar": "sudda",
    "suddarna": "sudd",
    "suddarnas": "sudd",
    "suddars": "sudd",
    "suddas": "sudda",
    "suddat": "sudda",
    "suddats": "sudda",
    "sudden": "sudd",
    "suddens": "sudd",
    "suddet": "sudd",
    "suddets": "sudd",
    "suddgummin": "suddgummi",
    "suddgummina": "suddgummi",
    "suddgumminas": "suddgummi",
    "suddgummins": "suddgummi",
    "suddgummis": "suddgummi",
    "suddgummit": "suddgummi",
    "suddgummits": "suddgummi",
    "suddiga": "suddig",
    "suddigare": "suddig",
    "suddigares": "suddig",
    "suddigas": "suddig",
    "suddigast": "suddig",
    "suddigaste": "suddig",
    "suddigastes": "suddig",
    "suddigasts": "suddig",
    "suddige": "suddig",
    "suddiges": "suddig",
    "suddigheten": "suddighet",
    "suddighetens": "suddighet",
    "suddigheter": "suddighet",
    "suddigheterna": "suddighet",
    "suddigheternas": "suddighet",
    "suddigheters": "suddighet",
    "suddighets": "suddighet",
    "suddigs": "suddig",
    "suddigt": "suddig",
    "suddigts": "suddig",
    "sudds": "sudd",
    "sudokun": "sudoku",
    "sudokuna": "sudoku",
    "sudokunas": "sudoku",
    "sudokuns": "sudoku",
    "sudokur": "sudoku",
    "sudokurna": "sudoku",
    "sudokurnas": "sudoku",
    "sudokurs": "sudoku",
    "sudokus": "sudoku",
    "sudokusar": "sudoku",
    "sudokusarna": "sudoku",
    "sudokusarnas": "sudoku",
    "sudokusars": "sudoku",
    "sudokusen": "sudoku",
    "sudokusens": "sudoku",
    "sudokut": "sudoku",
    "sudokuts": "sudoku",
    "suffigerad": "suffigera",
    "suffigerade": "suffigera",
    "suffigerades": "suffigera",
    "suffigerads": "suffigera",
    "suffigerande": "suffigera",
    "suffigeranden": "suffigerande",
    "suffigerandena": "suffigerande",
    "suffigerandenas": "suffigerande",
    "suffigerandens": "suffigerande",
    "suffigerandes": "suffigerande",
    "suffigerandet": "suffigerande",
    "suffigerandets": "suffigerande",
    "suffigerar": "suffigera",
    "suffigeras": "suffigera",
    "suffigerat": "suffigera",
    "suffigerats": "suffigera",
    "suffigerbara": "suffigerbar",
    "suffigerbarare": "suffigerbar",
    "suffigerbarares": "suffigerbar",
    "suffigerbaras": "suffigerbar",
    "suffigerbarast": "suffigerbar",
    "suffigerbaraste": "suffigerbar",
    "suffigerbarastes": "suffigerbar",
    "suffigerbarasts": "suffigerbar",
    "suffigerbare": "suffigerbar",
    "suffigerbares": "suffigerbar",
    "suffigerbarheten": "suffigerbarhet",
    "suffigerbarhetens": "suffigerbarhet",
    "suffigerbarhets": "suffigerbarhet",
    "suffigerbars": "suffigerbar",
    "suffigerbart": "suffigerbar",
    "suffigerbarts": "suffigerbar",
    "suffigeringar": "suffigering",
    "suffigeringarna": "suffigering",
    "suffigeringarnas": "suffigering",
    "suffigeringars": "suffigering",
    "suffigeringen": "suffigering",
    "suffigeringens": "suffigering",
    "suffigerings": "suffigering",
    "suffisansen": "suffisans",
    "suffisansens": "suffisans",
    "suffixen": "suffix",
    "suffixens": "suffix",
    "suffixet": "suffix",
    "suffixets": "suffix",
    "sufflerad": "sufflera",
    "sufflerade": "sufflera",
    "sufflerades": "sufflera",
    "sufflerads": "sufflera",
    "sufflerande": "sufflera",
    "suffleranden": "sufflerande",
    "sufflerandena": "sufflerande",
    "sufflerandenas": "sufflerande",
    "sufflerandens": "sufflerande",
    "sufflerandes": "sufflerande",
    "sufflerandet": "sufflerande",
    "sufflerandets": "sufflerande",
    "sufflerar": "sufflera",
    "suffleras": "sufflera",
    "sufflerat": "sufflera",
    "sufflerats": "sufflera",
    "sufflerbara": "sufflerbar",
    "sufflerbarare": "sufflerbar",
    "sufflerbarares": "sufflerbar",
    "sufflerbaras": "sufflerbar",
    "sufflerbarast": "sufflerbar",
    "sufflerbaraste": "sufflerbar",
    "sufflerbarastes": "sufflerbar",
    "sufflerbarasts": "sufflerbar",
    "sufflerbare": "sufflerbar",
    "sufflerbares": "sufflerbar",
    "sufflerbarheten": "sufflerbarhet",
    "sufflerbarhetens": "sufflerbarhet",
    "sufflerbarhets": "sufflerbarhet",
    "sufflerbars": "sufflerbar",
    "sufflerbart": "sufflerbar",
    "sufflerbarts": "sufflerbar",
    "suffleringar": "sufflering",
    "suffleringarna": "sufflering",
    "suffleringarnas": "sufflering",
    "suffleringars": "sufflering",
    "suffleringen": "sufflering",
    "suffleringens": "sufflering",
    "sufflerings": "sufflering",
    "suffletten": "sufflett",
    "sufflettens": "sufflett",
    "suffletter": "sufflett",
    "suffletterna": "sufflett",
    "suffletternas": "sufflett",
    "suffletters": "sufflett",
    "suffletts": "sufflett",
    "suffléer": "sufflé",
    "suffléerna": "sufflé",
    "suffléernas": "sufflé",
    "suffléers": "sufflé",
    "sufflén": "sufflé",
    "suffléns": "sufflé",
    "sufflés": "sufflé",
    "sufflören": "sufflör",
    "sufflörens": "sufflör",
    "sufflörer": "sufflör",
    "sufflörerna": "sufflör",
    "sufflörernas": "sufflör",
    "sufflörers": "sufflör",
    "sufflörs": "sufflör",
    "sufflösen": "sufflös",
    "sufflösens": "sufflös",
    "sufflöser": "sufflös",
    "sufflöserna": "sufflös",
    "sufflösernas": "sufflös",
    "sufflösers": "sufflös",
    "suffragetten": "suffragett",
    "suffragettens": "suffragett",
    "suffragetter": "suffragett",
    "suffragetterna": "suffragett",
    "suffragetternas": "suffragett",
    "suffragetters": "suffragett",
    "suffragetts": "suffragett",
    "sug": "suga",
    "sugande": "suga",
    "suganden": "sugande",
    "sugandena": "sugande",
    "sugandenas": "sugande",
    "sugandens": "sugande",
    "sugandes": "sugande",
    "sugandet": "sugande",
    "sugandets": "sugande",
    "sugar": "sug",
    "sugarna": "sug",
    "sugarnas": "sug",
    "sugars": "sug",
    "sugas": "suga",
    "suge": "suga",
    "sugen": "suga",
    "sugens": "sugen",
    "suger": "suga",
    "suges": "suga",
    "suget": "sugen",
    "sugets": "sugen",
    "sugfasen": "sugfas",
    "sugfasens": "sugfas",
    "sugfaser": "sugfas",
    "sugfaserna": "sugfas",
    "sugfasernas": "sugfas",
    "sugfasers": "sugfas",
    "sugg": "sugga",
    "suggan": "sugga",
    "suggans": "sugga",
    "suggas": "sugga",
    "sugge": "sugga",
    "suggererad": "suggerera",
    "suggererade": "suggerera",
    "suggererades": "suggerera",
    "suggererads": "suggerera",
    "suggererande": "suggerera",
    "suggereranden": "suggererande",
    "suggererandena": "suggererande",
    "suggererandenas": "suggererande",
    "suggererandens": "suggererande",
    "suggererandes": "suggererande",
    "suggererandet": "suggererande",
    "suggererandets": "suggererande",
    "suggererar": "suggerera",
    "suggereras": "suggerera",
    "suggererat": "suggerera",
    "suggererats": "suggerera",
    "suggererbara": "suggererbar",
    "suggererbarare": "suggererbar",
    "suggererbarares": "suggererbar",
    "suggererbaras": "suggererbar",
    "suggererbarast": "suggererbar",
    "suggererbaraste": "suggererbar",
    "suggererbarastes": "suggererbar",
    "suggererbarasts": "suggererbar",
    "suggererbare": "suggererbar",
    "suggererbares": "suggererbar",
    "suggererbarheten": "suggererbarhet",
    "suggererbarhetens": "suggererbarhet",
    "suggererbarhets": "suggererbarhet",
    "suggererbars": "suggererbar",
    "suggererbart": "suggererbar",
    "suggererbarts": "suggererbar",
    "suggereringar": "suggerering",
    "suggereringarna": "suggerering",
    "suggereringarnas": "suggerering",
    "suggereringars": "suggerering",
    "suggereringen": "suggerering",
    "suggereringens": "suggerering",
    "suggererings": "suggerering",
    "suggestibels": "suggestibel",
    "suggestibelt": "suggestibel",
    "suggestibelts": "suggestibel",
    "suggestibla": "suggestibel",
    "suggestiblare": "suggestibel",
    "suggestiblares": "suggestibel",
    "suggestiblas": "suggestibel",
    "suggestiblast": "suggestibel",
    "suggestiblaste": "suggestibel",
    "suggestiblastes": "suggestibel",
    "suggestiblasts": "suggestibel",
    "suggestible": "suggestibel",
    "suggestibles": "suggestibel",
    "suggestionen": "suggestion",
    "suggestionens": "suggestion",
    "suggestioner": "suggestion",
    "suggestionerna": "suggestion",
    "suggestionernas": "suggestion",
    "suggestioners": "suggestion",
    "suggestions": "suggestion",
    "suggestiva": "suggestiv",
    "suggestivare": "suggestiv",
    "suggestivares": "suggestiv",
    "suggestivas": "suggestiv",
    "suggestivast": "suggestiv",
    "suggestivaste": "suggestiv",
    "suggestivastes": "suggestiv",
    "suggestivasts": "suggestiv",
    "suggestive": "suggestiv",
    "suggestives": "suggestiv",
    "suggestivs": "suggestiv",
    "suggestivt": "suggestiv",
    "suggestivts": "suggestiv",
    "suggor": "sugga",
    "suggorna": "sugga",
    "suggornas": "sugga",
    "suggors": "sugga",
    "suggs": "sugga",
    "sughöjden": "sughöjd",
    "sughöjdens": "sughöjd",
    "sughöjds": "sughöjd",
    "sugit": "suga",
    "sugits": "suga",
    "sugkoppar": "sugkopp",
    "sugkopparna": "sugkopp",
    "sugkopparnas": "sugkopp",
    "sugkoppars": "sugkopp",
    "sugkoppen": "sugkopp",
    "sugkoppens": "sugkopp",
    "sugkopps": "sugkopp",
    "sugna": "sugen",
    "sugnare": "sugen",
    "sugnares": "sugen",
    "sugnas": "sugen",
    "sugnast": "sugen",
    "sugnaste": "sugen",
    "sugnastes": "sugen",
    "sugnasts": "sugen",
    "sugne": "sugen",
    "sugnes": "sugen",
    "sugrören": "sugrör",
    "sugrörens": "sugrör",
    "sugröret": "sugrör",
    "sugrörets": "sugrör",
    "sugrörs": "sugrör",
    "sugs": "suga",
    "suicidala": "suicidal",
    "suicidalare": "suicidal",
    "suicidalares": "suicidal",
    "suicidalas": "suicidal",
    "suicidalast": "suicidal",
    "suicidalaste": "suicidal",
    "suicidalastes": "suicidal",
    "suicidalasts": "suicidal",
    "suicidale": "suicidal",
    "suicidales": "suicidal",
    "suicidals": "suicidal",
    "suicidalt": "suicidal",
    "suicidalts": "suicidal",
    "sujetten": "sujett",
    "sujettens": "sujett",
    "sujetter": "sujett",
    "sujetterna": "sujett",
    "sujetternas": "sujett",
    "sujetters": "sujett",
    "sujetts": "sujett",
    "sukt": "sukta",
    "suktad": "sukta",
    "suktade": "sukta",
    "suktades": "sukta",
    "suktads": "sukta",
    "suktande": "sukta",
    "suktanden": "suktande",
    "suktandena": "suktande",
    "suktandenas": "suktande",
    "suktandens": "suktande",
    "suktandes": "suktande",
    "suktandet": "suktande",
    "suktandets": "suktande",
    "suktar": "sukta",
    "suktas": "sukta",
    "suktat": "sukta",
    "suktats": "sukta",
    "sul": "sula",
    "sulad": "sula",
    "sulade": "sula",
    "sulades": "sula",
    "sulads": "sula",
    "sulan": "sula",
    "sulande": "sula",
    "sulanden": "sulande",
    "sulandena": "sulande",
    "sulandenas": "sulande",
    "sulandens": "sulande",
    "sulandes": "sulande",
    "sulandet": "sulande",
    "sulandets": "sulande",
    "sulans": "sula",
    "sular": "sula",
    "sulas": "sula",
    "sulat": "sula",
    "sulats": "sula",
    "sule": "sula",
    "sulfan": "sulfa",
    "sulfans": "sulfa",
    "sulfas": "sulfa",
    "sulfaten": "sulfat",
    "sulfatens": "sulfat",
    "sulfater": "sulfat",
    "sulfaterna": "sulfat",
    "sulfaternas": "sulfat",
    "sulfaters": "sulfat",
    "sulfatet": "sulfat",
    "sulfatets": "sulfat",
    "sulfatfabriken": "sulfatfabrik",
    "sulfatfabrikens": "sulfatfabrik",
    "sulfatfabriker": "sulfatfabrik",
    "sulfatfabrikerna": "sulfatfabrik",
    "sulfatfabrikernas": "sulfatfabrik",
    "sulfatfabrikers": "sulfatfabrik",
    "sulfatfabriks": "sulfatfabrik",
    "sulfatmassan": "sulfatmassa",
    "sulfatmassans": "sulfatmassa",
    "sulfatmassas": "sulfatmassa",
    "sulfatmasse": "sulfatmassa",
    "sulfatmassor": "sulfatmassa",
    "sulfatmassorna": "sulfatmassa",
    "sulfatmassornas": "sulfatmassa",
    "sulfatmassors": "sulfatmassa",
    "sulfats": "sulfat",
    "sulfiden": "sulfid",
    "sulfidens": "sulfid",
    "sulfider": "sulfid",
    "sulfiderna": "sulfid",
    "sulfidernas": "sulfid",
    "sulfiders": "sulfid",
    "sulfids": "sulfid",
    "sulfiten": "sulfit",
    "sulfitens": "sulfit",
    "sulfiter": "sulfit",
    "sulfiterna": "sulfit",
    "sulfiternas": "sulfit",
    "sulfiters": "sulfit",
    "sulfitet": "sulfit",
    "sulfitets": "sulfit",
    "sulfitfabriken": "sulfitfabrik",
    "sulfitfabrikens": "sulfitfabrik",
    "sulfitfabriker": "sulfitfabrik",
    "sulfitfabrikerna": "sulfitfabrik",
    "sulfitfabrikernas": "sulfitfabrik",
    "sulfitfabrikers": "sulfitfabrik",
    "sulfitfabriks": "sulfitfabrik",
    "sulfits": "sulfit",
    "sulkyer": "sulky",
    "sulkyerna": "sulky",
    "sulkyernas": "sulky",
    "sulkyers": "sulky",
    "sulkyn": "sulky",
    "sulkyns": "sulky",
    "sulkys": "sulky",
    "sulor": "sula",
    "sulorna": "sula",
    "sulornas": "sula",
    "sulors": "sula",
    "suls": "sula",
    "sultanaten": "sultanat",
    "sultanatens": "sultanat",
    "sultanatet": "sultanat",
    "sultanatets": "sultanat",
    "sultanats": "sultanat",
    "sultanen": "sultan",
    "sultanens": "sultan",
    "sultaner": "sultan",
    "sultanerna": "sultan",
    "sultanernas": "sultan",
    "sultaners": "sultan",
    "sultanrussinen": "sultanrussin",
    "sultanrussinens": "sultanrussin",
    "sultanrussinet": "sultanrussin",
    "sultanrussinets": "sultanrussin",
    "sultanrussins": "sultanrussin",
    "sultans": "sultan",
    "sumeren": "sumer",
    "sumerens": "sumer",
    "sumerer": "sumer",
    "sumerern": "sumerer",
    "sumererna": "sumerer",
    "sumerernas": "sumerer",
    "sumererns": "sumerer",
    "sumerers": "sumerer",
    "sumeriska": "sumerisk",
    "sumeriskare": "sumerisk",
    "sumeriskares": "sumerisk",
    "sumeriskas": "sumerisk",
    "sumeriskast": "sumerisk",
    "sumeriskaste": "sumerisk",
    "sumeriskastes": "sumerisk",
    "sumeriskasts": "sumerisk",
    "sumeriske": "sumerisk",
    "sumeriskes": "sumerisk",
    "sumerisks": "sumerisk",
    "sumeriskt": "sumerisk",
    "sumeriskts": "sumerisk",
    "sumers": "sumer",
    "sumet": "simma",
    "sumets": "simma",
    "summade": "summa",
    "summades": "summa",
    "summan": "summa",
    "summande": "summa",
    "summanden": "summande",
    "summandena": "summande",
    "summandenas": "summande",
    "summandens": "summande",
    "summandes": "summande",
    "summandet": "summande",
    "summandets": "summande",
    "summans": "summa",
    "summar": "summa",
    "summariska": "summarisk",
    "summariskare": "summarisk",
    "summariskares": "summarisk",
    "summariskas": "summarisk",
    "summariskast": "summarisk",
    "summariskaste": "summarisk",
    "summariskastes": "summarisk",
    "summariskasts": "summarisk",
    "summariske": "summarisk",
    "summariskes": "summarisk",
    "summarisks": "summarisk",
    "summariskt": "summarisk",
    "summariskts": "summarisk",
    "summas": "summa",
    "summat": "summa",
    "summats": "summa",
    "summe": "summa",
    "summen": "simma",
    "summens": "simma",
    "summerad": "summera",
    "summerade": "summera",
    "summerades": "summera",
    "summerads": "summera",
    "summerande": "summera",
    "summeranden": "summerande",
    "summerandena": "summerande",
    "summerandenas": "summerande",
    "summerandens": "summerande",
    "summerandes": "summerande",
    "summerandet": "summerande",
    "summerandets": "summerande",
    "summerar": "summera",
    "summeras": "summera",
    "summerat": "summera",
    "summerats": "summera",
    "summerbara": "summerbar",
    "summerbarare": "summerbar",
    "summerbarares": "summerbar",
    "summerbaras": "summerbar",
    "summerbarast": "summerbar",
    "summerbaraste": "summerbar",
    "summerbarastes": "summerbar",
    "summerbarasts": "summerbar",
    "summerbare": "summerbar",
    "summerbares": "summerbar",
    "summerbarheten": "summerbarhet",
    "summerbarhetens": "summerbarhet",
    "summerbarhets": "summerbarhet",
    "summerbars": "summerbar",
    "summerbart": "summerbar",
    "summerbarts": "summerbar",
    "summeringar": "summering",
    "summeringarna": "summering",
    "summeringarnas": "summering",
    "summeringars": "summering",
    "summeringen": "summering",
    "summeringens": "summering",
    "summerings": "summering",
    "summern": "summer",
    "summerns": "summer",
    "summers": "summer",
    "summertonen": "summerton",
    "summertonens": "summerton",
    "summertoner": "summerton",
    "summertonerna": "summerton",
    "summertonernas": "summerton",
    "summertoners": "summerton",
    "summertons": "summerton",
    "summit": "simma",
    "summits": "simma",
    "summor": "summa",
    "summorna": "summa",
    "summornas": "summa",
    "summors": "summa",
    "sumna": "simma",
    "sumnas": "simma",
    "sumne": "simma",
    "sumnes": "simma",
    "sumon": "sumo",
    "sumona": "sumo",
    "sumonas": "sumo",
    "sumons": "sumo",
    "sumos": "sumo",
    "sumot": "sumo",
    "sumots": "sumo",
    "sump": "sumpa",
    "sumpad": "sumpa",
    "sumpade": "sumpa",
    "sumpades": "sumpa",
    "sumpads": "sumpa",
    "sumpande": "sumpa",
    "sumpanden": "sumpande",
    "sumpandena": "sumpande",
    "sumpandenas": "sumpande",
    "sumpandens": "sumpande",
    "sumpandes": "sumpande",
    "sumpandet": "sumpande",
    "sumpandets": "sumpande",
    "sumpar": "sumpa",
    "sumparna": "sump",
    "sumparnas": "sump",
    "sumpars": "sump",
    "sumpas": "sumpa",
    "sumpat": "sumpa",
    "sumpats": "sumpa",
    "sumpbävern": "sumpbäver",
    "sumpbäverns": "sumpbäver",
    "sumpbävers": "sumpbäver",
    "sumpbävrar": "sumpbäver",
    "sumpbävrarna": "sumpbäver",
    "sumpbävrarnas": "sumpbäver",
    "sumpbävrars": "sumpbäver",
    "sumpen": "sump",
    "sumpens": "sump",
    "sumpgasbranden": "sumpgasbrand",
    "sumpgasbrandens": "sumpgasbrand",
    "sumpgasbrands": "sumpgasbrand",
    "sumpgasbränder": "sumpgasbrand",
    "sumpgasbränderna": "sumpgasbrand",
    "sumpgasbrändernas": "sumpgasbrand",
    "sumpgasbränders": "sumpgasbrand",
    "sumpgasen": "sumpgas",
    "sumpgasens": "sumpgas",
    "sumphön": "sumphöna",
    "sumphönan": "sumphöna",
    "sumphönans": "sumphöna",
    "sumphönas": "sumphöna",
    "sumphöne": "sumphöna",
    "sumphönor": "sumphöna",
    "sumphönorna": "sumphöna",
    "sumphönornas": "sumphöna",
    "sumphönors": "sumphöna",
    "sumphöns": "sumphöna",
    "sumpiga": "sumpig",
    "sumpigare": "sumpig",
    "sumpigares": "sumpig",
    "sumpigas": "sumpig",
    "sumpigast": "sumpig",
    "sumpigaste": "sumpig",
    "sumpigastes": "sumpig",
    "sumpigasts": "sumpig",
    "sumpige": "sumpig",
    "sumpiges": "sumpig",
    "sumpigheten": "sumpighet",
    "sumpighetens": "sumpighet",
    "sumpighets": "sumpighet",
    "sumpigs": "sumpig",
    "sumpigt": "sumpig",
    "sumpigts": "sumpig",
    "sumpmarken": "sumpmark",
    "sumpmarkens": "sumpmark",
    "sumpmarker": "sumpmark",
    "sumpmarkerna": "sumpmark",
    "sumpmarkernas": "sumpmark",
    "sumpmarkers": "sumpmark",
    "sumpmarks": "sumpmark",
    "sumpområden": "sumpområde",
    "sumpområdena": "sumpområde",
    "sumpområdenas": "sumpområde",
    "sumpområdens": "sumpområde",
    "sumpområdes": "sumpområde",
    "sumpområdet": "sumpområde",
    "sumpområdets": "sumpområde",
    "sumps": "sump",
    "sumpskogar": "sumpskog",
    "sumpskogarna": "sumpskog",
    "sumpskogarnas": "sumpskog",
    "sumpskogars": "sumpskog",
    "sumpskogen": "sumpskog",
    "sumpskogens": "sumpskog",
    "sumpskogs": "sumpskog",
    "sumrar": "summer",
    "sumrarna": "summer",
    "sumrarnas": "summer",
    "sumrars": "summer",
    "sunda": "sund",
    "sundaen": "sundae",
    "sundaens": "sundae",
    "sundaer": "sundae",
    "sundaerna": "sundae",
    "sundaernas": "sundae",
    "sundaers": "sundae",
    "sundaes": "sundae",
    "sundare": "sund",
    "sundares": "sund",
    "sundas": "sund",
    "sundast": "sund",
    "sundaste": "sund",
    "sundastes": "sund",
    "sundasts": "sund",
    "sunde": "sund",
    "sunden": "sund",
    "sundens": "sund",
    "sundes": "sund",
    "sundet": "sund",
    "sundets": "sund",
    "sundheten": "sundhet",
    "sundhetens": "sundhet",
    "sundhets": "sundhet",
    "sundhetsteckens": "sundhetstecken",
    "sundhetstecknen": "sundhetstecken",
    "sundhetstecknens": "sundhetstecken",
    "sundhetstecknet": "sundhetstecken",
    "sundhetstecknets": "sundhetstecken",
    "sunds": "sund",
    "sunket": "sunk",
    "sunkets": "sunk",
    "sunkiga": "sunkig",
    "sunkigare": "sunkig",
    "sunkigares": "sunkig",
    "sunkigas": "sunkig",
    "sunkigast": "sunkig",
    "sunkigaste": "sunkig",
    "sunkigastes": "sunkig",
    "sunkigasts": "sunkig",
    "sunkige": "sunkig",
    "sunkiges": "sunkig",
    "sunkigheten": "sunkighet",
    "sunkighetens": "sunkighet",
    "sunkigheter": "sunkighet",
    "sunkigheterna": "sunkighet",
    "sunkigheternas": "sunkighet",
    "sunkigheters": "sunkighet",
    "sunkighets": "sunkighet",
    "sunkigs": "sunkig",
    "sunkigt": "sunkig",
    "sunkigts": "sunkig",
    "sunks": "sunk",
    "sunnans": "sunnan",
    "sunnas": "sunna",
    "sunnimuslimen": "sunnimuslim",
    "sunnimuslimens": "sunnimuslim",
    "sunnimuslimer": "sunnimuslim",
    "sunnimuslimerna": "sunnimuslim",
    "sunnimuslimernas": "sunnimuslim",
    "sunnimuslimers": "sunnimuslim",
    "sunnimuslims": "sunnimuslim",
    "sunnimuslimska": "sunnimuslimsk",
    "sunnimuslimskas": "sunnimuslimsk",
    "sunnimuslimske": "sunnimuslimsk",
    "sunnimuslimskes": "sunnimuslimsk",
    "sunnimuslimsks": "sunnimuslimsk",
    "sunnimuslimskt": "sunnimuslimsk",
    "sunnimuslimskts": "sunnimuslimsk",
    "sunnis": "sunni",
    "sunniten": "sunnit",
    "sunnitens": "sunnit",
    "sunniter": "sunnit",
    "sunniterna": "sunnit",
    "sunniternas": "sunnit",
    "sunniters": "sunnit",
    "sunnitiska": "sunnitisk",
    "sunnitiskas": "sunnitisk",
    "sunnitiske": "sunnitisk",
    "sunnitiskes": "sunnitisk",
    "sunnitisks": "sunnitisk",
    "sunnitiskt": "sunnitisk",
    "sunnitiskts": "sunnitisk",
    "sunnits": "sunnit",
    "sunt": "sund",
    "sunts": "sund",
    "suntälten": "suntält",
    "suntältens": "suntält",
    "suntältet": "suntält",
    "suntältets": "suntält",
    "suntälts": "suntält",
    "sup": "supa",
    "supande": "supa",
    "supanden": "supande",
    "supandena": "supande",
    "supandenas": "supande",
    "supandens": "supande",
    "supandes": "supande",
    "supandet": "supande",
    "supandets": "supande",
    "supar": "sup",
    "suparna": "sup",
    "suparnas": "sup",
    "supars": "sup",
    "supas": "supa",
    "supe": "supa",
    "supen": "supa",
    "supens": "supa",
    "super": "supa",
    "superade": "supera",
    "superades": "supera",
    "superande": "supera",
    "superanden": "superande",
    "superandena": "superande",
    "superandenas": "superande",
    "superandens": "superande",
    "superandes": "superande",
    "superandet": "superande",
    "superandets": "superande",
    "superar": "supera",
    "superas": "supera",
    "superat": "supera",
    "superats": "supera",
    "superba": "superb",
    "superbare": "superb",
    "superbares": "superb",
    "superbas": "superb",
    "superbast": "superb",
    "superbaste": "superb",
    "superbastes": "superb",
    "superbasts": "superb",
    "superbe": "superb",
    "superbes": "superb",
    "superbheten": "superbhet",
    "superbhetens": "superbhet",
    "superbhets": "superbhet",
    "superbilar": "superbil",
    "superbilarna": "superbil",
    "superbilarnas": "superbil",
    "superbilars": "superbil",
    "superbilen": "superbil",
    "superbilens": "superbil",
    "superbils": "superbil",
    "superbs": "superb",
    "superbt": "superb",
    "superbts": "superb",
    "superdatorer": "superdator",
    "superdatorerna": "superdator",
    "superdatorernas": "superdator",
    "superdatorers": "superdator",
    "superdatorn": "superdator",
    "superdatorns": "superdator",
    "superdators": "superdator",
    "superdivan": "superdiva",
    "superdivans": "superdiva",
    "superdivas": "superdiva",
    "superdivor": "superdiva",
    "superdivorna": "superdiva",
    "superdivornas": "superdiva",
    "superdivors": "superdiva",
    "superelastiska": "superelastisk",
    "superelastiskas": "superelastisk",
    "superelastiske": "superelastisk",
    "superelastiskes": "superelastisk",
    "superelastisks": "superelastisk",
    "superelastiskt": "superelastisk",
    "superelastiskts": "superelastisk",
    "superellipsen": "superellips",
    "superellipsens": "superellips",
    "superellipser": "superellips",
    "superellipserna": "superellips",
    "superellipsernas": "superellips",
    "superellipsers": "superellips",
    "superfosfatet": "superfosfat",
    "superfosfatets": "superfosfat",
    "superfosfats": "superfosfat",
    "superföreningar": "superförening",
    "superföreningarna": "superförening",
    "superföreningarnas": "superförening",
    "superföreningars": "superförening",
    "superföreningen": "superförening",
    "superföreningens": "superförening",
    "superförenings": "superförening",
    "supergalaxhopar": "supergalaxhop",
    "supergalaxhoparna": "supergalaxhop",
    "supergalaxhoparnas": "supergalaxhop",
    "supergalaxhopars": "supergalaxhop",
    "supergalaxhopen": "supergalaxhop",
    "supergalaxhopens": "supergalaxhop",
    "supergalaxhops": "supergalaxhop",
    "superglada": "superglad",
    "supergladare": "superglad",
    "supergladares": "superglad",
    "supergladas": "superglad",
    "supergladast": "superglad",
    "supergladaste": "superglad",
    "supergladastes": "superglad",
    "supergladasts": "superglad",
    "superglade": "superglad",
    "superglades": "superglad",
    "superglads": "superglad",
    "superglatt": "superglad",
    "superglatts": "superglad",
    "superhopar": "superhop",
    "superhoparna": "superhop",
    "superhoparnas": "superhop",
    "superhopars": "superhop",
    "superhopen": "superhop",
    "superhopens": "superhop",
    "superhops": "superhop",
    "superhopsling": "superhopslinga",
    "superhopslingan": "superhopslinga",
    "superhopslingans": "superhopslinga",
    "superhopslingas": "superhopslinga",
    "superhopslinge": "superhopslinga",
    "superhopslingor": "superhopslinga",
    "superhopslingorna": "superhopslinga",
    "superhopslingornas": "superhopslinga",
    "superhopslingors": "superhopslinga",
    "superhopslings": "superhopslinga",
    "superiet": "superi",
    "superiets": "superi",
    "superingar": "supering",
    "superingarna": "supering",
    "superingarnas": "supering",
    "superingars": "supering",
    "superingen": "supering",
    "superingens": "supering",
    "superings": "supering",
    "superintendenten": "superintendent",
    "superintendentens": "superintendent",
    "superintendenter": "superintendent",
    "superintendenterna": "superintendent",
    "superintendenternas": "superintendent",
    "superintendenters": "superintendent",
    "superintendents": "superintendent",
    "superis": "superi",
    "superit": "superi",
    "superits": "superi",
    "superjetar": "superjet",
    "superjetarna": "superjet",
    "superjetarnas": "superjet",
    "superjetars": "superjet",
    "superjeten": "superjet",
    "superjetens": "superjet",
    "superjets": "superjet",
    "superkargar": "superkarg",
    "superkargarna": "superkarg",
    "superkargarnas": "superkarg",
    "superkargars": "superkarg",
    "superkargen": "superkarg",
    "superkargens": "superkarg",
    "superkargs": "superkarg",
    "superlativa": "superlativ",
    "superlativare": "superlativ",
    "superlativares": "superlativ",
    "superlativas": "superlativ",
    "superlativast": "superlativ",
    "superlativaste": "superlativ",
    "superlativastes": "superlativ",
    "superlativasts": "superlativ",
    "superlative": "superlativ",
    "superlativen": "superlativ",
    "superlativens": "superlativ",
    "superlativer": "superlativ",
    "superlativerna": "superlativ",
    "superlativernas": "superlativ",
    "superlativers": "superlativ",
    "superlatives": "superlativ",
    "superlativs": "superlativ",
    "superlativt": "superlativ",
    "superlativts": "superlativ",
    "superlena": "superlen",
    "superlenare": "superlen",
    "superlenares": "superlen",
    "superlenas": "superlen",
    "superlenast": "superlen",
    "superlenaste": "superlen",
    "superlenastes": "superlen",
    "superlenasts": "superlen",
    "superlene": "superlen",
    "superlenes": "superlen",
    "superlens": "superlen",
    "superlent": "superlen",
    "superlents": "superlen",
    "supermakten": "supermakt",
    "supermaktens": "supermakt",
    "supermakter": "supermakt",
    "supermakterna": "supermakt",
    "supermakternas": "supermakt",
    "supermakters": "supermakt",
    "supermakts": "supermakt",
    "supermaktsstatusen": "supermaktsstatus",
    "supermaktsstatusens": "supermaktsstatus",
    "supermarketen": "supermarket",
    "supermarketens": "supermarket",
    "supermarkets": "supermarket",
    "supermatchen": "supermatch",
    "supermatchens": "supermatch",
    "supermatcher": "supermatch",
    "supermatcherna": "supermatch",
    "supermatchernas": "supermatch",
    "supermatchers": "supermatch",
    "supermatchs": "supermatch",
    "supernov": "supernova",
    "supernovaexplosionen": "supernovaexplosion",
    "supernovaexplosionens": "supernovaexplosion",
    "supernovaexplosioner": "supernovaexplosion",
    "supernovaexplosionerna": "supernovaexplosion",
    "supernovaexplosionernas": "supernovaexplosion",
    "supernovaexplosioners": "supernovaexplosion",
    "supernovaexplosions": "supernovaexplosion",
    "supernovan": "supernova",
    "supernovans": "supernova",
    "supernovas": "supernova",
    "supernovautbrotten": "supernovautbrott",
    "supernovautbrottens": "supernovautbrott",
    "supernovautbrottet": "supernovautbrott",
    "supernovautbrottets": "supernovautbrott",
    "supernovautbrotts": "supernovautbrott",
    "supernove": "supernova",
    "supernovor": "supernova",
    "supernovorna": "supernova",
    "supernovornas": "supernova",
    "supernovors": "supernova",
    "supernovs": "supernova",
    "superpositionen": "superposition",
    "superpositionens": "superposition",
    "superpositioner": "superposition",
    "superpositionerna": "superposition",
    "superpositionernas": "superposition",
    "superpositioners": "superposition",
    "superpositions": "superposition",
    "supersmaskiga": "supersmaskig",
    "supersmaskigas": "supersmaskig",
    "supersmaskige": "supersmaskig",
    "supersmaskiges": "supersmaskig",
    "supersmaskigheten": "supersmaskighet",
    "supersmaskighetens": "supersmaskighet",
    "supersmaskighets": "supersmaskighet",
    "supersmaskigs": "supersmaskig",
    "supersmaskigt": "supersmaskig",
    "supersmaskigts": "supersmaskig",
    "supersnabba": "supersnabb",
    "supersnabbare": "supersnabb",
    "supersnabbares": "supersnabb",
    "supersnabbas": "supersnabb",
    "supersnabbast": "supersnabb",
    "supersnabbaste": "supersnabb",
    "supersnabbastes": "supersnabb",
    "supersnabbasts": "supersnabb",
    "supersnabbe": "supersnabb",
    "supersnabbes": "supersnabb",
    "supersnabbheten": "supersnabbhet",
    "supersnabbhetens": "supersnabbhet",
    "supersnabbhets": "supersnabbhet",
    "supersnabbs": "supersnabb",
    "supersnabbt": "supersnabb",
    "supersnabbts": "supersnabb",
    "supersoniska": "supersonisk",
    "supersoniskare": "supersonisk",
    "supersoniskares": "supersonisk",
    "supersoniskas": "supersonisk",
    "supersoniskast": "supersonisk",
    "supersoniskaste": "supersonisk",
    "supersoniskastes": "supersonisk",
    "supersoniskasts": "supersonisk",
    "supersoniske": "supersonisk",
    "supersoniskes": "supersonisk",
    "supersonisks": "supersonisk",
    "supersoniskt": "supersonisk",
    "supersoniskts": "supersonisk",
    "superspeeden": "superspeed",
    "superspeedens": "superspeed",
    "superspeeds": "superspeed",
    "superstarka": "superstark",
    "superstarkare": "superstark",
    "superstarkares": "superstark",
    "superstarkas": "superstark",
    "superstarkast": "superstark",
    "superstarkaste": "superstark",
    "superstarkastes": "superstark",
    "superstarkasts": "superstark",
    "superstarke": "superstark",
    "superstarkes": "superstark",
    "superstarkheten": "superstarkhet",
    "superstarkhetens": "superstarkhet",
    "superstarkhets": "superstarkhet",
    "superstarks": "superstark",
    "superstarkt": "superstark",
    "superstarkts": "superstark",
    "superstjärnan": "superstjärna",
    "superstjärnans": "superstjärna",
    "superstjärnas": "superstjärna",
    "superstjärne": "superstjärna",
    "superstjärnor": "superstjärna",
    "superstjärnorna": "superstjärna",
    "superstjärnornas": "superstjärna",
    "superstjärnors": "superstjärna",
    "supertankern": "supertanker",
    "supertankerna": "supertanker",
    "supertankernas": "supertanker",
    "supertankerns": "supertanker",
    "supertankers": "supertanker",
    "supertankersarna": "supertanker",
    "supertankersarnas": "supertanker",
    "supertankrar": "supertanker",
    "supertankrarna": "supertanker",
    "supertankrarnas": "supertanker",
    "supertankrars": "supertanker",
    "supertungvikten": "supertungvikt",
    "supertungviktens": "supertungvikt",
    "supertungvikts": "supertungvikt",
    "superviktiga": "superviktig",
    "superviktigas": "superviktig",
    "superviktige": "superviktig",
    "superviktiges": "superviktig",
    "superviktigheten": "superviktighet",
    "superviktighetens": "superviktighet",
    "superviktighets": "superviktighet",
    "superviktigs": "superviktig",
    "superviktigt": "superviktig",
    "superviktigts": "superviktig",
    "supervinsten": "supervinst",
    "supervinstens": "supervinst",
    "supervinster": "supervinst",
    "supervinsterna": "supervinst",
    "supervinsternas": "supervinst",
    "supervinsters": "supervinst",
    "supervinsts": "supervinst",
    "supervätskan": "supervätska",
    "supervätskans": "supervätska",
    "supervätskas": "supervätska",
    "supervätske": "supervätska",
    "supes": "supa",
    "supet": "supa",
    "supets": "supa",
    "supiga": "supig",
    "supigare": "supig",
    "supigares": "supig",
    "supigas": "supig",
    "supigast": "supig",
    "supigaste": "supig",
    "supigastes": "supig",
    "supigasts": "supig",
    "supige": "supig",
    "supiges": "supig",
    "supigs": "supig",
    "supigt": "supig",
    "supigts": "supig",
    "supiner": "supinum",
    "supinerna": "supinum",
    "supinernas": "supinum",
    "supiners": "supinum",
    "supinumet": "supinum",
    "supinumets": "supinum",
    "supinums": "supinum",
    "supit": "supa",
    "supits": "supa",
    "supna": "supa",
    "supnas": "supa",
    "supne": "supa",
    "supnes": "supa",
    "suppleanten": "suppleant",
    "suppleantens": "suppleant",
    "suppleanter": "suppleant",
    "suppleanterna": "suppleant",
    "suppleanternas": "suppleant",
    "suppleanters": "suppleant",
    "suppleants": "suppleant",
    "supplementen": "supplement",
    "supplementens": "supplement",
    "supplementet": "supplement",
    "supplementets": "supplement",
    "supplements": "supplement",
    "supplementvinkeln": "supplementvinkel",
    "supplementvinkelns": "supplementvinkel",
    "supplementvinkels": "supplementvinkel",
    "supplementvinklar": "supplementvinkel",
    "supplementvinklarna": "supplementvinkel",
    "supplementvinklarnas": "supplementvinkel",
    "supplementvinklars": "supplementvinkel",
    "supplementära": "supplementär",
    "supplementärare": "supplementär",
    "supplementärares": "supplementär",
    "supplementäras": "supplementär",
    "supplementärast": "supplementär",
    "supplementäraste": "supplementär",
    "supplementärastes": "supplementär",
    "supplementärasts": "supplementär",
    "supplementäre": "supplementär",
    "supplementäres": "supplementär",
    "supplementärs": "supplementär",
    "supplementärt": "supplementär",
    "supplementärts": "supplementär",
    "supplerad": "supplera",
    "supplerade": "supplera",
    "supplerades": "supplera",
    "supplerads": "supplera",
    "supplerande": "supplera",
    "suppleranden": "supplerande",
    "supplerandena": "supplerande",
    "supplerandenas": "supplerande",
    "supplerandens": "supplerande",
    "supplerandes": "supplerande",
    "supplerandet": "supplerande",
    "supplerandets": "supplerande",
    "supplerar": "supplera",
    "suppleras": "supplera",
    "supplerat": "supplera",
    "supplerats": "supplera",
    "supplerbara": "supplerbar",
    "supplerbarare": "supplerbar",
    "supplerbarares": "supplerbar",
    "supplerbaras": "supplerbar",
    "supplerbarast": "supplerbar",
    "supplerbaraste": "supplerbar",
    "supplerbarastes": "supplerbar",
    "supplerbarasts": "supplerbar",
    "supplerbare": "supplerbar",
    "supplerbares": "supplerbar",
    "supplerbarheten": "supplerbarhet",
    "supplerbarhetens": "supplerbarhet",
    "supplerbarhets": "supplerbarhet",
    "supplerbars": "supplerbar",
    "supplerbart": "supplerbar",
    "supplerbarts": "supplerbar",
    "suppleringar": "supplering",
    "suppleringarna": "supplering",
    "suppleringarnas": "supplering",
    "suppleringars": "supplering",
    "suppleringen": "supplering",
    "suppleringens": "supplering",
    "supplerings": "supplering",
    "supplikanten": "supplikant",
    "supplikantens": "supplikant",
    "supplikanter": "supplikant",
    "supplikanterna": "supplikant",
    "supplikanternas": "supplikant",
    "supplikanters": "supplikant",
    "supplikants": "supplikant",
    "suppliken": "supplik",
    "supplikens": "supplik",
    "suppliker": "supplik",
    "supplikerna": "supplik",
    "supplikernas": "supplik",
    "supplikers": "supplik",
    "suppliks": "supplik",
    "supponerad": "supponera",
    "supponerade": "supponera",
    "supponerades": "supponera",
    "supponerads": "supponera",
    "supponerande": "supponera",
    "supponeranden": "supponerande",
    "supponerandena": "supponerande",
    "supponerandenas": "supponerande",
    "supponerandens": "supponerande",
    "supponerandes": "supponerande",
    "supponerandet": "supponerande",
    "supponerandets": "supponerande",
    "supponerar": "supponera",
    "supponeras": "supponera",
    "supponerat": "supponera",
    "supponerats": "supponera",
    "supponerbara": "supponerbar",
    "supponerbarare": "supponerbar",
    "supponerbarares": "supponerbar",
    "supponerbaras": "supponerbar",
    "supponerbarast": "supponerbar",
    "supponerbaraste": "supponerbar",
    "supponerbarastes": "supponerbar",
    "supponerbarasts": "supponerbar",
    "supponerbare": "supponerbar",
    "supponerbares": "supponerbar",
    "supponerbarheten": "supponerbarhet",
    "supponerbarhetens": "supponerbarhet",
    "supponerbarhets": "supponerbarhet",
    "supponerbars": "supponerbar",
    "supponerbart": "supponerbar",
    "supponerbarts": "supponerbar",
    "supponeringar": "supponering",
    "supponeringarna": "supponering",
    "supponeringarnas": "supponering",
    "supponeringars": "supponering",
    "supponeringen": "supponering",
    "supponeringens": "supponering",
    "supponerings": "supponering",
    "supporten": "support",
    "supportens": "support",
    "supporter": "support",
    "supporterbråken": "supporterbråk",
    "supporterbråkens": "supporterbråk",
    "supporterbråket": "supporterbråk",
    "supporterbråkets": "supporterbråk",
    "supporterbråks": "supporterbråk",
    "supporterklubbar": "supporterklubb",
    "supporterklubbarna": "supporterklubb",
    "supporterklubbarnas": "supporterklubb",
    "supporterklubbars": "supporterklubb",
    "supporterklubben": "supporterklubb",
    "supporterklubbens": "supporterklubb",
    "supporterklubbs": "supporterklubb",
    "supportern": "supporter",
    "supporterna": "support",
    "supporternas": "support",
    "supporterns": "supporter",
    "supporters": "supporter",
    "supportrar": "supporter",
    "supportrarna": "supporter",
    "supportrarnas": "supporter",
    "supportrars": "supporter",
    "supports": "support",
    "suppositionen": "supposition",
    "suppositionens": "supposition",
    "suppositioner": "supposition",
    "suppositionerna": "supposition",
    "suppositionernas": "supposition",
    "suppositioners": "supposition",
    "suppositions": "supposition",
    "suppositorie": "suppositorium",
    "suppositorier": "suppositorium",
    "suppositorierna": "suppositorium",
    "suppositoriernas": "suppositorium",
    "suppositoriers": "suppositorium",
    "suppositoriet": "suppositorium",
    "suppositoriets": "suppositorium",
    "suppositoriums": "suppositorium",
    "suppurerade": "suppurera",
    "suppurerades": "suppurera",
    "suppurerande": "suppurera",
    "suppureranden": "suppurerande",
    "suppurerandena": "suppurerande",
    "suppurerandenas": "suppurerande",
    "suppurerandens": "suppurerande",
    "suppurerandes": "suppurerande",
    "suppurerandet": "suppurerande",
    "suppurerandets": "suppurerande",
    "suppurerar": "suppurera",
    "suppureras": "suppurera",
    "suppurerat": "suppurera",
    "suppurerats": "suppurera",
    "suppureringar": "suppurering",
    "suppureringarna": "suppurering",
    "suppureringarnas": "suppurering",
    "suppureringars": "suppurering",
    "suppureringen": "suppurering",
    "suppureringens": "suppurering",
    "suppurerings": "suppurering",
    "supradentala": "supradental",
    "supradentalare": "supradental",
    "supradentalares": "supradental",
    "supradentalas": "supradental",
    "supradentalast": "supradental",
    "supradentalaste": "supradental",
    "supradentalastes": "supradental",
    "supradentalasts": "supradental",
    "supradentale": "supradental",
    "supradentalen": "supradental",
    "supradentalens": "supradental",
    "supradentaler": "supradental",
    "supradentalerna": "supradental",
    "supradentalernas": "supradental",
    "supradentalers": "supradental",
    "supradentales": "supradental",
    "supradentals": "supradental",
    "supradentalt": "supradental",
    "supradentalts": "supradental",
    "supraledar": "supraledare",
    "supraledaren": "supraledare",
    "supraledarens": "supraledare",
    "supraledares": "supraledare",
    "supraledarna": "supraledare",
    "supraledarnas": "supraledare",
    "supraledningar": "supraledning",
    "supraledningarna": "supraledning",
    "supraledningarnas": "supraledning",
    "supraledningars": "supraledning",
    "supraledningen": "supraledning",
    "supraledningens": "supraledning",
    "supralednings": "supraledning",
    "supramarina": "supramarin",
    "supramarinare": "supramarin",
    "supramarinares": "supramarin",
    "supramarinas": "supramarin",
    "supramarinast": "supramarin",
    "supramarinaste": "supramarin",
    "supramarinastes": "supramarin",
    "supramarinasts": "supramarin",
    "supramarine": "supramarin",
    "supramarines": "supramarin",
    "supramarins": "supramarin",
    "supramarint": "supramarin",
    "supramarints": "supramarin",
    "supranaturalismen": "supranaturalism",
    "supranaturalismens": "supranaturalism",
    "supranaturalismer": "supranaturalism",
    "supranaturalismerna": "supranaturalism",
    "supranaturalismernas": "supranaturalism",
    "supranaturalismers": "supranaturalism",
    "supranaturalisms": "supranaturalism",
    "supranaturalistiska": "supranaturalistisk",
    "supranaturalistiskas": "supranaturalistisk",
    "supranaturalistiske": "supranaturalistisk",
    "supranaturalistiskes": "supranaturalistisk",
    "supranaturalistisks": "supranaturalistisk",
    "supranaturalistiskt": "supranaturalistisk",
    "supranaturalistiskts": "supranaturalistisk",
    "suprematien": "supremati",
    "suprematiens": "supremati",
    "suprematin": "supremati",
    "suprematins": "supremati",
    "suprematis": "supremati",
    "suprematismen": "suprematism",
    "suprematismens": "suprematism",
    "suprematismer": "suprematism",
    "suprematismerna": "suprematism",
    "suprematismernas": "suprematism",
    "suprematismers": "suprematism",
    "suprematisms": "suprematism",
    "suprematistiska": "suprematistisk",
    "suprematistiskas": "suprematistisk",
    "suprematistiske": "suprematistisk",
    "suprematistiskes": "suprematistisk",
    "suprematistisks": "suprematistisk",
    "suprematistiskt": "suprematistisk",
    "suprematistiskts": "suprematistisk",
    "sups": "supa",
    "suputar": "suput",
    "suputarna": "suput",
    "suputarnas": "suput",
    "suputars": "suput",
    "suputen": "suput",
    "suputens": "suput",
    "suputer": "suput",
    "suputerna": "suput",
    "suputernas": "suput",
    "suputers": "suput",
    "suputs": "suput",
    "supéer": "supé",
    "supéerna": "supé",
    "supéernas": "supé",
    "supéers": "supé",
    "supén": "supé",
    "supéns": "supé",
    "supés": "supé",
    "sur": "sura",
    "sura": "sur",
    "surad": "sura",
    "surade": "sura",
    "surades": "sura",
    "surads": "sura",
    "suran": "sura",
    "surande": "sura",
    "suranden": "surande",
    "surandena": "surande",
    "surandenas": "surande",
    "surandens": "surande",
    "surandes": "surande",
    "surandet": "surande",
    "surandets": "surande",
    "surans": "sura",
    "surapeln": "surapel",
    "surapelns": "surapel",
    "surapels": "surapel",
    "suraplar": "surapel",
    "suraplarna": "surapel",
    "suraplarnas": "surapel",
    "suraplars": "surapel",
    "surar": "sura",
    "surare": "sur",
    "surares": "sur",
    "suras": "sura",
    "surast": "sur",
    "suraste": "sur",
    "surastes": "sur",
    "surasts": "sur",
    "surat": "sura",
    "surats": "sura",
    "surbrunnar": "surbrunn",
    "surbrunnarna": "surbrunn",
    "surbrunnarnas": "surbrunn",
    "surbrunnars": "surbrunn",
    "surbrunnen": "surbrunn",
    "surbrunnens": "surbrunn",
    "surbrunns": "surbrunn",
    "surdegar": "surdeg",
    "surdegarna": "surdeg",
    "surdegarnas": "surdeg",
    "surdegars": "surdeg",
    "surdegen": "surdeg",
    "surdegens": "surdeg",
    "surdegs": "surdeg",
    "sure": "sura",
    "sures": "sur",
    "surf": "surfa",
    "surfad": "surfa",
    "surfade": "surfa",
    "surfades": "surfa",
    "surfads": "surfa",
    "surfande": "surfa",
    "surfanden": "surfande",
    "surfandena": "surfande",
    "surfandenas": "surfande",
    "surfandens": "surfande",
    "surfandes": "surfande",
    "surfandet": "surfande",
    "surfandets": "surfande",
    "surfar": "surfare",
    "surfaren": "surfare",
    "surfarens": "surfare",
    "surfares": "surfare",
    "surfarna": "surfare",
    "surfarnas": "surfare",
    "surfas": "surfa",
    "surfat": "surfa",
    "surfats": "surfa",
    "surfbara": "surfbar",
    "surfbarare": "surfbar",
    "surfbarares": "surfbar",
    "surfbaras": "surfbar",
    "surfbarast": "surfbar",
    "surfbaraste": "surfbar",
    "surfbarastes": "surfbar",
    "surfbarasts": "surfbar",
    "surfbare": "surfbar",
    "surfbares": "surfbar",
    "surfbarheten": "surfbarhet",
    "surfbarhetens": "surfbarhet",
    "surfbarhets": "surfbarhet",
    "surfbars": "surfbar",
    "surfbart": "surfbar",
    "surfbarts": "surfbar",
    "surfbräd": "surfbräda",
    "surfbrädan": "surfbräda",
    "surfbrädans": "surfbräda",
    "surfbrädas": "surfbräda",
    "surfbräde": "surfbräda",
    "surfbräden": "surfbräde",
    "surfbrädena": "surfbräde",
    "surfbrädenas": "surfbräde",
    "surfbrädens": "surfbräde",
    "surfbrädes": "surfbräde",
    "surfbrädet": "surfbräde",
    "surfbrädets": "surfbräde",
    "surfbrädor": "surfbräda",
    "surfbrädorna": "surfbräda",
    "surfbrädornas": "surfbräda",
    "surfbrädors": "surfbräda",
    "surfbräds": "surfbräda",
    "surfen": "surf",
    "surfens": "surf",
    "surfingbräd": "surfingbräda",
    "surfingbrädan": "surfingbräda",
    "surfingbrädans": "surfingbräda",
    "surfingbrädas": "surfingbräda",
    "surfingbräde": "surfingbräda",
    "surfingbräden": "surfingbräde",
    "surfingbrädena": "surfingbräde",
    "surfingbrädenas": "surfingbräde",
    "surfingbrädens": "surfingbräde",
    "surfingbrädes": "surfingbräde",
    "surfingbrädet": "surfingbräde",
    "surfingbrädets": "surfingbräde",
    "surfingbrädor": "surfingbräda",
    "surfingbrädorna": "surfingbräda",
    "surfingbrädornas": "surfingbräda",
    "surfingbrädors": "surfingbräda",
    "surfingbräds": "surfingbräda",
    "surfingen": "surfing",
    "surfingens": "surfing",
    "surfings": "surfing",
    "surfningar": "surfning",
    "surfningarna": "surfning",
    "surfningarnas": "surfning",
    "surfningars": "surfning",
    "surfningen": "surfning",
    "surfningens": "surfning",
    "surfnings": "surfning",
    "surfoderna": "surfoder",
    "surfodernas": "surfoder",
    "surfoders": "surfoder",
    "surfodren": "surfoder",
    "surfodrens": "surfoder",
    "surfodret": "surfoder",
    "surfodrets": "surfoder",
    "surfplattan": "surfplatta",
    "surfplattans": "surfplatta",
    "surfplattas": "surfplatta",
    "surfplatte": "surfplatta",
    "surfplattor": "surfplatta",
    "surfplattorna": "surfplatta",
    "surfplattornas": "surfplatta",
    "surfplattors": "surfplatta",
    "surfproffsen": "surfproffs",
    "surfproffsens": "surfproffs",
    "surfproffset": "surfproffs",
    "surfproffsets": "surfproffs",
    "surfs": "surf",
    "surheten": "surhet",
    "surhetens": "surhet",
    "surheter": "surhet",
    "surheterna": "surhet",
    "surheternas": "surhet",
    "surheters": "surhet",
    "surhets": "surhet",
    "surhetsgraden": "surhetsgrad",
    "surhetsgradens": "surhetsgrad",
    "surhetsgrader": "surhetsgrad",
    "surhetsgraderna": "surhetsgrad",
    "surhetsgradernas": "surhetsgrad",
    "surhetsgraders": "surhetsgrad",
    "surhetsgrads": "surhetsgrad",
    "surinamesen": "surinames",
    "surinamesens": "surinames",
    "surinameser": "surinames",
    "surinameserna": "surinames",
    "surinamesernas": "surinames",
    "surinamesers": "surinames",
    "surinamesiska": "surinamesisk",
    "surinamesiskan": "surinamesiska",
    "surinamesiskans": "surinamesiska",
    "surinamesiskare": "surinamesisk",
    "surinamesiskares": "surinamesisk",
    "surinamesiskas": "surinamesiska",
    "surinamesiskast": "surinamesisk",
    "surinamesiskaste": "surinamesisk",
    "surinamesiskastes": "surinamesisk",
    "surinamesiskasts": "surinamesisk",
    "surinamesiske": "surinamesiska",
    "surinamesiskes": "surinamesisk",
    "surinamesiskor": "surinamesiska",
    "surinamesiskorna": "surinamesiska",
    "surinamesiskornas": "surinamesiska",
    "surinamesiskors": "surinamesiska",
    "surinamesisks": "surinamesisk",
    "surinamesiskt": "surinamesisk",
    "surinamesiskts": "surinamesisk",
    "surkartar": "surkart",
    "surkartarna": "surkart",
    "surkartarnas": "surkart",
    "surkartars": "surkart",
    "surkarten": "surkart",
    "surkartens": "surkart",
    "surkarts": "surkart",
    "surkålen": "surkål",
    "surkålens": "surkål",
    "surkåls": "surkål",
    "surkörsbären": "surkörsbär",
    "surkörsbärens": "surkörsbär",
    "surkörsbäret": "surkörsbär",
    "surkörsbärets": "surkörsbär",
    "surkörsbärs": "surkörsbär",
    "surmjölken": "surmjölk",
    "surmjölkens": "surmjölk",
    "surmjölks": "surmjölk",
    "surmulens": "surmulen",
    "surmulet": "surmulen",
    "surmulets": "surmulen",
    "surmulna": "surmulen",
    "surmulnare": "surmulen",
    "surmulnares": "surmulen",
    "surmulnas": "surmulen",
    "surmulnast": "surmulen",
    "surmulnaste": "surmulen",
    "surmulnastes": "surmulen",
    "surmulnasts": "surmulen",
    "surmulne": "surmulen",
    "surmulnes": "surmulen",
    "surn": "surna",
    "surnad": "surna",
    "surnade": "surna",
    "surnades": "surna",
    "surnads": "surna",
    "surnande": "surna",
    "surnanden": "surnande",
    "surnandena": "surnande",
    "surnandenas": "surnande",
    "surnandens": "surnande",
    "surnandes": "surnande",
    "surnandet": "surnande",
    "surnandets": "surnande",
    "surnar": "surna",
    "surnas": "surna",
    "surnat": "surna",
    "surnats": "surna",
    "suror": "sura",
    "surorna": "sura",
    "surornas": "sura",
    "surors": "sura",
    "surprisen": "surpris",
    "surprisens": "surpris",
    "surpriser": "surpris",
    "surpriserna": "surpris",
    "surprisernas": "surpris",
    "surprisers": "surpris",
    "surpupp": "surpuppa",
    "surpuppan": "surpuppa",
    "surpuppans": "surpuppa",
    "surpuppas": "surpuppa",
    "surpuppe": "surpuppa",
    "surpuppor": "surpuppa",
    "surpupporna": "surpuppa",
    "surpuppornas": "surpuppa",
    "surpuppors": "surpuppa",
    "surpupps": "surpuppa",
    "surr": "surra",
    "surrad": "surra",
    "surrade": "surra",
    "surrades": "surra",
    "surrads": "surra",
    "surrande": "surra",
    "surranden": "surrande",
    "surrandena": "surrande",
    "surrandenas": "surrande",
    "surrandens": "surrande",
    "surrandes": "surrande",
    "surrandet": "surrande",
    "surrandets": "surrande",
    "surrar": "surra",
    "surras": "surra",
    "surrat": "surra",
    "surrats": "surra",
    "surrealismen": "surrealism",
    "surrealismens": "surrealism",
    "surrealismer": "surrealism",
    "surrealismerna": "surrealism",
    "surrealismernas": "surrealism",
    "surrealismers": "surrealism",
    "surrealisms": "surrealism",
    "surrealistiska": "surrealistisk",
    "surrealistiskare": "surrealistisk",
    "surrealistiskares": "surrealistisk",
    "surrealistiskas": "surrealistisk",
    "surrealistiskast": "surrealistisk",
    "surrealistiskaste": "surrealistisk",
    "surrealistiskastes": "surrealistisk",
    "surrealistiskasts": "surrealistisk",
    "surrealistiske": "surrealistisk",
    "surrealistiskes": "surrealistisk",
    "surrealistisks": "surrealistisk",
    "surrealistiskt": "surrealistisk",
    "surrealistiskts": "surrealistisk",
    "surret": "surr",
    "surrets": "surr",
    "surrogaten": "surrogat",
    "surrogatens": "surrogat",
    "surrogatet": "surrogat",
    "surrogatets": "surrogat",
    "surrogatmamman": "surrogatmamma",
    "surrogatmammans": "surrogatmamma",
    "surrogatmammas": "surrogatmamma",
    "surrogatmamme": "surrogatmamma",
    "surrogatmammor": "surrogatmamma",
    "surrogatmammorna": "surrogatmamma",
    "surrogatmammornas": "surrogatmamma",
    "surrogatmammors": "surrogatmamma",
    "surrogats": "surrogat",
    "surrs": "surr",
    "surs": "sura",
    "surstekar": "surstek",
    "surstekarna": "surstek",
    "surstekarnas": "surstek",
    "surstekars": "surstek",
    "sursteken": "surstek",
    "surstekens": "surstek",
    "sursteks": "surstek",
    "surströmmingar": "surströmming",
    "surströmmingarna": "surströmming",
    "surströmmingarnas": "surströmming",
    "surströmmingars": "surströmming",
    "surströmmingen": "surströmming",
    "surströmmingens": "surströmming",
    "surströmmings": "surströmming",
    "surt": "sur",
    "surts": "sur",
    "surögda": "surögd",
    "surögdare": "surögd",
    "surögdares": "surögd",
    "surögdas": "surögd",
    "surögdast": "surögd",
    "surögdaste": "surögd",
    "surögdastes": "surögd",
    "surögdasts": "surögd",
    "surögde": "surögd",
    "surögdes": "surögd",
    "surögdheten": "surögdhet",
    "surögdhetens": "surögdhet",
    "surögdhets": "surögdhet",
    "surögds": "surögd",
    "surögt": "surögd",
    "surögts": "surögd",
    "sus": "susa",
    "susad": "susa",
    "susade": "susa",
    "susades": "susa",
    "susads": "susa",
    "susande": "susa",
    "susanden": "susande",
    "susandena": "susande",
    "susandenas": "susande",
    "susandens": "susande",
    "susandes": "susande",
    "susandet": "susande",
    "susandets": "susande",
    "susar": "susa",
    "susas": "susa",
    "susat": "susa",
    "susats": "susa",
    "suset": "sus",
    "susets": "sus",
    "sushin": "sushi",
    "sushins": "sushi",
    "sushis": "sushi",
    "susningar": "susning",
    "susningarna": "susning",
    "susningarnas": "susning",
    "susningars": "susning",
    "susningen": "susning",
    "susningens": "susning",
    "susnings": "susning",
    "suspekta": "suspekt",
    "suspektare": "suspekt",
    "suspektares": "suspekt",
    "suspektas": "suspekt",
    "suspektast": "suspekt",
    "suspektaste": "suspekt",
    "suspektastes": "suspekt",
    "suspektasts": "suspekt",
    "suspekte": "suspekt",
    "suspektes": "suspekt",
    "suspektheten": "suspekthet",
    "suspekthetens": "suspekthet",
    "suspekthets": "suspekthet",
    "suspekts": "suspekt",
    "suspenderad": "suspendera",
    "suspenderade": "suspendera",
    "suspenderades": "suspendera",
    "suspenderads": "suspendera",
    "suspenderande": "suspendera",
    "suspenderanden": "suspenderande",
    "suspenderandena": "suspenderande",
    "suspenderandenas": "suspenderande",
    "suspenderandens": "suspenderande",
    "suspenderandes": "suspenderande",
    "suspenderandet": "suspenderande",
    "suspenderandets": "suspenderande",
    "suspenderar": "suspendera",
    "suspenderas": "suspendera",
    "suspenderat": "suspendera",
    "suspenderats": "suspendera",
    "suspenderbara": "suspenderbar",
    "suspenderbarare": "suspenderbar",
    "suspenderbarares": "suspenderbar",
    "suspenderbaras": "suspenderbar",
    "suspenderbarast": "suspenderbar",
    "suspenderbaraste": "suspenderbar",
    "suspenderbarastes": "suspenderbar",
    "suspenderbarasts": "suspenderbar",
    "suspenderbare": "suspenderbar",
    "suspenderbares": "suspenderbar",
    "suspenderbarheten": "suspenderbarhet",
    "suspenderbarhetens": "suspenderbarhet",
    "suspenderbarhets": "suspenderbarhet",
    "suspenderbars": "suspenderbar",
    "suspenderbart": "suspenderbar",
    "suspenderbarts": "suspenderbar",
    "suspenderingar": "suspendering",
    "suspenderingarna": "suspendering",
    "suspenderingarnas": "suspendering",
    "suspenderingars": "suspendering",
    "suspenderingen": "suspendering",
    "suspenderingens": "suspendering",
    "suspenderings": "suspendering",
    "suspensionen": "suspension",
    "suspensionens": "suspension",
    "suspensioner": "suspension",
    "suspensionerna": "suspension",
    "suspensionernas": "suspension",
    "suspensioners": "suspension",
    "suspensions": "suspension",
    "suspensiva": "suspensiv",
    "suspensivare": "suspensiv",
    "suspensivares": "suspensiv",
    "suspensivas": "suspensiv",
    "suspensivast": "suspensiv",
    "suspensivaste": "suspensiv",
    "suspensivastes": "suspensiv",
    "suspensivasts": "suspensiv",
    "suspensive": "suspensiv",
    "suspensives": "suspensiv",
    "suspensivs": "suspensiv",
    "suspensivt": "suspensiv",
    "suspensivts": "suspensiv",
    "suspensoaren": "suspensoar",
    "suspensoarens": "suspensoar",
    "suspensoarer": "suspensoar",
    "suspensoarerna": "suspensoar",
    "suspensoarernas": "suspensoar",
    "suspensoarers": "suspensoar",
    "suspensoars": "suspensoar",
    "suss": "sussa",
    "sussad": "sussa",
    "sussade": "sussa",
    "sussades": "sussa",
    "sussads": "sussa",
    "sussande": "sussa",
    "sussanden": "sussande",
    "sussandena": "sussande",
    "sussandenas": "sussande",
    "sussandens": "sussande",
    "sussandes": "sussande",
    "sussandet": "sussande",
    "sussandets": "sussande",
    "sussar": "sussa",
    "sussas": "sussa",
    "sussat": "sussa",
    "sussats": "sussa",
    "sutanen": "sutan",
    "sutanens": "sutan",
    "sutaner": "sutan",
    "sutanerna": "sutan",
    "sutanernas": "sutan",
    "sutaners": "sutan",
    "sutans": "sutan",
    "sutar": "sutare",
    "sutaren": "sutare",
    "sutarens": "sutare",
    "sutares": "sutare",
    "sutarna": "sutare",
    "sutarnas": "sutare",
    "sutenören": "sutenör",
    "sutenörens": "sutenör",
    "sutenörer": "sutenör",
    "sutenörerna": "sutenör",
    "sutenörernas": "sutenör",
    "sutenörers": "sutenör",
    "sutenörs": "sutenör",
    "suterrängbyggnaden": "suterrängbyggnad",
    "suterrängbyggnadens": "suterrängbyggnad",
    "suterrängbyggnader": "suterrängbyggnad",
    "suterrängbyggnaderna": "suterrängbyggnad",
    "suterrängbyggnadernas": "suterrängbyggnad",
    "suterrängbyggnaders": "suterrängbyggnad",
    "suterrängbyggnads": "suterrängbyggnad",
    "suterrängen": "suterräng",
    "suterrängens": "suterräng",
    "suterränger": "suterräng",
    "suterrängerna": "suterräng",
    "suterrängernas": "suterräng",
    "suterrängers": "suterräng",
    "suterränghusen": "suterränghus",
    "suterränghusens": "suterränghus",
    "suterränghuset": "suterränghus",
    "suterränghusets": "suterränghus",
    "suterrängplanen": "suterrängplan",
    "suterrängplanens": "suterrängplan",
    "suterrängplanet": "suterrängplan",
    "suterrängplanets": "suterrängplan",
    "suterrängplans": "suterrängplan",
    "suterrängs": "suterräng",
    "suterrängvåningar": "suterrängvåning",
    "suterrängvåningarna": "suterrängvåning",
    "suterrängvåningarnas": "suterrängvåning",
    "suterrängvåningars": "suterrängvåning",
    "suterrängvåningen": "suterrängvåning",
    "suterrängvåningens": "suterrängvåning",
    "suterrängvånings": "suterrängvåning",
    "sutte": "sitta",
    "suttes": "sitta",
    "suttit": "sitta",
    "suttits": "sitta",
    "suturen": "sutur",
    "suturens": "sutur",
    "suturer": "sutur",
    "suturerna": "sutur",
    "suturernas": "sutur",
    "suturers": "sutur",
    "suturs": "sutur",
    "suveniren": "suvenir",
    "suvenirens": "suvenir",
    "suvenirer": "suvenir",
    "suvenirerna": "suvenir",
    "suvenirernas": "suvenir",
    "suvenirers": "suvenir",
    "suvenirs": "suvenir",
    "suveräna": "suverän",
    "suveränare": "suverän",
    "suveränares": "suverän",
    "suveränas": "suverän",
    "suveränast": "suverän",
    "suveränaste": "suverän",
    "suveränastes": "suverän",
    "suveränasts": "suverän",
    "suveräne": "suverän",
    "suveränen": "suverän",
    "suveränens": "suverän",
    "suveräner": "suverän",
    "suveränerna": "suverän",
    "suveränernas": "suverän",
    "suveräners": "suverän",
    "suveränes": "suverän",
    "suveräniteten": "suveränitet",
    "suveränitetens": "suveränitet",
    "suveräniteter": "suveränitet",
    "suveräniteterna": "suveränitet",
    "suveräniteternas": "suveränitet",
    "suveräniteters": "suveränitet",
    "suveränitets": "suveränitet",
    "suveräns": "suverän",
    "suveränt": "suverän",
    "suveränts": "suverän",
    "svabb": "svabba",
    "svabbad": "svabba",
    "svabbade": "svabba",
    "svabbades": "svabba",
    "svabbads": "svabba",
    "svabbande": "svabba",
    "svabbanden": "svabbande",
    "svabbandena": "svabbande",
    "svabbandenas": "svabbande",
    "svabbandens": "svabbande",
    "svabbandes": "svabbande",
    "svabbandet": "svabbande",
    "svabbandets": "svabbande",
    "svabbar": "svabba",
    "svabbarna": "svabb",
    "svabbarnas": "svabb",
    "svabbars": "svabb",
    "svabbas": "svabba",
    "svabbat": "svabba",
    "svabbats": "svabba",
    "svabben": "svabb",
    "svabbens": "svabb",
    "svabbs": "svabb",
    "svack": "svacka",
    "svackan": "svacka",
    "svackans": "svacka",
    "svackas": "svacka",
    "svacke": "svacka",
    "svackor": "svacka",
    "svackorna": "svacka",
    "svackornas": "svacka",
    "svackors": "svacka",
    "svacks": "svacka",
    "svadan": "svada",
    "svadans": "svada",
    "svadas": "svada",
    "svaga": "svag",
    "svagare": "svag",
    "svagares": "svag",
    "svagartikulerade": "svagartikulerad",
    "svagartikulerades": "svagartikulerad",
    "svagartikulerads": "svagartikulerad",
    "svagartikulerat": "svagartikulerad",
    "svagartikulerats": "svagartikulerad",
    "svagas": "svag",
    "svagast": "svag",
    "svagaste": "svag",
    "svagastes": "svag",
    "svagasts": "svag",
    "svagdrickan": "svagdricka",
    "svagdrickans": "svagdricka",
    "svagdrickas": "svagdricka",
    "svage": "svag",
    "svages": "svag",
    "svagheten": "svaghet",
    "svaghetens": "svaghet",
    "svagheter": "svaghet",
    "svagheterna": "svaghet",
    "svagheternas": "svaghet",
    "svagheters": "svaghet",
    "svaghets": "svaghet",
    "svaghetsteckens": "svaghetstecken",
    "svaghetstecknen": "svaghetstecken",
    "svaghetstecknens": "svaghetstecken",
    "svaghetstecknet": "svaghetstecken",
    "svaghetstecknets": "svaghetstecken",
    "svags": "svag",
    "svagsinta": "svagsint",
    "svagsintare": "svagsint",
    "svagsintares": "svagsint",
    "svagsintas": "svagsint",
    "svagsintast": "svagsint",
    "svagsintaste": "svagsint",
    "svagsintastes": "svagsint",
    "svagsintasts": "svagsint",
    "svagsinte": "svagsint",
    "svagsintes": "svagsint",
    "svagsintheten": "svagsinthet",
    "svagsinthetens": "svagsinthet",
    "svagsinthets": "svagsinthet",
    "svagsints": "svagsint",
    "svagströmmar": "svagström",
    "svagströmmarna": "svagström",
    "svagströmmarnas": "svagström",
    "svagströmmars": "svagström",
    "svagströmmen": "svagström",
    "svagströmmens": "svagström",
    "svagströms": "svagström",
    "svagsynta": "svagsynt",
    "svagsyntare": "svagsynt",
    "svagsyntares": "svagsynt",
    "svagsyntas": "svagsynt",
    "svagsyntast": "svagsynt",
    "svagsyntaste": "svagsynt",
    "svagsyntastes": "svagsynt",
    "svagsyntasts": "svagsynt",
    "svagsynte": "svagsynt",
    "svagsyntes": "svagsynt",
    "svagsyntheten": "svagsynthet",
    "svagsynthetens": "svagsynthet",
    "svagsynthets": "svagsynthet",
    "svagsynts": "svagsynt",
    "svagt": "svag",
    "svagtoniga": "svagtonig",
    "svagtonigare": "svagtonig",
    "svagtonigares": "svagtonig",
    "svagtonigas": "svagtonig",
    "svagtonigast": "svagtonig",
    "svagtonigaste": "svagtonig",
    "svagtonigastes": "svagtonig",
    "svagtonigasts": "svagtonig",
    "svagtonige": "svagtonig",
    "svagtoniges": "svagtonig",
    "svagtonigheten": "svagtonighet",
    "svagtonighetens": "svagtonighet",
    "svagtonighets": "svagtonighet",
    "svagtonigs": "svagtonig",
    "svagtonigt": "svagtonig",
    "svagtonigts": "svagtonig",
    "svagts": "svag",
    "svaj": "svaja",
    "svajad": "svaja",
    "svajade": "svaja",
    "svajades": "svaja",
    "svajads": "svaja",
    "svajande": "svaja",
    "svajanden": "svajande",
    "svajandena": "svajande",
    "svajandenas": "svajande",
    "svajandens": "svajande",
    "svajandes": "svajande",
    "svajandet": "svajande",
    "svajandets": "svajande",
    "svajar": "svaja",
    "svajas": "svaja",
    "svajat": "svaja",
    "svajats": "svaja",
    "svajet": "svaj",
    "svajets": "svaj",
    "svajiga": "svajig",
    "svajigare": "svajig",
    "svajigares": "svajig",
    "svajigas": "svajig",
    "svajigast": "svajig",
    "svajigaste": "svajig",
    "svajigastes": "svajig",
    "svajigasts": "svajig",
    "svajige": "svajig",
    "svajiges": "svajig",
    "svajigs": "svajig",
    "svajigt": "svajig",
    "svajigts": "svajig",
    "svajmasten": "svajmast",
    "svajmastens": "svajmast",
    "svajmaster": "svajmast",
    "svajmasterna": "svajmast",
    "svajmasternas": "svajmast",
    "svajmasters": "svajmast",
    "svajmasts": "svajmast",
    "svajs": "svaj",
    "sval": "svale",
    "svala": "sval",
    "svalan": "svala",
    "svalans": "svala",
    "svalar": "svale",
    "svalare": "sval",
    "svalares": "sval",
    "svalarna": "svale",
    "svalarnas": "svale",
    "svalars": "svale",
    "svalas": "svala",
    "svalast": "sval",
    "svalaste": "sval",
    "svalastes": "sval",
    "svalasts": "sval",
    "svald": "svälja",
    "svalda": "svälja",
    "svaldas": "svälja",
    "svalde": "svälja",
    "svaldes": "svälja",
    "svalds": "svälja",
    "svale": "svala",
    "svalen": "svale",
    "svalens": "svale",
    "svales": "svale",
    "svalgen": "svalg",
    "svalgens": "svalg",
    "svalget": "svalg",
    "svalgets": "svalg",
    "svalgmandeln": "svalgmandel",
    "svalgmandelns": "svalgmandel",
    "svalgmandels": "svalgmandel",
    "svalgmandlar": "svalgmandel",
    "svalgmandlarna": "svalgmandel",
    "svalgmandlarnas": "svalgmandel",
    "svalgmandlars": "svalgmandel",
    "svalgs": "svalg",
    "svalgångar": "svalgång",
    "svalgångarna": "svalgång",
    "svalgångarnas": "svalgång",
    "svalgångars": "svalgång",
    "svalgången": "svalgång",
    "svalgångens": "svalgång",
    "svalgångs": "svalgång",
    "svalheten": "svalhet",
    "svalhetens": "svalhet",
    "svalhets": "svalhet",
    "svalk": "svalka",
    "svalkad": "svalka",
    "svalkade": "svalka",
    "svalkades": "svalka",
    "svalkads": "svalka",
    "svalkan": "svalka",
    "svalkande": "svalka",
    "svalkanden": "svalkande",
    "svalkandena": "svalkande",
    "svalkandenas": "svalkande",
    "svalkandens": "svalkande",
    "svalkandes": "svalkande",
    "svalkandet": "svalkande",
    "svalkandets": "svalkande",
    "svalkans": "svalka",
    "svalkar": "svalka",
    "svalkas": "svalka",
    "svalkat": "svalka",
    "svalkats": "svalka",
    "svall": "svalla",
    "svallad": "svalla",
    "svallade": "svalla",
    "svallades": "svalla",
    "svallads": "svalla",
    "svallande": "svalla",
    "svallanden": "svallande",
    "svallandena": "svallande",
    "svallandenas": "svallande",
    "svallandens": "svallande",
    "svallandes": "svallande",
    "svallandet": "svallande",
    "svallandets": "svallande",
    "svallar": "svalla",
    "svallas": "svalla",
    "svallat": "svalla",
    "svallats": "svalla",
    "svallen": "svall",
    "svallens": "svall",
    "svallet": "svall",
    "svallets": "svall",
    "svallisen": "svallis",
    "svallisens": "svallis",
    "svallningar": "svallning",
    "svallningarna": "svallning",
    "svallningarnas": "svallning",
    "svallningars": "svallning",
    "svallningen": "svallning",
    "svallningens": "svallning",
    "svallnings": "svallning",
    "svalls": "svall",
    "svallvågen": "svallvåg",
    "svallvågens": "svallvåg",
    "svallvågor": "svallvåg",
    "svallvågorna": "svallvåg",
    "svallvågornas": "svallvåg",
    "svallvågors": "svallvåg",
    "svallvågs": "svallvåg",
    "svalnad": "svalna",
    "svalnade": "svalna",
    "svalnades": "svalna",
    "svalnads": "svalna",
    "svalnande": "svalna",
    "svalnanden": "svalnande",
    "svalnandena": "svalnande",
    "svalnandenas": "svalnande",
    "svalnandens": "svalnande",
    "svalnandes": "svalnande",
    "svalnandet": "svalnande",
    "svalnandets": "svalnande",
    "svalnar": "svalna",
    "svalnas": "svalna",
    "svalnat": "svalna",
    "svalnats": "svalna",
    "svalor": "svala",
    "svalorna": "svala",
    "svalornas": "svala",
    "svalors": "svala",
    "svals": "svale",
    "svalstjärtar": "svalstjärt",
    "svalstjärtarna": "svalstjärt",
    "svalstjärtarnas": "svalstjärt",
    "svalstjärtars": "svalstjärt",
    "svalstjärten": "svalstjärt",
    "svalstjärtens": "svalstjärt",
    "svalstjärts": "svalstjärt",
    "svalt": "svälta",
    "svalts": "svälta",
    "svalörten": "svalört",
    "svalörtens": "svalört",
    "svalörts": "svalört",
    "svamlade": "svamla",
    "svamlades": "svamla",
    "svamlande": "svamla",
    "svamlanden": "svamlande",
    "svamlandena": "svamlande",
    "svamlandenas": "svamlande",
    "svamlandens": "svamlande",
    "svamlandes": "svamlande",
    "svamlandet": "svamlande",
    "svamlandets": "svamlande",
    "svamlar": "svamla",
    "svamlas": "svamla",
    "svamlat": "svamla",
    "svamlats": "svamla",
    "svamlet": "svammel",
    "svamlets": "svammel",
    "svamliga": "svamlig",
    "svamligare": "svamlig",
    "svamligares": "svamlig",
    "svamligas": "svamlig",
    "svamligast": "svamlig",
    "svamligaste": "svamlig",
    "svamligastes": "svamlig",
    "svamligasts": "svamlig",
    "svamlige": "svamlig",
    "svamliges": "svamlig",
    "svamligheten": "svamlighet",
    "svamlighetens": "svamlighet",
    "svamligheter": "svamlighet",
    "svamligheterna": "svamlighet",
    "svamligheternas": "svamlighet",
    "svamligheters": "svamlighet",
    "svamlighets": "svamlighet",
    "svamligs": "svamlig",
    "svamligt": "svamlig",
    "svamligts": "svamlig",
    "svammel": "svamla",
    "svammels": "svammel",
    "svampar": "svamp",
    "svamparna": "svamp",
    "svamparnas": "svamp",
    "svampars": "svamp",
    "svampdjuren": "svampdjur",
    "svampdjurens": "svampdjur",
    "svampdjuret": "svampdjur",
    "svampdjurets": "svampdjur",
    "svampdjurs": "svampdjur",
    "svampen": "svamp",
    "svampens": "svamp",
    "svampiga": "svampig",
    "svampigare": "svampig",
    "svampigares": "svampig",
    "svampigas": "svampig",
    "svampigast": "svampig",
    "svampigaste": "svampig",
    "svampigastes": "svampig",
    "svampigasts": "svampig",
    "svampige": "svampig",
    "svampiges": "svampig",
    "svampigheten": "svampighet",
    "svampighetens": "svampighet",
    "svampighets": "svampighet",
    "svampigs": "svampig",
    "svampigt": "svampig",
    "svampigts": "svampig",
    "svampmolnen": "svampmoln",
    "svampmolnens": "svampmoln",
    "svampmolnet": "svampmoln",
    "svampmolnets": "svampmoln",
    "svampmolns": "svampmoln",
    "svampparasiten": "svampparasit",
    "svampparasitens": "svampparasit",
    "svampparasiter": "svampparasit",
    "svampparasiterna": "svampparasit",
    "svampparasiternas": "svampparasit",
    "svampparasiters": "svampparasit",
    "svampparasits": "svampparasit",
    "svampplockar": "svampplockare",
    "svampplockaren": "svampplockare",
    "svampplockarens": "svampplockare",
    "svampplockares": "svampplockare",
    "svampplockarna": "svampplockare",
    "svampplockarnas": "svampplockare",
    "svamps": "svamp",
    "svampsjukdomar": "svampsjukdom",
    "svampsjukdomarna": "svampsjukdom",
    "svampsjukdomarnas": "svampsjukdom",
    "svampsjukdomars": "svampsjukdom",
    "svampsjukdomen": "svampsjukdom",
    "svampsjukdomens": "svampsjukdom",
    "svampsjukdoms": "svampsjukdom",
    "svampskogar": "svampskog",
    "svampskogarna": "svampskog",
    "svampskogarnas": "svampskog",
    "svampskogars": "svampskog",
    "svampskogen": "svampskog",
    "svampskogens": "svampskog",
    "svampskogs": "svampskog",
    "svampväxten": "svampväxt",
    "svampväxtens": "svampväxt",
    "svampväxter": "svampväxt",
    "svampväxterna": "svampväxt",
    "svampväxternas": "svampväxt",
    "svampväxters": "svampväxt",
    "svampväxts": "svampväxt",
    "svanar": "svan",
    "svanarna": "svan",
    "svanarnas": "svan",
    "svanars": "svan",
    "svanen": "svan",
    "svanens": "svan",
    "svanesången": "svanesång",
    "svanesångens": "svanesång",
    "svanesångs": "svanesång",
    "svanhalsar": "svanhals",
    "svanhalsarna": "svanhals",
    "svanhalsarnas": "svanhals",
    "svanhalsars": "svanhals",
    "svanhalsen": "svanhals",
    "svanhalsens": "svanhals",
    "svanhoppen": "svanhopp",
    "svanhoppens": "svanhopp",
    "svanhoppet": "svanhopp",
    "svanhoppets": "svanhopp",
    "svanhopps": "svanhopp",
    "svank": "svanka",
    "svankad": "svanka",
    "svankade": "svanka",
    "svankades": "svanka",
    "svankads": "svanka",
    "svankande": "svanka",
    "svankanden": "svankande",
    "svankandena": "svankande",
    "svankandenas": "svankande",
    "svankandens": "svankande",
    "svankandes": "svankande",
    "svankandet": "svankande",
    "svankandets": "svankande",
    "svankar": "svanka",
    "svankarna": "svank",
    "svankarnas": "svank",
    "svankars": "svank",
    "svankas": "svanka",
    "svankat": "svanka",
    "svankats": "svanka",
    "svanken": "svank",
    "svankens": "svank",
    "svanket": "svank",
    "svankets": "svank",
    "svankiga": "svankig",
    "svankigare": "svankig",
    "svankigares": "svankig",
    "svankigas": "svankig",
    "svankigast": "svankig",
    "svankigaste": "svankig",
    "svankigastes": "svankig",
    "svankigasts": "svankig",
    "svankige": "svankig",
    "svankiges": "svankig",
    "svankigheten": "svankighet",
    "svankighetens": "svankighet",
    "svankighets": "svankighet",
    "svankigs": "svankig",
    "svankigt": "svankig",
    "svankigts": "svankig",
    "svankryggar": "svankrygg",
    "svankryggarna": "svankrygg",
    "svankryggarnas": "svankrygg",
    "svankryggars": "svankrygg",
    "svankryggen": "svankrygg",
    "svankryggens": "svankrygg",
    "svankryggs": "svankrygg",
    "svanks": "svank",
    "svann": "svinna",
    "svanns": "svinna",
    "svanor": "svan",
    "svanorna": "svan",
    "svanornas": "svan",
    "svanors": "svan",
    "svans": "svansa",
    "svansad": "svansa",
    "svansade": "svansa",
    "svansades": "svansa",
    "svansads": "svansa",
    "svansande": "svansa",
    "svansanden": "svansande",
    "svansandena": "svansande",
    "svansandenas": "svansande",
    "svansandens": "svansande",
    "svansandes": "svansande",
    "svansandet": "svansande",
    "svansandets": "svansande",
    "svansar": "svansa",
    "svansarna": "svans",
    "svansarnas": "svans",
    "svansars": "svans",
    "svansas": "svansa",
    "svansat": "svansa",
    "svansats": "svansa",
    "svansen": "svans",
    "svansens": "svans",
    "svansföringar": "svansföring",
    "svansföringarna": "svansföring",
    "svansföringarnas": "svansföring",
    "svansföringars": "svansföring",
    "svansföringen": "svansföring",
    "svansföringens": "svansföring",
    "svansförings": "svansföring",
    "svanskot": "svanskota",
    "svanskotan": "svanskota",
    "svanskotans": "svanskota",
    "svanskotas": "svanskota",
    "svanskote": "svanskota",
    "svanskotor": "svanskota",
    "svanskotorna": "svanskota",
    "svanskotornas": "svanskota",
    "svanskotors": "svanskota",
    "svanskots": "svanskota",
    "svansmotorer": "svansmotor",
    "svansmotorerna": "svansmotor",
    "svansmotorernas": "svansmotor",
    "svansmotorers": "svansmotor",
    "svansmotorn": "svansmotor",
    "svansmotorns": "svansmotor",
    "svansmotors": "svansmotor",
    "svanstippar": "svanstipp",
    "svanstipparna": "svanstipp",
    "svanstipparnas": "svanstipp",
    "svanstippars": "svanstipp",
    "svanstippen": "svanstipp",
    "svanstippens": "svanstipp",
    "svanstipps": "svanstipp",
    "svansviftar": "svansviftare",
    "svansviftaren": "svansviftare",
    "svansviftarens": "svansviftare",
    "svansviftares": "svansviftare",
    "svansviftarna": "svansviftare",
    "svansviftarnas": "svansviftare",
    "svanödlan": "svanödla",
    "svanödlans": "svanödla",
    "svanödlas": "svanödla",
    "svanödle": "svanödla",
    "svanödlor": "svanödla",
    "svanödlorna": "svanödla",
    "svanödlornas": "svanödla",
    "svanödlors": "svanödla",
    "svar": "svara",
    "svarad": "svara",
    "svarade": "svara",
    "svarades": "svara",
    "svarads": "svara",
    "svarande": "svara",
    "svaranden": "svarande",
    "svarandena": "svarande",
    "svarandenas": "svarande",
    "svarandens": "svarande",
    "svarandes": "svarande",
    "svarandet": "svarande",
    "svarandets": "svarande",
    "svarar": "svara",
    "svaras": "svara",
    "svarat": "svara",
    "svarats": "svara",
    "svaren": "svar",
    "svarens": "svar",
    "svaret": "svar",
    "svarets": "svar",
    "svaro": "svara",
    "svaromålen": "svaromål",
    "svaromålens": "svaromål",
    "svaromålet": "svaromål",
    "svaromålets": "svaromål",
    "svaromåls": "svaromål",
    "svars": "svar",
    "svarskupongen": "svarskupong",
    "svarskupongens": "svarskupong",
    "svarskuponger": "svarskupong",
    "svarskupongerna": "svarskupong",
    "svarskupongernas": "svarskupong",
    "svarskupongers": "svarskupong",
    "svarskupongs": "svarskupong",
    "svarslösa": "svarslös",
    "svarslösare": "svarslös",
    "svarslösares": "svarslös",
    "svarslösas": "svarslös",
    "svarslösast": "svarslös",
    "svarslösaste": "svarslös",
    "svarslösastes": "svarslös",
    "svarslösasts": "svarslös",
    "svarslöse": "svarslös",
    "svarslöses": "svarslös",
    "svarslösheten": "svarslöshet",
    "svarslöshetens": "svarslöshet",
    "svarslöshets": "svarslöshet",
    "svarslöst": "svarslös",
    "svarslösts": "svarslös",
    "svarta": "svart",
    "svartabörshajar": "svartabörshaj",
    "svartabörshajarna": "svartabörshaj",
    "svartabörshajarnas": "svartabörshaj",
    "svartabörshajars": "svartabörshaj",
    "svartabörshajen": "svartabörshaj",
    "svartabörshajens": "svartabörshaj",
    "svartabörshajs": "svartabörshaj",
    "svartare": "svart",
    "svartares": "svart",
    "svartas": "svart",
    "svartast": "svart",
    "svartaste": "svart",
    "svartastes": "svart",
    "svartasts": "svart",
    "svartbrodern": "svartbroder",
    "svartbroderns": "svartbroder",
    "svartbroders": "svartbroder",
    "svartbröder": "svartbroder",
    "svartbröderna": "svartbroder",
    "svartbrödernas": "svartbroder",
    "svartbröders": "svartbroder",
    "svartbyggen": "svartbygge",
    "svartbyggena": "svartbygge",
    "svartbyggenas": "svartbygge",
    "svartbyggens": "svartbygge",
    "svartbygges": "svartbygge",
    "svartbygget": "svartbygge",
    "svartbyggets": "svartbygge",
    "svarte": "svart",
    "svartes": "svart",
    "svartfoten": "svartfot",
    "svartfotens": "svartfot",
    "svartfots": "svartfot",
    "svartfötter": "svartfot",
    "svartfötterna": "svartfot",
    "svartfötternas": "svartfot",
    "svartfötters": "svartfot",
    "svarthätt": "svarthätta",
    "svarthättan": "svarthätta",
    "svarthättans": "svarthätta",
    "svarthättas": "svarthätta",
    "svarthätte": "svarthätta",
    "svarthättor": "svarthätta",
    "svarthättorna": "svarthätta",
    "svarthättornas": "svarthätta",
    "svarthättors": "svarthätta",
    "svarthätts": "svarthätta",
    "svartingar": "svarting",
    "svartingarna": "svarting",
    "svartingarnas": "svarting",
    "svartingars": "svarting",
    "svartingen": "svarting",
    "svartingens": "svarting",
    "svartings": "svarting",
    "svartklädda": "svartklädd",
    "svartkläddare": "svartklädd",
    "svartkläddares": "svartklädd",
    "svartkläddas": "svartklädd",
    "svartkläddast": "svartklädd",
    "svartkläddaste": "svartklädd",
    "svartkläddastes": "svartklädd",
    "svartkläddasts": "svartklädd",
    "svartklädde": "svartklädd",
    "svartkläddes": "svartklädd",
    "svartklädds": "svartklädd",
    "svartklätt": "svartklädd",
    "svartklätts": "svartklädd",
    "svartkonsten": "svartkonst",
    "svartkonstens": "svartkonst",
    "svartkonster": "svartkonst",
    "svartkonsterna": "svartkonst",
    "svartkonsternas": "svartkonst",
    "svartkonsters": "svartkonst",
    "svartkonsts": "svartkonst",
    "svartkrutet": "svartkrut",
    "svartkrutets": "svartkrut",
    "svartkruts": "svartkrut",
    "svartlackerade": "svartlackerad",
    "svartlackerades": "svartlackerad",
    "svartlackerads": "svartlackerad",
    "svartlackerat": "svartlackerad",
    "svartlackerats": "svartlackerad",
    "svartlist": "svartlista",
    "svartlistad": "svartlista",
    "svartlistade": "svartlista",
    "svartlistades": "svartlista",
    "svartlistads": "svartlista",
    "svartlistande": "svartlista",
    "svartlistanden": "svartlistande",
    "svartlistandena": "svartlistande",
    "svartlistandenas": "svartlistande",
    "svartlistandens": "svartlistande",
    "svartlistandes": "svartlistande",
    "svartlistandet": "svartlistande",
    "svartlistandets": "svartlistande",
    "svartlistar": "svartlista",
    "svartlistas": "svartlista",
    "svartlistat": "svartlista",
    "svartlistats": "svartlista",
    "svartlistningar": "svartlistning",
    "svartlistningarna": "svartlistning",
    "svartlistningarnas": "svartlistning",
    "svartlistningars": "svartlistning",
    "svartlistningen": "svartlistning",
    "svartlistningens": "svartlistning",
    "svartlistnings": "svartlistning",
    "svartlistningsgränsen": "svartlistningsgräns",
    "svartlistningsgränsens": "svartlistningsgräns",
    "svartlistningsgränser": "svartlistningsgräns",
    "svartlistningsgränserna": "svartlistningsgräns",
    "svartlistningsgränsernas": "svartlistningsgräns",
    "svartlistningsgränsers": "svartlistningsgräns",
    "svartmalmen": "svartmalm",
    "svartmalmens": "svartmalm",
    "svartmalms": "svartmalm",
    "svartmuskiga": "svartmuskig",
    "svartmuskigare": "svartmuskig",
    "svartmuskigares": "svartmuskig",
    "svartmuskigas": "svartmuskig",
    "svartmuskigast": "svartmuskig",
    "svartmuskigaste": "svartmuskig",
    "svartmuskigastes": "svartmuskig",
    "svartmuskigasts": "svartmuskig",
    "svartmuskige": "svartmuskig",
    "svartmuskiges": "svartmuskig",
    "svartmuskigheten": "svartmuskighet",
    "svartmuskighetens": "svartmuskighet",
    "svartmuskighets": "svartmuskighet",
    "svartmuskigs": "svartmuskig",
    "svartmuskigt": "svartmuskig",
    "svartmuskigts": "svartmuskig",
    "svartmyr": "svartmyra",
    "svartmyran": "svartmyra",
    "svartmyrans": "svartmyra",
    "svartmyras": "svartmyra",
    "svartmyre": "svartmyra",
    "svartmyror": "svartmyra",
    "svartmyrorna": "svartmyra",
    "svartmyrornas": "svartmyra",
    "svartmyrors": "svartmyra",
    "svartmyrs": "svartmyra",
    "svartmål": "svartmåla",
    "svartmålad": "svartmåla",
    "svartmålade": "svartmålad",
    "svartmålades": "svartmålad",
    "svartmålads": "svartmålad",
    "svartmålande": "svartmåla",
    "svartmålanden": "svartmålande",
    "svartmålandena": "svartmålande",
    "svartmålandenas": "svartmålande",
    "svartmålandens": "svartmålande",
    "svartmålandes": "svartmålande",
    "svartmålandet": "svartmålande",
    "svartmålandets": "svartmålande",
    "svartmålar": "svartmåla",
    "svartmålas": "svartmåla",
    "svartmålat": "svartmålad",
    "svartmålats": "svartmålad",
    "svartnad": "svartna",
    "svartnade": "svartna",
    "svartnaden": "svartnad",
    "svartnadens": "svartnad",
    "svartnader": "svartnad",
    "svartnaderna": "svartnad",
    "svartnadernas": "svartnad",
    "svartnaders": "svartnad",
    "svartnades": "svartna",
    "svartnads": "svartnad",
    "svartnaglade": "svartnaglad",
    "svartnaglades": "svartnaglad",
    "svartnaglads": "svartnaglad",
    "svartnaglat": "svartnaglad",
    "svartnaglats": "svartnaglad",
    "svartnande": "svartna",
    "svartnanden": "svartnande",
    "svartnandena": "svartnande",
    "svartnandenas": "svartnande",
    "svartnandens": "svartnande",
    "svartnandes": "svartnande",
    "svartnandet": "svartnande",
    "svartnandets": "svartnande",
    "svartnar": "svartna",
    "svartnas": "svartna",
    "svartnat": "svartna",
    "svartnats": "svartna",
    "svartoxiderade": "svartoxiderad",
    "svartoxiderades": "svartoxiderad",
    "svartoxiderads": "svartoxiderad",
    "svartoxiderat": "svartoxiderad",
    "svartoxiderats": "svartoxiderad",
    "svartpepparn": "svartpeppar",
    "svartpepparns": "svartpeppar",
    "svartpeppars": "svartpeppar",
    "svartrockar": "svartrock",
    "svartrockarna": "svartrock",
    "svartrockarnas": "svartrock",
    "svartrockars": "svartrock",
    "svartrocken": "svartrock",
    "svartrockens": "svartrock",
    "svartrocks": "svartrock",
    "svartrosten": "svartrost",
    "svartrostens": "svartrost",
    "svartrosts": "svartrost",
    "svartroten": "svartrot",
    "svartrotens": "svartrot",
    "svartrots": "svartrot",
    "svarts": "svart",
    "svartsjuka": "svartsjuk",
    "svartsjukan": "svartsjuka",
    "svartsjukans": "svartsjuka",
    "svartsjukare": "svartsjuk",
    "svartsjukares": "svartsjuk",
    "svartsjukas": "svartsjuka",
    "svartsjukast": "svartsjuk",
    "svartsjukaste": "svartsjuk",
    "svartsjukastes": "svartsjuk",
    "svartsjukasts": "svartsjuk",
    "svartsjuke": "svartsjuka",
    "svartsjukebråken": "svartsjukebråk",
    "svartsjukebråkens": "svartsjukebråk",
    "svartsjukebråket": "svartsjukebråk",
    "svartsjukebråkets": "svartsjukebråk",
    "svartsjukebråks": "svartsjukebråk",
    "svartsjukedraman": "svartsjukedrama",
    "svartsjukedramana": "svartsjukedrama",
    "svartsjukedramanas": "svartsjukedrama",
    "svartsjukedramans": "svartsjukedrama",
    "svartsjukedramas": "svartsjukedrama",
    "svartsjukedramat": "svartsjukedrama",
    "svartsjukedramats": "svartsjukedrama",
    "svartsjukedramer": "svartsjukedrama",
    "svartsjukedramerna": "svartsjukedrama",
    "svartsjukedramernas": "svartsjukedrama",
    "svartsjukedramers": "svartsjukedrama",
    "svartsjukes": "svartsjuk",
    "svartsjukheten": "svartsjukhet",
    "svartsjukhetens": "svartsjukhet",
    "svartsjukhets": "svartsjukhet",
    "svartsjuks": "svartsjuka",
    "svartsjukt": "svartsjuk",
    "svartsjukts": "svartsjuk",
    "svartskall": "svartskalle",
    "svartskallar": "svartskalle",
    "svartskallarna": "svartskalle",
    "svartskallarnas": "svartskalle",
    "svartskallars": "svartskalle",
    "svartskallen": "svartskalle",
    "svartskallens": "svartskalle",
    "svartskalles": "svartskalle",
    "svartskalls": "svartskalle",
    "svartskjort": "svartskjorta",
    "svartskjortan": "svartskjorta",
    "svartskjortans": "svartskjorta",
    "svartskjortas": "svartskjorta",
    "svartskjorte": "svartskjorta",
    "svartskjortor": "svartskjorta",
    "svartskjortorna": "svartskjorta",
    "svartskjortornas": "svartskjorta",
    "svartskjortors": "svartskjorta",
    "svartskjorts": "svartskjorta",
    "svartsoppan": "svartsoppa",
    "svartsoppans": "svartsoppa",
    "svartsoppas": "svartsoppa",
    "svartspriten": "svartsprit",
    "svartspritens": "svartsprit",
    "svartsprits": "svartsprit",
    "svartsynen": "svartsyn",
    "svartsynens": "svartsyn",
    "svartsyns": "svartsyn",
    "svartvita": "svartvit",
    "svartvitare": "svartvit",
    "svartvitares": "svartvit",
    "svartvitas": "svartvit",
    "svartvitast": "svartvit",
    "svartvitaste": "svartvit",
    "svartvitastes": "svartvit",
    "svartvitasts": "svartvit",
    "svartvite": "svartvit",
    "svartvites": "svartvit",
    "svartvits": "svartvit",
    "svartvitt": "svartvit",
    "svartvitts": "svartvit",
    "svarv": "svarva",
    "svarvad": "svarva",
    "svarvade": "svarva",
    "svarvades": "svarva",
    "svarvads": "svarva",
    "svarvande": "svarva",
    "svarvanden": "svarvande",
    "svarvandena": "svarvande",
    "svarvandenas": "svarvande",
    "svarvandens": "svarvande",
    "svarvandes": "svarvande",
    "svarvandet": "svarvande",
    "svarvandets": "svarvande",
    "svarvar": "svarvare",
    "svarvaren": "svarvare",
    "svarvarens": "svarvare",
    "svarvares": "svarvare",
    "svarvarna": "svarvare",
    "svarvarnas": "svarvare",
    "svarvars": "svarv",
    "svarvas": "svarva",
    "svarvat": "svarva",
    "svarvats": "svarva",
    "svarven": "svarv",
    "svarvens": "svarv",
    "svarvs": "svarv",
    "svarvstolar": "svarvstol",
    "svarvstolarna": "svarvstol",
    "svarvstolarnas": "svarvstol",
    "svarvstolars": "svarvstol",
    "svarvstolen": "svarvstol",
    "svarvstolens": "svarvstol",
    "svarvstols": "svarvstol",
    "svarvstålen": "svarvstål",
    "svarvstålens": "svarvstål",
    "svarvstålet": "svarvstål",
    "svarvstålets": "svarvstål",
    "svarvståls": "svarvstål",
    "svass": "svassa",
    "svassad": "svassa",
    "svassade": "svassa",
    "svassades": "svassa",
    "svassads": "svassa",
    "svassande": "svassa",
    "svassanden": "svassande",
    "svassandena": "svassande",
    "svassandenas": "svassande",
    "svassandens": "svassande",
    "svassandes": "svassande",
    "svassandet": "svassande",
    "svassandets": "svassande",
    "svassar": "svassa",
    "svassas": "svassa",
    "svassat": "svassa",
    "svassats": "svassa",
    "svastik": "svastika",
    "svastikan": "svastika",
    "svastikans": "svastika",
    "svastikas": "svastika",
    "svastike": "svastika",
    "svastikor": "svastika",
    "svastikorna": "svastika",
    "svastikornas": "svastika",
    "svastikors": "svastika",
    "svastiks": "svastika",
    "svavel": "svavla",
    "svavelbakterien": "svavelbakterie",
    "svavelbakteriens": "svavelbakterie",
    "svavelbakterier": "svavelbakterie",
    "svavelbakterierna": "svavelbakterie",
    "svavelbakteriernas": "svavelbakterie",
    "svavelbakteriers": "svavelbakterie",
    "svavelbakteries": "svavelbakterie",
    "svavelbindningar": "svavelbindning",
    "svavelbindningarna": "svavelbindning",
    "svavelbindningarnas": "svavelbindning",
    "svavelbindningars": "svavelbindning",
    "svavelbindningen": "svavelbindning",
    "svavelbindningens": "svavelbindning",
    "svavelbindnings": "svavelbindning",
    "svavelblomman": "svavelblomma",
    "svavelblommans": "svavelblomma",
    "svavelblommas": "svavelblomma",
    "svavelblomme": "svavelblomma",
    "svaveldioxiden": "svaveldioxid",
    "svaveldioxidens": "svaveldioxid",
    "svaveldioxids": "svaveldioxid",
    "svavelföreningar": "svavelförening",
    "svavelföreningarna": "svavelförening",
    "svavelföreningarnas": "svavelförening",
    "svavelföreningars": "svavelförening",
    "svavelföreningen": "svavelförening",
    "svavelföreningens": "svavelförening",
    "svavelförenings": "svavelförening",
    "svavelhalten": "svavelhalt",
    "svavelhaltens": "svavelhalt",
    "svavelhalter": "svavelhalt",
    "svavelhalterna": "svavelhalt",
    "svavelhalternas": "svavelhalt",
    "svavelhalters": "svavelhalt",
    "svavelhalts": "svavelhalt",
    "svavelkisen": "svavelkis",
    "svavelkisens": "svavelkis",
    "svavelomsättningar": "svavelomsättning",
    "svavelomsättningarna": "svavelomsättning",
    "svavelomsättningarnas": "svavelomsättning",
    "svavelomsättningars": "svavelomsättning",
    "svavelomsättningen": "svavelomsättning",
    "svavelomsättningens": "svavelomsättning",
    "svavelomsättnings": "svavelomsättning",
    "svavelpredikanten": "svavelpredikant",
    "svavelpredikantens": "svavelpredikant",
    "svavelpredikanter": "svavelpredikant",
    "svavelpredikanterna": "svavelpredikant",
    "svavelpredikanternas": "svavelpredikant",
    "svavelpredikanters": "svavelpredikant",
    "svavelpredikants": "svavelpredikant",
    "svavelpulverna": "svavelpulver",
    "svavelpulvernas": "svavelpulver",
    "svavelpulvers": "svavelpulver",
    "svavelpulvren": "svavelpulver",
    "svavelpulvrens": "svavelpulver",
    "svavelpulvret": "svavelpulver",
    "svavelpulvrets": "svavelpulver",
    "svavelrökar": "svavelrök",
    "svavelrökarna": "svavelrök",
    "svavelrökarnas": "svavelrök",
    "svavelrökars": "svavelrök",
    "svavelröken": "svavelrök",
    "svavelrökens": "svavelrök",
    "svavelröks": "svavelrök",
    "svavels": "svavel",
    "svavelstick": "svavelsticka",
    "svavelstickan": "svavelsticka",
    "svavelstickans": "svavelsticka",
    "svavelstickas": "svavelsticka",
    "svavelsticke": "svavelsticka",
    "svavelstickor": "svavelsticka",
    "svavelstickorna": "svavelsticka",
    "svavelstickornas": "svavelsticka",
    "svavelstickors": "svavelsticka",
    "svavelsticks": "svavelsticka",
    "svavelsyran": "svavelsyra",
    "svavelsyrans": "svavelsyra",
    "svavelsyras": "svavelsyra",
    "svavelsyre": "svavelsyra",
    "svavelsyrligheten": "svavelsyrlighet",
    "svavelsyrlighetens": "svavelsyrlighet",
    "svavelsyrligheter": "svavelsyrlighet",
    "svavelsyrligheterna": "svavelsyrlighet",
    "svavelsyrligheternas": "svavelsyrlighet",
    "svavelsyrligheters": "svavelsyrlighet",
    "svavelsyrlighets": "svavelsyrlighet",
    "svavelvätes": "svavelväte",
    "svavelvätet": "svavelväte",
    "svavelvätets": "svavelväte",
    "svavlad": "svavla",
    "svavlade": "svavla",
    "svavlades": "svavla",
    "svavlads": "svavla",
    "svavlande": "svavla",
    "svavlanden": "svavlande",
    "svavlandena": "svavlande",
    "svavlandenas": "svavlande",
    "svavlandens": "svavlande",
    "svavlandes": "svavlande",
    "svavlandet": "svavlande",
    "svavlandets": "svavlande",
    "svavlar": "svavla",
    "svavlas": "svavla",
    "svavlat": "svavla",
    "svavlats": "svavla",
    "svavlet": "svavel",
    "svavlets": "svavel",
    "svea": "svear",
    "sveamålen": "sveamål",
    "sveamålens": "sveamål",
    "sveamålet": "sveamål",
    "sveamålets": "sveamål",
    "sveamåls": "sveamål",
    "svearna": "svear",
    "svearnas": "svear",
    "svears": "svear",
    "svecian": "svecia",
    "svecians": "svecia",
    "svecias": "svecia",
    "svecismen": "svecism",
    "svecismens": "svecism",
    "svecismer": "svecism",
    "svecismerna": "svecism",
    "svecismernas": "svecism",
    "svecismers": "svecism",
    "svecisms": "svecism",
    "sved": "svida",
    "svedan": "sveda",
    "svedande": "sveda",
    "svedanden": "svedande",
    "svedandena": "svedande",
    "svedandenas": "svedande",
    "svedandens": "svedande",
    "svedandes": "svedande",
    "svedandet": "svedande",
    "svedandets": "svedande",
    "svedans": "sveda",
    "svedas": "sveda",
    "svedd": "sveda",
    "svedda": "sveda",
    "sveddas": "sveda",
    "svedde": "sveda",
    "sveddes": "sveda",
    "svedds": "sveda",
    "sveden": "sved",
    "svedens": "sved",
    "sveder": "sveda",
    "svederna": "sved",
    "svedernas": "sved",
    "sveders": "sved",
    "svedes": "sveda",
    "svedj": "svedja",
    "svedjad": "svedja",
    "svedjade": "svedja",
    "svedjades": "svedja",
    "svedjads": "svedja",
    "svedjan": "svedja",
    "svedjande": "svedja",
    "svedjanden": "svedjande",
    "svedjandena": "svedjande",
    "svedjandenas": "svedjande",
    "svedjandens": "svedjande",
    "svedjandes": "svedjande",
    "svedjandet": "svedjande",
    "svedjandets": "svedjande",
    "svedjans": "svedja",
    "svedjar": "svedja",
    "svedjas": "svedja",
    "svedjat": "svedja",
    "svedjats": "svedja",
    "svedje": "svedja",
    "svedjebruket": "svedjebruk",
    "svedjebrukets": "svedjebruk",
    "svedjebruks": "svedjebruk",
    "svedjelanden": "svedjeland",
    "svedjelandens": "svedjeland",
    "svedjelandet": "svedjeland",
    "svedjelandets": "svedjeland",
    "svedjelands": "svedjeland",
    "svedjor": "svedja",
    "svedjorna": "svedja",
    "svedjornas": "svedja",
    "svedjors": "svedja",
    "sveds": "svida",
    "svek": "svika",
    "sveken": "svek",
    "svekens": "svek",
    "sveket": "svek",
    "svekets": "svek",
    "svekfulla": "svekfull",
    "svekfullare": "svekfull",
    "svekfullares": "svekfull",
    "svekfullas": "svekfull",
    "svekfullast": "svekfull",
    "svekfullaste": "svekfull",
    "svekfullastes": "svekfull",
    "svekfullasts": "svekfull",
    "svekfulle": "svekfull",
    "svekfulles": "svekfull",
    "svekfullheten": "svekfullhet",
    "svekfullhetens": "svekfullhet",
    "svekfullheter": "svekfullhet",
    "svekfullheterna": "svekfullhet",
    "svekfullheternas": "svekfullhet",
    "svekfullheters": "svekfullhet",
    "svekfullhets": "svekfullhet",
    "svekfulls": "svekfull",
    "svekfullt": "svekfull",
    "svekfullts": "svekfull",
    "svekliga": "sveklig",
    "svekligare": "sveklig",
    "svekligares": "sveklig",
    "svekligas": "sveklig",
    "svekligast": "sveklig",
    "svekligaste": "sveklig",
    "svekligastes": "sveklig",
    "svekligasts": "sveklig",
    "sveklige": "sveklig",
    "svekliges": "sveklig",
    "svekligheten": "sveklighet",
    "sveklighetens": "sveklighet",
    "sveklighets": "sveklighet",
    "svekligs": "sveklig",
    "svekligt": "sveklig",
    "svekligts": "sveklig",
    "sveklösa": "sveklös",
    "sveklösare": "sveklös",
    "sveklösares": "sveklös",
    "sveklösas": "sveklös",
    "sveklösast": "sveklös",
    "sveklösaste": "sveklös",
    "sveklösastes": "sveklös",
    "sveklösasts": "sveklös",
    "sveklöse": "sveklös",
    "sveklöses": "sveklös",
    "sveklösheten": "sveklöshet",
    "sveklöshetens": "sveklöshet",
    "sveklöshets": "sveklöshet",
    "sveklöst": "sveklös",
    "sveklösts": "sveklös",
    "svekomanen": "svekoman",
    "svekomanens": "svekoman",
    "svekomaner": "svekoman",
    "svekomanerna": "svekoman",
    "svekomanernas": "svekoman",
    "svekomaners": "svekoman",
    "svekomans": "svekoman",
    "sveks": "svika",
    "svendomar": "svendom",
    "svendomarna": "svendom",
    "svendomarnas": "svendom",
    "svendomars": "svendom",
    "svendomen": "svendom",
    "svendomens": "svendom",
    "svendoms": "svendom",
    "svengelsk": "svengelska",
    "svengelskan": "svengelska",
    "svengelskans": "svengelska",
    "svengelskas": "svengelska",
    "svennar": "svenne",
    "svennarna": "svenne",
    "svennarnas": "svenne",
    "svennars": "svenne",
    "svennelurar": "svennelur",
    "svennelurarna": "svennelur",
    "svennelurarnas": "svennelur",
    "svennelurars": "svennelur",
    "svenneluren": "svennelur",
    "svennelurens": "svennelur",
    "svennelurs": "svennelur",
    "svennen": "svenne",
    "svennens": "svenne",
    "svenner": "sven",
    "svennerna": "sven",
    "svennernas": "sven",
    "svenners": "sven",
    "svennes": "svenne",
    "svens": "sven",
    "svensex": "svensexa",
    "svensexan": "svensexa",
    "svensexans": "svensexa",
    "svensexas": "svensexa",
    "svensexe": "svensexa",
    "svensexor": "svensexa",
    "svensexorna": "svensexa",
    "svensexornas": "svensexa",
    "svensexors": "svensexa",
    "svensk": "svenska",
    "svensk-engelska": "svensk-engelsk",
    "svensk-engelskas": "svensk-engelsk",
    "svensk-engelske": "svensk-engelsk",
    "svensk-engelskes": "svensk-engelsk",
    "svensk-engelsks": "svensk-engelsk",
    "svensk-engelskt": "svensk-engelsk",
    "svensk-engelskts": "svensk-engelsk",
    "svensk-ryska": "svensk-rysk",
    "svensk-ryskare": "svensk-rysk",
    "svensk-ryskares": "svensk-rysk",
    "svensk-ryskas": "svensk-rysk",
    "svensk-ryskast": "svensk-rysk",
    "svensk-ryskaste": "svensk-rysk",
    "svensk-ryskastes": "svensk-rysk",
    "svensk-ryskasts": "svensk-rysk",
    "svensk-ryske": "svensk-rysk",
    "svensk-ryskes": "svensk-rysk",
    "svensk-rysks": "svensk-rysk",
    "svensk-ryskt": "svensk-rysk",
    "svensk-ryskts": "svensk-rysk",
    "svensk-tyska": "svensk-tysk",
    "svensk-tyskas": "svensk-tysk",
    "svensk-tyske": "svensk-tysk",
    "svensk-tyskes": "svensk-tysk",
    "svensk-tysks": "svensk-tysk",
    "svensk-tyskt": "svensk-tysk",
    "svensk-tyskts": "svensk-tysk",
    "svenska": "svensk",
    "svenskamerikanen": "svenskamerikan",
    "svenskamerikanens": "svenskamerikan",
    "svenskamerikaner": "svenskamerikan",
    "svenskamerikanerna": "svenskamerikan",
    "svenskamerikanernas": "svenskamerikan",
    "svenskamerikaners": "svenskamerikan",
    "svenskamerikans": "svenskamerikan",
    "svenskan": "svenska",
    "svenskans": "svenska",
    "svenskar": "svensk",
    "svenskare": "svensk",
    "svenskares": "svensk",
    "svenskarna": "svensk",
    "svenskarnas": "svensk",
    "svenskars": "svensk",
    "svenskas": "svenska",
    "svenskast": "svensk",
    "svenskaste": "svensk",
    "svenskastes": "svensk",
    "svenskasts": "svensk",
    "svenskbygden": "svenskbygd",
    "svenskbygdens": "svenskbygd",
    "svenskbygder": "svenskbygd",
    "svenskbygderna": "svenskbygd",
    "svenskbygdernas": "svenskbygd",
    "svenskbygders": "svenskbygd",
    "svenskbygds": "svenskbygd",
    "svenske": "svenska",
    "svensken": "svensk",
    "svenskens": "svensk",
    "svenskes": "svensk",
    "svenskfödda": "svenskfödd",
    "svenskföddare": "svenskfödd",
    "svenskföddares": "svenskfödd",
    "svenskföddas": "svenskfödd",
    "svenskföddast": "svenskfödd",
    "svenskföddaste": "svenskfödd",
    "svenskföddastes": "svenskfödd",
    "svenskföddasts": "svenskfödd",
    "svenskfödde": "svenskfödd",
    "svenskföddes": "svenskfödd",
    "svenskfödds": "svenskfödd",
    "svenskförnekar": "svenskförnekare",
    "svenskförnekaren": "svenskförnekare",
    "svenskförnekarens": "svenskförnekare",
    "svenskförnekares": "svenskförnekare",
    "svenskförnekarna": "svenskförnekare",
    "svenskförnekarnas": "svenskförnekare",
    "svenskfött": "svenskfödd",
    "svenskfötts": "svenskfödd",
    "svenskhatet": "svenskhat",
    "svenskhatets": "svenskhat",
    "svenskhats": "svenskhat",
    "svenskheten": "svenskhet",
    "svenskhetens": "svenskhet",
    "svenskheter": "svenskhet",
    "svenskheterna": "svenskhet",
    "svenskheternas": "svenskhet",
    "svenskheters": "svenskhet",
    "svenskhets": "svenskhet",
    "svenskhetsivrar": "svenskhetsivrare",
    "svenskhetsivraren": "svenskhetsivrare",
    "svenskhetsivrarens": "svenskhetsivrare",
    "svenskhetsivrares": "svenskhetsivrare",
    "svenskhetsivrarna": "svenskhetsivrare",
    "svenskhetsivrarnas": "svenskhetsivrare",
    "svenskkursen": "svenskkurs",
    "svenskkursens": "svenskkurs",
    "svenskkurser": "svenskkurs",
    "svenskkurserna": "svenskkurs",
    "svenskkursernas": "svenskkurs",
    "svenskkursers": "svenskkurs",
    "svensklektionen": "svensklektion",
    "svensklektionens": "svensklektion",
    "svensklektioner": "svensklektion",
    "svensklektionerna": "svensklektion",
    "svensklektionernas": "svensklektion",
    "svensklektioners": "svensklektion",
    "svensklektions": "svensklektion",
    "svensklärar": "svensklärare",
    "svenskläraren": "svensklärare",
    "svensklärarens": "svensklärare",
    "svensklärares": "svensklärare",
    "svensklärarna": "svensklärare",
    "svensklärarnas": "svensklärare",
    "svenskmannaandan": "svenskmannaanda",
    "svenskmannaandans": "svenskmannaanda",
    "svenskmannaandas": "svenskmannaanda",
    "svenskor": "svenska",
    "svenskorna": "svenska",
    "svenskornas": "svenska",
    "svenskors": "svenska",
    "svenskregistrerade": "svenskregistrerad",
    "svenskregistrerades": "svenskregistrerad",
    "svenskregistrerads": "svenskregistrerad",
    "svenskregistrerat": "svenskregistrerad",
    "svenskregistrerats": "svenskregistrerad",
    "svensks": "svensk",
    "svenskspråkiga": "svenskspråkig",
    "svenskspråkigas": "svenskspråkig",
    "svenskspråkige": "svenskspråkig",
    "svenskspråkiges": "svenskspråkig",
    "svenskspråkigheten": "svenskspråkighet",
    "svenskspråkighetens": "svenskspråkighet",
    "svenskspråkighets": "svenskspråkighet",
    "svenskspråkigs": "svenskspråkig",
    "svenskspråkigt": "svenskspråkig",
    "svenskspråkigts": "svenskspråkig",
    "svenskstödda": "svenskstödd",
    "svenskstöddare": "svenskstödd",
    "svenskstöddares": "svenskstödd",
    "svenskstöddas": "svenskstödd",
    "svenskstöddast": "svenskstödd",
    "svenskstöddaste": "svenskstödd",
    "svenskstöddastes": "svenskstödd",
    "svenskstöddasts": "svenskstödd",
    "svenskstödde": "svenskstödd",
    "svenskstöddes": "svenskstödd",
    "svenskstödds": "svenskstödd",
    "svenskstött": "svenskstödd",
    "svenskstötts": "svenskstödd",
    "svenskt": "svensk",
    "svensktillverkade": "svensktillverkad",
    "svensktillverkades": "svensktillverkad",
    "svensktillverkads": "svensktillverkad",
    "svensktillverkat": "svensktillverkad",
    "svensktillverkats": "svensktillverkad",
    "svensktoppsmusiken": "svensktoppsmusik",
    "svensktoppsmusikens": "svensktoppsmusik",
    "svensktoppsmusiks": "svensktoppsmusik",
    "svenskts": "svensk",
    "svenskullen": "svenskull",
    "svenskullens": "svenskull",
    "svenskulls": "svenskull",
    "svenskundervisningen": "svenskundervisning",
    "svenskundervisningens": "svenskundervisning",
    "svenskundervisnings": "svenskundervisning",
    "svenskägde": "svenskägd",
    "svenskägdes": "svenskägd",
    "svenskägds": "svenskägd",
    "svenskägt": "svenskägd",
    "svenskägts": "svenskägd",
    "svep": "svepa",
    "svepande": "svepa",
    "svepanden": "svepande",
    "svepandena": "svepande",
    "svepandenas": "svepande",
    "svepandens": "svepande",
    "svepandes": "svepande",
    "svepandet": "svepande",
    "svepandets": "svepande",
    "svepas": "svepa",
    "svepen": "svepe",
    "svepena": "svepe",
    "svepenas": "svepe",
    "svepens": "svepe",
    "sveper": "svepa",
    "svepes": "svepe",
    "svepet": "svepe",
    "svepets": "svepe",
    "svephammar": "svephammare",
    "svephammaren": "svephammare",
    "svephammarens": "svephammare",
    "svephammares": "svephammare",
    "svephamrar": "svephammare",
    "svephamrarna": "svephammare",
    "svephamrarnas": "svephammare",
    "svephamrars": "svephammare",
    "svepningar": "svepning",
    "svepningarna": "svepning",
    "svepningarnas": "svepning",
    "svepningars": "svepning",
    "svepningen": "svepning",
    "svepningens": "svepning",
    "svepnings": "svepning",
    "sveps": "svepe",
    "svepskälen": "svepskäl",
    "svepskälens": "svepskäl",
    "svepskälet": "svepskäl",
    "svepskälets": "svepskäl",
    "svepskäls": "svepskäl",
    "svept": "svepa",
    "svepta": "svepa",
    "sveptas": "svepa",
    "svepte": "svepa",
    "sveptes": "svepa",
    "svepts": "svepa",
    "sverigefinn": "sverigefinne",
    "sverigefinnar": "sverigefinne",
    "sverigefinnarna": "sverigefinne",
    "sverigefinnarnas": "sverigefinne",
    "sverigefinnars": "sverigefinne",
    "sverigefinnen": "sverigefinne",
    "sverigefinnens": "sverigefinne",
    "sverigefinnes": "sverigefinne",
    "sverigefinns": "sverigefinne",
    "svets": "svetsa",
    "svetsad": "svetsa",
    "svetsade": "svetsa",
    "svetsades": "svetsa",
    "svetsads": "svetsa",
    "svetsande": "svetsa",
    "svetsanden": "svetsande",
    "svetsandena": "svetsande",
    "svetsandenas": "svetsande",
    "svetsandens": "svetsande",
    "svetsandes": "svetsande",
    "svetsandet": "svetsande",
    "svetsandets": "svetsande",
    "svetsar": "svetsare",
    "svetsaren": "svetsare",
    "svetsarens": "svetsare",
    "svetsares": "svetsare",
    "svetsarna": "svetsare",
    "svetsarnas": "svetsare",
    "svetsars": "svets",
    "svetsas": "svetsa",
    "svetsat": "svetsa",
    "svetsats": "svetsa",
    "svetselektroden": "svetselektrod",
    "svetselektrodens": "svetselektrod",
    "svetselektroder": "svetselektrod",
    "svetselektroderna": "svetselektrod",
    "svetselektrodernas": "svetselektrod",
    "svetselektroders": "svetselektrod",
    "svetselektrods": "svetselektrod",
    "svetsen": "svets",
    "svetsens": "svets",
    "svetslopp": "svetsloppa",
    "svetsloppan": "svetsloppa",
    "svetsloppans": "svetsloppa",
    "svetsloppas": "svetsloppa",
    "svetsloppe": "svetsloppa",
    "svetsloppor": "svetsloppa",
    "svetslopporna": "svetsloppa",
    "svetsloppornas": "svetsloppa",
    "svetsloppors": "svetsloppa",
    "svetslopps": "svetsloppa",
    "svetsningar": "svetsning",
    "svetsningarna": "svetsning",
    "svetsningarnas": "svetsning",
    "svetsningars": "svetsning",
    "svetsningen": "svetsning",
    "svetsningens": "svetsning",
    "svetsnings": "svetsning",
    "svetsslangar": "svetsslang",
    "svetsslangarna": "svetsslang",
    "svetsslangarnas": "svetsslang",
    "svetsslangars": "svetsslang",
    "svetsslangen": "svetsslang",
    "svetsslangens": "svetsslang",
    "svetsslangs": "svetsslang",
    "svetsstänger": "svetsstång",
    "svetsstängerna": "svetsstång",
    "svetsstängernas": "svetsstång",
    "svetsstängers": "svetsstång",
    "svetsstången": "svetsstång",
    "svetsstångens": "svetsstång",
    "svetsstångs": "svetsstång",
    "svetstrådar": "svetstråd",
    "svetstrådarna": "svetstråd",
    "svetstrådarnas": "svetstråd",
    "svetstrådars": "svetstråd",
    "svetstråden": "svetstråd",
    "svetstrådens": "svetstråd",
    "svetstråds": "svetstråd",
    "svett": "svetta",
    "svetta": "svett",
    "svettad": "svetta",
    "svettade": "svetta",
    "svettades": "svettas",
    "svettads": "svetta",
    "svettande": "svetta",
    "svettanden": "svettande",
    "svettandena": "svettande",
    "svettandenas": "svettande",
    "svettandens": "svettande",
    "svettandes": "svettande",
    "svettandet": "svettande",
    "svettandets": "svettande",
    "svettar": "svetta",
    "svettare": "svett",
    "svettares": "svett",
    "svettas": "svetta",
    "svettast": "svett",
    "svettaste": "svett",
    "svettastes": "svett",
    "svettasts": "svett",
    "svettat": "svetta",
    "svettats": "svettas",
    "svettbanden": "svettband",
    "svettbandens": "svettband",
    "svettbandet": "svettband",
    "svettbandets": "svettband",
    "svettbands": "svettband",
    "svette": "svett",
    "svetten": "svett",
    "svettens": "svett",
    "svettes": "svett",
    "svettfläckar": "svettfläck",
    "svettfläckarna": "svettfläck",
    "svettfläckarnas": "svettfläck",
    "svettfläckars": "svettfläck",
    "svettfläcken": "svettfläck",
    "svettfläckens": "svettfläck",
    "svettfläcks": "svettfläck",
    "svettheten": "svetthet",
    "svetthetens": "svetthet",
    "svetthets": "svetthet",
    "svettiga": "svettig",
    "svettigare": "svettig",
    "svettigares": "svettig",
    "svettigas": "svettig",
    "svettigast": "svettig",
    "svettigaste": "svettig",
    "svettigastes": "svettig",
    "svettigasts": "svettig",
    "svettige": "svettig",
    "svettiges": "svettig",
    "svettigheten": "svettighet",
    "svettighetens": "svettighet",
    "svettighets": "svettighet",
    "svettigs": "svettig",
    "svettigt": "svettig",
    "svettigts": "svettig",
    "svettkörteln": "svettkörtel",
    "svettkörtelns": "svettkörtel",
    "svettkörtels": "svettkörtel",
    "svettkörtlar": "svettkörtel",
    "svettkörtlarna": "svettkörtel",
    "svettkörtlarnas": "svettkörtel",
    "svettkörtlars": "svettkörtel",
    "svettningar": "svettning",
    "svettningarna": "svettning",
    "svettningarnas": "svettning",
    "svettningars": "svettning",
    "svettningen": "svettning",
    "svettningens": "svettning",
    "svettnings": "svettning",
    "svettremmar": "svettrem",
    "svettremmarna": "svettrem",
    "svettremmarnas": "svettrem",
    "svettremmars": "svettrem",
    "svettremmen": "svettrem",
    "svettremmens": "svettrem",
    "svettrems": "svettrem",
    "svetts": "svett",
    "svibeln": "svibel",
    "svibelns": "svibel",
    "svibels": "svibel",
    "sviblar": "svibel",
    "sviblarna": "svibel",
    "sviblarnas": "svibel",
    "sviblars": "svibel",
    "svick": "svicka",
    "svickan": "svicka",
    "svickans": "svicka",
    "svickas": "svicka",
    "svicke": "svicka",
    "svickor": "svicka",
    "svickorna": "svicka",
    "svickornas": "svicka",
    "svickors": "svicka",
    "svicks": "svicka",
    "svid": "svida",
    "svidande": "svida",
    "svidanden": "svidande",
    "svidandena": "svidande",
    "svidandenas": "svidande",
    "svidandens": "svidande",
    "svidandes": "svidande",
    "svidandet": "svidande",
    "svidandets": "svidande",
    "svidar": "svid",
    "svidarna": "svid",
    "svidarnas": "svid",
    "svidars": "svid",
    "svidas": "svida",
    "svide": "svida",
    "sviden": "svid",
    "svidens": "svid",
    "svider": "svida",
    "svides": "svida",
    "svidit": "svida",
    "svidits": "svida",
    "svidknotten": "svidknott",
    "svidknottens": "svidknott",
    "svidknottet": "svidknott",
    "svidknottets": "svidknott",
    "svidknotts": "svidknott",
    "svids": "svida",
    "svik": "svika",
    "svikande": "svika",
    "svikanden": "svikande",
    "svikandena": "svikande",
    "svikandenas": "svikande",
    "svikandens": "svikande",
    "svikandes": "svikande",
    "svikandet": "svikande",
    "svikandets": "svikande",
    "svikar": "svikare",
    "svikaren": "svikare",
    "svikarens": "svikare",
    "svikares": "svikare",
    "svikarna": "svikare",
    "svikarnas": "svikare",
    "svikas": "svika",
    "svike": "svika",
    "sviken": "svika",
    "svikens": "svika",
    "sviker": "svika",
    "svikes": "svika",
    "sviket": "svika",
    "svikets": "svika",
    "svikit": "svika",
    "svikits": "svika",
    "svikliga": "sviklig",
    "svikligare": "sviklig",
    "svikligares": "sviklig",
    "svikligas": "sviklig",
    "svikligast": "sviklig",
    "svikligaste": "sviklig",
    "svikligastes": "sviklig",
    "svikligasts": "sviklig",
    "sviklige": "sviklig",
    "svikliges": "sviklig",
    "svikligheten": "sviklighet",
    "sviklighetens": "sviklighet",
    "sviklighets": "sviklighet",
    "svikligs": "sviklig",
    "svikligt": "sviklig",
    "svikligts": "sviklig",
    "svikna": "svika",
    "sviknas": "svika",
    "svikne": "svika",
    "sviknes": "svika",
    "sviks": "svika",
    "svikt": "svikta",
    "sviktad": "svikta",
    "sviktade": "svikta",
    "sviktades": "svikta",
    "sviktads": "svikta",
    "sviktande": "svikta",
    "sviktanden": "sviktande",
    "sviktandena": "sviktande",
    "sviktandenas": "sviktande",
    "sviktandens": "sviktande",
    "sviktandes": "sviktande",
    "sviktandet": "sviktande",
    "sviktandets": "sviktande",
    "sviktar": "svikta",
    "sviktarna": "svikt",
    "sviktarnas": "svikt",
    "sviktars": "svikt",
    "sviktas": "svikta",
    "sviktat": "svikta",
    "sviktats": "svikta",
    "svikten": "svikt",
    "sviktens": "svikt",
    "svikts": "svikt",
    "svimfärdiga": "svimfärdig",
    "svimfärdigare": "svimfärdig",
    "svimfärdigares": "svimfärdig",
    "svimfärdigas": "svimfärdig",
    "svimfärdigast": "svimfärdig",
    "svimfärdigaste": "svimfärdig",
    "svimfärdigastes": "svimfärdig",
    "svimfärdigasts": "svimfärdig",
    "svimfärdige": "svimfärdig",
    "svimfärdiges": "svimfärdig",
    "svimfärdigheten": "svimfärdighet",
    "svimfärdighetens": "svimfärdighet",
    "svimfärdighets": "svimfärdighet",
    "svimfärdigs": "svimfärdig",
    "svimfärdigt": "svimfärdig",
    "svimfärdigts": "svimfärdig",
    "svimmade": "svimma",
    "svimmades": "svimma",
    "svimmande": "svimma",
    "svimmanden": "svimmande",
    "svimmandena": "svimmande",
    "svimmandenas": "svimmande",
    "svimmandens": "svimmande",
    "svimmandes": "svimmande",
    "svimmandet": "svimmande",
    "svimmandets": "svimmande",
    "svimmar": "svimma",
    "svimmas": "svimma",
    "svimmat": "svimma",
    "svimmats": "svimma",
    "svimningar": "svimning",
    "svimningarna": "svimning",
    "svimningarnas": "svimning",
    "svimningars": "svimning",
    "svimningen": "svimning",
    "svimningens": "svimning",
    "svimnings": "svimning",
    "svinaktiga": "svinaktig",
    "svinaktigare": "svinaktig",
    "svinaktigares": "svinaktig",
    "svinaktigas": "svinaktig",
    "svinaktigast": "svinaktig",
    "svinaktigaste": "svinaktig",
    "svinaktigastes": "svinaktig",
    "svinaktigasts": "svinaktig",
    "svinaktige": "svinaktig",
    "svinaktiges": "svinaktig",
    "svinaktigheten": "svinaktighet",
    "svinaktighetens": "svinaktighet",
    "svinaktigheter": "svinaktighet",
    "svinaktigheterna": "svinaktighet",
    "svinaktigheternas": "svinaktighet",
    "svinaktigheters": "svinaktighet",
    "svinaktighets": "svinaktighet",
    "svinaktigs": "svinaktig",
    "svinaktigt": "svinaktig",
    "svinaktigts": "svinaktig",
    "svinbesättningar": "svinbesättning",
    "svinbesättningarna": "svinbesättning",
    "svinbesättningarnas": "svinbesättning",
    "svinbesättningars": "svinbesättning",
    "svinbesättningen": "svinbesättning",
    "svinbesättningens": "svinbesättning",
    "svinbesättnings": "svinbesättning",
    "svindel": "svindla",
    "svindeln": "svindel",
    "svindelns": "svindel",
    "svindels": "svindel",
    "svindlad": "svindla",
    "svindlade": "svindla",
    "svindlades": "svindla",
    "svindlads": "svindla",
    "svindlande": "svindla",
    "svindlanden": "svindlande",
    "svindlandena": "svindlande",
    "svindlandenas": "svindlande",
    "svindlandens": "svindlande",
    "svindlandes": "svindlande",
    "svindlandet": "svindlande",
    "svindlandets": "svindlande",
    "svindlar": "svindlare",
    "svindlaren": "svindlare",
    "svindlarens": "svindlare",
    "svindlares": "svindlare",
    "svindlarna": "svindlare",
    "svindlarnas": "svindlare",
    "svindlas": "svindla",
    "svindlat": "svindla",
    "svindlats": "svindla",
    "svindlerier": "svindleri",
    "svindlerierna": "svindleri",
    "svindleriernas": "svindleri",
    "svindleriers": "svindleri",
    "svindleriet": "svindleri",
    "svindleriets": "svindleri",
    "svindlerihärvan": "svindlerihärva",
    "svindlerihärvans": "svindlerihärva",
    "svindlerihärvas": "svindlerihärva",
    "svindlerihärve": "svindlerihärva",
    "svindlerihärvor": "svindlerihärva",
    "svindlerihärvorna": "svindlerihärva",
    "svindlerihärvornas": "svindlerihärva",
    "svindlerihärvors": "svindlerihärva",
    "svindleris": "svindleri",
    "svindlerit": "svindleri",
    "svindlerits": "svindleri",
    "svindleriåtalen": "svindleriåtal",
    "svindleriåtalens": "svindleriåtal",
    "svindleriåtalet": "svindleriåtal",
    "svindleriåtalets": "svindleriåtal",
    "svindleriåtals": "svindleriåtal",
    "svindyra": "svindyr",
    "svindyrare": "svindyr",
    "svindyrares": "svindyr",
    "svindyras": "svindyr",
    "svindyrast": "svindyr",
    "svindyraste": "svindyr",
    "svindyrastes": "svindyr",
    "svindyrasts": "svindyr",
    "svindyre": "svindyr",
    "svindyres": "svindyr",
    "svindyrheten": "svindyrhet",
    "svindyrhetens": "svindyrhet",
    "svindyrhets": "svindyrhet",
    "svindyrs": "svindyr",
    "svindyrt": "svindyr",
    "svindyrts": "svindyr",
    "svinen": "svin",
    "svinens": "svin",
    "svinerier": "svineri",
    "svinerierna": "svineri",
    "svineriernas": "svineri",
    "svineriers": "svineri",
    "svineriet": "svineri",
    "svineriets": "svineri",
    "svineris": "svineri",
    "svinerit": "svineri",
    "svinerits": "svineri",
    "svinet": "svin",
    "svinets": "svin",
    "svinfetter": "svinfett",
    "svinfetterna": "svinfett",
    "svinfetternas": "svinfett",
    "svinfetters": "svinfett",
    "svinfettet": "svinfett",
    "svinfettets": "svinfett",
    "svinfetts": "svinfett",
    "sving": "svinga",
    "svingad": "svinga",
    "svingade": "svinga",
    "svingades": "svinga",
    "svingads": "svinga",
    "svingande": "svinga",
    "svinganden": "svingande",
    "svingandena": "svingande",
    "svingandenas": "svingande",
    "svingandens": "svingande",
    "svingandes": "svingande",
    "svingandet": "svingande",
    "svingandets": "svingande",
    "svingar": "svinga",
    "svingarna": "sving",
    "svingarnas": "sving",
    "svingars": "sving",
    "svingas": "svinga",
    "svingat": "svinga",
    "svingats": "svinga",
    "svingeln": "svingel",
    "svingelns": "svingel",
    "svingels": "svingel",
    "svingen": "sving",
    "svingens": "sving",
    "svinget": "sving",
    "svingets": "sving",
    "svings": "sving",
    "svininfluensan": "svininfluensa",
    "svininfluensans": "svininfluensa",
    "svininfluensas": "svininfluensa",
    "svininfluensor": "svininfluensa",
    "svininfluensorna": "svininfluensa",
    "svininfluensornas": "svininfluensa",
    "svininfluensors": "svininfluensa",
    "svinkalla": "svinkall",
    "svinkallare": "svinkall",
    "svinkallares": "svinkall",
    "svinkallas": "svinkall",
    "svinkallast": "svinkall",
    "svinkallaste": "svinkall",
    "svinkallastes": "svinkall",
    "svinkallasts": "svinkall",
    "svinkalle": "svinkall",
    "svinkalles": "svinkall",
    "svinkallheten": "svinkallhet",
    "svinkallhetens": "svinkallhet",
    "svinkallhets": "svinkallhet",
    "svinkalls": "svinkall",
    "svinkallt": "svinkall",
    "svinkallts": "svinkall",
    "svinkötten": "svinkött",
    "svinköttens": "svinkött",
    "svinköttet": "svinkött",
    "svinköttets": "svinkött",
    "svinkötts": "svinkött",
    "svinläders": "svinläder",
    "svinlädret": "svinläder",
    "svinlädrets": "svinläder",
    "svinmåll": "svinmålla",
    "svinmållan": "svinmålla",
    "svinmållans": "svinmålla",
    "svinmållas": "svinmålla",
    "svinmålle": "svinmålla",
    "svinmållor": "svinmålla",
    "svinmållorna": "svinmålla",
    "svinmållornas": "svinmålla",
    "svinmållors": "svinmålla",
    "svinmålls": "svinmålla",
    "svinn": "svinna",
    "svinnande": "svinna",
    "svinnanden": "svinnande",
    "svinnandena": "svinnande",
    "svinnandenas": "svinnande",
    "svinnandens": "svinnande",
    "svinnandes": "svinnande",
    "svinnandet": "svinnande",
    "svinnandets": "svinnande",
    "svinnas": "svinna",
    "svinne": "svinna",
    "svinnen": "svinn",
    "svinnens": "svinn",
    "svinner": "svinna",
    "svinnes": "svinna",
    "svinnet": "svinn",
    "svinnets": "svinn",
    "svinns": "svinna",
    "svinottan": "svinotta",
    "svinottans": "svinotta",
    "svinottas": "svinotta",
    "svinpälsar": "svinpäls",
    "svinpälsarna": "svinpäls",
    "svinpälsarnas": "svinpäls",
    "svinpälsars": "svinpäls",
    "svinpälsen": "svinpäls",
    "svinpälsens": "svinpäls",
    "svinryggar": "svinrygg",
    "svinryggarna": "svinrygg",
    "svinryggarnas": "svinrygg",
    "svinryggars": "svinrygg",
    "svinryggen": "svinrygg",
    "svinryggens": "svinrygg",
    "svinryggs": "svinrygg",
    "svins": "svin",
    "svinskötseln": "svinskötsel",
    "svinskötselns": "svinskötsel",
    "svinskötsels": "svinskötsel",
    "svinstallar": "svinstall",
    "svinstallarna": "svinstall",
    "svinstallarnas": "svinstall",
    "svinstallars": "svinstall",
    "svinstallen": "svinstall",
    "svinstallens": "svinstall",
    "svinstallet": "svinstall",
    "svinstallets": "svinstall",
    "svinstalls": "svinstall",
    "svinturen": "svintur",
    "svinturens": "svintur",
    "svinturs": "svintur",
    "svinuppfödningar": "svinuppfödning",
    "svinuppfödningarna": "svinuppfödning",
    "svinuppfödningarnas": "svinuppfödning",
    "svinuppfödningars": "svinuppfödning",
    "svinuppfödningen": "svinuppfödning",
    "svinuppfödningens": "svinuppfödning",
    "svinuppfödnings": "svinuppfödning",
    "svir": "svira",
    "svirade": "svira",
    "svirades": "svira",
    "svirande": "svira",
    "sviranden": "svirande",
    "svirandena": "svirande",
    "svirandenas": "svirande",
    "svirandens": "svirande",
    "svirandes": "svirande",
    "svirandet": "svirande",
    "svirandets": "svirande",
    "svirar": "svira",
    "sviras": "svira",
    "svirat": "svira",
    "svirats": "svira",
    "sviret": "svir",
    "svirets": "svir",
    "svirr": "svirra",
    "svirrade": "svirra",
    "svirrades": "svirra",
    "svirrande": "svirra",
    "svirranden": "svirrande",
    "svirrandena": "svirrande",
    "svirrandenas": "svirrande",
    "svirrandens": "svirrande",
    "svirrandes": "svirrande",
    "svirrandet": "svirrande",
    "svirrandets": "svirrande",
    "svirrar": "svirra",
    "svirras": "svirra",
    "svirrat": "svirra",
    "svirrats": "svirra",
    "svirs": "svir",
    "svirveln": "svirvel",
    "svirvelns": "svirvel",
    "svirvels": "svirvel",
    "svirvlar": "svirvel",
    "svirvlarna": "svirvel",
    "svirvlarnas": "svirvel",
    "svirvlars": "svirvel",
    "svisch": "svischa",
    "svischad": "svischa",
    "svischade": "svischa",
    "svischades": "svischa",
    "svischads": "svischa",
    "svischande": "svischa",
    "svischanden": "svischande",
    "svischandena": "svischande",
    "svischandenas": "svischande",
    "svischandens": "svischande",
    "svischandes": "svischande",
    "svischandet": "svischande",
    "svischandets": "svischande",
    "svischar": "svischa",
    "svischas": "svischa",
    "svischat": "svischa",
    "svischats": "svischa",
    "svischet": "svisch",
    "svischets": "svisch",
    "svischs": "svisch",
    "sviskonen": "sviskon",
    "sviskonens": "sviskon",
    "sviskonet": "sviskon",
    "sviskonets": "sviskon",
    "sviskons": "sviskon",
    "sviten": "svit",
    "svitens": "svit",
    "sviter": "svit",
    "sviterna": "sviter",
    "sviternas": "sviter",
    "sviters": "sviter",
    "svits": "svit",
    "sviveln": "svivel",
    "svivelns": "svivel",
    "svivels": "svivel",
    "svivlar": "svivel",
    "svivlarna": "svivel",
    "svivlarnas": "svivel",
    "svivlars": "svivel",
    "svor": "svära",
    "svordomar": "svordom",
    "svordomarna": "svordom",
    "svordomarnas": "svordom",
    "svordomars": "svordom",
    "svordomen": "svordom",
    "svordomens": "svordom",
    "svordoms": "svordom",
    "svors": "svära",
    "svullens": "svullen",
    "svullet": "svullen",
    "svullets": "svullen",
    "svulln": "svullna",
    "svullna": "svullen",
    "svullnad": "svullna",
    "svullnade": "svullna",
    "svullnaden": "svullnad",
    "svullnadens": "svullnad",
    "svullnader": "svullnad",
    "svullnaderna": "svullnad",
    "svullnadernas": "svullnad",
    "svullnaders": "svullnad",
    "svullnades": "svullna",
    "svullnads": "svullnad",
    "svullnande": "svullna",
    "svullnanden": "svullnande",
    "svullnandena": "svullnande",
    "svullnandenas": "svullnande",
    "svullnandens": "svullnande",
    "svullnandes": "svullnande",
    "svullnandet": "svullnande",
    "svullnandets": "svullnande",
    "svullnar": "svullna",
    "svullnare": "svullen",
    "svullnares": "svullen",
    "svullnas": "svullna",
    "svullnast": "svullen",
    "svullnaste": "svullen",
    "svullnastes": "svullen",
    "svullnasts": "svullen",
    "svullnat": "svullna",
    "svullnats": "svullna",
    "svullne": "svullen",
    "svullnes": "svullen",
    "svulsten": "svulst",
    "svulstens": "svulst",
    "svulster": "svulst",
    "svulsterna": "svulst",
    "svulsternas": "svulst",
    "svulsters": "svulst",
    "svulstiga": "svulstig",
    "svulstigare": "svulstig",
    "svulstigares": "svulstig",
    "svulstigas": "svulstig",
    "svulstigast": "svulstig",
    "svulstigaste": "svulstig",
    "svulstigastes": "svulstig",
    "svulstigasts": "svulstig",
    "svulstige": "svulstig",
    "svulstiges": "svulstig",
    "svulstigheten": "svulstighet",
    "svulstighetens": "svulstighet",
    "svulstigheter": "svulstighet",
    "svulstigheterna": "svulstighet",
    "svulstigheternas": "svulstighet",
    "svulstigheters": "svulstighet",
    "svulstighets": "svulstighet",
    "svulstigs": "svulstig",
    "svulstigt": "svulstig",
    "svulstigts": "svulstig",
    "svulsts": "svulst",
    "svulte": "svälta",
    "svultens": "svulten",
    "svultes": "svälta",
    "svultet": "svulten",
    "svultets": "svulten",
    "svultit": "svälta",
    "svultits": "svälta",
    "svultna": "svulten",
    "svultnare": "svulten",
    "svultnares": "svulten",
    "svultnas": "svulten",
    "svultnast": "svulten",
    "svultnaste": "svulten",
    "svultnastes": "svulten",
    "svultnasts": "svulten",
    "svultne": "svulten",
    "svultnes": "svulten",
    "svunna": "svinna",
    "svunnas": "svinna",
    "svunne": "svinna",
    "svunnen": "svinna",
    "svunnens": "svinna",
    "svunnes": "svinna",
    "svunnet": "svinna",
    "svunnets": "svinna",
    "svunnit": "svinna",
    "svunnits": "svinna",
    "svure": "svära",
    "svuren": "svära",
    "svurens": "svuren",
    "svures": "svära",
    "svuret": "svuren",
    "svurets": "svuren",
    "svurit": "svära",
    "svurits": "svära",
    "svurna": "svuren",
    "svurnare": "svuren",
    "svurnares": "svuren",
    "svurnas": "svuren",
    "svurnast": "svuren",
    "svurnaste": "svuren",
    "svurnastes": "svuren",
    "svurnasts": "svuren",
    "svurne": "svuren",
    "svurnes": "svuren",
    "svägerskan": "svägerska",
    "svägerskans": "svägerska",
    "svägerskas": "svägerska",
    "svägerske": "svägerska",
    "svägerskor": "svägerska",
    "svägerskorna": "svägerska",
    "svägerskornas": "svägerska",
    "svägerskors": "svägerska",
    "svälj": "svälja",
    "sväljande": "svälja",
    "sväljanden": "sväljande",
    "sväljandena": "sväljande",
    "sväljandenas": "sväljande",
    "sväljandens": "sväljande",
    "sväljandes": "sväljande",
    "sväljandet": "sväljande",
    "sväljandets": "sväljande",
    "sväljas": "svälja",
    "sväljer": "svälja",
    "sväljes": "svälja",
    "sväljs": "svälja",
    "sväll": "svälla",
    "svällande": "svälla",
    "svällanden": "svällande",
    "svällandena": "svällande",
    "svällandenas": "svällande",
    "svällandens": "svällande",
    "svällandes": "svällande",
    "svällandet": "svällande",
    "svällandets": "svällande",
    "svällas": "svälla",
    "svälld": "svälla",
    "svällda": "svälla",
    "svälldas": "svälla",
    "svällde": "svälla",
    "svälldes": "svälla",
    "svällds": "svälla",
    "sväller": "svälla",
    "svälles": "svälla",
    "svälls": "svälla",
    "svällt": "svälla",
    "svällts": "svälla",
    "svält": "svälta",
    "svältande": "svälta",
    "svältanden": "svältande",
    "svältandena": "svältande",
    "svältandenas": "svältande",
    "svältandens": "svältande",
    "svältandes": "svältande",
    "svältandet": "svältande",
    "svältandets": "svältande",
    "svältas": "svälta",
    "svältdrabbade": "svältdrabbad",
    "svältdrabbades": "svältdrabbad",
    "svältdrabbads": "svältdrabbad",
    "svältdrabbat": "svältdrabbad",
    "svältdrabbats": "svältdrabbad",
    "svältdödar": "svältdöd",
    "svältdödarna": "svältdöd",
    "svältdödarnas": "svältdöd",
    "svältdödars": "svältdöd",
    "svältdöden": "svältdöd",
    "svältdödens": "svältdöd",
    "svältdöds": "svältdöd",
    "svälte": "svälta",
    "svälten": "svält",
    "svältens": "svält",
    "svälter": "svälta",
    "svältes": "svälta",
    "svältfödda": "svältfödd",
    "svältföddare": "svältfödd",
    "svältföddares": "svältfödd",
    "svältföddas": "svältfödd",
    "svältföddast": "svältfödd",
    "svältföddaste": "svältfödd",
    "svältföddastes": "svältfödd",
    "svältföddasts": "svältfödd",
    "svältfödde": "svältfödd",
    "svältföddes": "svältfödd",
    "svältföddheten": "svältföddhet",
    "svältföddhetens": "svältföddhet",
    "svältföddhets": "svältföddhet",
    "svältfödds": "svältfödd",
    "svältfött": "svältfödd",
    "svältfötts": "svältfödd",
    "svältgränsen": "svältgräns",
    "svältgränsens": "svältgräns",
    "svältkatastrofen": "svältkatastrof",
    "svältkatastrofens": "svältkatastrof",
    "svältkatastrofer": "svältkatastrof",
    "svältkatastroferna": "svältkatastrof",
    "svältkatastrofernas": "svältkatastrof",
    "svältkatastrofers": "svältkatastrof",
    "svältkatastrofs": "svältkatastrof",
    "svältkonstnären": "svältkonstnär",
    "svältkonstnärens": "svältkonstnär",
    "svältkonstnärer": "svältkonstnär",
    "svältkonstnärerna": "svältkonstnär",
    "svältkonstnärernas": "svältkonstnär",
    "svältkonstnärers": "svältkonstnär",
    "svältkonstnärs": "svältkonstnär",
    "svältlönen": "svältlön",
    "svältlönens": "svältlön",
    "svältlöner": "svältlön",
    "svältlönerna": "svältlön",
    "svältlönernas": "svältlön",
    "svältlöners": "svältlön",
    "svältlöns": "svältlön",
    "svältmässiga": "svältmässig",
    "svältmässigare": "svältmässig",
    "svältmässigares": "svältmässig",
    "svältmässigas": "svältmässig",
    "svältmässigast": "svältmässig",
    "svältmässigaste": "svältmässig",
    "svältmässigastes": "svältmässig",
    "svältmässigasts": "svältmässig",
    "svältmässige": "svältmässig",
    "svältmässiges": "svältmässig",
    "svältmässigs": "svältmässig",
    "svältmässigt": "svältmässig",
    "svältmässigts": "svältmässig",
    "svälts": "svälta",
    "sväng": "svänga",
    "svängande": "svänga",
    "svänganden": "svängande",
    "svängandena": "svängande",
    "svängandenas": "svängande",
    "svängandens": "svängande",
    "svängandes": "svängande",
    "svängandet": "svängande",
    "svängandets": "svängande",
    "svängar": "sväng",
    "svängarmar": "svängarm",
    "svängarmarna": "svängarm",
    "svängarmarnas": "svängarm",
    "svängarmars": "svängarm",
    "svängarmen": "svängarm",
    "svängarmens": "svängarm",
    "svängarms": "svängarm",
    "svängarna": "sväng",
    "svängarnas": "sväng",
    "svängars": "sväng",
    "svängas": "svänga",
    "svängbara": "svängbar",
    "svängbarare": "svängbar",
    "svängbarares": "svängbar",
    "svängbaras": "svängbar",
    "svängbarast": "svängbar",
    "svängbaraste": "svängbar",
    "svängbarastes": "svängbar",
    "svängbarasts": "svängbar",
    "svängbare": "svängbar",
    "svängbares": "svängbar",
    "svängbarheten": "svängbarhet",
    "svängbarhetens": "svängbarhet",
    "svängbarhets": "svängbarhet",
    "svängbars": "svängbar",
    "svängbart": "svängbar",
    "svängbarts": "svängbar",
    "svängbroar": "svängbro",
    "svängbroarna": "svängbro",
    "svängbroarnas": "svängbro",
    "svängbroars": "svängbro",
    "svängbron": "svängbro",
    "svängbrons": "svängbro",
    "svängbros": "svängbro",
    "svängd": "svänga",
    "svängda": "svängd",
    "svängdare": "svängd",
    "svängdares": "svängd",
    "svängdas": "svängd",
    "svängdast": "svängd",
    "svängdaste": "svängd",
    "svängdastes": "svängd",
    "svängdasts": "svängd",
    "svängde": "svängd",
    "svängdes": "svängd",
    "svängdheten": "svängdhet",
    "svängdhetens": "svängdhet",
    "svängdhets": "svängdhet",
    "svängds": "svängd",
    "svängdörrar": "svängdörr",
    "svängdörrarna": "svängdörr",
    "svängdörrarnas": "svängdörr",
    "svängdörrars": "svängdörr",
    "svängdörren": "svängdörr",
    "svängdörrens": "svängdörr",
    "svängdörrs": "svängdörr",
    "svängeln": "svängel",
    "svängelns": "svängel",
    "svängels": "svängel",
    "svängen": "sväng",
    "svängens": "sväng",
    "svänger": "svänga",
    "svänges": "svänga",
    "svänghjulen": "svänghjul",
    "svänghjulens": "svänghjul",
    "svänghjulet": "svänghjul",
    "svänghjulets": "svänghjul",
    "svänghjuls": "svänghjul",
    "svänghjulsmagneten": "svänghjulsmagnet",
    "svänghjulsmagnetens": "svänghjulsmagnet",
    "svänghjulsmagneter": "svänghjulsmagnet",
    "svänghjulsmagneterna": "svänghjulsmagnet",
    "svänghjulsmagneternas": "svänghjulsmagnet",
    "svänghjulsmagneters": "svänghjulsmagnet",
    "svänghjulsmagnets": "svänghjulsmagnet",
    "svängiga": "svängig",
    "svängigare": "svängig",
    "svängigares": "svängig",
    "svängigas": "svängig",
    "svängigast": "svängig",
    "svängigaste": "svängig",
    "svängigastes": "svängig",
    "svängigasts": "svängig",
    "svängige": "svängig",
    "svängiges": "svängig",
    "svängigheten": "svängighet",
    "svängighetens": "svängighet",
    "svängighets": "svängighet",
    "svängigs": "svängig",
    "svängigt": "svängig",
    "svängigts": "svängig",
    "svänglar": "svängel",
    "svänglarna": "svängel",
    "svänglarnas": "svängel",
    "svänglars": "svängel",
    "svängningar": "svängning",
    "svängningarna": "svängning",
    "svängningarnas": "svängning",
    "svängningars": "svängning",
    "svängningen": "svängning",
    "svängningens": "svängning",
    "svängnings": "svängning",
    "svängningskretsar": "svängningskrets",
    "svängningskretsarna": "svängningskrets",
    "svängningskretsarnas": "svängningskrets",
    "svängningskretsars": "svängningskrets",
    "svängningskretsen": "svängningskrets",
    "svängningskretsens": "svängningskrets",
    "svängningsproblemen": "svängningsproblem",
    "svängningsproblemens": "svängningsproblem",
    "svängningsproblemet": "svängningsproblem",
    "svängningsproblemets": "svängningsproblem",
    "svängningsproblems": "svängningsproblem",
    "svängningstalen": "svängningstal",
    "svängningstalens": "svängningstal",
    "svängningstalet": "svängningstal",
    "svängningstalets": "svängningstal",
    "svängningstals": "svängningstal",
    "svängomar": "svängom",
    "svängomarna": "svängom",
    "svängomarnas": "svängom",
    "svängomars": "svängom",
    "svängomen": "svängom",
    "svängomens": "svängom",
    "svängoms": "svängom",
    "svängrummet": "svängrum",
    "svängrummets": "svängrum",
    "svängrums": "svängrum",
    "svängs": "svänga",
    "svängt": "svängd",
    "svängts": "svängd",
    "svär": "svära",
    "svärande": "svära",
    "sväranden": "svärande",
    "svärandena": "svärande",
    "svärandenas": "svärande",
    "svärandens": "svärande",
    "svärandes": "svärande",
    "svärandet": "svärande",
    "svärandets": "svärande",
    "sväras": "svära",
    "svärdbärar": "svärdbärare",
    "svärdbäraren": "svärdbärare",
    "svärdbärarens": "svärdbärare",
    "svärdbärares": "svärdbärare",
    "svärdbärarna": "svärdbärare",
    "svärdbärarnas": "svärdbärare",
    "svärden": "svärd",
    "svärdens": "svärd",
    "svärdet": "svärd",
    "svärdets": "svärd",
    "svärdfejar": "svärdfejare",
    "svärdfejaren": "svärdfejare",
    "svärdfejarens": "svärdfejare",
    "svärdfejares": "svärdfejare",
    "svärdfejarna": "svärdfejare",
    "svärdfejarnas": "svärdfejare",
    "svärdfiskar": "svärdfisk",
    "svärdfiskarna": "svärdfisk",
    "svärdfiskarnas": "svärdfisk",
    "svärdfiskars": "svärdfisk",
    "svärdfisken": "svärdfisk",
    "svärdfiskens": "svärdfisk",
    "svärdfisks": "svärdfisk",
    "svärdfäst": "svärdfäste",
    "svärdfästen": "svärdfäste",
    "svärdfästena": "svärdfäste",
    "svärdfästenas": "svärdfäste",
    "svärdfästens": "svärdfäste",
    "svärdfästes": "svärdfäste",
    "svärdfästet": "svärdfäste",
    "svärdfästets": "svärdfäste",
    "svärdlika": "svärdlik",
    "svärdlikare": "svärdlik",
    "svärdlikares": "svärdlik",
    "svärdlikas": "svärdlik",
    "svärdlikast": "svärdlik",
    "svärdlikaste": "svärdlik",
    "svärdlikastes": "svärdlik",
    "svärdlikasts": "svärdlik",
    "svärdlike": "svärdlik",
    "svärdlikes": "svärdlik",
    "svärdlikheten": "svärdlikhet",
    "svärdlikhetens": "svärdlikhet",
    "svärdlikhets": "svärdlikhet",
    "svärdliks": "svärdlik",
    "svärdlikt": "svärdlik",
    "svärdlikts": "svärdlik",
    "svärdlängden": "svärdlängd",
    "svärdlängdens": "svärdlängd",
    "svärdlängds": "svärdlängd",
    "svärdottern": "svärdotter",
    "svärdotterns": "svärdotter",
    "svärdotters": "svärdotter",
    "svärds": "svärd",
    "svärdsfejar": "svärdsfejare",
    "svärdsfejaren": "svärdsfejare",
    "svärdsfejarens": "svärdsfejare",
    "svärdsfejares": "svärdsfejare",
    "svärdsfejarna": "svärdsfejare",
    "svärdsfejarnas": "svärdsfejare",
    "svärdskling": "svärdsklinga",
    "svärdsklingan": "svärdsklinga",
    "svärdsklingans": "svärdsklinga",
    "svärdsklingas": "svärdsklinga",
    "svärdsklinge": "svärdsklinga",
    "svärdsklingor": "svärdsklinga",
    "svärdsklingorna": "svärdsklinga",
    "svärdsklingornas": "svärdsklinga",
    "svärdsklingors": "svärdsklinga",
    "svärdsklings": "svärdsklinga",
    "svärdskydden": "svärdskydd",
    "svärdskyddens": "svärdskydd",
    "svärdskyddet": "svärdskydd",
    "svärdskyddets": "svärdskydd",
    "svärdskydds": "svärdskydd",
    "svärdsliljan": "svärdslilja",
    "svärdsliljans": "svärdslilja",
    "svärdsliljas": "svärdslilja",
    "svärdslilje": "svärdslilja",
    "svärdsliljor": "svärdslilja",
    "svärdsliljorna": "svärdslilja",
    "svärdsliljornas": "svärdslilja",
    "svärdsliljors": "svärdslilja",
    "svärdslukar": "svärdslukare",
    "svärdslukaren": "svärdslukare",
    "svärdslukarens": "svärdslukare",
    "svärdslukares": "svärdslukare",
    "svärdslukarna": "svärdslukare",
    "svärdslukarnas": "svärdslukare",
    "svärdslösa": "svärdslös",
    "svärdslösare": "svärdslös",
    "svärdslösares": "svärdslös",
    "svärdslösas": "svärdslös",
    "svärdslösast": "svärdslös",
    "svärdslösaste": "svärdslös",
    "svärdslösastes": "svärdslös",
    "svärdslösasts": "svärdslös",
    "svärdslöse": "svärdslös",
    "svärdslöses": "svärdslös",
    "svärdslösheten": "svärdslöshet",
    "svärdslöshetens": "svärdslöshet",
    "svärdslöshets": "svärdslöshet",
    "svärdslöst": "svärdslös",
    "svärdslösts": "svärdslös",
    "svärdssidans": "svärdssidan",
    "svärdsslukar": "svärdsslukare",
    "svärdsslukaren": "svärdsslukare",
    "svärdsslukarens": "svärdsslukare",
    "svärdsslukares": "svärdsslukare",
    "svärdsslukarna": "svärdsslukare",
    "svärdsslukarnas": "svärdsslukare",
    "svärdöttrar": "svärdotter",
    "svärdöttrarna": "svärdotter",
    "svärdöttrarnas": "svärdotter",
    "svärdöttrars": "svärdotter",
    "sväre": "svära",
    "sväres": "svära",
    "svärfader": "svärfar",
    "svärfadern": "svärfar",
    "svärfaderns": "svärfar",
    "svärfaders": "svärfar",
    "svärfars": "svärfar",
    "svärfasder": "svärfar",
    "svärfäder": "svärfar",
    "svärfäderna": "svärfar",
    "svärfädernas": "svärfar",
    "svärfäders": "svärfar",
    "svärföräldern": "svärförälder",
    "svärförälderns": "svärförälder",
    "svärförälders": "svärförälder",
    "svärföräldrar": "svärförälder",
    "svärföräldrarna": "svärförälder",
    "svärföräldrarnas": "svärförälder",
    "svärföräldrars": "svärförälder",
    "svärja": "svära",
    "svärjande": "svära",
    "svärjandes": "svära",
    "svärjas": "svära",
    "svärje": "svära",
    "svärjer": "svära",
    "svärjes": "svära",
    "svärm": "svärma",
    "svärmad": "svärma",
    "svärmade": "svärma",
    "svärmades": "svärma",
    "svärmads": "svärma",
    "svärmande": "svärma",
    "svärmanden": "svärmande",
    "svärmandena": "svärmande",
    "svärmandenas": "svärmande",
    "svärmandens": "svärmande",
    "svärmandes": "svärmande",
    "svärmandet": "svärmande",
    "svärmandets": "svärmande",
    "svärmar": "svärmare",
    "svärmaren": "svärmare",
    "svärmarens": "svärmare",
    "svärmares": "svärmare",
    "svärmarna": "svärmare",
    "svärmarnas": "svärmare",
    "svärmars": "svärm",
    "svärmas": "svärma",
    "svärmat": "svärma",
    "svärmats": "svärma",
    "svärmen": "svärm",
    "svärmens": "svärm",
    "svärmerier": "svärmeri",
    "svärmerierna": "svärmeri",
    "svärmeriernas": "svärmeri",
    "svärmeriers": "svärmeri",
    "svärmeriet": "svärmeri",
    "svärmeriets": "svärmeri",
    "svärmeris": "svärmeri",
    "svärmerit": "svärmeri",
    "svärmerits": "svärmeri",
    "svärmiska": "svärmisk",
    "svärmiskare": "svärmisk",
    "svärmiskares": "svärmisk",
    "svärmiskas": "svärmisk",
    "svärmiskast": "svärmisk",
    "svärmiskaste": "svärmisk",
    "svärmiskastes": "svärmisk",
    "svärmiskasts": "svärmisk",
    "svärmiske": "svärmisk",
    "svärmiskes": "svärmisk",
    "svärmisks": "svärmisk",
    "svärmiskt": "svärmisk",
    "svärmiskts": "svärmisk",
    "svärmoder": "svärmor",
    "svärmodern": "svärmor",
    "svärmoderns": "svärmor",
    "svärmoders": "svärmor",
    "svärmors": "svärmor",
    "svärmorsdrömmar": "svärmorsdröm",
    "svärmorsdrömmarna": "svärmorsdröm",
    "svärmorsdrömmarnas": "svärmorsdröm",
    "svärmorsdrömmars": "svärmorsdröm",
    "svärmorsdrömmen": "svärmorsdröm",
    "svärmorsdrömmens": "svärmorsdröm",
    "svärmorsdröms": "svärmorsdröm",
    "svärmorshistorian": "svärmorshistoria",
    "svärmorshistorians": "svärmorshistoria",
    "svärmorshistorias": "svärmorshistoria",
    "svärmorshistorien": "svärmorshistoria",
    "svärmorshistoriens": "svärmorshistoria",
    "svärmorshistorier": "svärmorshistoria",
    "svärmorshistorierna": "svärmorshistoria",
    "svärmorshistoriernas": "svärmorshistoria",
    "svärmorshistoriers": "svärmorshistoria",
    "svärmorsrabatten": "svärmorsrabatt",
    "svärmorsrabattens": "svärmorsrabatt",
    "svärmorsrabatter": "svärmorsrabatt",
    "svärmorsrabatterna": "svärmorsrabatt",
    "svärmorsrabatternas": "svärmorsrabatt",
    "svärmorsrabatters": "svärmorsrabatt",
    "svärmorsrabatts": "svärmorsrabatt",
    "svärms": "svärm",
    "svärmödrar": "svärmor",
    "svärmödrarna": "svärmor",
    "svärmödrarnas": "svärmor",
    "svärmödrars": "svärmor",
    "svärorden": "svärord",
    "svärordens": "svärord",
    "svärordet": "svärord",
    "svärordets": "svärord",
    "svärords": "svärord",
    "svärs": "svära",
    "svärsonen": "svärson",
    "svärsonens": "svärson",
    "svärsons": "svärson",
    "svärsöner": "svärson",
    "svärsönerna": "svärson",
    "svärsönernas": "svärson",
    "svärsöners": "svärson",
    "svärt": "svärta",
    "svärtad": "svärta",
    "svärtade": "svärta",
    "svärtades": "svärta",
    "svärtads": "svärta",
    "svärtan": "svärta",
    "svärtande": "svärta",
    "svärtanden": "svärtande",
    "svärtandena": "svärtande",
    "svärtandenas": "svärtande",
    "svärtandens": "svärtande",
    "svärtandes": "svärtande",
    "svärtandet": "svärtande",
    "svärtandets": "svärtande",
    "svärtans": "svärta",
    "svärtar": "svärta",
    "svärtas": "svärta",
    "svärtat": "svärta",
    "svärtats": "svärta",
    "svärte": "svärta",
    "svärtor": "svärta",
    "svärtorna": "svärta",
    "svärtornas": "svärta",
    "svärtors": "svärta",
    "svärts": "svärta",
    "sväv": "sväva",
    "svävad": "sväva",
    "svävade": "sväva",
    "svävades": "sväva",
    "svävads": "sväva",
    "svävande": "sväva",
    "svävanden": "svävande",
    "svävandena": "svävande",
    "svävandenas": "svävande",
    "svävandens": "svävande",
    "svävandes": "svävande",
    "svävandet": "svävande",
    "svävandets": "svävande",
    "svävar": "svävare",
    "svävaren": "svävare",
    "svävarens": "svävare",
    "svävares": "svävare",
    "svävarklippar": "svävarklippare",
    "svävarklipparen": "svävarklippare",
    "svävarklipparens": "svävarklippare",
    "svävarklippares": "svävarklippare",
    "svävarklipparna": "svävarklippare",
    "svävarklipparnas": "svävarklippare",
    "svävarna": "svävare",
    "svävarnas": "svävare",
    "svävas": "sväva",
    "svävat": "sväva",
    "svävats": "sväva",
    "svävfarkosten": "svävfarkost",
    "svävfarkostens": "svävfarkost",
    "svävfarkoster": "svävfarkost",
    "svävfarkosterna": "svävfarkost",
    "svävfarkosternas": "svävfarkost",
    "svävfarkosters": "svävfarkost",
    "svävfarkosts": "svävfarkost",
    "svävningar": "svävning",
    "svävningarna": "svävning",
    "svävningarnas": "svävning",
    "svävningars": "svävning",
    "svävningen": "svävning",
    "svävningens": "svävning",
    "svävnings": "svävning",
    "svågerlaget": "svågerlag",
    "svågerlagets": "svågerlag",
    "svågerlags": "svågerlag",
    "svågern": "svåger",
    "svågerns": "svåger",
    "svågerpolitiken": "svågerpolitik",
    "svågerpolitikens": "svågerpolitik",
    "svågerpolitiks": "svågerpolitik",
    "svågers": "svåger",
    "svågerskapet": "svågerskap",
    "svågerskapets": "svågerskap",
    "svågerskaps": "svågerskap",
    "svågrar": "svåger",
    "svågrarna": "svåger",
    "svågrarnas": "svåger",
    "svågrars": "svåger",
    "svålar": "svål",
    "svålarna": "svål",
    "svålarnas": "svål",
    "svålars": "svål",
    "svålen": "svål",
    "svålens": "svål",
    "svåls": "svål",
    "svångremmar": "svångrem",
    "svångremmarna": "svångrem",
    "svångremmarnas": "svångrem",
    "svångremmars": "svångrem",
    "svångremmen": "svångrem",
    "svångremmens": "svångrem",
    "svångrems": "svångrem",
    "svångremspolitiken": "svångremspolitik",
    "svångremspolitikens": "svångremspolitik",
    "svångremspolitiks": "svångremspolitik",
    "svåra": "svår",
    "svårare": "svår",
    "svårares": "svår",
    "svårartade": "svårartad",
    "svårartades": "svårartad",
    "svårartads": "svårartad",
    "svårartat": "svårartad",
    "svårartats": "svårartad",
    "svåras": "svår",
    "svårast": "svår",
    "svåraste": "svår",
    "svårastes": "svår",
    "svårasts": "svår",
    "svårbedömda": "svårbedömd",
    "svårbedömdare": "svårbedömd",
    "svårbedömdares": "svårbedömd",
    "svårbedömdas": "svårbedömd",
    "svårbedömdast": "svårbedömd",
    "svårbedömdaste": "svårbedömd",
    "svårbedömdastes": "svårbedömd",
    "svårbedömdasts": "svårbedömd",
    "svårbedömde": "svårbedömd",
    "svårbedömdes": "svårbedömd",
    "svårbedömdheten": "svårbedömdhet",
    "svårbedömdhetens": "svårbedömdhet",
    "svårbedömdhets": "svårbedömdhet",
    "svårbedömds": "svårbedömd",
    "svårbedömt": "svårbedömd",
    "svårbedömts": "svårbedömd",
    "svårbegripliga": "svårbegriplig",
    "svårbegripligare": "svårbegriplig",
    "svårbegripligares": "svårbegriplig",
    "svårbegripligas": "svårbegriplig",
    "svårbegripligast": "svårbegriplig",
    "svårbegripligaste": "svårbegriplig",
    "svårbegripligastes": "svårbegriplig",
    "svårbegripligasts": "svårbegriplig",
    "svårbegriplige": "svårbegriplig",
    "svårbegripliges": "svårbegriplig",
    "svårbegripligheten": "svårbegriplighet",
    "svårbegriplighetens": "svårbegriplighet",
    "svårbegripligheter": "svårbegriplighet",
    "svårbegripligheterna": "svårbegriplighet",
    "svårbegripligheternas": "svårbegriplighet",
    "svårbegripligheters": "svårbegriplighet",
    "svårbegriplighets": "svårbegriplighet",
    "svårbegripligs": "svårbegriplig",
    "svårbegripligt": "svårbegriplig",
    "svårbegripligts": "svårbegriplig",
    "svårbemästrade": "svårbemästrad",
    "svårbemästrades": "svårbemästrad",
    "svårbemästrads": "svårbemästrad",
    "svårbemästrat": "svårbemästrad",
    "svårbemästrats": "svårbemästrad",
    "svårdiagnosticerade": "svårdiagnosticerad",
    "svårdiagnosticerades": "svårdiagnosticerad",
    "svårdiagnosticerads": "svårdiagnosticerad",
    "svårdiagnosticerat": "svårdiagnosticerad",
    "svårdiagnosticerats": "svårdiagnosticerad",
    "svåre": "svår",
    "svåres": "svår",
    "svårfattliga": "svårfattlig",
    "svårfattligare": "svårfattlig",
    "svårfattligares": "svårfattlig",
    "svårfattligas": "svårfattlig",
    "svårfattligast": "svårfattlig",
    "svårfattligaste": "svårfattlig",
    "svårfattligastes": "svårfattlig",
    "svårfattligasts": "svårfattlig",
    "svårfattlige": "svårfattlig",
    "svårfattliges": "svårfattlig",
    "svårfattligheten": "svårfattlighet",
    "svårfattlighetens": "svårfattlighet",
    "svårfattligheter": "svårfattlighet",
    "svårfattligheterna": "svårfattlighet",
    "svårfattligheternas": "svårfattlighet",
    "svårfattligheters": "svårfattlighet",
    "svårfattlighets": "svårfattlighet",
    "svårfattligs": "svårfattlig",
    "svårfattligt": "svårfattlig",
    "svårfattligts": "svårfattlig",
    "svårflirtade": "svårflirtad",
    "svårflirtades": "svårflirtad",
    "svårflirtads": "svårflirtad",
    "svårflirtat": "svårflirtad",
    "svårflirtats": "svårflirtad",
    "svårflörtade": "svårflörtad",
    "svårflörtades": "svårflörtad",
    "svårflörtads": "svårflörtad",
    "svårflörtat": "svårflörtad",
    "svårflörtats": "svårflörtad",
    "svårformulerade": "svårformulerad",
    "svårformulerades": "svårformulerad",
    "svårformulerads": "svårformulerad",
    "svårformulerat": "svårformulerad",
    "svårformulerats": "svårformulerad",
    "svårframkomliga": "svårframkomlig",
    "svårframkomligare": "svårframkomlig",
    "svårframkomligares": "svårframkomlig",
    "svårframkomligas": "svårframkomlig",
    "svårframkomligast": "svårframkomlig",
    "svårframkomligaste": "svårframkomlig",
    "svårframkomligastes": "svårframkomlig",
    "svårframkomligasts": "svårframkomlig",
    "svårframkomlige": "svårframkomlig",
    "svårframkomliges": "svårframkomlig",
    "svårframkomligheten": "svårframkomlighet",
    "svårframkomlighetens": "svårframkomlighet",
    "svårframkomlighets": "svårframkomlighet",
    "svårframkomligs": "svårframkomlig",
    "svårframkomligt": "svårframkomlig",
    "svårframkomligts": "svårframkomlig",
    "svårfunna": "svårfunnen",
    "svårfunnare": "svårfunnen",
    "svårfunnares": "svårfunnen",
    "svårfunnas": "svårfunnen",
    "svårfunnast": "svårfunnen",
    "svårfunnaste": "svårfunnen",
    "svårfunnastes": "svårfunnen",
    "svårfunnasts": "svårfunnen",
    "svårfunne": "svårfunnen",
    "svårfunnens": "svårfunnen",
    "svårfunnes": "svårfunnen",
    "svårfunnet": "svårfunnen",
    "svårfunnets": "svårfunnen",
    "svårförklarliga": "svårförklarlig",
    "svårförklarligare": "svårförklarlig",
    "svårförklarligares": "svårförklarlig",
    "svårförklarligas": "svårförklarlig",
    "svårförklarligast": "svårförklarlig",
    "svårförklarligaste": "svårförklarlig",
    "svårförklarligastes": "svårförklarlig",
    "svårförklarligasts": "svårförklarlig",
    "svårförklarlige": "svårförklarlig",
    "svårförklarliges": "svårförklarlig",
    "svårförklarligheten": "svårförklarlighet",
    "svårförklarlighetens": "svårförklarlighet",
    "svårförklarligheter": "svårförklarlighet",
    "svårförklarligheterna": "svårförklarlighet",
    "svårförklarligheternas": "svårförklarlighet",
    "svårförklarligheters": "svårförklarlighet",
    "svårförklarlighets": "svårförklarlighet",
    "svårförklarligs": "svårförklarlig",
    "svårförklarligt": "svårförklarlig",
    "svårförklarligts": "svårförklarlig",
    "svårförståeliga": "svårförståelig",
    "svårförståeligare": "svårförståelig",
    "svårförståeligares": "svårförståelig",
    "svårförståeligas": "svårförståelig",
    "svårförståeligast": "svårförståelig",
    "svårförståeligaste": "svårförståelig",
    "svårförståeligastes": "svårförståelig",
    "svårförståeligasts": "svårförståelig",
    "svårförståelige": "svårförståelig",
    "svårförståeliges": "svårförståelig",
    "svårförståeligheten": "svårförståelighet",
    "svårförståelighetens": "svårförståelighet",
    "svårförståeligheter": "svårförståelighet",
    "svårförståeligheterna": "svårförståelighet",
    "svårförståeligheternas": "svårförståelighet",
    "svårförståeligheters": "svårförståelighet",
    "svårförståelighets": "svårförståelighet",
    "svårförståeligs": "svårförståelig",
    "svårförståeligt": "svårförståelig",
    "svårförståeligts": "svårförståelig",
    "svårförsvarade": "svårförsvarad",
    "svårförsvarades": "svårförsvarad",
    "svårförsvarads": "svårförsvarad",
    "svårförsvarat": "svårförsvarad",
    "svårförsvarats": "svårförsvarad",
    "svårheten": "svårhet",
    "svårhetens": "svårhet",
    "svårhets": "svårhet",
    "svårigheten": "svårighet",
    "svårighetens": "svårighet",
    "svårigheter": "svårighet",
    "svårigheterna": "svårighet",
    "svårigheternas": "svårighet",
    "svårigheters": "svårighet",
    "svårighets": "svårighet",
    "svårlästa": "svårläst",
    "svårlästare": "svårläst",
    "svårlästares": "svårläst",
    "svårlästas": "svårläst",
    "svårlästast": "svårläst",
    "svårlästaste": "svårläst",
    "svårlästastes": "svårläst",
    "svårlästasts": "svårläst",
    "svårläste": "svårläst",
    "svårlästes": "svårläst",
    "svårlästheten": "svårlästhet",
    "svårlästhetens": "svårlästhet",
    "svårlästhets": "svårlästhet",
    "svårlästs": "svårläst",
    "svårlösta": "svårlöst",
    "svårlöstare": "svårlöst",
    "svårlöstares": "svårlöst",
    "svårlöstas": "svårlöst",
    "svårlöstast": "svårlöst",
    "svårlöstaste": "svårlöst",
    "svårlöstastes": "svårlöst",
    "svårlöstasts": "svårlöst",
    "svårlöste": "svårlöst",
    "svårlöstes": "svårlöst",
    "svårlöstheten": "svårlösthet",
    "svårlösthetens": "svårlösthet",
    "svårlösthets": "svårlösthet",
    "svårlösts": "svårlöst",
    "svårmodet": "svårmod",
    "svårmodets": "svårmod",
    "svårmodiga": "svårmodig",
    "svårmodigare": "svårmodig",
    "svårmodigares": "svårmodig",
    "svårmodigas": "svårmodig",
    "svårmodigast": "svårmodig",
    "svårmodigaste": "svårmodig",
    "svårmodigastes": "svårmodig",
    "svårmodigasts": "svårmodig",
    "svårmodige": "svårmodig",
    "svårmodiges": "svårmodig",
    "svårmodigheten": "svårmodighet",
    "svårmodighetens": "svårmodighet",
    "svårmodighets": "svårmodighet",
    "svårmodigs": "svårmodig",
    "svårmodigt": "svårmodig",
    "svårmodigts": "svårmodig",
    "svårmods": "svårmod",
    "svårobserverade": "svårobserverad",
    "svårobserverades": "svårobserverad",
    "svårobserverads": "svårobserverad",
    "svårobserverat": "svårobserverad",
    "svårobserverats": "svårobserverad",
    "svårpratade": "svårpratad",
    "svårpratades": "svårpratad",
    "svårpratads": "svårpratad",
    "svårpratat": "svårpratad",
    "svårpratats": "svårpratad",
    "svårpåvisbara": "svårpåvisbar",
    "svårpåvisbarare": "svårpåvisbar",
    "svårpåvisbarares": "svårpåvisbar",
    "svårpåvisbaras": "svårpåvisbar",
    "svårpåvisbarast": "svårpåvisbar",
    "svårpåvisbaraste": "svårpåvisbar",
    "svårpåvisbarastes": "svårpåvisbar",
    "svårpåvisbarasts": "svårpåvisbar",
    "svårpåvisbare": "svårpåvisbar",
    "svårpåvisbares": "svårpåvisbar",
    "svårpåvisbarheten": "svårpåvisbarhet",
    "svårpåvisbarhetens": "svårpåvisbarhet",
    "svårpåvisbarhets": "svårpåvisbarhet",
    "svårpåvisbars": "svårpåvisbar",
    "svårpåvisbart": "svårpåvisbar",
    "svårpåvisbarts": "svårpåvisbar",
    "svårs": "svår",
    "svårsjungens": "svårsjungen",
    "svårsjunget": "svårsjungen",
    "svårsjungets": "svårsjungen",
    "svårsjungna": "svårsjungen",
    "svårsjungnare": "svårsjungen",
    "svårsjungnares": "svårsjungen",
    "svårsjungnas": "svårsjungen",
    "svårsjungnast": "svårsjungen",
    "svårsjungnaste": "svårsjungen",
    "svårsjungnastes": "svårsjungen",
    "svårsjungnasts": "svårsjungen",
    "svårsjungne": "svårsjungen",
    "svårsjungnes": "svårsjungen",
    "svårsmälta": "svårsmält",
    "svårsmältare": "svårsmält",
    "svårsmältares": "svårsmält",
    "svårsmältas": "svårsmält",
    "svårsmältast": "svårsmält",
    "svårsmältaste": "svårsmält",
    "svårsmältastes": "svårsmält",
    "svårsmältasts": "svårsmält",
    "svårsmälte": "svårsmält",
    "svårsmältes": "svårsmält",
    "svårsmältheten": "svårsmälthet",
    "svårsmälthetens": "svårsmälthet",
    "svårsmälthets": "svårsmälthet",
    "svårsmälts": "svårsmält",
    "svårstartade": "svårstartad",
    "svårstartades": "svårstartad",
    "svårstartads": "svårstartad",
    "svårstartat": "svårstartad",
    "svårstartats": "svårstartad",
    "svårsålda": "svårsåld",
    "svårsåldare": "svårsåld",
    "svårsåldares": "svårsåld",
    "svårsåldas": "svårsåld",
    "svårsåldast": "svårsåld",
    "svårsåldaste": "svårsåld",
    "svårsåldastes": "svårsåld",
    "svårsåldasts": "svårsåld",
    "svårsålde": "svårsåld",
    "svårsåldes": "svårsåld",
    "svårsåldheten": "svårsåldhet",
    "svårsåldhetens": "svårsåldhet",
    "svårsåldhets": "svårsåldhet",
    "svårsålds": "svårsåld",
    "svårsålt": "svårsåld",
    "svårsålts": "svårsåld",
    "svårt": "svår",
    "svårtillgängliga": "svårtillgänglig",
    "svårtillgängligare": "svårtillgänglig",
    "svårtillgängligares": "svårtillgänglig",
    "svårtillgängligas": "svårtillgänglig",
    "svårtillgängligast": "svårtillgänglig",
    "svårtillgängligaste": "svårtillgänglig",
    "svårtillgängligastes": "svårtillgänglig",
    "svårtillgängligasts": "svårtillgänglig",
    "svårtillgänglige": "svårtillgänglig",
    "svårtillgängliges": "svårtillgänglig",
    "svårtillgängligheten": "svårtillgänglighet",
    "svårtillgänglighetens": "svårtillgänglighet",
    "svårtillgänglighets": "svårtillgänglighet",
    "svårtillgängligs": "svårtillgänglig",
    "svårtillgängligt": "svårtillgänglig",
    "svårtillgängligts": "svårtillgänglig",
    "svårtolkade": "svårtolkad",
    "svårtolkades": "svårtolkad",
    "svårtolkads": "svårtolkad",
    "svårtolkat": "svårtolkad",
    "svårtolkats": "svårtolkad",
    "svårts": "svår",
    "svårupptäckta": "svårupptäckt",
    "svårupptäcktare": "svårupptäckt",
    "svårupptäcktares": "svårupptäckt",
    "svårupptäcktas": "svårupptäckt",
    "svårupptäcktast": "svårupptäckt",
    "svårupptäcktaste": "svårupptäckt",
    "svårupptäcktastes": "svårupptäckt",
    "svårupptäcktasts": "svårupptäckt",
    "svårupptäckte": "svårupptäckt",
    "svårupptäcktes": "svårupptäckt",
    "svårupptäckts": "svårupptäckt",
    "svårutrotade": "svårutrotad",
    "svårutrotades": "svårutrotad",
    "svårutrotads": "svårutrotad",
    "svårutrotat": "svårutrotad",
    "svårutrotats": "svårutrotad",
    "svåruttalade": "svåruttalad",
    "svåruttalades": "svåruttalad",
    "svåruttalads": "svåruttalad",
    "svåruttalat": "svåruttalad",
    "svåruttalats": "svåruttalad",
    "svåröverblickbara": "svåröverblickbar",
    "svåröverblickbarare": "svåröverblickbar",
    "svåröverblickbarares": "svåröverblickbar",
    "svåröverblickbaras": "svåröverblickbar",
    "svåröverblickbarast": "svåröverblickbar",
    "svåröverblickbaraste": "svåröverblickbar",
    "svåröverblickbarastes": "svåröverblickbar",
    "svåröverblickbarasts": "svåröverblickbar",
    "svåröverblickbare": "svåröverblickbar",
    "svåröverblickbares": "svåröverblickbar",
    "svåröverblickbarheten": "svåröverblickbarhet",
    "svåröverblickbarhetens": "svåröverblickbarhet",
    "svåröverblickbarhets": "svåröverblickbarhet",
    "svåröverblickbars": "svåröverblickbar",
    "svåröverblickbart": "svåröverblickbar",
    "svåröverblickbarts": "svåröverblickbar",
    "svåröverträffade": "svåröverträffad",
    "svåröverträffades": "svåröverträffad",
    "svåröverträffads": "svåröverträffad",
    "svåröverträffat": "svåröverträffad",
    "svåröverträffats": "svåröverträffad",
    "swahilis": "swahili",
    "swaziländar": "swaziländare",
    "swaziländaren": "swaziländare",
    "swaziländarens": "swaziländare",
    "swaziländares": "swaziländare",
    "swaziländarna": "swaziländare",
    "swaziländarnas": "swaziländare",
    "swaziländska": "swaziländsk",
    "swaziländskan": "swaziländska",
    "swaziländskans": "swaziländska",
    "swaziländskare": "swaziländsk",
    "swaziländskares": "swaziländsk",
    "swaziländskas": "swaziländska",
    "swaziländskast": "swaziländsk",
    "swaziländskaste": "swaziländsk",
    "swaziländskastes": "swaziländsk",
    "swaziländskasts": "swaziländsk",
    "swaziländske": "swaziländska",
    "swaziländskes": "swaziländsk",
    "swaziländskor": "swaziländska",
    "swaziländskorna": "swaziländska",
    "swaziländskornas": "swaziländska",
    "swaziländskors": "swaziländska",
    "swaziländsks": "swaziländsk",
    "swaziländskt": "swaziländsk",
    "swaziländskts": "swaziländsk",
    "sweatern": "sweater",
    "sweaterns": "sweater",
    "sweaters": "sweater",
    "sweatrar": "sweater",
    "sweatrarna": "sweater",
    "sweatrarnas": "sweater",
    "sweatrars": "sweater",
    "sweatshirten": "sweatshirt",
    "sweatshirtens": "sweatshirt",
    "sweatshirts": "sweatshirt",
    "sweatshirtsarna": "sweatshirt",
    "sweatshirtsarnas": "sweatshirt",
    "sweatshirtsen": "sweatshirt",
    "sweatshirtsens": "sweatshirt",
    "sweepstakes": "sweepstake",
    "swimmingpoolen": "swimmingpool",
    "swimmingpoolens": "swimmingpool",
    "swimmingpooler": "swimmingpool",
    "swimmingpoolerna": "swimmingpool",
    "swimmingpoolernas": "swimmingpool",
    "swimmingpoolers": "swimmingpool",
    "swimmingpools": "swimmingpool",
    "swing": "swinga",
    "swingade": "swinga",
    "swingades": "swinga",
    "swingande": "swinga",
    "swinganden": "swingande",
    "swingandena": "swingande",
    "swingandenas": "swingande",
    "swingandens": "swingande",
    "swingandes": "swingande",
    "swingandet": "swingande",
    "swingandets": "swingande",
    "swingar": "swinga",
    "swingarna": "swing",
    "swingarnas": "swing",
    "swingars": "swing",
    "swingas": "swinga",
    "swingat": "swinga",
    "swingats": "swinga",
    "swingballen": "swingball",
    "swingballens": "swingball",
    "swingballs": "swingball",
    "swingen": "swing",
    "swingens": "swing",
    "swingmusiken": "swingmusik",
    "swingmusikens": "swingmusik",
    "swingmusiks": "swingmusik",
    "swingpjattar": "swingpjatt",
    "swingpjattarna": "swingpjatt",
    "swingpjattarnas": "swingpjatt",
    "swingpjattars": "swingpjatt",
    "swingpjatten": "swingpjatt",
    "swingpjattens": "swingpjatt",
    "swingpjatts": "swingpjatt",
    "swings": "swing",
    "sybariten": "sybarit",
    "sybaritens": "sybarit",
    "sybariter": "sybarit",
    "sybariterna": "sybarit",
    "sybariternas": "sybarit",
    "sybariters": "sybarit",
    "sybaritiska": "sybaritisk",
    "sybaritiskare": "sybaritisk",
    "sybaritiskares": "sybaritisk",
    "sybaritiskas": "sybaritisk",
    "sybaritiskast": "sybaritisk",
    "sybaritiskaste": "sybaritisk",
    "sybaritiskastes": "sybaritisk",
    "sybaritiskasts": "sybaritisk",
    "sybaritiske": "sybaritisk",
    "sybaritiskes": "sybaritisk",
    "sybaritisks": "sybaritisk",
    "sybaritiskt": "sybaritisk",
    "sybaritiskts": "sybaritisk",
    "sybarits": "sybarit",
    "sybehören": "sybehör",
    "sybehörens": "sybehör",
    "sybehöret": "sybehör",
    "sybehörets": "sybehör",
    "sybehörs": "sybehör",
    "sybåg": "sybåge",
    "sybågar": "sybåge",
    "sybågarna": "sybåge",
    "sybågarnas": "sybåge",
    "sybågars": "sybåge",
    "sybågen": "sybåge",
    "sybågens": "sybåge",
    "sybåges": "sybåge",
    "sybågs": "sybåge",
    "sydafrikanen": "sydafrikan",
    "sydafrikanens": "sydafrikan",
    "sydafrikaner": "sydafrikan",
    "sydafrikanerna": "sydafrikan",
    "sydafrikanernas": "sydafrikan",
    "sydafrikaners": "sydafrikan",
    "sydafrikans": "sydafrikan",
    "sydafrikanska": "sydafrikansk",
    "sydafrikanskan": "sydafrikanska",
    "sydafrikanskans": "sydafrikanska",
    "sydafrikanskare": "sydafrikansk",
    "sydafrikanskares": "sydafrikansk",
    "sydafrikanskas": "sydafrikanska",
    "sydafrikanskast": "sydafrikansk",
    "sydafrikanskaste": "sydafrikansk",
    "sydafrikanskastes": "sydafrikansk",
    "sydafrikanskasts": "sydafrikansk",
    "sydafrikanske": "sydafrikanska",
    "sydafrikanskes": "sydafrikansk",
    "sydafrikanskor": "sydafrikanska",
    "sydafrikanskorna": "sydafrikanska",
    "sydafrikanskornas": "sydafrikanska",
    "sydafrikanskors": "sydafrikanska",
    "sydafrikansks": "sydafrikansk",
    "sydafrikanskt": "sydafrikansk",
    "sydafrikanskts": "sydafrikansk",
    "sydamerikanska": "sydamerikansk",
    "sydamerikanskare": "sydamerikansk",
    "sydamerikanskares": "sydamerikansk",
    "sydamerikanskas": "sydamerikansk",
    "sydamerikanskast": "sydamerikansk",
    "sydamerikanskaste": "sydamerikansk",
    "sydamerikanskastes": "sydamerikansk",
    "sydamerikanskasts": "sydamerikansk",
    "sydamerikanske": "sydamerikansk",
    "sydamerikanskes": "sydamerikansk",
    "sydamerikansks": "sydamerikansk",
    "sydamerikanskt": "sydamerikansk",
    "sydamerikanskts": "sydamerikansk",
    "sydd": "sy",
    "sydda": "sy",
    "syddas": "sy",
    "sydde": "sy",
    "syddes": "sy",
    "sydds": "sy",
    "sydfrukten": "sydfrukt",
    "sydfruktens": "sydfrukt",
    "sydfrukter": "sydfrukt",
    "sydfrukterna": "sydfrukt",
    "sydfrukternas": "sydfrukt",
    "sydfrukters": "sydfrukt",
    "sydfrukts": "sydfrukt",
    "sydjemeniten": "sydjemenit",
    "sydjemenitens": "sydjemenit",
    "sydjemeniter": "sydjemenit",
    "sydjemeniterna": "sydjemenit",
    "sydjemeniternas": "sydjemenit",
    "sydjemeniters": "sydjemenit",
    "sydjemenits": "sydjemenit",
    "sydkoreanen": "sydkorean",
    "sydkoreanens": "sydkorean",
    "sydkoreaner": "sydkorean",
    "sydkoreanerna": "sydkorean",
    "sydkoreanernas": "sydkorean",
    "sydkoreaners": "sydkorean",
    "sydkoreans": "sydkorean",
    "sydkoreanska": "sydkoreansk",
    "sydkoreanskan": "sydkoreanska",
    "sydkoreanskans": "sydkoreanska",
    "sydkoreanskare": "sydkoreansk",
    "sydkoreanskares": "sydkoreansk",
    "sydkoreanskas": "sydkoreanska",
    "sydkoreanskast": "sydkoreansk",
    "sydkoreanskaste": "sydkoreansk",
    "sydkoreanskastes": "sydkoreansk",
    "sydkoreanskasts": "sydkoreansk",
    "sydkoreanske": "sydkoreanska",
    "sydkoreanskes": "sydkoreansk",
    "sydkoreanskor": "sydkoreanska",
    "sydkoreanskorna": "sydkoreanska",
    "sydkoreanskornas": "sydkoreanska",
    "sydkoreanskors": "sydkoreanska",
    "sydkoreansks": "sydkoreansk",
    "sydkoreanskt": "sydkoreansk",
    "sydkoreanskts": "sydkoreansk",
    "sydkusten": "sydkust",
    "sydkustens": "sydkust",
    "sydkuster": "sydkust",
    "sydkusterna": "sydkust",
    "sydkusternas": "sydkust",
    "sydkusters": "sydkust",
    "sydkusts": "sydkust",
    "sydliga": "sydlig",
    "sydligare": "sydlig",
    "sydligares": "sydlig",
    "sydligas": "sydlig",
    "sydligast": "sydlig",
    "sydligaste": "sydlig",
    "sydligastes": "sydlig",
    "sydligasts": "sydlig",
    "sydlige": "sydlig",
    "sydliges": "sydlig",
    "sydligs": "sydlig",
    "sydligt": "sydlig",
    "sydligts": "sydlig",
    "sydländska": "sydländsk",
    "sydländskare": "sydländsk",
    "sydländskares": "sydländsk",
    "sydländskas": "sydländsk",
    "sydländskast": "sydländsk",
    "sydländskaste": "sydländsk",
    "sydländskastes": "sydländsk",
    "sydländskasts": "sydländsk",
    "sydländske": "sydländsk",
    "sydländskes": "sydländsk",
    "sydländsks": "sydländsk",
    "sydländskt": "sydländsk",
    "sydländskts": "sydländsk",
    "sydlänningar": "sydlänning",
    "sydlänningarna": "sydlänning",
    "sydlänningarnas": "sydlänning",
    "sydlänningars": "sydlänning",
    "sydlänningen": "sydlänning",
    "sydlänningens": "sydlänning",
    "sydlännings": "sydlänning",
    "sydosts": "sydost",
    "sydpolen": "sydpol",
    "sydpolens": "sydpol",
    "sydpoler": "sydpol",
    "sydpolerna": "sydpol",
    "sydpolernas": "sydpol",
    "sydpolers": "sydpol",
    "sydpols": "sydpol",
    "syds": "syd",
    "sydsidan": "sydsida",
    "sydsidans": "sydsida",
    "sydsidas": "sydsida",
    "sydside": "sydsida",
    "sydsides": "sydsida",
    "sydsidor": "sydsida",
    "sydsidorna": "sydsida",
    "sydsidornas": "sydsida",
    "sydsidors": "sydsida",
    "sydstaten": "sydstat",
    "sydstatens": "sydstat",
    "sydstater": "sydstat",
    "sydstaterna": "sydstat",
    "sydstaternas": "sydstat",
    "sydstaters": "sydstat",
    "sydstats": "sydstat",
    "sydsvenska": "sydsvensk",
    "sydsvenskare": "sydsvensk",
    "sydsvenskares": "sydsvensk",
    "sydsvenskas": "sydsvensk",
    "sydsvenskast": "sydsvensk",
    "sydsvenskaste": "sydsvensk",
    "sydsvenskastes": "sydsvensk",
    "sydsvenskasts": "sydsvensk",
    "sydsvenske": "sydsvensk",
    "sydsvenskes": "sydsvensk",
    "sydsvensks": "sydsvensk",
    "sydsvenskt": "sydsvensk",
    "sydsvenskts": "sydsvensk",
    "sydvästar": "sydväst",
    "sydvästarna": "sydväst",
    "sydvästarnas": "sydväst",
    "sydvästars": "sydväst",
    "sydvästen": "sydväst",
    "sydvästens": "sydväst",
    "sydvästs": "sydväst",
    "sydyemeniten": "sydyemenit",
    "sydyemenitens": "sydyemenit",
    "sydyemeniter": "sydyemenit",
    "sydyemeniterna": "sydyemenit",
    "sydyemeniternas": "sydyemenit",
    "sydyemeniters": "sydyemenit",
    "sydyemenits": "sydyemenit",
    "sydösts": "sydöst",
    "syende": "sy",
    "syenden": "syende",
    "syendena": "syende",
    "syendenas": "syende",
    "syendens": "syende",
    "syendes": "syende",
    "syendet": "syende",
    "syendets": "syende",
    "syffen": "syffe",
    "syffens": "syffe",
    "syffes": "syffe",
    "syffisansen": "syffisans",
    "syffisansens": "syffisans",
    "syfilisen": "syfilis",
    "syfilisens": "syfilis",
    "syfilitiska": "syfilitisk",
    "syfilitiskare": "syfilitisk",
    "syfilitiskares": "syfilitisk",
    "syfilitiskas": "syfilitisk",
    "syfilitiskast": "syfilitisk",
    "syfilitiskaste": "syfilitisk",
    "syfilitiskastes": "syfilitisk",
    "syfilitiskasts": "syfilitisk",
    "syfilitiske": "syfilitisk",
    "syfilitiskes": "syfilitisk",
    "syfilitisks": "syfilitisk",
    "syfilitiskt": "syfilitisk",
    "syfilitiskts": "syfilitisk",
    "syft": "syfta",
    "syftad": "syfta",
    "syftade": "syfta",
    "syftades": "syfta",
    "syftads": "syfta",
    "syftande": "syfta",
    "syftanden": "syftande",
    "syftandena": "syftande",
    "syftandenas": "syftande",
    "syftandens": "syftande",
    "syftandes": "syftande",
    "syftandet": "syftande",
    "syftandets": "syftande",
    "syftar": "syfta",
    "syftas": "syfta",
    "syftat": "syfta",
    "syftats": "syfta",
    "syften": "syfte",
    "syftena": "syfte",
    "syftenas": "syfte",
    "syftens": "syfte",
    "syftes": "syfte",
    "syftet": "syfte",
    "syftets": "syfte",
    "syföreningar": "syförening",
    "syföreningarna": "syförening",
    "syföreningarnas": "syförening",
    "syföreningars": "syförening",
    "syföreningen": "syförening",
    "syföreningens": "syförening",
    "syförenings": "syförening",
    "syföreningstanten": "syföreningstant",
    "syföreningstantens": "syföreningstant",
    "syföreningstanter": "syföreningstant",
    "syföreningstanterna": "syföreningstant",
    "syföreningstanternas": "syföreningstant",
    "syföreningstanters": "syföreningstant",
    "syföreningstants": "syföreningstant",
    "syjunt": "syjunta",
    "syjuntan": "syjunta",
    "syjuntans": "syjunta",
    "syjuntas": "syjunta",
    "syjunte": "syjunta",
    "syjuntor": "syjunta",
    "syjuntorna": "syjunta",
    "syjuntornas": "syjunta",
    "syjuntors": "syjunta",
    "syjunts": "syjunta",
    "sykofanten": "sykofant",
    "sykofantens": "sykofant",
    "sykofanter": "sykofant",
    "sykofanterna": "sykofant",
    "sykofanternas": "sykofant",
    "sykofanters": "sykofant",
    "sykofants": "sykofant",
    "sykomoren": "sykomor",
    "sykomorens": "sykomor",
    "sykomorer": "sykomor",
    "sykomorerna": "sykomor",
    "sykomorernas": "sykomor",
    "sykomorers": "sykomor",
    "sykomors": "sykomor",
    "sylar": "syl",
    "sylarna": "syl",
    "sylarnas": "syl",
    "sylars": "syl",
    "sylen": "syl",
    "sylens": "syl",
    "sylfen": "sylf",
    "sylfens": "sylf",
    "sylfer": "sylf",
    "sylferna": "sylf",
    "sylfernas": "sylf",
    "sylfers": "sylf",
    "sylfiden": "sylfid",
    "sylfidens": "sylfid",
    "sylfider": "sylfid",
    "sylfiderna": "sylfid",
    "sylfidernas": "sylfid",
    "sylfiders": "sylfid",
    "sylfids": "sylfid",
    "sylfs": "sylf",
    "syllabiska": "syllabisk",
    "syllabiskare": "syllabisk",
    "syllabiskares": "syllabisk",
    "syllabiskas": "syllabisk",
    "syllabiskast": "syllabisk",
    "syllabiskaste": "syllabisk",
    "syllabiskastes": "syllabisk",
    "syllabiskasts": "syllabisk",
    "syllabiske": "syllabisk",
    "syllabiskes": "syllabisk",
    "syllabisks": "syllabisk",
    "syllabiskt": "syllabisk",
    "syllabiskts": "syllabisk",
    "syllar": "syll",
    "syllarna": "syll",
    "syllarnas": "syll",
    "syllars": "syll",
    "syllen": "syll",
    "syllens": "syll",
    "syllogismen": "syllogism",
    "syllogismens": "syllogism",
    "syllogismer": "syllogism",
    "syllogismerna": "syllogism",
    "syllogismernas": "syllogism",
    "syllogismers": "syllogism",
    "syllogisms": "syllogism",
    "syllogistiska": "syllogistisk",
    "syllogistiskas": "syllogistisk",
    "syllogistiske": "syllogistisk",
    "syllogistiskes": "syllogistisk",
    "syllogistisks": "syllogistisk",
    "syllogistiskt": "syllogistisk",
    "syllogistiskts": "syllogistisk",
    "sylls": "syll",
    "syls": "syl",
    "sylt": "sylta",
    "syltad": "sylta",
    "syltade": "sylta",
    "syltades": "sylta",
    "syltads": "sylta",
    "syltan": "sylta",
    "syltande": "sylta",
    "syltanden": "syltande",
    "syltandena": "syltande",
    "syltandenas": "syltande",
    "syltandens": "syltande",
    "syltandes": "syltande",
    "syltandet": "syltande",
    "syltandets": "syltande",
    "syltans": "sylta",
    "syltar": "sylta",
    "syltas": "sylta",
    "syltat": "sylta",
    "syltats": "sylta",
    "syltberedningar": "syltberedning",
    "syltberedningarna": "syltberedning",
    "syltberedningarnas": "syltberedning",
    "syltberedningars": "syltberedning",
    "syltberedningen": "syltberedning",
    "syltberedningens": "syltberedning",
    "syltberednings": "syltberedning",
    "syltburkar": "syltburk",
    "syltburkarna": "syltburk",
    "syltburkarnas": "syltburk",
    "syltburkars": "syltburk",
    "syltburken": "syltburk",
    "syltburkens": "syltburk",
    "syltburks": "syltburk",
    "sylte": "sylta",
    "sylten": "sylt",
    "syltens": "sylt",
    "sylter": "sylt",
    "sylterna": "sylt",
    "sylternas": "sylt",
    "sylters": "sylt",
    "syltgurk": "syltgurka",
    "syltgurkan": "syltgurka",
    "syltgurkans": "syltgurka",
    "syltgurkas": "syltgurka",
    "syltgurke": "syltgurka",
    "syltgurkor": "syltgurka",
    "syltgurkorna": "syltgurka",
    "syltgurkornas": "syltgurka",
    "syltgurkors": "syltgurka",
    "syltgurks": "syltgurka",
    "syltkak": "syltkaka",
    "syltkakan": "syltkaka",
    "syltkakans": "syltkaka",
    "syltkakas": "syltkaka",
    "syltkake": "syltkaka",
    "syltkakor": "syltkaka",
    "syltkakorna": "syltkaka",
    "syltkakornas": "syltkaka",
    "syltkakors": "syltkaka",
    "syltkaks": "syltkaka",
    "syltlökar": "syltlök",
    "syltlökarna": "syltlök",
    "syltlökarnas": "syltlök",
    "syltlökars": "syltlök",
    "syltlöken": "syltlök",
    "syltlökens": "syltlök",
    "syltlöks": "syltlök",
    "syltor": "sylta",
    "syltorna": "sylta",
    "syltornas": "sylta",
    "syltors": "sylta",
    "syltpäronen": "syltpäron",
    "syltpäronens": "syltpäron",
    "syltpäronet": "syltpäron",
    "syltpäronets": "syltpäron",
    "syltpärons": "syltpäron",
    "sylts": "sylta",
    "sylvesterbalen": "sylvesterbal",
    "sylvesterbalens": "sylvesterbal",
    "sylvesterbaler": "sylvesterbal",
    "sylvesterbalerna": "sylvesterbal",
    "sylvesterbalernas": "sylvesterbal",
    "sylvesterbalers": "sylvesterbal",
    "sylvesterbals": "sylvesterbal",
    "symaskinen": "symaskin",
    "symaskinens": "symaskin",
    "symaskiner": "symaskin",
    "symaskinerna": "symaskin",
    "symaskinernas": "symaskin",
    "symaskiners": "symaskin",
    "symaskins": "symaskin",
    "symaskinsoljan": "symaskinsolja",
    "symaskinsoljans": "symaskinsolja",
    "symaskinsoljas": "symaskinsolja",
    "symaskinsolje": "symaskinsolja",
    "symbionten": "symbiont",
    "symbiontens": "symbiont",
    "symbionter": "symbiont",
    "symbionterna": "symbiont",
    "symbionternas": "symbiont",
    "symbionters": "symbiont",
    "symbionts": "symbiont",
    "symbiosen": "symbios",
    "symbiosens": "symbios",
    "symbiotiska": "symbiotisk",
    "symbiotiskare": "symbiotisk",
    "symbiotiskares": "symbiotisk",
    "symbiotiskas": "symbiotisk",
    "symbiotiskast": "symbiotisk",
    "symbiotiskaste": "symbiotisk",
    "symbiotiskastes": "symbiotisk",
    "symbiotiskasts": "symbiotisk",
    "symbiotiske": "symbiotisk",
    "symbiotiskes": "symbiotisk",
    "symbiotisks": "symbiotisk",
    "symbiotiskt": "symbiotisk",
    "symbiotiskts": "symbiotisk",
    "symbolen": "symbol",
    "symbolens": "symbol",
    "symboler": "symbol",
    "symbolerna": "symbol",
    "symbolernas": "symbol",
    "symbolers": "symbol",
    "symbolhandlingar": "symbolhandling",
    "symbolhandlingarna": "symbolhandling",
    "symbolhandlingarnas": "symbolhandling",
    "symbolhandlingars": "symbolhandling",
    "symbolhandlingen": "symbolhandling",
    "symbolhandlingens": "symbolhandling",
    "symbolhandlings": "symbolhandling",
    "symboliken": "symbolik",
    "symbolikens": "symbolik",
    "symboliks": "symbolik",
    "symboliserad": "symbolisera",
    "symboliserade": "symbolisera",
    "symboliserades": "symbolisera",
    "symboliserads": "symbolisera",
    "symboliserande": "symbolisera",
    "symboliseranden": "symboliserande",
    "symboliserandena": "symboliserande",
    "symboliserandenas": "symboliserande",
    "symboliserandens": "symboliserande",
    "symboliserandes": "symboliserande",
    "symboliserandet": "symboliserande",
    "symboliserandets": "symboliserande",
    "symboliserar": "symbolisera",
    "symboliseras": "symbolisera",
    "symboliserat": "symbolisera",
    "symboliserats": "symbolisera",
    "symboliserbara": "symboliserbar",
    "symboliserbarare": "symboliserbar",
    "symboliserbarares": "symboliserbar",
    "symboliserbaras": "symboliserbar",
    "symboliserbarast": "symboliserbar",
    "symboliserbaraste": "symboliserbar",
    "symboliserbarastes": "symboliserbar",
    "symboliserbarasts": "symboliserbar",
    "symboliserbare": "symboliserbar",
    "symboliserbares": "symboliserbar",
    "symboliserbarheten": "symboliserbarhet",
    "symboliserbarhetens": "symboliserbarhet",
    "symboliserbarhets": "symboliserbarhet",
    "symboliserbars": "symboliserbar",
    "symboliserbart": "symboliserbar",
    "symboliserbarts": "symboliserbar",
    "symboliseringar": "symbolisering",
    "symboliseringarna": "symbolisering",
    "symboliseringarnas": "symbolisering",
    "symboliseringars": "symbolisering",
    "symboliseringen": "symbolisering",
    "symboliseringens": "symbolisering",
    "symboliserings": "symbolisering",
    "symboliska": "symbolisk",
    "symboliskare": "symbolisk",
    "symboliskares": "symbolisk",
    "symboliskas": "symbolisk",
    "symboliskast": "symbolisk",
    "symboliskaste": "symbolisk",
    "symboliskastes": "symbolisk",
    "symboliskasts": "symbolisk",
    "symboliske": "symbolisk",
    "symboliskes": "symbolisk",
    "symbolisks": "symbolisk",
    "symboliskt": "symbolisk",
    "symboliskts": "symbolisk",
    "symbolismen": "symbolism",
    "symbolismens": "symbolism",
    "symbolismer": "symbolism",
    "symbolismerna": "symbolism",
    "symbolismernas": "symbolism",
    "symbolismers": "symbolism",
    "symbolisms": "symbolism",
    "symbolisten": "symbolist",
    "symbolistens": "symbolist",
    "symbolister": "symbolist",
    "symbolisterna": "symbolist",
    "symbolisternas": "symbolist",
    "symbolisters": "symbolist",
    "symbolistiska": "symbolistisk",
    "symbolistiskas": "symbolistisk",
    "symbolistiske": "symbolistisk",
    "symbolistiskes": "symbolistisk",
    "symbolistisks": "symbolistisk",
    "symbolistiskt": "symbolistisk",
    "symbolistiskts": "symbolistisk",
    "symbolists": "symbolist",
    "symbolmässiga": "symbolmässig",
    "symbolmässigare": "symbolmässig",
    "symbolmässigares": "symbolmässig",
    "symbolmässigas": "symbolmässig",
    "symbolmässigast": "symbolmässig",
    "symbolmässigaste": "symbolmässig",
    "symbolmässigastes": "symbolmässig",
    "symbolmässigasts": "symbolmässig",
    "symbolmässige": "symbolmässig",
    "symbolmässiges": "symbolmässig",
    "symbolmässigs": "symbolmässig",
    "symbolmässigt": "symbolmässig",
    "symbolmässigts": "symbolmässig",
    "symbols": "symbol",
    "symbolsekvensen": "symbolsekvens",
    "symbolsekvensens": "symbolsekvens",
    "symbolsekvenser": "symbolsekvens",
    "symbolsekvenserna": "symbolsekvens",
    "symbolsekvensernas": "symbolsekvens",
    "symbolsekvensers": "symbolsekvens",
    "symbolskatten": "symbolskatt",
    "symbolskattens": "symbolskatt",
    "symbolskatter": "symbolskatt",
    "symbolskatterna": "symbolskatt",
    "symbolskatternas": "symbolskatt",
    "symbolskatters": "symbolskatt",
    "symbolskatts": "symbolskatt",
    "symboltolkningar": "symboltolkning",
    "symboltolkningarna": "symboltolkning",
    "symboltolkningarnas": "symboltolkning",
    "symboltolkningars": "symboltolkning",
    "symboltolkningen": "symboltolkning",
    "symboltolkningens": "symboltolkning",
    "symboltolknings": "symboltolkning",
    "symfonien": "symfoni",
    "symfoniens": "symfoni",
    "symfonier": "symfoni",
    "symfonierna": "symfoni",
    "symfoniernas": "symfoni",
    "symfoniers": "symfoni",
    "symfonikern": "symfoniker",
    "symfonikerna": "symfoniker",
    "symfonikernas": "symfoniker",
    "symfonikerns": "symfoniker",
    "symfonikers": "symfoniker",
    "symfonin": "symfoni",
    "symfonins": "symfoni",
    "symfoniorkestern": "symfoniorkester",
    "symfoniorkesterns": "symfoniorkester",
    "symfoniorkesters": "symfoniorkester",
    "symfoniorkestrar": "symfoniorkester",
    "symfoniorkestrarna": "symfoniorkester",
    "symfoniorkestrarnas": "symfoniorkester",
    "symfoniorkestrars": "symfoniorkester",
    "symfonis": "symfoni",
    "symfoniska": "symfonisk",
    "symfoniskare": "symfonisk",
    "symfoniskares": "symfonisk",
    "symfoniskas": "symfonisk",
    "symfoniskast": "symfonisk",
    "symfoniskaste": "symfonisk",
    "symfoniskastes": "symfonisk",
    "symfoniskasts": "symfonisk",
    "symfoniske": "symfonisk",
    "symfoniskes": "symfonisk",
    "symfonisks": "symfonisk",
    "symfoniskt": "symfonisk",
    "symfoniskts": "symfonisk",
    "symfysen": "symfys",
    "symfysens": "symfys",
    "symfyser": "symfys",
    "symfyserna": "symfys",
    "symfysernas": "symfys",
    "symfysers": "symfys",
    "symmetriaxeln": "symmetriaxel",
    "symmetriaxelns": "symmetriaxel",
    "symmetriaxels": "symmetriaxel",
    "symmetriaxlar": "symmetriaxel",
    "symmetriaxlarna": "symmetriaxel",
    "symmetriaxlarnas": "symmetriaxel",
    "symmetriaxlars": "symmetriaxel",
    "symmetrien": "symmetri",
    "symmetriens": "symmetri",
    "symmetrier": "symmetri",
    "symmetrierna": "symmetri",
    "symmetriernas": "symmetri",
    "symmetriers": "symmetri",
    "symmetrilinjen": "symmetrilinje",
    "symmetrilinjens": "symmetrilinje",
    "symmetrilinjer": "symmetrilinje",
    "symmetrilinjerna": "symmetrilinje",
    "symmetrilinjernas": "symmetrilinje",
    "symmetrilinjers": "symmetrilinje",
    "symmetrilinjes": "symmetrilinje",
    "symmetrin": "symmetri",
    "symmetrins": "symmetri",
    "symmetriplanen": "symmetriplan",
    "symmetriplanens": "symmetriplan",
    "symmetriplanet": "symmetriplan",
    "symmetriplanets": "symmetriplan",
    "symmetriplans": "symmetriplan",
    "symmetris": "symmetri",
    "symmetriska": "symmetrisk",
    "symmetriskare": "symmetrisk",
    "symmetriskares": "symmetrisk",
    "symmetriskas": "symmetrisk",
    "symmetriskast": "symmetrisk",
    "symmetriskaste": "symmetrisk",
    "symmetriskastes": "symmetrisk",
    "symmetriskasts": "symmetrisk",
    "symmetriske": "symmetrisk",
    "symmetriskes": "symmetrisk",
    "symmetrisks": "symmetrisk",
    "symmetriskt": "symmetrisk",
    "symmetriskts": "symmetrisk",
    "sympatetiska": "sympatetisk",
    "sympatetiskare": "sympatetisk",
    "sympatetiskares": "sympatetisk",
    "sympatetiskas": "sympatetisk",
    "sympatetiskast": "sympatetisk",
    "sympatetiskaste": "sympatetisk",
    "sympatetiskastes": "sympatetisk",
    "sympatetiskasts": "sympatetisk",
    "sympatetiske": "sympatetisk",
    "sympatetiskes": "sympatetisk",
    "sympatetisks": "sympatetisk",
    "sympatetiskt": "sympatetisk",
    "sympatetiskts": "sympatetisk",
    "sympatien": "sympati",
    "sympatiens": "sympati",
    "sympatier": "sympati",
    "sympatierna": "sympati",
    "sympatiernas": "sympati",
    "sympatiers": "sympati",
    "sympatin": "sympati",
    "sympatins": "sympati",
    "sympatis": "sympati",
    "sympatiserade": "sympatisera",
    "sympatiserades": "sympatisera",
    "sympatiserande": "sympatisera",
    "sympatiseranden": "sympatiserande",
    "sympatiserandena": "sympatiserande",
    "sympatiserandenas": "sympatiserande",
    "sympatiserandens": "sympatiserande",
    "sympatiserandes": "sympatiserande",
    "sympatiserandet": "sympatiserande",
    "sympatiserandets": "sympatiserande",
    "sympatiserar": "sympatisera",
    "sympatiseras": "sympatisera",
    "sympatiserat": "sympatisera",
    "sympatiserats": "sympatisera",
    "sympatiseringar": "sympatisering",
    "sympatiseringarna": "sympatisering",
    "sympatiseringarnas": "sympatisering",
    "sympatiseringars": "sympatisering",
    "sympatiseringen": "sympatisering",
    "sympatiseringens": "sympatisering",
    "sympatiserings": "sympatisering",
    "sympatiska": "sympatisk",
    "sympatiskare": "sympatisk",
    "sympatiskares": "sympatisk",
    "sympatiskas": "sympatisk",
    "sympatiskast": "sympatisk",
    "sympatiskaste": "sympatisk",
    "sympatiskastes": "sympatisk",
    "sympatiskasts": "sympatisk",
    "sympatiske": "sympatisk",
    "sympatiskes": "sympatisk",
    "sympatisks": "sympatisk",
    "sympatiskt": "sympatisk",
    "sympatiskts": "sympatisk",
    "sympatistrejken": "sympatistrejk",
    "sympatistrejkens": "sympatistrejk",
    "sympatistrejker": "sympatistrejk",
    "sympatistrejkerna": "sympatistrejk",
    "sympatistrejkernas": "sympatistrejk",
    "sympatistrejkers": "sympatistrejk",
    "sympatistrejks": "sympatistrejk",
    "sympatisören": "sympatisör",
    "sympatisörens": "sympatisör",
    "sympatisörer": "sympatisör",
    "sympatisörerna": "sympatisör",
    "sympatisörernas": "sympatisör",
    "sympatisörers": "sympatisör",
    "sympatisörs": "sympatisör",
    "symposie": "symposium",
    "symposier": "symposium",
    "symposierna": "symposium",
    "symposiernas": "symposium",
    "symposiers": "symposium",
    "symposiet": "symposium",
    "symposiets": "symposium",
    "symposiums": "symposium",
    "symptomatiska": "symptomatisk",
    "symptomatiskare": "symptomatisk",
    "symptomatiskares": "symptomatisk",
    "symptomatiskas": "symptomatisk",
    "symptomatiskast": "symptomatisk",
    "symptomatiskaste": "symptomatisk",
    "symptomatiskastes": "symptomatisk",
    "symptomatiskasts": "symptomatisk",
    "symptomatiske": "symptomatisk",
    "symptomatiskes": "symptomatisk",
    "symptomatisks": "symptomatisk",
    "symptomatiskt": "symptomatisk",
    "symptomatiskts": "symptomatisk",
    "symptomen": "symptom",
    "symptomens": "symptom",
    "symptomet": "symptom",
    "symptomets": "symptom",
    "symptoms": "symptom",
    "symtomatiska": "symtomatisk",
    "symtomatiskare": "symtomatisk",
    "symtomatiskares": "symtomatisk",
    "symtomatiskas": "symtomatisk",
    "symtomatiskast": "symtomatisk",
    "symtomatiskaste": "symtomatisk",
    "symtomatiskastes": "symtomatisk",
    "symtomatiskasts": "symtomatisk",
    "symtomatiske": "symtomatisk",
    "symtomatiskes": "symtomatisk",
    "symtomatisks": "symtomatisk",
    "symtomatiskt": "symtomatisk",
    "symtomatiskts": "symtomatisk",
    "symtomen": "symtom",
    "symtomens": "symtom",
    "symtomet": "symtom",
    "symtomets": "symtom",
    "symtoms": "symtom",
    "syn": "syna",
    "synad": "syna",
    "synade": "syna",
    "synades": "syna",
    "synads": "syna",
    "synagog": "synagoga",
    "synagogan": "synagoga",
    "synagogans": "synagoga",
    "synagogas": "synagoga",
    "synagoge": "synagoga",
    "synagogor": "synagoga",
    "synagogorna": "synagoga",
    "synagogornas": "synagoga",
    "synagogors": "synagoga",
    "synagogs": "synagoga",
    "synande": "syna",
    "synanden": "synande",
    "synandena": "synande",
    "synandenas": "synande",
    "synandens": "synande",
    "synandes": "synande",
    "synandet": "synande",
    "synandets": "synande",
    "synapsbassängen": "synapsbassäng",
    "synapsbassängens": "synapsbassäng",
    "synapsbassänger": "synapsbassäng",
    "synapsbassängerna": "synapsbassäng",
    "synapsbassängernas": "synapsbassäng",
    "synapsbassängers": "synapsbassäng",
    "synapsbassängs": "synapsbassäng",
    "synapsen": "synaps",
    "synapsens": "synaps",
    "synapser": "synaps",
    "synapserna": "synaps",
    "synapsernas": "synaps",
    "synapsers": "synaps",
    "synar": "synare",
    "synaren": "synare",
    "synarens": "synare",
    "synares": "synare",
    "synarna": "synare",
    "synarnas": "synare",
    "synas": "syna",
    "synat": "syna",
    "synats": "syna",
    "synbara": "synbar",
    "synbarare": "synbar",
    "synbarares": "synbar",
    "synbaras": "synbar",
    "synbarast": "synbar",
    "synbaraste": "synbar",
    "synbarastes": "synbar",
    "synbarasts": "synbar",
    "synbare": "synbar",
    "synbares": "synbar",
    "synbarheten": "synbarhet",
    "synbarhetens": "synbarhet",
    "synbarhets": "synbarhet",
    "synbarliga": "synbarlig",
    "synbarligare": "synbarlig",
    "synbarligares": "synbarlig",
    "synbarligas": "synbarlig",
    "synbarligast": "synbarlig",
    "synbarligaste": "synbarlig",
    "synbarligastes": "synbarlig",
    "synbarligasts": "synbarlig",
    "synbarlige": "synbarlig",
    "synbarliges": "synbarlig",
    "synbarligheten": "synbarlighet",
    "synbarlighetens": "synbarlighet",
    "synbarlighets": "synbarlighet",
    "synbarligs": "synbarlig",
    "synbarligt": "synbarlig",
    "synbarligts": "synbarlig",
    "synbars": "synbar",
    "synbart": "synbar",
    "synbarts": "synbar",
    "synbilden": "synbild",
    "synbildens": "synbild",
    "synbilder": "synbild",
    "synbilderna": "synbild",
    "synbildernas": "synbild",
    "synbilders": "synbild",
    "synbilds": "synbild",
    "syncellen": "syncell",
    "syncellens": "syncell",
    "synceller": "syncell",
    "syncellerna": "syncell",
    "syncellernas": "syncell",
    "syncellers": "syncell",
    "syncells": "syncell",
    "synd": "synda",
    "syndabekännelsen": "syndabekännelse",
    "syndabekännelsens": "syndabekännelse",
    "syndabekännelser": "syndabekännelse",
    "syndabekännelserna": "syndabekännelse",
    "syndabekännelsernas": "syndabekännelse",
    "syndabekännelsers": "syndabekännelse",
    "syndabekännelses": "syndabekännelse",
    "syndabockar": "syndabock",
    "syndabockarna": "syndabock",
    "syndabockarnas": "syndabock",
    "syndabockars": "syndabock",
    "syndabocken": "syndabock",
    "syndabockens": "syndabock",
    "syndabocks": "syndabock",
    "syndad": "synda",
    "syndade": "synda",
    "syndades": "synda",
    "syndads": "synda",
    "syndafallen": "syndafall",
    "syndafallens": "syndafall",
    "syndafallet": "syndafall",
    "syndafallets": "syndafall",
    "syndafalls": "syndafall",
    "syndafloden": "syndaflod",
    "syndaflodens": "syndaflod",
    "syndafloder": "syndaflod",
    "syndafloderna": "syndaflod",
    "syndaflodernas": "syndaflod",
    "syndafloders": "syndaflod",
    "syndaflods": "syndaflod",
    "syndaförlåtelsen": "syndaförlåtelse",
    "syndaförlåtelsens": "syndaförlåtelse",
    "syndaförlåtelses": "syndaförlåtelse",
    "syndande": "synda",
    "syndanden": "syndande",
    "syndandena": "syndande",
    "syndandenas": "syndande",
    "syndandens": "syndande",
    "syndandes": "syndande",
    "syndandet": "syndande",
    "syndandets": "syndande",
    "syndapengar": "syndapeng",
    "syndapengarna": "syndapeng",
    "syndapengarnas": "syndapeng",
    "syndapengars": "syndapeng",
    "syndapengen": "syndapeng",
    "syndapengens": "syndapeng",
    "syndapengs": "syndapeng",
    "syndar": "syndare",
    "syndaren": "syndare",
    "syndarens": "syndare",
    "syndares": "syndare",
    "syndarna": "syndare",
    "syndarnas": "syndare",
    "syndas": "synda",
    "syndastraffen": "syndastraff",
    "syndastraffens": "syndastraff",
    "syndastraffet": "syndastraff",
    "syndastraffets": "syndastraff",
    "syndastraffs": "syndastraff",
    "syndat": "synda",
    "syndats": "synda",
    "synden": "synd",
    "syndens": "synd",
    "synder": "synd",
    "synderna": "synd",
    "syndernas": "synd",
    "synders": "synd",
    "syndet": "syndeter",
    "syndeterna": "syndeter",
    "syndeternas": "syndeter",
    "syndeters": "syndeter",
    "syndetikonet": "syndetikon",
    "syndetikonets": "syndetikon",
    "syndetikons": "syndetikon",
    "syndets": "syndeter",
    "syndiga": "syndig",
    "syndigare": "syndig",
    "syndigares": "syndig",
    "syndigas": "syndig",
    "syndigast": "syndig",
    "syndigaste": "syndig",
    "syndigastes": "syndig",
    "syndigasts": "syndig",
    "syndige": "syndig",
    "syndiges": "syndig",
    "syndigheten": "syndighet",
    "syndighetens": "syndighet",
    "syndighets": "syndighet",
    "syndigs": "syndig",
    "syndigt": "syndig",
    "syndigts": "syndig",
    "syndikalismen": "syndikalism",
    "syndikalismens": "syndikalism",
    "syndikalismer": "syndikalism",
    "syndikalismerna": "syndikalism",
    "syndikalismernas": "syndikalism",
    "syndikalismers": "syndikalism",
    "syndikalisms": "syndikalism",
    "syndikalisten": "syndikalist",
    "syndikalistens": "syndikalist",
    "syndikalister": "syndikalist",
    "syndikalisterna": "syndikalist",
    "syndikalisternas": "syndikalist",
    "syndikalisters": "syndikalist",
    "syndikalistiska": "syndikalistisk",
    "syndikalistiskas": "syndikalistisk",
    "syndikalistiske": "syndikalistisk",
    "syndikalistiskes": "syndikalistisk",
    "syndikalistisks": "syndikalistisk",
    "syndikalistiskt": "syndikalistisk",
    "syndikalistiskts": "syndikalistisk",
    "syndikalists": "syndikalist",
    "syndikaten": "syndikat",
    "syndikatens": "syndikat",
    "syndikatet": "syndikat",
    "syndikatets": "syndikat",
    "syndikats": "syndikat",
    "syndromen": "syndrom",
    "syndromens": "syndrom",
    "syndromet": "syndrom",
    "syndromets": "syndrom",
    "syndroms": "syndrom",
    "synds": "synd",
    "synekdoken": "synekdoke",
    "synekdokens": "synekdoke",
    "synekdokes": "synekdoke",
    "synen": "syn",
    "synens": "syn",
    "syner": "syn",
    "synergismen": "synergism",
    "synergismens": "synergism",
    "synergismer": "synergism",
    "synergismerna": "synergism",
    "synergismernas": "synergism",
    "synergismers": "synergism",
    "synergisms": "synergism",
    "synergistiska": "synergistisk",
    "synergistiskas": "synergistisk",
    "synergistiske": "synergistisk",
    "synergistiskes": "synergistisk",
    "synergistisks": "synergistisk",
    "synergistiskt": "synergistisk",
    "synergistiskts": "synergistisk",
    "synerna": "syn",
    "synernas": "syn",
    "syners": "syn",
    "synestesien": "synestesi",
    "synestesiens": "synestesi",
    "synestesier": "synestesi",
    "synestesierna": "synestesi",
    "synestesiernas": "synestesi",
    "synestesiers": "synestesi",
    "synestesin": "synestesi",
    "synestesins": "synestesi",
    "synestesis": "synestesi",
    "synfelen": "synfel",
    "synfelens": "synfel",
    "synfelet": "synfel",
    "synfelets": "synfel",
    "synfels": "synfel",
    "synfälten": "synfält",
    "synfältens": "synfält",
    "synfältet": "synfält",
    "synfältets": "synfält",
    "synfälts": "synfält",
    "synförnimmelsen": "synförnimmelse",
    "synförnimmelsens": "synförnimmelse",
    "synförnimmelser": "synförnimmelse",
    "synförnimmelserna": "synförnimmelse",
    "synförnimmelsernas": "synförnimmelse",
    "synförnimmelsers": "synförnimmelse",
    "synförnimmelses": "synförnimmelse",
    "synhålls": "synhåll",
    "synintrycken": "synintryck",
    "synintryckens": "synintryck",
    "synintrycket": "synintryck",
    "synintryckets": "synintryck",
    "synintrycks": "synintryck",
    "synk": "synka",
    "synkad": "synka",
    "synkade": "synka",
    "synkades": "synka",
    "synkads": "synka",
    "synkande": "synka",
    "synkanden": "synkande",
    "synkandena": "synkande",
    "synkandenas": "synkande",
    "synkandens": "synkande",
    "synkandes": "synkande",
    "synkandet": "synkande",
    "synkandets": "synkande",
    "synkar": "synka",
    "synkarna": "synk",
    "synkarnas": "synk",
    "synkars": "synk",
    "synkas": "synka",
    "synkat": "synka",
    "synkats": "synka",
    "synken": "synk",
    "synkens": "synk",
    "synklinalen": "synklinal",
    "synklinalens": "synklinal",
    "synklinaler": "synklinal",
    "synklinalerna": "synklinal",
    "synklinalernas": "synklinal",
    "synklinalers": "synklinal",
    "synklinals": "synklinal",
    "synkningen": "synkning",
    "synkningens": "synkning",
    "synknings": "synkning",
    "synkopen": "synkope",
    "synkopens": "synkope",
    "synkoper": "synkop",
    "synkoperad": "synkopera",
    "synkoperade": "synkoperad",
    "synkoperades": "synkoperad",
    "synkoperads": "synkoperad",
    "synkoperande": "synkopera",
    "synkoperanden": "synkoperande",
    "synkoperandena": "synkoperande",
    "synkoperandenas": "synkoperande",
    "synkoperandens": "synkoperande",
    "synkoperandes": "synkoperande",
    "synkoperandet": "synkoperande",
    "synkoperandets": "synkoperande",
    "synkoperar": "synkopera",
    "synkoperas": "synkopera",
    "synkoperat": "synkoperad",
    "synkoperats": "synkoperad",
    "synkoperbara": "synkoperbar",
    "synkoperbarare": "synkoperbar",
    "synkoperbarares": "synkoperbar",
    "synkoperbaras": "synkoperbar",
    "synkoperbarast": "synkoperbar",
    "synkoperbaraste": "synkoperbar",
    "synkoperbarastes": "synkoperbar",
    "synkoperbarasts": "synkoperbar",
    "synkoperbare": "synkoperbar",
    "synkoperbares": "synkoperbar",
    "synkoperbarheten": "synkoperbarhet",
    "synkoperbarhetens": "synkoperbarhet",
    "synkoperbarhets": "synkoperbarhet",
    "synkoperbars": "synkoperbar",
    "synkoperbart": "synkoperbar",
    "synkoperbarts": "synkoperbar",
    "synkoperingar": "synkopering",
    "synkoperingarna": "synkopering",
    "synkoperingarnas": "synkopering",
    "synkoperingars": "synkopering",
    "synkoperingen": "synkopering",
    "synkoperingens": "synkopering",
    "synkoperings": "synkopering",
    "synkoperna": "synkop",
    "synkopernas": "synkop",
    "synkopers": "synkop",
    "synkopes": "synkope",
    "synkopiska": "synkopisk",
    "synkopiskare": "synkopisk",
    "synkopiskares": "synkopisk",
    "synkopiskas": "synkopisk",
    "synkopiskast": "synkopisk",
    "synkopiskaste": "synkopisk",
    "synkopiskastes": "synkopisk",
    "synkopiskasts": "synkopisk",
    "synkopiske": "synkopisk",
    "synkopiskes": "synkopisk",
    "synkopisks": "synkopisk",
    "synkopiskt": "synkopisk",
    "synkopiskts": "synkopisk",
    "synkops": "synkop",
    "synkpulsen": "synkpuls",
    "synkpulsens": "synkpuls",
    "synkpulser": "synkpuls",
    "synkpulserna": "synkpuls",
    "synkpulsernas": "synkpuls",
    "synkpulsers": "synkpuls",
    "synkretismen": "synkretism",
    "synkretismens": "synkretism",
    "synkretismer": "synkretism",
    "synkretismerna": "synkretism",
    "synkretismernas": "synkretism",
    "synkretismers": "synkretism",
    "synkretisms": "synkretism",
    "synkretistiska": "synkretistisk",
    "synkretistiskas": "synkretistisk",
    "synkretistiske": "synkretistisk",
    "synkretistiskes": "synkretistisk",
    "synkretistisks": "synkretistisk",
    "synkretistiskt": "synkretistisk",
    "synkretistiskts": "synkretistisk",
    "synkrona": "synkron",
    "synkronare": "synkron",
    "synkronares": "synkron",
    "synkronas": "synkron",
    "synkronast": "synkron",
    "synkronaste": "synkron",
    "synkronastes": "synkron",
    "synkronasts": "synkron",
    "synkrone": "synkron",
    "synkrones": "synkron",
    "synkroniserad": "synkronisera",
    "synkroniserade": "synkronisera",
    "synkroniserades": "synkronisera",
    "synkroniserads": "synkronisera",
    "synkroniserande": "synkronisera",
    "synkroniseranden": "synkroniserande",
    "synkroniserandena": "synkroniserande",
    "synkroniserandenas": "synkroniserande",
    "synkroniserandens": "synkroniserande",
    "synkroniserandes": "synkroniserande",
    "synkroniserandet": "synkroniserande",
    "synkroniserandets": "synkroniserande",
    "synkroniserar": "synkronisera",
    "synkroniseras": "synkronisera",
    "synkroniserat": "synkronisera",
    "synkroniserats": "synkronisera",
    "synkroniserbara": "synkroniserbar",
    "synkroniserbarare": "synkroniserbar",
    "synkroniserbarares": "synkroniserbar",
    "synkroniserbaras": "synkroniserbar",
    "synkroniserbarast": "synkroniserbar",
    "synkroniserbaraste": "synkroniserbar",
    "synkroniserbarastes": "synkroniserbar",
    "synkroniserbarasts": "synkroniserbar",
    "synkroniserbare": "synkroniserbar",
    "synkroniserbares": "synkroniserbar",
    "synkroniserbarheten": "synkroniserbarhet",
    "synkroniserbarhetens": "synkroniserbarhet",
    "synkroniserbarhets": "synkroniserbarhet",
    "synkroniserbars": "synkroniserbar",
    "synkroniserbart": "synkroniserbar",
    "synkroniserbarts": "synkroniserbar",
    "synkroniseringar": "synkronisering",
    "synkroniseringarna": "synkronisering",
    "synkroniseringarnas": "synkronisering",
    "synkroniseringars": "synkronisering",
    "synkroniseringen": "synkronisering",
    "synkroniseringens": "synkronisering",
    "synkroniserings": "synkronisering",
    "synkroniska": "synkronisk",
    "synkroniskare": "synkronisk",
    "synkroniskares": "synkronisk",
    "synkroniskas": "synkronisk",
    "synkroniskast": "synkronisk",
    "synkroniskaste": "synkronisk",
    "synkroniskastes": "synkronisk",
    "synkroniskasts": "synkronisk",
    "synkroniske": "synkronisk",
    "synkroniskes": "synkronisk",
    "synkronisks": "synkronisk",
    "synkroniskt": "synkronisk",
    "synkroniskts": "synkronisk",
    "synkronismen": "synkronism",
    "synkronismens": "synkronism",
    "synkronismer": "synkronism",
    "synkronismerna": "synkronism",
    "synkronismernas": "synkronism",
    "synkronismers": "synkronism",
    "synkronisms": "synkronism",
    "synkrons": "synkron",
    "synkront": "synkron",
    "synkronts": "synkron",
    "synkrotronen": "synkrotron",
    "synkrotronens": "synkrotron",
    "synkrotroner": "synkrotron",
    "synkrotronerna": "synkrotron",
    "synkrotronernas": "synkrotron",
    "synkrotroners": "synkrotron",
    "synkrotronljusringar": "synkrotronljusring",
    "synkrotronljusringarna": "synkrotronljusring",
    "synkrotronljusringarnas": "synkrotronljusring",
    "synkrotronljusringars": "synkrotronljusring",
    "synkrotronljusringen": "synkrotronljusring",
    "synkrotronljusringens": "synkrotronljusring",
    "synkrotronljusrings": "synkrotronljusring",
    "synkrotrons": "synkrotron",
    "synks": "synk",
    "synliga": "synlig",
    "synligare": "synlig",
    "synligares": "synlig",
    "synligas": "synlig",
    "synligast": "synlig",
    "synligaste": "synlig",
    "synligastes": "synlig",
    "synligasts": "synlig",
    "synlige": "synlig",
    "synliges": "synlig",
    "synliggjord": "synliggöra",
    "synliggjorda": "synliggöra",
    "synliggjordas": "synliggöra",
    "synliggjorde": "synliggöra",
    "synliggjordes": "synliggöra",
    "synliggjords": "synliggöra",
    "synliggjort": "synliggöra",
    "synliggjorts": "synliggöra",
    "synliggör": "synliggöra",
    "synliggörande": "synliggöra",
    "synliggörandes": "synliggöra",
    "synliggöras": "synliggöra",
    "synliggöres": "synliggöra",
    "synliggörs": "synliggöra",
    "synligheten": "synlighet",
    "synlighetens": "synlighet",
    "synligheter": "synlighet",
    "synligheterna": "synlighet",
    "synligheternas": "synlighet",
    "synligheters": "synlighet",
    "synlighets": "synlighet",
    "synligs": "synlig",
    "synligt": "synlig",
    "synligts": "synlig",
    "synnerliga": "synnerlig",
    "synnerligare": "synnerlig",
    "synnerligares": "synnerlig",
    "synnerligas": "synnerlig",
    "synnerligast": "synnerlig",
    "synnerligaste": "synnerlig",
    "synnerligastes": "synnerlig",
    "synnerligasts": "synnerlig",
    "synnerlige": "synnerlig",
    "synnerliges": "synnerlig",
    "synnerligs": "synnerlig",
    "synnerligt": "synnerlig",
    "synnerligts": "synnerlig",
    "synnerven": "synnerv",
    "synnervens": "synnerv",
    "synnerver": "synnerv",
    "synnerverna": "synnerv",
    "synnervernas": "synnerv",
    "synnervers": "synnerv",
    "synnervs": "synnerv",
    "synodala": "synodal",
    "synodalare": "synodal",
    "synodalares": "synodal",
    "synodalas": "synodal",
    "synodalast": "synodal",
    "synodalaste": "synodal",
    "synodalastes": "synodal",
    "synodalasts": "synodal",
    "synodale": "synodal",
    "synodales": "synodal",
    "synodals": "synodal",
    "synodalt": "synodal",
    "synodalts": "synodal",
    "synoden": "synod",
    "synodens": "synod",
    "synoder": "synod",
    "synoderna": "synod",
    "synodernas": "synod",
    "synoders": "synod",
    "synodiska": "synodisk",
    "synodiskare": "synodisk",
    "synodiskares": "synodisk",
    "synodiskas": "synodisk",
    "synodiskast": "synodisk",
    "synodiskaste": "synodisk",
    "synodiskastes": "synodisk",
    "synodiskasts": "synodisk",
    "synodiske": "synodisk",
    "synodiskes": "synodisk",
    "synodisks": "synodisk",
    "synodiskt": "synodisk",
    "synodiskts": "synodisk",
    "synods": "synod",
    "synonyma": "synonym",
    "synonymare": "synonym",
    "synonymares": "synonym",
    "synonymas": "synonym",
    "synonymast": "synonym",
    "synonymaste": "synonym",
    "synonymastes": "synonym",
    "synonymasts": "synonym",
    "synonyme": "synonym",
    "synonymen": "synonym",
    "synonymens": "synonym",
    "synonymer": "synonym",
    "synonymerna": "synonym",
    "synonymernas": "synonym",
    "synonymers": "synonym",
    "synonymes": "synonym",
    "synonymien": "synonymi",
    "synonymiens": "synonymi",
    "synonymier": "synonymi",
    "synonymierna": "synonymi",
    "synonymiernas": "synonymi",
    "synonymiers": "synonymi",
    "synonymin": "synonymi",
    "synonymins": "synonymi",
    "synonymis": "synonymi",
    "synonymlexikonen": "synonymlexikon",
    "synonymlexikonens": "synonymlexikon",
    "synonymlexikonet": "synonymlexikon",
    "synonymlexikonets": "synonymlexikon",
    "synonymlexikons": "synonymlexikon",
    "synonymmängden": "synonymmängd",
    "synonymmängdens": "synonymmängd",
    "synonymmängder": "synonymmängd",
    "synonymmängderna": "synonymmängd",
    "synonymmängdernas": "synonymmängd",
    "synonymmängders": "synonymmängd",
    "synonymmängds": "synonymmängd",
    "synonymordboken": "synonymordbok",
    "synonymordbokens": "synonymordbok",
    "synonymordboks": "synonymordbok",
    "synonymordböcker": "synonymordbok",
    "synonymordböckerna": "synonymordbok",
    "synonymordböckernas": "synonymordbok",
    "synonymordböckers": "synonymordbok",
    "synonymparen": "synonympar",
    "synonymparens": "synonympar",
    "synonymparet": "synonympar",
    "synonymparets": "synonympar",
    "synonympars": "synonympar",
    "synonyms": "synonym",
    "synonymt": "synonym",
    "synonymts": "synonym",
    "synopsen": "synops",
    "synopsens": "synops",
    "synopser": "synops",
    "synopserna": "synops",
    "synopsernas": "synops",
    "synopsers": "synops",
    "synoptikern": "synoptiker",
    "synoptikerna": "synoptiker",
    "synoptikernas": "synoptiker",
    "synoptikerns": "synoptiker",
    "synoptikers": "synoptiker",
    "synoptiska": "synoptisk",
    "synoptiskare": "synoptisk",
    "synoptiskares": "synoptisk",
    "synoptiskas": "synoptisk",
    "synoptiskast": "synoptisk",
    "synoptiskaste": "synoptisk",
    "synoptiskastes": "synoptisk",
    "synoptiskasts": "synoptisk",
    "synoptiske": "synoptisk",
    "synoptiskes": "synoptisk",
    "synoptisks": "synoptisk",
    "synoptiskt": "synoptisk",
    "synoptiskts": "synoptisk",
    "synorganen": "synorgan",
    "synorganens": "synorgan",
    "synorganet": "synorgan",
    "synorganets": "synorgan",
    "synorgans": "synorgan",
    "synpunkten": "synpunkt",
    "synpunktens": "synpunkt",
    "synpunkter": "synpunkt",
    "synpunkterna": "synpunkt",
    "synpunkternas": "synpunkt",
    "synpunkters": "synpunkt",
    "synpunkts": "synpunkt",
    "synpurpurn": "synpurpur",
    "synpurpurns": "synpurpur",
    "synpurpurs": "synpurpur",
    "synranden": "synrand",
    "synrandens": "synrand",
    "synrands": "synrand",
    "syns": "syn",
    "synseten": "synset",
    "synsetens": "synset",
    "synsetet": "synset",
    "synsetets": "synset",
    "synsets": "synset",
    "synsetsen": "synset",
    "synsetsens": "synset",
    "synsjukdomar": "synsjukdom",
    "synsjukdomarna": "synsjukdom",
    "synsjukdomarnas": "synsjukdom",
    "synsjukdomars": "synsjukdom",
    "synsjukdomen": "synsjukdom",
    "synsjukdomens": "synsjukdom",
    "synsjukdoms": "synsjukdom",
    "synska": "synsk",
    "synskadade": "synskadad",
    "synskadades": "synskadad",
    "synskadads": "synskadad",
    "synskadat": "synskadad",
    "synskadats": "synskadad",
    "synskare": "synsk",
    "synskares": "synsk",
    "synskas": "synsk",
    "synskast": "synsk",
    "synskaste": "synsk",
    "synskastes": "synsk",
    "synskasts": "synsk",
    "synske": "synsk",
    "synskes": "synsk",
    "synskheten": "synskhet",
    "synskhetens": "synskhet",
    "synskhets": "synskhet",
    "synsks": "synsk",
    "synskt": "synsk",
    "synskts": "synsk",
    "synsätten": "synsätt",
    "synsättens": "synsätt",
    "synsättet": "synsätt",
    "synsättets": "synsätt",
    "synsätts": "synsätt",
    "syntagmen": "syntagm",
    "syntagmens": "syntagm",
    "syntagmer": "syntagm",
    "syntagmerna": "syntagm",
    "syntagmernas": "syntagm",
    "syntagmers": "syntagm",
    "syntagmet": "syntagm",
    "syntagmets": "syntagm",
    "syntagms": "syntagm",
    "syntaktiska": "syntaktisk",
    "syntaktiskare": "syntaktisk",
    "syntaktiskares": "syntaktisk",
    "syntaktiskas": "syntaktisk",
    "syntaktiskast": "syntaktisk",
    "syntaktiskaste": "syntaktisk",
    "syntaktiskastes": "syntaktisk",
    "syntaktiskasts": "syntaktisk",
    "syntaktiske": "syntaktisk",
    "syntaktiskes": "syntaktisk",
    "syntaktisks": "syntaktisk",
    "syntaktiskt": "syntaktisk",
    "syntaktiskts": "syntaktisk",
    "syntar": "synt",
    "syntarna": "synt",
    "syntarnas": "synt",
    "syntars": "synt",
    "syntaxanalysen": "syntaxanalys",
    "syntaxanalysens": "syntaxanalys",
    "syntaxanalyser": "syntaxanalys",
    "syntaxanalyserna": "syntaxanalys",
    "syntaxanalysernas": "syntaxanalys",
    "syntaxanalysers": "syntaxanalys",
    "syntaxen": "syntax",
    "syntaxens": "syntax",
    "syntaxer": "syntax",
    "syntaxerna": "syntax",
    "syntaxernas": "syntax",
    "syntaxers": "syntax",
    "syntaxträden": "syntaxträd",
    "syntaxträdens": "syntaxträd",
    "syntaxträdet": "syntaxträd",
    "syntaxträdets": "syntaxträd",
    "syntaxträds": "syntaxträd",
    "synten": "synt",
    "syntens": "synt",
    "syntes": "synas",
    "syntesen": "syntes",
    "syntesens": "syntes",
    "synteser": "syntes",
    "synteserna": "syntes",
    "syntesernas": "syntes",
    "syntesers": "syntes",
    "synteten": "syntet",
    "syntetens": "syntet",
    "synteter": "syntet",
    "synteterna": "syntet",
    "synteternas": "syntet",
    "synteters": "syntet",
    "syntetfibern": "syntetfiber",
    "syntetfiberns": "syntetfiber",
    "syntetfibers": "syntetfiber",
    "syntetfibrer": "syntetfiber",
    "syntetfibrerna": "syntetfiber",
    "syntetfibrernas": "syntetfiber",
    "syntetfibrers": "syntetfiber",
    "syntetiserad": "syntetisera",
    "syntetiserade": "syntetisera",
    "syntetiserades": "syntetisera",
    "syntetiserads": "syntetisera",
    "syntetiserande": "syntetisera",
    "syntetiseranden": "syntetiserande",
    "syntetiserandena": "syntetiserande",
    "syntetiserandenas": "syntetiserande",
    "syntetiserandens": "syntetiserande",
    "syntetiserandes": "syntetiserande",
    "syntetiserandet": "syntetiserande",
    "syntetiserandets": "syntetiserande",
    "syntetiserar": "syntetisera",
    "syntetiseras": "syntetisera",
    "syntetiserat": "syntetisera",
    "syntetiserats": "syntetisera",
    "syntetiserbara": "syntetiserbar",
    "syntetiserbarare": "syntetiserbar",
    "syntetiserbarares": "syntetiserbar",
    "syntetiserbaras": "syntetiserbar",
    "syntetiserbarast": "syntetiserbar",
    "syntetiserbaraste": "syntetiserbar",
    "syntetiserbarastes": "syntetiserbar",
    "syntetiserbarasts": "syntetiserbar",
    "syntetiserbare": "syntetiserbar",
    "syntetiserbares": "syntetiserbar",
    "syntetiserbarheten": "syntetiserbarhet",
    "syntetiserbarhetens": "syntetiserbarhet",
    "syntetiserbarhets": "syntetiserbarhet",
    "syntetiserbars": "syntetiserbar",
    "syntetiserbart": "syntetiserbar",
    "syntetiserbarts": "syntetiserbar",
    "syntetiseringar": "syntetisering",
    "syntetiseringarna": "syntetisering",
    "syntetiseringarnas": "syntetisering",
    "syntetiseringars": "syntetisering",
    "syntetiseringen": "syntetisering",
    "syntetiseringens": "syntetisering",
    "syntetiserings": "syntetisering",
    "syntetiska": "syntetisk",
    "syntetiskare": "syntetisk",
    "syntetiskares": "syntetisk",
    "syntetiskas": "syntetisk",
    "syntetiskast": "syntetisk",
    "syntetiskaste": "syntetisk",
    "syntetiskastes": "syntetisk",
    "syntetiskasts": "syntetisk",
    "syntetiske": "syntetisk",
    "syntetiskes": "syntetisk",
    "syntetisks": "syntetisk",
    "syntetiskt": "syntetisk",
    "syntetiskts": "syntetisk",
    "syntetklädseln": "syntetklädsel",
    "syntetklädselns": "syntetklädsel",
    "syntetklädsels": "syntetklädsel",
    "syntetklädslar": "syntetklädsel",
    "syntetklädslarna": "syntetklädsel",
    "syntetklädslarnas": "syntetklädsel",
    "syntetklädslars": "syntetklädsel",
    "syntetmaterialen": "syntetmaterial",
    "syntetmaterialens": "syntetmaterial",
    "syntetmaterialet": "syntetmaterial",
    "syntetmaterialets": "syntetmaterial",
    "syntetmaterials": "syntetmaterial",
    "syntets": "syntet",
    "synthesizern": "synthesizer",
    "synthesizerns": "synthesizer",
    "synthesizers": "synthesizer",
    "synthesizersarna": "synthesizer",
    "synthesizersarnas": "synthesizer",
    "synthesizersen": "synthesizer",
    "synthesizersens": "synthesizer",
    "synthesizrar": "synthesizer",
    "synthesizrarna": "synthesizer",
    "synthesizrarnas": "synthesizer",
    "synthesizrars": "synthesizer",
    "synts": "synt",
    "synvill": "synvilla",
    "synvillan": "synvilla",
    "synvillans": "synvilla",
    "synvillas": "synvilla",
    "synville": "synvilla",
    "synvillor": "synvilla",
    "synvillorna": "synvilla",
    "synvillornas": "synvilla",
    "synvillors": "synvilla",
    "synvills": "synvilla",
    "synvinkeln": "synvinkel",
    "synvinkelns": "synvinkel",
    "synvinkels": "synvinkel",
    "synvinklar": "synvinkel",
    "synvinklarna": "synvinkel",
    "synvinklarnas": "synvinkel",
    "synvinklars": "synvinkel",
    "synålar": "synål",
    "synålarna": "synål",
    "synålarnas": "synål",
    "synålars": "synål",
    "synålen": "synål",
    "synålens": "synål",
    "synåls": "synål",
    "syo-s": "syo",
    "syo:s": "syo",
    "syokonsulenten": "syokonsulent",
    "syokonsulentens": "syokonsulent",
    "syokonsulenter": "syokonsulent",
    "syokonsulenterna": "syokonsulent",
    "syokonsulenternas": "syokonsulent",
    "syokonsulenters": "syokonsulent",
    "syokonsulents": "syokonsulent",
    "syon": "syo",
    "syons": "syo",
    "syor": "syo",
    "syorna": "syo",
    "syornas": "syo",
    "syors": "syo",
    "syos": "syo",
    "syperba": "syperb",
    "syperbare": "syperb",
    "syperbares": "syperb",
    "syperbas": "syperb",
    "syperbast": "syperb",
    "syperbaste": "syperb",
    "syperbastes": "syperb",
    "syperbasts": "syperb",
    "syperbe": "syperb",
    "syperbes": "syperb",
    "syperbheten": "syperbhet",
    "syperbhetens": "syperbhet",
    "syperbhets": "syperbhet",
    "syperbs": "syperb",
    "syperbt": "syperb",
    "syperbts": "syperb",
    "syr": "syra",
    "syracisternen": "syracistern",
    "syracisternens": "syracistern",
    "syracisterner": "syracistern",
    "syracisternerna": "syracistern",
    "syracisternernas": "syracistern",
    "syracisterners": "syracistern",
    "syracisterns": "syracistern",
    "syrad": "syra",
    "syrade": "syrad",
    "syrades": "syrad",
    "syrads": "syrad",
    "syrafasta": "syrafast",
    "syrafastare": "syrafast",
    "syrafastares": "syrafast",
    "syrafastas": "syrafast",
    "syrafastast": "syrafast",
    "syrafastaste": "syrafast",
    "syrafastastes": "syrafast",
    "syrafastasts": "syrafast",
    "syrafaste": "syrafast",
    "syrafastes": "syrafast",
    "syrafastheten": "syrafasthet",
    "syrafasthetens": "syrafasthet",
    "syrafasthets": "syrafasthet",
    "syrafasts": "syrafast",
    "syraläckagen": "syraläckage",
    "syraläckagens": "syraläckage",
    "syraläckages": "syraläckage",
    "syraläckaget": "syraläckage",
    "syraläckagets": "syraläckage",
    "syran": "syra",
    "syrande": "syra",
    "syranden": "syrande",
    "syrandena": "syrande",
    "syrandenas": "syrande",
    "syrandens": "syrande",
    "syrandes": "syrande",
    "syrandet": "syrande",
    "syrandets": "syrande",
    "syrans": "syra",
    "syraprovar": "syraprovare",
    "syraprovaren": "syraprovare",
    "syraprovarens": "syraprovare",
    "syraprovares": "syraprovare",
    "syraprovarna": "syraprovare",
    "syraprovarnas": "syraprovare",
    "syrar": "syra",
    "syras": "syra",
    "syrat": "syrad",
    "syrats": "syrad",
    "syreatomen": "syreatom",
    "syreatomens": "syreatom",
    "syreatomer": "syreatom",
    "syreatomerna": "syreatom",
    "syreatomernas": "syreatom",
    "syreatomers": "syreatom",
    "syreatoms": "syreatom",
    "syrebristen": "syrebrist",
    "syrebristens": "syrebrist",
    "syrebrists": "syrebrist",
    "syrefattiga": "syrefattig",
    "syrefattigare": "syrefattig",
    "syrefattigares": "syrefattig",
    "syrefattigas": "syrefattig",
    "syrefattigast": "syrefattig",
    "syrefattigaste": "syrefattig",
    "syrefattigastes": "syrefattig",
    "syrefattigasts": "syrefattig",
    "syrefattige": "syrefattig",
    "syrefattiges": "syrefattig",
    "syrefattigheten": "syrefattighet",
    "syrefattighetens": "syrefattighet",
    "syrefattighets": "syrefattighet",
    "syrefattigs": "syrefattig",
    "syrefattigt": "syrefattig",
    "syrefattigts": "syrefattig",
    "syrefälten": "syrefält",
    "syrefältens": "syrefält",
    "syrefältet": "syrefält",
    "syrefältets": "syrefält",
    "syrefälts": "syrefält",
    "syreisotopen": "syreisotop",
    "syreisotopens": "syreisotop",
    "syreisotoper": "syreisotop",
    "syreisotoperna": "syreisotop",
    "syreisotopernas": "syreisotop",
    "syreisotopers": "syreisotop",
    "syreisotops": "syreisotop",
    "syremolekylen": "syremolekyl",
    "syremolekylens": "syremolekyl",
    "syremolekyler": "syremolekyl",
    "syremolekylerna": "syremolekyl",
    "syremolekylernas": "syremolekyl",
    "syremolekylers": "syremolekyl",
    "syremolekyls": "syremolekyl",
    "syrenen": "syren",
    "syrenens": "syren",
    "syrener": "syren",
    "syrenerna": "syren",
    "syrenernas": "syren",
    "syreners": "syren",
    "syrens": "syren",
    "syrerika": "syrerik",
    "syrerikare": "syrerik",
    "syrerikares": "syrerik",
    "syrerikas": "syrerik",
    "syrerikast": "syrerik",
    "syrerikaste": "syrerik",
    "syrerikastes": "syrerik",
    "syrerikasts": "syrerik",
    "syrerike": "syrerik",
    "syrerikes": "syrerik",
    "syrerikheten": "syrerikhet",
    "syrerikhetens": "syrerikhet",
    "syrerikhets": "syrerikhet",
    "syreriks": "syrerik",
    "syrerikt": "syrerik",
    "syrerikts": "syrerik",
    "syres": "syre",
    "syret": "syre",
    "syretransporten": "syretransport",
    "syretransportens": "syretransport",
    "syretransporter": "syretransport",
    "syretransporterna": "syretransport",
    "syretransporternas": "syretransport",
    "syretransporters": "syretransport",
    "syretransports": "syretransport",
    "syrets": "syre",
    "syrgasen": "syrgas",
    "syrgasens": "syrgas",
    "syrgasmasken": "syrgasmask",
    "syrgasmaskens": "syrgasmask",
    "syrgasmasker": "syrgasmask",
    "syrgasmaskerna": "syrgasmask",
    "syrgasmaskernas": "syrgasmask",
    "syrgasmaskers": "syrgasmask",
    "syrgasmasks": "syrgasmask",
    "syrgasmolekylen": "syrgasmolekyl",
    "syrgasmolekylens": "syrgasmolekyl",
    "syrgasmolekyler": "syrgasmolekyl",
    "syrgasmolekylerna": "syrgasmolekyl",
    "syrgasmolekylernas": "syrgasmolekyl",
    "syrgasmolekylers": "syrgasmolekyl",
    "syrgasmolekyls": "syrgasmolekyl",
    "syrgastuben": "syrgastub",
    "syrgastubens": "syrgastub",
    "syrgastuber": "syrgastub",
    "syrgastuberna": "syrgastub",
    "syrgastubernas": "syrgastub",
    "syrgastubers": "syrgastub",
    "syrgastubs": "syrgastub",
    "syriern": "syrier",
    "syrierna": "syrier",
    "syriernas": "syrier",
    "syrierns": "syrier",
    "syriers": "syrier",
    "syrinxar": "syrinx",
    "syrinxarna": "syrinx",
    "syrinxarnas": "syrinx",
    "syrinxars": "syrinx",
    "syrinxen": "syrinx",
    "syrinxens": "syrinx",
    "syrisk": "syriska",
    "syriska": "syrisk",
    "syriskan": "syriska",
    "syriskans": "syriska",
    "syriskare": "syrisk",
    "syriskares": "syrisk",
    "syriskas": "syriska",
    "syriskast": "syrisk",
    "syriskaste": "syrisk",
    "syriskastes": "syrisk",
    "syriskasts": "syrisk",
    "syriske": "syriska",
    "syriskes": "syrisk",
    "syriskor": "syriska",
    "syriskorna": "syriska",
    "syriskornas": "syriska",
    "syriskors": "syriska",
    "syrisks": "syrisk",
    "syriskt": "syrisk",
    "syriskts": "syrisk",
    "syrliga": "syrlig",
    "syrligare": "syrlig",
    "syrligares": "syrlig",
    "syrligas": "syrlig",
    "syrligast": "syrlig",
    "syrligaste": "syrlig",
    "syrligastes": "syrlig",
    "syrligasts": "syrlig",
    "syrlige": "syrlig",
    "syrliges": "syrlig",
    "syrligheten": "syrlighet",
    "syrlighetens": "syrlighet",
    "syrligheter": "syrlighet",
    "syrligheterna": "syrlighet",
    "syrligheternas": "syrlighet",
    "syrligheters": "syrlighet",
    "syrlighets": "syrlighet",
    "syrligs": "syrlig",
    "syrligt": "syrlig",
    "syrligts": "syrlig",
    "syror": "syra",
    "syrorna": "syra",
    "syrornas": "syra",
    "syrors": "syra",
    "syrran": "syrra",
    "syrrans": "syrra",
    "syrras": "syrra",
    "syrror": "syrra",
    "syrrorna": "syrra",
    "syrrornas": "syrra",
    "syrrors": "syrra",
    "syrs": "syrsa",
    "syrsan": "syrsa",
    "syrsans": "syrsa",
    "syrsas": "syrsa",
    "syrsatt": "syrsätta",
    "syrsatta": "syrsätta",
    "syrsattas": "syrsätta",
    "syrsatte": "syrsätta",
    "syrsattes": "syrsätta",
    "syrsatts": "syrsätta",
    "syrse": "syrsa",
    "syrsor": "syrsa",
    "syrsorna": "syrsa",
    "syrsornas": "syrsa",
    "syrsors": "syrsa",
    "syrsätt": "syrsätta",
    "syrsättande": "syrsätta",
    "syrsättanden": "syrsättande",
    "syrsättandena": "syrsättande",
    "syrsättandenas": "syrsättande",
    "syrsättandens": "syrsättande",
    "syrsättandes": "syrsättande",
    "syrsättandet": "syrsättande",
    "syrsättandets": "syrsättande",
    "syrsättas": "syrsätta",
    "syrsätter": "syrsätta",
    "syrsättes": "syrsätta",
    "syrsätts": "syrsätta",
    "syrtuten": "syrtut",
    "syrtutens": "syrtut",
    "syrtuter": "syrtut",
    "syrtuterna": "syrtut",
    "syrtuternas": "syrtut",
    "syrtuters": "syrtut",
    "syrtuts": "syrtut",
    "sys": "sy",
    "sysilkes": "sysilke",
    "sysilket": "sysilke",
    "sysilkets": "sysilke",
    "syskonbarnen": "syskonbarn",
    "syskonbarnens": "syskonbarn",
    "syskonbarnet": "syskonbarn",
    "syskonbarnets": "syskonbarn",
    "syskonbarns": "syskonbarn",
    "syskonbäddar": "syskonbädd",
    "syskonbäddarna": "syskonbädd",
    "syskonbäddarnas": "syskonbädd",
    "syskonbäddars": "syskonbädd",
    "syskonbädden": "syskonbädd",
    "syskonbäddens": "syskonbädd",
    "syskonbädds": "syskonbädd",
    "syskonen": "syskon",
    "syskonens": "syskon",
    "syskonet": "syskon",
    "syskonets": "syskon",
    "syskongruppen": "syskongrupp",
    "syskongruppens": "syskongrupp",
    "syskongrupper": "syskongrupp",
    "syskongrupperna": "syskongrupp",
    "syskongruppernas": "syskongrupp",
    "syskongruppers": "syskongrupp",
    "syskongrupps": "syskongrupp",
    "syskonkärlekar": "syskonkärlek",
    "syskonkärlekarna": "syskonkärlek",
    "syskonkärlekarnas": "syskonkärlek",
    "syskonkärlekars": "syskonkärlek",
    "syskonkärleken": "syskonkärlek",
    "syskonkärlekens": "syskonkärlek",
    "syskonkärleks": "syskonkärlek",
    "syskonliga": "syskonlig",
    "syskonligare": "syskonlig",
    "syskonligares": "syskonlig",
    "syskonligas": "syskonlig",
    "syskonligast": "syskonlig",
    "syskonligaste": "syskonlig",
    "syskonligastes": "syskonlig",
    "syskonligasts": "syskonlig",
    "syskonlige": "syskonlig",
    "syskonliges": "syskonlig",
    "syskonligs": "syskonlig",
    "syskonligt": "syskonlig",
    "syskonligts": "syskonlig",
    "syskons": "syskon",
    "syskonskapet": "syskonskap",
    "syskonskapets": "syskonskap",
    "syskonskaps": "syskonskap",
    "syskonskar": "syskonskara",
    "syskonskaran": "syskonskara",
    "syskonskarans": "syskonskara",
    "syskonskaras": "syskonskara",
    "syskonskare": "syskonskara",
    "syskonskaror": "syskonskara",
    "syskonskarorna": "syskonskara",
    "syskonskarornas": "syskonskara",
    "syskonskarors": "syskonskara",
    "syskonskars": "syskonskara",
    "syskontyckes": "syskontycke",
    "syskontycket": "syskontycke",
    "syskontyckets": "syskontycke",
    "syskonäktenskapen": "syskonäktenskap",
    "syskonäktenskapens": "syskonäktenskap",
    "syskonäktenskapet": "syskonäktenskap",
    "syskonäktenskapets": "syskonäktenskap",
    "syskonäktenskaps": "syskonäktenskap",
    "sysselsatt": "sysselsätta",
    "sysselsatta": "sysselsätta",
    "sysselsattare": "sysselsatt",
    "sysselsattares": "sysselsatt",
    "sysselsattas": "sysselsätta",
    "sysselsattast": "sysselsatt",
    "sysselsattaste": "sysselsatt",
    "sysselsattastes": "sysselsatt",
    "sysselsattasts": "sysselsatt",
    "sysselsatte": "sysselsätta",
    "sysselsattes": "sysselsätta",
    "sysselsatts": "sysselsätta",
    "sysselsätt": "sysselsätta",
    "sysselsättande": "sysselsätta",
    "sysselsättanden": "sysselsättande",
    "sysselsättandena": "sysselsättande",
    "sysselsättandenas": "sysselsättande",
    "sysselsättandens": "sysselsättande",
    "sysselsättandes": "sysselsättande",
    "sysselsättandet": "sysselsättande",
    "sysselsättandets": "sysselsättande",
    "sysselsättas": "sysselsätta",
    "sysselsätter": "sysselsätta",
    "sysselsättes": "sysselsätta",
    "sysselsättningar": "sysselsättning",
    "sysselsättningarna": "sysselsättning",
    "sysselsättningarnas": "sysselsättning",
    "sysselsättningars": "sysselsättning",
    "sysselsättningen": "sysselsättning",
    "sysselsättningens": "sysselsättning",
    "sysselsättnings": "sysselsättning",
    "sysselsättningsgraden": "sysselsättningsgrad",
    "sysselsättningsgradens": "sysselsättningsgrad",
    "sysselsättningsgrader": "sysselsättningsgrad",
    "sysselsättningsgraderna": "sysselsättningsgrad",
    "sysselsättningsgradernas": "sysselsättningsgrad",
    "sysselsättningsgraders": "sysselsättningsgrad",
    "sysselsättningsgrads": "sysselsättningsgrad",
    "sysselsättningsmässiga": "sysselsättningsmässig",
    "sysselsättningsmässigare": "sysselsättningsmässig",
    "sysselsättningsmässigares": "sysselsättningsmässig",
    "sysselsättningsmässigas": "sysselsättningsmässig",
    "sysselsättningsmässigast": "sysselsättningsmässig",
    "sysselsättningsmässigaste": "sysselsättningsmässig",
    "sysselsättningsmässigastes": "sysselsättningsmässig",
    "sysselsättningsmässigasts": "sysselsättningsmässig",
    "sysselsättningsmässige": "sysselsättningsmässig",
    "sysselsättningsmässiges": "sysselsättningsmässig",
    "sysselsättningsmässigs": "sysselsättningsmässig",
    "sysselsättningsmässigt": "sysselsättningsmässig",
    "sysselsättningsmässigts": "sysselsättningsmässig",
    "sysselsättningspolitiken": "sysselsättningspolitik",
    "sysselsättningspolitikens": "sysselsättningspolitik",
    "sysselsättningspolitiks": "sysselsättningspolitik",
    "sysselsättningspolitiska": "sysselsättningspolitisk",
    "sysselsättningspolitiskas": "sysselsättningspolitisk",
    "sysselsättningspolitiske": "sysselsättningspolitisk",
    "sysselsättningspolitiskes": "sysselsättningspolitisk",
    "sysselsättningspolitisks": "sysselsättningspolitisk",
    "sysselsättningspolitiskt": "sysselsättningspolitisk",
    "sysselsättningspolitiskts": "sysselsättningspolitisk",
    "sysselsätts": "sysselsätta",
    "syssl": "syssla",
    "sysslade": "syssla",
    "sysslades": "syssla",
    "sysslan": "syssla",
    "sysslande": "syssla",
    "sysslanden": "sysslande",
    "sysslandena": "sysslande",
    "sysslandenas": "sysslande",
    "sysslandens": "sysslande",
    "sysslandes": "sysslande",
    "sysslandet": "sysslande",
    "sysslandets": "sysslande",
    "sysslans": "syssla",
    "sysslar": "syssla",
    "sysslas": "syssla",
    "sysslat": "syssla",
    "sysslats": "syssla",
    "syssle": "syssla",
    "sysslingar": "syssling",
    "sysslingarna": "syssling",
    "sysslingarnas": "syssling",
    "sysslingars": "syssling",
    "sysslingen": "syssling",
    "sysslingens": "syssling",
    "sysslings": "syssling",
    "sysslo": "syssla",
    "sysslolösa": "sysslolös",
    "sysslolösare": "sysslolös",
    "sysslolösares": "sysslolös",
    "sysslolösas": "sysslolös",
    "sysslolösast": "sysslolös",
    "sysslolösaste": "sysslolös",
    "sysslolösastes": "sysslolös",
    "sysslolösasts": "sysslolös",
    "sysslolöse": "sysslolös",
    "sysslolöses": "sysslolös",
    "sysslolösheten": "sysslolöshet",
    "sysslolöshetens": "sysslolöshet",
    "sysslolöshets": "sysslolöshet",
    "sysslolöst": "sysslolös",
    "sysslolösts": "sysslolös",
    "sysslomannen": "syssloman",
    "sysslomannens": "syssloman",
    "sysslomans": "syssloman",
    "sysslomän": "syssloman",
    "sysslomännen": "syssloman",
    "sysslomännens": "syssloman",
    "sysslomäns": "syssloman",
    "sysslor": "syssla",
    "sysslorna": "syssla",
    "sysslornas": "syssla",
    "sysslors": "syssla",
    "systemanalysen": "systemanalys",
    "systemanalysens": "systemanalys",
    "systematiken": "systematik",
    "systematikens": "systematik",
    "systematiks": "systematik",
    "systematiserad": "systematisera",
    "systematiserade": "systematisera",
    "systematiserades": "systematisera",
    "systematiserads": "systematisera",
    "systematiserande": "systematisera",
    "systematiseranden": "systematiserande",
    "systematiserandena": "systematiserande",
    "systematiserandenas": "systematiserande",
    "systematiserandens": "systematiserande",
    "systematiserandes": "systematiserande",
    "systematiserandet": "systematiserande",
    "systematiserandets": "systematiserande",
    "systematiserar": "systematisera",
    "systematiseras": "systematisera",
    "systematiserat": "systematisera",
    "systematiserats": "systematisera",
    "systematiserbara": "systematiserbar",
    "systematiserbarare": "systematiserbar",
    "systematiserbarares": "systematiserbar",
    "systematiserbaras": "systematiserbar",
    "systematiserbarast": "systematiserbar",
    "systematiserbaraste": "systematiserbar",
    "systematiserbarastes": "systematiserbar",
    "systematiserbarasts": "systematiserbar",
    "systematiserbare": "systematiserbar",
    "systematiserbares": "systematiserbar",
    "systematiserbarheten": "systematiserbarhet",
    "systematiserbarhetens": "systematiserbarhet",
    "systematiserbarhets": "systematiserbarhet",
    "systematiserbars": "systematiserbar",
    "systematiserbart": "systematiserbar",
    "systematiserbarts": "systematiserbar",
    "systematiseringar": "systematisering",
    "systematiseringarna": "systematisering",
    "systematiseringarnas": "systematisering",
    "systematiseringars": "systematisering",
    "systematiseringen": "systematisering",
    "systematiseringens": "systematisering",
    "systematiserings": "systematisering",
    "systematiska": "systematisk",
    "systematiskare": "systematisk",
    "systematiskares": "systematisk",
    "systematiskas": "systematisk",
    "systematiskast": "systematisk",
    "systematiskaste": "systematisk",
    "systematiskastes": "systematisk",
    "systematiskasts": "systematisk",
    "systematiske": "systematisk",
    "systematiskes": "systematisk",
    "systematisks": "systematisk",
    "systematiskt": "systematisk",
    "systematiskts": "systematisk",
    "systembolagen": "systembolag",
    "systembolagens": "systembolag",
    "systembolaget": "systembolag",
    "systembolagets": "systembolag",
    "systembolags": "systembolag",
    "systemen": "system",
    "systemens": "system",
    "systemerade": "systemera",
    "systemerades": "systemera",
    "systemerande": "systemera",
    "systemeranden": "systemerande",
    "systemerandena": "systemerande",
    "systemerandenas": "systemerande",
    "systemerandens": "systemerande",
    "systemerandes": "systemerande",
    "systemerandet": "systemerande",
    "systemerandets": "systemerande",
    "systemerar": "systemerare",
    "systemeraren": "systemerare",
    "systemerarens": "systemerare",
    "systemerares": "systemerare",
    "systemerarna": "systemerare",
    "systemerarnas": "systemerare",
    "systemeras": "systemera",
    "systemerat": "systemera",
    "systemerats": "systemera",
    "systemeringen": "systemering",
    "systemeringens": "systemering",
    "systemerings": "systemering",
    "systemet": "system",
    "systemets": "system",
    "systemkameran": "systemkamera",
    "systemkamerans": "systemkamera",
    "systemkameras": "systemkamera",
    "systemkameror": "systemkamera",
    "systemkamerorna": "systemkamera",
    "systemkamerornas": "systemkamera",
    "systemkamerors": "systemkamera",
    "systemköer": "systemkö",
    "systemköerna": "systemkö",
    "systemköernas": "systemkö",
    "systemköers": "systemkö",
    "systemkön": "systemkö",
    "systemköns": "systemkö",
    "systemkös": "systemkö",
    "systemmannen": "systemman",
    "systemmannens": "systemman",
    "systemmans": "systemman",
    "systemmän": "systemman",
    "systemmännen": "systemman",
    "systemmännens": "systemman",
    "systemmäns": "systemman",
    "systemmässiga": "systemmässig",
    "systemmässigare": "systemmässig",
    "systemmässigares": "systemmässig",
    "systemmässigas": "systemmässig",
    "systemmässigast": "systemmässig",
    "systemmässigaste": "systemmässig",
    "systemmässigastes": "systemmässig",
    "systemmässigasts": "systemmässig",
    "systemmässige": "systemmässig",
    "systemmässiges": "systemmässig",
    "systemmässigs": "systemmässig",
    "systemmässigt": "systemmässig",
    "systemmässigts": "systemmässig",
    "systems": "system",
    "systemskiften": "systemskifte",
    "systemskiftena": "systemskifte",
    "systemskiftenas": "systemskifte",
    "systemskiftens": "systemskifte",
    "systemskiftes": "systemskifte",
    "systemskiftet": "systemskifte",
    "systemskiftets": "systemskifte",
    "systemutvecklar": "systemutvecklare",
    "systemutvecklaren": "systemutvecklare",
    "systemutvecklarens": "systemutvecklare",
    "systemutvecklares": "systemutvecklare",
    "systemutvecklarna": "systemutvecklare",
    "systemutvecklarnas": "systemutvecklare",
    "systerbarnen": "systerbarn",
    "systerbarnens": "systerbarn",
    "systerbarnet": "systerbarn",
    "systerbarnets": "systerbarn",
    "systerbarns": "systerbarn",
    "systerdottern": "systerdotter",
    "systerdotterns": "systerdotter",
    "systerdotters": "systerdotter",
    "systerdöttrar": "systerdotter",
    "systerdöttrarna": "systerdotter",
    "systerdöttrarnas": "systerdotter",
    "systerdöttrars": "systerdotter",
    "systerfartygen": "systerfartyg",
    "systerfartygens": "systerfartyg",
    "systerfartyget": "systerfartyg",
    "systerfartygets": "systerfartyg",
    "systerfartygs": "systerfartyg",
    "systern": "syster",
    "systerns": "syster",
    "systers": "syster",
    "systerskapet": "systerskap",
    "systerskapets": "systerskap",
    "systerskaps": "systerskap",
    "systersonen": "systerson",
    "systersonens": "systerson",
    "systersons": "systerson",
    "systersöner": "systerson",
    "systersönerna": "systerson",
    "systersönernas": "systerson",
    "systersöners": "systerson",
    "systolen": "systole",
    "systolens": "systole",
    "systoles": "systole",
    "systoliska": "systolisk",
    "systoliskare": "systolisk",
    "systoliskares": "systolisk",
    "systoliskas": "systolisk",
    "systoliskast": "systolisk",
    "systoliskaste": "systolisk",
    "systoliskastes": "systolisk",
    "systoliskasts": "systolisk",
    "systoliske": "systolisk",
    "systoliskes": "systolisk",
    "systolisks": "systolisk",
    "systoliskt": "systolisk",
    "systoliskts": "systolisk",
    "systrar": "syster",
    "systrarna": "syster",
    "systrarnas": "syster",
    "systrars": "syster",
    "sytrådar": "sytråd",
    "sytrådarna": "sytråd",
    "sytrådarnas": "sytråd",
    "sytrådars": "sytråd",
    "sytråden": "sytråd",
    "sytrådens": "sytråd",
    "sytråds": "sytråd",
    "sytt": "sy",
    "sytts": "sy",
    "säck": "säcka",
    "säckad": "säcka",
    "säckade": "säcka",
    "säckades": "säcka",
    "säckads": "säcka",
    "säckande": "säcka",
    "säckanden": "säckande",
    "säckandena": "säckande",
    "säckandenas": "säckande",
    "säckandens": "säckande",
    "säckandes": "säckande",
    "säckandet": "säckande",
    "säckandets": "säckande",
    "säckar": "säcka",
    "säckarna": "säck",
    "säckarnas": "säck",
    "säckars": "säck",
    "säckas": "säcka",
    "säckat": "säcka",
    "säckats": "säcka",
    "säcken": "säck",
    "säckens": "säck",
    "säckiga": "säckig",
    "säckigare": "säckig",
    "säckigares": "säckig",
    "säckigas": "säckig",
    "säckigast": "säckig",
    "säckigaste": "säckig",
    "säckigastes": "säckig",
    "säckigasts": "säckig",
    "säckige": "säckig",
    "säckiges": "säckig",
    "säckigheten": "säckighet",
    "säckighetens": "säckighet",
    "säckighets": "säckighet",
    "säckigs": "säckig",
    "säckigt": "säckig",
    "säckigts": "säckig",
    "säckkärr": "säckkärra",
    "säckkärran": "säckkärra",
    "säckkärrans": "säckkärra",
    "säckkärras": "säckkärra",
    "säckkärre": "säckkärra",
    "säckkärror": "säckkärra",
    "säckkärrorna": "säckkärra",
    "säckkärrornas": "säckkärra",
    "säckkärrors": "säckkärra",
    "säckkärrs": "säckkärra",
    "säcklöpningar": "säcklöpning",
    "säcklöpningarna": "säcklöpning",
    "säcklöpningarnas": "säcklöpning",
    "säcklöpningars": "säcklöpning",
    "säcklöpningen": "säcklöpning",
    "säcklöpningens": "säcklöpning",
    "säcklöpnings": "säcklöpning",
    "säckpip": "säckpipa",
    "säckpipan": "säckpipa",
    "säckpipans": "säckpipa",
    "säckpipas": "säckpipa",
    "säckpipe": "säckpipa",
    "säckpipor": "säckpipa",
    "säckpiporna": "säckpipa",
    "säckpipornas": "säckpipa",
    "säckpipors": "säckpipa",
    "säckpips": "säckpipa",
    "säcks": "säck",
    "säcksvampar": "säcksvamp",
    "säcksvamparna": "säcksvamp",
    "säcksvamparnas": "säcksvamp",
    "säcksvampars": "säcksvamp",
    "säcksvampen": "säcksvamp",
    "säcksvampens": "säcksvamp",
    "säcksvamps": "säcksvamp",
    "säckväven": "säckväv",
    "säckvävens": "säckväv",
    "säckvävs": "säckväv",
    "säden": "säde",
    "sädena": "säde",
    "sädenas": "säde",
    "sädens": "säde",
    "sädes": "säde",
    "sädesblås": "sädesblåsa",
    "sädesblåsan": "sädesblåsa",
    "sädesblåsans": "sädesblåsa",
    "sädesblåsas": "sädesblåsa",
    "sädesblåse": "sädesblåsa",
    "sädesblåsor": "sädesblåsa",
    "sädesblåsorna": "sädesblåsa",
    "sädesblåsornas": "sädesblåsa",
    "sädesblåsors": "sädesblåsa",
    "sädesbruket": "sädesbruk",
    "sädesbrukets": "sädesbruk",
    "sädesbruks": "sädesbruk",
    "sädescellen": "sädescell",
    "sädescellens": "sädescell",
    "sädesceller": "sädescell",
    "sädescellerna": "sädescell",
    "sädescellernas": "sädescell",
    "sädescellers": "sädescell",
    "sädescells": "sädescell",
    "sädeskärn": "sädeskärna",
    "sädeskärnan": "sädeskärna",
    "sädeskärnans": "sädeskärna",
    "sädeskärnas": "sädeskärna",
    "sädeskärne": "sädeskärna",
    "sädeskärnor": "sädeskärna",
    "sädeskärnorna": "sädeskärna",
    "sädeskärnornas": "sädeskärna",
    "sädeskärnors": "sädeskärna",
    "sädeskärns": "sädeskärna",
    "sädeskärv": "sädeskärve",
    "sädeskärvar": "sädeskärve",
    "sädeskärvarna": "sädeskärve",
    "sädeskärvarnas": "sädeskärve",
    "sädeskärvars": "sädeskärve",
    "sädeskärven": "sädeskärve",
    "sädeskärvens": "sädeskärve",
    "sädeskärves": "sädeskärve",
    "sädeskärvs": "sädeskärve",
    "sädesledar": "sädesledare",
    "sädesledaren": "sädesledare",
    "sädesledarens": "sädesledare",
    "sädesledares": "sädesledare",
    "sädesledarna": "sädesledare",
    "sädesledarnas": "sädesledare",
    "sädesskylar": "sädesskyl",
    "sädesskylarna": "sädesskyl",
    "sädesskylarnas": "sädesskyl",
    "sädesskylars": "sädesskyl",
    "sädesskylen": "sädesskyl",
    "sädesskylens": "sädesskyl",
    "sädesskyls": "sädesskyl",
    "sädesslagen": "sädesslag",
    "sädesslagens": "sädesslag",
    "sädesslaget": "sädesslag",
    "sädesslagets": "sädesslag",
    "sädesslags": "sädesslag",
    "sädestorkar": "sädestork",
    "sädestorkarna": "sädestork",
    "sädestorkarnas": "sädestork",
    "sädestorkars": "sädestork",
    "sädestorken": "sädestork",
    "sädestorkens": "sädestork",
    "sädestorks": "sädestork",
    "sädesuttömningar": "sädesuttömning",
    "sädesuttömningarna": "sädesuttömning",
    "sädesuttömningarnas": "sädesuttömning",
    "sädesuttömningars": "sädesuttömning",
    "sädesuttömningen": "sädesuttömning",
    "sädesuttömningens": "sädesuttömning",
    "sädesuttömnings": "sädesuttömning",
    "sädesvätskan": "sädesvätska",
    "sädesvätskans": "sädesvätska",
    "sädesvätskas": "sädesvätska",
    "sädesvätske": "sädesvätska",
    "sädesärl": "sädesärla",
    "sädesärlan": "sädesärla",
    "sädesärlans": "sädesärla",
    "sädesärlas": "sädesärla",
    "sädesärle": "sädesärla",
    "sädesärlor": "sädesärla",
    "sädesärlorna": "sädesärla",
    "sädesärlornas": "sädesärla",
    "sädesärlors": "sädesärla",
    "sädesärls": "sädesärla",
    "sädet": "säde",
    "sädets": "säde",
    "sädgäss": "sädgås",
    "sädgässen": "sädgås",
    "sädgässens": "sädgås",
    "sädgåsen": "sädgås",
    "sädgåsens": "sädgås",
    "säds": "säde",
    "säg": "säga",
    "sägande": "säga",
    "säganden": "sägande",
    "sägandena": "sägande",
    "sägandenas": "sägande",
    "sägandens": "sägande",
    "sägandes": "sägande",
    "sägandet": "sägande",
    "sägandets": "sägande",
    "sägas": "säga",
    "sägenn": "sägen",
    "sägenns": "sägen",
    "sägenomspunna": "sägenomspunnen",
    "sägenomspunnare": "sägenomspunnen",
    "sägenomspunnares": "sägenomspunnen",
    "sägenomspunnas": "sägenomspunnen",
    "sägenomspunnast": "sägenomspunnen",
    "sägenomspunnaste": "sägenomspunnen",
    "sägenomspunnastes": "sägenomspunnen",
    "sägenomspunnasts": "sägenomspunnen",
    "sägenomspunne": "sägenomspunnen",
    "sägenomspunnens": "sägenomspunnen",
    "sägenomspunnes": "sägenomspunnen",
    "sägenomspunnet": "sägenomspunnen",
    "sägenomspunnets": "sägenomspunnen",
    "sägenomsusade": "sägenomsusad",
    "sägenomsusades": "sägenomsusad",
    "sägenomsusads": "sägenomsusad",
    "sägenomsusat": "sägenomsusad",
    "sägenomsusats": "sägenomsusad",
    "sägens": "sägen",
    "säger": "säga",
    "säges": "säga",
    "sägner": "sägen",
    "sägnerna": "sägen",
    "sägnernas": "sägen",
    "sägners": "sägen",
    "sägs": "säga",
    "säj": "säga",
    "säja": "säga",
    "säjande": "säga",
    "säjandes": "säga",
    "säjas": "säga",
    "säjer": "säga",
    "säjes": "säga",
    "säjs": "säga",
    "säkerheten": "säkerhet",
    "säkerhetens": "säkerhet",
    "säkerheter": "säkerhet",
    "säkerheterna": "säkerhet",
    "säkerheternas": "säkerhet",
    "säkerheters": "säkerhet",
    "säkerhets": "säkerhet",
    "säkerhetsanordningar": "säkerhetsanordning",
    "säkerhetsanordningarna": "säkerhetsanordning",
    "säkerhetsanordningarnas": "säkerhetsanordning",
    "säkerhetsanordningars": "säkerhetsanordning",
    "säkerhetsanordningen": "säkerhetsanordning",
    "säkerhetsanordningens": "säkerhetsanordning",
    "säkerhetsanordnings": "säkerhetsanordning",
    "säkerhetsarbeten": "säkerhetsarbete",
    "säkerhetsarbetena": "säkerhetsarbete",
    "säkerhetsarbetenas": "säkerhetsarbete",
    "säkerhetsarbetens": "säkerhetsarbete",
    "säkerhetsarbetes": "säkerhetsarbete",
    "säkerhetsarbetet": "säkerhetsarbete",
    "säkerhetsarbetets": "säkerhetsarbete",
    "säkerhetsarbets": "säkerhetsarbete",
    "säkerhetsarrangemangen": "säkerhetsarrangemang",
    "säkerhetsarrangemangens": "säkerhetsarrangemang",
    "säkerhetsarrangemanget": "säkerhetsarrangemang",
    "säkerhetsarrangemangets": "säkerhetsarrangemang",
    "säkerhetsarrangemangs": "säkerhetsarrangemang",
    "säkerhetsbestämmelsen": "säkerhetsbestämmelse",
    "säkerhetsbestämmelsens": "säkerhetsbestämmelse",
    "säkerhetsbestämmelser": "säkerhetsbestämmelse",
    "säkerhetsbestämmelserna": "säkerhetsbestämmelse",
    "säkerhetsbestämmelsernas": "säkerhetsbestämmelse",
    "säkerhetsbestämmelsers": "säkerhetsbestämmelse",
    "säkerhetsbestämmelses": "säkerhetsbestämmelse",
    "säkerhetsbromsar": "säkerhetsbroms",
    "säkerhetsbromsarna": "säkerhetsbroms",
    "säkerhetsbromsarnas": "säkerhetsbroms",
    "säkerhetsbromsars": "säkerhetsbroms",
    "säkerhetsbromsen": "säkerhetsbroms",
    "säkerhetsbromsens": "säkerhetsbroms",
    "säkerhetsbrytar": "säkerhetsbrytare",
    "säkerhetsbrytaren": "säkerhetsbrytare",
    "säkerhetsbrytarens": "säkerhetsbrytare",
    "säkerhetsbrytares": "säkerhetsbrytare",
    "säkerhetsbrytarna": "säkerhetsbrytare",
    "säkerhetsbrytarnas": "säkerhetsbrytare",
    "säkerhetsbälten": "säkerhetsbälte",
    "säkerhetsbältena": "säkerhetsbälte",
    "säkerhetsbältenas": "säkerhetsbälte",
    "säkerhetsbältens": "säkerhetsbälte",
    "säkerhetsbältes": "säkerhetsbälte",
    "säkerhetsbältet": "säkerhetsbälte",
    "säkerhetsbältets": "säkerhetsbälte",
    "säkerhetschefen": "säkerhetschef",
    "säkerhetschefens": "säkerhetschef",
    "säkerhetschefer": "säkerhetschef",
    "säkerhetscheferna": "säkerhetschef",
    "säkerhetschefernas": "säkerhetschef",
    "säkerhetschefers": "säkerhetschef",
    "säkerhetschefs": "säkerhetschef",
    "säkerhetsfilosofien": "säkerhetsfilosofi",
    "säkerhetsfilosofiens": "säkerhetsfilosofi",
    "säkerhetsfilosofier": "säkerhetsfilosofi",
    "säkerhetsfilosofierna": "säkerhetsfilosofi",
    "säkerhetsfilosofiernas": "säkerhetsfilosofi",
    "säkerhetsfilosofiers": "säkerhetsfilosofi",
    "säkerhetsfilosofin": "säkerhetsfilosofi",
    "säkerhetsfilosofins": "säkerhetsfilosofi",
    "säkerhetsfilosofis": "säkerhetsfilosofi",
    "säkerhetsföreskriften": "säkerhetsföreskrift",
    "säkerhetsföreskriftens": "säkerhetsföreskrift",
    "säkerhetsföreskrifter": "säkerhetsföreskrift",
    "säkerhetsföreskrifterna": "säkerhetsföreskrift",
    "säkerhetsföreskrifternas": "säkerhetsföreskrift",
    "säkerhetsföreskrifters": "säkerhetsföreskrift",
    "säkerhetsföreskrifts": "säkerhetsföreskrift",
    "säkerhetsgreppen": "säkerhetsgrepp",
    "säkerhetsgreppens": "säkerhetsgrepp",
    "säkerhetsgreppet": "säkerhetsgrepp",
    "säkerhetsgreppets": "säkerhetsgrepp",
    "säkerhetsgrepps": "säkerhetsgrepp",
    "säkerhetskedjan": "säkerhetskedja",
    "säkerhetskedjans": "säkerhetskedja",
    "säkerhetskedjas": "säkerhetskedja",
    "säkerhetskedje": "säkerhetskedja",
    "säkerhetskedjor": "säkerhetskedja",
    "säkerhetskedjorna": "säkerhetskedja",
    "säkerhetskedjornas": "säkerhetskedja",
    "säkerhetskedjors": "säkerhetskedja",
    "säkerhetskontrollen": "säkerhetskontroll",
    "säkerhetskontrollens": "säkerhetskontroll",
    "säkerhetskontroller": "säkerhetskontroll",
    "säkerhetskontrollerna": "säkerhetskontroll",
    "säkerhetskontrollernas": "säkerhetskontroll",
    "säkerhetskontrollers": "säkerhetskontroll",
    "säkerhetskontrolls": "säkerhetskontroll",
    "säkerhetskrokar": "säkerhetskrok",
    "säkerhetskrokarna": "säkerhetskrok",
    "säkerhetskrokarnas": "säkerhetskrok",
    "säkerhetskrokars": "säkerhetskrok",
    "säkerhetskroken": "säkerhetskrok",
    "säkerhetskrokens": "säkerhetskrok",
    "säkerhetskroks": "säkerhetskrok",
    "säkerhetslamp": "säkerhetslampa",
    "säkerhetslampan": "säkerhetslampa",
    "säkerhetslampans": "säkerhetslampa",
    "säkerhetslampas": "säkerhetslampa",
    "säkerhetslampe": "säkerhetslampa",
    "säkerhetslampor": "säkerhetslampa",
    "säkerhetslamporna": "säkerhetslampa",
    "säkerhetslampornas": "säkerhetslampa",
    "säkerhetslampors": "säkerhetslampa",
    "säkerhetslamps": "säkerhetslampa",
    "säkerhetslin": "säkerhetslina",
    "säkerhetslinan": "säkerhetslina",
    "säkerhetslinans": "säkerhetslina",
    "säkerhetslinas": "säkerhetslina",
    "säkerhetsline": "säkerhetslina",
    "säkerhetslinor": "säkerhetslina",
    "säkerhetslinorna": "säkerhetslina",
    "säkerhetslinornas": "säkerhetslina",
    "säkerhetslinors": "säkerhetslina",
    "säkerhetslins": "säkerhetslina",
    "säkerhetslägen": "säkerhetsläge",
    "säkerhetslägena": "säkerhetsläge",
    "säkerhetslägenas": "säkerhetsläge",
    "säkerhetslägens": "säkerhetsläge",
    "säkerhetsläges": "säkerhetsläge",
    "säkerhetsläget": "säkerhetsläge",
    "säkerhetslägets": "säkerhetsläge",
    "säkerhetsmannen": "säkerhetsman",
    "säkerhetsmannens": "säkerhetsman",
    "säkerhetsmans": "säkerhetsman",
    "säkerhetsmassan": "säkerhetsmassa",
    "säkerhetsmassans": "säkerhetsmassa",
    "säkerhetsmassas": "säkerhetsmassa",
    "säkerhetsmasse": "säkerhetsmassa",
    "säkerhetsmassor": "säkerhetsmassa",
    "säkerhetsmassorna": "säkerhetsmassa",
    "säkerhetsmassornas": "säkerhetsmassa",
    "säkerhetsmassors": "säkerhetsmassa",
    "säkerhetsmän": "säkerhetsman",
    "säkerhetsmännen": "säkerhetsman",
    "säkerhetsmännens": "säkerhetsman",
    "säkerhetsmäns": "säkerhetsman",
    "säkerhetsmässiga": "säkerhetsmässig",
    "säkerhetsmässigare": "säkerhetsmässig",
    "säkerhetsmässigares": "säkerhetsmässig",
    "säkerhetsmässigas": "säkerhetsmässig",
    "säkerhetsmässigast": "säkerhetsmässig",
    "säkerhetsmässigaste": "säkerhetsmässig",
    "säkerhetsmässigastes": "säkerhetsmässig",
    "säkerhetsmässigasts": "säkerhetsmässig",
    "säkerhetsmässige": "säkerhetsmässig",
    "säkerhetsmässiges": "säkerhetsmässig",
    "säkerhetsmässigs": "säkerhetsmässig",
    "säkerhetsmässigt": "säkerhetsmässig",
    "säkerhetsmässigts": "säkerhetsmässig",
    "säkerhetsnålar": "säkerhetsnål",
    "säkerhetsnålarna": "säkerhetsnål",
    "säkerhetsnålarnas": "säkerhetsnål",
    "säkerhetsnålars": "säkerhetsnål",
    "säkerhetsnålen": "säkerhetsnål",
    "säkerhetsnålens": "säkerhetsnål",
    "säkerhetsnåls": "säkerhetsnål",
    "säkerhetspolisen": "säkerhetspolis",
    "säkerhetspolisens": "säkerhetspolis",
    "säkerhetspoliser": "säkerhetspolis",
    "säkerhetspoliserna": "säkerhetspolis",
    "säkerhetspolisernas": "säkerhetspolis",
    "säkerhetspolisers": "säkerhetspolis",
    "säkerhetspolitiken": "säkerhetspolitik",
    "säkerhetspolitikens": "säkerhetspolitik",
    "säkerhetspolitiks": "säkerhetspolitik",
    "säkerhetspolitiska": "säkerhetspolitisk",
    "säkerhetspolitiskas": "säkerhetspolitisk",
    "säkerhetspolitiske": "säkerhetspolitisk",
    "säkerhetspolitiskes": "säkerhetspolitisk",
    "säkerhetspolitisks": "säkerhetspolitisk",
    "säkerhetspolitiskt": "säkerhetspolitisk",
    "säkerhetspolitiskts": "säkerhetspolitisk",
    "säkerhetsproblemen": "säkerhetsproblem",
    "säkerhetsproblemens": "säkerhetsproblem",
    "säkerhetsproblemet": "säkerhetsproblem",
    "säkerhetsproblemets": "säkerhetsproblem",
    "säkerhetsproblems": "säkerhetsproblem",
    "säkerhetspådragen": "säkerhetspådrag",
    "säkerhetspådragens": "säkerhetspådrag",
    "säkerhetspådraget": "säkerhetspådrag",
    "säkerhetspådragets": "säkerhetspådrag",
    "säkerhetspådrags": "säkerhetspådrag",
    "säkerhetsreläer": "säkerhetsrelä",
    "säkerhetsreläerna": "säkerhetsrelä",
    "säkerhetsreläernas": "säkerhetsrelä",
    "säkerhetsreläers": "säkerhetsrelä",
    "säkerhetsreläet": "säkerhetsrelä",
    "säkerhetsreläets": "säkerhetsrelä",
    "säkerhetsreläs": "säkerhetsrelä",
    "säkerhetsrelät": "säkerhetsrelä",
    "säkerhetsreläts": "säkerhetsrelä",
    "säkerhetsrisken": "säkerhetsrisk",
    "säkerhetsriskens": "säkerhetsrisk",
    "säkerhetsrisker": "säkerhetsrisk",
    "säkerhetsriskerna": "säkerhetsrisk",
    "säkerhetsriskernas": "säkerhetsrisk",
    "säkerhetsriskers": "säkerhetsrisk",
    "säkerhetsrisks": "säkerhetsrisk",
    "säkerhetsrådet": "säkerhetsråd",
    "säkerhetsrådets": "säkerhetsråd",
    "säkerhetsrådgivar": "säkerhetsrådgivare",
    "säkerhetsrådgivaren": "säkerhetsrådgivare",
    "säkerhetsrådgivarens": "säkerhetsrådgivare",
    "säkerhetsrådgivares": "säkerhetsrådgivare",
    "säkerhetsrådgivarna": "säkerhetsrådgivare",
    "säkerhetsrådgivarnas": "säkerhetsrådgivare",
    "säkerhetsråds": "säkerhetsråd",
    "säkerhetssalar": "säkerhetssal",
    "säkerhetssalarna": "säkerhetssal",
    "säkerhetssalarnas": "säkerhetssal",
    "säkerhetssalars": "säkerhetssal",
    "säkerhetssalen": "säkerhetssal",
    "säkerhetssalens": "säkerhetssal",
    "säkerhetssals": "säkerhetssal",
    "säkerhetsselen": "säkerhetssele",
    "säkerhetsselena": "säkerhetssele",
    "säkerhetsselenas": "säkerhetssele",
    "säkerhetsselens": "säkerhetssele",
    "säkerhetsseles": "säkerhetssele",
    "säkerhetsselet": "säkerhetssele",
    "säkerhetsselets": "säkerhetssele",
    "säkerhetsskälen": "säkerhetsskäl",
    "säkerhetsskälens": "säkerhetsskäl",
    "säkerhetsskälet": "säkerhetsskäl",
    "säkerhetsskälets": "säkerhetsskäl",
    "säkerhetsskäls": "säkerhetsskäl",
    "säkerhetssprintar": "säkerhetssprint",
    "säkerhetssprintarna": "säkerhetssprint",
    "säkerhetssprintarnas": "säkerhetssprint",
    "säkerhetssprintars": "säkerhetssprint",
    "säkerhetssprinten": "säkerhetssprint",
    "säkerhetssprintens": "säkerhetssprint",
    "säkerhetssprints": "säkerhetssprint",
    "säkerhetssystemen": "säkerhetssystem",
    "säkerhetssystemens": "säkerhetssystem",
    "säkerhetssystemet": "säkerhetssystem",
    "säkerhetssystemets": "säkerhetssystem",
    "säkerhetssystems": "säkerhetssystem",
    "säkerhetstjänsten": "säkerhetstjänst",
    "säkerhetstjänstens": "säkerhetstjänst",
    "säkerhetstjänster": "säkerhetstjänst",
    "säkerhetstjänsterna": "säkerhetstjänst",
    "säkerhetstjänsternas": "säkerhetstjänst",
    "säkerhetstjänsters": "säkerhetstjänst",
    "säkerhetstjänsts": "säkerhetstjänst",
    "säkerhetständstick": "säkerhetständsticka",
    "säkerhetständstickan": "säkerhetständsticka",
    "säkerhetständstickans": "säkerhetständsticka",
    "säkerhetständstickas": "säkerhetständsticka",
    "säkerhetständsticke": "säkerhetständsticka",
    "säkerhetständstickor": "säkerhetständsticka",
    "säkerhetständstickorna": "säkerhetständsticka",
    "säkerhetständstickornas": "säkerhetständsticka",
    "säkerhetständstickors": "säkerhetständsticka",
    "säkerhetständsticks": "säkerhetständsticka",
    "säkerhetstänket": "säkerhetstänk",
    "säkerhetstänkets": "säkerhetstänk",
    "säkerhetstänks": "säkerhetstänk",
    "säkerhetsvakten": "säkerhetsvakt",
    "säkerhetsvaktens": "säkerhetsvakt",
    "säkerhetsvakter": "säkerhetsvakt",
    "säkerhetsvakterna": "säkerhetsvakt",
    "säkerhetsvakternas": "säkerhetsvakt",
    "säkerhetsvakters": "säkerhetsvakt",
    "säkerhetsvakts": "säkerhetsvakt",
    "säkerhetsventilen": "säkerhetsventil",
    "säkerhetsventilens": "säkerhetsventil",
    "säkerhetsventiler": "säkerhetsventil",
    "säkerhetsventilerna": "säkerhetsventil",
    "säkerhetsventilernas": "säkerhetsventil",
    "säkerhetsventilers": "säkerhetsventil",
    "säkerhetsventils": "säkerhetsventil",
    "säkers": "säker",
    "säkerställ": "säkerställa",
    "säkerställande": "säkerställa",
    "säkerställanden": "säkerställande",
    "säkerställandena": "säkerställande",
    "säkerställandenas": "säkerställande",
    "säkerställandens": "säkerställande",
    "säkerställandes": "säkerställande",
    "säkerställandet": "säkerställande",
    "säkerställandets": "säkerställande",
    "säkerställas": "säkerställa",
    "säkerställd": "säkerställa",
    "säkerställda": "säkerställa",
    "säkerställdas": "säkerställa",
    "säkerställde": "säkerställa",
    "säkerställdes": "säkerställa",
    "säkerställds": "säkerställa",
    "säkerställer": "säkerställa",
    "säkerställes": "säkerställa",
    "säkerställs": "säkerställa",
    "säkerställt": "säkerställa",
    "säkerställts": "säkerställa",
    "säkert": "säker",
    "säkerts": "säker",
    "säkra": "säker",
    "säkrad": "säkra",
    "säkrade": "säkra",
    "säkrades": "säkra",
    "säkrads": "säkra",
    "säkrande": "säkra",
    "säkranden": "säkrande",
    "säkrandena": "säkrande",
    "säkrandenas": "säkrande",
    "säkrandens": "säkrande",
    "säkrandes": "säkrande",
    "säkrandet": "säkrande",
    "säkrandets": "säkrande",
    "säkrar": "säkra",
    "säkrare": "säker",
    "säkrares": "säker",
    "säkras": "säkra",
    "säkrast": "säker",
    "säkraste": "säker",
    "säkrastes": "säker",
    "säkrasts": "säker",
    "säkrat": "säkra",
    "säkrats": "säkra",
    "säkre": "säker",
    "säkres": "säker",
    "säkringar": "säkring",
    "säkringarna": "säkring",
    "säkringarnas": "säkring",
    "säkringars": "säkring",
    "säkringen": "säkring",
    "säkringens": "säkring",
    "säkrings": "säkring",
    "säkringshållar": "säkringshållare",
    "säkringshållaren": "säkringshållare",
    "säkringshållarens": "säkringshållare",
    "säkringshållares": "säkringshållare",
    "säkringshållarna": "säkringshållare",
    "säkringshållarnas": "säkringshållare",
    "sälar": "säl",
    "sälarna": "säl",
    "sälarnas": "säl",
    "sälars": "säl",
    "säldjuren": "säldjur",
    "säldjurens": "säldjur",
    "säldjuret": "säldjur",
    "säldjurets": "säldjur",
    "säldjurs": "säldjur",
    "sälen": "säl",
    "sälens": "säl",
    "sälgar": "sälg",
    "sälgarna": "sälg",
    "sälgarnas": "sälg",
    "sälgars": "sälg",
    "sälgen": "sälg",
    "sälgens": "sälg",
    "sälghängen": "sälghänge",
    "sälghängena": "sälghänge",
    "sälghängenas": "sälghänge",
    "sälghängens": "sälghänge",
    "sälghänges": "sälghänge",
    "sälghänget": "sälghänge",
    "sälghängets": "sälghänge",
    "sälghängs": "sälghänge",
    "sälgs": "sälg",
    "sälj": "sälja",
    "säljande": "sälja",
    "säljanden": "säljande",
    "säljandena": "säljande",
    "säljandenas": "säljande",
    "säljandens": "säljande",
    "säljandes": "säljande",
    "säljandet": "säljande",
    "säljandets": "säljande",
    "säljar": "säljare",
    "säljaren": "säljare",
    "säljarens": "säljare",
    "säljares": "säljare",
    "säljarna": "säljare",
    "säljarnas": "säljare",
    "säljas": "sälja",
    "säljbara": "säljbar",
    "säljbarare": "säljbar",
    "säljbarares": "säljbar",
    "säljbaras": "säljbar",
    "säljbarast": "säljbar",
    "säljbaraste": "säljbar",
    "säljbarastes": "säljbar",
    "säljbarasts": "säljbar",
    "säljbare": "säljbar",
    "säljbares": "säljbar",
    "säljbarheten": "säljbarhet",
    "säljbarhetens": "säljbarhet",
    "säljbarhets": "säljbarhet",
    "säljbars": "säljbar",
    "säljbart": "säljbar",
    "säljbarts": "säljbar",
    "säljer": "sälja",
    "säljes": "sälja",
    "säljs": "sälja",
    "sälkutar": "sälkut",
    "sälkutarna": "sälkut",
    "sälkutarnas": "sälkut",
    "sälkutars": "sälkut",
    "sälkuten": "sälkut",
    "sälkutens": "sälkut",
    "sälkuts": "sälkut",
    "säll": "sälle",
    "sälla": "säll",
    "sällar": "sälle",
    "sällare": "säll",
    "sällares": "säll",
    "sällarna": "sälle",
    "sällarnas": "sälle",
    "sällars": "sälle",
    "sällas": "säll",
    "sällast": "säll",
    "sällaste": "säll",
    "sällastes": "säll",
    "sällasts": "säll",
    "sälle": "säll",
    "sällen": "sälle",
    "sällens": "sälle",
    "sälles": "sälle",
    "sällheten": "sällhet",
    "sällhetens": "sällhet",
    "sällheter": "sällhet",
    "sällheterna": "sällhet",
    "sällheternas": "sällhet",
    "sällheters": "sällhet",
    "sällhets": "sällhet",
    "sälls": "sälle",
    "sällsamheten": "sällsamhet",
    "sällsamhetens": "sällsamhet",
    "sällsamheter": "sällsamhet",
    "sällsamheterna": "sällsamhet",
    "sällsamheternas": "sällsamhet",
    "sällsamheters": "sällsamhet",
    "sällsamhets": "sällsamhet",
    "sällsamma": "sällsam",
    "sällsammare": "sällsam",
    "sällsammares": "sällsam",
    "sällsammas": "sällsam",
    "sällsammast": "sällsam",
    "sällsammaste": "sällsam",
    "sällsammastes": "sällsam",
    "sällsammasts": "sällsam",
    "sällsamme": "sällsam",
    "sällsammes": "sällsam",
    "sällsams": "sällsam",
    "sällsamt": "sällsam",
    "sällsamts": "sällsam",
    "sällskapade": "sällskapa",
    "sällskapades": "sällskapa",
    "sällskapande": "sällskapa",
    "sällskapanden": "sällskapande",
    "sällskapandena": "sällskapande",
    "sällskapandenas": "sällskapande",
    "sällskapandens": "sällskapande",
    "sällskapandes": "sällskapande",
    "sällskapandet": "sällskapande",
    "sällskapandets": "sällskapande",
    "sällskapar": "sällskapa",
    "sällskapas": "sällskapa",
    "sällskapat": "sällskapa",
    "sällskapats": "sällskapa",
    "sällskapen": "sällskap",
    "sällskapens": "sällskap",
    "sällskapet": "sällskap",
    "sällskapets": "sällskap",
    "sällskapliga": "sällskaplig",
    "sällskapligare": "sällskaplig",
    "sällskapligares": "sällskaplig",
    "sällskapligas": "sällskaplig",
    "sällskapligast": "sällskaplig",
    "sällskapligaste": "sällskaplig",
    "sällskapligastes": "sällskaplig",
    "sällskapligasts": "sällskaplig",
    "sällskaplige": "sällskaplig",
    "sällskapliges": "sällskaplig",
    "sällskapligheten": "sällskaplighet",
    "sällskaplighetens": "sällskaplighet",
    "sällskaplighets": "sällskaplighet",
    "sällskapligs": "sällskaplig",
    "sällskapligt": "sällskaplig",
    "sällskapligts": "sällskaplig",
    "sällskaps": "sällskap",
    "sällskapsdamen": "sällskapsdam",
    "sällskapsdamens": "sällskapsdam",
    "sällskapsdamer": "sällskapsdam",
    "sällskapsdamerna": "sällskapsdam",
    "sällskapsdamernas": "sällskapsdam",
    "sällskapsdamers": "sällskapsdam",
    "sällskapsdams": "sällskapsdam",
    "sällskapsdansen": "sällskapsdans",
    "sällskapsdansens": "sällskapsdans",
    "sällskapsdanser": "sällskapsdans",
    "sällskapsdanserna": "sällskapsdans",
    "sällskapsdansernas": "sällskapsdans",
    "sällskapsdansers": "sällskapsdans",
    "sällskapsdjuren": "sällskapsdjur",
    "sällskapsdjurens": "sällskapsdjur",
    "sällskapsdjuret": "sällskapsdjur",
    "sällskapsdjurets": "sällskapsdjur",
    "sällskapsdjurs": "sällskapsdjur",
    "sällskapsliven": "sällskapsliv",
    "sällskapslivens": "sällskapsliv",
    "sällskapslivet": "sällskapsliv",
    "sällskapslivets": "sällskapsliv",
    "sällskapslivs": "sällskapsliv",
    "sällskapsmänniskan": "sällskapsmänniska",
    "sällskapsmänniskans": "sällskapsmänniska",
    "sällskapsmänniskas": "sällskapsmänniska",
    "sällskapsmännisko": "sällskapsmänniska",
    "sällskapsmänniskor": "sällskapsmänniska",
    "sällskapsmänniskorna": "sällskapsmänniska",
    "sällskapsmänniskornas": "sällskapsmänniska",
    "sällskapsmänniskors": "sällskapsmänniska",
    "sällskapsresan": "sällskapsresa",
    "sällskapsresans": "sällskapsresa",
    "sällskapsresas": "sällskapsresa",
    "sällskapsrese": "sällskapsresa",
    "sällskapsresor": "sällskapsresa",
    "sällskapsresorna": "sällskapsresa",
    "sällskapsresornas": "sällskapsresa",
    "sällskapsresors": "sällskapsresa",
    "sällskapsrummen": "sällskapsrum",
    "sällskapsrummens": "sällskapsrum",
    "sällskapsrummet": "sällskapsrum",
    "sällskapsrummets": "sällskapsrum",
    "sällskapsrums": "sällskapsrum",
    "sällskapssjuka": "sällskapssjuk",
    "sällskapssjukare": "sällskapssjuk",
    "sällskapssjukares": "sällskapssjuk",
    "sällskapssjukas": "sällskapssjuk",
    "sällskapssjukast": "sällskapssjuk",
    "sällskapssjukaste": "sällskapssjuk",
    "sällskapssjukastes": "sällskapssjuk",
    "sällskapssjukasts": "sällskapssjuk",
    "sällskapssjuke": "sällskapssjuk",
    "sällskapssjukes": "sällskapssjuk",
    "sällskapssjukheten": "sällskapssjukhet",
    "sällskapssjukhetens": "sällskapssjukhet",
    "sällskapssjukhets": "sällskapssjukhet",
    "sällskapssjuks": "sällskapssjuk",
    "sällskapssjukt": "sällskapssjuk",
    "sällskapssjukts": "sällskapssjuk",
    "sällskapsspelen": "sällskapsspel",
    "sällskapsspelens": "sällskapsspel",
    "sällskapsspelet": "sällskapsspel",
    "sällskapsspelets": "sällskapsspel",
    "sällskapsspels": "sällskapsspel",
    "sällskapsät": "sällskapsäta",
    "sällskapsätande": "sällskapsäta",
    "sällskapsätandes": "sällskapsäta",
    "sällskapsätas": "sällskapsäta",
    "sällskapsäte": "sällskapsäta",
    "sällskapsäten": "sällskapsäta",
    "sällskapsätens": "sällskapsäta",
    "sällskapsäter": "sällskapsäta",
    "sällskapsätes": "sällskapsäta",
    "sällskapsätet": "sällskapsäta",
    "sällskapsätets": "sällskapsäta",
    "sällskapsätit": "sällskapsäta",
    "sällskapsätits": "sällskapsäta",
    "sällskapsätna": "sällskapsäta",
    "sällskapsätnas": "sällskapsäta",
    "sällskapsätne": "sällskapsäta",
    "sällskapsätnes": "sällskapsäta",
    "sällskapsäts": "sällskapsäta",
    "sällskapsåt": "sällskapsäta",
    "sällskapsåte": "sällskapsäta",
    "sällskapsåtes": "sällskapsäta",
    "sällskapsåts": "sällskapsäta",
    "sällsporda": "sällspord",
    "sällspordare": "sällspord",
    "sällspordares": "sällspord",
    "sällspordas": "sällspord",
    "sällspordast": "sällspord",
    "sällspordaste": "sällspord",
    "sällspordastes": "sällspord",
    "sällspordasts": "sällspord",
    "sällsporde": "sällspord",
    "sällspordes": "sällspord",
    "sällspordheten": "sällspordhet",
    "sällspordhetens": "sällspordhet",
    "sällspordhets": "sällspordhet",
    "sällspords": "sällspord",
    "sällsport": "sällspord",
    "sällsports": "sällspord",
    "sällsynta": "sällsynt",
    "sällsyntare": "sällsynt",
    "sällsyntares": "sällsynt",
    "sällsyntas": "sällsynt",
    "sällsyntast": "sällsynt",
    "sällsyntaste": "sällsynt",
    "sällsyntastes": "sällsynt",
    "sällsyntasts": "sällsynt",
    "sällsynte": "sällsynt",
    "sällsyntes": "sällsynt",
    "sällsyntheten": "sällsynthet",
    "sällsynthetens": "sällsynthet",
    "sällsyntheter": "sällsynthet",
    "sällsyntheterna": "sällsynthet",
    "sällsyntheternas": "sällsynthet",
    "sällsyntheters": "sällsynthet",
    "sällsynthets": "sällsynthet",
    "sällsynts": "sällsynt",
    "sällt": "säll",
    "sällträet": "sällträ",
    "sällträets": "sällträ",
    "sällträn": "sällträ",
    "sällträna": "sällträ",
    "sälltränas": "sällträ",
    "sällträns": "sällträ",
    "sällträs": "sällträ",
    "sällträt": "sällträ",
    "sällträts": "sällträ",
    "sällts": "säll",
    "säls": "säl",
    "sälskinnen": "sälskinn",
    "sälskinnens": "sälskinn",
    "sälskinnet": "sälskinn",
    "sälskinnets": "sälskinn",
    "sälskinns": "sälskinn",
    "sälskyttes": "sälskytte",
    "sälskyttet": "sälskytte",
    "sälskyttets": "sälskytte",
    "sält": "sälta",
    "sältan": "sälta",
    "sältans": "sälta",
    "sältas": "sälta",
    "sälte": "sälta",
    "sältor": "sälta",
    "sältorna": "sälta",
    "sältornas": "sälta",
    "sältors": "sälta",
    "sälts": "sälta",
    "sälungar": "sälunge",
    "sälungarna": "sälunge",
    "sälungarnas": "sälunge",
    "sälungars": "sälunge",
    "sälungen": "sälunge",
    "sälungens": "sälunge",
    "sälunges": "sälunge",
    "sämjades": "sämjas",
    "sämjan": "sämja",
    "sämjans": "sämja",
    "sämjas": "sämja",
    "sämjats": "sämjas",
    "sämre": "illa",
    "sämres": "dålig",
    "sämsk": "sämska",
    "sämskad": "sämska",
    "sämskade": "sämska",
    "sämskades": "sämska",
    "sämskads": "sämska",
    "sämskande": "sämska",
    "sämskanden": "sämskande",
    "sämskandena": "sämskande",
    "sämskandenas": "sämskande",
    "sämskandens": "sämskande",
    "sämskandes": "sämskande",
    "sämskandet": "sämskande",
    "sämskandets": "sämskande",
    "sämskar": "sämska",
    "sämskas": "sämska",
    "sämskat": "sämska",
    "sämskats": "sämska",
    "sämskgarv": "sämskgarva",
    "sämskgarvad": "sämskgarva",
    "sämskgarvade": "sämskgarva",
    "sämskgarvades": "sämskgarva",
    "sämskgarvads": "sämskgarva",
    "sämskgarvande": "sämskgarva",
    "sämskgarvanden": "sämskgarvande",
    "sämskgarvandena": "sämskgarvande",
    "sämskgarvandenas": "sämskgarvande",
    "sämskgarvandens": "sämskgarvande",
    "sämskgarvandes": "sämskgarvande",
    "sämskgarvandet": "sämskgarvande",
    "sämskgarvandets": "sämskgarvande",
    "sämskgarvar": "sämskgarva",
    "sämskgarvas": "sämskgarva",
    "sämskgarvat": "sämskgarva",
    "sämskgarvats": "sämskgarva",
    "sämskskinnen": "sämskskinn",
    "sämskskinnens": "sämskskinn",
    "sämskskinnet": "sämskskinn",
    "sämskskinnets": "sämskskinn",
    "sämskskinns": "sämskskinn",
    "sämst": "illa",
    "sämsta": "dålig",
    "sämstas": "dålig",
    "sämste": "dålig",
    "sämstes": "dålig",
    "sämsts": "dålig",
    "sänd": "sända",
    "sändande": "sända",
    "sändanden": "sändande",
    "sändandena": "sändande",
    "sändandenas": "sändande",
    "sändandens": "sändande",
    "sändandes": "sändande",
    "sändandet": "sändande",
    "sändandets": "sändande",
    "sändar": "sändare",
    "sändaren": "sändare",
    "sändarens": "sändare",
    "sändares": "sändare",
    "sändarna": "sändare",
    "sändarnas": "sändare",
    "sändas": "sända",
    "sände": "sända",
    "sändebuden": "sändebud",
    "sändebudens": "sändebud",
    "sändebudet": "sändebud",
    "sändebudets": "sändebud",
    "sändebuds": "sändebud",
    "sänder": "sända",
    "sändes": "sända",
    "sändningar": "sändning",
    "sändningarna": "sändning",
    "sändningarnas": "sändning",
    "sändningars": "sändning",
    "sändningen": "sändning",
    "sändningens": "sändning",
    "sändnings": "sändning",
    "sändningsrättigheten": "sändningsrättighet",
    "sändningsrättighetens": "sändningsrättighet",
    "sändningsrättigheter": "sändningsrättighet",
    "sändningsrättigheterna": "sändningsrättighet",
    "sändningsrättigheternas": "sändningsrättighet",
    "sändningsrättigheters": "sändningsrättighet",
    "sändningsrättighets": "sändningsrättighet",
    "sändningsuppehållen": "sändningsuppehåll",
    "sändningsuppehållens": "sändningsuppehåll",
    "sändningsuppehållet": "sändningsuppehåll",
    "sändningsuppehållets": "sändningsuppehåll",
    "sändningsuppehålls": "sändningsuppehåll",
    "sänds": "sända",
    "sängar": "säng",
    "sängarna": "säng",
    "sängarnas": "säng",
    "sängars": "säng",
    "sängborden": "sängbord",
    "sängbordens": "sängbord",
    "sängbordet": "sängbord",
    "sängbordets": "sängbord",
    "sängbords": "sängbord",
    "sängen": "säng",
    "sängens": "säng",
    "sängfoten": "sängfot",
    "sängfotens": "sängfot",
    "sängfots": "sängfot",
    "sängförhängen": "sängförhänge",
    "sängförhängena": "sängförhänge",
    "sängförhängenas": "sängförhänge",
    "sängförhängens": "sängförhänge",
    "sängförhänges": "sängförhänge",
    "sängförhänget": "sängförhänge",
    "sängförhängets": "sängförhänge",
    "sängfösar": "sängfösare",
    "sängfösaren": "sängfösare",
    "sängfösarens": "sängfösare",
    "sängfösares": "sängfösare",
    "sängfösarna": "sängfösare",
    "sängfösarnas": "sängfösare",
    "sängfötter": "sängfot",
    "sängfötterna": "sängfot",
    "sängfötternas": "sängfot",
    "sängfötters": "sängfot",
    "sänghalmen": "sänghalm",
    "sänghalmens": "sänghalm",
    "sänghalms": "sänghalm",
    "sänghimlar": "sänghimmel",
    "sänghimlarna": "sänghimmel",
    "sänghimlarnas": "sänghimmel",
    "sänghimlars": "sänghimmel",
    "sänghimlen": "sänghimmel",
    "sänghimlens": "sänghimmel",
    "sänghimmelen": "sänghimmel",
    "sänghimmelens": "sänghimmel",
    "sänghimmeln": "sänghimmel",
    "sänghimmelns": "sänghimmel",
    "sänghimmels": "sänghimmel",
    "sängkammar": "sängkammare",
    "sängkammaren": "sängkammare",
    "sängkammarens": "sängkammare",
    "sängkammares": "sängkammare",
    "sängkammarfarsen": "sängkammarfars",
    "sängkammarfarsens": "sängkammarfars",
    "sängkammarfarser": "sängkammarfars",
    "sängkammarfarserna": "sängkammarfars",
    "sängkammarfarsernas": "sängkammarfars",
    "sängkammarfarsers": "sängkammarfars",
    "sängkamrar": "sängkammare",
    "sängkamrarna": "sängkammare",
    "sängkamrarnas": "sängkammare",
    "sängkamrars": "sängkammare",
    "sängkanten": "sängkant",
    "sängkantens": "sängkant",
    "sängkanter": "sängkant",
    "sängkanterna": "sängkant",
    "sängkanternas": "sängkant",
    "sängkanters": "sängkant",
    "sängkants": "sängkant",
    "sängkläderna": "sängkläder",
    "sängklädernas": "sängkläder",
    "sängkläders": "sängkläder",
    "sängklädes": "sängkläder",
    "sängkläds": "sängkläder",
    "sänglinnes": "sänglinne",
    "sänglinnet": "sänglinne",
    "sänglinnets": "sänglinne",
    "sängläges": "sängläge",
    "sängläget": "sängläge",
    "sänglägets": "sängläge",
    "sängrök": "sängröka",
    "sängrökande": "sängröka",
    "sängrökanden": "sängrökande",
    "sängrökandena": "sängrökande",
    "sängrökandenas": "sängrökande",
    "sängrökandens": "sängrökande",
    "sängrökandes": "sängrökande",
    "sängrökandet": "sängrökande",
    "sängrökandets": "sängrökande",
    "sängrökar": "sängrökare",
    "sängrökaren": "sängrökare",
    "sängrökarens": "sängrökare",
    "sängrökares": "sängrökare",
    "sängrökarna": "sängrökare",
    "sängrökarnas": "sängrökare",
    "sängrökas": "sängröka",
    "sängröker": "sängröka",
    "sängrökes": "sängröka",
    "sängröks": "sängröka",
    "sängrökt": "sängröka",
    "sängrökte": "sängröka",
    "sängröktes": "sängröka",
    "sängrökts": "sängröka",
    "sängs": "säng",
    "sängvärmen": "sängvärme",
    "sängvärmens": "sängvärme",
    "sängvärmes": "sängvärme",
    "sängvätar": "sängvätare",
    "sängvätaren": "sängvätare",
    "sängvätarens": "sängvätare",
    "sängvätares": "sängvätare",
    "sängvätarna": "sängvätare",
    "sängvätarnas": "sängvätare",
    "sänk": "sänka",
    "sänkan": "sänka",
    "sänkande": "sänka",
    "sänkanden": "sänkande",
    "sänkandena": "sänkande",
    "sänkandenas": "sänkande",
    "sänkandens": "sänkande",
    "sänkandes": "sänkande",
    "sänkandet": "sänkande",
    "sänkandets": "sänkande",
    "sänkans": "sänka",
    "sänkas": "sänka",
    "sänke": "sänka",
    "sänken": "sänke",
    "sänkena": "sänke",
    "sänkenas": "sänke",
    "sänkens": "sänke",
    "sänker": "sänka",
    "sänkes": "sänke",
    "sänket": "sänke",
    "sänkets": "sänke",
    "sänkhåvar": "sänkhåv",
    "sänkhåvarna": "sänkhåv",
    "sänkhåvarnas": "sänkhåv",
    "sänkhåvars": "sänkhåv",
    "sänkhåven": "sänkhåv",
    "sänkhåvens": "sänkhåv",
    "sänkhåvs": "sänkhåv",
    "sänkningar": "sänkning",
    "sänkningarna": "sänkning",
    "sänkningarnas": "sänkning",
    "sänkningars": "sänkning",
    "sänkningen": "sänkning",
    "sänkningens": "sänkning",
    "sänknings": "sänkning",
    "sänkningsreaktionen": "sänkningsreaktion",
    "sänkningsreaktionens": "sänkningsreaktion",
    "sänkningsreaktioner": "sänkningsreaktion",
    "sänkningsreaktionerna": "sänkningsreaktion",
    "sänkningsreaktionernas": "sänkningsreaktion",
    "sänkningsreaktioners": "sänkningsreaktion",
    "sänkningsreaktions": "sänkningsreaktion",
    "sänkningsteckens": "sänkningstecken",
    "sänkningstecknen": "sänkningstecken",
    "sänkningstecknens": "sänkningstecken",
    "sänkningstecknet": "sänkningstecken",
    "sänkningstecknets": "sänkningstecken",
    "sänkor": "sänka",
    "sänkorna": "sänka",
    "sänkornas": "sänka",
    "sänkors": "sänka",
    "sänks": "sänke",
    "sänkt": "sänka",
    "sänkta": "sänka",
    "sänktas": "sänka",
    "sänkte": "sänka",
    "sänktes": "sänka",
    "sänkts": "sänka",
    "sänkvågar": "sänkvåg",
    "sänkvågarna": "sänkvåg",
    "sänkvågarnas": "sänkvåg",
    "sänkvågars": "sänkvåg",
    "sänkvågen": "sänkvåg",
    "sänkvågens": "sänkvåg",
    "sänkvågs": "sänkvåg",
    "sänt": "sända",
    "sänts": "sända",
    "sär": "sära",
    "särad": "sära",
    "särade": "sära",
    "särades": "sära",
    "särads": "sära",
    "särande": "sära",
    "säranden": "särande",
    "särandena": "särande",
    "särandenas": "särande",
    "särandens": "särande",
    "särandes": "särande",
    "särandet": "särande",
    "särandets": "särande",
    "särar": "sära",
    "särarten": "särart",
    "särartens": "särart",
    "särarts": "särart",
    "säras": "sära",
    "särat": "sära",
    "särats": "sära",
    "särbehandlad": "särbehandla",
    "särbehandlade": "särbehandla",
    "särbehandlades": "särbehandla",
    "särbehandlads": "särbehandla",
    "särbehandlande": "särbehandla",
    "särbehandlanden": "särbehandlande",
    "särbehandlandena": "särbehandlande",
    "särbehandlandenas": "särbehandlande",
    "särbehandlandens": "särbehandlande",
    "särbehandlandes": "särbehandlande",
    "särbehandlandet": "särbehandlande",
    "särbehandlandets": "särbehandlande",
    "särbehandlar": "särbehandla",
    "särbehandlas": "särbehandla",
    "särbehandlat": "särbehandla",
    "särbehandlats": "särbehandla",
    "särbeskatt": "särbeskatta",
    "särbeskattad": "särbeskatta",
    "särbeskattade": "särbeskatta",
    "särbeskattades": "särbeskatta",
    "särbeskattads": "särbeskatta",
    "särbeskattande": "särbeskatta",
    "särbeskattanden": "särbeskattande",
    "särbeskattandena": "särbeskattande",
    "särbeskattandenas": "särbeskattande",
    "särbeskattandens": "särbeskattande",
    "särbeskattandes": "särbeskattande",
    "särbeskattandet": "särbeskattande",
    "särbeskattandets": "särbeskattande",
    "särbeskattar": "särbeskatta",
    "särbeskattas": "särbeskatta",
    "särbeskattat": "särbeskatta",
    "särbeskattats": "särbeskatta",
    "särbon": "särbo",
    "särbons": "särbo",
    "särbor": "särbo",
    "särborna": "särbo",
    "särbornas": "särbo",
    "särbors": "särbo",
    "särbos": "särbo",
    "särdragen": "särdrag",
    "särdragens": "särdrag",
    "särdraget": "särdrag",
    "särdragets": "särdrag",
    "särdrags": "särdrag",
    "säregenheten": "säregenhet",
    "säregenhetens": "säregenhet",
    "säregenheter": "säregenhet",
    "säregenheterna": "säregenhet",
    "säregenheternas": "säregenhet",
    "säregenheters": "säregenhet",
    "säregenhets": "säregenhet",
    "säregens": "säregen",
    "säreget": "säregen",
    "säregets": "säregen",
    "säregna": "säregen",
    "säregnare": "säregen",
    "säregnares": "säregen",
    "säregnas": "säregen",
    "säregnast": "säregen",
    "säregnaste": "säregen",
    "säregnastes": "säregen",
    "säregnasts": "säregen",
    "säregne": "säregen",
    "säregnes": "säregen",
    "särfallen": "särfall",
    "särfallens": "särfall",
    "särfallet": "särfall",
    "särfallets": "särfall",
    "särfalls": "särfall",
    "särfrågan": "särfråga",
    "särfrågans": "särfråga",
    "särfrågas": "särfråga",
    "särfråge": "särfråga",
    "särfrågor": "särfråga",
    "särfrågorna": "särfråga",
    "särfrågornas": "särfråga",
    "särfrågors": "särfråga",
    "särintressen": "särintresse",
    "särintressena": "särintresse",
    "särintressenas": "särintresse",
    "särintressens": "särintresse",
    "särintresses": "särintresse",
    "särintresset": "särintresse",
    "särintressets": "särintresse",
    "särkar": "särk",
    "särkarna": "särk",
    "särkarnas": "särk",
    "särkars": "särk",
    "särken": "särk",
    "särkens": "särk",
    "särklassen": "särklass",
    "särklassens": "särklass",
    "särklasser": "särklass",
    "särklasserna": "särklass",
    "särklassernas": "särklass",
    "särklassers": "särklass",
    "särklassiga": "särklassig",
    "särklassigare": "särklassig",
    "särklassigares": "särklassig",
    "särklassigas": "särklassig",
    "särklassigast": "särklassig",
    "särklassigaste": "särklassig",
    "särklassigastes": "särklassig",
    "särklassigasts": "särklassig",
    "särklassige": "särklassig",
    "särklassiges": "särklassig",
    "särklassigheten": "särklassighet",
    "särklassighetens": "särklassighet",
    "särklassighets": "särklassighet",
    "särklassigs": "särklassig",
    "särklassigt": "särklassig",
    "särklassigts": "särklassig",
    "särks": "särk",
    "särkullbarnen": "särkullbarn",
    "särkullbarnens": "särkullbarn",
    "särkullbarnet": "särkullbarn",
    "särkullbarnets": "särkullbarn",
    "särkullbarns": "särkullbarn",
    "särkullsbarnen": "särkullsbarn",
    "särkullsbarnens": "särkullsbarn",
    "särkullsbarnet": "särkullsbarn",
    "särkullsbarnets": "särkullsbarn",
    "särkullsbarns": "särkullsbarn",
    "särlingar": "särling",
    "särlingarna": "särling",
    "särlingarnas": "särling",
    "särlingars": "särling",
    "särlingen": "särling",
    "särlingens": "särling",
    "särlings": "särling",
    "särmärken": "särmärke",
    "särmärkena": "särmärke",
    "särmärkenas": "särmärke",
    "särmärkens": "särmärke",
    "särmärkes": "särmärke",
    "särmärket": "särmärke",
    "särmärkets": "särmärke",
    "särprägeln": "särprägel",
    "särprägelns": "särprägel",
    "särprägels": "särprägel",
    "särpräglade": "särpräglad",
    "särpräglades": "särpräglad",
    "särpräglads": "särpräglad",
    "särpräglat": "särpräglad",
    "särpräglats": "särpräglad",
    "särskild": "särskilja",
    "särskilda": "särskilja",
    "särskildare": "särskild",
    "särskildares": "särskild",
    "särskildas": "särskilja",
    "särskildast": "särskild",
    "särskildaste": "särskild",
    "särskildastes": "särskild",
    "särskildasts": "särskild",
    "särskilde": "särskilja",
    "särskildes": "särskilja",
    "särskilds": "särskilja",
    "särskilj": "särskilja",
    "särskiljande": "särskilja",
    "särskiljanden": "särskiljande",
    "särskiljandena": "särskiljande",
    "särskiljandenas": "särskiljande",
    "särskiljandens": "särskiljande",
    "särskiljandes": "särskiljande",
    "särskiljandet": "särskiljande",
    "särskiljandets": "särskiljande",
    "särskiljas": "särskilja",
    "särskiljer": "särskilja",
    "särskiljes": "särskilja",
    "särskiljs": "särskilja",
    "särskilt": "särskilja",
    "särskilts": "särskilja",
    "särskolan": "särskola",
    "särskolans": "särskola",
    "särskolas": "särskola",
    "särskole": "särskola",
    "särskolor": "särskola",
    "särskolorna": "särskola",
    "särskolornas": "särskola",
    "särskolors": "särskola",
    "särställningar": "särställning",
    "särställningarna": "särställning",
    "särställningarnas": "särställning",
    "särställningars": "särställning",
    "särställningen": "särställning",
    "särställningens": "särställning",
    "särställnings": "särställning",
    "särtrycken": "särtryck",
    "särtryckens": "särtryck",
    "särtrycket": "särtryck",
    "särtryckets": "särtryck",
    "särtrycks": "särtryck",
    "säsongen": "säsong",
    "säsongens": "säsong",
    "säsonger": "säsong",
    "säsongerna": "säsong",
    "säsongernas": "säsong",
    "säsongers": "säsong",
    "säsongmässiga": "säsongmässig",
    "säsongmässigare": "säsongmässig",
    "säsongmässigares": "säsongmässig",
    "säsongmässigas": "säsongmässig",
    "säsongmässigast": "säsongmässig",
    "säsongmässigaste": "säsongmässig",
    "säsongmässigastes": "säsongmässig",
    "säsongmässigasts": "säsongmässig",
    "säsongmässige": "säsongmässig",
    "säsongmässiges": "säsongmässig",
    "säsongmässigs": "säsongmässig",
    "säsongmässigt": "säsongmässig",
    "säsongmässigts": "säsongmässig",
    "säsongs": "säsong",
    "säsongsinfluensan": "säsongsinfluensa",
    "säsongsinfluensans": "säsongsinfluensa",
    "säsongsinfluensas": "säsongsinfluensa",
    "säsongsinfluensor": "säsongsinfluensa",
    "säsongsinfluensorna": "säsongsinfluensa",
    "säsongsinfluensornas": "säsongsinfluensa",
    "säsongsinfluensors": "säsongsinfluensa",
    "säsongsmässiga": "säsongsmässig",
    "säsongsmässigare": "säsongsmässig",
    "säsongsmässigares": "säsongsmässig",
    "säsongsmässigas": "säsongsmässig",
    "säsongsmässigast": "säsongsmässig",
    "säsongsmässigaste": "säsongsmässig",
    "säsongsmässigastes": "säsongsmässig",
    "säsongsmässigasts": "säsongsmässig",
    "säsongsmässige": "säsongsmässig",
    "säsongsmässiges": "säsongsmässig",
    "säsongsmässigs": "säsongsmässig",
    "säsongsmässigt": "säsongsmässig",
    "säsongsmässigts": "säsongsmässig",
    "säten": "säte",
    "sätena": "säte",
    "sätenas": "säte",
    "sätens": "säte",
    "säterier": "säteri",
    "säterierna": "säteri",
    "säteriernas": "säteri",
    "säteriers": "säteri",
    "säteriet": "säteri",
    "säteriets": "säteri",
    "säteris": "säteri",
    "säterit": "säteri",
    "säteritaken": "säteritak",
    "säteritakens": "säteritak",
    "säteritaket": "säteritak",
    "säteritakets": "säteritak",
    "säteritaks": "säteritak",
    "säterits": "säteri",
    "sätern": "säter",
    "säterns": "säter",
    "säters": "säter",
    "sätes": "säte",
    "sätesbjudningar": "sätesbjudning",
    "sätesbjudningarna": "sätesbjudning",
    "sätesbjudningarnas": "sätesbjudning",
    "sätesbjudningars": "sätesbjudning",
    "sätesbjudningen": "sätesbjudning",
    "sätesbjudningens": "sätesbjudning",
    "sätesbjudnings": "sätesbjudning",
    "sätesgårdar": "sätesgård",
    "sätesgårdarna": "sätesgård",
    "sätesgårdarnas": "sätesgård",
    "sätesgårdars": "sätesgård",
    "sätesgården": "sätesgård",
    "sätesgårdens": "sätesgård",
    "sätesgårds": "sätesgård",
    "sätet": "säte",
    "sätets": "säte",
    "sätrar": "säter",
    "sätrarna": "säter",
    "sätrarnas": "säter",
    "sätrars": "säter",
    "sätt": "sätta",
    "sättande": "sätta",
    "sättanden": "sättande",
    "sättandena": "sättande",
    "sättandenas": "sättande",
    "sättandens": "sättande",
    "sättandes": "sättande",
    "sättandet": "sättande",
    "sättandets": "sättande",
    "sättar": "sättare",
    "sättaren": "sättare",
    "sättarens": "sättare",
    "sättares": "sättare",
    "sättarna": "sättare",
    "sättarnas": "sättare",
    "sättas": "sätta",
    "sätten": "sätt",
    "sättens": "sätt",
    "sätter": "sätta",
    "sätterier": "sätteri",
    "sätterierna": "sätteri",
    "sätteriernas": "sätteri",
    "sätteriers": "sätteri",
    "sätteriet": "sätteri",
    "sätteriets": "sätteri",
    "sätteris": "sätteri",
    "sätterit": "sätteri",
    "sätterits": "sätteri",
    "sättes": "sätta",
    "sättet": "sätt",
    "sättets": "sätt",
    "sätthakar": "sätthake",
    "sätthakarna": "sätthake",
    "sätthakarnas": "sätthake",
    "sätthakars": "sätthake",
    "sätthaken": "sätthake",
    "sätthakens": "sätthake",
    "sätthakes": "sätthake",
    "sättmaskinen": "sättmaskin",
    "sättmaskinens": "sättmaskin",
    "sättmaskiner": "sättmaskin",
    "sättmaskinerna": "sättmaskin",
    "sättmaskinernas": "sättmaskin",
    "sättmaskiners": "sättmaskin",
    "sättmaskins": "sättmaskin",
    "sättningar": "sättning",
    "sättningarna": "sättning",
    "sättningarnas": "sättning",
    "sättningars": "sättning",
    "sättningen": "sättning",
    "sättningens": "sättning",
    "sättnings": "sättning",
    "sättnäten": "sättnät",
    "sättnätens": "sättnät",
    "sättnätet": "sättnät",
    "sättnätets": "sättnät",
    "sättnäts": "sättnät",
    "sättpotatisar": "sättpotatis",
    "sättpotatisarna": "sättpotatis",
    "sättpotatisarnas": "sättpotatis",
    "sättpotatisars": "sättpotatis",
    "sättpotatisen": "sättpotatis",
    "sättpotatisens": "sättpotatis",
    "sätts": "sätta",
    "sättsadverbialen": "sättsadverbial",
    "sättsadverbialens": "sättsadverbial",
    "sättsadverbialet": "sättsadverbial",
    "sättsadverbialets": "sättsadverbial",
    "sättsadverbials": "sättsadverbial",
    "sättskeppen": "sättskepp",
    "sättskeppens": "sättskepp",
    "sättskeppet": "sättskepp",
    "sättskeppets": "sättskepp",
    "sättskepps": "sättskepp",
    "sättsorden": "sättsord",
    "sättsordens": "sättsord",
    "sättsordet": "sättsord",
    "sättsordets": "sättsord",
    "sättsords": "sättsord",
    "säven": "säv",
    "sävens": "säv",
    "sävliga": "sävlig",
    "sävligare": "sävlig",
    "sävligares": "sävlig",
    "sävligas": "sävlig",
    "sävligast": "sävlig",
    "sävligaste": "sävlig",
    "sävligastes": "sävlig",
    "sävligasts": "sävlig",
    "sävlige": "sävlig",
    "sävliges": "sävlig",
    "sävligheten": "sävlighet",
    "sävlighetens": "sävlighet",
    "sävlighets": "sävlighet",
    "sävligs": "sävlig",
    "sävligt": "sävlig",
    "sävligts": "sävlig",
    "sävs": "säv",
    "såar": "så",
    "såarna": "så",
    "såarnas": "så",
    "såars": "så",
    "sådan": "sån",
    "sådana": "sån",
    "sådanas": "sån",
    "sådans": "sån",
    "sådant": "sån",
    "sådants": "sån",
    "sådd": "så",
    "sådda": "så",
    "såddas": "så",
    "sådde": "så",
    "sådden": "sådd",
    "såddens": "sådd",
    "sådder": "sådd",
    "sådderna": "sådd",
    "såddernas": "sådd",
    "sådders": "sådd",
    "såddes": "så",
    "sådds": "sådd",
    "sådiga": "sådig",
    "sådigare": "sådig",
    "sådigares": "sådig",
    "sådigas": "sådig",
    "sådigast": "sådig",
    "sådigaste": "sådig",
    "sådigastes": "sådig",
    "sådigasts": "sådig",
    "sådige": "sådig",
    "sådiges": "sådig",
    "sådigs": "sådig",
    "sådigt": "sådig",
    "sådigts": "sådig",
    "sådorna": "sådor",
    "sådornas": "sådor",
    "sådors": "sådor",
    "sående": "så",
    "såenden": "sående",
    "såendena": "sående",
    "såendenas": "sående",
    "såendens": "sående",
    "såendes": "sående",
    "såendet": "sående",
    "såendets": "sående",
    "såg": "se",
    "sågad": "såga",
    "sågade": "såga",
    "sågades": "såga",
    "sågads": "såga",
    "sågande": "såga",
    "såganden": "sågande",
    "sågandena": "sågande",
    "sågandenas": "sågande",
    "sågandens": "sågande",
    "sågandes": "sågande",
    "sågandet": "sågande",
    "sågandets": "sågande",
    "sågar": "såga",
    "sågarna": "såg",
    "sågarnas": "såg",
    "sågars": "såg",
    "sågas": "såga",
    "sågat": "såga",
    "sågats": "såga",
    "sågbladen": "sågblad",
    "sågbladens": "sågblad",
    "sågbladet": "sågblad",
    "sågbladets": "sågblad",
    "sågblads": "sågblad",
    "sågbockar": "sågbock",
    "sågbockarna": "sågbock",
    "sågbockarnas": "sågbock",
    "sågbockars": "sågbock",
    "sågbocken": "sågbock",
    "sågbockens": "sågbock",
    "sågbocks": "sågbock",
    "såge": "se",
    "sågen": "såg",
    "sågens": "såg",
    "såges": "se",
    "sågfiskar": "sågfisk",
    "sågfiskarna": "sågfisk",
    "sågfiskarnas": "sågfisk",
    "sågfiskars": "sågfisk",
    "sågfisken": "sågfisk",
    "sågfiskens": "sågfisk",
    "sågfisks": "sågfisk",
    "sågkedjan": "sågkedja",
    "sågkedjans": "sågkedja",
    "sågkedjas": "sågkedja",
    "sågkedje": "sågkedja",
    "sågkedjefilar": "sågkedjefil",
    "sågkedjefilarna": "sågkedjefil",
    "sågkedjefilarnas": "sågkedjefil",
    "sågkedjefilars": "sågkedjefil",
    "sågkedjefilen": "sågkedjefil",
    "sågkedjefilens": "sågkedjefil",
    "sågkedjefils": "sågkedjefil",
    "sågkedjor": "sågkedja",
    "sågkedjorna": "sågkedja",
    "sågkedjornas": "sågkedja",
    "sågkedjors": "sågkedja",
    "sågkling": "sågklinga",
    "sågklingan": "sågklinga",
    "sågklingans": "sågklinga",
    "sågklingas": "sågklinga",
    "sågklinge": "sågklinga",
    "sågklingor": "sågklinga",
    "sågklingorna": "sågklinga",
    "sågklingornas": "sågklinga",
    "sågklingors": "sågklinga",
    "sågklings": "sågklinga",
    "sågs": "se",
    "sågspånen": "sågspån",
    "sågspånens": "sågspån",
    "sågspånet": "sågspån",
    "sågspånets": "sågspån",
    "sågspåns": "sågspån",
    "sågtaken": "sågtak",
    "sågtakens": "sågtak",
    "sågtaket": "sågtak",
    "sågtakets": "sågtak",
    "sågtaks": "sågtak",
    "sågtandade": "sågtandad",
    "sågtandades": "sågtandad",
    "sågtandads": "sågtandad",
    "sågtandat": "sågtandad",
    "sågtandats": "sågtandad",
    "sågverken": "sågverk",
    "sågverkens": "sågverk",
    "sågverket": "sågverk",
    "sågverkets": "sågverk",
    "sågverks": "sågverk",
    "sågverksarbetar": "sågverksarbetare",
    "sågverksarbetaren": "sågverksarbetare",
    "sågverksarbetarens": "sågverksarbetare",
    "sågverksarbetares": "sågverksarbetare",
    "sågverksarbetarna": "sågverksarbetare",
    "sågverksarbetarnas": "sågverksarbetare",
    "sågverksindustrien": "sågverksindustri",
    "sågverksindustriens": "sågverksindustri",
    "sågverksindustrier": "sågverksindustri",
    "sågverksindustrierna": "sågverksindustri",
    "sågverksindustriernas": "sågverksindustri",
    "sågverksindustriers": "sågverksindustri",
    "sågverksindustrin": "sågverksindustri",
    "sågverksindustrins": "sågverksindustri",
    "sågverksindustris": "sågverksindustri",
    "såld": "sälja",
    "sålda": "sälja",
    "såldare": "såld",
    "såldares": "såld",
    "såldas": "sälja",
    "såldast": "såld",
    "såldaste": "såld",
    "såldastes": "såld",
    "såldasts": "såld",
    "sålde": "sälja",
    "såldes": "sälja",
    "sålds": "sälja",
    "såll": "sålla",
    "sållad": "sålla",
    "sållade": "sålla",
    "sållades": "sålla",
    "sållads": "sålla",
    "sållande": "sålla",
    "sållanden": "sållande",
    "sållandena": "sållande",
    "sållandenas": "sållande",
    "sållandens": "sållande",
    "sållandes": "sållande",
    "sållandet": "sållande",
    "sållandets": "sållande",
    "sållar": "sålla",
    "sållas": "sålla",
    "sållat": "sålla",
    "sållats": "sålla",
    "sållen": "såll",
    "sållens": "såll",
    "sållet": "såll",
    "sållets": "såll",
    "sålls": "såll",
    "sålt": "sälja",
    "sålts": "sälja",
    "såmaskinen": "såmaskin",
    "såmaskinens": "såmaskin",
    "såmaskiner": "såmaskin",
    "såmaskinerna": "såmaskin",
    "såmaskinernas": "såmaskin",
    "såmaskiners": "såmaskin",
    "såmaskins": "såmaskin",
    "sån": "så",
    "såna": "sån",
    "sånas": "sån",
    "sångar": "sångare",
    "sångaren": "sångare",
    "sångarens": "sångare",
    "sångares": "sångare",
    "sångarfågeln": "sångarfågel",
    "sångarfågelns": "sångarfågel",
    "sångarfågels": "sångarfågel",
    "sångarfåglar": "sångarfågel",
    "sångarfåglarna": "sångarfågel",
    "sångarfåglarnas": "sångarfågel",
    "sångarfåglars": "sångarfågel",
    "sångarna": "sångare",
    "sångarnas": "sångare",
    "sångbara": "sångbar",
    "sångbarare": "sångbar",
    "sångbarares": "sångbar",
    "sångbaras": "sångbar",
    "sångbarast": "sångbar",
    "sångbaraste": "sångbar",
    "sångbarastes": "sångbar",
    "sångbarasts": "sångbar",
    "sångbare": "sångbar",
    "sångbares": "sångbar",
    "sångbarheten": "sångbarhet",
    "sångbarhetens": "sångbarhet",
    "sångbarhets": "sångbarhet",
    "sångbars": "sångbar",
    "sångbart": "sångbar",
    "sångbarts": "sångbar",
    "sången": "sång",
    "sångens": "sång",
    "sånger": "sång",
    "sångerna": "sång",
    "sångernas": "sång",
    "sångers": "sång",
    "sångerskan": "sångerska",
    "sångerskans": "sångerska",
    "sångerskas": "sångerska",
    "sångerske": "sångerska",
    "sångerskor": "sångerska",
    "sångerskorna": "sångerska",
    "sångerskornas": "sångerska",
    "sångerskors": "sångerska",
    "sångfågeln": "sångfågel",
    "sångfågelns": "sångfågel",
    "sångfågels": "sångfågel",
    "sångfåglar": "sångfågel",
    "sångfåglarna": "sångfågel",
    "sångfåglarnas": "sångfågel",
    "sångfåglars": "sångfågel",
    "sånggudinnan": "sånggudinna",
    "sånggudinnans": "sånggudinna",
    "sånggudinnas": "sånggudinna",
    "sånggudinne": "sånggudinna",
    "sånggudinnor": "sånggudinna",
    "sånggudinnorna": "sånggudinna",
    "sånggudinnornas": "sånggudinna",
    "sånggudinnors": "sånggudinna",
    "sånglekar": "sånglek",
    "sånglekarna": "sånglek",
    "sånglekarnas": "sånglek",
    "sånglekars": "sånglek",
    "sångleken": "sånglek",
    "sånglekens": "sånglek",
    "sångleks": "sånglek",
    "sångliga": "sånglig",
    "sångligare": "sånglig",
    "sångligares": "sånglig",
    "sångligas": "sånglig",
    "sångligast": "sånglig",
    "sångligaste": "sånglig",
    "sångligastes": "sånglig",
    "sångligasts": "sånglig",
    "sånglige": "sånglig",
    "sångliges": "sånglig",
    "sångligheten": "sånglighet",
    "sånglighetens": "sånglighet",
    "sånglighets": "sånglighet",
    "sångligs": "sånglig",
    "sångligt": "sånglig",
    "sångligts": "sånglig",
    "sånglärk": "sånglärka",
    "sånglärkan": "sånglärka",
    "sånglärkans": "sånglärka",
    "sånglärkas": "sånglärka",
    "sånglärke": "sånglärka",
    "sånglärkor": "sånglärka",
    "sånglärkorna": "sånglärka",
    "sånglärkornas": "sånglärka",
    "sånglärkors": "sånglärka",
    "sånglärks": "sånglärka",
    "sångmässiga": "sångmässig",
    "sångmässigare": "sångmässig",
    "sångmässigares": "sångmässig",
    "sångmässigas": "sångmässig",
    "sångmässigast": "sångmässig",
    "sångmässigaste": "sångmässig",
    "sångmässigastes": "sångmässig",
    "sångmässigasts": "sångmässig",
    "sångmässige": "sångmässig",
    "sångmässiges": "sångmässig",
    "sångmässigs": "sångmässig",
    "sångmässigt": "sångmässig",
    "sångmässigts": "sångmässig",
    "sångmön": "sångmö",
    "sångmöns": "sångmö",
    "sångmör": "sångmö",
    "sångmörna": "sångmö",
    "sångmörnas": "sångmö",
    "sångmörs": "sångmö",
    "sångmös": "sångmö",
    "sångproven": "sångprov",
    "sångprovens": "sångprov",
    "sångprovet": "sångprov",
    "sångprovets": "sångprov",
    "sångprovs": "sångprov",
    "sångrösten": "sångröst",
    "sångröstens": "sångröst",
    "sångrösts": "sångröst",
    "sångs": "sång",
    "sångspelen": "sångspel",
    "sångspelens": "sångspel",
    "sångspelet": "sångspel",
    "sångspelets": "sångspel",
    "sångspels": "sångspel",
    "sångsvanar": "sångsvan",
    "sångsvanarna": "sångsvan",
    "sångsvanarnas": "sångsvan",
    "sångsvanars": "sångsvan",
    "sångsvanen": "sångsvan",
    "sångsvanens": "sångsvan",
    "sångsvans": "sångsvan",
    "sångsätten": "sångsätt",
    "sångsättens": "sångsätt",
    "sångsättet": "sångsätt",
    "sångsättets": "sångsätt",
    "sångsätts": "sångsätt",
    "sångtekniken": "sångteknik",
    "sångteknikens": "sångteknik",
    "sångtekniker": "sångteknik",
    "sångteknikerna": "sångteknik",
    "sångteknikernas": "sångteknik",
    "sångteknikers": "sångteknik",
    "sångtekniks": "sångteknik",
    "sångteman": "sångtema",
    "sångtemana": "sångtema",
    "sångtemanas": "sångtema",
    "sångtemans": "sångtema",
    "sångtemas": "sångtema",
    "sångtemat": "sångtema",
    "sångtemata": "sångtema",
    "sångtematana": "sångtema",
    "sångtematanas": "sångtema",
    "sångtematas": "sångtema",
    "sångtemats": "sångtema",
    "sångtävlingar": "sångtävling",
    "sångtävlingarna": "sångtävling",
    "sångtävlingarnas": "sångtävling",
    "sångtävlingars": "sångtävling",
    "sångtävlingen": "sångtävling",
    "sångtävlingens": "sångtävling",
    "sångtävlings": "sångtävling",
    "sångövningar": "sångövning",
    "sångövningarna": "sångövning",
    "sångövningarnas": "sångövning",
    "sångövningars": "sångövning",
    "sångövningen": "sångövning",
    "sångövningens": "sångövning",
    "sångövnings": "sångövning",
    "såningsmannen": "såningsman",
    "såningsmannens": "såningsman",
    "såningsmans": "såningsman",
    "såningsmän": "såningsman",
    "såningsmännen": "såningsman",
    "såningsmännens": "såningsman",
    "såningsmäns": "såningsman",
    "såns": "sån",
    "sånt": "sån",
    "sånts": "sån",
    "såp": "såpa",
    "såpad": "såpa",
    "såpade": "såpa",
    "såpades": "såpa",
    "såpads": "såpa",
    "såpan": "såpa",
    "såpande": "såpa",
    "såpanden": "såpande",
    "såpandena": "såpande",
    "såpandenas": "såpande",
    "såpandens": "såpande",
    "såpandes": "såpande",
    "såpandet": "såpande",
    "såpandets": "såpande",
    "såpans": "såpa",
    "såpar": "såpa",
    "såpas": "såpa",
    "såpaskådisar": "såpaskådis",
    "såpaskådisarna": "såpaskådis",
    "såpaskådisarnas": "såpaskådis",
    "såpaskådisars": "såpaskådis",
    "såpaskådisen": "såpaskådis",
    "såpaskådisens": "såpaskådis",
    "såpat": "såpa",
    "såpats": "såpa",
    "såpbubbel": "såpbubbla",
    "såpbubblan": "såpbubbla",
    "såpbubblans": "såpbubbla",
    "såpbubblas": "såpbubbla",
    "såpbubble": "såpbubbla",
    "såpbubblor": "såpbubbla",
    "såpbubblorna": "såpbubbla",
    "såpbubblornas": "såpbubbla",
    "såpbubblors": "såpbubbla",
    "såpe": "såpa",
    "såphala": "såphal",
    "såphalare": "såphal",
    "såphalares": "såphal",
    "såphalas": "såphal",
    "såphalast": "såphal",
    "såphalaste": "såphal",
    "såphalastes": "såphal",
    "såphalasts": "såphal",
    "såphale": "såphal",
    "såphales": "såphal",
    "såphals": "såphal",
    "såphalt": "såphal",
    "såphalts": "såphal",
    "såpoperan": "såpopera",
    "såpoperans": "såpopera",
    "såpoperas": "såpopera",
    "såpoperor": "såpopera",
    "såpoperorna": "såpopera",
    "såpoperornas": "såpopera",
    "såpoperors": "såpopera",
    "såpor": "såpa",
    "såporna": "såpa",
    "såpornas": "såpa",
    "såpors": "såpa",
    "såps": "såpa",
    "såpvattens": "såpvatten",
    "såpvattnen": "såpvatten",
    "såpvattnens": "såpvatten",
    "såpvattnet": "såpvatten",
    "såpvattnets": "såpvatten",
    "sår": "såra",
    "sårad": "såra",
    "sårade": "såra",
    "sårades": "såra",
    "sårads": "såra",
    "sårande": "såra",
    "såranden": "sårande",
    "sårandena": "sårande",
    "sårandenas": "sårande",
    "sårandens": "sårande",
    "sårandes": "sårande",
    "sårandet": "sårande",
    "sårandets": "sårande",
    "sårar": "såra",
    "såras": "såra",
    "sårat": "såra",
    "sårats": "såra",
    "sårbara": "sårbar",
    "sårbarare": "sårbar",
    "sårbarares": "sårbar",
    "sårbaras": "sårbar",
    "sårbarast": "sårbar",
    "sårbaraste": "sårbar",
    "sårbarastes": "sårbar",
    "sårbarasts": "sårbar",
    "sårbare": "sårbar",
    "sårbares": "sårbar",
    "sårbarheten": "sårbarhet",
    "sårbarhetens": "sårbarhet",
    "sårbarheter": "sårbarhet",
    "sårbarheterna": "sårbarhet",
    "sårbarheternas": "sårbarhet",
    "sårbarheters": "sårbarhet",
    "sårbarhets": "sårbarhet",
    "sårbars": "sårbar",
    "sårbart": "sårbar",
    "sårbarts": "sårbar",
    "såren": "sår",
    "sårens": "sår",
    "såret": "sår",
    "sårets": "sår",
    "såriga": "sårig",
    "sårigare": "sårig",
    "sårigares": "sårig",
    "sårigas": "sårig",
    "sårigast": "sårig",
    "sårigaste": "sårig",
    "sårigastes": "sårig",
    "sårigasts": "sårig",
    "sårige": "sårig",
    "såriges": "sårig",
    "sårigheten": "sårighet",
    "sårighetens": "sårighet",
    "sårigheter": "sårighet",
    "sårigheterna": "sårighet",
    "sårigheternas": "sårighet",
    "sårigheters": "sårighet",
    "sårighets": "sårighet",
    "sårigs": "sårig",
    "sårigt": "sårig",
    "sårigts": "sårig",
    "sårinfektionen": "sårinfektion",
    "sårinfektionens": "sårinfektion",
    "sårinfektioner": "sårinfektion",
    "sårinfektionerna": "sårinfektion",
    "sårinfektionernas": "sårinfektion",
    "sårinfektioners": "sårinfektion",
    "sårinfektions": "sårinfektion",
    "sårmarkören": "sårmarkör",
    "sårmarkörens": "sårmarkör",
    "sårmarkörer": "sårmarkör",
    "sårmarkörerna": "sårmarkör",
    "sårmarkörernas": "sårmarkör",
    "sårmarkörers": "sårmarkör",
    "sårmarkörs": "sårmarkör",
    "sårnaden": "sårnad",
    "sårnadens": "sårnad",
    "sårnader": "sårnad",
    "sårnaderna": "sårnad",
    "sårnadernas": "sårnad",
    "sårnaders": "sårnad",
    "sårnads": "sårnad",
    "sårs": "sår",
    "sårskadan": "sårskada",
    "sårskadans": "sårskada",
    "sårskadas": "sårskada",
    "sårskade": "sårskada",
    "sårskador": "sårskada",
    "sårskadorna": "sårskada",
    "sårskadornas": "sårskada",
    "sårskadors": "sårskada",
    "sårskorp": "sårskorpa",
    "sårskorpan": "sårskorpa",
    "sårskorpans": "sårskorpa",
    "sårskorpas": "sårskorpa",
    "sårskorpe": "sårskorpa",
    "sårskorpor": "sårskorpa",
    "sårskorporna": "sårskorpa",
    "sårskorpornas": "sårskorpa",
    "sårskorpors": "sårskorpa",
    "sårskorps": "sårskorpa",
    "sås": "såsa",
    "såsade": "såsa",
    "såsades": "såsa",
    "såsande": "såsa",
    "såsanden": "såsande",
    "såsandena": "såsande",
    "såsandenas": "såsande",
    "såsandens": "såsande",
    "såsandes": "såsande",
    "såsandet": "såsande",
    "såsandets": "såsande",
    "såsar": "såsa",
    "såsas": "såsa",
    "såsat": "såsa",
    "såsats": "såsa",
    "såsen": "sås",
    "såsens": "sås",
    "såser": "sås",
    "såserna": "sås",
    "såsernas": "sås",
    "såsers": "sås",
    "såsiga": "såsig",
    "såsigare": "såsig",
    "såsigares": "såsig",
    "såsigas": "såsig",
    "såsigast": "såsig",
    "såsigaste": "såsig",
    "såsigastes": "såsig",
    "såsigasts": "såsig",
    "såsige": "såsig",
    "såsiges": "såsig",
    "såsigs": "såsig",
    "såsigt": "såsig",
    "såsigts": "såsig",
    "såskann": "såskanna",
    "såskannan": "såskanna",
    "såskannans": "såskanna",
    "såskannas": "såskanna",
    "såskanne": "såskanna",
    "såskannor": "såskanna",
    "såskannorna": "såskanna",
    "såskannornas": "såskanna",
    "såskannors": "såskanna",
    "såskanns": "såskanna",
    "såskoppar": "såskopp",
    "såskopparna": "såskopp",
    "såskopparnas": "såskopp",
    "såskoppars": "såskopp",
    "såskoppen": "såskopp",
    "såskoppens": "såskopp",
    "såskopps": "såskopp",
    "såt": "såte",
    "såta": "såt",
    "såtad": "såta",
    "såtade": "såta",
    "såtades": "såta",
    "såtads": "såta",
    "såtande": "såta",
    "såtanden": "såtande",
    "såtandena": "såtande",
    "såtandenas": "såtande",
    "såtandens": "såtande",
    "såtandes": "såtande",
    "såtandet": "såtande",
    "såtandets": "såtande",
    "såtar": "såte",
    "såtare": "såt",
    "såtares": "såt",
    "såtarna": "såte",
    "såtarnas": "såte",
    "såtars": "såte",
    "såtas": "såta",
    "såtast": "såt",
    "såtaste": "såt",
    "såtastes": "såt",
    "såtasts": "såt",
    "såtat": "såta",
    "såtats": "såta",
    "såte": "såt",
    "såten": "såte",
    "såtens": "såte",
    "såter": "såt",
    "såterad": "såtera",
    "såterade": "såtera",
    "såterades": "såtera",
    "såterads": "såtera",
    "såterande": "såtera",
    "såteranden": "såterande",
    "såterandena": "såterande",
    "såterandenas": "såterande",
    "såterandens": "såterande",
    "såterandes": "såterande",
    "såterandet": "såterande",
    "såterandets": "såterande",
    "såterar": "såtera",
    "såteras": "såtera",
    "såterat": "såtera",
    "såterats": "såtera",
    "såterbara": "såterbar",
    "såterbarare": "såterbar",
    "såterbarares": "såterbar",
    "såterbaras": "såterbar",
    "såterbarast": "såterbar",
    "såterbaraste": "såterbar",
    "såterbarastes": "såterbar",
    "såterbarasts": "såterbar",
    "såterbare": "såterbar",
    "såterbares": "såterbar",
    "såterbarheten": "såterbarhet",
    "såterbarhetens": "såterbarhet",
    "såterbarhets": "såterbarhet",
    "såterbars": "såterbar",
    "såterbart": "såterbar",
    "såterbarts": "såterbar",
    "såteringar": "såtering",
    "såteringarna": "såtering",
    "såteringarnas": "såtering",
    "såteringars": "såtering",
    "såteringen": "såtering",
    "såteringens": "såtering",
    "såterings": "såtering",
    "såterna": "såt",
    "såternas": "såt",
    "såters": "såt",
    "såtes": "såte",
    "såts": "såte",
    "sått": "så",
    "såtts": "så",
    "såtéer": "såté",
    "såtéerna": "såté",
    "såtéernas": "såté",
    "såtéers": "såté",
    "såtén": "såté",
    "såténs": "såté",
    "såtés": "såté",
    "såverad": "såvera",
    "såverade": "såvera",
    "såverades": "såvera",
    "såverads": "såvera",
    "såverande": "såvera",
    "såveranden": "såverande",
    "såverandena": "såverande",
    "såverandenas": "såverande",
    "såverandens": "såverande",
    "såverandes": "såverande",
    "såverandet": "såverande",
    "såverandets": "såverande",
    "såverar": "såvera",
    "såveras": "såvera",
    "såverat": "såvera",
    "såverats": "såvera",
    "såverbara": "såverbar",
    "såverbarare": "såverbar",
    "såverbarares": "såverbar",
    "såverbaras": "såverbar",
    "såverbarast": "såverbar",
    "såverbaraste": "såverbar",
    "såverbarastes": "såverbar",
    "såverbarasts": "såverbar",
    "såverbare": "såverbar",
    "såverbares": "såverbar",
    "såverbarheten": "såverbarhet",
    "såverbarhetens": "såverbarhet",
    "såverbarhets": "såverbarhet",
    "såverbars": "såverbar",
    "såverbart": "såverbar",
    "såverbarts": "såverbar",
    "såveringar": "såvering",
    "såveringarna": "såvering",
    "såveringarnas": "såvering",
    "såveringars": "såvering",
    "såveringen": "såvering",
    "såveringens": "såvering",
    "såverings": "såvering",
    "söckendagar": "söckendag",
    "söckendagarna": "söckendag",
    "söckendagarnas": "söckendag",
    "söckendagars": "söckendag",
    "söckendagen": "söckendag",
    "söckendagens": "söckendag",
    "söckendags": "söckendag",
    "södergökar": "södergök",
    "södergökarna": "södergök",
    "södergökarnas": "södergök",
    "södergökars": "södergök",
    "södergöken": "södergök",
    "södergökens": "södergök",
    "södergöks": "södergök",
    "söderkisar": "söderkis",
    "söderkisarna": "söderkis",
    "söderkisarnas": "söderkis",
    "söderkisars": "söderkis",
    "söderkisen": "söderkis",
    "söderkisens": "söderkis",
    "södermanländsk": "södermanländska",
    "södermanländska": "södermanländsk",
    "södermanländskan": "södermanländska",
    "södermanländskans": "södermanländska",
    "södermanländskare": "södermanländsk",
    "södermanländskares": "södermanländsk",
    "södermanländskas": "södermanländska",
    "södermanländskast": "södermanländsk",
    "södermanländskaste": "södermanländsk",
    "södermanländskastes": "södermanländsk",
    "södermanländskasts": "södermanländsk",
    "södermanländske": "södermanländska",
    "södermanländskes": "södermanländsk",
    "södermanländskor": "södermanländska",
    "södermanländskorna": "södermanländska",
    "södermanländskornas": "södermanländska",
    "södermanländskors": "södermanländska",
    "södermanländsks": "södermanländsk",
    "södermanländskt": "södermanländsk",
    "södermanländskts": "södermanländsk",
    "södermanlänningar": "södermanlänning",
    "södermanlänningarna": "södermanlänning",
    "södermanlänningarnas": "södermanlänning",
    "södermanlänningars": "södermanlänning",
    "södermanlänningen": "södermanlänning",
    "södermanlänningens": "södermanlänning",
    "södermanlännings": "södermanlänning",
    "södern": "söder",
    "söderns": "söder",
    "söders": "söder",
    "södersidan": "södersida",
    "södersidans": "södersida",
    "södersidas": "södersida",
    "söderside": "södersida",
    "södersides": "södersida",
    "södersidor": "södersida",
    "södersidorna": "södersida",
    "södersidornas": "södersida",
    "södersidors": "södersida",
    "södersolar": "södersol",
    "södersolarna": "södersol",
    "södersolarnas": "södersol",
    "södersolars": "södersol",
    "södersolen": "södersol",
    "södersolens": "södersol",
    "södersols": "södersol",
    "sög": "suga",
    "söge": "suga",
    "söges": "suga",
    "sögs": "suga",
    "sök": "söka",
    "sökaktiviteten": "sökaktivitet",
    "sökaktivitetens": "sökaktivitet",
    "sökaktiviteter": "sökaktivitet",
    "sökaktiviteterna": "sökaktivitet",
    "sökaktiviteternas": "sökaktivitet",
    "sökaktiviteters": "sökaktivitet",
    "sökaktivitets": "sökaktivitet",
    "sökande": "söka",
    "sökanden": "sökande",
    "sökandena": "sökande",
    "sökandenas": "sökande",
    "sökandens": "sökande",
    "sökandes": "sökande",
    "sökandet": "sökande",
    "sökandets": "sökande",
    "sökar": "sökare",
    "sökaren": "sökare",
    "sökarens": "sökare",
    "sökares": "sökare",
    "sökarljusen": "sökarljus",
    "sökarljusens": "sökarljus",
    "sökarljuset": "sökarljus",
    "sökarljusets": "sökarljus",
    "sökarna": "sökare",
    "sökarnas": "sökare",
    "sökas": "söka",
    "söker": "söka",
    "sökes": "söka",
    "söket": "sök",
    "sökets": "sök",
    "sökmotorer": "sökmotor",
    "sökmotorerna": "sökmotor",
    "sökmotorernas": "sökmotor",
    "sökmotorers": "sökmotor",
    "sökmotorn": "sökmotor",
    "sökmotorns": "sökmotor",
    "sökmotors": "sökmotor",
    "sökpådragen": "sökpådrag",
    "sökpådragens": "sökpådrag",
    "sökpådraget": "sökpådrag",
    "sökpådragets": "sökpådrag",
    "sökpådrags": "sökpådrag",
    "söks": "söka",
    "sökt": "söka",
    "sökta": "sökt",
    "söktare": "sökt",
    "söktares": "sökt",
    "söktas": "sökt",
    "söktast": "sökt",
    "söktaste": "sökt",
    "söktastes": "sökt",
    "söktasts": "sökt",
    "sökte": "sökt",
    "söktes": "sökt",
    "söktheten": "sökthet",
    "sökthetens": "sökthet",
    "sökthets": "sökthet",
    "sökts": "sökt",
    "söl": "söla",
    "sölad": "söla",
    "sölade": "söla",
    "sölades": "söla",
    "sölads": "söla",
    "sölande": "söla",
    "sölanden": "sölande",
    "sölandena": "sölande",
    "sölandenas": "sölande",
    "sölandens": "sölande",
    "sölandes": "sölande",
    "sölandet": "sölande",
    "sölandets": "sölande",
    "sölar": "söla",
    "sölas": "söla",
    "sölat": "söla",
    "sölats": "söla",
    "sölet": "söl",
    "sölets": "söl",
    "söliga": "sölig",
    "söligare": "sölig",
    "söligares": "sölig",
    "söligas": "sölig",
    "söligast": "sölig",
    "söligaste": "sölig",
    "söligastes": "sölig",
    "söligasts": "sölig",
    "sölige": "sölig",
    "söliges": "sölig",
    "söligheten": "sölighet",
    "sölighetens": "sölighet",
    "sölighets": "sölighet",
    "söligs": "sölig",
    "söligt": "sölig",
    "söligts": "sölig",
    "sölj": "sölja",
    "söljan": "sölja",
    "söljans": "sölja",
    "söljas": "sölja",
    "sölje": "sölja",
    "söljor": "sölja",
    "söljorna": "sölja",
    "söljornas": "sölja",
    "söljors": "sölja",
    "söljs": "sölja",
    "sölkorvar": "sölkorv",
    "sölkorvarna": "sölkorv",
    "sölkorvarnas": "sölkorv",
    "sölkorvars": "sölkorv",
    "sölkorven": "sölkorv",
    "sölkorvens": "sölkorv",
    "sölkorvs": "sölkorv",
    "söls": "söl",
    "sömmad": "sömma",
    "sömmade": "sömma",
    "sömmades": "sömma",
    "sömmads": "sömma",
    "sömmande": "sömma",
    "sömmanden": "sömmande",
    "sömmandena": "sömmande",
    "sömmandenas": "sömmande",
    "sömmandens": "sömmande",
    "sömmandes": "sömmande",
    "sömmandet": "sömmande",
    "sömmandets": "sömmande",
    "sömmar": "sömmare",
    "sömmaren": "sömmare",
    "sömmarens": "sömmare",
    "sömmares": "sömmare",
    "sömmarna": "sömmare",
    "sömmarnas": "sömmare",
    "sömmars": "söm",
    "sömmas": "sömma",
    "sömmat": "sömma",
    "sömmats": "sömma",
    "sömmen": "söm",
    "sömmens": "söm",
    "sömmerskan": "sömmerska",
    "sömmerskans": "sömmerska",
    "sömmerskas": "sömmerska",
    "sömmerske": "sömmerska",
    "sömmersketipsen": "sömmersketips",
    "sömmersketipsens": "sömmersketips",
    "sömmersketipset": "sömmersketips",
    "sömmersketipsets": "sömmersketips",
    "sömmerskor": "sömmerska",
    "sömmerskorna": "sömmerska",
    "sömmerskornas": "sömmerska",
    "sömmerskors": "sömmerska",
    "sömmet": "söm",
    "sömmets": "söm",
    "sömnaden": "sömnad",
    "sömnadens": "sömnad",
    "sömnader": "sömnad",
    "sömnaderna": "sömnad",
    "sömnadernas": "sömnad",
    "sömnaders": "sömnad",
    "sömnads": "sömnad",
    "sömnapnéer": "sömnapné",
    "sömnapnéerna": "sömnapné",
    "sömnapnéernas": "sömnapné",
    "sömnapnéers": "sömnapné",
    "sömnapnén": "sömnapné",
    "sömnapnéns": "sömnapné",
    "sömnapnés": "sömnapné",
    "sömnbristen": "sömnbrist",
    "sömnbristens": "sömnbrist",
    "sömnbrists": "sömnbrist",
    "sömndruckens": "sömndrucken",
    "sömndrucket": "sömndrucken",
    "sömndruckets": "sömndrucken",
    "sömndruckna": "sömndrucken",
    "sömndrucknare": "sömndrucken",
    "sömndrucknares": "sömndrucken",
    "sömndrucknas": "sömndrucken",
    "sömndrucknast": "sömndrucken",
    "sömndrucknaste": "sömndrucken",
    "sömndrucknastes": "sömndrucken",
    "sömndrucknasts": "sömndrucken",
    "sömndruckne": "sömndrucken",
    "sömndrucknes": "sömndrucken",
    "sömnen": "sömn",
    "sömnens": "sömn",
    "sömngångar": "sömngångare",
    "sömngångaraktiga": "sömngångaraktig",
    "sömngångaraktigare": "sömngångaraktig",
    "sömngångaraktigares": "sömngångaraktig",
    "sömngångaraktigas": "sömngångaraktig",
    "sömngångaraktigast": "sömngångaraktig",
    "sömngångaraktigaste": "sömngångaraktig",
    "sömngångaraktigastes": "sömngångaraktig",
    "sömngångaraktigasts": "sömngångaraktig",
    "sömngångaraktige": "sömngångaraktig",
    "sömngångaraktiges": "sömngångaraktig",
    "sömngångaraktigheten": "sömngångaraktighet",
    "sömngångaraktighetens": "sömngångaraktighet",
    "sömngångaraktighets": "sömngångaraktighet",
    "sömngångaraktigs": "sömngångaraktig",
    "sömngångaraktigt": "sömngångaraktig",
    "sömngångaraktigts": "sömngångaraktig",
    "sömngångaren": "sömngångare",
    "sömngångarens": "sömngångare",
    "sömngångares": "sömngångare",
    "sömngångarna": "sömngångare",
    "sömngångarnas": "sömngångare",
    "sömniga": "sömnig",
    "sömnigare": "sömnig",
    "sömnigares": "sömnig",
    "sömnigas": "sömnig",
    "sömnigast": "sömnig",
    "sömnigaste": "sömnig",
    "sömnigastes": "sömnig",
    "sömnigasts": "sömnig",
    "sömnige": "sömnig",
    "sömniges": "sömnig",
    "sömnigheten": "sömnighet",
    "sömnighetens": "sömnighet",
    "sömnighets": "sömnighet",
    "sömnigs": "sömnig",
    "sömnigt": "sömnig",
    "sömnigts": "sömnig",
    "sömnlösa": "sömnlös",
    "sömnlösare": "sömnlös",
    "sömnlösares": "sömnlös",
    "sömnlösas": "sömnlös",
    "sömnlösast": "sömnlös",
    "sömnlösaste": "sömnlös",
    "sömnlösastes": "sömnlös",
    "sömnlösasts": "sömnlös",
    "sömnlöse": "sömnlös",
    "sömnlöses": "sömnlös",
    "sömnlösheten": "sömnlöshet",
    "sömnlöshetens": "sömnlöshet",
    "sömnlöshets": "sömnlöshet",
    "sömnlöst": "sömnlös",
    "sömnlösts": "sömnlös",
    "sömnmedels": "sömnmedel",
    "sömnmedlen": "sömnmedel",
    "sömnmedlens": "sömnmedel",
    "sömnmedlet": "sömnmedel",
    "sömnmedlets": "sömnmedel",
    "sömnproblemen": "sömnproblem",
    "sömnproblemens": "sömnproblem",
    "sömnproblemet": "sömnproblem",
    "sömnproblemets": "sömnproblem",
    "sömnproblems": "sömnproblem",
    "sömns": "sömn",
    "sömnsjukan": "sömnsjuka",
    "sömnsjukans": "sömnsjuka",
    "sömnsjukas": "sömnsjuka",
    "sömnsjuke": "sömnsjuka",
    "sömnsjuks": "sömnsjuka",
    "sömnstörningar": "sömnstörning",
    "sömnstörningarna": "sömnstörning",
    "sömnstörningarnas": "sömnstörning",
    "sömnstörningars": "sömnstörning",
    "sömnstörningen": "sömnstörning",
    "sömnstörningens": "sömnstörning",
    "sömnstörnings": "sömnstörning",
    "sömnsvårigheten": "sömnsvårighet",
    "sömnsvårighetens": "sömnsvårighet",
    "sömnsvårigheter": "sömnsvårighet",
    "sömnsvårigheterna": "sömnsvårighet",
    "sömnsvårigheternas": "sömnsvårighet",
    "sömnsvårigheters": "sömnsvårighet",
    "sömnsvårighets": "sömnsvårighet",
    "sömntabletten": "sömntablett",
    "sömntablettens": "sömntablett",
    "sömntabletter": "sömntablett",
    "sömntabletterna": "sömntablett",
    "sömntabletternas": "sömntablett",
    "sömntabletters": "sömntablett",
    "sömntabletts": "sömntablett",
    "sömntunga": "sömntung",
    "sömntungare": "sömntung",
    "sömntungares": "sömntung",
    "sömntungas": "sömntung",
    "sömntungast": "sömntung",
    "sömntungaste": "sömntung",
    "sömntungastes": "sömntung",
    "sömntungasts": "sömntung",
    "sömntunge": "sömntung",
    "sömntunges": "sömntung",
    "sömntungheten": "sömntunghet",
    "sömntunghetens": "sömntunghet",
    "sömntunghets": "sömntunghet",
    "sömntungs": "sömntung",
    "sömntungt": "sömntung",
    "sömntungts": "sömntung",
    "sömntut": "sömntuta",
    "sömntutan": "sömntuta",
    "sömntutans": "sömntuta",
    "sömntutas": "sömntuta",
    "sömntute": "sömntuta",
    "sömntutor": "sömntuta",
    "sömntutorna": "sömntuta",
    "sömntutornas": "sömntuta",
    "sömntutors": "sömntuta",
    "sömntuts": "sömntuta",
    "söms": "söm",
    "sömsmånen": "sömsmån",
    "sömsmånens": "sömsmån",
    "sömsmåner": "sömsmån",
    "sömsmånerna": "sömsmån",
    "sömsmånernas": "sömsmån",
    "sömsmåners": "sömsmån",
    "sömsmåns": "sömsmån",
    "söndagar": "söndag",
    "söndagarna": "söndag",
    "söndagarnas": "söndag",
    "söndagars": "söndag",
    "söndageftermiddagar": "söndageftermiddag",
    "söndageftermiddagarna": "söndageftermiddag",
    "söndageftermiddagarnas": "söndageftermiddag",
    "söndageftermiddagars": "söndageftermiddag",
    "söndageftermiddagen": "söndageftermiddag",
    "söndageftermiddagens": "söndageftermiddag",
    "söndageftermiddags": "söndageftermiddag",
    "söndagen": "söndag",
    "söndagens": "söndag",
    "söndagkvällar": "söndagkväll",
    "söndagkvällarna": "söndagkväll",
    "söndagkvällarnas": "söndagkväll",
    "söndagkvällars": "söndagkväll",
    "söndagkvällen": "söndagkväll",
    "söndagkvällens": "söndagkväll",
    "söndagkvälls": "söndagkväll",
    "söndagmorgnar": "söndagmorgon",
    "söndagmorgnarna": "söndagmorgon",
    "söndagmorgnarnas": "söndagmorgon",
    "söndagmorgnars": "söndagmorgon",
    "söndagmorgonen": "söndagmorgon",
    "söndagmorgonens": "söndagmorgon",
    "söndagmorgons": "söndagmorgon",
    "söndagmornar": "söndagmorgon",
    "söndagmornarna": "söndagmorgon",
    "söndagmornarnas": "söndagmorgon",
    "söndagmornars": "söndagmorgon",
    "söndags": "söndag",
    "söndagsbarnen": "söndagsbarn",
    "söndagsbarnens": "söndagsbarn",
    "söndagsbarnet": "söndagsbarn",
    "söndagsbarnets": "söndagsbarn",
    "söndagsbarns": "söndagsbarn",
    "söndagsbilag": "söndagsbilaga",
    "söndagsbilagan": "söndagsbilaga",
    "söndagsbilagans": "söndagsbilaga",
    "söndagsbilagas": "söndagsbilaga",
    "söndagsbilage": "söndagsbilaga",
    "söndagsbilagor": "söndagsbilaga",
    "söndagsbilagorna": "söndagsbilaga",
    "söndagsbilagornas": "söndagsbilaga",
    "söndagsbilagors": "söndagsbilaga",
    "söndagsbilags": "söndagsbilaga",
    "söndagsbokstaven": "söndagsbokstav",
    "söndagsbokstavens": "söndagsbokstav",
    "söndagsbokstavs": "söndagsbokstav",
    "söndagsbokstäver": "söndagsbokstav",
    "söndagsbokstäverna": "söndagsbokstav",
    "söndagsbokstävernas": "söndagsbokstav",
    "söndagsbokstävers": "söndagsbokstav",
    "söndagseftermiddagar": "söndagseftermiddag",
    "söndagseftermiddagarna": "söndagseftermiddag",
    "söndagseftermiddagarnas": "söndagseftermiddag",
    "söndagseftermiddagars": "söndagseftermiddag",
    "söndagseftermiddagen": "söndagseftermiddag",
    "söndagseftermiddagens": "söndagseftermiddag",
    "söndagseftermiddags": "söndagseftermiddag",
    "söndagsjägar": "söndagsjägare",
    "söndagsjägaren": "söndagsjägare",
    "söndagsjägarens": "söndagsjägare",
    "söndagsjägares": "söndagsjägare",
    "söndagsjägarna": "söndagsjägare",
    "söndagsjägarnas": "söndagsjägare",
    "söndagskvällar": "söndagskväll",
    "söndagskvällarna": "söndagskväll",
    "söndagskvällarnas": "söndagskväll",
    "söndagskvällars": "söndagskväll",
    "söndagskvällen": "söndagskväll",
    "söndagskvällens": "söndagskväll",
    "söndagskvälls": "söndagskväll",
    "söndagsmorgnar": "söndagsmorgon",
    "söndagsmorgnarna": "söndagsmorgon",
    "söndagsmorgnarnas": "söndagsmorgon",
    "söndagsmorgnars": "söndagsmorgon",
    "söndagsmorgonen": "söndagsmorgon",
    "söndagsmorgonens": "söndagsmorgon",
    "söndagsmorgons": "söndagsmorgon",
    "söndagsmornar": "söndagsmorgon",
    "söndagsmornarna": "söndagsmorgon",
    "söndagsmornarnas": "söndagsmorgon",
    "söndagsmornars": "söndagsmorgon",
    "söndagspappan": "söndagspappa",
    "söndagspappans": "söndagspappa",
    "söndagspappas": "söndagspappa",
    "söndagspappor": "söndagspappa",
    "söndagspapporna": "söndagspappa",
    "söndagspappornas": "söndagspappa",
    "söndagspappors": "söndagspappa",
    "söndagsskolan": "söndagsskola",
    "söndagsskolans": "söndagsskola",
    "söndagsskolas": "söndagsskola",
    "söndagsskole": "söndagsskola",
    "söndagsskolefrökens": "söndagsskolefröken",
    "söndagsskolefröknar": "söndagsskolefröken",
    "söndagsskolefröknarna": "söndagsskolefröken",
    "söndagsskolefröknarnas": "söndagsskolefröken",
    "söndagsskolefröknars": "söndagsskolefröken",
    "söndagsskolefröknen": "söndagsskolefröken",
    "söndagsskolefröknens": "söndagsskolefröken",
    "söndagsskolor": "söndagsskola",
    "söndagsskolorna": "söndagsskola",
    "söndagsskolornas": "söndagsskola",
    "söndagsskolors": "söndagsskola",
    "sönderbrända": "sönderbränd",
    "sönderbrändare": "sönderbränd",
    "sönderbrändares": "sönderbränd",
    "sönderbrändas": "sönderbränd",
    "sönderbrändast": "sönderbränd",
    "sönderbrändaste": "sönderbränd",
    "sönderbrändastes": "sönderbränd",
    "sönderbrändasts": "sönderbränd",
    "sönderbrände": "sönderbränd",
    "sönderbrändes": "sönderbränd",
    "sönderbrändheten": "sönderbrändhet",
    "sönderbrändhetens": "sönderbrändhet",
    "sönderbrändhets": "sönderbrändhet",
    "sönderbränds": "sönderbränd",
    "sönderbränt": "sönderbränd",
    "sönderbränts": "sönderbränd",
    "sönderdel": "sönderdela",
    "sönderdelad": "sönderdela",
    "sönderdelade": "sönderdela",
    "sönderdelades": "sönderdela",
    "sönderdelads": "sönderdela",
    "sönderdelande": "sönderdela",
    "sönderdelanden": "sönderdelande",
    "sönderdelandena": "sönderdelande",
    "sönderdelandenas": "sönderdelande",
    "sönderdelandens": "sönderdelande",
    "sönderdelandes": "sönderdelande",
    "sönderdelandet": "sönderdelande",
    "sönderdelandets": "sönderdelande",
    "sönderdelar": "sönderdela",
    "sönderdelas": "sönderdela",
    "sönderdelat": "sönderdela",
    "sönderdelats": "sönderdela",
    "sönderdelningar": "sönderdelning",
    "sönderdelningarna": "sönderdelning",
    "sönderdelningarnas": "sönderdelning",
    "sönderdelningars": "sönderdelning",
    "sönderdelningen": "sönderdelning",
    "sönderdelningens": "sönderdelning",
    "sönderdelnings": "sönderdelning",
    "sönderfall": "sönderfalla",
    "sönderfallande": "sönderfalla",
    "sönderfallanden": "sönderfallande",
    "sönderfallandena": "sönderfallande",
    "sönderfallandenas": "sönderfallande",
    "sönderfallandens": "sönderfallande",
    "sönderfallandes": "sönderfallande",
    "sönderfallandet": "sönderfallande",
    "sönderfallandets": "sönderfallande",
    "sönderfallas": "sönderfalla",
    "sönderfalle": "sönderfalla",
    "sönderfallen": "sönderfalla",
    "sönderfallens": "sönderfalla",
    "sönderfaller": "sönderfalla",
    "sönderfalles": "sönderfalla",
    "sönderfallet": "sönderfalla",
    "sönderfallets": "sönderfalla",
    "sönderfallit": "sönderfalla",
    "sönderfallits": "sönderfalla",
    "sönderfallna": "sönderfalla",
    "sönderfallnas": "sönderfalla",
    "sönderfallne": "sönderfalla",
    "sönderfallnes": "sönderfalla",
    "sönderfalls": "sönderfalla",
    "sönderföll": "sönderfalla",
    "sönderfölle": "sönderfalla",
    "sönderfölles": "sönderfalla",
    "sönderfölls": "sönderfalla",
    "sönderhack": "sönderhacka",
    "sönderhackad": "sönderhacka",
    "sönderhackade": "sönderhacka",
    "sönderhackades": "sönderhacka",
    "sönderhackads": "sönderhacka",
    "sönderhackande": "sönderhacka",
    "sönderhackanden": "sönderhackande",
    "sönderhackandena": "sönderhackande",
    "sönderhackandenas": "sönderhackande",
    "sönderhackandens": "sönderhackande",
    "sönderhackandes": "sönderhackande",
    "sönderhackandet": "sönderhackande",
    "sönderhackandets": "sönderhackande",
    "sönderhackar": "sönderhacka",
    "sönderhackas": "sönderhacka",
    "sönderhackat": "sönderhacka",
    "sönderhackats": "sönderhacka",
    "sönderkörde": "sönderkörd",
    "sönderkördes": "sönderkörd",
    "sönderkörds": "sönderkörd",
    "sönderkört": "sönderkörd",
    "sönderkörts": "sönderkörd",
    "sönderplockade": "sönderplockad",
    "sönderplockades": "sönderplockad",
    "sönderplockads": "sönderplockad",
    "sönderplockat": "sönderplockad",
    "sönderplockats": "sönderplockad",
    "sönderrev": "sönderriva",
    "sönderrevs": "sönderriva",
    "sönderriv": "sönderriva",
    "sönderrivande": "sönderriva",
    "sönderrivanden": "sönderrivande",
    "sönderrivandena": "sönderrivande",
    "sönderrivandenas": "sönderrivande",
    "sönderrivandens": "sönderrivande",
    "sönderrivandes": "sönderrivande",
    "sönderrivandet": "sönderrivande",
    "sönderrivandets": "sönderrivande",
    "sönderrivas": "sönderriva",
    "sönderrive": "sönderriva",
    "sönderriven": "sönderriva",
    "sönderrivens": "sönderriva",
    "sönderriver": "sönderriva",
    "sönderrives": "sönderriva",
    "sönderrivet": "sönderriva",
    "sönderrivets": "sönderriva",
    "sönderrivit": "sönderriva",
    "sönderrivits": "sönderriva",
    "sönderrivna": "sönderriva",
    "sönderrivnas": "sönderriva",
    "sönderrivne": "sönderriva",
    "sönderrivnes": "sönderriva",
    "sönderrivs": "sönderriva",
    "sönderrostade": "sönderrostad",
    "sönderrostades": "sönderrostad",
    "sönderrostads": "sönderrostad",
    "sönderrostat": "sönderrostad",
    "sönderrostats": "sönderrostad",
    "sönderspekulerade": "sönderspekulerad",
    "sönderspekulerades": "sönderspekulerad",
    "sönderspekulerads": "sönderspekulerad",
    "sönderspekulerat": "sönderspekulerad",
    "sönderspekulerats": "sönderspekulerad",
    "sönderspräng": "sönderspränga",
    "söndersprängande": "sönderspränga",
    "sönderspränganden": "söndersprängande",
    "söndersprängandena": "söndersprängande",
    "söndersprängandenas": "söndersprängande",
    "söndersprängandens": "söndersprängande",
    "söndersprängandes": "söndersprängande",
    "söndersprängandet": "söndersprängande",
    "söndersprängandets": "söndersprängande",
    "söndersprängas": "sönderspränga",
    "söndersprängd": "sönderspränga",
    "söndersprängda": "sönderspränga",
    "söndersprängdas": "sönderspränga",
    "söndersprängde": "sönderspränga",
    "söndersprängdes": "sönderspränga",
    "söndersprängds": "sönderspränga",
    "sönderspränger": "sönderspränga",
    "sönderspränges": "sönderspränga",
    "söndersprängningar": "söndersprängning",
    "söndersprängningarna": "söndersprängning",
    "söndersprängningarnas": "söndersprängning",
    "söndersprängningars": "söndersprängning",
    "söndersprängningen": "söndersprängning",
    "söndersprängningens": "söndersprängning",
    "söndersprängnings": "söndersprängning",
    "söndersprängs": "sönderspränga",
    "söndersprängt": "sönderspränga",
    "söndersprängts": "sönderspränga",
    "söndertrasade": "söndertrasad",
    "söndertrasades": "söndertrasad",
    "söndertrasads": "söndertrasad",
    "söndertrasat": "söndertrasad",
    "söndertrasats": "söndertrasad",
    "sönderälskade": "sönderälskad",
    "sönderälskades": "sönderälskad",
    "sönderälskads": "sönderälskad",
    "sönderälskat": "sönderälskad",
    "sönderälskats": "sönderälskad",
    "söndrad": "söndra",
    "söndrade": "söndra",
    "söndrades": "söndra",
    "söndrads": "söndra",
    "söndrande": "söndra",
    "söndranden": "söndrande",
    "söndrandena": "söndrande",
    "söndrandenas": "söndrande",
    "söndrandens": "söndrande",
    "söndrandes": "söndrande",
    "söndrandet": "söndrande",
    "söndrandets": "söndrande",
    "söndrar": "söndra",
    "söndras": "söndra",
    "söndrat": "söndra",
    "söndrats": "söndra",
    "söndriga": "söndrig",
    "söndrigare": "söndrig",
    "söndrigares": "söndrig",
    "söndrigas": "söndrig",
    "söndrigast": "söndrig",
    "söndrigaste": "söndrig",
    "söndrigastes": "söndrig",
    "söndrigasts": "söndrig",
    "söndrige": "söndrig",
    "söndriges": "söndrig",
    "söndrigheten": "söndrighet",
    "söndrighetens": "söndrighet",
    "söndrighets": "söndrighet",
    "söndrigs": "söndrig",
    "söndrigt": "söndrig",
    "söndrigts": "söndrig",
    "söndringar": "söndring",
    "söndringarna": "söndring",
    "söndringarnas": "söndring",
    "söndringars": "söndring",
    "söndringen": "söndring",
    "söndringens": "söndring",
    "söndrings": "söndring",
    "söner": "son",
    "sönerna": "son",
    "sönernas": "son",
    "söners": "son",
    "söp": "supa",
    "söpe": "supa",
    "söpes": "supa",
    "söps": "supa",
    "sörgårdsidyllen": "sörgårdsidyll",
    "sörgårdsidyllens": "sörgårdsidyll",
    "sörgårdsidyller": "sörgårdsidyll",
    "sörgårdsidyllerna": "sörgårdsidyll",
    "sörgårdsidyllernas": "sörgårdsidyll",
    "sörgårdsidyllers": "sörgårdsidyll",
    "sörgårdsidylls": "sörgårdsidyll",
    "sörj": "sörja",
    "sörjan": "sörja",
    "sörjande": "sörja",
    "sörjanden": "sörjande",
    "sörjandena": "sörjande",
    "sörjandenas": "sörjande",
    "sörjandens": "sörjande",
    "sörjandes": "sörjande",
    "sörjandet": "sörjande",
    "sörjandets": "sörjande",
    "sörjans": "sörja",
    "sörjas": "sörja",
    "sörjd": "sörja",
    "sörjda": "sörja",
    "sörjdas": "sörja",
    "sörjde": "sörja",
    "sörjdes": "sörja",
    "sörjds": "sörja",
    "sörjer": "sörja",
    "sörjes": "sörja",
    "sörjs": "sörja",
    "sörjt": "sörja",
    "sörjts": "sörja",
    "sörländska": "sörländsk",
    "sörländskare": "sörländsk",
    "sörländskares": "sörländsk",
    "sörländskas": "sörländsk",
    "sörländskast": "sörländsk",
    "sörländskaste": "sörländsk",
    "sörländskastes": "sörländsk",
    "sörländskasts": "sörländsk",
    "sörländske": "sörländsk",
    "sörländskes": "sörländsk",
    "sörländsks": "sörländsk",
    "sörländskt": "sörländsk",
    "sörländskts": "sörländsk",
    "sörlänningar": "sörlänning",
    "sörlänningarna": "sörlänning",
    "sörlänningarnas": "sörlänning",
    "sörlänningars": "sörlänning",
    "sörlänningen": "sörlänning",
    "sörlänningens": "sörlänning",
    "sörlännings": "sörlänning",
    "sörmländsk": "sörmländska",
    "sörmländska": "sörmländsk",
    "sörmländskan": "sörmländska",
    "sörmländskans": "sörmländska",
    "sörmländskare": "sörmländsk",
    "sörmländskares": "sörmländsk",
    "sörmländskas": "sörmländska",
    "sörmländskast": "sörmländsk",
    "sörmländskaste": "sörmländsk",
    "sörmländskastes": "sörmländsk",
    "sörmländskasts": "sörmländsk",
    "sörmländske": "sörmländska",
    "sörmländskes": "sörmländsk",
    "sörmländskor": "sörmländska",
    "sörmländskorna": "sörmländska",
    "sörmländskornas": "sörmländska",
    "sörmländskors": "sörmländska",
    "sörmländsks": "sörmländsk",
    "sörmländskt": "sörmländsk",
    "sörmländskts": "sörmländsk",
    "sörmlänningar": "sörmlänning",
    "sörmlänningarna": "sörmlänning",
    "sörmlänningarnas": "sörmlänning",
    "sörmlänningars": "sörmlänning",
    "sörmlänningen": "sörmlänning",
    "sörmlänningens": "sörmlänning",
    "sörmlännings": "sörmlänning",
    "sörpan": "sörpa",
    "sörpans": "sörpa",
    "sörpas": "sörpa",
    "sörpel": "sörpla",
    "sörplade": "sörpla",
    "sörplades": "sörpla",
    "sörplande": "sörpla",
    "sörplanden": "sörplande",
    "sörplandena": "sörplande",
    "sörplandenas": "sörplande",
    "sörplandens": "sörplande",
    "sörplandes": "sörplande",
    "sörplandet": "sörplande",
    "sörplandets": "sörplande",
    "sörplar": "sörpla",
    "sörplas": "sörpla",
    "sörplat": "sörpla",
    "sörplats": "sörpla",
    "söt": "söta",
    "söta": "söt",
    "sötad": "söta",
    "sötade": "söta",
    "sötades": "söta",
    "sötads": "söta",
    "sötaktiga": "sötaktig",
    "sötaktigare": "sötaktig",
    "sötaktigares": "sötaktig",
    "sötaktigas": "sötaktig",
    "sötaktigast": "sötaktig",
    "sötaktigaste": "sötaktig",
    "sötaktigastes": "sötaktig",
    "sötaktigasts": "sötaktig",
    "sötaktige": "sötaktig",
    "sötaktiges": "sötaktig",
    "sötaktigheten": "sötaktighet",
    "sötaktighetens": "sötaktighet",
    "sötaktighets": "sötaktighet",
    "sötaktigs": "sötaktig",
    "sötaktigt": "sötaktig",
    "sötaktigts": "sötaktig",
    "sötande": "söta",
    "sötanden": "sötande",
    "sötandena": "sötande",
    "sötandenas": "sötande",
    "sötandens": "sötande",
    "sötandes": "sötande",
    "sötandet": "sötande",
    "sötandets": "sötande",
    "sötar": "söta",
    "sötare": "söt",
    "sötares": "söt",
    "sötas": "söta",
    "sötast": "söt",
    "sötaste": "söt",
    "sötastes": "söt",
    "sötasts": "söt",
    "sötat": "söta",
    "sötats": "söta",
    "söte": "söt",
    "sötebrödsdagarna": "sötebrödsdagar",
    "sötebrödsdagarnas": "sötebrödsdagar",
    "sötebrödsdagars": "sötebrödsdagar",
    "sötebrödsdags": "sötebrödsdagar",
    "sötes": "söt",
    "sötheten": "söthet",
    "söthetens": "söthet",
    "söthets": "söthet",
    "sötman": "sötma",
    "sötmandeln": "sötmandel",
    "sötmandelns": "sötmandel",
    "sötmandels": "sötmandel",
    "sötmandlar": "sötmandel",
    "sötmandlarna": "sötmandel",
    "sötmandlarnas": "sötmandel",
    "sötmandlars": "sötmandel",
    "sötmans": "sötma",
    "sötmas": "sötma",
    "sötmjölken": "sötmjölk",
    "sötmjölkens": "sötmjölk",
    "sötmjölks": "sötmjölk",
    "sötningsmedels": "sötningsmedel",
    "sötningsmedlen": "sötningsmedel",
    "sötningsmedlens": "sötningsmedel",
    "sötningsmedlet": "sötningsmedel",
    "sötningsmedlets": "sötningsmedel",
    "sötnosar": "sötnos",
    "sötnosarna": "sötnos",
    "sötnosarnas": "sötnos",
    "sötnosars": "sötnos",
    "sötnosen": "sötnos",
    "sötnosens": "sötnos",
    "sötpotatisar": "sötpotatis",
    "sötpotatisarna": "sötpotatis",
    "sötpotatisarnas": "sötpotatis",
    "sötpotatisars": "sötpotatis",
    "sötpotatisen": "sötpotatis",
    "sötpotatisens": "sötpotatis",
    "söts": "söt",
    "sötsaken": "sötsak",
    "sötsakens": "sötsak",
    "sötsaker": "sötsak",
    "sötsakerna": "sötsak",
    "sötsakernas": "sötsak",
    "sötsakers": "sötsak",
    "sötsaks": "sötsak",
    "sötsliskiga": "sötsliskig",
    "sötsliskigare": "sötsliskig",
    "sötsliskigares": "sötsliskig",
    "sötsliskigas": "sötsliskig",
    "sötsliskigast": "sötsliskig",
    "sötsliskigaste": "sötsliskig",
    "sötsliskigastes": "sötsliskig",
    "sötsliskigasts": "sötsliskig",
    "sötsliskige": "sötsliskig",
    "sötsliskiges": "sötsliskig",
    "sötsliskigheten": "sötsliskighet",
    "sötsliskighetens": "sötsliskighet",
    "sötsliskighets": "sötsliskighet",
    "sötsliskigs": "sötsliskig",
    "sötsliskigt": "sötsliskig",
    "sötsliskigts": "sötsliskig",
    "sötsuget": "sötsug",
    "sötsugets": "sötsug",
    "sötsugs": "sötsug",
    "sötsura": "sötsur",
    "sötsurare": "sötsur",
    "sötsurares": "sötsur",
    "sötsuras": "sötsur",
    "sötsurast": "sötsur",
    "sötsuraste": "sötsur",
    "sötsurastes": "sötsur",
    "sötsurasts": "sötsur",
    "sötsure": "sötsur",
    "sötsures": "sötsur",
    "sötsurheten": "sötsurhet",
    "sötsurhetens": "sötsurhet",
    "sötsurhets": "sötsurhet",
    "sötsurs": "sötsur",
    "sötsurt": "sötsur",
    "sötsurts": "sötsur",
    "sött": "söt",
    "sötts": "söt",
    "sötvattens": "sötvatten",
    "sötvattensforskar": "sötvattensforskare",
    "sötvattensforskaren": "sötvattensforskare",
    "sötvattensforskarens": "sötvattensforskare",
    "sötvattensforskares": "sötvattensforskare",
    "sötvattensforskarna": "sötvattensforskare",
    "sötvattensforskarnas": "sötvattensforskare",
    "sötvattensnäck": "sötvattensnäcka",
    "sötvattensnäckan": "sötvattensnäcka",
    "sötvattensnäckans": "sötvattensnäcka",
    "sötvattensnäckas": "sötvattensnäcka",
    "sötvattensnäcke": "sötvattensnäcka",
    "sötvattensnäckor": "sötvattensnäcka",
    "sötvattensnäckorna": "sötvattensnäcka",
    "sötvattensnäckornas": "sötvattensnäcka",
    "sötvattensnäckors": "sötvattensnäcka",
    "sötvattensnäcks": "sötvattensnäcka",
    "sötvattnen": "sötvatten",
    "sötvattnens": "sötvatten",
    "sötvattnet": "sötvatten",
    "sötvattnets": "sötvatten",
    "söv": "söva",
    "sövande": "söva",
    "sövanden": "sövande",
    "sövandena": "sövande",
    "sövandenas": "sövande",
    "sövandens": "sövande",
    "sövandes": "sövande",
    "sövandet": "sövande",
    "sövandets": "sövande",
    "sövas": "söva",
    "sövd": "söva",
    "sövda": "söva",
    "sövdas": "söva",
    "sövde": "söva",
    "sövdes": "söva",
    "sövds": "söva",
    "söver": "söva",
    "söves": "söva",
    "sövs": "söva",
    "sövt": "söva",
    "sövts": "söva",
    "t-et": "t",
    "t-ets": "t",
    "t-n": "t",
    "t-na": "t",
    "t-nas": "t",
    "t-ns": "t",
    "t-shirtar": "t-shirt",
    "t-shirtarnas": "t-shirt",
    "t-shirten": "t-shirt",
    "t-shirts": "t-shirt",
    "t-t": "t",
    "t-tröjans": "t-tröja",
    "t-tröje": "t-tröja",
    "t-tröjor": "t-tröja",
    "t-tröjornas": "t-tröja",
    "t-tröjors": "t-tröja",
    "t-ts": "t",
    "t:et": "t",
    "t:ets": "t",
    "t:n": "t",
    "t:na": "t",
    "t:nas": "t",
    "t:ns": "t",
    "t:s": "t",
    "t:t": "t",
    "t:ts": "t",
    "tRNA-er": "tRNA",
    "tRNA-erna": "tRNA",
    "tRNA-ernas": "tRNA",
    "tRNA-ers": "tRNA",
    "tRNA-n": "tRNA",
    "tRNA-na": "tRNA",
    "tRNA-nas": "tRNA",
    "tRNA-ns": "tRNA",
    "tRNA-s": "tRNA",
    "tRNA-t": "tRNA",
    "tRNA-ts": "tRNA",
    "tRNA:er": "tRNA",
    "tRNA:erna": "tRNA",
    "tRNA:ernas": "tRNA",
    "tRNA:ers": "tRNA",
    "tRNA:n": "tRNA",
    "tRNA:na": "tRNA",
    "tRNA:nas": "tRNA",
    "tRNA:ns": "tRNA",
    "tRNA:s": "tRNA",
    "tRNA:t": "tRNA",
    "tRNA:ts": "tRNA",
    "tRNAer": "tRNA",
    "tRNAerna": "tRNA",
    "tRNAernas": "tRNA",
    "tRNAers": "tRNA",
    "tRNAn": "tRNA",
    "tRNAna": "tRNA",
    "tRNAnas": "tRNA",
    "tRNAns": "tRNA",
    "tRNAs": "tRNA",
    "tRNAt": "tRNA",
    "tRNAts": "tRNA",
    "tabascon": "tabasco",
    "tabascons": "tabasco",
    "tabascos": "tabasco",
    "tabb": "tabbe",
    "tabbar": "tabbe",
    "tabbarna": "tabbe",
    "tabbarnas": "tabbe",
    "tabbars": "tabbe",
    "tabben": "tabbe",
    "tabbens": "tabbe",
    "tabbes": "tabbe",
    "tabbs": "tabbe",
    "tabellariska": "tabellarisk",
    "tabellariskare": "tabellarisk",
    "tabellariskares": "tabellarisk",
    "tabellariskas": "tabellarisk",
    "tabellariskast": "tabellarisk",
    "tabellariskaste": "tabellarisk",
    "tabellariskastes": "tabellarisk",
    "tabellariskasts": "tabellarisk",
    "tabellariske": "tabellarisk",
    "tabellariskes": "tabellarisk",
    "tabellarisks": "tabellarisk",
    "tabellariskt": "tabellarisk",
    "tabellariskts": "tabellarisk",
    "tabellen": "tabell",
    "tabellens": "tabell",
    "tabeller": "tabell",
    "tabellerad": "tabellera",
    "tabellerade": "tabellera",
    "tabellerades": "tabellera",
    "tabellerads": "tabellera",
    "tabellerande": "tabellera",
    "tabelleranden": "tabellerande",
    "tabellerandena": "tabellerande",
    "tabellerandenas": "tabellerande",
    "tabellerandens": "tabellerande",
    "tabellerandes": "tabellerande",
    "tabellerandet": "tabellerande",
    "tabellerandets": "tabellerande",
    "tabellerar": "tabellera",
    "tabelleras": "tabellera",
    "tabellerat": "tabellera",
    "tabellerats": "tabellera",
    "tabellerbara": "tabellerbar",
    "tabellerbarare": "tabellerbar",
    "tabellerbarares": "tabellerbar",
    "tabellerbaras": "tabellerbar",
    "tabellerbarast": "tabellerbar",
    "tabellerbaraste": "tabellerbar",
    "tabellerbarastes": "tabellerbar",
    "tabellerbarasts": "tabellerbar",
    "tabellerbare": "tabellerbar",
    "tabellerbares": "tabellerbar",
    "tabellerbarheten": "tabellerbarhet",
    "tabellerbarhetens": "tabellerbarhet",
    "tabellerbarhets": "tabellerbarhet",
    "tabellerbars": "tabellerbar",
    "tabellerbart": "tabellerbar",
    "tabellerbarts": "tabellerbar",
    "tabelleringar": "tabellering",
    "tabelleringarna": "tabellering",
    "tabelleringarnas": "tabellering",
    "tabelleringars": "tabellering",
    "tabelleringen": "tabellering",
    "tabelleringens": "tabellering",
    "tabellerings": "tabellering",
    "tabellerna": "tabell",
    "tabellernas": "tabell",
    "tabellers": "tabell",
    "tabellhuvuden": "tabellhuvud",
    "tabellhuvudena": "tabellhuvud",
    "tabellhuvudenas": "tabellhuvud",
    "tabellhuvudens": "tabellhuvud",
    "tabellhuvudet": "tabellhuvud",
    "tabellhuvudets": "tabellhuvud",
    "tabellhuvuds": "tabellhuvud",
    "tabells": "tabell",
    "tabellskatten": "tabellskatt",
    "tabellskattens": "tabellskatt",
    "tabellskatter": "tabellskatt",
    "tabellskatterna": "tabellskatt",
    "tabellskatternas": "tabellskatt",
    "tabellskatters": "tabellskatt",
    "tabellskatts": "tabellskatt",
    "tabernakels": "tabernakel",
    "tabernaklen": "tabernakel",
    "tabernaklens": "tabernakel",
    "tabernakler": "tabernakel",
    "tabernaklerna": "tabernakel",
    "tabernaklernas": "tabernakel",
    "tabernaklers": "tabernakel",
    "tabernaklet": "tabernakel",
    "tabernaklets": "tabernakel",
    "tabletten": "tablett",
    "tablettens": "tablett",
    "tabletter": "tablett",
    "tabletterna": "tablett",
    "tabletternas": "tablett",
    "tabletters": "tablett",
    "tabletts": "tablett",
    "tabloiden": "tabloid",
    "tabloidens": "tabloid",
    "tabloider": "tabloid",
    "tabloiderna": "tabloid",
    "tabloidernas": "tabloid",
    "tabloiders": "tabloid",
    "tabloids": "tabloid",
    "tablåer": "tablå",
    "tablåerna": "tablå",
    "tablåernas": "tablå",
    "tablåers": "tablå",
    "tablåmässiga": "tablåmässig",
    "tablåmässigare": "tablåmässig",
    "tablåmässigares": "tablåmässig",
    "tablåmässigas": "tablåmässig",
    "tablåmässigast": "tablåmässig",
    "tablåmässigaste": "tablåmässig",
    "tablåmässigastes": "tablåmässig",
    "tablåmässigasts": "tablåmässig",
    "tablåmässige": "tablåmässig",
    "tablåmässiges": "tablåmässig",
    "tablåmässigs": "tablåmässig",
    "tablåmässigt": "tablåmässig",
    "tablåmässigts": "tablåmässig",
    "tablån": "tablå",
    "tablåns": "tablå",
    "tablås": "tablå",
    "tabuerad": "tabuera",
    "tabuerade": "tabuera",
    "tabuerades": "tabuera",
    "tabuerads": "tabuera",
    "tabuerande": "tabuera",
    "tabueranden": "tabuerande",
    "tabuerandena": "tabuerande",
    "tabuerandenas": "tabuerande",
    "tabuerandens": "tabuerande",
    "tabuerandes": "tabuerande",
    "tabuerandet": "tabuerande",
    "tabuerandets": "tabuerande",
    "tabuerar": "tabuera",
    "tabueras": "tabuera",
    "tabuerat": "tabuera",
    "tabuerats": "tabuera",
    "tabuerbara": "tabuerbar",
    "tabuerbarare": "tabuerbar",
    "tabuerbarares": "tabuerbar",
    "tabuerbaras": "tabuerbar",
    "tabuerbarast": "tabuerbar",
    "tabuerbaraste": "tabuerbar",
    "tabuerbarastes": "tabuerbar",
    "tabuerbarasts": "tabuerbar",
    "tabuerbare": "tabuerbar",
    "tabuerbares": "tabuerbar",
    "tabuerbarheten": "tabuerbarhet",
    "tabuerbarhetens": "tabuerbarhet",
    "tabuerbarhets": "tabuerbarhet",
    "tabuerbars": "tabuerbar",
    "tabuerbart": "tabuerbar",
    "tabuerbarts": "tabuerbar",
    "tabueringar": "tabuering",
    "tabueringarna": "tabuering",
    "tabueringarnas": "tabuering",
    "tabueringars": "tabuering",
    "tabueringen": "tabuering",
    "tabueringens": "tabuering",
    "tabuerings": "tabuering",
    "tabugränsen": "tabugräns",
    "tabugränsens": "tabugräns",
    "tabugränser": "tabugräns",
    "tabugränserna": "tabugräns",
    "tabugränsernas": "tabugräns",
    "tabugränsers": "tabugräns",
    "tabulatorer": "tabulator",
    "tabulatorerna": "tabulator",
    "tabulatorernas": "tabulator",
    "tabulatorers": "tabulator",
    "tabulatorn": "tabulator",
    "tabulatorns": "tabulator",
    "tabulators": "tabulator",
    "tabulaturen": "tabulatur",
    "tabulaturens": "tabulatur",
    "tabulaturer": "tabulatur",
    "tabulaturerna": "tabulatur",
    "tabulaturernas": "tabulatur",
    "tabulaturers": "tabulatur",
    "tabulaturs": "tabulatur",
    "tabulerade": "tabulera",
    "tabulerades": "tabulera",
    "tabulerande": "tabulera",
    "tabuleranden": "tabulerande",
    "tabulerandena": "tabulerande",
    "tabulerandenas": "tabulerande",
    "tabulerandens": "tabulerande",
    "tabulerandes": "tabulerande",
    "tabulerandet": "tabulerande",
    "tabulerandets": "tabulerande",
    "tabulerar": "tabulera",
    "tabuleras": "tabulera",
    "tabulerat": "tabulera",
    "tabulerats": "tabulera",
    "tabuleringar": "tabulering",
    "tabuleringarna": "tabulering",
    "tabuleringarnas": "tabulering",
    "tabuleringars": "tabulering",
    "tabuleringen": "tabulering",
    "tabuleringens": "tabulering",
    "tabulerings": "tabulering",
    "tabun": "tabu",
    "tabuna": "tabu",
    "tabunas": "tabu",
    "tabuns": "tabu",
    "tabuorden": "tabuord",
    "tabuordens": "tabuord",
    "tabuordet": "tabuord",
    "tabuordets": "tabuord",
    "tabuords": "tabuord",
    "taburetten": "taburett",
    "taburettens": "taburett",
    "taburetter": "taburett",
    "taburetterna": "taburett",
    "taburetternas": "taburett",
    "taburetters": "taburett",
    "taburetts": "taburett",
    "tabus": "tabu",
    "tabut": "tabu",
    "tabuts": "tabu",
    "tack": "tacka",
    "tackad": "tacka",
    "tackade": "tacka",
    "tackades": "tacka",
    "tackads": "tacka",
    "tackan": "tacka",
    "tackande": "tacka",
    "tackanden": "tackande",
    "tackandena": "tackande",
    "tackandenas": "tackande",
    "tackandens": "tackande",
    "tackandes": "tackande",
    "tackandet": "tackande",
    "tackandets": "tackande",
    "tackans": "tacka",
    "tackar": "tacka",
    "tackas": "tacka",
    "tackat": "tacka",
    "tackats": "tacka",
    "tacke": "tacka",
    "tackel": "tackla",
    "tackels": "tackel",
    "tacken": "tack",
    "tackens": "tack",
    "tacket": "tack",
    "tackets": "tack",
    "tackjärnet": "tackjärn",
    "tackjärnets": "tackjärn",
    "tackjärns": "tackjärn",
    "tackjärnsblandar": "tackjärnsblandare",
    "tackjärnsblandaren": "tackjärnsblandare",
    "tackjärnsblandarens": "tackjärnsblandare",
    "tackjärnsblandares": "tackjärnsblandare",
    "tackjärnsblandarna": "tackjärnsblandare",
    "tackjärnsblandarnas": "tackjärnsblandare",
    "tackkorten": "tackkort",
    "tackkortens": "tackkort",
    "tackkortet": "tackkort",
    "tackkortets": "tackkort",
    "tackkorts": "tackkort",
    "tacklad": "tackla",
    "tacklade": "tackla",
    "tacklades": "tackla",
    "tacklads": "tackla",
    "tacklages": "tacklage",
    "tacklaget": "tacklage",
    "tacklagets": "tacklage",
    "tacklande": "tackla",
    "tacklanden": "tacklande",
    "tacklandena": "tacklande",
    "tacklandenas": "tacklande",
    "tacklandens": "tacklande",
    "tacklandes": "tacklande",
    "tacklandet": "tacklande",
    "tacklandets": "tacklande",
    "tacklar": "tackla",
    "tacklas": "tackla",
    "tacklat": "tackla",
    "tacklats": "tackla",
    "tacklen": "tackel",
    "tacklens": "tackel",
    "tacklet": "tackel",
    "tacklets": "tackel",
    "tacklingar": "tackling",
    "tacklingarna": "tackling",
    "tacklingarnas": "tackling",
    "tacklingars": "tackling",
    "tacklingen": "tackling",
    "tacklingens": "tackling",
    "tacklings": "tackling",
    "tacknämliga": "tacknämlig",
    "tacknämligare": "tacknämlig",
    "tacknämligares": "tacknämlig",
    "tacknämligas": "tacknämlig",
    "tacknämligast": "tacknämlig",
    "tacknämligaste": "tacknämlig",
    "tacknämligastes": "tacknämlig",
    "tacknämligasts": "tacknämlig",
    "tacknämlige": "tacknämlig",
    "tacknämliges": "tacknämlig",
    "tacknämligheten": "tacknämlighet",
    "tacknämlighetens": "tacknämlighet",
    "tacknämlighets": "tacknämlighet",
    "tacknämligs": "tacknämlig",
    "tacknämligt": "tacknämlig",
    "tacknämligts": "tacknämlig",
    "tackoffers": "tackoffer",
    "tackoffren": "tackoffer",
    "tackoffrens": "tackoffer",
    "tackoffret": "tackoffer",
    "tackoffrets": "tackoffer",
    "tackor": "tacka",
    "tackorna": "tacka",
    "tackornas": "tacka",
    "tackors": "tacka",
    "tacks": "tacka",
    "tacksamheten": "tacksamhet",
    "tacksamhetens": "tacksamhet",
    "tacksamheter": "tacksamhet",
    "tacksamheterna": "tacksamhet",
    "tacksamheternas": "tacksamhet",
    "tacksamheters": "tacksamhet",
    "tacksamhets": "tacksamhet",
    "tacksamhetsskulden": "tacksamhetsskuld",
    "tacksamhetsskuldens": "tacksamhetsskuld",
    "tacksamhetsskulds": "tacksamhetsskuld",
    "tacksamma": "tacksam",
    "tacksammare": "tacksam",
    "tacksammares": "tacksam",
    "tacksammas": "tacksam",
    "tacksammast": "tacksam",
    "tacksammaste": "tacksam",
    "tacksammastes": "tacksam",
    "tacksammasts": "tacksam",
    "tacksamme": "tacksam",
    "tacksammes": "tacksam",
    "tacksams": "tacksam",
    "tacksamt": "tacksam",
    "tacksamts": "tacksam",
    "tacksägelsedagar": "tacksägelsedag",
    "tacksägelsedagarna": "tacksägelsedag",
    "tacksägelsedagarnas": "tacksägelsedag",
    "tacksägelsedagars": "tacksägelsedag",
    "tacksägelsedagen": "tacksägelsedag",
    "tacksägelsedagens": "tacksägelsedag",
    "tacksägelsedags": "tacksägelsedag",
    "tacksägelsefesten": "tacksägelsefest",
    "tacksägelsefestens": "tacksägelsefest",
    "tacksägelsefester": "tacksägelsefest",
    "tacksägelsefesterna": "tacksägelsefest",
    "tacksägelsefesternas": "tacksägelsefest",
    "tacksägelsefesters": "tacksägelsefest",
    "tacksägelsefests": "tacksägelsefest",
    "tacksägelsegudstjänsten": "tacksägelsegudstjänst",
    "tacksägelsegudstjänstens": "tacksägelsegudstjänst",
    "tacksägelsegudstjänster": "tacksägelsegudstjänst",
    "tacksägelsegudstjänsterna": "tacksägelsegudstjänst",
    "tacksägelsegudstjänsternas": "tacksägelsegudstjänst",
    "tacksägelsegudstjänsters": "tacksägelsegudstjänst",
    "tacksägelsegudstjänsts": "tacksägelsegudstjänst",
    "tacksägelsen": "tacksägelse",
    "tacksägelsens": "tacksägelse",
    "tacksägelser": "tacksägelse",
    "tacksägelserna": "tacksägelse",
    "tacksägelsernas": "tacksägelse",
    "tacksägelsers": "tacksägelse",
    "tacksägelses": "tacksägelse",
    "tacktalen": "tacktal",
    "tacktalens": "tacktal",
    "tacktalet": "tacktal",
    "tacktalets": "tacktal",
    "tacktals": "tacktal",
    "tacon": "taco",
    "tacons": "taco",
    "tacorecepten": "tacorecept",
    "tacoreceptens": "tacorecept",
    "tacoreceptet": "tacorecept",
    "tacoreceptets": "tacorecept",
    "tacorecepts": "tacorecept",
    "tacos": "taco",
    "tacosarna": "taco",
    "tacosarnas": "taco",
    "tacosen": "taco",
    "tacosens": "taco",
    "tadel": "tadla",
    "tadelfria": "tadelfri",
    "tadelfriare": "tadelfri",
    "tadelfriares": "tadelfri",
    "tadelfrias": "tadelfri",
    "tadelfriast": "tadelfri",
    "tadelfriaste": "tadelfri",
    "tadelfriastes": "tadelfri",
    "tadelfriasts": "tadelfri",
    "tadelfrie": "tadelfri",
    "tadelfries": "tadelfri",
    "tadelfris": "tadelfri",
    "tadelfritt": "tadelfri",
    "tadelfritts": "tadelfri",
    "tadels": "tadel",
    "tadlad": "tadla",
    "tadlade": "tadla",
    "tadlades": "tadla",
    "tadlads": "tadla",
    "tadlande": "tadla",
    "tadlanden": "tadlande",
    "tadlandena": "tadlande",
    "tadlandenas": "tadlande",
    "tadlandens": "tadlande",
    "tadlandes": "tadlande",
    "tadlandet": "tadlande",
    "tadlandets": "tadlande",
    "tadlar": "tadla",
    "tadlas": "tadla",
    "tadlat": "tadla",
    "tadlats": "tadla",
    "tadlet": "tadel",
    "tadlets": "tadel",
    "tadzjiken": "tadzjik",
    "tadzjikens": "tadzjik",
    "tadzjiker": "tadzjik",
    "tadzjikerna": "tadzjik",
    "tadzjikernas": "tadzjik",
    "tadzjikers": "tadzjik",
    "tadzjikisk": "tadzjikiska",
    "tadzjikiska": "tadzjikisk",
    "tadzjikiskan": "tadzjikiska",
    "tadzjikiskans": "tadzjikiska",
    "tadzjikiskare": "tadzjikisk",
    "tadzjikiskares": "tadzjikisk",
    "tadzjikiskas": "tadzjikiska",
    "tadzjikiskast": "tadzjikisk",
    "tadzjikiskaste": "tadzjikisk",
    "tadzjikiskastes": "tadzjikisk",
    "tadzjikiskasts": "tadzjikisk",
    "tadzjikiske": "tadzjikiska",
    "tadzjikiskes": "tadzjikisk",
    "tadzjikiskor": "tadzjikiska",
    "tadzjikiskorna": "tadzjikiska",
    "tadzjikiskornas": "tadzjikiska",
    "tadzjikiskors": "tadzjikiska",
    "tadzjikisks": "tadzjikisk",
    "tadzjikiskt": "tadzjikisk",
    "tadzjikiskts": "tadzjikisk",
    "tadzjiks": "tadzjik",
    "tafatta": "tafatt",
    "tafattare": "tafatt",
    "tafattares": "tafatt",
    "tafattas": "tafatt",
    "tafattast": "tafatt",
    "tafattaste": "tafatt",
    "tafattastes": "tafatt",
    "tafattasts": "tafatt",
    "tafatte": "tafatt",
    "tafattes": "tafatt",
    "tafattheten": "tafatthet",
    "tafatthetens": "tafatthet",
    "tafatthets": "tafatthet",
    "tafatts": "tafatt",
    "taffel": "taffla",
    "taffelbergen": "taffelberg",
    "taffelbergens": "taffelberg",
    "taffelberget": "taffelberg",
    "taffelbergets": "taffelberg",
    "taffelbergs": "taffelberg",
    "taffellandet": "taffelland",
    "taffellandets": "taffelland",
    "taffellands": "taffelland",
    "taffelmusiken": "taffelmusik",
    "taffelmusikens": "taffelmusik",
    "taffelmusiks": "taffelmusik",
    "taffeln": "taffel",
    "taffelns": "taffel",
    "taffels": "taffel",
    "taffeltäckar": "taffeltäckare",
    "taffeltäckaren": "taffeltäckare",
    "taffeltäckarens": "taffeltäckare",
    "taffeltäckares": "taffeltäckare",
    "taffeltäckarna": "taffeltäckare",
    "taffeltäckarnas": "taffeltäckare",
    "taffelvågar": "taffelvåg",
    "taffelvågarna": "taffelvåg",
    "taffelvågarnas": "taffelvåg",
    "taffelvågars": "taffelvåg",
    "taffelvågen": "taffelvåg",
    "taffelvågens": "taffelvåg",
    "taffelvågs": "taffelvåg",
    "tafflade": "taffla",
    "tafflades": "taffla",
    "tafflande": "taffla",
    "tafflanden": "tafflande",
    "tafflandena": "tafflande",
    "tafflandenas": "tafflande",
    "tafflandens": "tafflande",
    "tafflandes": "tafflande",
    "tafflandet": "tafflande",
    "tafflandets": "tafflande",
    "tafflar": "taffla",
    "tafflarna": "taffel",
    "tafflarnas": "taffel",
    "tafflars": "taffel",
    "tafflas": "taffla",
    "tafflat": "taffla",
    "tafflats": "taffla",
    "taffliga": "tafflig",
    "taffligare": "tafflig",
    "taffligares": "tafflig",
    "taffligas": "tafflig",
    "taffligast": "tafflig",
    "taffligaste": "tafflig",
    "taffligastes": "tafflig",
    "taffligasts": "tafflig",
    "tafflige": "tafflig",
    "taffliges": "tafflig",
    "taffligheten": "tafflighet",
    "tafflighetens": "tafflighet",
    "taffligheter": "tafflighet",
    "taffligheterna": "tafflighet",
    "taffligheternas": "tafflighet",
    "taffligheters": "tafflighet",
    "tafflighets": "tafflighet",
    "taffligs": "tafflig",
    "taffligt": "tafflig",
    "taffligts": "tafflig",
    "tafs": "tafsa",
    "tafsad": "tafsa",
    "tafsade": "tafsa",
    "tafsades": "tafsa",
    "tafsads": "tafsa",
    "tafsande": "tafsa",
    "tafsanden": "tafsande",
    "tafsandena": "tafsande",
    "tafsandenas": "tafsande",
    "tafsandens": "tafsande",
    "tafsandes": "tafsande",
    "tafsandet": "tafsande",
    "tafsandets": "tafsande",
    "tafsar": "tafsare",
    "tafsaren": "tafsare",
    "tafsarens": "tafsare",
    "tafsares": "tafsare",
    "tafsarna": "tafsare",
    "tafsarnas": "tafsare",
    "tafsars": "tafs",
    "tafsas": "tafsa",
    "tafsat": "tafsa",
    "tafsats": "tafsa",
    "tafsen": "tafs",
    "tafsens": "tafs",
    "tafsiga": "tafsig",
    "tafsigare": "tafsig",
    "tafsigares": "tafsig",
    "tafsigas": "tafsig",
    "tafsigast": "tafsig",
    "tafsigaste": "tafsig",
    "tafsigastes": "tafsig",
    "tafsigasts": "tafsig",
    "tafsige": "tafsig",
    "tafsiges": "tafsig",
    "tafsigheten": "tafsighet",
    "tafsighetens": "tafsighet",
    "tafsighets": "tafsighet",
    "tafsigs": "tafsig",
    "tafsigt": "tafsig",
    "tafsigts": "tafsig",
    "taftbindningar": "taftbindning",
    "taftbindningarna": "taftbindning",
    "taftbindningarnas": "taftbindning",
    "taftbindningars": "taftbindning",
    "taftbindningen": "taftbindning",
    "taftbindningens": "taftbindning",
    "taftbindnings": "taftbindning",
    "taften": "taft",
    "taftens": "taft",
    "taftet": "taft",
    "taftets": "taft",
    "tafts": "taft",
    "tag": "ta",
    "taga": "ta",
    "tagande": "ta",
    "taganden": "tagande",
    "tagandena": "tagande",
    "tagandenas": "tagande",
    "tagandens": "tagande",
    "tagandes": "tagande",
    "tagandet": "tagande",
    "tagandets": "tagande",
    "tagas": "ta",
    "tage": "ta",
    "tagel": "tagla",
    "tagelmadrassen": "tagelmadrass",
    "tagelmadrassens": "tagelmadrass",
    "tagelmadrasser": "tagelmadrass",
    "tagelmadrasserna": "tagelmadrass",
    "tagelmadrassernas": "tagelmadrass",
    "tagelmadrassers": "tagelmadrass",
    "tagelmaskar": "tagelmask",
    "tagelmaskarna": "tagelmask",
    "tagelmaskarnas": "tagelmask",
    "tagelmaskars": "tagelmask",
    "tagelmasken": "tagelmask",
    "tagelmaskens": "tagelmask",
    "tagelmasks": "tagelmask",
    "tagels": "tagel",
    "tagelskjort": "tagelskjorta",
    "tagelskjortan": "tagelskjorta",
    "tagelskjortans": "tagelskjorta",
    "tagelskjortas": "tagelskjorta",
    "tagelskjorte": "tagelskjorta",
    "tagelskjortor": "tagelskjorta",
    "tagelskjortorna": "tagelskjorta",
    "tagelskjortornas": "tagelskjorta",
    "tagelskjortors": "tagelskjorta",
    "tagelskjorts": "tagelskjorta",
    "tagen": "tag",
    "tagens": "tagen",
    "tager": "ta",
    "tages": "ta",
    "taget": "tagen",
    "tagetesar": "tagetes",
    "tagetesarna": "tagetes",
    "tagetesarnas": "tagetes",
    "tagetesars": "tagetes",
    "tagetesen": "tagetes",
    "tagetesens": "tagetes",
    "tagets": "tagen",
    "tagg": "tagga",
    "taggad": "tagga",
    "taggade": "taggad",
    "taggades": "taggad",
    "taggads": "taggad",
    "taggande": "tagga",
    "tagganden": "taggande",
    "taggandena": "taggande",
    "taggandenas": "taggande",
    "taggandens": "taggande",
    "taggandes": "taggande",
    "taggandet": "taggande",
    "taggandets": "taggande",
    "taggar": "taggare",
    "taggaren": "taggare",
    "taggarens": "taggare",
    "taggares": "taggare",
    "taggarna": "taggare",
    "taggarnas": "taggare",
    "taggars": "tagg",
    "taggas": "tagga",
    "taggat": "taggad",
    "taggats": "taggad",
    "taggbräkens": "taggbräken",
    "taggbräknar": "taggbräken",
    "taggbräknarna": "taggbräken",
    "taggbräknarnas": "taggbräken",
    "taggbräknars": "taggbräken",
    "taggbräknen": "taggbräken",
    "taggbräknens": "taggbräken",
    "taggen": "tagg",
    "taggens": "tagg",
    "taggfeniga": "taggfenig",
    "taggfenigare": "taggfenig",
    "taggfenigares": "taggfenig",
    "taggfenigas": "taggfenig",
    "taggfenigast": "taggfenig",
    "taggfenigaste": "taggfenig",
    "taggfenigastes": "taggfenig",
    "taggfenigasts": "taggfenig",
    "taggfenige": "taggfenig",
    "taggfeniges": "taggfenig",
    "taggfenigheten": "taggfenighet",
    "taggfenighetens": "taggfenighet",
    "taggfenighets": "taggfenighet",
    "taggfenigs": "taggfenig",
    "taggfenigt": "taggfenig",
    "taggfenigts": "taggfenig",
    "taggfeningar": "taggfening",
    "taggfeningarna": "taggfening",
    "taggfeningarnas": "taggfening",
    "taggfeningars": "taggfening",
    "taggfeningen": "taggfening",
    "taggfeningens": "taggfening",
    "taggfenings": "taggfening",
    "taggförsedda": "taggförsedd",
    "taggförseddare": "taggförsedd",
    "taggförseddares": "taggförsedd",
    "taggförseddas": "taggförsedd",
    "taggförseddast": "taggförsedd",
    "taggförseddaste": "taggförsedd",
    "taggförseddastes": "taggförsedd",
    "taggförseddasts": "taggförsedd",
    "taggförsedde": "taggförsedd",
    "taggförseddes": "taggförsedd",
    "taggförsedds": "taggförsedd",
    "taggförsett": "taggförsedd",
    "taggförsetts": "taggförsedd",
    "tagghudingar": "tagghuding",
    "tagghudingarna": "tagghuding",
    "tagghudingarnas": "tagghuding",
    "tagghudingars": "tagghuding",
    "tagghudingen": "tagghuding",
    "tagghudingens": "tagghuding",
    "tagghudings": "tagghuding",
    "taggiga": "taggig",
    "taggigare": "taggig",
    "taggigares": "taggig",
    "taggigas": "taggig",
    "taggigast": "taggig",
    "taggigaste": "taggig",
    "taggigastes": "taggig",
    "taggigasts": "taggig",
    "taggige": "taggig",
    "taggiges": "taggig",
    "taggigheten": "taggighet",
    "taggighetens": "taggighet",
    "taggighets": "taggighet",
    "taggigs": "taggig",
    "taggigt": "taggig",
    "taggigts": "taggig",
    "taggparen": "taggpar",
    "taggparens": "taggpar",
    "taggparet": "taggpar",
    "taggparets": "taggpar",
    "taggpars": "taggpar",
    "taggs": "tagg",
    "taggstrål": "taggstråle",
    "taggstrålar": "taggstråle",
    "taggstrålarna": "taggstråle",
    "taggstrålarnas": "taggstråle",
    "taggstrålars": "taggstråle",
    "taggstrålen": "taggstråle",
    "taggstrålens": "taggstråle",
    "taggstråles": "taggstråle",
    "taggstråls": "taggstråle",
    "taggsvampar": "taggsvamp",
    "taggsvamparna": "taggsvamp",
    "taggsvamparnas": "taggsvamp",
    "taggsvampars": "taggsvamp",
    "taggsvampen": "taggsvamp",
    "taggsvampens": "taggsvamp",
    "taggsvamps": "taggsvamp",
    "taggtrådar": "taggtråd",
    "taggtrådarna": "taggtråd",
    "taggtrådarnas": "taggtråd",
    "taggtrådars": "taggtråd",
    "taggtråden": "taggtråd",
    "taggtrådens": "taggtråd",
    "taggtråds": "taggtråd",
    "taggtrådsrull": "taggtrådsrulle",
    "taggtrådsrullar": "taggtrådsrulle",
    "taggtrådsrullarna": "taggtrådsrulle",
    "taggtrådsrullarnas": "taggtrådsrulle",
    "taggtrådsrullars": "taggtrådsrulle",
    "taggtrådsrullen": "taggtrådsrulle",
    "taggtrådsrullens": "taggtrådsrulle",
    "taggtrådsrulles": "taggtrådsrulle",
    "taggtrådsrulls": "taggtrådsrulle",
    "tagit": "ta",
    "tagits": "tas",
    "taglad": "tagla",
    "taglade": "tagla",
    "taglades": "tagla",
    "taglads": "tagla",
    "taglande": "tagla",
    "taglanden": "taglande",
    "taglandena": "taglande",
    "taglandenas": "taglande",
    "taglandens": "taglande",
    "taglandes": "taglande",
    "taglandet": "taglande",
    "taglandets": "taglande",
    "taglar": "tagla",
    "taglas": "tagla",
    "taglat": "tagla",
    "taglats": "tagla",
    "taglen": "tagel",
    "taglens": "tagel",
    "taglet": "tagel",
    "taglets": "tagel",
    "taglingsgarnet": "taglingsgarn",
    "taglingsgarnets": "taglingsgarn",
    "taglingsgarns": "taglingsgarn",
    "tagna": "tagen",
    "tagnare": "tagen",
    "tagnares": "tagen",
    "tagnas": "tagen",
    "tagnast": "tagen",
    "tagnaste": "tagen",
    "tagnastes": "tagen",
    "tagnasts": "tagen",
    "tagne": "tagen",
    "tagnes": "tagen",
    "tagningar": "tagning",
    "tagningarna": "tagning",
    "tagningarnas": "tagning",
    "tagningars": "tagning",
    "tagningen": "tagning",
    "tagningens": "tagning",
    "tagnings": "tagning",
    "tags": "tag",
    "taig": "taiga",
    "taigan": "taiga",
    "taigans": "taiga",
    "taigas": "taiga",
    "taige": "taiga",
    "taigor": "taiga",
    "taigorna": "taiga",
    "taigornas": "taiga",
    "taigors": "taiga",
    "taigs": "taiga",
    "taiwanesen": "taiwanes",
    "taiwanesens": "taiwanes",
    "taiwaneser": "taiwanes",
    "taiwaneserna": "taiwanes",
    "taiwanesernas": "taiwanes",
    "taiwanesers": "taiwanes",
    "taiwanesisk": "taiwanesiska",
    "taiwanesiska": "taiwanesisk",
    "taiwanesiskan": "taiwanesiska",
    "taiwanesiskans": "taiwanesiska",
    "taiwanesiskare": "taiwanesisk",
    "taiwanesiskares": "taiwanesisk",
    "taiwanesiskas": "taiwanesiska",
    "taiwanesiskast": "taiwanesisk",
    "taiwanesiskaste": "taiwanesisk",
    "taiwanesiskastes": "taiwanesisk",
    "taiwanesiskasts": "taiwanesisk",
    "taiwanesiske": "taiwanesiska",
    "taiwanesiskes": "taiwanesisk",
    "taiwanesiskor": "taiwanesiska",
    "taiwanesiskorna": "taiwanesiska",
    "taiwanesiskornas": "taiwanesiska",
    "taiwanesiskors": "taiwanesiska",
    "taiwanesisks": "taiwanesisk",
    "taiwanesiskt": "taiwanesisk",
    "taiwanesiskts": "taiwanesisk",
    "tajgan": "tajga",
    "tajgans": "tajga",
    "tajgas": "tajga",
    "tajm": "tajma",
    "tajmad": "tajma",
    "tajmade": "tajma",
    "tajmades": "tajma",
    "tajmads": "tajma",
    "tajmande": "tajma",
    "tajmanden": "tajmande",
    "tajmandena": "tajmande",
    "tajmandenas": "tajmande",
    "tajmandens": "tajmande",
    "tajmandes": "tajmande",
    "tajmandet": "tajmande",
    "tajmandets": "tajmande",
    "tajmar": "tajma",
    "tajmas": "tajma",
    "tajmat": "tajma",
    "tajmats": "tajma",
    "tajmingar": "tajming",
    "tajmingarna": "tajming",
    "tajmingarnas": "tajming",
    "tajmingars": "tajming",
    "tajmingen": "tajming",
    "tajmingens": "tajming",
    "tajmings": "tajming",
    "tajta": "tajt",
    "tajtare": "tajt",
    "tajtares": "tajt",
    "tajtas": "tajt",
    "tajtast": "tajt",
    "tajtaste": "tajt",
    "tajtastes": "tajt",
    "tajtasts": "tajt",
    "tajte": "tajt",
    "tajtes": "tajt",
    "tajtheten": "tajthet",
    "tajthetens": "tajthet",
    "tajthets": "tajthet",
    "tajts": "tajt",
    "takbjälk": "takbjälke",
    "takbjälkar": "takbjälke",
    "takbjälkarna": "takbjälke",
    "takbjälkarnas": "takbjälke",
    "takbjälkars": "takbjälke",
    "takbjälken": "takbjälke",
    "takbjälkens": "takbjälke",
    "takbjälkes": "takbjälke",
    "takbjälks": "takbjälke",
    "takboxar": "takbox",
    "takboxarna": "takbox",
    "takboxarnas": "takbox",
    "takboxars": "takbox",
    "takboxen": "takbox",
    "takboxens": "takbox",
    "takbranden": "takbrand",
    "takbrandens": "takbrand",
    "takbrands": "takbrand",
    "takbränder": "takbrand",
    "takbränderna": "takbrand",
    "takbrändernas": "takbrand",
    "takbränders": "takbrand",
    "takdroppet": "takdropp",
    "takdroppets": "takdropp",
    "takdropps": "takdropp",
    "take-awayen": "take-away",
    "take-awayens": "take-away",
    "take-awayer": "take-away",
    "take-awayerna": "take-away",
    "take-awayernas": "take-away",
    "take-awayers": "take-away",
    "take-aways": "take-away",
    "takeawayen": "takeaway",
    "takeawayens": "takeaway",
    "takeawayer": "takeaway",
    "takeawayerna": "takeaway",
    "takeawayernas": "takeaway",
    "takeawayers": "takeaway",
    "takeaways": "takeaway",
    "taken": "tak",
    "takens": "tak",
    "taket": "tak",
    "takets": "tak",
    "takfallen": "takfall",
    "takfallens": "takfall",
    "takfallet": "takfall",
    "takfallets": "takfall",
    "takfalls": "takfall",
    "takfläktar": "takfläkt",
    "takfläktarna": "takfläkt",
    "takfläktarnas": "takfläkt",
    "takfläktars": "takfläkt",
    "takfläkten": "takfläkt",
    "takfläktens": "takfläkt",
    "takfläkts": "takfläkt",
    "takfoten": "takfot",
    "takfotens": "takfot",
    "takfots": "takfot",
    "takfrisen": "takfris",
    "takfrisens": "takfris",
    "takfriser": "takfris",
    "takfriserna": "takfris",
    "takfrisernas": "takfris",
    "takfrisers": "takfris",
    "takfönsterna": "takfönster",
    "takfönsternas": "takfönster",
    "takfönsters": "takfönster",
    "takfönstren": "takfönster",
    "takfönstrens": "takfönster",
    "takfönstret": "takfönster",
    "takfönstrets": "takfönster",
    "takgesimsen": "takgesims",
    "takgesimsens": "takgesims",
    "takgesimser": "takgesims",
    "takgesimserna": "takgesims",
    "takgesimsernas": "takgesims",
    "takgesimsers": "takgesims",
    "takhimlar": "takhimmel",
    "takhimlarna": "takhimmel",
    "takhimlarnas": "takhimmel",
    "takhimlars": "takhimmel",
    "takhimlen": "takhimmel",
    "takhimlens": "takhimmel",
    "takhimmelen": "takhimmel",
    "takhimmelens": "takhimmel",
    "takhimmeln": "takhimmel",
    "takhimmelns": "takhimmel",
    "takhimmels": "takhimmel",
    "takhuvar": "takhuv",
    "takhuvarna": "takhuv",
    "takhuvarnas": "takhuv",
    "takhuvars": "takhuv",
    "takhuven": "takhuv",
    "takhuvens": "takhuv",
    "takhuvs": "takhuv",
    "takhöjden": "takhöjd",
    "takhöjdens": "takhöjd",
    "takhöjder": "takhöjd",
    "takhöjderna": "takhöjd",
    "takhöjdernas": "takhöjd",
    "takhöjders": "takhöjd",
    "takhöjds": "takhöjd",
    "takistoskopen": "takistoskop",
    "takistoskopens": "takistoskop",
    "takistoskopet": "takistoskop",
    "takistoskopets": "takistoskop",
    "takistoskopien": "takistoskopi",
    "takistoskopiens": "takistoskopi",
    "takistoskopier": "takistoskopi",
    "takistoskopierna": "takistoskopi",
    "takistoskopiernas": "takistoskopi",
    "takistoskopiers": "takistoskopi",
    "takistoskopin": "takistoskopi",
    "takistoskopins": "takistoskopi",
    "takistoskopis": "takistoskopi",
    "takistoskops": "takistoskop",
    "takkammar": "takkam",
    "takkammarna": "takkam",
    "takkammarnas": "takkam",
    "takkammars": "takkam",
    "takkammen": "takkam",
    "takkammens": "takkam",
    "takkams": "takkam",
    "takklättrar": "takklättrare",
    "takklättraren": "takklättrare",
    "takklättrarens": "takklättrare",
    "takklättrares": "takklättrare",
    "takklättrarna": "takklättrare",
    "takklättrarnas": "takklättrare",
    "taklagen": "taklag",
    "taklagens": "taklag",
    "taklaget": "taklag",
    "taklagets": "taklag",
    "taklags": "taklag",
    "taklagsfesten": "taklagsfest",
    "taklagsfestens": "taklagsfest",
    "taklagsfester": "taklagsfest",
    "taklagsfesterna": "taklagsfest",
    "taklagsfesternas": "taklagsfest",
    "taklagsfesters": "taklagsfest",
    "taklagsfests": "taklagsfest",
    "taklagsölen": "taklagsöl",
    "taklagsölens": "taklagsöl",
    "taklagsölet": "taklagsöl",
    "taklagsölets": "taklagsöl",
    "taklagsöls": "taklagsöl",
    "taklamp": "taklampa",
    "taklampan": "taklampa",
    "taklampans": "taklampa",
    "taklampas": "taklampa",
    "taklampe": "taklampa",
    "taklampor": "taklampa",
    "taklamporna": "taklampa",
    "taklampornas": "taklampa",
    "taklampors": "taklampa",
    "taklamps": "taklampa",
    "taklisten": "taklist",
    "taklistens": "taklist",
    "taklister": "taklist",
    "taklisterna": "taklist",
    "taklisternas": "taklist",
    "taklisters": "taklist",
    "taklists": "taklist",
    "takläggar": "takläggare",
    "takläggaren": "takläggare",
    "takläggarens": "takläggare",
    "takläggares": "takläggare",
    "takläggarna": "takläggare",
    "takläggarnas": "takläggare",
    "takläkten": "takläkt",
    "takläktens": "takläkt",
    "takläkter": "takläkt",
    "takläkterna": "takläkt",
    "takläkternas": "takläkt",
    "takläkters": "takläkt",
    "takläkts": "takläkt",
    "taklöken": "taklök",
    "taklökens": "taklök",
    "taklöks": "taklök",
    "taknockar": "taknock",
    "taknockarna": "taknock",
    "taknockarnas": "taknock",
    "taknockars": "taknock",
    "taknocken": "taknock",
    "taknockens": "taknock",
    "taknocks": "taknock",
    "takometern": "takometer",
    "takometerns": "takometer",
    "takometers": "takometer",
    "takometrar": "takometer",
    "takometrarna": "takometer",
    "takometrarnas": "takometer",
    "takometrars": "takometer",
    "takpanelen": "takpanel",
    "takpanelens": "takpanel",
    "takpanels": "takpanel",
    "takpann": "takpanna",
    "takpannan": "takpanna",
    "takpannans": "takpanna",
    "takpannas": "takpanna",
    "takpanne": "takpanna",
    "takpannor": "takpanna",
    "takpannorna": "takpanna",
    "takpannornas": "takpanna",
    "takpannors": "takpanna",
    "takpanns": "takpanna",
    "takpappen": "takpapp",
    "takpappens": "takpapp",
    "takpappet": "takpapp",
    "takpappets": "takpapp",
    "takpapps": "takpapp",
    "takplatt": "takplatta",
    "takplattan": "takplatta",
    "takplattans": "takplatta",
    "takplattas": "takplatta",
    "takplatte": "takplatta",
    "takplattor": "takplatta",
    "takplattorna": "takplatta",
    "takplattornas": "takplatta",
    "takplattors": "takplatta",
    "takplatts": "takplatta",
    "takrasen": "takras",
    "takrasens": "takras",
    "takraset": "takras",
    "takrasets": "takras",
    "takresningar": "takresning",
    "takresningarna": "takresning",
    "takresningarnas": "takresning",
    "takresningars": "takresning",
    "takresningen": "takresning",
    "takresningens": "takresning",
    "takresnings": "takresning",
    "takryggar": "takrygg",
    "takryggarna": "takrygg",
    "takryggarnas": "takrygg",
    "takryggars": "takrygg",
    "takryggen": "takrygg",
    "takryggens": "takrygg",
    "takryggs": "takrygg",
    "takryttar": "takryttare",
    "takryttaren": "takryttare",
    "takryttarens": "takryttare",
    "takryttares": "takryttare",
    "takryttarna": "takryttare",
    "takryttarnas": "takryttare",
    "takräcken": "takräcke",
    "takräckena": "takräcke",
    "takräckenas": "takräcke",
    "takräckens": "takräcke",
    "takräckes": "takräcke",
    "takräcket": "takräcke",
    "takräckets": "takräcke",
    "takräcks": "takräck",
    "takränn": "takränna",
    "takrännan": "takränna",
    "takrännans": "takränna",
    "takrännas": "takränna",
    "takränne": "takränna",
    "takrännor": "takränna",
    "takrännorna": "takränna",
    "takrännornas": "takränna",
    "takrännors": "takränna",
    "takränns": "takränna",
    "takröst": "takröste",
    "takrösten": "takröste",
    "takröstena": "takröste",
    "takröstenas": "takröste",
    "takröstens": "takröste",
    "takröstes": "takröste",
    "takröstet": "takröste",
    "takröstets": "takröste",
    "takrösts": "takröst",
    "taks": "tak",
    "takskäggen": "takskägg",
    "takskäggens": "takskägg",
    "takskägget": "takskägg",
    "takskäggets": "takskägg",
    "takskäggs": "takskägg",
    "taksparr": "taksparre",
    "taksparrar": "taksparre",
    "taksparrarna": "taksparre",
    "taksparrarnas": "taksparre",
    "taksparrars": "taksparre",
    "taksparren": "taksparre",
    "taksparrens": "taksparre",
    "taksparres": "taksparre",
    "taksparrs": "taksparre",
    "taksprången": "taksprång",
    "taksprångens": "taksprång",
    "taksprånget": "taksprång",
    "taksprångets": "taksprång",
    "taksprångs": "taksprång",
    "takstolar": "takstol",
    "takstolarna": "takstol",
    "takstolarnas": "takstol",
    "takstolars": "takstol",
    "takstolen": "takstol",
    "takstolens": "takstol",
    "takstols": "takstol",
    "taktarten": "taktart",
    "taktartens": "taktart",
    "taktarter": "taktart",
    "taktarterna": "taktart",
    "taktarternas": "taktart",
    "taktarters": "taktart",
    "taktarts": "taktart",
    "taktbeteckningar": "taktbeteckning",
    "taktbeteckningarna": "taktbeteckning",
    "taktbeteckningarnas": "taktbeteckning",
    "taktbeteckningars": "taktbeteckning",
    "taktbeteckningen": "taktbeteckning",
    "taktbeteckningens": "taktbeteckning",
    "taktbetecknings": "taktbeteckning",
    "taktdelar": "taktdel",
    "taktdelarna": "taktdel",
    "taktdelarnas": "taktdel",
    "taktdelars": "taktdel",
    "taktdelen": "taktdel",
    "taktdelens": "taktdel",
    "taktdels": "taktdel",
    "taktegels": "taktegel",
    "takteglen": "taktegel",
    "takteglens": "taktegel",
    "takteglet": "taktegel",
    "takteglets": "taktegel",
    "takten": "takt",
    "taktens": "takt",
    "takter": "takt",
    "takterade": "taktera",
    "takterades": "taktera",
    "takterande": "taktera",
    "takteranden": "takterande",
    "takterandena": "takterande",
    "takterandenas": "takterande",
    "takterandens": "takterande",
    "takterandes": "takterande",
    "takterandet": "takterande",
    "takterandets": "takterande",
    "takterar": "taktera",
    "takteras": "taktera",
    "takterat": "taktera",
    "takterats": "taktera",
    "takteringar": "taktering",
    "takteringarna": "taktering",
    "takteringarnas": "taktering",
    "takteringars": "taktering",
    "takteringen": "taktering",
    "takteringens": "taktering",
    "takterings": "taktering",
    "takterna": "takt",
    "takternas": "takt",
    "takters": "takt",
    "taktfasta": "taktfast",
    "taktfastare": "taktfast",
    "taktfastares": "taktfast",
    "taktfastas": "taktfast",
    "taktfastast": "taktfast",
    "taktfastaste": "taktfast",
    "taktfastastes": "taktfast",
    "taktfastasts": "taktfast",
    "taktfaste": "taktfast",
    "taktfastes": "taktfast",
    "taktfastheten": "taktfasthet",
    "taktfasthetens": "taktfasthet",
    "taktfasthets": "taktfasthet",
    "taktfasts": "taktfast",
    "taktfulla": "taktfull",
    "taktfullare": "taktfull",
    "taktfullares": "taktfull",
    "taktfullas": "taktfull",
    "taktfullast": "taktfull",
    "taktfullaste": "taktfull",
    "taktfullastes": "taktfull",
    "taktfullasts": "taktfull",
    "taktfulle": "taktfull",
    "taktfulles": "taktfull",
    "taktfullheten": "taktfullhet",
    "taktfullhetens": "taktfullhet",
    "taktfullhets": "taktfullhet",
    "taktfulls": "taktfull",
    "taktfullt": "taktfull",
    "taktfullts": "taktfull",
    "taktiken": "taktik",
    "taktikens": "taktik",
    "taktiker": "taktik",
    "taktikern": "taktiker",
    "taktikerna": "taktiker",
    "taktikernas": "taktiker",
    "taktikerns": "taktiker",
    "taktikers": "taktiker",
    "taktiks": "taktik",
    "taktila": "taktil",
    "taktilare": "taktil",
    "taktilares": "taktil",
    "taktilas": "taktil",
    "taktilast": "taktil",
    "taktilaste": "taktil",
    "taktilastes": "taktil",
    "taktilasts": "taktil",
    "taktile": "taktil",
    "taktiles": "taktil",
    "taktils": "taktil",
    "taktilt": "taktil",
    "taktilts": "taktil",
    "taktiska": "taktisk",
    "taktiskare": "taktisk",
    "taktiskares": "taktisk",
    "taktiskas": "taktisk",
    "taktiskast": "taktisk",
    "taktiskaste": "taktisk",
    "taktiskastes": "taktisk",
    "taktiskasts": "taktisk",
    "taktiske": "taktisk",
    "taktiskes": "taktisk",
    "taktisks": "taktisk",
    "taktiskt": "taktisk",
    "taktiskts": "taktisk",
    "taktkänslan": "taktkänsla",
    "taktkänslans": "taktkänsla",
    "taktkänslas": "taktkänsla",
    "taktkänsle": "taktkänsla",
    "taktkänslo": "taktkänsla",
    "taktlösa": "taktlös",
    "taktlösare": "taktlös",
    "taktlösares": "taktlös",
    "taktlösas": "taktlös",
    "taktlösast": "taktlös",
    "taktlösaste": "taktlös",
    "taktlösastes": "taktlös",
    "taktlösasts": "taktlös",
    "taktlöse": "taktlös",
    "taktlöses": "taktlös",
    "taktlösheten": "taktlöshet",
    "taktlöshetens": "taktlöshet",
    "taktlösheter": "taktlöshet",
    "taktlösheterna": "taktlöshet",
    "taktlösheternas": "taktlöshet",
    "taktlösheters": "taktlöshet",
    "taktlöshets": "taktlöshet",
    "taktlöst": "taktlös",
    "taktlösts": "taktlös",
    "taktmässiga": "taktmässig",
    "taktmässigare": "taktmässig",
    "taktmässigares": "taktmässig",
    "taktmässigas": "taktmässig",
    "taktmässigast": "taktmässig",
    "taktmässigaste": "taktmässig",
    "taktmässigastes": "taktmässig",
    "taktmässigasts": "taktmässig",
    "taktmässige": "taktmässig",
    "taktmässiges": "taktmässig",
    "taktmässigs": "taktmässig",
    "taktmässigt": "taktmässig",
    "taktmässigts": "taktmässig",
    "taktpinn": "taktpinne",
    "taktpinnar": "taktpinne",
    "taktpinnarna": "taktpinne",
    "taktpinnarnas": "taktpinne",
    "taktpinnars": "taktpinne",
    "taktpinnen": "taktpinne",
    "taktpinnens": "taktpinne",
    "taktpinnes": "taktpinne",
    "taktpinns": "taktpinne",
    "takts": "takt",
    "taktslagen": "taktslag",
    "taktslagens": "taktslag",
    "taktslaget": "taktslag",
    "taktslagets": "taktslag",
    "taktslags": "taktslag",
    "taktstrecken": "taktstreck",
    "taktstreckens": "taktstreck",
    "taktstrecket": "taktstreck",
    "taktstreckets": "taktstreck",
    "taktstrecks": "taktstreck",
    "taktäckar": "taktäckare",
    "taktäckaren": "taktäckare",
    "taktäckarens": "taktäckare",
    "taktäckares": "taktäckare",
    "taktäckarna": "taktäckare",
    "taktäckarnas": "taktäckare",
    "taktäckningar": "taktäckning",
    "taktäckningarna": "taktäckning",
    "taktäckningarnas": "taktäckning",
    "taktäckningars": "taktäckning",
    "taktäckningen": "taktäckning",
    "taktäckningens": "taktäckning",
    "taktäcknings": "taktäckning",
    "takvåningar": "takvåning",
    "takvåningarna": "takvåning",
    "takvåningarnas": "takvåning",
    "takvåningars": "takvåning",
    "takvåningen": "takvåning",
    "takvåningens": "takvåning",
    "takvånings": "takvåning",
    "takykardien": "takykardi",
    "takykardiens": "takykardi",
    "takykardier": "takykardi",
    "takykardierna": "takykardi",
    "takykardiernas": "takykardi",
    "takykardiers": "takykardi",
    "takykardin": "takykardi",
    "takykardins": "takykardi",
    "takykardis": "takykardi",
    "takymetern": "takymeter",
    "takymeterns": "takymeter",
    "takymeters": "takymeter",
    "takymetrar": "takymeter",
    "takymetrarna": "takymeter",
    "takymetrarnas": "takymeter",
    "takymetrars": "takymeter",
    "takåsar": "takås",
    "takåsarna": "takås",
    "takåsarnas": "takås",
    "takåsars": "takås",
    "takåsen": "takås",
    "takåsens": "takås",
    "tal": "tala",
    "talad": "tala",
    "talade": "tala",
    "talades": "tala",
    "talads": "tala",
    "talakten": "talakt",
    "talaktens": "talakt",
    "talakter": "talakt",
    "talakterna": "talakt",
    "talakternas": "talakt",
    "talakters": "talakt",
    "talakts": "talakt",
    "talande": "tala",
    "talanden": "talande",
    "talandena": "talande",
    "talandenas": "talande",
    "talandens": "talande",
    "talandes": "talande",
    "talandet": "talande",
    "talandets": "talande",
    "talangen": "talang",
    "talangens": "talang",
    "talanger": "talang",
    "talangerna": "talang",
    "talangernas": "talang",
    "talangers": "talang",
    "talangfulla": "talangfull",
    "talangfullare": "talangfull",
    "talangfullares": "talangfull",
    "talangfullas": "talangfull",
    "talangfullast": "talangfull",
    "talangfullaste": "talangfull",
    "talangfullastes": "talangfull",
    "talangfullasts": "talangfull",
    "talangfulle": "talangfull",
    "talangfulles": "talangfull",
    "talangfullheten": "talangfullhet",
    "talangfullhetens": "talangfullhet",
    "talangfullhets": "talangfullhet",
    "talangfulls": "talangfull",
    "talangfullt": "talangfull",
    "talangfullts": "talangfull",
    "talangjakten": "talangjakt",
    "talangjaktens": "talangjakt",
    "talangjakter": "talangjakt",
    "talangjakterna": "talangjakt",
    "talangjakternas": "talangjakt",
    "talangjakters": "talangjakt",
    "talangjakts": "talangjakt",
    "talangs": "talang",
    "talangscouten": "talangscout",
    "talangscoutens": "talangscout",
    "talangscouter": "talangscout",
    "talangscouterna": "talangscout",
    "talangscouternas": "talangscout",
    "talangscouters": "talangscout",
    "talangscouts": "talangscout",
    "talans": "talan",
    "talapparaten": "talapparat",
    "talapparatens": "talapparat",
    "talapparater": "talapparat",
    "talapparaterna": "talapparat",
    "talapparaternas": "talapparat",
    "talapparaters": "talapparat",
    "talapparats": "talapparat",
    "talar": "talare",
    "talaren": "talare",
    "talarens": "talare",
    "talarer": "talar",
    "talarerna": "talar",
    "talarernas": "talar",
    "talarers": "talar",
    "talares": "talare",
    "talarkonsten": "talarkonst",
    "talarkonstens": "talarkonst",
    "talarkonsts": "talarkonst",
    "talarlistan": "talarlista",
    "talarlistans": "talarlista",
    "talarlistas": "talarlista",
    "talarliste": "talarlista",
    "talarlistor": "talarlista",
    "talarlistorna": "talarlista",
    "talarlistornas": "talarlista",
    "talarlistors": "talarlista",
    "talarna": "talare",
    "talarnas": "talare",
    "talars": "talar",
    "talarstolar": "talarstol",
    "talarstolarna": "talarstol",
    "talarstolarnas": "talarstol",
    "talarstolars": "talarstol",
    "talarstolen": "talarstol",
    "talarstolens": "talarstol",
    "talarstols": "talarstol",
    "talas": "tala",
    "talat": "tala",
    "talats": "tala",
    "talboken": "talbok",
    "talbokens": "talbok",
    "talboks": "talbok",
    "talböcker": "talbok",
    "talböckerna": "talbok",
    "talböckernas": "talbok",
    "talböckers": "talbok",
    "talcentra": "talcentrum",
    "talcentrana": "talcentrum",
    "talcentranas": "talcentrum",
    "talcentras": "talcentrum",
    "talcentrumen": "talcentrum",
    "talcentrumens": "talcentrum",
    "talcentrumet": "talcentrum",
    "talcentrumets": "talcentrum",
    "talcentrums": "talcentrum",
    "tald": "tala",
    "talda": "tala",
    "taldas": "tala",
    "talde": "tälja",
    "taldes": "tälja",
    "talds": "tala",
    "talekonsten": "talekonst",
    "talekonstens": "talekonst",
    "talekonsts": "talekonst",
    "talen": "tal",
    "talens": "tal",
    "talenten": "talent",
    "talentens": "talent",
    "talenter": "talent",
    "talenterna": "talent",
    "talenternas": "talent",
    "talenters": "talent",
    "talents": "talent",
    "talerätten": "talerätt",
    "talerättens": "talerätt",
    "talerätts": "talerätt",
    "talesmannen": "talesman",
    "talesmannens": "talesman",
    "talesmans": "talesman",
    "talesmän": "talesman",
    "talesmännen": "talesman",
    "talesmännens": "talesman",
    "talesmäns": "talesman",
    "talespersonen": "talesperson",
    "talespersonens": "talesperson",
    "talespersoner": "talesperson",
    "talespersonerna": "talesperson",
    "talespersonernas": "talesperson",
    "talespersoners": "talesperson",
    "talespersons": "talesperson",
    "talesätten": "talesätt",
    "talesättens": "talesätt",
    "talesättet": "talesätt",
    "talesättets": "talesätt",
    "talesätts": "talesätt",
    "talet": "tal",
    "talets": "tal",
    "talfelen": "talfel",
    "talfelens": "talfel",
    "talfelet": "talfel",
    "talfelets": "talfel",
    "talfels": "talfel",
    "talföljden": "talföljd",
    "talföljdens": "talföljd",
    "talföljder": "talföljd",
    "talföljderna": "talföljd",
    "talföljdernas": "talföljd",
    "talföljders": "talföljd",
    "talföljds": "talföljd",
    "talföra": "talför",
    "talförare": "talför",
    "talförares": "talför",
    "talföras": "talför",
    "talförast": "talför",
    "talföraste": "talför",
    "talförastes": "talför",
    "talförasts": "talför",
    "talföre": "talför",
    "talföres": "talför",
    "talförheten": "talförhet",
    "talförhetens": "talförhet",
    "talförhets": "talförhet",
    "talförmågan": "talförmåga",
    "talförmågans": "talförmåga",
    "talförmågas": "talförmåga",
    "talförmåge": "talförmåga",
    "talförmågor": "talförmåga",
    "talförmågorna": "talförmåga",
    "talförmågornas": "talförmåga",
    "talförmågors": "talförmåga",
    "talförs": "talför",
    "talfört": "talför",
    "talförts": "talför",
    "talg": "talga",
    "talgad": "talga",
    "talgade": "talga",
    "talgades": "talga",
    "talgads": "talga",
    "talgande": "talga",
    "talganden": "talgande",
    "talgandena": "talgande",
    "talgandenas": "talgande",
    "talgandens": "talgande",
    "talgandes": "talgande",
    "talgandet": "talgande",
    "talgandets": "talgande",
    "talgar": "talga",
    "talgas": "talga",
    "talgat": "talga",
    "talgats": "talga",
    "talgdankar": "talgdank",
    "talgdankarna": "talgdank",
    "talgdankarnas": "talgdank",
    "talgdankars": "talgdank",
    "talgdanken": "talgdank",
    "talgdankens": "talgdank",
    "talgdanks": "talgdank",
    "talgen": "talg",
    "talgens": "talg",
    "talgiga": "talgig",
    "talgigare": "talgig",
    "talgigares": "talgig",
    "talgigas": "talgig",
    "talgigast": "talgig",
    "talgigaste": "talgig",
    "talgigastes": "talgig",
    "talgigasts": "talgig",
    "talgige": "talgig",
    "talgiges": "talgig",
    "talgigheten": "talgighet",
    "talgighetens": "talgighet",
    "talgighets": "talgighet",
    "talgigs": "talgig",
    "talgigt": "talgig",
    "talgigts": "talgig",
    "talgkörteln": "talgkörtel",
    "talgkörtelns": "talgkörtel",
    "talgkörtels": "talgkörtel",
    "talgkörtlar": "talgkörtel",
    "talgkörtlarna": "talgkörtel",
    "talgkörtlarnas": "talgkörtel",
    "talgkörtlars": "talgkörtel",
    "talgox": "talgoxe",
    "talgoxar": "talgoxe",
    "talgoxarna": "talgoxe",
    "talgoxarnas": "talgoxe",
    "talgoxars": "talgoxe",
    "talgoxen": "talgoxe",
    "talgoxens": "talgoxe",
    "talgoxes": "talgoxe",
    "talgs": "talg",
    "talgögda": "talgögd",
    "talgögdare": "talgögd",
    "talgögdares": "talgögd",
    "talgögdas": "talgögd",
    "talgögdast": "talgögd",
    "talgögdaste": "talgögd",
    "talgögdastes": "talgögd",
    "talgögdasts": "talgögd",
    "talgögde": "talgögd",
    "talgögdes": "talgögd",
    "talgögdheten": "talgögdhet",
    "talgögdhetens": "talgögdhet",
    "talgögdhets": "talgögdhet",
    "talgögds": "talgögd",
    "talgögt": "talgögd",
    "talgögts": "talgögd",
    "talibanen": "taliban",
    "talibanens": "taliban",
    "talibaner": "taliban",
    "talibanerna": "taliban",
    "talibanernas": "taliban",
    "talibaners": "taliban",
    "talibanrebellen": "talibanrebell",
    "talibanrebellens": "talibanrebell",
    "talibanrebeller": "talibanrebell",
    "talibanrebellerna": "talibanrebell",
    "talibanrebellernas": "talibanrebell",
    "talibanrebellers": "talibanrebell",
    "talibanrebells": "talibanrebell",
    "talibans": "taliban",
    "talismanen": "talisman",
    "talismanens": "talisman",
    "talismaner": "talisman",
    "talismanerna": "talisman",
    "talismanernas": "talisman",
    "talismaners": "talisman",
    "talismans": "talisman",
    "talj": "talja",
    "taljan": "talja",
    "taljans": "talja",
    "taljas": "talja",
    "talje": "talja",
    "taljor": "talja",
    "taljorna": "talja",
    "taljornas": "talja",
    "taljors": "talja",
    "taljs": "talja",
    "talk": "talka",
    "talkad": "talka",
    "talkade": "talka",
    "talkades": "talka",
    "talkads": "talka",
    "talkande": "talka",
    "talkanden": "talkande",
    "talkandena": "talkande",
    "talkandenas": "talkande",
    "talkandens": "talkande",
    "talkandes": "talkande",
    "talkandet": "talkande",
    "talkandets": "talkande",
    "talkar": "talka",
    "talkas": "talka",
    "talkat": "talka",
    "talkats": "talka",
    "talken": "talk",
    "talkens": "talk",
    "talkiga": "talkig",
    "talkigare": "talkig",
    "talkigares": "talkig",
    "talkigas": "talkig",
    "talkigast": "talkig",
    "talkigaste": "talkig",
    "talkigastes": "talkig",
    "talkigasts": "talkig",
    "talkige": "talkig",
    "talkiges": "talkig",
    "talkigheten": "talkighet",
    "talkighetens": "talkighet",
    "talkighets": "talkighet",
    "talkigs": "talkig",
    "talkigt": "talkig",
    "talkigts": "talkig",
    "talkliniken": "talklinik",
    "talklinikens": "talklinik",
    "talkliniker": "talklinik",
    "talklinikerna": "talklinik",
    "talklinikernas": "talklinik",
    "talklinikers": "talklinik",
    "talkliniks": "talklinik",
    "talks": "talk",
    "talkshowen": "talkshow",
    "talkshowens": "talkshow",
    "talkshower": "talkshow",
    "talkshowerna": "talkshow",
    "talkshowernas": "talkshow",
    "talkshowers": "talkshow",
    "talkshows": "talkshow",
    "talkskiffern": "talkskiffer",
    "talkskifferns": "talkskiffer",
    "talkskiffers": "talkskiffer",
    "talkören": "talkör",
    "talkörens": "talkör",
    "talkörer": "talkör",
    "talkörerna": "talkör",
    "talkörernas": "talkör",
    "talkörers": "talkör",
    "talkörs": "talkör",
    "tall": "talla",
    "tallad": "talla",
    "tallade": "talla",
    "tallades": "talla",
    "tallads": "talla",
    "tallande": "talla",
    "tallanden": "tallande",
    "tallandena": "tallande",
    "tallandenas": "tallande",
    "tallandens": "tallande",
    "tallandes": "tallande",
    "tallandet": "tallande",
    "tallandets": "tallande",
    "tallar": "talla",
    "tallarna": "tall",
    "tallarnas": "tall",
    "tallars": "tall",
    "tallas": "talla",
    "tallat": "talla",
    "tallats": "talla",
    "tallbarren": "tallbarr",
    "tallbarrens": "tallbarr",
    "tallbarret": "tallbarr",
    "tallbarrets": "tallbarr",
    "tallbarrs": "tallbarr",
    "tallbarrsoljan": "tallbarrsolja",
    "tallbarrsoljans": "tallbarrsolja",
    "tallbarrsoljas": "tallbarrsolja",
    "tallbarrsolje": "tallbarrsolja",
    "tallbitar": "tallbit",
    "tallbitarna": "tallbit",
    "tallbitarnas": "tallbit",
    "tallbitars": "tallbit",
    "tallbiten": "tallbit",
    "tallbitens": "tallbit",
    "tallbits": "tallbit",
    "tallbockar": "tallbock",
    "tallbockarna": "tallbock",
    "tallbockarnas": "tallbock",
    "tallbockars": "tallbock",
    "tallbocken": "tallbock",
    "tallbockens": "tallbock",
    "tallbocks": "tallbock",
    "talldungar": "talldunge",
    "talldungarna": "talldunge",
    "talldungarnas": "talldunge",
    "talldungars": "talldunge",
    "talldungen": "talldunge",
    "talldungens": "talldunge",
    "talldunges": "talldunge",
    "tallen": "tall",
    "tallens": "tall",
    "talliet": "tallium",
    "talliets": "tallium",
    "tallinjen": "tallinje",
    "tallinjens": "tallinje",
    "tallinjer": "tallinje",
    "tallinjerna": "tallinje",
    "tallinjernas": "tallinje",
    "tallinjers": "tallinje",
    "tallinjes": "tallinje",
    "talliumet": "tallium",
    "talliumets": "tallium",
    "talliums": "tallium",
    "tallkottkörteln": "tallkottkörtel",
    "tallkottkörtelns": "tallkottkörtel",
    "tallkottkörtels": "tallkottkörtel",
    "tallkottkörtlar": "tallkottkörtel",
    "tallkottkörtlarna": "tallkottkörtel",
    "tallkottkörtlarnas": "tallkottkörtel",
    "tallkottkörtlars": "tallkottkörtel",
    "tallkottskörteln": "tallkottskörtel",
    "tallkottskörtelns": "tallkottskörtel",
    "tallkottskörtels": "tallkottskörtel",
    "tallkottskörtlar": "tallkottskörtel",
    "tallkottskörtlarna": "tallkottskörtel",
    "tallkottskörtlarnas": "tallkottskörtel",
    "tallkottskörtlars": "tallkottskörtel",
    "tallmätar": "tallmätare",
    "tallmätaren": "tallmätare",
    "tallmätarens": "tallmätare",
    "tallmätares": "tallmätare",
    "tallmätarna": "tallmätare",
    "tallmätarnas": "tallmätare",
    "talloljan": "tallolja",
    "talloljans": "tallolja",
    "talloljas": "tallolja",
    "tallolje": "tallolja",
    "tallplant": "tallplanta",
    "tallplantan": "tallplanta",
    "tallplantans": "tallplanta",
    "tallplantas": "tallplanta",
    "tallplante": "tallplanta",
    "tallplantor": "tallplanta",
    "tallplantorna": "tallplanta",
    "tallplantornas": "tallplanta",
    "tallplantors": "tallplanta",
    "tallplants": "tallplanta",
    "tallrika": "tallrik",
    "tallrikar": "tallrik",
    "tallrikare": "tallrik",
    "tallrikares": "tallrik",
    "tallrikarna": "tallrik",
    "tallrikarnas": "tallrik",
    "tallrikars": "tallrik",
    "tallrikas": "tallrik",
    "tallrikast": "tallrik",
    "tallrikaste": "tallrik",
    "tallrikastes": "tallrik",
    "tallrikasts": "tallrik",
    "tallrike": "tallrik",
    "tallriken": "tallrik",
    "tallrikens": "tallrik",
    "tallrikes": "tallrik",
    "tallrikheten": "tallrikhet",
    "tallrikhetens": "tallrikhet",
    "tallrikhets": "tallrikhet",
    "tallriks": "tallrik",
    "tallriksformade": "tallriksformad",
    "tallriksformades": "tallriksformad",
    "tallriksformads": "tallriksformad",
    "tallriksformat": "tallriksformad",
    "tallriksformats": "tallriksformad",
    "tallriksharvar": "tallriksharv",
    "tallriksharvarna": "tallriksharv",
    "tallriksharvarnas": "tallriksharv",
    "tallriksharvars": "tallriksharv",
    "tallriksharven": "tallriksharv",
    "tallriksharvens": "tallriksharv",
    "tallriksharvs": "tallriksharv",
    "tallrikshjulen": "tallrikshjul",
    "tallrikshjulens": "tallrikshjul",
    "tallrikshjulet": "tallrikshjul",
    "tallrikshjulets": "tallrikshjul",
    "tallrikshjuls": "tallrikshjul",
    "tallriksisen": "tallriksis",
    "tallriksisens": "tallriksis",
    "tallriksslickar": "tallriksslickare",
    "tallriksslickaren": "tallriksslickare",
    "tallriksslickarens": "tallriksslickare",
    "tallriksslickares": "tallriksslickare",
    "tallriksslickarna": "tallriksslickare",
    "tallriksslickarnas": "tallriksslickare",
    "tallriksventilen": "tallriksventil",
    "tallriksventilens": "tallriksventil",
    "tallriksventiler": "tallriksventil",
    "tallriksventilerna": "tallriksventil",
    "tallriksventilernas": "tallriksventil",
    "tallriksventilers": "tallriksventil",
    "tallriksventils": "tallriksventil",
    "tallrikt": "tallrik",
    "tallrikts": "tallrik",
    "talls": "tall",
    "tallskogar": "tallskog",
    "tallskogarna": "tallskog",
    "tallskogarnas": "tallskog",
    "tallskogars": "tallskog",
    "tallskogen": "tallskog",
    "tallskogens": "tallskog",
    "tallskogs": "tallskog",
    "tallsorten": "tallsort",
    "tallsortens": "tallsort",
    "tallsorter": "tallsort",
    "tallsorterna": "tallsort",
    "tallsorternas": "tallsort",
    "tallsorters": "tallsort",
    "tallsorts": "tallsort",
    "tallspinnar": "tallspinnare",
    "tallspinnaren": "tallspinnare",
    "tallspinnarens": "tallspinnare",
    "tallspinnares": "tallspinnare",
    "tallspinnarna": "tallspinnare",
    "tallspinnarnas": "tallspinnare",
    "tallstekeln": "tallstekel",
    "tallstekelns": "tallstekel",
    "tallstekels": "tallstekel",
    "tallsteklar": "tallstekel",
    "tallsteklarna": "tallstekel",
    "tallsteklarnas": "tallstekel",
    "tallsteklars": "tallstekel",
    "tallstrunten": "tallstrunt",
    "tallstruntens": "tallstrunt",
    "tallstrunts": "tallstrunt",
    "talltick": "tallticka",
    "talltickan": "tallticka",
    "talltickans": "tallticka",
    "talltickas": "tallticka",
    "tallticke": "tallticka",
    "talltickor": "tallticka",
    "talltickorna": "tallticka",
    "talltickornas": "tallticka",
    "talltickors": "tallticka",
    "tallticks": "tallticka",
    "talltit": "talltita",
    "talltitan": "talltita",
    "talltitans": "talltita",
    "talltitas": "talltita",
    "talltite": "talltita",
    "talltitor": "talltita",
    "talltitorna": "talltita",
    "talltitornas": "talltita",
    "talltitors": "talltita",
    "talltits": "talltita",
    "tallörten": "tallört",
    "tallörtens": "tallört",
    "tallörter": "tallört",
    "tallörterna": "tallört",
    "tallörternas": "tallört",
    "tallörters": "tallört",
    "tallörts": "tallört",
    "tallösa": "tallös",
    "tallösare": "tallös",
    "tallösares": "tallös",
    "tallösas": "tallös",
    "tallösast": "tallös",
    "tallösaste": "tallös",
    "tallösastes": "tallös",
    "tallösasts": "tallös",
    "tallöse": "tallös",
    "tallöses": "tallös",
    "tallösheten": "tallöshet",
    "tallöshetens": "tallöshet",
    "tallöshets": "tallöshet",
    "tallöst": "tallös",
    "tallösts": "tallös",
    "talmannen": "talman",
    "talmannens": "talman",
    "talmans": "talman",
    "talmanskonferensen": "talmanskonferens",
    "talmanskonferensens": "talmanskonferens",
    "talmanskonferenser": "talmanskonferens",
    "talmanskonferenserna": "talmanskonferens",
    "talmanskonferensernas": "talmanskonferens",
    "talmanskonferensers": "talmanskonferens",
    "talmis": "talmi",
    "talmit": "talmi",
    "talmits": "talmi",
    "talmystiken": "talmystik",
    "talmystikens": "talmystik",
    "talmystiks": "talmystik",
    "talmän": "talman",
    "talmännen": "talman",
    "talmännens": "talman",
    "talmäns": "talman",
    "talongen": "talong",
    "talongens": "talong",
    "talonger": "talong",
    "talongerna": "talong",
    "talongernas": "talong",
    "talongers": "talong",
    "talongs": "talong",
    "talorganen": "talorgan",
    "talorganens": "talorgan",
    "talorganet": "talorgan",
    "talorganets": "talorgan",
    "talorgans": "talorgan",
    "talpedagogen": "talpedagog",
    "talpedagogens": "talpedagog",
    "talpedagoger": "talpedagog",
    "talpedagogerna": "talpedagog",
    "talpedagogernas": "talpedagog",
    "talpedagogers": "talpedagog",
    "talpedagogs": "talpedagog",
    "talpjäsen": "talpjäs",
    "talpjäsens": "talpjäs",
    "talpjäser": "talpjäs",
    "talpjäserna": "talpjäs",
    "talpjäsernas": "talpjäs",
    "talpjäsers": "talpjäs",
    "talregistreringsapparaten": "talregistreringsapparat",
    "talregistreringsapparatens": "talregistreringsapparat",
    "talregistreringsapparater": "talregistreringsapparat",
    "talregistreringsapparaterna": "talregistreringsapparat",
    "talregistreringsapparaternas": "talregistreringsapparat",
    "talregistreringsapparaters": "talregistreringsapparat",
    "talregistreringsapparats": "talregistreringsapparat",
    "talrika": "talrik",
    "talrikare": "talrik",
    "talrikares": "talrik",
    "talrikas": "talrik",
    "talrikast": "talrik",
    "talrikaste": "talrik",
    "talrikastes": "talrik",
    "talrikasts": "talrik",
    "talrike": "talrik",
    "talrikes": "talrik",
    "talrikheten": "talrikhet",
    "talrikhetens": "talrikhet",
    "talrikhets": "talrikhet",
    "talriks": "talrik",
    "talrikt": "talrik",
    "talrikts": "talrik",
    "talrollen": "talroll",
    "talrollens": "talroll",
    "talroller": "talroll",
    "talrollerna": "talroll",
    "talrollernas": "talroll",
    "talrollers": "talroll",
    "talrolls": "talroll",
    "talrubbningar": "talrubbning",
    "talrubbningarna": "talrubbning",
    "talrubbningarnas": "talrubbning",
    "talrubbningars": "talrubbning",
    "talrubbningen": "talrubbning",
    "talrubbningens": "talrubbning",
    "talrubbnings": "talrubbning",
    "talrören": "talrör",
    "talrörens": "talrör",
    "talröret": "talrör",
    "talrörets": "talrör",
    "talrörs": "talrör",
    "tals": "tal",
    "talscenen": "talscen",
    "talscenens": "talscen",
    "talscener": "talscen",
    "talscenerna": "talscen",
    "talscenernas": "talscen",
    "talsceners": "talscen",
    "talscens": "talscen",
    "talsituationen": "talsituation",
    "talsituationens": "talsituation",
    "talsituationer": "talsituation",
    "talsituationerna": "talsituation",
    "talsituationernas": "talsituation",
    "talsituationers": "talsituation",
    "talsituations": "talsituation",
    "talskrivar": "talskrivare",
    "talskrivaren": "talskrivare",
    "talskrivarens": "talskrivare",
    "talskrivares": "talskrivare",
    "talskrivarna": "talskrivare",
    "talskrivarnas": "talskrivare",
    "talspråken": "talspråk",
    "talspråkens": "talspråk",
    "talspråket": "talspråk",
    "talspråkets": "talspråk",
    "talspråkliga": "talspråklig",
    "talspråkligare": "talspråklig",
    "talspråkligares": "talspråklig",
    "talspråkligas": "talspråklig",
    "talspråkligast": "talspråklig",
    "talspråkligaste": "talspråklig",
    "talspråkligastes": "talspråklig",
    "talspråkligasts": "talspråklig",
    "talspråklige": "talspråklig",
    "talspråkliges": "talspråklig",
    "talspråkligheten": "talspråklighet",
    "talspråklighetens": "talspråklighet",
    "talspråkligheter": "talspråklighet",
    "talspråkligheterna": "talspråklighet",
    "talspråkligheternas": "talspråklighet",
    "talspråkligheters": "talspråklighet",
    "talspråklighets": "talspråklighet",
    "talspråkligs": "talspråklig",
    "talspråkligt": "talspråklig",
    "talspråkligts": "talspråklig",
    "talspråks": "talspråk",
    "talspråksmässiga": "talspråksmässig",
    "talspråksmässigare": "talspråksmässig",
    "talspråksmässigares": "talspråksmässig",
    "talspråksmässigas": "talspråksmässig",
    "talspråksmässigast": "talspråksmässig",
    "talspråksmässigaste": "talspråksmässig",
    "talspråksmässigastes": "talspråksmässig",
    "talspråksmässigasts": "talspråksmässig",
    "talspråksmässige": "talspråksmässig",
    "talspråksmässiges": "talspråksmässig",
    "talspråksmässigs": "talspråksmässig",
    "talspråksmässigt": "talspråksmässig",
    "talspråksmässigts": "talspråksmässig",
    "talsvårigheten": "talsvårighet",
    "talsvårighetens": "talsvårighet",
    "talsvårigheter": "talsvårighet",
    "talsvårigheterna": "talsvårighet",
    "talsvårigheternas": "talsvårighet",
    "talsvårigheters": "talsvårighet",
    "talsvårighets": "talsvårighet",
    "talsymboliken": "talsymbolik",
    "talsymbolikens": "talsymbolik",
    "talsymboliks": "talsymbolik",
    "talsyntesen": "talsyntes",
    "talsyntesens": "talsyntes",
    "talsystemen": "talsystem",
    "talsystemens": "talsystem",
    "talsystemet": "talsystem",
    "talsystemets": "talsystem",
    "talsystems": "talsystem",
    "talt": "tälja",
    "talte": "tala",
    "taltekniken": "talteknik",
    "talteknikens": "talteknik",
    "taltekniks": "talteknik",
    "talteknologien": "talteknologi",
    "talteknologiens": "talteknologi",
    "talteknologier": "talteknologi",
    "talteknologierna": "talteknologi",
    "talteknologiernas": "talteknologi",
    "talteknologiers": "talteknologi",
    "talteknologin": "talteknologi",
    "talteknologins": "talteknologi",
    "talteknologis": "talteknologi",
    "talteorien": "talteori",
    "talteoriens": "talteori",
    "talteorin": "talteori",
    "talteorins": "talteori",
    "talteoris": "talteori",
    "taltes": "tala",
    "taltrastar": "taltrast",
    "taltrastarna": "taltrast",
    "taltrastarnas": "taltrast",
    "taltrastars": "taltrast",
    "taltrasten": "taltrast",
    "taltrastens": "taltrast",
    "taltrasts": "taltrast",
    "taltrattar": "taltratt",
    "taltrattarna": "taltratt",
    "taltrattarnas": "taltratt",
    "taltrattars": "taltratt",
    "taltratten": "taltratt",
    "taltrattens": "taltratt",
    "taltratts": "taltratt",
    "talträngda": "talträngd",
    "talträngdare": "talträngd",
    "talträngdares": "talträngd",
    "talträngdas": "talträngd",
    "talträngdast": "talträngd",
    "talträngdaste": "talträngd",
    "talträngdastes": "talträngd",
    "talträngdasts": "talträngd",
    "talträngde": "talträngd",
    "talträngdes": "talträngd",
    "talträngdheten": "talträngdhet",
    "talträngdhetens": "talträngdhet",
    "talträngdhets": "talträngdhet",
    "talträngds": "talträngd",
    "talträngt": "talträngd",
    "talträngts": "talträngd",
    "talts": "tälja",
    "talvården": "talvård",
    "talvårdens": "talvård",
    "talvårds": "talvård",
    "talängslans": "talängslan",
    "tama": "tam",
    "tamare": "tam",
    "tamares": "tam",
    "tamarinden": "tamarind",
    "tamarindens": "tamarind",
    "tamarinder": "tamarind",
    "tamarinderna": "tamarind",
    "tamarindernas": "tamarind",
    "tamarinders": "tamarind",
    "tamarinds": "tamarind",
    "tamarisken": "tamarisk",
    "tamariskens": "tamarisk",
    "tamarisker": "tamarisk",
    "tamariskerna": "tamarisk",
    "tamariskernas": "tamarisk",
    "tamariskers": "tamarisk",
    "tamarisks": "tamarisk",
    "tamas": "tam",
    "tamast": "tam",
    "tamaste": "tam",
    "tamastes": "tam",
    "tamasts": "tam",
    "tamburen": "tambur",
    "tamburens": "tambur",
    "tamburer": "tambur",
    "tamburerna": "tambur",
    "tamburernas": "tambur",
    "tamburers": "tambur",
    "tamburinen": "tamburin",
    "tamburinens": "tamburin",
    "tamburiner": "tamburin",
    "tamburinerna": "tamburin",
    "tamburinernas": "tamburin",
    "tamburiners": "tamburin",
    "tamburins": "tamburin",
    "tamburmajoren": "tamburmajor",
    "tamburmajorens": "tamburmajor",
    "tamburmajorer": "tamburmajor",
    "tamburmajorerna": "tamburmajor",
    "tamburmajorernas": "tamburmajor",
    "tamburmajorers": "tamburmajor",
    "tamburmajorn": "tamburmajor",
    "tamburmajorns": "tamburmajor",
    "tamburmajors": "tamburmajor",
    "tamburs": "tambur",
    "tambursömmar": "tambursöm",
    "tambursömmarna": "tambursöm",
    "tambursömmarnas": "tambursöm",
    "tambursömmars": "tambursöm",
    "tambursömmen": "tambursöm",
    "tambursömmens": "tambursöm",
    "tambursöms": "tambursöm",
    "tamburvaktmästar": "tamburvaktmästare",
    "tamburvaktmästaren": "tamburvaktmästare",
    "tamburvaktmästarens": "tamburvaktmästare",
    "tamburvaktmästares": "tamburvaktmästare",
    "tamburvaktmästarna": "tamburvaktmästare",
    "tamburvaktmästarnas": "tamburvaktmästare",
    "tamduv": "tamduva",
    "tamduvan": "tamduva",
    "tamduvans": "tamduva",
    "tamduvas": "tamduva",
    "tamduve": "tamduva",
    "tamduvor": "tamduva",
    "tamduvorna": "tamduva",
    "tamduvornas": "tamduva",
    "tamduvors": "tamduva",
    "tamduvs": "tamduva",
    "tame": "tam",
    "tames": "tam",
    "tamfågeln": "tamfågel",
    "tamfågelns": "tamfågel",
    "tamfågels": "tamfågel",
    "tamfåglar": "tamfågel",
    "tamfåglarna": "tamfågel",
    "tamfåglarnas": "tamfågel",
    "tamfåglars": "tamfågel",
    "tamheten": "tamhet",
    "tamhetens": "tamhet",
    "tamhets": "tamhet",
    "tamifluet": "tamiflu",
    "tamifluets": "tamiflu",
    "tamiflus": "tamiflu",
    "tamilen": "tamil",
    "tamilens": "tamil",
    "tamiler": "tamil",
    "tamilerna": "tamil",
    "tamilernas": "tamil",
    "tamilers": "tamil",
    "tamils": "tamil",
    "tampades": "tampas",
    "tampar": "tamp",
    "tamparna": "tamp",
    "tamparnas": "tamp",
    "tampars": "tamp",
    "tampats": "tampas",
    "tampen": "tamp",
    "tampens": "tamp",
    "tamponerad": "tamponera",
    "tamponerade": "tamponera",
    "tamponerades": "tamponera",
    "tamponerads": "tamponera",
    "tamponerande": "tamponera",
    "tamponeranden": "tamponerande",
    "tamponerandena": "tamponerande",
    "tamponerandenas": "tamponerande",
    "tamponerandens": "tamponerande",
    "tamponerandes": "tamponerande",
    "tamponerandet": "tamponerande",
    "tamponerandets": "tamponerande",
    "tamponerar": "tamponera",
    "tamponeras": "tamponera",
    "tamponerat": "tamponera",
    "tamponerats": "tamponera",
    "tamponerbara": "tamponerbar",
    "tamponerbarare": "tamponerbar",
    "tamponerbarares": "tamponerbar",
    "tamponerbaras": "tamponerbar",
    "tamponerbarast": "tamponerbar",
    "tamponerbaraste": "tamponerbar",
    "tamponerbarastes": "tamponerbar",
    "tamponerbarasts": "tamponerbar",
    "tamponerbare": "tamponerbar",
    "tamponerbares": "tamponerbar",
    "tamponerbarheten": "tamponerbarhet",
    "tamponerbarhetens": "tamponerbarhet",
    "tamponerbarhets": "tamponerbarhet",
    "tamponerbars": "tamponerbar",
    "tamponerbart": "tamponerbar",
    "tamponerbarts": "tamponerbar",
    "tamponeringar": "tamponering",
    "tamponeringarna": "tamponering",
    "tamponeringarnas": "tamponering",
    "tamponeringars": "tamponering",
    "tamponeringen": "tamponering",
    "tamponeringens": "tamponering",
    "tamponerings": "tamponering",
    "tampongen": "tampong",
    "tampongens": "tampong",
    "tamponger": "tampong",
    "tampongerna": "tampong",
    "tampongernas": "tampong",
    "tampongers": "tampong",
    "tampongs": "tampong",
    "tamps": "tamp",
    "tamrenar": "tamren",
    "tamrenarna": "tamren",
    "tamrenarnas": "tamren",
    "tamrenars": "tamren",
    "tamrenen": "tamren",
    "tamrenens": "tamren",
    "tamrens": "tamren",
    "tams": "tam",
    "tamsvinen": "tamsvin",
    "tamsvinens": "tamsvin",
    "tamsvinet": "tamsvin",
    "tamsvinets": "tamsvin",
    "tamsvins": "tamsvin",
    "tamt": "tam",
    "tamtams": "tamtam",
    "tamts": "tam",
    "tamulen": "tamul",
    "tamulens": "tamul",
    "tamuler": "tamul",
    "tamulerna": "tamul",
    "tamulernas": "tamul",
    "tamulers": "tamul",
    "tamuls": "tamul",
    "tan": "tana",
    "tanan": "tana",
    "tanans": "tana",
    "tanas": "tana",
    "tand": "tanda",
    "tandad": "tanda",
    "tandade": "tandad",
    "tandades": "tandad",
    "tandads": "tandad",
    "tandagnisslans": "tandagnisslan",
    "tandande": "tanda",
    "tandanden": "tandande",
    "tandandena": "tandande",
    "tandandenas": "tandande",
    "tandandens": "tandande",
    "tandandes": "tandande",
    "tandandet": "tandande",
    "tandandets": "tandande",
    "tandar": "tanda",
    "tandas": "tanda",
    "tandat": "tandad",
    "tandats": "tandad",
    "tandbenet": "tandben",
    "tandbenets": "tandben",
    "tandbens": "tandben",
    "tandborrar": "tandborr",
    "tandborrarna": "tandborr",
    "tandborrarnas": "tandborr",
    "tandborrars": "tandborr",
    "tandborren": "tandborr",
    "tandborrens": "tandborr",
    "tandborret": "tandborr",
    "tandborrets": "tandborr",
    "tandborrmaskinen": "tandborrmaskin",
    "tandborrmaskinens": "tandborrmaskin",
    "tandborrmaskiner": "tandborrmaskin",
    "tandborrmaskinerna": "tandborrmaskin",
    "tandborrmaskinernas": "tandborrmaskin",
    "tandborrmaskiners": "tandborrmaskin",
    "tandborrmaskins": "tandborrmaskin",
    "tandborrs": "tandborr",
    "tandborst": "tandborste",
    "tandborstar": "tandborste",
    "tandborstarna": "tandborste",
    "tandborstarnas": "tandborste",
    "tandborstars": "tandborste",
    "tandborsten": "tandborste",
    "tandborstens": "tandborste",
    "tandborstes": "tandborste",
    "tandborstglasen": "tandborstglas",
    "tandborstglasens": "tandborstglas",
    "tandborstglaset": "tandborstglas",
    "tandborstglasets": "tandborstglas",
    "tandborstmuggar": "tandborstmugg",
    "tandborstmuggarna": "tandborstmugg",
    "tandborstmuggarnas": "tandborstmugg",
    "tandborstmuggars": "tandborstmugg",
    "tandborstmuggen": "tandborstmugg",
    "tandborstmuggens": "tandborstmugg",
    "tandborstmuggs": "tandborstmugg",
    "tandborstningar": "tandborstning",
    "tandborstningarna": "tandborstning",
    "tandborstningarnas": "tandborstning",
    "tandborstningars": "tandborstning",
    "tandborstningen": "tandborstning",
    "tandborstningens": "tandborstning",
    "tandborstnings": "tandborstning",
    "tandbrygg": "tandbrygga",
    "tandbryggan": "tandbrygga",
    "tandbryggans": "tandbrygga",
    "tandbryggas": "tandbrygga",
    "tandbrygge": "tandbrygga",
    "tandbryggor": "tandbrygga",
    "tandbryggorna": "tandbrygga",
    "tandbryggornas": "tandbrygga",
    "tandbryggors": "tandbrygga",
    "tandbryggs": "tandbrygga",
    "tandbölden": "tandböld",
    "tandböldens": "tandböld",
    "tandbölder": "tandböld",
    "tandbölderna": "tandböld",
    "tandböldernas": "tandböld",
    "tandbölders": "tandböld",
    "tandbölds": "tandböld",
    "tandemcykeln": "tandemcykel",
    "tandemcykelns": "tandemcykel",
    "tandemcykels": "tandemcykel",
    "tandemcyklar": "tandemcykel",
    "tandemcyklarna": "tandemcykel",
    "tandemcyklarnas": "tandemcykel",
    "tandemcyklars": "tandemcykel",
    "tandemet": "tandem",
    "tandemets": "tandem",
    "tandemmaskinen": "tandemmaskin",
    "tandemmaskinens": "tandemmaskin",
    "tandemmaskiner": "tandemmaskin",
    "tandemmaskinerna": "tandemmaskin",
    "tandemmaskinernas": "tandemmaskin",
    "tandemmaskiners": "tandemmaskin",
    "tandemmaskins": "tandemmaskin",
    "tandemridningar": "tandemridning",
    "tandemridningarna": "tandemridning",
    "tandemridningarnas": "tandemridning",
    "tandemridningars": "tandemridning",
    "tandemridningen": "tandemridning",
    "tandemridningens": "tandemridning",
    "tandemridnings": "tandemridning",
    "tandems": "tandem",
    "tandemspermien": "tandemspermie",
    "tandemspermiens": "tandemspermie",
    "tandemspermier": "tandemspermie",
    "tandemspermierna": "tandemspermie",
    "tandemspermiernas": "tandemspermie",
    "tandemspermiers": "tandemspermie",
    "tandemspermies": "tandemspermie",
    "tanden": "tand",
    "tandens": "tand",
    "tandfisteln": "tandfistel",
    "tandfistelns": "tandfistel",
    "tandfistels": "tandfistel",
    "tandfistlar": "tandfistel",
    "tandfistlarna": "tandfistel",
    "tandfistlarnas": "tandfistel",
    "tandfistlars": "tandfistel",
    "tandformeln": "tandformel",
    "tandformelns": "tandformel",
    "tandformels": "tandformel",
    "tandformler": "tandformel",
    "tandformlerna": "tandformel",
    "tandformlernas": "tandformel",
    "tandformlers": "tandformel",
    "tandfyllningar": "tandfyllning",
    "tandfyllningarna": "tandfyllning",
    "tandfyllningarnas": "tandfyllning",
    "tandfyllningars": "tandfyllning",
    "tandfyllningen": "tandfyllning",
    "tandfyllningens": "tandfyllning",
    "tandfyllnings": "tandfyllning",
    "tandfällningar": "tandfällning",
    "tandfällningarna": "tandfällning",
    "tandfällningarnas": "tandfällning",
    "tandfällningars": "tandfällning",
    "tandfällningen": "tandfällning",
    "tandfällningens": "tandfällning",
    "tandfällnings": "tandfällning",
    "tandgarnityren": "tandgarnityr",
    "tandgarnityrens": "tandgarnityr",
    "tandgarnityret": "tandgarnityr",
    "tandgarnityrets": "tandgarnityr",
    "tandgarnityrs": "tandgarnityr",
    "tandgenombrotten": "tandgenombrott",
    "tandgenombrottens": "tandgenombrott",
    "tandgenombrottet": "tandgenombrott",
    "tandgenombrottets": "tandgenombrott",
    "tandgenombrotts": "tandgenombrott",
    "tandguldet": "tandguld",
    "tandguldets": "tandguld",
    "tandgulds": "tandguld",
    "tandhalsar": "tandhals",
    "tandhalsarna": "tandhals",
    "tandhalsarnas": "tandhals",
    "tandhalsars": "tandhals",
    "tandhalsen": "tandhals",
    "tandhalsens": "tandhals",
    "tandhjulen": "tandhjul",
    "tandhjulens": "tandhjul",
    "tandhjulet": "tandhjul",
    "tandhjulets": "tandhjul",
    "tandhjuls": "tandhjul",
    "tandhygienisten": "tandhygienist",
    "tandhygienistens": "tandhygienist",
    "tandhygienister": "tandhygienist",
    "tandhygienisterna": "tandhygienist",
    "tandhygienisternas": "tandhygienist",
    "tandhygienisters": "tandhygienist",
    "tandhygienists": "tandhygienist",
    "tandhyveln": "tandhyvel",
    "tandhyvelns": "tandhyvel",
    "tandhyvels": "tandhyvel",
    "tandhyvlar": "tandhyvel",
    "tandhyvlarna": "tandhyvel",
    "tandhyvlarnas": "tandhyvel",
    "tandhyvlars": "tandhyvel",
    "tandhäveln": "tandhävel",
    "tandhävelns": "tandhävel",
    "tandhävels": "tandhävel",
    "tandhävlar": "tandhävel",
    "tandhävlarna": "tandhävel",
    "tandhävlarnas": "tandhävel",
    "tandhävlars": "tandhävel",
    "tandhål": "tandhåla",
    "tandhålan": "tandhåla",
    "tandhålans": "tandhåla",
    "tandhålas": "tandhåla",
    "tandhåle": "tandhåla",
    "tandhålor": "tandhåla",
    "tandhålorna": "tandhåla",
    "tandhålornas": "tandhåla",
    "tandhålors": "tandhåla",
    "tandhåls": "tandhåla",
    "tandimplantaten": "tandimplantat",
    "tandimplantatens": "tandimplantat",
    "tandimplantatet": "tandimplantat",
    "tandimplantatets": "tandimplantat",
    "tandimplantats": "tandimplantat",
    "tandkittet": "tandkitt",
    "tandkittets": "tandkitt",
    "tandkitts": "tandkitt",
    "tandkonstruktionen": "tandkonstruktion",
    "tandkonstruktionens": "tandkonstruktion",
    "tandkonstruktioner": "tandkonstruktion",
    "tandkonstruktionerna": "tandkonstruktion",
    "tandkonstruktionernas": "tandkonstruktion",
    "tandkonstruktioners": "tandkonstruktion",
    "tandkonstruktions": "tandkonstruktion",
    "tandkron": "tandkrona",
    "tandkronan": "tandkrona",
    "tandkronans": "tandkrona",
    "tandkronas": "tandkrona",
    "tandkrone": "tandkrona",
    "tandkronor": "tandkrona",
    "tandkronorna": "tandkrona",
    "tandkronornas": "tandkrona",
    "tandkronors": "tandkrona",
    "tandkrons": "tandkrona",
    "tandkrämen": "tandkräm",
    "tandkrämens": "tandkräm",
    "tandkrämer": "tandkräm",
    "tandkrämerna": "tandkräm",
    "tandkrämernas": "tandkräm",
    "tandkrämers": "tandkräm",
    "tandkräms": "tandkräm",
    "tandköttet": "tandkött",
    "tandköttets": "tandkött",
    "tandkötts": "tandkött",
    "tandlagningar": "tandlagning",
    "tandlagningarna": "tandlagning",
    "tandlagningarnas": "tandlagning",
    "tandlagningars": "tandlagning",
    "tandlagningen": "tandlagning",
    "tandlagningens": "tandlagning",
    "tandlagnings": "tandlagning",
    "tandlika": "tandlik",
    "tandlikare": "tandlik",
    "tandlikares": "tandlik",
    "tandlikas": "tandlik",
    "tandlikast": "tandlik",
    "tandlikaste": "tandlik",
    "tandlikastes": "tandlik",
    "tandlikasts": "tandlik",
    "tandlike": "tandlik",
    "tandlikes": "tandlik",
    "tandlikheten": "tandlikhet",
    "tandlikhetens": "tandlikhet",
    "tandlikhets": "tandlikhet",
    "tandliks": "tandlik",
    "tandlikt": "tandlik",
    "tandlikts": "tandlik",
    "tandlisten": "tandlist",
    "tandlistens": "tandlist",
    "tandlister": "tandlist",
    "tandlisterna": "tandlist",
    "tandlisternas": "tandlist",
    "tandlisters": "tandlist",
    "tandlists": "tandlist",
    "tandlossningar": "tandlossning",
    "tandlossningarna": "tandlossning",
    "tandlossningarnas": "tandlossning",
    "tandlossningars": "tandlossning",
    "tandlossningen": "tandlossning",
    "tandlossningens": "tandlossning",
    "tandlossnings": "tandlossning",
    "tandläkar": "tandläkare",
    "tandläkarbesöken": "tandläkarbesök",
    "tandläkarbesökens": "tandläkarbesök",
    "tandläkarbesöket": "tandläkarbesök",
    "tandläkarbesökets": "tandläkarbesök",
    "tandläkarbesöks": "tandläkarbesök",
    "tandläkaren": "tandläkare",
    "tandläkarens": "tandläkare",
    "tandläkares": "tandläkare",
    "tandläkarna": "tandläkare",
    "tandläkarnas": "tandläkare",
    "tandläkarpraktiken": "tandläkarpraktik",
    "tandläkarpraktikens": "tandläkarpraktik",
    "tandläkarpraktiker": "tandläkarpraktik",
    "tandläkarpraktikerna": "tandläkarpraktik",
    "tandläkarpraktikernas": "tandläkarpraktik",
    "tandläkarpraktikers": "tandläkarpraktik",
    "tandläkarpraktiks": "tandläkarpraktik",
    "tandläkarskyltar": "tandläkarskylt",
    "tandläkarskyltarna": "tandläkarskylt",
    "tandläkarskyltarnas": "tandläkarskylt",
    "tandläkarskyltars": "tandläkarskylt",
    "tandläkarskylten": "tandläkarskylt",
    "tandläkarskyltens": "tandläkarskylt",
    "tandläkarskylts": "tandläkarskylt",
    "tandläkarstolar": "tandläkarstol",
    "tandläkarstolarna": "tandläkarstol",
    "tandläkarstolarnas": "tandläkarstol",
    "tandläkarstolars": "tandläkarstol",
    "tandläkarstolen": "tandläkarstol",
    "tandläkarstolens": "tandläkarstol",
    "tandläkarstols": "tandläkarstol",
    "tandläkarundersökningar": "tandläkarundersökning",
    "tandläkarundersökningarna": "tandläkarundersökning",
    "tandläkarundersökningarnas": "tandläkarundersökning",
    "tandläkarundersökningars": "tandläkarundersökning",
    "tandläkarundersökningen": "tandläkarundersökning",
    "tandläkarundersökningens": "tandläkarundersökning",
    "tandläkarundersöknings": "tandläkarundersökning",
    "tandlösa": "tandlös",
    "tandlösare": "tandlös",
    "tandlösares": "tandlös",
    "tandlösas": "tandlös",
    "tandlösast": "tandlös",
    "tandlösaste": "tandlös",
    "tandlösastes": "tandlös",
    "tandlösasts": "tandlös",
    "tandlöse": "tandlös",
    "tandlöses": "tandlös",
    "tandlösheten": "tandlöshet",
    "tandlöshetens": "tandlöshet",
    "tandlöshets": "tandlöshet",
    "tandlöst": "tandlös",
    "tandlösts": "tandlös",
    "tandningar": "tandning",
    "tandningarna": "tandning",
    "tandningarnas": "tandning",
    "tandningars": "tandning",
    "tandningen": "tandning",
    "tandningens": "tandning",
    "tandnings": "tandning",
    "tandpast": "tandpasta",
    "tandpastan": "tandpasta",
    "tandpastans": "tandpasta",
    "tandpastas": "tandpasta",
    "tandpaste": "tandpasta",
    "tandpastor": "tandpasta",
    "tandpastorna": "tandpasta",
    "tandpastornas": "tandpasta",
    "tandpastors": "tandpasta",
    "tandpetar": "tandpetare",
    "tandpetaren": "tandpetare",
    "tandpetarens": "tandpetare",
    "tandpetares": "tandpetare",
    "tandpetarna": "tandpetare",
    "tandpetarnas": "tandpetare",
    "tandprotesen": "tandprotes",
    "tandprotesens": "tandprotes",
    "tandproteser": "tandprotes",
    "tandproteserna": "tandprotes",
    "tandprotesernas": "tandprotes",
    "tandprotesers": "tandprotes",
    "tandpulp": "tandpulpa",
    "tandpulpan": "tandpulpa",
    "tandpulpans": "tandpulpa",
    "tandpulpas": "tandpulpa",
    "tandpulpe": "tandpulpa",
    "tandpulpor": "tandpulpa",
    "tandpulporna": "tandpulpa",
    "tandpulpornas": "tandpulpa",
    "tandpulpors": "tandpulpa",
    "tandpulps": "tandpulpa",
    "tandregleringar": "tandreglering",
    "tandregleringarna": "tandreglering",
    "tandregleringarnas": "tandreglering",
    "tandregleringars": "tandreglering",
    "tandregleringen": "tandreglering",
    "tandregleringens": "tandreglering",
    "tandreglerings": "tandreglering",
    "tandroten": "tandrot",
    "tandrotens": "tandrot",
    "tandrots": "tandrot",
    "tandrötan": "tandröta",
    "tandrötans": "tandröta",
    "tandrötas": "tandröta",
    "tandröte": "tandröta",
    "tandrötter": "tandrot",
    "tandrötterna": "tandrot",
    "tandrötternas": "tandrot",
    "tandrötters": "tandrot",
    "tands": "tand",
    "tandsköterskan": "tandsköterska",
    "tandsköterskans": "tandsköterska",
    "tandsköterskas": "tandsköterska",
    "tandsköterske": "tandsköterska",
    "tandsköterskor": "tandsköterska",
    "tandsköterskorna": "tandsköterska",
    "tandsköterskornas": "tandsköterska",
    "tandsköterskors": "tandsköterska",
    "tandsnitten": "tandsnitt",
    "tandsnittens": "tandsnitt",
    "tandsnittet": "tandsnitt",
    "tandsnittets": "tandsnitt",
    "tandsnitts": "tandsnitt",
    "tandsprickningar": "tandsprickning",
    "tandsprickningarna": "tandsprickning",
    "tandsprickningarnas": "tandsprickning",
    "tandsprickningars": "tandsprickning",
    "tandsprickningen": "tandsprickning",
    "tandsprickningens": "tandsprickning",
    "tandspricknings": "tandsprickning",
    "tandstenen": "tandsten",
    "tandstenens": "tandsten",
    "tandstens": "tandsten",
    "tandstick": "tandsticka",
    "tandstickan": "tandsticka",
    "tandstickans": "tandsticka",
    "tandstickas": "tandsticka",
    "tandsticke": "tandsticka",
    "tandstickor": "tandsticka",
    "tandstickorna": "tandsticka",
    "tandstickornas": "tandsticka",
    "tandstickors": "tandsticka",
    "tandsticks": "tandsticka",
    "tandställningar": "tandställning",
    "tandställningarna": "tandställning",
    "tandställningarnas": "tandställning",
    "tandställningars": "tandställning",
    "tandställningen": "tandställning",
    "tandställningens": "tandställning",
    "tandställnings": "tandställning",
    "tandteknikern": "tandtekniker",
    "tandteknikerna": "tandtekniker",
    "tandteknikernas": "tandtekniker",
    "tandteknikerns": "tandtekniker",
    "tandteknikers": "tandtekniker",
    "tandtråden": "tandtråd",
    "tandtrådens": "tandtråd",
    "tandtråds": "tandtråd",
    "tanduppsättningar": "tanduppsättning",
    "tanduppsättningarna": "tanduppsättning",
    "tanduppsättningarnas": "tanduppsättning",
    "tanduppsättningars": "tanduppsättning",
    "tanduppsättningen": "tanduppsättning",
    "tanduppsättningens": "tanduppsättning",
    "tanduppsättnings": "tanduppsättning",
    "tandutskotten": "tandutskott",
    "tandutskottens": "tandutskott",
    "tandutskottet": "tandutskott",
    "tandutskottets": "tandutskott",
    "tandutskotts": "tandutskott",
    "tandvalar": "tandval",
    "tandvalarna": "tandval",
    "tandvalarnas": "tandval",
    "tandvalars": "tandval",
    "tandvalen": "tandval",
    "tandvalens": "tandval",
    "tandvallar": "tandvall",
    "tandvallarna": "tandvall",
    "tandvallarnas": "tandvall",
    "tandvallars": "tandvall",
    "tandvallen": "tandvall",
    "tandvallens": "tandvall",
    "tandvalls": "tandvall",
    "tandvals": "tandval",
    "tandvänliga": "tandvänlig",
    "tandvänligare": "tandvänlig",
    "tandvänligares": "tandvänlig",
    "tandvänligas": "tandvänlig",
    "tandvänligast": "tandvänlig",
    "tandvänligaste": "tandvänlig",
    "tandvänligastes": "tandvänlig",
    "tandvänligasts": "tandvänlig",
    "tandvänlige": "tandvänlig",
    "tandvänliges": "tandvänlig",
    "tandvänligheten": "tandvänlighet",
    "tandvänlighetens": "tandvänlighet",
    "tandvänlighets": "tandvänlighet",
    "tandvänligs": "tandvänlig",
    "tandvänligt": "tandvänlig",
    "tandvänligts": "tandvänlig",
    "tandvärken": "tandvärk",
    "tandvärkens": "tandvärk",
    "tandvärks": "tandvärk",
    "tandvården": "tandvård",
    "tandvårdens": "tandvård",
    "tandvårds": "tandvård",
    "tandvårdsbidragen": "tandvårdsbidrag",
    "tandvårdsbidragens": "tandvårdsbidrag",
    "tandvårdsbidraget": "tandvårdsbidrag",
    "tandvårdsbidragets": "tandvårdsbidrag",
    "tandvårdsbidrags": "tandvårdsbidrag",
    "tandvårdsförsäkringar": "tandvårdsförsäkring",
    "tandvårdsförsäkringarna": "tandvårdsförsäkring",
    "tandvårdsförsäkringarnas": "tandvårdsförsäkring",
    "tandvårdsförsäkringars": "tandvårdsförsäkring",
    "tandvårdsförsäkringen": "tandvårdsförsäkring",
    "tandvårdsförsäkringens": "tandvårdsförsäkring",
    "tandvårdsförsäkrings": "tandvårdsförsäkring",
    "tandvårdsstödet": "tandvårdsstöd",
    "tandvårdsstödets": "tandvårdsstöd",
    "tandvårdsstöds": "tandvårdsstöd",
    "tandytan": "tandyta",
    "tandytans": "tandyta",
    "tandytas": "tandyta",
    "tandyte": "tandyta",
    "tandytor": "tandyta",
    "tandytorna": "tandyta",
    "tandytornas": "tandyta",
    "tandytors": "tandyta",
    "tandömsningar": "tandömsning",
    "tandömsningarna": "tandömsning",
    "tandömsningarnas": "tandömsning",
    "tandömsningars": "tandömsning",
    "tandömsningen": "tandömsning",
    "tandömsningens": "tandömsning",
    "tandömsnings": "tandömsning",
    "tane": "tana",
    "tangakalsongen": "tangakalsong",
    "tangakalsongens": "tangakalsong",
    "tangakalsonger": "tangakalsong",
    "tangakalsongerna": "tangakalsong",
    "tangakalsongernas": "tangakalsong",
    "tangakalsongers": "tangakalsong",
    "tangakalsongs": "tangakalsong",
    "tangensen": "tangens",
    "tangensens": "tangens",
    "tangentborden": "tangentbord",
    "tangentbordens": "tangentbord",
    "tangentbordet": "tangentbord",
    "tangentbordets": "tangentbord",
    "tangentbords": "tangentbord",
    "tangenten": "tangent",
    "tangentens": "tangent",
    "tangenter": "tangent",
    "tangenterna": "tangent",
    "tangenternas": "tangent",
    "tangenters": "tangent",
    "tangentinstrumenten": "tangentinstrument",
    "tangentinstrumentens": "tangentinstrument",
    "tangentinstrumentet": "tangentinstrument",
    "tangentinstrumentets": "tangentinstrument",
    "tangentinstruments": "tangentinstrument",
    "tangentplanen": "tangentplan",
    "tangentplanens": "tangentplan",
    "tangentplanet": "tangentplan",
    "tangentplanets": "tangentplan",
    "tangentplans": "tangentplan",
    "tangents": "tangent",
    "tangerad": "tangera",
    "tangerade": "tangera",
    "tangerades": "tangera",
    "tangerads": "tangera",
    "tangerande": "tangera",
    "tangeranden": "tangerande",
    "tangerandena": "tangerande",
    "tangerandenas": "tangerande",
    "tangerandens": "tangerande",
    "tangerandes": "tangerande",
    "tangerandet": "tangerande",
    "tangerandets": "tangerande",
    "tangerar": "tangera",
    "tangeras": "tangera",
    "tangerat": "tangera",
    "tangerats": "tangera",
    "tangerbara": "tangerbar",
    "tangerbarare": "tangerbar",
    "tangerbarares": "tangerbar",
    "tangerbaras": "tangerbar",
    "tangerbarast": "tangerbar",
    "tangerbaraste": "tangerbar",
    "tangerbarastes": "tangerbar",
    "tangerbarasts": "tangerbar",
    "tangerbare": "tangerbar",
    "tangerbares": "tangerbar",
    "tangerbarheten": "tangerbarhet",
    "tangerbarhetens": "tangerbarhet",
    "tangerbarhets": "tangerbarhet",
    "tangerbars": "tangerbar",
    "tangerbart": "tangerbar",
    "tangerbarts": "tangerbar",
    "tangerinen": "tangerin",
    "tangerinens": "tangerin",
    "tangeriner": "tangerin",
    "tangerinerna": "tangerin",
    "tangerinernas": "tangerin",
    "tangeriners": "tangerin",
    "tangeringar": "tangering",
    "tangeringarna": "tangering",
    "tangeringarnas": "tangering",
    "tangeringars": "tangering",
    "tangeringen": "tangering",
    "tangeringens": "tangering",
    "tangerings": "tangering",
    "tangeringspunkten": "tangeringspunkt",
    "tangeringspunktens": "tangeringspunkt",
    "tangeringspunkter": "tangeringspunkt",
    "tangeringspunkterna": "tangeringspunkt",
    "tangeringspunkternas": "tangeringspunkt",
    "tangeringspunkters": "tangeringspunkt",
    "tangeringspunkts": "tangeringspunkt",
    "tangerins": "tangerin",
    "tangoer": "tango",
    "tangoerna": "tango",
    "tangoernas": "tango",
    "tangoers": "tango",
    "tangon": "tango",
    "tangons": "tango",
    "tangor": "tango",
    "tangorabatten": "tangorabatt",
    "tangorabattens": "tangorabatt",
    "tangorabatter": "tangorabatt",
    "tangorabatterna": "tangorabatt",
    "tangorabatternas": "tangorabatt",
    "tangorabatters": "tangorabatt",
    "tangorabatts": "tangorabatt",
    "tangorna": "tango",
    "tangornas": "tango",
    "tangors": "tango",
    "tangos": "tango",
    "tangosar": "tango",
    "tangosarna": "tango",
    "tangosarnas": "tango",
    "tangosars": "tango",
    "taniga": "tanig",
    "tanigare": "tanig",
    "tanigares": "tanig",
    "tanigas": "tanig",
    "tanigast": "tanig",
    "tanigaste": "tanig",
    "tanigastes": "tanig",
    "tanigasts": "tanig",
    "tanige": "tanig",
    "taniges": "tanig",
    "tanigs": "tanig",
    "tanigt": "tanig",
    "tanigts": "tanig",
    "tank": "tanka",
    "tankad": "tanka",
    "tankade": "tanka",
    "tankades": "tanka",
    "tankads": "tanka",
    "tankande": "tanka",
    "tankanden": "tankande",
    "tankandena": "tankande",
    "tankandenas": "tankande",
    "tankandens": "tankande",
    "tankandes": "tankande",
    "tankandet": "tankande",
    "tankandets": "tankande",
    "tankar": "tanke",
    "tankarna": "tanke",
    "tankarnas": "tanke",
    "tankars": "tanke",
    "tankas": "tanka",
    "tankat": "tanka",
    "tankats": "tanka",
    "tankbilar": "tankbil",
    "tankbilarna": "tankbil",
    "tankbilarnas": "tankbil",
    "tankbilars": "tankbil",
    "tankbilen": "tankbil",
    "tankbilens": "tankbil",
    "tankbils": "tankbil",
    "tankearbeten": "tankearbete",
    "tankearbetena": "tankearbete",
    "tankearbetenas": "tankearbete",
    "tankearbetens": "tankearbete",
    "tankearbetes": "tankearbete",
    "tankearbetet": "tankearbete",
    "tankearbetets": "tankearbete",
    "tankearbets": "tankearbete",
    "tankebanan": "tankebana",
    "tankebanans": "tankebana",
    "tankebanas": "tankebana",
    "tankebane": "tankebana",
    "tankebanor": "tankebana",
    "tankebanorna": "tankebana",
    "tankebanornas": "tankebana",
    "tankebanors": "tankebana",
    "tankebyggnaden": "tankebyggnad",
    "tankebyggnadens": "tankebyggnad",
    "tankebyggnader": "tankebyggnad",
    "tankebyggnaderna": "tankebyggnad",
    "tankebyggnadernas": "tankebyggnad",
    "tankebyggnaders": "tankebyggnad",
    "tankebyggnads": "tankebyggnad",
    "tankedigerheten": "tankedigerhet",
    "tankedigerhetens": "tankedigerhet",
    "tankedigerhets": "tankedigerhet",
    "tankedigers": "tankediger",
    "tankedigert": "tankediger",
    "tankedigerts": "tankediger",
    "tankedigra": "tankediger",
    "tankedigrare": "tankediger",
    "tankedigrares": "tankediger",
    "tankedigras": "tankediger",
    "tankedigrast": "tankediger",
    "tankedigraste": "tankediger",
    "tankedigrastes": "tankediger",
    "tankedigrasts": "tankediger",
    "tankedigre": "tankediger",
    "tankedigres": "tankediger",
    "tankedikten": "tankedikt",
    "tankediktens": "tankedikt",
    "tankedikter": "tankedikt",
    "tankedikterna": "tankedikt",
    "tankedikternas": "tankedikt",
    "tankedikters": "tankedikt",
    "tankedikts": "tankedikt",
    "tankedjupet": "tankedjup",
    "tankedjupets": "tankedjup",
    "tankedjups": "tankedjup",
    "tankeexperimenten": "tankeexperiment",
    "tankeexperimentens": "tankeexperiment",
    "tankeexperimentet": "tankeexperiment",
    "tankeexperimentets": "tankeexperiment",
    "tankeexperiments": "tankeexperiment",
    "tankefelen": "tankefel",
    "tankefelens": "tankefel",
    "tankefelet": "tankefel",
    "tankefelets": "tankefel",
    "tankefels": "tankefel",
    "tankefiguren": "tankefigur",
    "tankefigurens": "tankefigur",
    "tankefigurer": "tankefigur",
    "tankefigurerna": "tankefigur",
    "tankefigurernas": "tankefigur",
    "tankefigurers": "tankefigur",
    "tankefigurs": "tankefigur",
    "tankeflykten": "tankeflykt",
    "tankeflyktens": "tankeflykt",
    "tankeflykts": "tankeflykt",
    "tankefosterna": "tankefoster",
    "tankefosternas": "tankefoster",
    "tankefosters": "tankefoster",
    "tankefostren": "tankefoster",
    "tankefostrens": "tankefoster",
    "tankefostret": "tankefoster",
    "tankefostrets": "tankefoster",
    "tankefriheten": "tankefrihet",
    "tankefrihetens": "tankefrihet",
    "tankefriheter": "tankefrihet",
    "tankefriheterna": "tankefrihet",
    "tankefriheternas": "tankefrihet",
    "tankefriheters": "tankefrihet",
    "tankefrihets": "tankefrihet",
    "tankegångar": "tankegång",
    "tankegångarna": "tankegång",
    "tankegångarnas": "tankegång",
    "tankegångars": "tankegång",
    "tankegången": "tankegång",
    "tankegångens": "tankegång",
    "tankegångs": "tankegång",
    "tankeherraväldes": "tankeherravälde",
    "tankeherraväldet": "tankeherravälde",
    "tankeherraväldets": "tankeherravälde",
    "tankeinnehållet": "tankeinnehåll",
    "tankeinnehållets": "tankeinnehåll",
    "tankeinnehålls": "tankeinnehåll",
    "tankekraften": "tankekraft",
    "tankekraftens": "tankekraft",
    "tankekrafter": "tankekraft",
    "tankekrafterna": "tankekraft",
    "tankekrafternas": "tankekraft",
    "tankekrafters": "tankekraft",
    "tankekrafts": "tankekraft",
    "tankelagar": "tankelag",
    "tankelagarna": "tankelag",
    "tankelagarnas": "tankelag",
    "tankelagars": "tankelag",
    "tankelagen": "tankelag",
    "tankelagens": "tankelag",
    "tankelags": "tankelag",
    "tankeleden": "tankeled",
    "tankeledens": "tankeled",
    "tankeledet": "tankeled",
    "tankeledets": "tankeled",
    "tankeleds": "tankeled",
    "tankelekar": "tankelek",
    "tankelekarna": "tankelek",
    "tankelekarnas": "tankelek",
    "tankelekars": "tankelek",
    "tankeleken": "tankelek",
    "tankelekens": "tankelek",
    "tankeleks": "tankelek",
    "tankelivet": "tankeliv",
    "tankelivets": "tankeliv",
    "tankelivs": "tankeliv",
    "tankelyriken": "tankelyrik",
    "tankelyrikens": "tankelyrik",
    "tankelyriks": "tankelyrik",
    "tankeläsar": "tankeläsare",
    "tankeläsaren": "tankeläsare",
    "tankeläsarens": "tankeläsare",
    "tankeläsares": "tankeläsare",
    "tankeläsarna": "tankeläsare",
    "tankeläsarnas": "tankeläsare",
    "tankeläsningar": "tankeläsning",
    "tankeläsningarna": "tankeläsning",
    "tankeläsningarnas": "tankeläsning",
    "tankeläsningars": "tankeläsning",
    "tankeläsningen": "tankeläsning",
    "tankeläsningens": "tankeläsning",
    "tankeläsnings": "tankeläsning",
    "tankemetoden": "tankemetod",
    "tankemetodens": "tankemetod",
    "tankemetoder": "tankemetod",
    "tankemetoderna": "tankemetod",
    "tankemetodernas": "tankemetod",
    "tankemetoders": "tankemetod",
    "tankemetods": "tankemetod",
    "tankemässiga": "tankemässig",
    "tankemässigare": "tankemässig",
    "tankemässigares": "tankemässig",
    "tankemässigas": "tankemässig",
    "tankemässigast": "tankemässig",
    "tankemässigaste": "tankemässig",
    "tankemässigastes": "tankemässig",
    "tankemässigasts": "tankemässig",
    "tankemässige": "tankemässig",
    "tankemässiges": "tankemässig",
    "tankemässigheten": "tankemässighet",
    "tankemässighetens": "tankemässighet",
    "tankemässighets": "tankemässighet",
    "tankemässigs": "tankemässig",
    "tankemässigt": "tankemässig",
    "tankemässigts": "tankemässig",
    "tankemödan": "tankemöda",
    "tankemödans": "tankemöda",
    "tankemödas": "tankemöda",
    "tankemöde": "tankemöda",
    "tankemödo": "tankemöda",
    "tankemödor": "tankemöda",
    "tankemödorna": "tankemöda",
    "tankemödornas": "tankemöda",
    "tankemödors": "tankemöda",
    "tankemönsterna": "tankemönster",
    "tankemönsternas": "tankemönster",
    "tankemönsters": "tankemönster",
    "tankemönstren": "tankemönster",
    "tankemönstrens": "tankemönster",
    "tankemönstret": "tankemönster",
    "tankemönstrets": "tankemönster",
    "tanken": "tanke",
    "tankens": "tanke",
    "tankenöten": "tankenöt",
    "tankenötens": "tankenöt",
    "tankenöts": "tankenöt",
    "tankenötter": "tankenöt",
    "tankenötterna": "tankenöt",
    "tankenötternas": "tankenöt",
    "tankenötters": "tankenöt",
    "tankeredan": "tankereda",
    "tankeredans": "tankereda",
    "tankeredas": "tankereda",
    "tankern": "tanker",
    "tankerna": "tanker",
    "tankernas": "tanker",
    "tankerns": "tanker",
    "tankers": "tanker",
    "tankersarna": "tanker",
    "tankersarnas": "tanker",
    "tankes": "tanke",
    "tankesmedjan": "tankesmedja",
    "tankesmedjans": "tankesmedja",
    "tankesmedjas": "tankesmedja",
    "tankesmedje": "tankesmedja",
    "tankesmedjor": "tankesmedja",
    "tankesmedjorna": "tankesmedja",
    "tankesmedjornas": "tankesmedja",
    "tankesmedjors": "tankesmedja",
    "tankeställar": "tankeställare",
    "tankeställaren": "tankeställare",
    "tankeställarens": "tankeställare",
    "tankeställares": "tankeställare",
    "tankeställarna": "tankeställare",
    "tankeställarnas": "tankeställare",
    "tankesystemen": "tankesystem",
    "tankesystemens": "tankesystem",
    "tankesystemet": "tankesystem",
    "tankesystemets": "tankesystem",
    "tankesystems": "tankesystem",
    "tanketraditionen": "tanketradition",
    "tanketraditionens": "tanketradition",
    "tanketraditioner": "tanketradition",
    "tanketraditionerna": "tanketradition",
    "tanketraditionernas": "tanketradition",
    "tanketraditioners": "tanketradition",
    "tanketraditions": "tanketradition",
    "tankeutbyten": "tankeutbyte",
    "tankeutbytena": "tankeutbyte",
    "tankeutbytenas": "tankeutbyte",
    "tankeutbytens": "tankeutbyte",
    "tankeutbytes": "tankeutbyte",
    "tankeutbytet": "tankeutbyte",
    "tankeutbytets": "tankeutbyte",
    "tankevill": "tankevilla",
    "tankevillan": "tankevilla",
    "tankevillans": "tankevilla",
    "tankevillas": "tankevilla",
    "tankeville": "tankevilla",
    "tankevillor": "tankevilla",
    "tankevillorna": "tankevilla",
    "tankevillornas": "tankevilla",
    "tankevillors": "tankevilla",
    "tankevills": "tankevilla",
    "tankevurp": "tankevurpa",
    "tankevurpan": "tankevurpa",
    "tankevurpans": "tankevurpa",
    "tankevurpas": "tankevurpa",
    "tankevurpe": "tankevurpa",
    "tankevurpor": "tankevurpa",
    "tankevurporna": "tankevurpa",
    "tankevurpornas": "tankevurpa",
    "tankevurpors": "tankevurpa",
    "tankevurps": "tankevurpa",
    "tankevärlden": "tankevärld",
    "tankevärldens": "tankevärld",
    "tankevärlds": "tankevärld",
    "tankeöverföringar": "tankeöverföring",
    "tankeöverföringarna": "tankeöverföring",
    "tankeöverföringarnas": "tankeöverföring",
    "tankeöverföringars": "tankeöverföring",
    "tankeöverföringen": "tankeöverföring",
    "tankeöverföringens": "tankeöverföring",
    "tankeöverförings": "tankeöverföring",
    "tankfartygen": "tankfartyg",
    "tankfartygens": "tankfartyg",
    "tankfartyget": "tankfartyg",
    "tankfartygets": "tankfartyg",
    "tankfartygs": "tankfartyg",
    "tankfulla": "tankfull",
    "tankfullare": "tankfull",
    "tankfullares": "tankfull",
    "tankfullas": "tankfull",
    "tankfullast": "tankfull",
    "tankfullaste": "tankfull",
    "tankfullastes": "tankfull",
    "tankfullasts": "tankfull",
    "tankfulle": "tankfull",
    "tankfulles": "tankfull",
    "tankfullheten": "tankfullhet",
    "tankfullhetens": "tankfullhet",
    "tankfullhets": "tankfullhet",
    "tankfulls": "tankfull",
    "tankfullt": "tankfull",
    "tankfullts": "tankfull",
    "tankgevären": "tankgevär",
    "tankgevärens": "tankgevär",
    "tankgeväret": "tankgevär",
    "tankgevärets": "tankgevär",
    "tankgevärs": "tankgevär",
    "tankkapaciteten": "tankkapacitet",
    "tankkapacitetens": "tankkapacitet",
    "tankkapaciteter": "tankkapacitet",
    "tankkapaciteterna": "tankkapacitet",
    "tankkapaciteternas": "tankkapacitet",
    "tankkapaciteters": "tankkapacitet",
    "tankkapacitets": "tankkapacitet",
    "tanklösa": "tanklös",
    "tanklösare": "tanklös",
    "tanklösares": "tanklös",
    "tanklösas": "tanklös",
    "tanklösast": "tanklös",
    "tanklösaste": "tanklös",
    "tanklösastes": "tanklös",
    "tanklösasts": "tanklös",
    "tanklöse": "tanklös",
    "tanklöses": "tanklös",
    "tanklösheten": "tanklöshet",
    "tanklöshetens": "tanklöshet",
    "tanklösheter": "tanklöshet",
    "tanklösheterna": "tanklöshet",
    "tanklösheternas": "tanklöshet",
    "tanklösheters": "tanklöshet",
    "tanklöshets": "tanklöshet",
    "tanklöst": "tanklös",
    "tanklösts": "tanklös",
    "tankomaten": "tankomat",
    "tankomatens": "tankomat",
    "tankomater": "tankomat",
    "tankomaterna": "tankomat",
    "tankomaternas": "tankomat",
    "tankomaters": "tankomat",
    "tankomats": "tankomat",
    "tankrar": "tanker",
    "tankrarna": "tanker",
    "tankrarnas": "tanker",
    "tankrars": "tanker",
    "tanks": "tank",
    "tanksarna": "tank",
    "tanksarnas": "tank",
    "tanksen": "tanks",
    "tanksens": "tanks",
    "tankset": "tanks",
    "tanksets": "tanks",
    "tankspridda": "tankspridd",
    "tankspriddare": "tankspridd",
    "tankspriddares": "tankspridd",
    "tankspriddas": "tankspridd",
    "tankspriddast": "tankspridd",
    "tankspriddaste": "tankspridd",
    "tankspriddastes": "tankspridd",
    "tankspriddasts": "tankspridd",
    "tankspridde": "tankspridd",
    "tankspriddes": "tankspridd",
    "tankspriddheten": "tankspriddhet",
    "tankspriddhetens": "tankspriddhet",
    "tankspriddhets": "tankspriddhet",
    "tankspridds": "tankspridd",
    "tankspritt": "tankspridd",
    "tankspritts": "tankspridd",
    "tankstrecken": "tankstreck",
    "tankstreckens": "tankstreck",
    "tankstrecket": "tankstreck",
    "tankstreckets": "tankstreck",
    "tankstrecks": "tankstreck",
    "tankvagnar": "tankvagn",
    "tankvagnarna": "tankvagn",
    "tankvagnarnas": "tankvagn",
    "tankvagnars": "tankvagn",
    "tankvagnen": "tankvagn",
    "tankvagnens": "tankvagn",
    "tankvagns": "tankvagn",
    "tankvolymen": "tankvolym",
    "tankvolymens": "tankvolym",
    "tankvolymer": "tankvolym",
    "tankvolymerna": "tankvolym",
    "tankvolymernas": "tankvolym",
    "tankvolymers": "tankvolym",
    "tankvolyms": "tankvolym",
    "tanninen": "tannin",
    "tanninens": "tannin",
    "tanninet": "tannin",
    "tanninets": "tannin",
    "tannins": "tannin",
    "tanor": "tana",
    "tanorna": "tana",
    "tanornas": "tana",
    "tanors": "tana",
    "tans": "tana",
    "tantaktiga": "tantaktig",
    "tantaktigare": "tantaktig",
    "tantaktigares": "tantaktig",
    "tantaktigas": "tantaktig",
    "tantaktigast": "tantaktig",
    "tantaktigaste": "tantaktig",
    "tantaktigastes": "tantaktig",
    "tantaktigasts": "tantaktig",
    "tantaktige": "tantaktig",
    "tantaktiges": "tantaktig",
    "tantaktigheten": "tantaktighet",
    "tantaktighetens": "tantaktighet",
    "tantaktighets": "tantaktighet",
    "tantaktigs": "tantaktig",
    "tantaktigt": "tantaktig",
    "tantaktigts": "tantaktig",
    "tantalen": "tantal",
    "tantalens": "tantal",
    "tantalet": "tantal",
    "tantalets": "tantal",
    "tantalikvalen": "tantalikval",
    "tantalikvalens": "tantalikval",
    "tantalikvalet": "tantalikval",
    "tantalikvalets": "tantalikval",
    "tantalikvals": "tantalikval",
    "tantaliten": "tantalit",
    "tantalitens": "tantalit",
    "tantalits": "tantalit",
    "tantals": "tantal",
    "tantaluskvalen": "tantaluskval",
    "tantaluskvalens": "tantaluskval",
    "tantaluskvals": "tantaluskval",
    "tanten": "tant",
    "tantens": "tant",
    "tanter": "tant",
    "tanterna": "tant",
    "tanternas": "tant",
    "tanters": "tant",
    "tantiemen": "tantiem",
    "tantiemens": "tantiem",
    "tantiemer": "tantiem",
    "tantiemerna": "tantiem",
    "tantiemernas": "tantiem",
    "tantiemers": "tantiem",
    "tantiemet": "tantiem",
    "tantiemets": "tantiem",
    "tantiems": "tantiem",
    "tantiga": "tantig",
    "tantigare": "tantig",
    "tantigares": "tantig",
    "tantigas": "tantig",
    "tantigast": "tantig",
    "tantigaste": "tantig",
    "tantigastes": "tantig",
    "tantigasts": "tantig",
    "tantige": "tantig",
    "tantiges": "tantig",
    "tantigheten": "tantighet",
    "tantighetens": "tantighet",
    "tantighets": "tantighet",
    "tantigs": "tantig",
    "tantigt": "tantig",
    "tantigts": "tantig",
    "tants": "tant",
    "tantsnusket": "tantsnusk",
    "tantsnuskets": "tantsnusk",
    "tantsnusks": "tantsnusk",
    "tanzaniern": "tanzanier",
    "tanzanierna": "tanzanier",
    "tanzaniernas": "tanzanier",
    "tanzanierns": "tanzanier",
    "tanzaniers": "tanzanier",
    "tanzaniska": "tanzanisk",
    "tanzaniskan": "tanzaniska",
    "tanzaniskans": "tanzaniska",
    "tanzaniskare": "tanzanisk",
    "tanzaniskares": "tanzanisk",
    "tanzaniskas": "tanzaniska",
    "tanzaniskast": "tanzanisk",
    "tanzaniskaste": "tanzanisk",
    "tanzaniskastes": "tanzanisk",
    "tanzaniskasts": "tanzanisk",
    "tanzaniske": "tanzaniska",
    "tanzaniskes": "tanzanisk",
    "tanzaniskor": "tanzaniska",
    "tanzaniskorna": "tanzaniska",
    "tanzaniskornas": "tanzaniska",
    "tanzaniskors": "tanzaniska",
    "tanzanisks": "tanzanisk",
    "tanzaniskt": "tanzanisk",
    "tanzaniskts": "tanzanisk",
    "taoismen": "taoism",
    "taoismens": "taoism",
    "taoismer": "taoism",
    "taoismerna": "taoism",
    "taoismernas": "taoism",
    "taoismers": "taoism",
    "taoisms": "taoism",
    "taoisten": "taoist",
    "taoistens": "taoist",
    "taoister": "taoist",
    "taoisterna": "taoist",
    "taoisternas": "taoist",
    "taoisters": "taoist",
    "taoistiska": "taoistisk",
    "taoistiskas": "taoistisk",
    "taoistiske": "taoistisk",
    "taoistiskes": "taoistisk",
    "taoistisks": "taoistisk",
    "taoistiskt": "taoistisk",
    "taoistiskts": "taoistisk",
    "taoists": "taoist",
    "tap": "tape",
    "tapar": "tape",
    "taparna": "tape",
    "taparnas": "tape",
    "tapars": "tape",
    "tapen": "tape",
    "tapens": "tape",
    "taper": "tape",
    "taperna": "tape",
    "tapernas": "tape",
    "tapers": "tape",
    "tapes": "tape",
    "tapetborst": "tapetborste",
    "tapetborstar": "tapetborste",
    "tapetborstarna": "tapetborste",
    "tapetborstarnas": "tapetborste",
    "tapetborstars": "tapetborste",
    "tapetborsten": "tapetborste",
    "tapetborstens": "tapetborste",
    "tapetborstes": "tapetborste",
    "tapetbården": "tapetbård",
    "tapetbårdens": "tapetbård",
    "tapetbårder": "tapetbård",
    "tapetbårderna": "tapetbård",
    "tapetbårdernas": "tapetbård",
    "tapetbårders": "tapetbård",
    "tapetbårds": "tapetbård",
    "tapetdörrar": "tapetdörr",
    "tapetdörrarna": "tapetdörr",
    "tapetdörrarnas": "tapetdörr",
    "tapetdörrars": "tapetdörr",
    "tapetdörren": "tapetdörr",
    "tapetdörrens": "tapetdörr",
    "tapetdörrs": "tapetdörr",
    "tapeten": "tapet",
    "tapetens": "tapet",
    "tapeter": "tapet",
    "tapeterna": "tapet",
    "tapeternas": "tapet",
    "tapeters": "tapet",
    "tapets": "tapet",
    "tapetserad": "tapetsera",
    "tapetserade": "tapetsera",
    "tapetserades": "tapetsera",
    "tapetserads": "tapetsera",
    "tapetserande": "tapetsera",
    "tapetseranden": "tapetserande",
    "tapetserandena": "tapetserande",
    "tapetserandenas": "tapetserande",
    "tapetserandens": "tapetserande",
    "tapetserandes": "tapetserande",
    "tapetserandet": "tapetserande",
    "tapetserandets": "tapetserande",
    "tapetserar": "tapetserare",
    "tapetseraren": "tapetserare",
    "tapetserarens": "tapetserare",
    "tapetserares": "tapetserare",
    "tapetserarna": "tapetserare",
    "tapetserarnas": "tapetserare",
    "tapetserarstiften": "tapetserarstift",
    "tapetserarstiftens": "tapetserarstift",
    "tapetserarstiftet": "tapetserarstift",
    "tapetserarstiftets": "tapetserarstift",
    "tapetserarstifts": "tapetserarstift",
    "tapetseras": "tapetsera",
    "tapetserat": "tapetsera",
    "tapetserats": "tapetsera",
    "tapetserbara": "tapetserbar",
    "tapetserbarare": "tapetserbar",
    "tapetserbarares": "tapetserbar",
    "tapetserbaras": "tapetserbar",
    "tapetserbarast": "tapetserbar",
    "tapetserbaraste": "tapetserbar",
    "tapetserbarastes": "tapetserbar",
    "tapetserbarasts": "tapetserbar",
    "tapetserbare": "tapetserbar",
    "tapetserbares": "tapetserbar",
    "tapetserbarheten": "tapetserbarhet",
    "tapetserbarhetens": "tapetserbarhet",
    "tapetserbarhets": "tapetserbarhet",
    "tapetserbars": "tapetserbar",
    "tapetserbart": "tapetserbar",
    "tapetserbarts": "tapetserbar",
    "tapetseringar": "tapetsering",
    "tapetseringarna": "tapetsering",
    "tapetseringarnas": "tapetsering",
    "tapetseringars": "tapetsering",
    "tapetseringen": "tapetsering",
    "tapetseringens": "tapetsering",
    "tapetserings": "tapetsering",
    "tapetvåden": "tapetvåd",
    "tapetvådens": "tapetvåd",
    "tapetvåder": "tapetvåd",
    "tapetvåderna": "tapetvåd",
    "tapetvådernas": "tapetvåd",
    "tapetvåders": "tapetvåd",
    "tapetvåds": "tapetvåd",
    "tapiokan": "tapioka",
    "tapiokans": "tapioka",
    "tapiokas": "tapioka",
    "tapiren": "tapir",
    "tapirens": "tapir",
    "tapirer": "tapir",
    "tapirerna": "tapir",
    "tapirernas": "tapir",
    "tapirers": "tapir",
    "tapirs": "tapir",
    "tapisseriaffären": "tapisseriaffär",
    "tapisseriaffärens": "tapisseriaffär",
    "tapisseriaffärer": "tapisseriaffär",
    "tapisseriaffärerna": "tapisseriaffär",
    "tapisseriaffärernas": "tapisseriaffär",
    "tapisseriaffärers": "tapisseriaffär",
    "tapisseriaffärs": "tapisseriaffär",
    "tapisserier": "tapisseri",
    "tapisserierna": "tapisseri",
    "tapisseriernas": "tapisseri",
    "tapisseriers": "tapisseri",
    "tapisseriet": "tapisseri",
    "tapisseriets": "tapisseri",
    "tapisserinålar": "tapisserinål",
    "tapisserinålarna": "tapisserinål",
    "tapisserinålarnas": "tapisserinål",
    "tapisserinålars": "tapisserinål",
    "tapisserinålen": "tapisserinål",
    "tapisserinålens": "tapisserinål",
    "tapisserinåls": "tapisserinål",
    "tapisseris": "tapisseri",
    "tapisserit": "tapisseri",
    "tapisserits": "tapisseri",
    "tapp": "tappa",
    "tappad": "tappa",
    "tappade": "tappa",
    "tappades": "tappa",
    "tappads": "tappa",
    "tappande": "tappa",
    "tappanden": "tappande",
    "tappandena": "tappande",
    "tappandenas": "tappande",
    "tappandens": "tappande",
    "tappandes": "tappande",
    "tappandet": "tappande",
    "tappandets": "tappande",
    "tappar": "tappa",
    "tapparna": "tapp",
    "tapparnas": "tapp",
    "tappars": "tapp",
    "tappas": "tappa",
    "tappat": "tappa",
    "tappats": "tappa",
    "tappborrar": "tappborr",
    "tappborrarna": "tappborr",
    "tappborrarnas": "tappborr",
    "tappborrars": "tappborr",
    "tappborren": "tappborr",
    "tappborrens": "tappborr",
    "tappborret": "tappborr",
    "tappborrets": "tappborr",
    "tappborrs": "tappborr",
    "tappen": "tapp",
    "tappens": "tapp",
    "tapperheten": "tapperhet",
    "tapperhetens": "tapperhet",
    "tapperheter": "tapperhet",
    "tapperheterna": "tapperhet",
    "tapperheternas": "tapperhet",
    "tapperheters": "tapperhet",
    "tapperhets": "tapperhet",
    "tapperhetsmedaljen": "tapperhetsmedalj",
    "tapperhetsmedaljens": "tapperhetsmedalj",
    "tapperhetsmedaljer": "tapperhetsmedalj",
    "tapperhetsmedaljerna": "tapperhetsmedalj",
    "tapperhetsmedaljernas": "tapperhetsmedalj",
    "tapperhetsmedaljers": "tapperhetsmedalj",
    "tapperhetsmedaljs": "tapperhetsmedalj",
    "tappers": "tapper",
    "tappert": "tapper",
    "tapperts": "tapper",
    "tappet": "tapp",
    "tappets": "tapp",
    "tapphålen": "tapphål",
    "tapphålens": "tapphål",
    "tapphålet": "tapphål",
    "tapphålets": "tapphål",
    "tapphåls": "tapphål",
    "tappkranar": "tappkran",
    "tappkranarna": "tappkran",
    "tappkranarnas": "tappkran",
    "tappkranars": "tappkran",
    "tappkranen": "tappkran",
    "tappkranens": "tappkran",
    "tappkrans": "tappkran",
    "tapplagerna": "tapplager",
    "tapplagernas": "tapplager",
    "tapplagers": "tapplager",
    "tapplagren": "tapplager",
    "tapplagrens": "tapplager",
    "tapplagret": "tapplager",
    "tapplagrets": "tapplager",
    "tappningar": "tappning",
    "tappningarna": "tappning",
    "tappningarnas": "tappning",
    "tappningars": "tappning",
    "tappningen": "tappning",
    "tappningens": "tappning",
    "tappnings": "tappning",
    "tappningsrören": "tappningsrör",
    "tappningsrörens": "tappningsrör",
    "tappningsröret": "tappningsrör",
    "tappningsrörets": "tappningsrör",
    "tappningsrörs": "tappningsrör",
    "tappra": "tapper",
    "tapprare": "tapper",
    "tapprares": "tapper",
    "tappras": "tapper",
    "tapprast": "tapper",
    "tappraste": "tapper",
    "tapprastes": "tapper",
    "tapprasts": "tapper",
    "tappre": "tapper",
    "tappres": "tapper",
    "tapps": "tapp",
    "tappstationen": "tappstation",
    "tappstationens": "tappstation",
    "tappstationer": "tappstation",
    "tappstationerna": "tappstation",
    "tappstationernas": "tappstation",
    "tappstationers": "tappstation",
    "tappstations": "tappstation",
    "tappten": "tappt",
    "tapptens": "tappt",
    "tappter": "tappt",
    "tappterna": "tappt",
    "tappternas": "tappt",
    "tappters": "tappt",
    "tappts": "tappt",
    "taps": "tape",
    "tapton": "tapto",
    "taptona": "tapto",
    "taptonas": "tapto",
    "taptons": "tapto",
    "taptos": "tapto",
    "taptot": "tapto",
    "taptots": "tapto",
    "tar": "ta",
    "taran": "tara",
    "tarans": "tara",
    "tarantell": "tarantella",
    "tarantellan": "tarantella",
    "tarantellans": "tarantella",
    "tarantellas": "tarantella",
    "tarantelle": "tarantella",
    "tarantellor": "tarantella",
    "tarantellorna": "tarantella",
    "tarantellornas": "tarantella",
    "tarantellors": "tarantella",
    "tarantells": "tarantella",
    "taranteln": "tarantel",
    "tarantelns": "tarantel",
    "tarantels": "tarantel",
    "tarantlar": "tarantel",
    "tarantlarna": "tarantel",
    "tarantlarnas": "tarantel",
    "tarantlars": "tarantel",
    "taras": "tara",
    "tarerad": "tarera",
    "tarerade": "tarera",
    "tarerades": "tarera",
    "tarerads": "tarera",
    "tarerande": "tarera",
    "tareranden": "tarerande",
    "tarerandena": "tarerande",
    "tarerandenas": "tarerande",
    "tarerandens": "tarerande",
    "tarerandes": "tarerande",
    "tarerandet": "tarerande",
    "tarerandets": "tarerande",
    "tarerar": "tarera",
    "tareras": "tarera",
    "tarerat": "tarera",
    "tarerats": "tarera",
    "tarerbara": "tarerbar",
    "tarerbarare": "tarerbar",
    "tarerbarares": "tarerbar",
    "tarerbaras": "tarerbar",
    "tarerbarast": "tarerbar",
    "tarerbaraste": "tarerbar",
    "tarerbarastes": "tarerbar",
    "tarerbarasts": "tarerbar",
    "tarerbare": "tarerbar",
    "tarerbares": "tarerbar",
    "tarerbarheten": "tarerbarhet",
    "tarerbarhetens": "tarerbarhet",
    "tarerbarhets": "tarerbarhet",
    "tarerbars": "tarerbar",
    "tarerbart": "tarerbar",
    "tarerbarts": "tarerbar",
    "tareringar": "tarering",
    "tareringarna": "tarering",
    "tareringarnas": "tarering",
    "tareringars": "tarering",
    "tareringen": "tarering",
    "tareringens": "tarering",
    "tarerings": "tarering",
    "tariffen": "tariff",
    "tariffens": "tariff",
    "tariffer": "tariff",
    "tarifferad": "tariffera",
    "tarifferade": "tariffera",
    "tarifferades": "tariffera",
    "tarifferads": "tariffera",
    "tarifferande": "tariffera",
    "tarifferanden": "tarifferande",
    "tarifferandena": "tarifferande",
    "tarifferandenas": "tarifferande",
    "tarifferandens": "tarifferande",
    "tarifferandes": "tarifferande",
    "tarifferandet": "tarifferande",
    "tarifferandets": "tarifferande",
    "tarifferar": "tariffera",
    "tarifferas": "tariffera",
    "tarifferat": "tariffera",
    "tarifferats": "tariffera",
    "tarifferbara": "tarifferbar",
    "tarifferbarare": "tarifferbar",
    "tarifferbarares": "tarifferbar",
    "tarifferbaras": "tarifferbar",
    "tarifferbarast": "tarifferbar",
    "tarifferbaraste": "tarifferbar",
    "tarifferbarastes": "tarifferbar",
    "tarifferbarasts": "tarifferbar",
    "tarifferbare": "tarifferbar",
    "tarifferbares": "tarifferbar",
    "tarifferbarheten": "tarifferbarhet",
    "tarifferbarhetens": "tarifferbarhet",
    "tarifferbarhets": "tarifferbarhet",
    "tarifferbars": "tarifferbar",
    "tarifferbart": "tarifferbar",
    "tarifferbarts": "tarifferbar",
    "tarifferingar": "tariffering",
    "tarifferingarna": "tariffering",
    "tarifferingarnas": "tariffering",
    "tarifferingars": "tariffering",
    "tarifferingen": "tariffering",
    "tarifferingens": "tariffering",
    "tarifferings": "tariffering",
    "tarifferna": "tariff",
    "tariffernas": "tariff",
    "tariffers": "tariff",
    "tariffs": "tariff",
    "tarlatanen": "tarlatan",
    "tarlatanens": "tarlatan",
    "tarlatanet": "tarlatan",
    "tarlatanets": "tarlatan",
    "tarlatans": "tarlatan",
    "tarmar": "tarm",
    "tarmarna": "tarm",
    "tarmarnas": "tarm",
    "tarmars": "tarm",
    "tarmbakterien": "tarmbakterie",
    "tarmbakteriens": "tarmbakterie",
    "tarmbakterier": "tarmbakterie",
    "tarmbakterierna": "tarmbakterie",
    "tarmbakteriernas": "tarmbakterie",
    "tarmbakteriers": "tarmbakterie",
    "tarmbakteries": "tarmbakterie",
    "tarmbenen": "tarmben",
    "tarmbenens": "tarmben",
    "tarmbenet": "tarmben",
    "tarmbenets": "tarmben",
    "tarmbens": "tarmben",
    "tarmen": "tarm",
    "tarmens": "tarm",
    "tarmfisteln": "tarmfistel",
    "tarmfistelns": "tarmfistel",
    "tarmfistels": "tarmfistel",
    "tarmfistlar": "tarmfistel",
    "tarmfistlarna": "tarmfistel",
    "tarmfistlarnas": "tarmfistel",
    "tarmfistlars": "tarmfistel",
    "tarmförträngningar": "tarmförträngning",
    "tarmförträngningarna": "tarmförträngning",
    "tarmförträngningarnas": "tarmförträngning",
    "tarmförträngningars": "tarmförträngning",
    "tarmförträngningen": "tarmförträngning",
    "tarmförträngningens": "tarmförträngning",
    "tarmförträngnings": "tarmförträngning",
    "tarmgasen": "tarmgas",
    "tarmgasens": "tarmgas",
    "tarmgaser": "tarmgas",
    "tarmgaserna": "tarmgas",
    "tarmgasernas": "tarmgas",
    "tarmgasers": "tarmgas",
    "tarmkanalen": "tarmkanal",
    "tarmkanalens": "tarmkanal",
    "tarmkanaler": "tarmkanal",
    "tarmkanalerna": "tarmkanal",
    "tarmkanalernas": "tarmkanal",
    "tarmkanalers": "tarmkanal",
    "tarmkanals": "tarmkanal",
    "tarmkatarren": "tarmkatarr",
    "tarmkatarrens": "tarmkatarr",
    "tarmkatarrer": "tarmkatarr",
    "tarmkatarrerna": "tarmkatarr",
    "tarmkatarrernas": "tarmkatarr",
    "tarmkatarrers": "tarmkatarr",
    "tarmkatarrs": "tarmkatarr",
    "tarmkäxen": "tarmkäx",
    "tarmkäxens": "tarmkäx",
    "tarmkäxet": "tarmkäx",
    "tarmkäxets": "tarmkäx",
    "tarmludden": "tarmludd",
    "tarmluddens": "tarmludd",
    "tarmluddet": "tarmludd",
    "tarmluddets": "tarmludd",
    "tarmludds": "tarmludd",
    "tarmrörelsen": "tarmrörelse",
    "tarmrörelsens": "tarmrörelse",
    "tarmrörelser": "tarmrörelse",
    "tarmrörelserna": "tarmrörelse",
    "tarmrörelsernas": "tarmrörelse",
    "tarmrörelsers": "tarmrörelse",
    "tarmrörelses": "tarmrörelse",
    "tarms": "tarm",
    "tarmsaften": "tarmsaft",
    "tarmsaftens": "tarmsaft",
    "tarmsafter": "tarmsaft",
    "tarmsafterna": "tarmsaft",
    "tarmsafternas": "tarmsaft",
    "tarmsafters": "tarmsaft",
    "tarmsafts": "tarmsaft",
    "tarmsköljningar": "tarmsköljning",
    "tarmsköljningarna": "tarmsköljning",
    "tarmsköljningarnas": "tarmsköljning",
    "tarmsköljningars": "tarmsköljning",
    "tarmsköljningen": "tarmsköljning",
    "tarmsköljningens": "tarmsköljning",
    "tarmsköljnings": "tarmsköljning",
    "tarmstenen": "tarmsten",
    "tarmstenens": "tarmsten",
    "tarmstens": "tarmsten",
    "tarmsystemen": "tarmsystem",
    "tarmsystemens": "tarmsystem",
    "tarmsystemet": "tarmsystem",
    "tarmsystemets": "tarmsystem",
    "tarmsystems": "tarmsystem",
    "tarmvreden": "tarmvred",
    "tarmvredens": "tarmvred",
    "tarmvredet": "tarmvred",
    "tarmvredets": "tarmvred",
    "tarmvreds": "tarmvred",
    "taroken": "tarok",
    "tarokens": "tarok",
    "taroks": "tarok",
    "taron": "taro",
    "tarons": "taro",
    "taros": "taro",
    "tarsalbenen": "tarsalben",
    "tarsalbenens": "tarsalben",
    "tarsalbenet": "tarsalben",
    "tarsalbenets": "tarsalben",
    "tarsalbens": "tarsalben",
    "tarsen": "tars",
    "tarsens": "tars",
    "tarser": "tars",
    "tarserna": "tars",
    "tarsernas": "tars",
    "tarsers": "tars",
    "tartanen": "tartan",
    "tartanens": "tartan",
    "tartanet": "tartan",
    "tartanets": "tartan",
    "tartans": "tartan",
    "tartarbiffar": "tartarbiff",
    "tartarbiffarna": "tartarbiff",
    "tartarbiffarnas": "tartarbiff",
    "tartarbiffars": "tartarbiff",
    "tartarbiffen": "tartarbiff",
    "tartarbiffens": "tartarbiff",
    "tartarbiffs": "tartarbiff",
    "tartaren": "tartar",
    "tartarens": "tartar",
    "tartars": "tartar",
    "tartarsmörgåsar": "tartarsmörgås",
    "tartarsmörgåsarna": "tartarsmörgås",
    "tartarsmörgåsarnas": "tartarsmörgås",
    "tartarsmörgåsars": "tartarsmörgås",
    "tartarsmörgåsen": "tartarsmörgås",
    "tartarsmörgåsens": "tartarsmörgås",
    "tartarsåsen": "tartarsås",
    "tartarsåsens": "tartarsås",
    "tarteletten": "tartelett",
    "tartelettens": "tartelett",
    "tarteletter": "tartelett",
    "tarteletterna": "tartelett",
    "tarteletternas": "tartelett",
    "tarteletters": "tartelett",
    "tarteletts": "tartelett",
    "tartraten": "tartrat",
    "tartratens": "tartrat",
    "tartrater": "tartrat",
    "tartraterna": "tartrat",
    "tartraternas": "tartrat",
    "tartraters": "tartrat",
    "tartrats": "tartrat",
    "tarv": "tarva",
    "tarvad": "tarva",
    "tarvade": "tarva",
    "tarvades": "tarva",
    "tarvads": "tarva",
    "tarvande": "tarva",
    "tarvanden": "tarvande",
    "tarvandena": "tarvande",
    "tarvandenas": "tarvande",
    "tarvandens": "tarvande",
    "tarvandes": "tarvande",
    "tarvandet": "tarvande",
    "tarvandets": "tarvande",
    "tarvar": "tarva",
    "tarvas": "tarva",
    "tarvat": "tarva",
    "tarvats": "tarva",
    "tarvet": "tarv",
    "tarvets": "tarv",
    "tarvliga": "tarvlig",
    "tarvligare": "tarvlig",
    "tarvligares": "tarvlig",
    "tarvligas": "tarvlig",
    "tarvligast": "tarvlig",
    "tarvligaste": "tarvlig",
    "tarvligastes": "tarvlig",
    "tarvligasts": "tarvlig",
    "tarvlige": "tarvlig",
    "tarvliges": "tarvlig",
    "tarvligheten": "tarvlighet",
    "tarvlighetens": "tarvlighet",
    "tarvligheter": "tarvlighet",
    "tarvligheterna": "tarvlighet",
    "tarvligheternas": "tarvlighet",
    "tarvligheters": "tarvlighet",
    "tarvlighets": "tarvlighet",
    "tarvligs": "tarvlig",
    "tarvligt": "tarvlig",
    "tarvligts": "tarvlig",
    "tarvs": "tarv",
    "task": "taska",
    "taskan": "taska",
    "taskans": "taska",
    "taskar": "task",
    "taskarna": "task",
    "taskarnas": "task",
    "taskars": "task",
    "taskas": "taska",
    "taske": "taska",
    "tasken": "task",
    "taskens": "task",
    "taskiga": "taskig",
    "taskigare": "taskig",
    "taskigares": "taskig",
    "taskigas": "taskig",
    "taskigast": "taskig",
    "taskigaste": "taskig",
    "taskigastes": "taskig",
    "taskigasts": "taskig",
    "taskige": "taskig",
    "taskiges": "taskig",
    "taskigheten": "taskighet",
    "taskighetens": "taskighet",
    "taskigheter": "taskighet",
    "taskigheterna": "taskighet",
    "taskigheternas": "taskighet",
    "taskigheters": "taskighet",
    "taskighets": "taskighet",
    "taskigs": "taskig",
    "taskigt": "taskig",
    "taskigts": "taskig",
    "taskor": "taska",
    "taskorna": "taska",
    "taskornas": "taska",
    "taskors": "taska",
    "tasks": "task",
    "taskspelar": "taskspelare",
    "taskspelaren": "taskspelare",
    "taskspelarens": "taskspelare",
    "taskspelares": "taskspelare",
    "taskspelarna": "taskspelare",
    "taskspelarnas": "taskspelare",
    "taskspelerier": "taskspeleri",
    "taskspelerierna": "taskspeleri",
    "taskspeleriernas": "taskspeleri",
    "taskspeleriers": "taskspeleri",
    "taskspeleriet": "taskspeleri",
    "taskspeleriets": "taskspeleri",
    "taskspeleris": "taskspeleri",
    "taskspelerit": "taskspeleri",
    "taskspelerits": "taskspeleri",
    "tass": "tassa",
    "tassad": "tassa",
    "tassade": "tassa",
    "tassades": "tassa",
    "tassads": "tassa",
    "tassande": "tassa",
    "tassanden": "tassande",
    "tassandena": "tassande",
    "tassandenas": "tassande",
    "tassandens": "tassande",
    "tassandes": "tassande",
    "tassandet": "tassande",
    "tassandets": "tassande",
    "tassar": "tassa",
    "tassarna": "tass",
    "tassarnas": "tass",
    "tassars": "tass",
    "tassas": "tassa",
    "tassat": "tassa",
    "tassats": "tassa",
    "tassel": "tassla",
    "tassels": "tassel",
    "tassemarken": "tassemark",
    "tassemarkens": "tassemark",
    "tassemarker": "tassemark",
    "tassemarkerna": "tassemark",
    "tassemarkernas": "tassemark",
    "tassemarkers": "tassemark",
    "tassemarks": "tassemark",
    "tassen": "tass",
    "tassens": "tass",
    "tassfoten": "tassfot",
    "tassfotens": "tassfot",
    "tassfots": "tassfot",
    "tassfötter": "tassfot",
    "tassfötterna": "tassfot",
    "tassfötternas": "tassfot",
    "tassfötters": "tassfot",
    "tasslade": "tassla",
    "tasslades": "tassla",
    "tasslande": "tassla",
    "tasslanden": "tasslande",
    "tasslandena": "tasslande",
    "tasslandenas": "tasslande",
    "tasslandens": "tasslande",
    "tasslandes": "tasslande",
    "tasslandet": "tasslande",
    "tasslandets": "tasslande",
    "tasslar": "tassla",
    "tasslas": "tassla",
    "tasslat": "tassla",
    "tasslats": "tassla",
    "tasslet": "tassel",
    "tasslets": "tassel",
    "tataren": "tatar",
    "tatarens": "tatar",
    "tatarer": "tatar",
    "tatarerna": "tatar",
    "tatarernas": "tatar",
    "tatarers": "tatar",
    "tatars": "tatar",
    "tattar": "tattare",
    "tattaren": "tattare",
    "tattarens": "tattare",
    "tattares": "tattare",
    "tattarna": "tattare",
    "tattarnas": "tattare",
    "tatuerad": "tatuera",
    "tatuerade": "tatuera",
    "tatuerades": "tatuera",
    "tatuerads": "tatuera",
    "tatuerande": "tatuera",
    "tatueranden": "tatuerande",
    "tatuerandena": "tatuerande",
    "tatuerandenas": "tatuerande",
    "tatuerandens": "tatuerande",
    "tatuerandes": "tatuerande",
    "tatuerandet": "tatuerande",
    "tatuerandets": "tatuerande",
    "tatuerar": "tatuerare",
    "tatueraren": "tatuerare",
    "tatuerarens": "tatuerare",
    "tatuerares": "tatuerare",
    "tatuerarna": "tatuerare",
    "tatuerarnas": "tatuerare",
    "tatueras": "tatuera",
    "tatuerat": "tatuera",
    "tatuerats": "tatuera",
    "tatuerbara": "tatuerbar",
    "tatuerbarare": "tatuerbar",
    "tatuerbarares": "tatuerbar",
    "tatuerbaras": "tatuerbar",
    "tatuerbarast": "tatuerbar",
    "tatuerbaraste": "tatuerbar",
    "tatuerbarastes": "tatuerbar",
    "tatuerbarasts": "tatuerbar",
    "tatuerbare": "tatuerbar",
    "tatuerbares": "tatuerbar",
    "tatuerbarheten": "tatuerbarhet",
    "tatuerbarhetens": "tatuerbarhet",
    "tatuerbarhets": "tatuerbarhet",
    "tatuerbars": "tatuerbar",
    "tatuerbart": "tatuerbar",
    "tatuerbarts": "tatuerbar",
    "tatueringar": "tatuering",
    "tatueringarna": "tatuering",
    "tatueringarnas": "tatuering",
    "tatueringars": "tatuering",
    "tatueringen": "tatuering",
    "tatueringens": "tatuering",
    "tatuerings": "tatuering",
    "tauen": "tau",
    "tauens": "tau",
    "tauet": "tau",
    "tauets": "tau",
    "taus": "tau",
    "tautologien": "tautologi",
    "tautologiens": "tautologi",
    "tautologier": "tautologi",
    "tautologierna": "tautologi",
    "tautologiernas": "tautologi",
    "tautologiers": "tautologi",
    "tautologin": "tautologi",
    "tautologins": "tautologi",
    "tautologis": "tautologi",
    "tautomerien": "tautomeri",
    "tautomeriens": "tautomeri",
    "tautomerin": "tautomeri",
    "tautomerins": "tautomeri",
    "tautomeris": "tautomeri",
    "tavel": "tavla",
    "tavelgallerier": "tavelgalleri",
    "tavelgallerierna": "tavelgalleri",
    "tavelgalleriernas": "tavelgalleri",
    "tavelgalleriers": "tavelgalleri",
    "tavelgalleriet": "tavelgalleri",
    "tavelgalleriets": "tavelgalleri",
    "tavelgalleris": "tavelgalleri",
    "tavelgallerit": "tavelgalleri",
    "tavelgallerits": "tavelgalleri",
    "tavelsuddar": "tavelsudd",
    "tavelsuddarna": "tavelsudd",
    "tavelsuddarnas": "tavelsudd",
    "tavelsuddars": "tavelsudd",
    "tavelsudden": "tavelsudd",
    "tavelsuddens": "tavelsudd",
    "tavelsudds": "tavelsudd",
    "tavern": "taverna",
    "tavernan": "taverna",
    "tavernans": "taverna",
    "tavernas": "taverna",
    "taverne": "taverna",
    "tavernor": "taverna",
    "tavernorna": "taverna",
    "tavernornas": "taverna",
    "tavernors": "taverna",
    "taverns": "taverna",
    "tavlan": "tavla",
    "tavlans": "tavla",
    "tavlas": "tavla",
    "tavle": "tavla",
    "tavlor": "tavla",
    "tavlorna": "tavla",
    "tavlornas": "tavla",
    "tavlors": "tavla",
    "tax": "taxa",
    "tax-frees": "tax-free",
    "taxad": "taxa",
    "taxade": "taxa",
    "taxades": "taxa",
    "taxads": "taxa",
    "taxametern": "taxameter",
    "taxameterns": "taxameter",
    "taxameters": "taxameter",
    "taxametrar": "taxameter",
    "taxametrarna": "taxameter",
    "taxametrarnas": "taxameter",
    "taxametrars": "taxameter",
    "taxan": "taxa",
    "taxande": "taxa",
    "taxanden": "taxande",
    "taxandena": "taxande",
    "taxandenas": "taxande",
    "taxandens": "taxande",
    "taxandes": "taxande",
    "taxandet": "taxande",
    "taxandets": "taxande",
    "taxans": "taxa",
    "taxar": "taxa",
    "taxarna": "tax",
    "taxarnas": "tax",
    "taxars": "tax",
    "taxas": "taxa",
    "taxat": "taxa",
    "taxats": "taxa",
    "taxe": "taxa",
    "taxen": "tax",
    "taxens": "tax",
    "taxeområden": "taxeområde",
    "taxeområdena": "taxeområde",
    "taxeområdenas": "taxeområde",
    "taxeområdens": "taxeområde",
    "taxeområdes": "taxeområde",
    "taxeområdet": "taxeområde",
    "taxeområdets": "taxeområde",
    "taxerad": "taxera",
    "taxerade": "taxera",
    "taxerades": "taxera",
    "taxerads": "taxera",
    "taxerande": "taxera",
    "taxeranden": "taxerande",
    "taxerandena": "taxerande",
    "taxerandenas": "taxerande",
    "taxerandens": "taxerande",
    "taxerandes": "taxerande",
    "taxerandet": "taxerande",
    "taxerandets": "taxerande",
    "taxerar": "taxera",
    "taxeras": "taxera",
    "taxerat": "taxera",
    "taxerats": "taxera",
    "taxerbara": "taxerbar",
    "taxerbarare": "taxerbar",
    "taxerbarares": "taxerbar",
    "taxerbaras": "taxerbar",
    "taxerbarast": "taxerbar",
    "taxerbaraste": "taxerbar",
    "taxerbarastes": "taxerbar",
    "taxerbarasts": "taxerbar",
    "taxerbare": "taxerbar",
    "taxerbares": "taxerbar",
    "taxerbarheten": "taxerbarhet",
    "taxerbarhetens": "taxerbarhet",
    "taxerbarhets": "taxerbarhet",
    "taxerbars": "taxerbar",
    "taxerbart": "taxerbar",
    "taxerbarts": "taxerbar",
    "taxeringar": "taxering",
    "taxeringarna": "taxering",
    "taxeringarnas": "taxering",
    "taxeringars": "taxering",
    "taxeringen": "taxering",
    "taxeringens": "taxering",
    "taxerings": "taxering",
    "taxeringsassistenten": "taxeringsassistent",
    "taxeringsassistentens": "taxeringsassistent",
    "taxeringsassistenter": "taxeringsassistent",
    "taxeringsassistenterna": "taxeringsassistent",
    "taxeringsassistenternas": "taxeringsassistent",
    "taxeringsassistenters": "taxeringsassistent",
    "taxeringsassistents": "taxeringsassistent",
    "taxeringsbesluten": "taxeringsbeslut",
    "taxeringsbeslutens": "taxeringsbeslut",
    "taxeringsbeslutet": "taxeringsbeslut",
    "taxeringsbeslutets": "taxeringsbeslut",
    "taxeringsbesluts": "taxeringsbeslut",
    "taxeringsbevisen": "taxeringsbevis",
    "taxeringsbevisens": "taxeringsbevis",
    "taxeringsbeviset": "taxeringsbevis",
    "taxeringsbevisets": "taxeringsbevis",
    "taxeringsenheten": "taxeringsenhet",
    "taxeringsenhetens": "taxeringsenhet",
    "taxeringsenheter": "taxeringsenhet",
    "taxeringsenheterna": "taxeringsenhet",
    "taxeringsenheternas": "taxeringsenhet",
    "taxeringsenheters": "taxeringsenhet",
    "taxeringsenhets": "taxeringsenhet",
    "taxeringsintendenten": "taxeringsintendent",
    "taxeringsintendentens": "taxeringsintendent",
    "taxeringsintendenter": "taxeringsintendent",
    "taxeringsintendenterna": "taxeringsintendent",
    "taxeringsintendenternas": "taxeringsintendent",
    "taxeringsintendenters": "taxeringsintendent",
    "taxeringsintendents": "taxeringsintendent",
    "taxeringskalendern": "taxeringskalender",
    "taxeringskalenderns": "taxeringskalender",
    "taxeringskalenders": "taxeringskalender",
    "taxeringskalendrar": "taxeringskalender",
    "taxeringskalendrarna": "taxeringskalender",
    "taxeringskalendrarnas": "taxeringskalender",
    "taxeringskalendrars": "taxeringskalender",
    "taxeringslängden": "taxeringslängd",
    "taxeringslängdens": "taxeringslängd",
    "taxeringslängder": "taxeringslängd",
    "taxeringslängderna": "taxeringslängd",
    "taxeringslängdernas": "taxeringslängd",
    "taxeringslängders": "taxeringslängd",
    "taxeringslängds": "taxeringslängd",
    "taxeringsmannen": "taxeringsman",
    "taxeringsmannens": "taxeringsman",
    "taxeringsmans": "taxeringsman",
    "taxeringsmyndigheten": "taxeringsmyndighet",
    "taxeringsmyndighetens": "taxeringsmyndighet",
    "taxeringsmyndigheter": "taxeringsmyndighet",
    "taxeringsmyndigheterna": "taxeringsmyndighet",
    "taxeringsmyndigheternas": "taxeringsmyndighet",
    "taxeringsmyndigheters": "taxeringsmyndighet",
    "taxeringsmyndighets": "taxeringsmyndighet",
    "taxeringsmän": "taxeringsman",
    "taxeringsmännen": "taxeringsman",
    "taxeringsmännens": "taxeringsman",
    "taxeringsmäns": "taxeringsman",
    "taxeringsmässiga": "taxeringsmässig",
    "taxeringsmässigare": "taxeringsmässig",
    "taxeringsmässigares": "taxeringsmässig",
    "taxeringsmässigas": "taxeringsmässig",
    "taxeringsmässigast": "taxeringsmässig",
    "taxeringsmässigaste": "taxeringsmässig",
    "taxeringsmässigastes": "taxeringsmässig",
    "taxeringsmässigasts": "taxeringsmässig",
    "taxeringsmässige": "taxeringsmässig",
    "taxeringsmässiges": "taxeringsmässig",
    "taxeringsmässigs": "taxeringsmässig",
    "taxeringsmässigt": "taxeringsmässig",
    "taxeringsmässigts": "taxeringsmässig",
    "taxeringsnämnden": "taxeringsnämnd",
    "taxeringsnämndens": "taxeringsnämnd",
    "taxeringsnämnder": "taxeringsnämnd",
    "taxeringsnämnderna": "taxeringsnämnd",
    "taxeringsnämndernas": "taxeringsnämnd",
    "taxeringsnämnders": "taxeringsnämnd",
    "taxeringsnämnds": "taxeringsnämnd",
    "taxeringsvärden": "taxeringsvärde",
    "taxeringsvärdena": "taxeringsvärde",
    "taxeringsvärdenas": "taxeringsvärde",
    "taxeringsvärdens": "taxeringsvärde",
    "taxeringsvärdes": "taxeringsvärde",
    "taxeringsvärdet": "taxeringsvärde",
    "taxeringsvärdets": "taxeringsvärde",
    "taxeringsåren": "taxeringsår",
    "taxeringsårens": "taxeringsår",
    "taxeringsåret": "taxeringsår",
    "taxeringsårets": "taxeringsår",
    "taxeringsårs": "taxeringsår",
    "taxibilar": "taxibil",
    "taxibilarna": "taxibil",
    "taxibilarnas": "taxibil",
    "taxibilars": "taxibil",
    "taxibilen": "taxibil",
    "taxibilens": "taxibil",
    "taxibils": "taxibil",
    "taxichauffören": "taxichaufför",
    "taxichaufförens": "taxichaufför",
    "taxichaufförer": "taxichaufför",
    "taxichaufförerna": "taxichaufför",
    "taxichaufförernas": "taxichaufför",
    "taxichaufförers": "taxichaufför",
    "taxichaufförn": "taxichaufför",
    "taxichaufförns": "taxichaufför",
    "taxichaufförs": "taxichaufför",
    "taxikunden": "taxikund",
    "taxikundens": "taxikund",
    "taxikunder": "taxikund",
    "taxikunderna": "taxikund",
    "taxikundernas": "taxikund",
    "taxikunders": "taxikund",
    "taxikunds": "taxikund",
    "taxin": "taxi",
    "taxina": "taxi",
    "taxinas": "taxi",
    "taxins": "taxi",
    "taxiresan": "taxiresa",
    "taxiresans": "taxiresa",
    "taxiresas": "taxiresa",
    "taxirese": "taxiresa",
    "taxiresor": "taxiresa",
    "taxiresorna": "taxiresa",
    "taxiresornas": "taxiresa",
    "taxiresors": "taxiresa",
    "taxis": "taxi",
    "taxisen": "taxis",
    "taxisens": "taxis",
    "taxistationen": "taxistation",
    "taxistationens": "taxistation",
    "taxistationer": "taxistation",
    "taxistationerna": "taxistation",
    "taxistationernas": "taxistation",
    "taxistationers": "taxistation",
    "taxistations": "taxistation",
    "taxonomien": "taxonomi",
    "taxonomiens": "taxonomi",
    "taxonomier": "taxonomi",
    "taxonomierna": "taxonomi",
    "taxonomiernas": "taxonomi",
    "taxonomiers": "taxonomi",
    "taxonomin": "taxonomi",
    "taxonomins": "taxonomi",
    "taxonomis": "taxonomi",
    "taxonomiska": "taxonomisk",
    "taxonomiskas": "taxonomisk",
    "taxonomiske": "taxonomisk",
    "taxonomiskes": "taxonomisk",
    "taxonomisks": "taxonomisk",
    "taxonomiskt": "taxonomisk",
    "taxonomiskts": "taxonomisk",
    "taxor": "taxa",
    "taxorna": "taxa",
    "taxornas": "taxa",
    "taxors": "taxa",
    "taxvalpar": "taxvalp",
    "taxvalparna": "taxvalp",
    "taxvalparnas": "taxvalp",
    "taxvalpars": "taxvalp",
    "taxvalpen": "taxvalp",
    "taxvalpens": "taxvalp",
    "taxvalps": "taxvalp",
    "tazetten": "tazett",
    "tazettens": "tazett",
    "tazetter": "tazett",
    "tazetterna": "tazett",
    "tazetternas": "tazett",
    "tazetters": "tazett",
    "tazetts": "tazett",
    "tbc-s": "tbc",
    "tbc:s": "tbc",
    "tbcs": "tbc",
    "tchadiern": "tchadier",
    "tchadierna": "tchadier",
    "tchadiernas": "tchadier",
    "tchadierns": "tchadier",
    "tchadiers": "tchadier",
    "tchadiska": "tchadisk",
    "tchadiskan": "tchadiska",
    "tchadiskans": "tchadiska",
    "tchadiskare": "tchadisk",
    "tchadiskares": "tchadisk",
    "tchadiskas": "tchadiska",
    "tchadiskast": "tchadisk",
    "tchadiskaste": "tchadisk",
    "tchadiskastes": "tchadisk",
    "tchadiskasts": "tchadisk",
    "tchadiske": "tchadiska",
    "tchadiskes": "tchadisk",
    "tchadiskor": "tchadiska",
    "tchadiskorna": "tchadiska",
    "tchadiskornas": "tchadiska",
    "tchadiskors": "tchadiska",
    "tchadisks": "tchadisk",
    "tchadiskt": "tchadisk",
    "tchadiskts": "tchadisk",
    "teach-ina": "teach-in",
    "teach-inas": "teach-in",
    "teach-ins": "teach-in",
    "teaken": "teak",
    "teakens": "teak",
    "teaks": "teak",
    "teakträden": "teakträd",
    "teakträdens": "teakträd",
    "teakträdet": "teakträd",
    "teakträdets": "teakträd",
    "teakträds": "teakträd",
    "teamen": "team",
    "teamens": "team",
    "teamet": "team",
    "teamets": "team",
    "teams": "team",
    "teamworken": "teamwork",
    "teamworkens": "teamwork",
    "teamworker": "teamwork",
    "teamworkerna": "teamwork",
    "teamworkernas": "teamwork",
    "teamworkers": "teamwork",
    "teamworket": "teamwork",
    "teamworkets": "teamwork",
    "teamworks": "teamwork",
    "teateranmälans": "teateranmälan",
    "teateranmälningar": "teateranmälan",
    "teateranmälningarna": "teateranmälan",
    "teateranmälningarnas": "teateranmälan",
    "teateranmälningars": "teateranmälan",
    "teaterap": "teaterapa",
    "teaterapan": "teaterapa",
    "teaterapans": "teaterapa",
    "teaterapas": "teaterapa",
    "teaterape": "teaterapa",
    "teaterapor": "teaterapa",
    "teateraporna": "teaterapa",
    "teaterapornas": "teaterapa",
    "teaterapors": "teaterapa",
    "teateraps": "teaterapa",
    "teaterbesökar": "teaterbesökare",
    "teaterbesökaren": "teaterbesökare",
    "teaterbesökarens": "teaterbesökare",
    "teaterbesökares": "teaterbesökare",
    "teaterbesökarna": "teaterbesökare",
    "teaterbesökarnas": "teaterbesökare",
    "teaterbiljetten": "teaterbiljett",
    "teaterbiljettens": "teaterbiljett",
    "teaterbiljetter": "teaterbiljett",
    "teaterbiljetterna": "teaterbiljett",
    "teaterbiljetternas": "teaterbiljett",
    "teaterbiljetters": "teaterbiljett",
    "teaterbiljetts": "teaterbiljett",
    "teaterchefen": "teaterchef",
    "teaterchefens": "teaterchef",
    "teaterchefer": "teaterchef",
    "teatercheferna": "teaterchef",
    "teaterchefernas": "teaterchef",
    "teaterchefers": "teaterchef",
    "teaterchefs": "teaterchef",
    "teaterdebatten": "teaterdebatt",
    "teaterdebattens": "teaterdebatt",
    "teaterdebatter": "teaterdebatt",
    "teaterdebatterna": "teaterdebatt",
    "teaterdebatternas": "teaterdebatt",
    "teaterdebatters": "teaterdebatt",
    "teaterdebatts": "teaterdebatt",
    "teaterdekorationen": "teaterdekoration",
    "teaterdekorationens": "teaterdekoration",
    "teaterdekorationer": "teaterdekoration",
    "teaterdekorationerna": "teaterdekoration",
    "teaterdekorationernas": "teaterdekoration",
    "teaterdekorationers": "teaterdekoration",
    "teaterdekorations": "teaterdekoration",
    "teaterdistrikten": "teaterdistrikt",
    "teaterdistriktens": "teaterdistrikt",
    "teaterdistriktet": "teaterdistrikt",
    "teaterdistriktets": "teaterdistrikt",
    "teaterdistrikts": "teaterdistrikt",
    "teatereffekten": "teatereffekt",
    "teatereffektens": "teatereffekt",
    "teatereffekter": "teatereffekt",
    "teatereffekterna": "teatereffekt",
    "teatereffekternas": "teatereffekt",
    "teatereffekters": "teatereffekt",
    "teatereffekts": "teatereffekt",
    "teaterfiguren": "teaterfigur",
    "teaterfigurens": "teaterfigur",
    "teaterfigurer": "teaterfigur",
    "teaterfigurerna": "teaterfigur",
    "teaterfigurernas": "teaterfigur",
    "teaterfigurers": "teaterfigur",
    "teaterfigurs": "teaterfigur",
    "teaterföreställningar": "teaterföreställning",
    "teaterföreställningarna": "teaterföreställning",
    "teaterföreställningarnas": "teaterföreställning",
    "teaterföreställningars": "teaterföreställning",
    "teaterföreställningen": "teaterföreställning",
    "teaterföreställningens": "teaterföreställning",
    "teaterföreställnings": "teaterföreställning",
    "teatergruppen": "teatergrupp",
    "teatergruppens": "teatergrupp",
    "teatergrupper": "teatergrupp",
    "teatergrupperna": "teatergrupp",
    "teatergruppernas": "teatergrupp",
    "teatergruppers": "teatergrupp",
    "teatergrupps": "teatergrupp",
    "teaterhabituéen": "teaterhabitué",
    "teaterhabituéens": "teaterhabitué",
    "teaterhabituéer": "teaterhabitué",
    "teaterhabituéerna": "teaterhabitué",
    "teaterhabituéernas": "teaterhabitué",
    "teaterhabituéers": "teaterhabitué",
    "teaterhabituén": "teaterhabitué",
    "teaterhabituéns": "teaterhabitué",
    "teaterhabitués": "teaterhabitué",
    "teaterkikar": "teaterkikare",
    "teaterkikaren": "teaterkikare",
    "teaterkikarens": "teaterkikare",
    "teaterkikares": "teaterkikare",
    "teaterkikarna": "teaterkikare",
    "teaterkikarnas": "teaterkikare",
    "teaterkritiken": "teaterkritik",
    "teaterkritikens": "teaterkritik",
    "teaterkritiks": "teaterkritik",
    "teaterliven": "teaterliv",
    "teaterlivens": "teaterliv",
    "teaterlivet": "teaterliv",
    "teaterlivets": "teaterliv",
    "teaterlivs": "teaterliv",
    "teaterlogen": "teaterloge",
    "teaterlogens": "teaterloge",
    "teaterloger": "teaterloge",
    "teaterlogerna": "teaterloge",
    "teaterlogernas": "teaterloge",
    "teaterlogers": "teaterloge",
    "teaterloges": "teaterloge",
    "teatermaskinerier": "teatermaskineri",
    "teatermaskinerierna": "teatermaskineri",
    "teatermaskineriernas": "teatermaskineri",
    "teatermaskineriers": "teatermaskineri",
    "teatermaskineriet": "teatermaskineri",
    "teatermaskineriets": "teatermaskineri",
    "teatermaskineris": "teatermaskineri",
    "teatermaskinerit": "teatermaskineri",
    "teatermaskinerits": "teatermaskineri",
    "teatermaskinisten": "teatermaskinist",
    "teatermaskinistens": "teatermaskinist",
    "teatermaskinister": "teatermaskinist",
    "teatermaskinisterna": "teatermaskinist",
    "teatermaskinisternas": "teatermaskinist",
    "teatermaskinisters": "teatermaskinist",
    "teatermaskinists": "teatermaskinist",
    "teatermässiga": "teatermässig",
    "teatermässigare": "teatermässig",
    "teatermässigares": "teatermässig",
    "teatermässigas": "teatermässig",
    "teatermässigast": "teatermässig",
    "teatermässigaste": "teatermässig",
    "teatermässigastes": "teatermässig",
    "teatermässigasts": "teatermässig",
    "teatermässige": "teatermässig",
    "teatermässiges": "teatermässig",
    "teatermässigs": "teatermässig",
    "teatermässigt": "teatermässig",
    "teatermässigts": "teatermässig",
    "teatern": "teater",
    "teaterns": "teater",
    "teaterpjäsen": "teaterpjäs",
    "teaterpjäsens": "teaterpjäs",
    "teaterpjäser": "teaterpjäs",
    "teaterpjäserna": "teaterpjäs",
    "teaterpjäsernas": "teaterpjäs",
    "teaterpjäsers": "teaterpjäs",
    "teaterpubliken": "teaterpublik",
    "teaterpublikens": "teaterpublik",
    "teaterpubliks": "teaterpublik",
    "teaterrollen": "teaterroll",
    "teaterrollens": "teaterroll",
    "teaterroller": "teaterroll",
    "teaterrollerna": "teaterroll",
    "teaterrollernas": "teaterroll",
    "teaterrollers": "teaterroll",
    "teaterrolls": "teaterroll",
    "teaters": "teater",
    "teaterscenen": "teaterscen",
    "teaterscenens": "teaterscen",
    "teaterscener": "teaterscen",
    "teaterscenerna": "teaterscen",
    "teaterscenernas": "teaterscen",
    "teatersceners": "teaterscen",
    "teaterscens": "teaterscen",
    "teaterstycken": "teaterstycke",
    "teaterstyckena": "teaterstycke",
    "teaterstyckenas": "teaterstycke",
    "teaterstyckens": "teaterstycke",
    "teaterstyckes": "teaterstycke",
    "teaterstycket": "teaterstycke",
    "teaterstyckets": "teaterstycke",
    "teaterstycks": "teaterstycke",
    "teatersällskapen": "teatersällskap",
    "teatersällskapens": "teatersällskap",
    "teatersällskapet": "teatersällskap",
    "teatersällskapets": "teatersällskap",
    "teatersällskaps": "teatersällskap",
    "teaterviskningar": "teaterviskning",
    "teaterviskningarna": "teaterviskning",
    "teaterviskningarnas": "teaterviskning",
    "teaterviskningars": "teaterviskning",
    "teaterviskningen": "teaterviskning",
    "teaterviskningens": "teaterviskning",
    "teatervisknings": "teaterviskning",
    "teatrala": "teatral",
    "teatralare": "teatral",
    "teatralares": "teatral",
    "teatralas": "teatral",
    "teatralast": "teatral",
    "teatralaste": "teatral",
    "teatralastes": "teatral",
    "teatralasts": "teatral",
    "teatrale": "teatral",
    "teatrales": "teatral",
    "teatraliska": "teatralisk",
    "teatraliskare": "teatralisk",
    "teatraliskares": "teatralisk",
    "teatraliskas": "teatralisk",
    "teatraliskast": "teatralisk",
    "teatraliskaste": "teatralisk",
    "teatraliskastes": "teatralisk",
    "teatraliskasts": "teatralisk",
    "teatraliske": "teatralisk",
    "teatraliskes": "teatralisk",
    "teatralisks": "teatralisk",
    "teatraliskt": "teatralisk",
    "teatraliskts": "teatralisk",
    "teatrals": "teatral",
    "teatralt": "teatral",
    "teatralts": "teatral",
    "teatrar": "teater",
    "teatrarna": "teater",
    "teatrarnas": "teater",
    "teatrars": "teater",
    "tebjudningar": "tebjudning",
    "tebjudningarna": "tebjudning",
    "tebjudningarnas": "tebjudning",
    "tebjudningars": "tebjudning",
    "tebjudningen": "tebjudning",
    "tebjudningens": "tebjudning",
    "tebjudnings": "tebjudning",
    "tebladen": "teblad",
    "tebladens": "teblad",
    "tebladet": "teblad",
    "tebladets": "teblad",
    "teblads": "teblad",
    "teblasket": "teblask",
    "teblaskets": "teblask",
    "teblasks": "teblask",
    "tebusk": "tebuske",
    "tebuskar": "tebuske",
    "tebuskarna": "tebuske",
    "tebuskarnas": "tebuske",
    "tebuskars": "tebuske",
    "tebusken": "tebuske",
    "tebuskens": "tebuske",
    "tebuskes": "tebuske",
    "teceremonien": "teceremoni",
    "teceremoniens": "teceremoni",
    "teceremonier": "teceremoni",
    "teceremonierna": "teceremoni",
    "teceremoniernas": "teceremoni",
    "teceremoniers": "teceremoni",
    "teceremonin": "teceremoni",
    "teceremonins": "teceremoni",
    "teceremonis": "teceremoni",
    "technon": "techno",
    "technons": "techno",
    "technos": "techno",
    "teckenalfabeten": "teckenalfabet",
    "teckenalfabetens": "teckenalfabet",
    "teckenalfabetet": "teckenalfabet",
    "teckenalfabetets": "teckenalfabet",
    "teckenalfabets": "teckenalfabet",
    "teckenförklaringar": "teckenförklaring",
    "teckenförklaringarna": "teckenförklaring",
    "teckenförklaringarnas": "teckenförklaring",
    "teckenförklaringars": "teckenförklaring",
    "teckenförklaringen": "teckenförklaring",
    "teckenförklaringens": "teckenförklaring",
    "teckenförklarings": "teckenförklaring",
    "teckengivningar": "teckengivning",
    "teckengivningarna": "teckengivning",
    "teckengivningarnas": "teckengivning",
    "teckengivningars": "teckengivning",
    "teckengivningen": "teckengivning",
    "teckengivningens": "teckengivning",
    "teckengivnings": "teckengivning",
    "teckenrutan": "teckenruta",
    "teckenrutans": "teckenruta",
    "teckenrutas": "teckenruta",
    "teckenrute": "teckenruta",
    "teckenrutor": "teckenruta",
    "teckenrutorna": "teckenruta",
    "teckenrutornas": "teckenruta",
    "teckenrutors": "teckenruta",
    "teckens": "tecken",
    "teckenskådar": "teckenskådare",
    "teckenskådaren": "teckenskådare",
    "teckenskådarens": "teckenskådare",
    "teckenskådares": "teckenskådare",
    "teckenskådarna": "teckenskådare",
    "teckenskådarnas": "teckenskådare",
    "teckenspråken": "teckenspråk",
    "teckenspråkens": "teckenspråk",
    "teckenspråket": "teckenspråk",
    "teckenspråkets": "teckenspråk",
    "teckenspråks": "teckenspråk",
    "teckensystemen": "teckensystem",
    "teckensystemens": "teckensystem",
    "teckensystemet": "teckensystem",
    "teckensystemets": "teckensystem",
    "teckensystems": "teckensystem",
    "teckentolkningen": "teckentolkning",
    "teckentolkningens": "teckentolkning",
    "teckentolknings": "teckentolkning",
    "teckentydar": "teckentydare",
    "teckentydaren": "teckentydare",
    "teckentydarens": "teckentydare",
    "teckentydares": "teckentydare",
    "teckentydarna": "teckentydare",
    "teckentydarnas": "teckentydare",
    "tecknad": "teckna",
    "tecknade": "tecknad",
    "tecknades": "tecknad",
    "tecknads": "tecknad",
    "tecknande": "teckna",
    "tecknanden": "tecknande",
    "tecknandena": "tecknande",
    "tecknandenas": "tecknande",
    "tecknandens": "tecknande",
    "tecknandes": "tecknande",
    "tecknandet": "tecknande",
    "tecknandets": "tecknande",
    "tecknar": "tecknare",
    "tecknaren": "tecknare",
    "tecknarens": "tecknare",
    "tecknares": "tecknare",
    "tecknarna": "tecknare",
    "tecknarnas": "tecknare",
    "tecknas": "teckna",
    "tecknat": "tecknad",
    "tecknats": "tecknad",
    "tecknen": "tecken",
    "tecknens": "tecken",
    "tecknet": "tecken",
    "tecknets": "tecken",
    "teckningar": "teckning",
    "teckningarna": "teckning",
    "teckningarnas": "teckning",
    "teckningars": "teckning",
    "teckningen": "teckning",
    "teckningens": "teckning",
    "tecknings": "teckning",
    "teckningsbevisen": "teckningsbevis",
    "teckningsbevisens": "teckningsbevis",
    "teckningsbeviset": "teckningsbevis",
    "teckningsbevisets": "teckningsbevis",
    "teckningslistan": "teckningslista",
    "teckningslistans": "teckningslista",
    "teckningslistas": "teckningslista",
    "teckningsliste": "teckningslista",
    "teckningslistor": "teckningslista",
    "teckningslistorna": "teckningslista",
    "teckningslistornas": "teckningslista",
    "teckningslistors": "teckningslista",
    "teckningsrätten": "teckningsrätt",
    "teckningsrättens": "teckningsrätt",
    "teckningsrätts": "teckningsrätt",
    "teddybjörnar": "teddybjörn",
    "teddybjörnarna": "teddybjörn",
    "teddybjörnarnas": "teddybjörn",
    "teddybjörnars": "teddybjörn",
    "teddybjörnen": "teddybjörn",
    "teddybjörnens": "teddybjörn",
    "teddybjörns": "teddybjörn",
    "teddyn": "teddy",
    "teddyns": "teddy",
    "teddys": "teddy",
    "tedeumen": "tedeum",
    "tedeumens": "tedeum",
    "tedeumet": "tedeum",
    "tedeumets": "tedeum",
    "tedeums": "tedeum",
    "tedrickanden": "tedrickande",
    "tedrickandena": "tedrickande",
    "tedrickandenas": "tedrickande",
    "tedrickandens": "tedrickande",
    "tedrickandes": "tedrickande",
    "tedrickandet": "tedrickande",
    "tedrickandets": "tedrickande",
    "teer": "te",
    "teerna": "te",
    "teernas": "te",
    "teers": "te",
    "teet": "te",
    "teets": "te",
    "tefaten": "tefat",
    "tefatens": "tefat",
    "tefatet": "tefat",
    "tefatets": "tefat",
    "tefats": "tefat",
    "teflonet": "teflon",
    "teflonets": "teflon",
    "teflonhjärn": "teflonhjärna",
    "teflonhjärnan": "teflonhjärna",
    "teflonhjärnans": "teflonhjärna",
    "teflonhjärnas": "teflonhjärna",
    "teflonhjärne": "teflonhjärna",
    "teflonhjärnor": "teflonhjärna",
    "teflonhjärnorna": "teflonhjärna",
    "teflonhjärnornas": "teflonhjärna",
    "teflonhjärnors": "teflonhjärna",
    "teflonhjärns": "teflonhjärna",
    "teflons": "teflon",
    "tefralagers": "tefralager",
    "tefralagren": "tefralager",
    "tefralagrens": "tefralager",
    "tefralagret": "tefralager",
    "tefralagrets": "tefralager",
    "tefran": "tefra",
    "tefrans": "tefra",
    "tefras": "tefra",
    "tefrokronologien": "tefrokronologi",
    "tefrokronologiens": "tefrokronologi",
    "tefrokronologin": "tefrokronologi",
    "tefrokronologins": "tefrokronologi",
    "tefrokronologis": "tefrokronologi",
    "teg": "tiga",
    "tegar": "teg",
    "tegarna": "teg",
    "tegarnas": "teg",
    "tegars": "teg",
    "tegelbruken": "tegelbruk",
    "tegelbrukens": "tegelbruk",
    "tegelbruket": "tegelbruk",
    "tegelbrukets": "tegelbruk",
    "tegelbruks": "tegelbruk",
    "tegelbyggnaden": "tegelbyggnad",
    "tegelbyggnadens": "tegelbyggnad",
    "tegelbyggnader": "tegelbyggnad",
    "tegelbyggnaderna": "tegelbyggnad",
    "tegelbyggnadernas": "tegelbyggnad",
    "tegelbyggnaders": "tegelbyggnad",
    "tegelbyggnads": "tegelbyggnad",
    "tegelfärgade": "tegelfärgad",
    "tegelfärgades": "tegelfärgad",
    "tegelfärgads": "tegelfärgad",
    "tegelfärgat": "tegelfärgad",
    "tegelfärgats": "tegelfärgad",
    "tegelfärgen": "tegelfärg",
    "tegelfärgens": "tegelfärg",
    "tegelfärgs": "tegelfärg",
    "tegelleran": "tegellera",
    "tegellerans": "tegellera",
    "tegelleras": "tegellera",
    "tegelmurade": "tegelmurad",
    "tegelmurades": "tegelmurad",
    "tegelmurads": "tegelmurad",
    "tegelmurar": "tegelmur",
    "tegelmurarna": "tegelmur",
    "tegelmurarnas": "tegelmur",
    "tegelmurars": "tegelmur",
    "tegelmurat": "tegelmurad",
    "tegelmurats": "tegelmurad",
    "tegelmuren": "tegelmur",
    "tegelmurens": "tegelmur",
    "tegelmurs": "tegelmur",
    "tegelmästar": "tegelmästare",
    "tegelmästaren": "tegelmästare",
    "tegelmästarens": "tegelmästare",
    "tegelmästares": "tegelmästare",
    "tegelmästarna": "tegelmästare",
    "tegelmästarnas": "tegelmästare",
    "tegelpann": "tegelpanna",
    "tegelpannan": "tegelpanna",
    "tegelpannans": "tegelpanna",
    "tegelpannas": "tegelpanna",
    "tegelpanne": "tegelpanna",
    "tegelpannor": "tegelpanna",
    "tegelpannorna": "tegelpanna",
    "tegelpannornas": "tegelpanna",
    "tegelpannors": "tegelpanna",
    "tegelpanns": "tegelpanna",
    "tegelplatt": "tegelplatta",
    "tegelplattan": "tegelplatta",
    "tegelplattans": "tegelplatta",
    "tegelplattas": "tegelplatta",
    "tegelplatte": "tegelplatta",
    "tegelplattor": "tegelplatta",
    "tegelplattorna": "tegelplatta",
    "tegelplattornas": "tegelplatta",
    "tegelplattors": "tegelplatta",
    "tegelplatts": "tegelplatta",
    "tegelröda": "tegelröd",
    "tegelrödare": "tegelröd",
    "tegelrödares": "tegelröd",
    "tegelrödas": "tegelröd",
    "tegelrödast": "tegelröd",
    "tegelrödaste": "tegelröd",
    "tegelrödastes": "tegelröd",
    "tegelrödasts": "tegelröd",
    "tegelröde": "tegelröd",
    "tegelrödes": "tegelröd",
    "tegelröds": "tegelröd",
    "tegelrött": "tegelröd",
    "tegelrötts": "tegelröd",
    "tegels": "tegel",
    "tegelskorstenar": "tegelskorsten",
    "tegelskorstenarna": "tegelskorsten",
    "tegelskorstenarnas": "tegelskorsten",
    "tegelskorstenars": "tegelskorsten",
    "tegelskorstenen": "tegelskorsten",
    "tegelskorstenens": "tegelskorsten",
    "tegelskorstens": "tegelskorsten",
    "tegelslagar": "tegelslagare",
    "tegelslagaren": "tegelslagare",
    "tegelslagarens": "tegelslagare",
    "tegelslagares": "tegelslagare",
    "tegelslagarna": "tegelslagare",
    "tegelslagarnas": "tegelslagare",
    "tegelstenar": "tegelsten",
    "tegelstenarna": "tegelsten",
    "tegelstenarnas": "tegelsten",
    "tegelstenars": "tegelsten",
    "tegelstenen": "tegelsten",
    "tegelstenens": "tegelsten",
    "tegelstens": "tegelsten",
    "tegelstensromanen": "tegelstensroman",
    "tegelstensromanens": "tegelstensroman",
    "tegelstensromaner": "tegelstensroman",
    "tegelstensromanerna": "tegelstensroman",
    "tegelstensromanernas": "tegelstensroman",
    "tegelstensromaners": "tegelstensroman",
    "tegelstensromans": "tegelstensroman",
    "tegelugnar": "tegelugn",
    "tegelugnarna": "tegelugn",
    "tegelugnarnas": "tegelugn",
    "tegelugnars": "tegelugn",
    "tegelugnen": "tegelugn",
    "tegelugnens": "tegelugn",
    "tegelugns": "tegelugn",
    "tegelväggar": "tegelvägg",
    "tegelväggarna": "tegelvägg",
    "tegelväggarnas": "tegelvägg",
    "tegelväggars": "tegelvägg",
    "tegelväggen": "tegelvägg",
    "tegelväggens": "tegelvägg",
    "tegelväggs": "tegelvägg",
    "tegen": "teg",
    "tegens": "teg",
    "tegfår": "tegfåra",
    "tegfåran": "tegfåra",
    "tegfårans": "tegfåra",
    "tegfåras": "tegfåra",
    "tegfåre": "tegfåra",
    "tegfåror": "tegfåra",
    "tegfårorna": "tegfåra",
    "tegfårornas": "tegfåra",
    "tegfårors": "tegfåra",
    "tegfårs": "tegfåra",
    "teglasen": "teglas",
    "teglasens": "teglas",
    "teglaset": "teglas",
    "teglasets": "teglas",
    "teglen": "tegel",
    "teglens": "tegel",
    "teglet": "tegel",
    "teglets": "tegel",
    "tegplöjningar": "tegplöjning",
    "tegplöjningarna": "tegplöjning",
    "tegplöjningarnas": "tegplöjning",
    "tegplöjningars": "tegplöjning",
    "tegplöjningen": "tegplöjning",
    "tegplöjningens": "tegplöjning",
    "tegplöjnings": "tegplöjning",
    "tegs": "tiga",
    "tegskiftes": "tegskifte",
    "tegskiftet": "tegskifte",
    "tegskiftets": "tegskifte",
    "tehuvar": "tehuv",
    "tehuvarna": "tehuv",
    "tehuvarnas": "tehuv",
    "tehuvars": "tehuv",
    "tehuven": "tehuv",
    "tehuvens": "tehuv",
    "tehuvs": "tehuv",
    "teinen": "tein",
    "teinens": "tein",
    "teiner": "tein",
    "teinerna": "tein",
    "teinernas": "tein",
    "teiners": "tein",
    "teinet": "tein",
    "teinets": "tein",
    "teins": "tein",
    "teinten": "teint",
    "teintens": "teint",
    "teints": "teint",
    "teismen": "teism",
    "teismens": "teism",
    "teismer": "teism",
    "teismerna": "teism",
    "teismernas": "teism",
    "teismers": "teism",
    "teisms": "teism",
    "teistiska": "teistisk",
    "teistiskas": "teistisk",
    "teistiske": "teistisk",
    "teistiskes": "teistisk",
    "teistisks": "teistisk",
    "teistiskt": "teistisk",
    "teistiskts": "teistisk",
    "tejp": "tejpa",
    "tejpad": "tejpa",
    "tejpade": "tejpa",
    "tejpades": "tejpa",
    "tejpads": "tejpa",
    "tejpande": "tejpa",
    "tejpanden": "tejpande",
    "tejpandena": "tejpande",
    "tejpandenas": "tejpande",
    "tejpandens": "tejpande",
    "tejpandes": "tejpande",
    "tejpandet": "tejpande",
    "tejpandets": "tejpande",
    "tejpar": "tejpa",
    "tejparna": "tejp",
    "tejparnas": "tejp",
    "tejpars": "tejp",
    "tejpas": "tejpa",
    "tejpat": "tejpa",
    "tejpats": "tejpa",
    "tejpen": "tejp",
    "tejpens": "tejp",
    "tejper": "tejp",
    "tejperna": "tejp",
    "tejpernas": "tejp",
    "tejpers": "tejp",
    "tejprull": "tejprulle",
    "tejprullar": "tejprulle",
    "tejprullarna": "tejprulle",
    "tejprullarnas": "tejprulle",
    "tejprullars": "tejprulle",
    "tejprullen": "tejprulle",
    "tejprullens": "tejprulle",
    "tejprulles": "tejprulle",
    "tejprulls": "tejprulle",
    "tejps": "tejp",
    "tejstar": "tejst",
    "tejstarna": "tejst",
    "tejstarnas": "tejst",
    "tejstars": "tejst",
    "tejsten": "tejst",
    "tejstens": "tejst",
    "tejsts": "tejst",
    "tek": "teka",
    "tekad": "teka",
    "tekade": "teka",
    "tekades": "teka",
    "tekads": "teka",
    "tekak": "tekaka",
    "tekakan": "tekaka",
    "tekakans": "tekaka",
    "tekakas": "tekaka",
    "tekake": "tekaka",
    "tekakor": "tekaka",
    "tekakorna": "tekaka",
    "tekakornas": "tekaka",
    "tekakors": "tekaka",
    "tekaks": "tekaka",
    "tekande": "teka",
    "tekanden": "tekande",
    "tekandena": "tekande",
    "tekandenas": "tekande",
    "tekandens": "tekande",
    "tekandes": "tekande",
    "tekandet": "tekande",
    "tekandets": "tekande",
    "tekannan": "tekanna",
    "tekannans": "tekanna",
    "tekannas": "tekanna",
    "tekanne": "tekanna",
    "tekannor": "tekanna",
    "tekannorna": "tekanna",
    "tekannornas": "tekanna",
    "tekannors": "tekanna",
    "tekar": "teka",
    "tekas": "teka",
    "tekat": "teka",
    "tekats": "teka",
    "teknetiet": "teknetium",
    "teknetiets": "teknetium",
    "teknetiumet": "teknetium",
    "teknetiumets": "teknetium",
    "teknetiums": "teknetium",
    "teknifierad": "teknifiera",
    "teknifierade": "teknifiera",
    "teknifierades": "teknifiera",
    "teknifierads": "teknifiera",
    "teknifierande": "teknifiera",
    "teknifieranden": "teknifierande",
    "teknifierandena": "teknifierande",
    "teknifierandenas": "teknifierande",
    "teknifierandens": "teknifierande",
    "teknifierandes": "teknifierande",
    "teknifierandet": "teknifierande",
    "teknifierandets": "teknifierande",
    "teknifierar": "teknifiera",
    "teknifieras": "teknifiera",
    "teknifierat": "teknifiera",
    "teknifierats": "teknifiera",
    "teknifierbara": "teknifierbar",
    "teknifierbarare": "teknifierbar",
    "teknifierbarares": "teknifierbar",
    "teknifierbaras": "teknifierbar",
    "teknifierbarast": "teknifierbar",
    "teknifierbaraste": "teknifierbar",
    "teknifierbarastes": "teknifierbar",
    "teknifierbarasts": "teknifierbar",
    "teknifierbare": "teknifierbar",
    "teknifierbares": "teknifierbar",
    "teknifierbarheten": "teknifierbarhet",
    "teknifierbarhetens": "teknifierbarhet",
    "teknifierbarhets": "teknifierbarhet",
    "teknifierbars": "teknifierbar",
    "teknifierbart": "teknifierbar",
    "teknifierbarts": "teknifierbar",
    "teknifieringar": "teknifiering",
    "teknifieringarna": "teknifiering",
    "teknifieringarnas": "teknifiering",
    "teknifieringars": "teknifiering",
    "teknifieringen": "teknifiering",
    "teknifieringens": "teknifiering",
    "teknifierings": "teknifiering",
    "teknikaliteten": "teknikalitet",
    "teknikalitetens": "teknikalitet",
    "teknikaliteter": "teknikalitet",
    "teknikaliteterna": "teknikalitet",
    "teknikaliteternas": "teknikalitet",
    "teknikaliteters": "teknikalitet",
    "teknikalitets": "teknikalitet",
    "teknikanpassade": "teknikanpassad",
    "teknikanpassades": "teknikanpassad",
    "teknikanpassads": "teknikanpassad",
    "teknikanpassat": "teknikanpassad",
    "teknikanpassats": "teknikanpassad",
    "tekniken": "teknik",
    "teknikens": "teknik",
    "tekniker": "teknik",
    "teknikern": "tekniker",
    "teknikerna": "tekniker",
    "teknikernas": "tekniker",
    "teknikerns": "tekniker",
    "teknikers": "tekniker",
    "teknikjournalisten": "teknikjournalist",
    "teknikjournalistens": "teknikjournalist",
    "teknikjournalister": "teknikjournalist",
    "teknikjournalisterna": "teknikjournalist",
    "teknikjournalisternas": "teknikjournalist",
    "teknikjournalisters": "teknikjournalist",
    "teknikjournalists": "teknikjournalist",
    "teknikkunnanden": "teknikkunnande",
    "teknikkunnandena": "teknikkunnande",
    "teknikkunnandenas": "teknikkunnande",
    "teknikkunnandens": "teknikkunnande",
    "teknikkunnandes": "teknikkunnande",
    "teknikkunnandet": "teknikkunnande",
    "teknikkunnandets": "teknikkunnande",
    "teknikrådgivar": "teknikrådgivare",
    "teknikrådgivaren": "teknikrådgivare",
    "teknikrådgivarens": "teknikrådgivare",
    "teknikrådgivares": "teknikrådgivare",
    "teknikrådgivarna": "teknikrådgivare",
    "teknikrådgivarnas": "teknikrådgivare",
    "tekniks": "teknik",
    "teknikutvecklingar": "teknikutveckling",
    "teknikutvecklingarna": "teknikutveckling",
    "teknikutvecklingarnas": "teknikutveckling",
    "teknikutvecklingars": "teknikutveckling",
    "teknikutvecklingen": "teknikutveckling",
    "teknikutvecklingens": "teknikutveckling",
    "teknikutvecklings": "teknikutveckling",
    "tekniköverföringar": "tekniköverföring",
    "tekniköverföringarna": "tekniköverföring",
    "tekniköverföringarnas": "tekniköverföring",
    "tekniköverföringars": "tekniköverföring",
    "tekniköverföringen": "tekniköverföring",
    "tekniköverföringens": "tekniköverföring",
    "tekniköverförings": "tekniköverföring",
    "tekningar": "tekning",
    "tekningarna": "tekning",
    "tekningarnas": "tekning",
    "tekningars": "tekning",
    "tekningen": "tekning",
    "tekningens": "tekning",
    "teknings": "tekning",
    "tekniska": "teknisk",
    "tekniskare": "teknisk",
    "tekniskares": "teknisk",
    "tekniskas": "teknisk",
    "tekniskast": "teknisk",
    "tekniskaste": "teknisk",
    "tekniskastes": "teknisk",
    "tekniskasts": "teknisk",
    "tekniske": "teknisk",
    "tekniskes": "teknisk",
    "teknisks": "teknisk",
    "tekniskt": "teknisk",
    "tekniskts": "teknisk",
    "teknokraten": "teknokrat",
    "teknokratens": "teknokrat",
    "teknokrater": "teknokrat",
    "teknokraterna": "teknokrat",
    "teknokraternas": "teknokrat",
    "teknokraters": "teknokrat",
    "teknokratien": "teknokrati",
    "teknokratiens": "teknokrati",
    "teknokratier": "teknokrati",
    "teknokratierna": "teknokrati",
    "teknokratiernas": "teknokrati",
    "teknokratiers": "teknokrati",
    "teknokratin": "teknokrati",
    "teknokratins": "teknokrati",
    "teknokratis": "teknokrati",
    "teknokrats": "teknokrat",
    "teknologen": "teknolog",
    "teknologens": "teknolog",
    "teknologer": "teknolog",
    "teknologerna": "teknolog",
    "teknologernas": "teknolog",
    "teknologers": "teknolog",
    "teknologien": "teknologi",
    "teknologiens": "teknologi",
    "teknologier": "teknologi",
    "teknologierna": "teknologi",
    "teknologiernas": "teknologi",
    "teknologiers": "teknologi",
    "teknologin": "teknologi",
    "teknologins": "teknologi",
    "teknologis": "teknologi",
    "teknologiska": "teknologisk",
    "teknologiskare": "teknologisk",
    "teknologiskares": "teknologisk",
    "teknologiskas": "teknologisk",
    "teknologiskast": "teknologisk",
    "teknologiskaste": "teknologisk",
    "teknologiskastes": "teknologisk",
    "teknologiskasts": "teknologisk",
    "teknologiske": "teknologisk",
    "teknologiskes": "teknologisk",
    "teknologisks": "teknologisk",
    "teknologiskt": "teknologisk",
    "teknologiskts": "teknologisk",
    "teknologs": "teknolog",
    "tekoindustrien": "tekoindustri",
    "tekoindustriens": "tekoindustri",
    "tekoindustrier": "tekoindustri",
    "tekoindustrierna": "tekoindustri",
    "tekoindustriernas": "tekoindustri",
    "tekoindustriers": "tekoindustri",
    "tekoindustrin": "tekoindustri",
    "tekoindustrins": "tekoindustri",
    "tekoindustris": "tekoindustri",
    "tekoppar": "tekopp",
    "tekopparna": "tekopp",
    "tekopparnas": "tekopp",
    "tekoppars": "tekopp",
    "tekoppen": "tekopp",
    "tekoppens": "tekopp",
    "tekopps": "tekopp",
    "tektoniken": "tektonik",
    "tektonikens": "tektonik",
    "tektoniks": "tektonik",
    "teleavgiften": "teleavgift",
    "teleavgiftens": "teleavgift",
    "teleavgifter": "teleavgift",
    "teleavgifterna": "teleavgift",
    "teleavgifternas": "teleavgift",
    "teleavgifters": "teleavgift",
    "teleavgifts": "teleavgift",
    "teledatan": "teledata",
    "teledatana": "teledata",
    "teledatanas": "teledata",
    "teledatans": "teledata",
    "teledatas": "teledata",
    "teledatat": "teledata",
    "teledatats": "teledata",
    "telefaksimilet": "telefaksimil",
    "telefaksimilets": "telefaksimil",
    "telefaksimils": "telefaksimil",
    "telefaxet": "telefax",
    "telefaxets": "telefax",
    "telefonabonnenten": "telefonabonnent",
    "telefonabonnentens": "telefonabonnent",
    "telefonabonnenter": "telefonabonnent",
    "telefonabonnenterna": "telefonabonnent",
    "telefonabonnenternas": "telefonabonnent",
    "telefonabonnenters": "telefonabonnent",
    "telefonabonnents": "telefonabonnent",
    "telefonanropen": "telefonanrop",
    "telefonanropens": "telefonanrop",
    "telefonanropet": "telefonanrop",
    "telefonanropets": "telefonanrop",
    "telefonanrops": "telefonanrop",
    "telefonapparaten": "telefonapparat",
    "telefonapparatens": "telefonapparat",
    "telefonapparater": "telefonapparat",
    "telefonapparaterna": "telefonapparat",
    "telefonapparaternas": "telefonapparat",
    "telefonapparaters": "telefonapparat",
    "telefonapparats": "telefonapparat",
    "telefonautomaten": "telefonautomat",
    "telefonautomatens": "telefonautomat",
    "telefonautomater": "telefonautomat",
    "telefonautomaterna": "telefonautomat",
    "telefonautomaternas": "telefonautomat",
    "telefonautomaters": "telefonautomat",
    "telefonautomats": "telefonautomat",
    "telefonavlyssningar": "telefonavlyssning",
    "telefonavlyssningarna": "telefonavlyssning",
    "telefonavlyssningarnas": "telefonavlyssning",
    "telefonavlyssningars": "telefonavlyssning",
    "telefonavlyssningen": "telefonavlyssning",
    "telefonavlyssningens": "telefonavlyssning",
    "telefonavlyssnings": "telefonavlyssning",
    "telefonbolagen": "telefonbolag",
    "telefonbolagens": "telefonbolag",
    "telefonbolaget": "telefonbolag",
    "telefonbolagets": "telefonbolag",
    "telefonbolags": "telefonbolag",
    "telefonen": "telefon",
    "telefonens": "telefon",
    "telefoner": "telefon",
    "telefonerad": "telefonera",
    "telefonerade": "telefonera",
    "telefonerades": "telefonera",
    "telefonerads": "telefonera",
    "telefonerande": "telefonera",
    "telefoneranden": "telefonerande",
    "telefonerandena": "telefonerande",
    "telefonerandenas": "telefonerande",
    "telefonerandens": "telefonerande",
    "telefonerandes": "telefonerande",
    "telefonerandet": "telefonerande",
    "telefonerandets": "telefonerande",
    "telefonerar": "telefonera",
    "telefoneras": "telefonera",
    "telefonerat": "telefonera",
    "telefonerats": "telefonera",
    "telefonerbara": "telefonerbar",
    "telefonerbarare": "telefonerbar",
    "telefonerbarares": "telefonerbar",
    "telefonerbaras": "telefonerbar",
    "telefonerbarast": "telefonerbar",
    "telefonerbaraste": "telefonerbar",
    "telefonerbarastes": "telefonerbar",
    "telefonerbarasts": "telefonerbar",
    "telefonerbare": "telefonerbar",
    "telefonerbares": "telefonerbar",
    "telefonerbarheten": "telefonerbarhet",
    "telefonerbarhetens": "telefonerbarhet",
    "telefonerbarhets": "telefonerbarhet",
    "telefonerbars": "telefonerbar",
    "telefonerbart": "telefonerbar",
    "telefonerbarts": "telefonerbar",
    "telefoneringar": "telefonering",
    "telefoneringarna": "telefonering",
    "telefoneringarnas": "telefonering",
    "telefoneringars": "telefonering",
    "telefoneringen": "telefonering",
    "telefoneringens": "telefonering",
    "telefonerings": "telefonering",
    "telefonerna": "telefon",
    "telefonernas": "telefon",
    "telefoners": "telefon",
    "telefonhytten": "telefonhytt",
    "telefonhyttens": "telefonhytt",
    "telefonhytter": "telefonhytt",
    "telefonhytterna": "telefonhytt",
    "telefonhytternas": "telefonhytt",
    "telefonhytters": "telefonhytt",
    "telefonhytts": "telefonhytt",
    "telefonien": "telefoni",
    "telefoniens": "telefoni",
    "telefonin": "telefoni",
    "telefonins": "telefoni",
    "telefonis": "telefoni",
    "telefonisten": "telefonist",
    "telefonistens": "telefonist",
    "telefonister": "telefonist",
    "telefonisterna": "telefonist",
    "telefonisternas": "telefonist",
    "telefonisters": "telefonist",
    "telefonists": "telefonist",
    "telefonjackar": "telefonjack",
    "telefonjackarna": "telefonjack",
    "telefonjackarnas": "telefonjack",
    "telefonjackars": "telefonjack",
    "telefonjacken": "telefonjack",
    "telefonjackens": "telefonjack",
    "telefonjacket": "telefonjack",
    "telefonjackets": "telefonjack",
    "telefonjacks": "telefonjack",
    "telefonjouren": "telefonjour",
    "telefonjourens": "telefonjour",
    "telefonjours": "telefonjour",
    "telefonkatalogen": "telefonkatalog",
    "telefonkatalogens": "telefonkatalog",
    "telefonkataloger": "telefonkatalog",
    "telefonkatalogerna": "telefonkatalog",
    "telefonkatalogernas": "telefonkatalog",
    "telefonkatalogers": "telefonkatalog",
    "telefonkatalogs": "telefonkatalog",
    "telefonkiosken": "telefonkiosk",
    "telefonkioskens": "telefonkiosk",
    "telefonkiosker": "telefonkiosk",
    "telefonkioskerna": "telefonkiosk",
    "telefonkioskernas": "telefonkiosk",
    "telefonkioskers": "telefonkiosk",
    "telefonkiosks": "telefonkiosk",
    "telefonkonferensen": "telefonkonferens",
    "telefonkonferensens": "telefonkonferens",
    "telefonkonferenser": "telefonkonferens",
    "telefonkonferenserna": "telefonkonferens",
    "telefonkonferensernas": "telefonkonferens",
    "telefonkonferensers": "telefonkonferens",
    "telefonkorten": "telefonkort",
    "telefonkortens": "telefonkort",
    "telefonkortet": "telefonkort",
    "telefonkortets": "telefonkort",
    "telefonkorts": "telefonkort",
    "telefonköer": "telefonkö",
    "telefonköerna": "telefonkö",
    "telefonköernas": "telefonkö",
    "telefonköers": "telefonkö",
    "telefonkön": "telefonkö",
    "telefonköns": "telefonkö",
    "telefonkös": "telefonkö",
    "telefonledningar": "telefonledning",
    "telefonledningarna": "telefonledning",
    "telefonledningarnas": "telefonledning",
    "telefonledningars": "telefonledning",
    "telefonledningen": "telefonledning",
    "telefonledningens": "telefonledning",
    "telefonlednings": "telefonledning",
    "telefonlurar": "telefonlur",
    "telefonlurarna": "telefonlur",
    "telefonlurarnas": "telefonlur",
    "telefonlurars": "telefonlur",
    "telefonluren": "telefonlur",
    "telefonlurens": "telefonlur",
    "telefonlurs": "telefonlur",
    "telefonnummerna": "telefonnummer",
    "telefonnummernas": "telefonnummer",
    "telefonnummers": "telefonnummer",
    "telefonnumren": "telefonnummer",
    "telefonnumrens": "telefonnummer",
    "telefonnumret": "telefonnummer",
    "telefonnumrets": "telefonnummer",
    "telefonnäten": "telefonnät",
    "telefonnätens": "telefonnät",
    "telefonnätet": "telefonnät",
    "telefonnätets": "telefonnät",
    "telefonnäts": "telefonnät",
    "telefonoperatören": "telefonoperatör",
    "telefonoperatörens": "telefonoperatör",
    "telefonoperatörer": "telefonoperatör",
    "telefonoperatörerna": "telefonoperatör",
    "telefonoperatörernas": "telefonoperatör",
    "telefonoperatörers": "telefonoperatör",
    "telefonoperatörs": "telefonoperatör",
    "telefons": "telefon",
    "telefonsamtalen": "telefonsamtal",
    "telefonsamtalens": "telefonsamtal",
    "telefonsamtalet": "telefonsamtal",
    "telefonsamtalets": "telefonsamtal",
    "telefonsamtals": "telefonsamtal",
    "telefonsignalen": "telefonsignal",
    "telefonsignalens": "telefonsignal",
    "telefonsignaler": "telefonsignal",
    "telefonsignalerna": "telefonsignal",
    "telefonsignalernas": "telefonsignal",
    "telefonsignalers": "telefonsignal",
    "telefonsignals": "telefonsignal",
    "telefonsladdar": "telefonsladd",
    "telefonsladdarna": "telefonsladd",
    "telefonsladdarnas": "telefonsladd",
    "telefonsladdars": "telefonsladd",
    "telefonsladden": "telefonsladd",
    "telefonsladdens": "telefonsladd",
    "telefonsladds": "telefonsladd",
    "telefonstationen": "telefonstation",
    "telefonstationens": "telefonstation",
    "telefonstationer": "telefonstation",
    "telefonstationerna": "telefonstation",
    "telefonstationernas": "telefonstation",
    "telefonstationers": "telefonstation",
    "telefonstations": "telefonstation",
    "telefonstolp": "telefonstolpe",
    "telefonstolpar": "telefonstolpe",
    "telefonstolparna": "telefonstolpe",
    "telefonstolparnas": "telefonstolpe",
    "telefonstolpars": "telefonstolpe",
    "telefonstolpen": "telefonstolpe",
    "telefonstolpens": "telefonstolpe",
    "telefonstolpes": "telefonstolpe",
    "telefonstolps": "telefonstolpe",
    "telefonsvarar": "telefonsvarare",
    "telefonsvararen": "telefonsvarare",
    "telefonsvararens": "telefonsvarare",
    "telefonsvarares": "telefonsvarare",
    "telefonsvararmeddelanden": "telefonsvararmeddelande",
    "telefonsvararmeddelandena": "telefonsvararmeddelande",
    "telefonsvararmeddelandenas": "telefonsvararmeddelande",
    "telefonsvararmeddelandens": "telefonsvararmeddelande",
    "telefonsvararmeddelandes": "telefonsvararmeddelande",
    "telefonsvararmeddelandet": "telefonsvararmeddelande",
    "telefonsvararmeddelandets": "telefonsvararmeddelande",
    "telefonsvararna": "telefonsvarare",
    "telefonsvararnas": "telefonsvarare",
    "telefonsvaren": "telefonsvar",
    "telefonsvarens": "telefonsvar",
    "telefonsvaret": "telefonsvar",
    "telefonsvarets": "telefonsvar",
    "telefonsvars": "telefonsvar",
    "telefonterrorn": "telefonterror",
    "telefonterrorns": "telefonterror",
    "telefonterrors": "telefonterror",
    "telefontrådar": "telefontråd",
    "telefontrådarna": "telefontråd",
    "telefontrådarnas": "telefontråd",
    "telefontrådars": "telefontråd",
    "telefontråden": "telefontråd",
    "telefontrådens": "telefontråd",
    "telefontråds": "telefontråd",
    "telefonvakten": "telefonvakt",
    "telefonvaktens": "telefonvakt",
    "telefonvakter": "telefonvakt",
    "telefonvakterna": "telefonvakt",
    "telefonvakternas": "telefonvakt",
    "telefonvakters": "telefonvakt",
    "telefonvakts": "telefonvakt",
    "telefonväckningar": "telefonväckning",
    "telefonväckningarna": "telefonväckning",
    "telefonväckningarnas": "telefonväckning",
    "telefonväckningars": "telefonväckning",
    "telefonväckningen": "telefonväckning",
    "telefonväckningens": "telefonväckning",
    "telefonväcknings": "telefonväckning",
    "telefonväktar": "telefonväktare",
    "telefonväktaren": "telefonväktare",
    "telefonväktarens": "telefonväktare",
    "telefonväktares": "telefonväktare",
    "telefonväktarna": "telefonväktare",
    "telefonväktarnas": "telefonväktare",
    "telefonväxeln": "telefonväxel",
    "telefonväxelns": "telefonväxel",
    "telefonväxels": "telefonväxel",
    "telefonväxlar": "telefonväxel",
    "telefonväxlarna": "telefonväxel",
    "telefonväxlarnas": "telefonväxel",
    "telefonväxlars": "telefonväxel",
    "telefonören": "telefonör",
    "telefonörens": "telefonör",
    "telefonörer": "telefonör",
    "telefonörerna": "telefonör",
    "telefonörernas": "telefonör",
    "telefonörers": "telefonör",
    "telefonörs": "telefonör",
    "telefoton": "telefoto",
    "telefotona": "telefoto",
    "telefotonas": "telefoto",
    "telefotons": "telefoto",
    "telefotos": "telefoto",
    "telefotot": "telefoto",
    "telefotots": "telefoto",
    "teleförbindelsen": "teleförbindelse",
    "teleförbindelsens": "teleförbindelse",
    "teleförbindelser": "teleförbindelse",
    "teleförbindelserna": "teleförbindelse",
    "teleförbindelsernas": "teleförbindelse",
    "teleförbindelsers": "teleförbindelse",
    "teleförbindelses": "teleförbindelse",
    "telegrafen": "telegraf",
    "telegrafens": "telegraf",
    "telegrafer": "telegraf",
    "telegraferad": "telegrafera",
    "telegraferade": "telegrafera",
    "telegraferades": "telegrafera",
    "telegraferads": "telegrafera",
    "telegraferande": "telegrafera",
    "telegraferanden": "telegraferande",
    "telegraferandena": "telegraferande",
    "telegraferandenas": "telegraferande",
    "telegraferandens": "telegraferande",
    "telegraferandes": "telegraferande",
    "telegraferandet": "telegraferande",
    "telegraferandets": "telegraferande",
    "telegraferar": "telegrafera",
    "telegraferas": "telegrafera",
    "telegraferat": "telegrafera",
    "telegraferats": "telegrafera",
    "telegraferbara": "telegraferbar",
    "telegraferbarare": "telegraferbar",
    "telegraferbarares": "telegraferbar",
    "telegraferbaras": "telegraferbar",
    "telegraferbarast": "telegraferbar",
    "telegraferbaraste": "telegraferbar",
    "telegraferbarastes": "telegraferbar",
    "telegraferbarasts": "telegraferbar",
    "telegraferbare": "telegraferbar",
    "telegraferbares": "telegraferbar",
    "telegraferbarheten": "telegraferbarhet",
    "telegraferbarhetens": "telegraferbarhet",
    "telegraferbarhets": "telegraferbarhet",
    "telegraferbars": "telegraferbar",
    "telegraferbart": "telegraferbar",
    "telegraferbarts": "telegraferbar",
    "telegraferingar": "telegrafering",
    "telegraferingarna": "telegrafering",
    "telegraferingarnas": "telegrafering",
    "telegraferingars": "telegrafering",
    "telegraferingen": "telegrafering",
    "telegraferingens": "telegrafering",
    "telegraferings": "telegrafering",
    "telegraferna": "telegraf",
    "telegrafernas": "telegraf",
    "telegrafers": "telegraf",
    "telegrafien": "telegrafi",
    "telegrafiens": "telegrafi",
    "telegrafin": "telegrafi",
    "telegrafins": "telegrafi",
    "telegrafis": "telegrafi",
    "telegrafiska": "telegrafisk",
    "telegrafiskare": "telegrafisk",
    "telegrafiskares": "telegrafisk",
    "telegrafiskas": "telegrafisk",
    "telegrafiskast": "telegrafisk",
    "telegrafiskaste": "telegrafisk",
    "telegrafiskastes": "telegrafisk",
    "telegrafiskasts": "telegrafisk",
    "telegrafiske": "telegrafisk",
    "telegrafiskes": "telegrafisk",
    "telegrafisks": "telegrafisk",
    "telegrafiskt": "telegrafisk",
    "telegrafiskts": "telegrafisk",
    "telegrafisten": "telegrafist",
    "telegrafistens": "telegrafist",
    "telegrafister": "telegrafist",
    "telegrafisterna": "telegrafist",
    "telegrafisternas": "telegrafist",
    "telegrafisters": "telegrafist",
    "telegrafists": "telegrafist",
    "telegrafnyckeln": "telegrafnyckel",
    "telegrafnyckelns": "telegrafnyckel",
    "telegrafnyckels": "telegrafnyckel",
    "telegrafnycklar": "telegrafnyckel",
    "telegrafnycklarna": "telegrafnyckel",
    "telegrafnycklarnas": "telegrafnyckel",
    "telegrafnycklars": "telegrafnyckel",
    "telegrafrems": "telegrafremsa",
    "telegrafremsan": "telegrafremsa",
    "telegrafremsans": "telegrafremsa",
    "telegrafremsas": "telegrafremsa",
    "telegrafremse": "telegrafremsa",
    "telegrafremsor": "telegrafremsa",
    "telegrafremsorna": "telegrafremsa",
    "telegrafremsornas": "telegrafremsa",
    "telegrafremsors": "telegrafremsa",
    "telegrafs": "telegraf",
    "telegrafstationen": "telegrafstation",
    "telegrafstationens": "telegrafstation",
    "telegrafstationer": "telegrafstation",
    "telegrafstationerna": "telegrafstation",
    "telegrafstationernas": "telegrafstation",
    "telegrafstationers": "telegrafstation",
    "telegrafstations": "telegrafstation",
    "telegrafutrustningar": "telegrafutrustning",
    "telegrafutrustningarna": "telegrafutrustning",
    "telegrafutrustningarnas": "telegrafutrustning",
    "telegrafutrustningars": "telegrafutrustning",
    "telegrafutrustningen": "telegrafutrustning",
    "telegrafutrustningens": "telegrafutrustning",
    "telegrafutrustnings": "telegrafutrustning",
    "telegramadressen": "telegramadress",
    "telegramadressens": "telegramadress",
    "telegramadresser": "telegramadress",
    "telegramadresserna": "telegramadress",
    "telegramadressernas": "telegramadress",
    "telegramadressers": "telegramadress",
    "telegrambuden": "telegrambud",
    "telegrambudens": "telegrambud",
    "telegrambudet": "telegrambud",
    "telegrambudets": "telegrambud",
    "telegrambuds": "telegrambud",
    "telegrambyråer": "telegrambyrå",
    "telegrambyråerna": "telegrambyrå",
    "telegrambyråernas": "telegrambyrå",
    "telegrambyråers": "telegrambyrå",
    "telegrambyrån": "telegrambyrå",
    "telegrambyråns": "telegrambyrå",
    "telegrambyrås": "telegrambyrå",
    "telegrammen": "telegram",
    "telegrammens": "telegram",
    "telegrammet": "telegram",
    "telegrammets": "telegram",
    "telegrams": "telegram",
    "telegramspråket": "telegramspråk",
    "telegramspråkets": "telegramspråk",
    "telegramspråks": "telegramspråk",
    "telegramstilen": "telegramstil",
    "telegramstilens": "telegramstil",
    "telegramstils": "telegramstil",
    "telekinesien": "telekinesi",
    "telekinesiens": "telekinesi",
    "telekinesin": "telekinesi",
    "telekinesins": "telekinesi",
    "telekinesis": "telekinesi",
    "telekommunikationen": "telekommunikation",
    "telekommunikationens": "telekommunikation",
    "telekommunikationer": "telekommunikation",
    "telekommunikationerna": "telekommunikation",
    "telekommunikationernas": "telekommunikation",
    "telekommunikationers": "telekommunikation",
    "telekommunikations": "telekommunikation",
    "telematiken": "telematik",
    "telematikens": "telematik",
    "telematiks": "telematik",
    "telemetern": "telemeter",
    "telemeterns": "telemeter",
    "telemeters": "telemeter",
    "telemetrar": "telemeter",
    "telemetrarna": "telemeter",
    "telemetrarnas": "telemeter",
    "telemetrars": "telemeter",
    "telenäten": "telenät",
    "telenätens": "telenät",
    "telenätet": "telenät",
    "telenätets": "telenät",
    "telenäts": "telenät",
    "teleobjektiven": "teleobjektiv",
    "teleobjektivens": "teleobjektiv",
    "teleobjektivet": "teleobjektiv",
    "teleobjektivets": "teleobjektiv",
    "teleobjektivs": "teleobjektiv",
    "teleologien": "teleologi",
    "teleologiens": "teleologi",
    "teleologin": "teleologi",
    "teleologins": "teleologi",
    "teleologis": "teleologi",
    "teleologiska": "teleologisk",
    "teleologiskare": "teleologisk",
    "teleologiskares": "teleologisk",
    "teleologiskas": "teleologisk",
    "teleologiskast": "teleologisk",
    "teleologiskaste": "teleologisk",
    "teleologiskastes": "teleologisk",
    "teleologiskasts": "teleologisk",
    "teleologiske": "teleologisk",
    "teleologiskes": "teleologisk",
    "teleologisks": "teleologisk",
    "teleologiskt": "teleologisk",
    "teleologiskts": "teleologisk",
    "telepatien": "telepati",
    "telepatiens": "telepati",
    "telepatier": "telepati",
    "telepatierna": "telepati",
    "telepatiernas": "telepati",
    "telepatiers": "telepati",
    "telepatin": "telepati",
    "telepatins": "telepati",
    "telepatis": "telepati",
    "telepatiska": "telepatisk",
    "telepatiskare": "telepatisk",
    "telepatiskares": "telepatisk",
    "telepatiskas": "telepatisk",
    "telepatiskast": "telepatisk",
    "telepatiskaste": "telepatisk",
    "telepatiskastes": "telepatisk",
    "telepatiskasts": "telepatisk",
    "telepatiske": "telepatisk",
    "telepatiskes": "telepatisk",
    "telepatisks": "telepatisk",
    "telepatiskt": "telepatisk",
    "telepatiskts": "telepatisk",
    "teleprintern": "teleprinter",
    "teleprinterns": "teleprinter",
    "teleprinters": "teleprinter",
    "teleprintrar": "teleprinter",
    "teleprintrarna": "teleprinter",
    "teleprintrarnas": "teleprinter",
    "teleprintrars": "teleprinter",
    "telesatelliten": "telesatellit",
    "telesatellitens": "telesatellit",
    "telesatelliter": "telesatellit",
    "telesatelliterna": "telesatellit",
    "telesatelliternas": "telesatellit",
    "telesatelliters": "telesatellit",
    "telesatellits": "telesatellit",
    "teleschacket": "teleschack",
    "teleschackets": "teleschack",
    "teleschacks": "teleschack",
    "teleskopen": "teleskop",
    "teleskopens": "teleskop",
    "teleskopet": "teleskop",
    "teleskopets": "teleskop",
    "teleskopfunktionen": "teleskopfunktion",
    "teleskopfunktionens": "teleskopfunktion",
    "teleskopfunktioner": "teleskopfunktion",
    "teleskopfunktionerna": "teleskopfunktion",
    "teleskopfunktionernas": "teleskopfunktion",
    "teleskopfunktioners": "teleskopfunktion",
    "teleskopfunktions": "teleskopfunktion",
    "teleskopien": "teleskopi",
    "teleskopiens": "teleskopi",
    "teleskopin": "teleskopi",
    "teleskopins": "teleskopi",
    "teleskopis": "teleskopi",
    "teleskopiska": "teleskopisk",
    "teleskopiskare": "teleskopisk",
    "teleskopiskares": "teleskopisk",
    "teleskopiskas": "teleskopisk",
    "teleskopiskast": "teleskopisk",
    "teleskopiskaste": "teleskopisk",
    "teleskopiskastes": "teleskopisk",
    "teleskopiskasts": "teleskopisk",
    "teleskopiske": "teleskopisk",
    "teleskopiskes": "teleskopisk",
    "teleskopisks": "teleskopisk",
    "teleskopiskt": "teleskopisk",
    "teleskopiskts": "teleskopisk",
    "teleskoprören": "teleskoprör",
    "teleskoprörens": "teleskoprör",
    "teleskopröret": "teleskoprör",
    "teleskoprörets": "teleskoprör",
    "teleskoprörs": "teleskoprör",
    "teleskops": "teleskop",
    "teleskopögas": "teleskopöga",
    "teleskopögat": "teleskopöga",
    "teleskopögats": "teleskopöga",
    "teleskopögon": "teleskopöga",
    "teleskopögonen": "teleskopöga",
    "teleskopögonens": "teleskopöga",
    "teleskopögons": "teleskopöga",
    "telestationen": "telestation",
    "telestationens": "telestation",
    "telestationer": "telestation",
    "telestationerna": "telestation",
    "telestationernas": "telestation",
    "telestationers": "telestation",
    "telestations": "telestation",
    "teletekniska": "teleteknisk",
    "teletekniskare": "teleteknisk",
    "teletekniskares": "teleteknisk",
    "teletekniskas": "teleteknisk",
    "teletekniskast": "teleteknisk",
    "teletekniskaste": "teleteknisk",
    "teletekniskastes": "teleteknisk",
    "teletekniskasts": "teleteknisk",
    "teletekniske": "teleteknisk",
    "teletekniskes": "teleteknisk",
    "teleteknisks": "teleteknisk",
    "teletekniskt": "teleteknisk",
    "teletekniskts": "teleteknisk",
    "teletexen": "teletex",
    "teletexens": "teletex",
    "televerken": "televerk",
    "televerkens": "televerk",
    "televerket": "televerk",
    "televerkets": "televerk",
    "televerks": "televerk",
    "televiserad": "televisera",
    "televiserade": "televisera",
    "televiserades": "televisera",
    "televiserads": "televisera",
    "televiserande": "televisera",
    "televiseranden": "televiserande",
    "televiserandena": "televiserande",
    "televiserandenas": "televiserande",
    "televiserandens": "televiserande",
    "televiserandes": "televiserande",
    "televiserandet": "televiserande",
    "televiserandets": "televiserande",
    "televiserar": "televisera",
    "televiseras": "televisera",
    "televiserat": "televisera",
    "televiserats": "televisera",
    "televiserbara": "televiserbar",
    "televiserbarare": "televiserbar",
    "televiserbarares": "televiserbar",
    "televiserbaras": "televiserbar",
    "televiserbarast": "televiserbar",
    "televiserbaraste": "televiserbar",
    "televiserbarastes": "televiserbar",
    "televiserbarasts": "televiserbar",
    "televiserbare": "televiserbar",
    "televiserbares": "televiserbar",
    "televiserbarheten": "televiserbarhet",
    "televiserbarhetens": "televiserbarhet",
    "televiserbarhets": "televiserbarhet",
    "televiserbars": "televiserbar",
    "televiserbart": "televiserbar",
    "televiserbarts": "televiserbar",
    "televiseringar": "televisering",
    "televiseringarna": "televisering",
    "televiseringarnas": "televisering",
    "televiseringars": "televisering",
    "televiseringen": "televisering",
    "televiseringens": "televisering",
    "televiserings": "televisering",
    "televisionen": "television",
    "televisionens": "television",
    "televisions": "television",
    "televisionskameran": "televisionskamera",
    "televisionskamerans": "televisionskamera",
    "televisionskameras": "televisionskamera",
    "televisionskameror": "televisionskamera",
    "televisionskamerorna": "televisionskamera",
    "televisionskamerornas": "televisionskamera",
    "televisionskamerors": "televisionskamera",
    "telexen": "telex",
    "telexens": "telex",
    "telexet": "telex",
    "telexets": "telex",
    "telfern": "telfer",
    "telferns": "telfer",
    "telfers": "telfer",
    "telfrar": "telfer",
    "telfrarna": "telfer",
    "telfrarnas": "telfer",
    "telfrars": "telfer",
    "telluren": "tellur",
    "tellurens": "tellur",
    "telluret": "tellur",
    "tellurets": "tellur",
    "tellurie": "tellurium",
    "tellurier": "tellurium",
    "tellurierna": "tellurium",
    "telluriernas": "tellurium",
    "telluriers": "tellurium",
    "telluriet": "tellurium",
    "telluriets": "tellurium",
    "telluriska": "tellurisk",
    "telluriskare": "tellurisk",
    "telluriskares": "tellurisk",
    "telluriskas": "tellurisk",
    "telluriskast": "tellurisk",
    "telluriskaste": "tellurisk",
    "telluriskastes": "tellurisk",
    "telluriskasts": "tellurisk",
    "telluriske": "tellurisk",
    "telluriskes": "tellurisk",
    "tellurisks": "tellurisk",
    "telluriskt": "tellurisk",
    "telluriskts": "tellurisk",
    "telluriums": "tellurium",
    "tellurs": "tellur",
    "telnar": "teln",
    "telnarna": "teln",
    "telnarnas": "teln",
    "telnars": "teln",
    "telnen": "teln",
    "telnens": "teln",
    "telningar": "telning",
    "telningarna": "telning",
    "telningarnas": "telning",
    "telningars": "telning",
    "telningen": "telning",
    "telningens": "telning",
    "telnings": "telning",
    "telns": "teln",
    "temadagar": "temadag",
    "temadagarna": "temadag",
    "temadagarnas": "temadag",
    "temadagars": "temadag",
    "temadagen": "temadag",
    "temadagens": "temadag",
    "temadags": "temadag",
    "teman": "tema",
    "temana": "tema",
    "temanas": "tema",
    "temans": "tema",
    "temanummerna": "temanummer",
    "temanummernas": "temanummer",
    "temanummers": "temanummer",
    "temanumren": "temanummer",
    "temanumrens": "temanummer",
    "temanumret": "temanummer",
    "temanumrets": "temanummer",
    "temas": "tema",
    "temat": "tema",
    "temata": "tema",
    "tematana": "tema",
    "tematanas": "tema",
    "tematas": "tema",
    "tematiken": "tematik",
    "tematikens": "tematik",
    "tematiks": "tematik",
    "tematiska": "tematisk",
    "tematiskare": "tematisk",
    "tematiskares": "tematisk",
    "tematiskas": "tematisk",
    "tematiskast": "tematisk",
    "tematiskaste": "tematisk",
    "tematiskastes": "tematisk",
    "tematiskasts": "tematisk",
    "tematiske": "tematisk",
    "tematiskes": "tematisk",
    "tematisks": "tematisk",
    "tematiskt": "tematisk",
    "tematiskts": "tematisk",
    "temats": "tema",
    "temp": "tempa",
    "tempad": "tempa",
    "tempade": "tempa",
    "tempades": "tempa",
    "tempads": "tempa",
    "tempande": "tempa",
    "tempanden": "tempande",
    "tempandena": "tempande",
    "tempandenas": "tempande",
    "tempandens": "tempande",
    "tempandes": "tempande",
    "tempandet": "tempande",
    "tempandets": "tempande",
    "tempar": "tempa",
    "temparna": "temp",
    "temparnas": "temp",
    "tempars": "temp",
    "tempas": "tempa",
    "tempat": "tempa",
    "tempats": "tempa",
    "tempelherrar": "tempelherre",
    "tempelherrarna": "tempelherre",
    "tempelherrarnas": "tempelherre",
    "tempelherrars": "tempelherre",
    "tempelherren": "tempelherre",
    "tempelherrens": "tempelherre",
    "tempelherreordens": "tempelherreorden",
    "tempelherreordnar": "tempelherreorden",
    "tempelherreordnarna": "tempelherreorden",
    "tempelherreordnarnas": "tempelherreorden",
    "tempelherreordnars": "tempelherreorden",
    "tempelherreordnen": "tempelherreorden",
    "tempelherreordnens": "tempelherreorden",
    "tempelherres": "tempelherre",
    "tempels": "tempel",
    "tempeltornen": "tempeltorn",
    "tempeltornens": "tempeltorn",
    "tempeltornet": "tempeltorn",
    "tempeltornets": "tempeltorn",
    "tempeltorns": "tempeltorn",
    "tempen": "temp",
    "tempens": "temp",
    "temperad": "tempera",
    "temperade": "tempera",
    "temperades": "tempera",
    "temperads": "tempera",
    "temperamenten": "temperament",
    "temperamentens": "temperament",
    "temperamentet": "temperament",
    "temperamentets": "temperament",
    "temperaments": "temperament",
    "temperamentsfria": "temperamentsfri",
    "temperamentsfriare": "temperamentsfri",
    "temperamentsfriares": "temperamentsfri",
    "temperamentsfrias": "temperamentsfri",
    "temperamentsfriast": "temperamentsfri",
    "temperamentsfriaste": "temperamentsfri",
    "temperamentsfriastes": "temperamentsfri",
    "temperamentsfriasts": "temperamentsfri",
    "temperamentsfrie": "temperamentsfri",
    "temperamentsfries": "temperamentsfri",
    "temperamentsfris": "temperamentsfri",
    "temperamentsfritt": "temperamentsfri",
    "temperamentsfritts": "temperamentsfri",
    "temperamentsfulla": "temperamentsfull",
    "temperamentsfullare": "temperamentsfull",
    "temperamentsfullares": "temperamentsfull",
    "temperamentsfullas": "temperamentsfull",
    "temperamentsfullast": "temperamentsfull",
    "temperamentsfullaste": "temperamentsfull",
    "temperamentsfullastes": "temperamentsfull",
    "temperamentsfullasts": "temperamentsfull",
    "temperamentsfulle": "temperamentsfull",
    "temperamentsfulles": "temperamentsfull",
    "temperamentsfullheten": "temperamentsfullhet",
    "temperamentsfullhetens": "temperamentsfullhet",
    "temperamentsfullhets": "temperamentsfullhet",
    "temperamentsfulls": "temperamentsfull",
    "temperamentsfullt": "temperamentsfull",
    "temperamentsfullts": "temperamentsfull",
    "temperamentsmänniskan": "temperamentsmänniska",
    "temperamentsmänniskans": "temperamentsmänniska",
    "temperamentsmänniskas": "temperamentsmänniska",
    "temperamentsmännisko": "temperamentsmänniska",
    "temperamentsmänniskor": "temperamentsmänniska",
    "temperamentsmänniskorna": "temperamentsmänniska",
    "temperamentsmänniskornas": "temperamentsmänniska",
    "temperamentsmänniskors": "temperamentsmänniska",
    "temperamentsutbrotten": "temperamentsutbrott",
    "temperamentsutbrottens": "temperamentsutbrott",
    "temperamentsutbrottet": "temperamentsutbrott",
    "temperamentsutbrottets": "temperamentsutbrott",
    "temperamentsutbrotts": "temperamentsutbrott",
    "temperan": "tempera",
    "temperande": "tempera",
    "temperanden": "temperande",
    "temperandena": "temperande",
    "temperandenas": "temperande",
    "temperandens": "temperande",
    "temperandes": "temperande",
    "temperandet": "temperande",
    "temperandets": "temperande",
    "temperans": "tempera",
    "temperar": "tempera",
    "temperas": "tempera",
    "temperat": "tempera",
    "temperats": "tempera",
    "temperaturbeständiga": "temperaturbeständig",
    "temperaturbeständigare": "temperaturbeständig",
    "temperaturbeständigares": "temperaturbeständig",
    "temperaturbeständigas": "temperaturbeständig",
    "temperaturbeständigast": "temperaturbeständig",
    "temperaturbeständigaste": "temperaturbeständig",
    "temperaturbeständigastes": "temperaturbeständig",
    "temperaturbeständigasts": "temperaturbeständig",
    "temperaturbeständige": "temperaturbeständig",
    "temperaturbeständiges": "temperaturbeständig",
    "temperaturbeständigheten": "temperaturbeständighet",
    "temperaturbeständighetens": "temperaturbeständighet",
    "temperaturbeständighets": "temperaturbeständighet",
    "temperaturbeständigs": "temperaturbeständig",
    "temperaturbeständigt": "temperaturbeständig",
    "temperaturbeständigts": "temperaturbeständig",
    "temperaturen": "temperatur",
    "temperaturens": "temperatur",
    "temperaturer": "temperatur",
    "temperaturerna": "temperatur",
    "temperaturernas": "temperatur",
    "temperaturers": "temperatur",
    "temperaturfördelningar": "temperaturfördelning",
    "temperaturfördelningarna": "temperaturfördelning",
    "temperaturfördelningarnas": "temperaturfördelning",
    "temperaturfördelningars": "temperaturfördelning",
    "temperaturfördelningen": "temperaturfördelning",
    "temperaturfördelningens": "temperaturfördelning",
    "temperaturfördelnings": "temperaturfördelning",
    "temperaturförhållanden": "temperaturförhållande",
    "temperaturförhållandena": "temperaturförhållande",
    "temperaturförhållandenas": "temperaturförhållande",
    "temperaturförhållandens": "temperaturförhållande",
    "temperaturförhållandes": "temperaturförhållande",
    "temperaturförhållandet": "temperaturförhållande",
    "temperaturförhållandets": "temperaturförhållande",
    "temperaturförändringar": "temperaturförändring",
    "temperaturförändringarna": "temperaturförändring",
    "temperaturförändringarnas": "temperaturförändring",
    "temperaturförändringars": "temperaturförändring",
    "temperaturförändringen": "temperaturförändring",
    "temperaturförändringens": "temperaturförändring",
    "temperaturförändrings": "temperaturförändring",
    "temperaturhöjningar": "temperaturhöjning",
    "temperaturhöjningarna": "temperaturhöjning",
    "temperaturhöjningarnas": "temperaturhöjning",
    "temperaturhöjningars": "temperaturhöjning",
    "temperaturhöjningen": "temperaturhöjning",
    "temperaturhöjningens": "temperaturhöjning",
    "temperaturhöjnings": "temperaturhöjning",
    "temperaturkänsliga": "temperaturkänslig",
    "temperaturkänsligare": "temperaturkänslig",
    "temperaturkänsligares": "temperaturkänslig",
    "temperaturkänsligas": "temperaturkänslig",
    "temperaturkänsligast": "temperaturkänslig",
    "temperaturkänsligaste": "temperaturkänslig",
    "temperaturkänsligastes": "temperaturkänslig",
    "temperaturkänsligasts": "temperaturkänslig",
    "temperaturkänslige": "temperaturkänslig",
    "temperaturkänsliges": "temperaturkänslig",
    "temperaturkänsligheten": "temperaturkänslighet",
    "temperaturkänslighetens": "temperaturkänslighet",
    "temperaturkänslighets": "temperaturkänslighet",
    "temperaturkänsligs": "temperaturkänslig",
    "temperaturkänsligt": "temperaturkänslig",
    "temperaturkänsligts": "temperaturkänslig",
    "temperaturområden": "temperaturområde",
    "temperaturområdena": "temperaturområde",
    "temperaturområdenas": "temperaturområde",
    "temperaturområdens": "temperaturområde",
    "temperaturområdes": "temperaturområde",
    "temperaturområdet": "temperaturområde",
    "temperaturområdets": "temperaturområde",
    "temperaturregulatorer": "temperaturregulator",
    "temperaturregulatorerna": "temperaturregulator",
    "temperaturregulatorernas": "temperaturregulator",
    "temperaturregulatorers": "temperaturregulator",
    "temperaturregulatorn": "temperaturregulator",
    "temperaturregulatorns": "temperaturregulator",
    "temperaturregulators": "temperaturregulator",
    "temperaturs": "temperatur",
    "temperaturskal": "temperaturskala",
    "temperaturskalan": "temperaturskala",
    "temperaturskalans": "temperaturskala",
    "temperaturskalas": "temperaturskala",
    "temperaturskale": "temperaturskala",
    "temperaturskalor": "temperaturskala",
    "temperaturskalorna": "temperaturskala",
    "temperaturskalornas": "temperaturskala",
    "temperaturskalors": "temperaturskala",
    "temperaturskals": "temperaturskala",
    "temperaturskillnaden": "temperaturskillnad",
    "temperaturskillnadens": "temperaturskillnad",
    "temperaturskillnader": "temperaturskillnad",
    "temperaturskillnaderna": "temperaturskillnad",
    "temperaturskillnadernas": "temperaturskillnad",
    "temperaturskillnaders": "temperaturskillnad",
    "temperaturskillnads": "temperaturskillnad",
    "temperaturstrålningar": "temperaturstrålning",
    "temperaturstrålningarna": "temperaturstrålning",
    "temperaturstrålningarnas": "temperaturstrålning",
    "temperaturstrålningars": "temperaturstrålning",
    "temperaturstrålningen": "temperaturstrålning",
    "temperaturstrålningens": "temperaturstrålning",
    "temperaturstrålnings": "temperaturstrålning",
    "temperatursvängningar": "temperatursvängning",
    "temperatursvängningarna": "temperatursvängning",
    "temperatursvängningarnas": "temperatursvängning",
    "temperatursvängningars": "temperatursvängning",
    "temperatursvängningen": "temperatursvängning",
    "temperatursvängningens": "temperatursvängning",
    "temperatursvängnings": "temperatursvängning",
    "temperatursänkningar": "temperatursänkning",
    "temperatursänkningarna": "temperatursänkning",
    "temperatursänkningarnas": "temperatursänkning",
    "temperatursänkningars": "temperatursänkning",
    "temperatursänkningen": "temperatursänkning",
    "temperatursänkningens": "temperatursänkning",
    "temperatursänknings": "temperatursänkning",
    "temperaturutvecklingen": "temperaturutveckling",
    "temperaturutvecklingens": "temperaturutveckling",
    "temperaturutvecklings": "temperaturutveckling",
    "temperaturväxlingar": "temperaturväxling",
    "temperaturväxlingarna": "temperaturväxling",
    "temperaturväxlingarnas": "temperaturväxling",
    "temperaturväxlingars": "temperaturväxling",
    "temperaturväxlingen": "temperaturväxling",
    "temperaturväxlingens": "temperaturväxling",
    "temperaturväxlings": "temperaturväxling",
    "temperbara": "temperbar",
    "temperbarare": "temperbar",
    "temperbarares": "temperbar",
    "temperbaras": "temperbar",
    "temperbarast": "temperbar",
    "temperbaraste": "temperbar",
    "temperbarastes": "temperbar",
    "temperbarasts": "temperbar",
    "temperbare": "temperbar",
    "temperbares": "temperbar",
    "temperbarheten": "temperbarhet",
    "temperbarhetens": "temperbarhet",
    "temperbarhets": "temperbarhet",
    "temperbars": "temperbar",
    "temperbart": "temperbar",
    "temperbarts": "temperbar",
    "tempererad": "temperera",
    "tempererade": "tempererad",
    "tempererades": "tempererad",
    "tempererads": "tempererad",
    "tempererande": "temperera",
    "tempereranden": "tempererande",
    "tempererandena": "tempererande",
    "tempererandenas": "tempererande",
    "tempererandens": "tempererande",
    "tempererandes": "tempererande",
    "tempererandet": "tempererande",
    "tempererandets": "tempererande",
    "tempererar": "temperera",
    "tempereras": "temperera",
    "tempererat": "tempererad",
    "tempererats": "tempererad",
    "tempererbara": "tempererbar",
    "tempererbarare": "tempererbar",
    "tempererbarares": "tempererbar",
    "tempererbaras": "tempererbar",
    "tempererbarast": "tempererbar",
    "tempererbaraste": "tempererbar",
    "tempererbarastes": "tempererbar",
    "tempererbarasts": "tempererbar",
    "tempererbare": "tempererbar",
    "tempererbares": "tempererbar",
    "tempererbarheten": "tempererbarhet",
    "tempererbarhetens": "tempererbarhet",
    "tempererbarhets": "tempererbarhet",
    "tempererbars": "tempererbar",
    "tempererbart": "tempererbar",
    "tempererbarts": "tempererbar",
    "tempereringar": "temperering",
    "tempereringarna": "temperering",
    "tempereringarnas": "temperering",
    "tempereringars": "temperering",
    "tempereringen": "temperering",
    "tempereringens": "temperering",
    "tempererings": "temperering",
    "temperingar": "tempering",
    "temperingarna": "tempering",
    "temperingarnas": "tempering",
    "temperingars": "tempering",
    "temperingen": "tempering",
    "temperingens": "tempering",
    "temperings": "tempering",
    "tempi": "tempo",
    "tempis": "tempo",
    "templen": "tempel",
    "templens": "tempel",
    "templet": "tempel",
    "templets": "tempel",
    "tempoarbetar": "tempoarbetare",
    "tempoarbetaren": "tempoarbetare",
    "tempoarbetarens": "tempoarbetare",
    "tempoarbetares": "tempoarbetare",
    "tempoarbetarna": "tempoarbetare",
    "tempoarbetarnas": "tempoarbetare",
    "tempoarbeten": "tempoarbete",
    "tempoarbetena": "tempoarbete",
    "tempoarbetenas": "tempoarbete",
    "tempoarbetens": "tempoarbete",
    "tempoarbetes": "tempoarbete",
    "tempoarbetet": "tempoarbete",
    "tempoarbetets": "tempoarbete",
    "tempoarbets": "tempoarbete",
    "tempobeteckningar": "tempobeteckning",
    "tempobeteckningarna": "tempobeteckning",
    "tempobeteckningarnas": "tempobeteckning",
    "tempobeteckningars": "tempobeteckning",
    "tempobeteckningen": "tempobeteckning",
    "tempobeteckningens": "tempobeteckning",
    "tempobetecknings": "tempobeteckning",
    "tempoloppen": "tempolopp",
    "tempoloppens": "tempolopp",
    "tempoloppet": "tempolopp",
    "tempoloppets": "tempolopp",
    "tempolopps": "tempolopp",
    "tempomässiga": "tempomässig",
    "tempomässigare": "tempomässig",
    "tempomässigares": "tempomässig",
    "tempomässigas": "tempomässig",
    "tempomässigast": "tempomässig",
    "tempomässigaste": "tempomässig",
    "tempomässigastes": "tempomässig",
    "tempomässigasts": "tempomässig",
    "tempomässige": "tempomässig",
    "tempomässiges": "tempomässig",
    "tempomässigs": "tempomässig",
    "tempomässigt": "tempomässig",
    "tempomässigts": "tempomässig",
    "tempon": "tempo",
    "tempona": "tempo",
    "temponas": "tempo",
    "tempons": "tempo",
    "temporala": "temporal",
    "temporalas": "temporal",
    "temporale": "temporal",
    "temporales": "temporal",
    "temporals": "temporal",
    "temporalt": "temporal",
    "temporalts": "temporal",
    "temporära": "temporär",
    "temporärare": "temporär",
    "temporärares": "temporär",
    "temporäras": "temporär",
    "temporärast": "temporär",
    "temporäraste": "temporär",
    "temporärastes": "temporär",
    "temporärasts": "temporär",
    "temporäre": "temporär",
    "temporäres": "temporär",
    "temporärs": "temporär",
    "temporärt": "temporär",
    "temporärts": "temporär",
    "tempos": "tempo",
    "tempot": "tempo",
    "tempots": "tempo",
    "temps": "temp",
    "tempsen": "tempus",
    "tempsens": "tempus",
    "tempset": "tempus",
    "tempsets": "tempus",
    "tempusen": "tempus",
    "tempusens": "tempus",
    "tempuset": "tempus",
    "tempusets": "tempus",
    "tempusväxlingar": "tempusväxling",
    "tempusväxlingarna": "tempusväxling",
    "tempusväxlingarnas": "tempusväxling",
    "tempusväxlingars": "tempusväxling",
    "tempusväxlingen": "tempusväxling",
    "tempusväxlingens": "tempusväxling",
    "tempusväxlings": "tempusväxling",
    "tenar": "ten",
    "tenarna": "ten",
    "tenarnas": "ten",
    "tenars": "ten",
    "tendensen": "tendens",
    "tendensens": "tendens",
    "tendenser": "tendens",
    "tendenserna": "tendens",
    "tendensernas": "tendens",
    "tendensers": "tendens",
    "tendentiösa": "tendentiös",
    "tendentiösare": "tendentiös",
    "tendentiösares": "tendentiös",
    "tendentiösas": "tendentiös",
    "tendentiösast": "tendentiös",
    "tendentiösaste": "tendentiös",
    "tendentiösastes": "tendentiös",
    "tendentiösasts": "tendentiös",
    "tendentiöse": "tendentiös",
    "tendentiöses": "tendentiös",
    "tendentiöst": "tendentiös",
    "tendentiösts": "tendentiös",
    "tenderade": "tendera",
    "tenderades": "tendera",
    "tenderande": "tendera",
    "tenderanden": "tenderande",
    "tenderandena": "tenderande",
    "tenderandenas": "tenderande",
    "tenderandens": "tenderande",
    "tenderandes": "tenderande",
    "tenderandet": "tenderande",
    "tenderandets": "tenderande",
    "tenderar": "tendera",
    "tenderas": "tendera",
    "tenderat": "tendera",
    "tenderats": "tendera",
    "tendern": "tender",
    "tenderns": "tender",
    "tenders": "tender",
    "tendrar": "tender",
    "tendrarna": "tender",
    "tendrarnas": "tender",
    "tendrars": "tender",
    "tenen": "ten",
    "tenens": "ten",
    "tennbrick": "tennbricka",
    "tennbrickan": "tennbricka",
    "tennbrickans": "tennbricka",
    "tennbrickas": "tennbricka",
    "tennbricke": "tennbricka",
    "tennbrickor": "tennbricka",
    "tennbrickorna": "tennbricka",
    "tennbrickornas": "tennbricka",
    "tennbrickors": "tennbricka",
    "tennbricks": "tennbricka",
    "tennet": "tenn",
    "tennets": "tenn",
    "tennfolien": "tennfolie",
    "tennfoliens": "tennfolie",
    "tennfolier": "tennfolie",
    "tennfolierna": "tennfolie",
    "tennfoliernas": "tennfolie",
    "tennfoliers": "tennfolie",
    "tennfolies": "tennfolie",
    "tennfoliet": "tennfolie",
    "tennfoliets": "tennfolie",
    "tennisarmen": "tennisarm",
    "tennisarmens": "tennisarm",
    "tennisarms": "tennisarm",
    "tennisbanan": "tennisbana",
    "tennisbanans": "tennisbana",
    "tennisbanas": "tennisbana",
    "tennisbane": "tennisbana",
    "tennisbanor": "tennisbana",
    "tennisbanorna": "tennisbana",
    "tennisbanornas": "tennisbana",
    "tennisbanors": "tennisbana",
    "tennisbollar": "tennisboll",
    "tennisbollarna": "tennisboll",
    "tennisbollarnas": "tennisboll",
    "tennisbollars": "tennisboll",
    "tennisbollen": "tennisboll",
    "tennisbollens": "tennisboll",
    "tennisbolls": "tennisboll",
    "tennisen": "tennis",
    "tennisens": "tennis",
    "tennisframgångar": "tennisframgång",
    "tennisframgångarna": "tennisframgång",
    "tennisframgångarnas": "tennisframgång",
    "tennisframgångars": "tennisframgång",
    "tennisframgången": "tennisframgång",
    "tennisframgångens": "tennisframgång",
    "tennisframgångs": "tennisframgång",
    "tennisjournalisten": "tennisjournalist",
    "tennisjournalistens": "tennisjournalist",
    "tennisjournalister": "tennisjournalist",
    "tennisjournalisterna": "tennisjournalist",
    "tennisjournalisternas": "tennisjournalist",
    "tennisjournalisters": "tennisjournalist",
    "tennisjournalists": "tennisjournalist",
    "tennisplanen": "tennisplan",
    "tennisplanens": "tennisplan",
    "tennisplaner": "tennisplan",
    "tennisplanerna": "tennisplan",
    "tennisplanernas": "tennisplan",
    "tennisplaners": "tennisplan",
    "tennisplans": "tennisplan",
    "tennisrackar": "tennisrack",
    "tennisrackarna": "tennisrack",
    "tennisrackarnas": "tennisrack",
    "tennisrackars": "tennisrack",
    "tennisracken": "tennisrack",
    "tennisrackens": "tennisrack",
    "tennisracket": "tennisrack",
    "tennisracketar": "tennisracket",
    "tennisracketarna": "tennisracket",
    "tennisracketarnas": "tennisracket",
    "tennisracketars": "tennisracket",
    "tennisracketen": "tennisracket",
    "tennisracketens": "tennisracket",
    "tennisrackets": "tennisracket",
    "tennisracks": "tennisrack",
    "tennisspelar": "tennisspelare",
    "tennisspelaren": "tennisspelare",
    "tennisspelarens": "tennisspelare",
    "tennisspelares": "tennisspelare",
    "tennisspelarna": "tennisspelare",
    "tennisspelarnas": "tennisspelare",
    "tennlodet": "tennlod",
    "tennlodets": "tennlod",
    "tennlods": "tennlod",
    "tennpesten": "tennpest",
    "tennpestens": "tennpest",
    "tennpests": "tennpest",
    "tenns": "tenn",
    "tennsoldaten": "tennsoldat",
    "tennsoldatens": "tennsoldat",
    "tennsoldater": "tennsoldat",
    "tennsoldaterna": "tennsoldat",
    "tennsoldaternas": "tennsoldat",
    "tennsoldaters": "tennsoldat",
    "tennsoldats": "tennsoldat",
    "tennstenen": "tennsten",
    "tennstenens": "tennsten",
    "tennstens": "tennsten",
    "tenorbarytonen": "tenorbaryton",
    "tenorbarytonens": "tenorbaryton",
    "tenorbarytoner": "tenorbaryton",
    "tenorbarytonerna": "tenorbaryton",
    "tenorbarytonernas": "tenorbaryton",
    "tenorbarytoners": "tenorbaryton",
    "tenorbarytons": "tenorbaryton",
    "tenoren": "tenor",
    "tenorens": "tenor",
    "tenorer": "tenor",
    "tenorerna": "tenor",
    "tenorernas": "tenor",
    "tenorers": "tenor",
    "tenors": "tenor",
    "tenorsaxofonen": "tenorsaxofon",
    "tenorsaxofonens": "tenorsaxofon",
    "tenorsaxofoner": "tenorsaxofon",
    "tenorsaxofonerna": "tenorsaxofon",
    "tenorsaxofonernas": "tenorsaxofon",
    "tenorsaxofoners": "tenorsaxofon",
    "tenorsaxofons": "tenorsaxofon",
    "tens": "ten",
    "tensiden": "tensid",
    "tensidens": "tensid",
    "tensider": "tensid",
    "tensiderna": "tensid",
    "tensidernas": "tensid",
    "tensiders": "tensid",
    "tensids": "tensid",
    "tensionen": "tension",
    "tensionens": "tension",
    "tensioner": "tension",
    "tensionerna": "tension",
    "tensionernas": "tension",
    "tensioners": "tension",
    "tensions": "tension",
    "tent": "tenta",
    "tentad": "tenta",
    "tentade": "tenta",
    "tentades": "tenta",
    "tentads": "tenta",
    "tentakeln": "tentakel",
    "tentakelns": "tentakel",
    "tentakels": "tentakel",
    "tentakler": "tentakel",
    "tentaklerna": "tentakel",
    "tentaklernas": "tentakel",
    "tentaklers": "tentakel",
    "tentamens": "tentamen",
    "tentamensboken": "tentamensbok",
    "tentamensbokens": "tentamensbok",
    "tentamensboks": "tentamensbok",
    "tentamensböcker": "tentamensbok",
    "tentamensböckerna": "tentamensbok",
    "tentamensböckernas": "tentamensbok",
    "tentamensböckers": "tentamensbok",
    "tentamensläs": "tentamensläsa",
    "tentamensläsande": "tentamensläsa",
    "tentamensläsanden": "tentamensläsande",
    "tentamensläsandena": "tentamensläsande",
    "tentamensläsandenas": "tentamensläsande",
    "tentamensläsandens": "tentamensläsande",
    "tentamensläsandes": "tentamensläsande",
    "tentamensläsandet": "tentamensläsande",
    "tentamensläsandets": "tentamensläsande",
    "tentamensläsas": "tentamensläsa",
    "tentamensläser": "tentamensläsa",
    "tentamensläses": "tentamensläsa",
    "tentamensläst": "tentamensläsa",
    "tentamenslästa": "tentamensläsa",
    "tentamenslästas": "tentamensläsa",
    "tentamensläste": "tentamensläsa",
    "tentamenslästes": "tentamensläsa",
    "tentamenslästs": "tentamensläsa",
    "tentamensnervositeten": "tentamensnervositet",
    "tentamensnervositetens": "tentamensnervositet",
    "tentamensnervositeter": "tentamensnervositet",
    "tentamensnervositeterna": "tentamensnervositet",
    "tentamensnervositeternas": "tentamensnervositet",
    "tentamensnervositeters": "tentamensnervositet",
    "tentamensnervositets": "tentamensnervositet",
    "tentamina": "tentamen",
    "tentaminas": "tentamen",
    "tentan": "tenta",
    "tentande": "tenta",
    "tentanden": "tentande",
    "tentandena": "tentande",
    "tentandenas": "tentande",
    "tentandens": "tentande",
    "tentander": "tentand",
    "tentanderna": "tentand",
    "tentandernas": "tentand",
    "tentanders": "tentand",
    "tentandes": "tentande",
    "tentandet": "tentande",
    "tentandets": "tentande",
    "tentands": "tentand",
    "tentans": "tenta",
    "tentar": "tenta",
    "tentas": "tenta",
    "tentat": "tenta",
    "tentativa": "tentativ",
    "tentativare": "tentativ",
    "tentativares": "tentativ",
    "tentativas": "tentativ",
    "tentativast": "tentativ",
    "tentativaste": "tentativ",
    "tentativastes": "tentativ",
    "tentativasts": "tentativ",
    "tentative": "tentativ",
    "tentatives": "tentativ",
    "tentativs": "tentativ",
    "tentativt": "tentativ",
    "tentativts": "tentativ",
    "tentatorer": "tentator",
    "tentatorerna": "tentator",
    "tentatorernas": "tentator",
    "tentatorers": "tentator",
    "tentatorn": "tentator",
    "tentatorns": "tentator",
    "tentators": "tentator",
    "tentats": "tenta",
    "tenterad": "tentera",
    "tenterade": "tentera",
    "tenterades": "tentera",
    "tenterads": "tentera",
    "tenterande": "tentera",
    "tenteranden": "tenterande",
    "tenterandena": "tenterande",
    "tenterandenas": "tenterande",
    "tenterandens": "tenterande",
    "tenterandes": "tenterande",
    "tenterandet": "tenterande",
    "tenterandets": "tenterande",
    "tenterar": "tentera",
    "tenteras": "tentera",
    "tenterat": "tentera",
    "tenterats": "tentera",
    "tenterbara": "tenterbar",
    "tenterbarare": "tenterbar",
    "tenterbarares": "tenterbar",
    "tenterbaras": "tenterbar",
    "tenterbarast": "tenterbar",
    "tenterbaraste": "tenterbar",
    "tenterbarastes": "tenterbar",
    "tenterbarasts": "tenterbar",
    "tenterbare": "tenterbar",
    "tenterbares": "tenterbar",
    "tenterbarheten": "tenterbarhet",
    "tenterbarhetens": "tenterbarhet",
    "tenterbarhets": "tenterbarhet",
    "tenterbars": "tenterbar",
    "tenterbart": "tenterbar",
    "tenterbarts": "tenterbar",
    "tenteringar": "tentering",
    "tenteringarna": "tentering",
    "tenteringarnas": "tentering",
    "tenteringars": "tentering",
    "tenteringen": "tentering",
    "tenteringens": "tentering",
    "tenterings": "tentering",
    "tentor": "tenta",
    "tentorna": "tenta",
    "tentornas": "tenta",
    "tentors": "tenta",
    "teobrominen": "teobromin",
    "teobrominens": "teobromin",
    "teobrominer": "teobromin",
    "teobrominerna": "teobromin",
    "teobrominernas": "teobromin",
    "teobrominers": "teobromin",
    "teobrominet": "teobromin",
    "teobrominets": "teobromin",
    "teobromins": "teobromin",
    "teocentriska": "teocentrisk",
    "teocentriskare": "teocentrisk",
    "teocentriskares": "teocentrisk",
    "teocentriskas": "teocentrisk",
    "teocentriskast": "teocentrisk",
    "teocentriskaste": "teocentrisk",
    "teocentriskastes": "teocentrisk",
    "teocentriskasts": "teocentrisk",
    "teocentriske": "teocentrisk",
    "teocentriskes": "teocentrisk",
    "teocentrisks": "teocentrisk",
    "teocentriskt": "teocentrisk",
    "teocentriskts": "teocentrisk",
    "teodicén": "teodicé",
    "teodicéns": "teodicé",
    "teodicés": "teodicé",
    "teodoliten": "teodolit",
    "teodolitens": "teodolit",
    "teodoliter": "teodolit",
    "teodoliterna": "teodolit",
    "teodoliternas": "teodolit",
    "teodoliters": "teodolit",
    "teodolits": "teodolit",
    "teofyllinen": "teofyllin",
    "teofyllinens": "teofyllin",
    "teofylliner": "teofyllin",
    "teofyllinerna": "teofyllin",
    "teofyllinernas": "teofyllin",
    "teofylliners": "teofyllin",
    "teofyllinet": "teofyllin",
    "teofyllinets": "teofyllin",
    "teofyllins": "teofyllin",
    "teogonien": "teogoni",
    "teogoniens": "teogoni",
    "teogonier": "teogoni",
    "teogonierna": "teogoni",
    "teogoniernas": "teogoni",
    "teogoniers": "teogoni",
    "teogonin": "teogoni",
    "teogonins": "teogoni",
    "teogonis": "teogoni",
    "teokratien": "teokrati",
    "teokratiens": "teokrati",
    "teokratier": "teokrati",
    "teokratierna": "teokrati",
    "teokratiernas": "teokrati",
    "teokratiers": "teokrati",
    "teokratin": "teokrati",
    "teokratins": "teokrati",
    "teokratis": "teokrati",
    "teokratiska": "teokratisk",
    "teokratiskare": "teokratisk",
    "teokratiskares": "teokratisk",
    "teokratiskas": "teokratisk",
    "teokratiskast": "teokratisk",
    "teokratiskaste": "teokratisk",
    "teokratiskastes": "teokratisk",
    "teokratiskasts": "teokratisk",
    "teokratiske": "teokratisk",
    "teokratiskes": "teokratisk",
    "teokratisks": "teokratisk",
    "teokratiskt": "teokratisk",
    "teokratiskts": "teokratisk",
    "teologen": "teolog",
    "teologens": "teolog",
    "teologer": "teolog",
    "teologerna": "teolog",
    "teologernas": "teolog",
    "teologers": "teolog",
    "teologien": "teologi",
    "teologiens": "teologi",
    "teologin": "teologi",
    "teologins": "teologi",
    "teologis": "teologi",
    "teologiska": "teologisk",
    "teologiskare": "teologisk",
    "teologiskares": "teologisk",
    "teologiskas": "teologisk",
    "teologiskast": "teologisk",
    "teologiskaste": "teologisk",
    "teologiskastes": "teologisk",
    "teologiskasts": "teologisk",
    "teologiske": "teologisk",
    "teologiskes": "teologisk",
    "teologisks": "teologisk",
    "teologiskt": "teologisk",
    "teologiskts": "teologisk",
    "teologs": "teolog",
    "teoremen": "teorem",
    "teoremens": "teorem",
    "teoremet": "teorem",
    "teoremets": "teorem",
    "teorems": "teorem",
    "teoretikern": "teoretiker",
    "teoretikerna": "teoretiker",
    "teoretikernas": "teoretiker",
    "teoretikerns": "teoretiker",
    "teoretikers": "teoretiker",
    "teoretiserade": "teoretisera",
    "teoretiserades": "teoretisera",
    "teoretiserande": "teoretisera",
    "teoretiseranden": "teoretiserande",
    "teoretiserandena": "teoretiserande",
    "teoretiserandenas": "teoretiserande",
    "teoretiserandens": "teoretiserande",
    "teoretiserandes": "teoretiserande",
    "teoretiserandet": "teoretiserande",
    "teoretiserandets": "teoretiserande",
    "teoretiserar": "teoretisera",
    "teoretiseras": "teoretisera",
    "teoretiserat": "teoretisera",
    "teoretiserats": "teoretisera",
    "teoretiseringar": "teoretisering",
    "teoretiseringarna": "teoretisering",
    "teoretiseringarnas": "teoretisering",
    "teoretiseringars": "teoretisering",
    "teoretiseringen": "teoretisering",
    "teoretiseringens": "teoretisering",
    "teoretiserings": "teoretisering",
    "teoretiska": "teoretisk",
    "teoretiskare": "teoretisk",
    "teoretiskares": "teoretisk",
    "teoretiskas": "teoretisk",
    "teoretiskast": "teoretisk",
    "teoretiskaste": "teoretisk",
    "teoretiskastes": "teoretisk",
    "teoretiskasts": "teoretisk",
    "teoretiske": "teoretisk",
    "teoretiskes": "teoretisk",
    "teoretisks": "teoretisk",
    "teoretiskt": "teoretisk",
    "teoretiskts": "teoretisk",
    "teoribildningar": "teoribildning",
    "teoribildningarna": "teoribildning",
    "teoribildningarnas": "teoribildning",
    "teoribildningars": "teoribildning",
    "teoribildningen": "teoribildning",
    "teoribildningens": "teoribildning",
    "teoribildnings": "teoribildning",
    "teorien": "teori",
    "teoriens": "teori",
    "teorier": "teori",
    "teorierna": "teori",
    "teoriernas": "teori",
    "teoriers": "teori",
    "teorin": "teori",
    "teorins": "teori",
    "teoris": "teori",
    "teosofen": "teosof",
    "teosofens": "teosof",
    "teosofer": "teosof",
    "teosoferna": "teosof",
    "teosofernas": "teosof",
    "teosofers": "teosof",
    "teosofien": "teosofi",
    "teosofiens": "teosofi",
    "teosofin": "teosofi",
    "teosofins": "teosofi",
    "teosofis": "teosofi",
    "teosofiska": "teosofisk",
    "teosofiskare": "teosofisk",
    "teosofiskares": "teosofisk",
    "teosofiskas": "teosofisk",
    "teosofiskast": "teosofisk",
    "teosofiskaste": "teosofisk",
    "teosofiskastes": "teosofisk",
    "teosofiskasts": "teosofisk",
    "teosofiske": "teosofisk",
    "teosofiskes": "teosofisk",
    "teosofisks": "teosofisk",
    "teosofiskt": "teosofisk",
    "teosofiskts": "teosofisk",
    "teosofs": "teosof",
    "tepås": "tepåse",
    "tepåsar": "tepåse",
    "tepåsarna": "tepåse",
    "tepåsarnas": "tepåse",
    "tepåsars": "tepåse",
    "tepåsen": "tepåse",
    "tepåsens": "tepåse",
    "tepåses": "tepåse",
    "tequilan": "tequila",
    "tequilans": "tequila",
    "tequilas": "tequila",
    "terabyten": "terabyte",
    "terabytena": "terabyte",
    "terabytenas": "terabyte",
    "terabytens": "terabyte",
    "terabytes": "terabyte",
    "teraelektronvolten": "teraelektronvolt",
    "teraelektronvoltens": "teraelektronvolt",
    "teraelektronvolts": "teraelektronvolt",
    "terapeuten": "terapeut",
    "terapeutens": "terapeut",
    "terapeuter": "terapeut",
    "terapeuterna": "terapeut",
    "terapeuternas": "terapeut",
    "terapeuters": "terapeut",
    "terapeutiska": "terapeutisk",
    "terapeutiskare": "terapeutisk",
    "terapeutiskares": "terapeutisk",
    "terapeutiskas": "terapeutisk",
    "terapeutiskast": "terapeutisk",
    "terapeutiskaste": "terapeutisk",
    "terapeutiskastes": "terapeutisk",
    "terapeutiskasts": "terapeutisk",
    "terapeutiske": "terapeutisk",
    "terapeutiskes": "terapeutisk",
    "terapeutisks": "terapeutisk",
    "terapeutiskt": "terapeutisk",
    "terapeutiskts": "terapeutisk",
    "terapeuts": "terapeut",
    "terapien": "terapi",
    "terapiens": "terapi",
    "terapier": "terapi",
    "terapierna": "terapi",
    "terapiernas": "terapi",
    "terapiers": "terapi",
    "terapin": "terapi",
    "terapins": "terapi",
    "terapis": "terapi",
    "terapisessionen": "terapisession",
    "terapisessionens": "terapisession",
    "terapisessioner": "terapisession",
    "terapisessionerna": "terapisession",
    "terapisessionernas": "terapisession",
    "terapisessioners": "terapisession",
    "terapisessions": "terapisession",
    "terassen": "terass",
    "terassens": "terass",
    "terasser": "terass",
    "terasserna": "terass",
    "terassernas": "terass",
    "terassers": "terass",
    "terasstvätten": "terasstvätt",
    "terasstvättens": "terasstvätt",
    "terasstvätts": "terasstvätt",
    "terawatten": "terawatt",
    "terawattens": "terawatt",
    "terawatts": "terawatt",
    "terbiet": "terbium",
    "terbiets": "terbium",
    "terbiumet": "terbium",
    "terbiumets": "terbium",
    "terbiums": "terbium",
    "terebinten": "terebint",
    "terebintens": "terebint",
    "terebinter": "terebint",
    "terebinterna": "terebint",
    "terebinternas": "terebint",
    "terebinters": "terebint",
    "terebints": "terebint",
    "termen": "term",
    "termens": "term",
    "termer": "term",
    "termerna": "termer",
    "termernas": "termer",
    "termers": "termer",
    "termiken": "termik",
    "termikens": "termik",
    "termiks": "termik",
    "terminala": "terminal",
    "terminalare": "terminal",
    "terminalares": "terminal",
    "terminalas": "terminal",
    "terminalast": "terminal",
    "terminalaste": "terminal",
    "terminalastes": "terminal",
    "terminalasts": "terminal",
    "terminale": "terminal",
    "terminalen": "terminal",
    "terminalens": "terminal",
    "terminaler": "terminal",
    "terminalerna": "terminal",
    "terminalernas": "terminal",
    "terminalers": "terminal",
    "terminales": "terminal",
    "terminals": "terminal",
    "terminalt": "terminal",
    "terminalts": "terminal",
    "terminalvården": "terminalvård",
    "terminalvårdens": "terminalvård",
    "terminalvårds": "terminalvård",
    "terminen": "termin",
    "terminens": "termin",
    "terminer": "termin",
    "terminerna": "termin",
    "terminernas": "termin",
    "terminers": "termin",
    "terminologen": "terminolog",
    "terminologens": "terminolog",
    "terminologer": "terminolog",
    "terminologerna": "terminolog",
    "terminologernas": "terminolog",
    "terminologers": "terminolog",
    "terminologien": "terminologi",
    "terminologiens": "terminologi",
    "terminologier": "terminologi",
    "terminologierna": "terminologi",
    "terminologiernas": "terminologi",
    "terminologiers": "terminologi",
    "terminologin": "terminologi",
    "terminologins": "terminologi",
    "terminologis": "terminologi",
    "terminologiska": "terminologisk",
    "terminologiskare": "terminologisk",
    "terminologiskares": "terminologisk",
    "terminologiskas": "terminologisk",
    "terminologiskast": "terminologisk",
    "terminologiskaste": "terminologisk",
    "terminologiskastes": "terminologisk",
    "terminologiskasts": "terminologisk",
    "terminologiske": "terminologisk",
    "terminologiskes": "terminologisk",
    "terminologisks": "terminologisk",
    "terminologiskt": "terminologisk",
    "terminologiskts": "terminologisk",
    "terminologs": "terminolog",
    "termins": "termin",
    "terminsaffären": "terminsaffär",
    "terminsaffärens": "terminsaffär",
    "terminsaffärer": "terminsaffär",
    "terminsaffärerna": "terminsaffär",
    "terminsaffärernas": "terminsaffär",
    "terminsaffärers": "terminsaffär",
    "terminsaffärs": "terminsaffär",
    "terminsavgiften": "terminsavgift",
    "terminsavgiftens": "terminsavgift",
    "terminsavgifter": "terminsavgift",
    "terminsavgifterna": "terminsavgift",
    "terminsavgifternas": "terminsavgift",
    "terminsavgifters": "terminsavgift",
    "terminsavgifts": "terminsavgift",
    "termiska": "termisk",
    "termiskare": "termisk",
    "termiskares": "termisk",
    "termiskas": "termisk",
    "termiskast": "termisk",
    "termiskaste": "termisk",
    "termiskastes": "termisk",
    "termiskasts": "termisk",
    "termiske": "termisk",
    "termiskes": "termisk",
    "termisks": "termisk",
    "termiskt": "termisk",
    "termiskts": "termisk",
    "termistorer": "termistor",
    "termistorerna": "termistor",
    "termistorernas": "termistor",
    "termistorers": "termistor",
    "termistorn": "termistor",
    "termistorns": "termistor",
    "termistors": "termistor",
    "termiten": "termit",
    "termitens": "termit",
    "termiter": "termit",
    "termiterna": "termit",
    "termiternas": "termit",
    "termiters": "termit",
    "termits": "termit",
    "termobyx": "termobyxa",
    "termobyxan": "termobyxa",
    "termobyxans": "termobyxa",
    "termobyxas": "termobyxa",
    "termobyxe": "termobyxa",
    "termobyxor": "termobyxa",
    "termobyxorna": "termobyxa",
    "termobyxornas": "termobyxa",
    "termobyxors": "termobyxa",
    "termodynamiken": "termodynamik",
    "termodynamikens": "termodynamik",
    "termodynamiks": "termodynamik",
    "termodynamiska": "termodynamisk",
    "termodynamiskare": "termodynamisk",
    "termodynamiskares": "termodynamisk",
    "termodynamiskas": "termodynamisk",
    "termodynamiskast": "termodynamisk",
    "termodynamiskaste": "termodynamisk",
    "termodynamiskastes": "termodynamisk",
    "termodynamiskasts": "termodynamisk",
    "termodynamiske": "termodynamisk",
    "termodynamiskes": "termodynamisk",
    "termodynamisks": "termodynamisk",
    "termodynamiskt": "termodynamisk",
    "termodynamiskts": "termodynamisk",
    "termoelektriciteten": "termoelektricitet",
    "termoelektricitetens": "termoelektricitet",
    "termoelektriciteter": "termoelektricitet",
    "termoelektriciteterna": "termoelektricitet",
    "termoelektriciteternas": "termoelektricitet",
    "termoelektriciteters": "termoelektricitet",
    "termoelektricitets": "termoelektricitet",
    "termoelementen": "termoelement",
    "termoelementens": "termoelement",
    "termoelementet": "termoelement",
    "termoelementets": "termoelement",
    "termoelements": "termoelement",
    "termofila": "termofil",
    "termofilare": "termofil",
    "termofilares": "termofil",
    "termofilas": "termofil",
    "termofilast": "termofil",
    "termofilaste": "termofil",
    "termofilastes": "termofil",
    "termofilasts": "termofil",
    "termofile": "termofil",
    "termofiles": "termofil",
    "termofils": "termofil",
    "termofilt": "termofil",
    "termofilts": "termofil",
    "termografien": "termografi",
    "termografiens": "termografi",
    "termografin": "termografi",
    "termografins": "termografi",
    "termografis": "termografi",
    "termokapp": "termokappa",
    "termokappan": "termokappa",
    "termokappans": "termokappa",
    "termokappas": "termokappa",
    "termokappe": "termokappa",
    "termokappor": "termokappa",
    "termokapporna": "termokappa",
    "termokappornas": "termokappa",
    "termokappors": "termokappa",
    "termokapps": "termokappa",
    "termokemien": "termokemi",
    "termokemiens": "termokemi",
    "termokemin": "termokemi",
    "termokemins": "termokemi",
    "termokemis": "termokemi",
    "termometern": "termometer",
    "termometerns": "termometer",
    "termometers": "termometer",
    "termometrar": "termometer",
    "termometrarna": "termometer",
    "termometrarnas": "termometer",
    "termometrars": "termometer",
    "termonukleära": "termonukleär",
    "termonukleärare": "termonukleär",
    "termonukleärares": "termonukleär",
    "termonukleäras": "termonukleär",
    "termonukleärast": "termonukleär",
    "termonukleäraste": "termonukleär",
    "termonukleärastes": "termonukleär",
    "termonukleärasts": "termonukleär",
    "termonukleäre": "termonukleär",
    "termonukleäres": "termonukleär",
    "termonukleärs": "termonukleär",
    "termonukleärt": "termonukleär",
    "termonukleärts": "termonukleär",
    "termoplasten": "termoplast",
    "termoplastens": "termoplast",
    "termoplaster": "termoplast",
    "termoplasterna": "termoplast",
    "termoplasternas": "termoplast",
    "termoplasters": "termoplast",
    "termoplasts": "termoplast",
    "termoregulatorer": "termoregulator",
    "termoregulatorerna": "termoregulator",
    "termoregulatorernas": "termoregulator",
    "termoregulatorers": "termoregulator",
    "termoregulatorn": "termoregulator",
    "termoregulatorns": "termoregulator",
    "termoregulators": "termoregulator",
    "termosar": "termos",
    "termosarna": "termos",
    "termosarnas": "termos",
    "termosars": "termos",
    "termosen": "termos",
    "termosens": "termos",
    "termostapeln": "termostapel",
    "termostapelns": "termostapel",
    "termostapels": "termostapel",
    "termostaplar": "termostapel",
    "termostaplarna": "termostapel",
    "termostaplarnas": "termostapel",
    "termostaplars": "termostapel",
    "termostaten": "termostat",
    "termostatens": "termostat",
    "termostater": "termostat",
    "termostaterna": "termostat",
    "termostaternas": "termostat",
    "termostaters": "termostat",
    "termostats": "termostat",
    "terms": "term",
    "ternen": "tern",
    "ternens": "tern",
    "terner": "tern",
    "ternerna": "tern",
    "ternernas": "tern",
    "terners": "tern",
    "terns": "tern",
    "terosen": "teros",
    "terosens": "teros",
    "terosor": "teros",
    "terosorna": "teros",
    "terosornas": "teros",
    "terosors": "teros",
    "terpenen": "terpen",
    "terpenens": "terpen",
    "terpener": "terpen",
    "terpenerna": "terpen",
    "terpenernas": "terpen",
    "terpeners": "terpen",
    "terpens": "terpen",
    "terpentinen": "terpentin",
    "terpentinens": "terpentin",
    "terpentinet": "terpentin",
    "terpentinets": "terpentin",
    "terpentins": "terpentin",
    "terrakottan": "terrakotta",
    "terrakottans": "terrakotta",
    "terrakottas": "terrakotta",
    "terrarie": "terrarium",
    "terrarier": "terrarium",
    "terrarierna": "terrarium",
    "terrariernas": "terrarium",
    "terrariers": "terrarium",
    "terrariet": "terrarium",
    "terrariets": "terrarium",
    "terrariums": "terrarium",
    "terrassen": "terrass",
    "terrassens": "terrass",
    "terrasser": "terrass",
    "terrasserad": "terrassera",
    "terrasserade": "terrassera",
    "terrasserades": "terrassera",
    "terrasserads": "terrassera",
    "terrasserande": "terrassera",
    "terrasseranden": "terrasserande",
    "terrasserandena": "terrasserande",
    "terrasserandenas": "terrasserande",
    "terrasserandens": "terrasserande",
    "terrasserandes": "terrasserande",
    "terrasserandet": "terrasserande",
    "terrasserandets": "terrasserande",
    "terrasserar": "terrassera",
    "terrasseras": "terrassera",
    "terrasserat": "terrassera",
    "terrasserats": "terrassera",
    "terrasserbara": "terrasserbar",
    "terrasserbarare": "terrasserbar",
    "terrasserbarares": "terrasserbar",
    "terrasserbaras": "terrasserbar",
    "terrasserbarast": "terrasserbar",
    "terrasserbaraste": "terrasserbar",
    "terrasserbarastes": "terrasserbar",
    "terrasserbarasts": "terrasserbar",
    "terrasserbare": "terrasserbar",
    "terrasserbares": "terrasserbar",
    "terrasserbarheten": "terrasserbarhet",
    "terrasserbarhetens": "terrasserbarhet",
    "terrasserbarhets": "terrasserbarhet",
    "terrasserbars": "terrasserbar",
    "terrasserbart": "terrasserbar",
    "terrasserbarts": "terrasserbar",
    "terrasseringar": "terrassering",
    "terrasseringarna": "terrassering",
    "terrasseringarnas": "terrassering",
    "terrasseringars": "terrassering",
    "terrasseringen": "terrassering",
    "terrasseringens": "terrassering",
    "terrasserings": "terrassering",
    "terrasserna": "terrass",
    "terrassernas": "terrass",
    "terrassers": "terrass",
    "terresters": "terrester",
    "terrestert": "terrester",
    "terresterts": "terrester",
    "terrestra": "terrester",
    "terrestrare": "terrester",
    "terrestrares": "terrester",
    "terrestras": "terrester",
    "terrestrast": "terrester",
    "terrestraste": "terrester",
    "terrestrastes": "terrester",
    "terrestrasts": "terrester",
    "terrestre": "terrester",
    "terrestres": "terrester",
    "terriern": "terrier",
    "terrierna": "terrier",
    "terriernas": "terrier",
    "terrierns": "terrier",
    "terriers": "terrier",
    "terrigena": "terrigen",
    "terrigenare": "terrigen",
    "terrigenares": "terrigen",
    "terrigenas": "terrigen",
    "terrigenast": "terrigen",
    "terrigenaste": "terrigen",
    "terrigenastes": "terrigen",
    "terrigenasts": "terrigen",
    "terrigene": "terrigen",
    "terrigenes": "terrigen",
    "terrigens": "terrigen",
    "terrigent": "terrigen",
    "terrigents": "terrigen",
    "terrinen": "terrin",
    "terrinens": "terrin",
    "terriner": "terrin",
    "terrinerna": "terrin",
    "terrinernas": "terrin",
    "terriners": "terrin",
    "terrins": "terrin",
    "territen": "territ",
    "territens": "territ",
    "territorialgränsen": "territorialgräns",
    "territorialgränsens": "territorialgräns",
    "territorialgränser": "territorialgräns",
    "territorialgränserna": "territorialgräns",
    "territorialgränsernas": "territorialgräns",
    "territorialgränsers": "territorialgräns",
    "territorialvattens": "territorialvatten",
    "territorialvattnen": "territorialvatten",
    "territorialvattnens": "territorialvatten",
    "territorialvattnet": "territorialvatten",
    "territorialvattnets": "territorialvatten",
    "territorie": "territorium",
    "territoriella": "territoriell",
    "territoriellare": "territoriell",
    "territoriellares": "territoriell",
    "territoriellas": "territoriell",
    "territoriellast": "territoriell",
    "territoriellaste": "territoriell",
    "territoriellastes": "territoriell",
    "territoriellasts": "territoriell",
    "territorielle": "territoriell",
    "territorielles": "territoriell",
    "territoriells": "territoriell",
    "territoriellt": "territoriell",
    "territoriellts": "territoriell",
    "territorier": "territorium",
    "territorierna": "territorium",
    "territoriernas": "territorium",
    "territoriers": "territorium",
    "territoriet": "territorium",
    "territoriets": "territorium",
    "territoriums": "territorium",
    "territs": "territ",
    "terrorattacken": "terrorattack",
    "terrorattackens": "terrorattack",
    "terrorattacker": "terrorattack",
    "terrorattackerna": "terrorattack",
    "terrorattackernas": "terrorattack",
    "terrorattackers": "terrorattack",
    "terrorattacks": "terrorattack",
    "terrorbalansen": "terrorbalans",
    "terrorbalansens": "terrorbalans",
    "terrorbombningar": "terrorbombning",
    "terrorbombningarna": "terrorbombning",
    "terrorbombningarnas": "terrorbombning",
    "terrorbombningars": "terrorbombning",
    "terrorbombningen": "terrorbombning",
    "terrorbombningens": "terrorbombning",
    "terrorbombnings": "terrorbombning",
    "terrordåden": "terrordåd",
    "terrordådens": "terrordåd",
    "terrordådet": "terrordåd",
    "terrordådets": "terrordåd",
    "terrordåds": "terrordåd",
    "terrorhotbedömningar": "terrorhotbedömning",
    "terrorhotbedömningarna": "terrorhotbedömning",
    "terrorhotbedömningarnas": "terrorhotbedömning",
    "terrorhotbedömningars": "terrorhotbedömning",
    "terrorhotbedömningen": "terrorhotbedömning",
    "terrorhotbedömningens": "terrorhotbedömning",
    "terrorhotbedömnings": "terrorhotbedömning",
    "terrorhoten": "terrorhot",
    "terrorhotens": "terrorhot",
    "terrorhotet": "terrorhot",
    "terrorhotets": "terrorhot",
    "terrorhots": "terrorhot",
    "terroriserad": "terrorisera",
    "terroriserade": "terrorisera",
    "terroriserades": "terrorisera",
    "terroriserads": "terrorisera",
    "terroriserande": "terrorisera",
    "terroriseranden": "terroriserande",
    "terroriserandena": "terroriserande",
    "terroriserandenas": "terroriserande",
    "terroriserandens": "terroriserande",
    "terroriserandes": "terroriserande",
    "terroriserandet": "terroriserande",
    "terroriserandets": "terroriserande",
    "terroriserar": "terrorisera",
    "terroriseras": "terrorisera",
    "terroriserat": "terrorisera",
    "terroriserats": "terrorisera",
    "terroriserbara": "terroriserbar",
    "terroriserbarare": "terroriserbar",
    "terroriserbarares": "terroriserbar",
    "terroriserbaras": "terroriserbar",
    "terroriserbarast": "terroriserbar",
    "terroriserbaraste": "terroriserbar",
    "terroriserbarastes": "terroriserbar",
    "terroriserbarasts": "terroriserbar",
    "terroriserbare": "terroriserbar",
    "terroriserbares": "terroriserbar",
    "terroriserbarheten": "terroriserbarhet",
    "terroriserbarhetens": "terroriserbarhet",
    "terroriserbarhets": "terroriserbarhet",
    "terroriserbars": "terroriserbar",
    "terroriserbart": "terroriserbar",
    "terroriserbarts": "terroriserbar",
    "terroriseringar": "terrorisering",
    "terroriseringarna": "terrorisering",
    "terroriseringarnas": "terrorisering",
    "terroriseringars": "terrorisering",
    "terroriseringen": "terrorisering",
    "terroriseringens": "terrorisering",
    "terroriserings": "terrorisering",
    "terrorismen": "terrorism",
    "terrorismens": "terrorism",
    "terrorismer": "terrorism",
    "terrorismerna": "terrorism",
    "terrorismernas": "terrorism",
    "terrorismers": "terrorism",
    "terrorisms": "terrorism",
    "terroristattacken": "terroristattack",
    "terroristattackens": "terroristattack",
    "terroristattacker": "terroristattack",
    "terroristattackerna": "terroristattack",
    "terroristattackernas": "terroristattack",
    "terroristattackers": "terroristattack",
    "terroristattacks": "terroristattack",
    "terroristen": "terrorist",
    "terroristens": "terrorist",
    "terrorister": "terrorist",
    "terroristerna": "terrorist",
    "terroristernas": "terrorist",
    "terroristers": "terrorist",
    "terroristiska": "terroristisk",
    "terroristiskas": "terroristisk",
    "terroristiske": "terroristisk",
    "terroristiskes": "terroristisk",
    "terroristisks": "terroristisk",
    "terroristiskt": "terroristisk",
    "terroristiskts": "terroristisk",
    "terroristlagstiftningar": "terroristlagstiftning",
    "terroristlagstiftningarna": "terroristlagstiftning",
    "terroristlagstiftningarnas": "terroristlagstiftning",
    "terroristlagstiftningars": "terroristlagstiftning",
    "terroristlagstiftningen": "terroristlagstiftning",
    "terroristlagstiftningens": "terroristlagstiftning",
    "terroristlagstiftnings": "terroristlagstiftning",
    "terroristledar": "terroristledare",
    "terroristledaren": "terroristledare",
    "terroristledarens": "terroristledare",
    "terroristledares": "terroristledare",
    "terroristledarna": "terroristledare",
    "terroristledarnas": "terroristledare",
    "terrorists": "terrorist",
    "terrormisstänkta": "terrormisstänkt",
    "terrormisstänktas": "terrormisstänkt",
    "terrormisstänkte": "terrormisstänkt",
    "terrormisstänktes": "terrormisstänkt",
    "terrormisstänkts": "terrormisstänkt",
    "terrorn": "terror",
    "terrorns": "terror",
    "terrornätverken": "terrornätverk",
    "terrornätverkens": "terrornätverk",
    "terrornätverket": "terrornätverk",
    "terrornätverkets": "terrornätverk",
    "terrornätverks": "terrornätverk",
    "terrors": "terror",
    "terrorvarningar": "terrorvarning",
    "terrorvarningarna": "terrorvarning",
    "terrorvarningarnas": "terrorvarning",
    "terrorvarningars": "terrorvarning",
    "terrorvarningen": "terrorvarning",
    "terrorvarningens": "terrorvarning",
    "terrorvarnings": "terrorvarning",
    "terrängbanan": "terrängbana",
    "terrängbanans": "terrängbana",
    "terrängbanas": "terrängbana",
    "terrängbane": "terrängbana",
    "terrängbanor": "terrängbana",
    "terrängbanorna": "terrängbana",
    "terrängbanornas": "terrängbana",
    "terrängbanors": "terrängbana",
    "terrängbilar": "terrängbil",
    "terrängbilarna": "terrängbil",
    "terrängbilarnas": "terrängbil",
    "terrängbilars": "terrängbil",
    "terrängbilen": "terrängbil",
    "terrängbilens": "terrängbil",
    "terrängbils": "terrängbil",
    "terrängen": "terräng",
    "terrängens": "terräng",
    "terränger": "terräng",
    "terrängerna": "terräng",
    "terrängernas": "terräng",
    "terrängers": "terräng",
    "terrängförlusten": "terrängförlust",
    "terrängförlustens": "terrängförlust",
    "terrängförluster": "terrängförlust",
    "terrängförlusterna": "terrängförlust",
    "terrängförlusternas": "terrängförlust",
    "terrängförlusters": "terrängförlust",
    "terrängförlusts": "terrängförlust",
    "terrängkörningar": "terrängkörning",
    "terrängkörningarna": "terrängkörning",
    "terrängkörningarnas": "terrängkörning",
    "terrängkörningars": "terrängkörning",
    "terrängkörningen": "terrängkörning",
    "terrängkörningens": "terrängkörning",
    "terrängkörnings": "terrängkörning",
    "terränglöpningar": "terränglöpning",
    "terränglöpningarna": "terränglöpning",
    "terränglöpningarnas": "terränglöpning",
    "terränglöpningars": "terränglöpning",
    "terränglöpningen": "terränglöpning",
    "terränglöpningens": "terränglöpning",
    "terränglöpnings": "terränglöpning",
    "terrängnamnen": "terrängnamn",
    "terrängnamnens": "terrängnamn",
    "terrängnamnet": "terrängnamn",
    "terrängnamnets": "terrängnamn",
    "terrängnamns": "terrängnamn",
    "terrängs": "terräng",
    "terrängscootern": "terrängscooter",
    "terrängscooterns": "terrängscooter",
    "terrängscooters": "terrängscooter",
    "terrängscootrar": "terrängscooter",
    "terrängscootrarna": "terrängscooter",
    "terrängscootrarnas": "terrängscooter",
    "terrängscootrars": "terrängscooter",
    "terrängskotern": "terrängskoter",
    "terrängskoterns": "terrängskoter",
    "terrängskoters": "terrängskoter",
    "terrängskotrar": "terrängskoter",
    "terrängskotrarna": "terrängskoter",
    "terrängskotrarnas": "terrängskoter",
    "terrängskotrars": "terrängskoter",
    "terrängvinkeln": "terrängvinkel",
    "terrängvinkelns": "terrängvinkel",
    "terrängvinkels": "terrängvinkel",
    "terrängvinklar": "terrängvinkel",
    "terrängvinklarna": "terrängvinkel",
    "terrängvinklarnas": "terrängvinkel",
    "terrängvinklars": "terrängvinkel",
    "terrängvinsten": "terrängvinst",
    "terrängvinstens": "terrängvinst",
    "terrängvinster": "terrängvinst",
    "terrängvinsterna": "terrängvinst",
    "terrängvinsternas": "terrängvinst",
    "terrängvinsters": "terrängvinst",
    "terrängvinsts": "terrängvinst",
    "tersen": "ters",
    "tersens": "ters",
    "terser": "ters",
    "terserna": "ters",
    "tersernas": "ters",
    "tersers": "ters",
    "tersetten": "tersett",
    "tersettens": "tersett",
    "tersetter": "tersett",
    "tersetterna": "tersett",
    "tersetternas": "tersett",
    "tersetters": "tersett",
    "tersetts": "tersett",
    "tertiära": "tertiär",
    "tertiärare": "tertiär",
    "tertiärares": "tertiär",
    "tertiäras": "tertiär",
    "tertiärast": "tertiär",
    "tertiäraste": "tertiär",
    "tertiärastes": "tertiär",
    "tertiärasts": "tertiär",
    "tertiäre": "tertiär",
    "tertiäres": "tertiär",
    "tertiärperioden": "tertiärperiod",
    "tertiärperiodens": "tertiärperiod",
    "tertiärperiods": "tertiärperiod",
    "tertiärs": "tertiär",
    "tertiärsystemet": "tertiärsystem",
    "tertiärsystemets": "tertiärsystem",
    "tertiärsystems": "tertiärsystem",
    "tertiärt": "tertiär",
    "tertiärtiden": "tertiärtid",
    "tertiärtidens": "tertiärtid",
    "tertiärtids": "tertiärtid",
    "tertiärts": "tertiär",
    "terylenen": "terylen",
    "terylenens": "terylen",
    "terylenet": "terylen",
    "terylenets": "terylen",
    "terylens": "terylen",
    "terzetten": "terzett",
    "terzettens": "terzett",
    "terzetter": "terzett",
    "terzetterna": "terzett",
    "terzetternas": "terzett",
    "terzetters": "terzett",
    "terzetts": "terzett",
    "terzinen": "terzin",
    "terzinens": "terzin",
    "terziner": "terzin",
    "terzinerna": "terzin",
    "terzinernas": "terzin",
    "terziners": "terzin",
    "terzins": "terzin",
    "tes": "te",
    "tesaurerad": "tesaurera",
    "tesaurerade": "tesaurera",
    "tesaurerades": "tesaurera",
    "tesaurerads": "tesaurera",
    "tesaurerande": "tesaurera",
    "tesaureranden": "tesaurerande",
    "tesaurerandena": "tesaurerande",
    "tesaurerandenas": "tesaurerande",
    "tesaurerandens": "tesaurerande",
    "tesaurerandes": "tesaurerande",
    "tesaurerandet": "tesaurerande",
    "tesaurerandets": "tesaurerande",
    "tesaurerar": "tesaurera",
    "tesaureras": "tesaurera",
    "tesaurerat": "tesaurera",
    "tesaurerats": "tesaurera",
    "tesaurerbara": "tesaurerbar",
    "tesaurerbarare": "tesaurerbar",
    "tesaurerbarares": "tesaurerbar",
    "tesaurerbaras": "tesaurerbar",
    "tesaurerbarast": "tesaurerbar",
    "tesaurerbaraste": "tesaurerbar",
    "tesaurerbarastes": "tesaurerbar",
    "tesaurerbarasts": "tesaurerbar",
    "tesaurerbare": "tesaurerbar",
    "tesaurerbares": "tesaurerbar",
    "tesaurerbarheten": "tesaurerbarhet",
    "tesaurerbarhetens": "tesaurerbarhet",
    "tesaurerbarhets": "tesaurerbarhet",
    "tesaurerbars": "tesaurerbar",
    "tesaurerbart": "tesaurerbar",
    "tesaurerbarts": "tesaurerbar",
    "tesaureringar": "tesaurering",
    "tesaureringarna": "tesaurering",
    "tesaureringarnas": "tesaurering",
    "tesaureringars": "tesaurering",
    "tesaureringen": "tesaurering",
    "tesaureringens": "tesaurering",
    "tesaurerings": "tesaurering",
    "tesaurusar": "tesaurus",
    "tesaurusarna": "tesaurus",
    "tesaurusarnas": "tesaurus",
    "tesaurusars": "tesaurus",
    "tesaurusen": "tesaurus",
    "tesaurusens": "tesaurus",
    "tesen": "tes",
    "tesens": "tes",
    "teser": "tes",
    "teserna": "tes",
    "tesernas": "tes",
    "tesers": "tes",
    "teskedar": "tesked",
    "teskedarna": "tesked",
    "teskedarnas": "tesked",
    "teskedars": "tesked",
    "teskeden": "tesked",
    "teskedens": "tesked",
    "teskeds": "tesked",
    "teslan": "tesla",
    "teslana": "tesla",
    "teslanas": "tesla",
    "teslans": "tesla",
    "teslas": "tesla",
    "teslaströmmar": "teslaström",
    "teslaströmmarna": "teslaström",
    "teslaströmmarnas": "teslaström",
    "teslaströmmars": "teslaström",
    "teslaströmmen": "teslaström",
    "teslaströmmens": "teslaström",
    "teslaströms": "teslaström",
    "tespiskärran": "tespiskärra",
    "tespiskärrans": "tespiskärra",
    "tespiskärras": "tespiskärra",
    "test": "testa",
    "testabels": "testabel",
    "testabelt": "testabel",
    "testabelts": "testabel",
    "testabla": "testabel",
    "testablare": "testabel",
    "testablares": "testabel",
    "testablas": "testabel",
    "testablast": "testabel",
    "testablaste": "testabel",
    "testablastes": "testabel",
    "testablasts": "testabel",
    "testable": "testabel",
    "testables": "testabel",
    "testad": "testa",
    "testade": "testa",
    "testades": "testa",
    "testads": "testa",
    "testamentariska": "testamentarisk",
    "testamentariskare": "testamentarisk",
    "testamentariskares": "testamentarisk",
    "testamentariskas": "testamentarisk",
    "testamentariskast": "testamentarisk",
    "testamentariskaste": "testamentarisk",
    "testamentariskastes": "testamentarisk",
    "testamentariskasts": "testamentarisk",
    "testamentariske": "testamentarisk",
    "testamentariskes": "testamentarisk",
    "testamentarisks": "testamentarisk",
    "testamentariskt": "testamentarisk",
    "testamentariskts": "testamentarisk",
    "testamenten": "testamente",
    "testamentena": "testamente",
    "testamentenas": "testamente",
    "testamentens": "testamente",
    "testamenterad": "testamentera",
    "testamenterade": "testamentera",
    "testamenterades": "testamentera",
    "testamenterads": "testamentera",
    "testamenterande": "testamentera",
    "testamenteranden": "testamenterande",
    "testamenterandena": "testamenterande",
    "testamenterandenas": "testamenterande",
    "testamenterandens": "testamenterande",
    "testamenterandes": "testamenterande",
    "testamenterandet": "testamenterande",
    "testamenterandets": "testamenterande",
    "testamenterar": "testamentera",
    "testamenteras": "testamentera",
    "testamenterat": "testamentera",
    "testamenterats": "testamentera",
    "testamenterbara": "testamenterbar",
    "testamenterbarare": "testamenterbar",
    "testamenterbarares": "testamenterbar",
    "testamenterbaras": "testamenterbar",
    "testamenterbarast": "testamenterbar",
    "testamenterbaraste": "testamenterbar",
    "testamenterbarastes": "testamenterbar",
    "testamenterbarasts": "testamenterbar",
    "testamenterbare": "testamenterbar",
    "testamenterbares": "testamenterbar",
    "testamenterbarheten": "testamenterbarhet",
    "testamenterbarhetens": "testamenterbarhet",
    "testamenterbarhets": "testamenterbarhet",
    "testamenterbars": "testamenterbar",
    "testamenterbart": "testamenterbar",
    "testamenterbarts": "testamenterbar",
    "testamenteringar": "testamentering",
    "testamenteringarna": "testamentering",
    "testamenteringarnas": "testamentering",
    "testamenteringars": "testamentering",
    "testamenteringen": "testamentering",
    "testamenteringens": "testamentering",
    "testamenterings": "testamentering",
    "testamentes": "testamente",
    "testamentet": "testamente",
    "testamentets": "testamente",
    "testaments": "testamente",
    "testamentsexekutorer": "testamentsexekutor",
    "testamentsexekutorerna": "testamentsexekutor",
    "testamentsexekutorernas": "testamentsexekutor",
    "testamentsexekutorers": "testamentsexekutor",
    "testamentsexekutorn": "testamentsexekutor",
    "testamentsexekutorns": "testamentsexekutor",
    "testamentsexekutors": "testamentsexekutor",
    "testande": "testa",
    "testanden": "testande",
    "testandena": "testande",
    "testandenas": "testande",
    "testandens": "testande",
    "testandes": "testande",
    "testandet": "testande",
    "testandets": "testande",
    "testar": "testa",
    "testarna": "test",
    "testarnas": "test",
    "testars": "test",
    "testas": "testa",
    "testat": "testa",
    "testatorer": "testator",
    "testatorerna": "testator",
    "testatorernas": "testator",
    "testatorers": "testator",
    "testatorn": "testator",
    "testatorns": "testator",
    "testators": "testator",
    "testats": "testa",
    "testbatterier": "testbatteri",
    "testbatterierna": "testbatteri",
    "testbatteriernas": "testbatteri",
    "testbatteriers": "testbatteri",
    "testbatteriet": "testbatteri",
    "testbatteriets": "testbatteri",
    "testbatteris": "testbatteri",
    "testbatterit": "testbatteri",
    "testbatterits": "testbatteri",
    "testbilden": "testbild",
    "testbildens": "testbild",
    "testbilder": "testbild",
    "testbilderna": "testbild",
    "testbildernas": "testbild",
    "testbilders": "testbild",
    "testbilds": "testbild",
    "testcykeln": "testcykel",
    "testcykelns": "testcykel",
    "testcykels": "testcykel",
    "testcyklar": "testcykel",
    "testcyklarna": "testcykel",
    "testcyklarnas": "testcykel",
    "testcyklars": "testcykel",
    "testen": "test",
    "testens": "test",
    "tester": "test",
    "testerna": "test",
    "testernas": "test",
    "testers": "test",
    "testet": "test",
    "testets": "test",
    "testiga": "testig",
    "testigare": "testig",
    "testigares": "testig",
    "testigas": "testig",
    "testigast": "testig",
    "testigaste": "testig",
    "testigastes": "testig",
    "testigasts": "testig",
    "testige": "testig",
    "testiges": "testig",
    "testigheten": "testighet",
    "testighetens": "testighet",
    "testighets": "testighet",
    "testigs": "testig",
    "testigt": "testig",
    "testigts": "testig",
    "testikeln": "testikel",
    "testikelns": "testikel",
    "testikels": "testikel",
    "testiklar": "testikel",
    "testiklarna": "testikel",
    "testiklarnas": "testikel",
    "testiklars": "testikel",
    "testimonie": "testimonium",
    "testimonier": "testimonium",
    "testimonierna": "testimonium",
    "testimoniernas": "testimonium",
    "testimoniers": "testimonium",
    "testimoniet": "testimonium",
    "testimoniets": "testimonium",
    "testimoniums": "testimonium",
    "testkör": "testköra",
    "testkörande": "testköra",
    "testkörandes": "testköra",
    "testköras": "testköra",
    "testkörd": "testköra",
    "testkörda": "testköra",
    "testkördas": "testköra",
    "testkörde": "testköra",
    "testkördes": "testköra",
    "testkörds": "testköra",
    "testköres": "testköra",
    "testkörs": "testköra",
    "testkört": "testköra",
    "testkörts": "testköra",
    "testosteronet": "testosteron",
    "testosteronets": "testosteron",
    "testosteronpumpade": "testosteronpumpad",
    "testosteronpumpades": "testosteronpumpad",
    "testosteronpumpads": "testosteronpumpad",
    "testosteronpumpat": "testosteronpumpad",
    "testosteronpumpats": "testosteronpumpad",
    "testosterons": "testosteron",
    "testpiloten": "testpilot",
    "testpilotens": "testpilot",
    "testpiloter": "testpilot",
    "testpiloterna": "testpilot",
    "testpiloternas": "testpilot",
    "testpiloters": "testpilot",
    "testpilots": "testpilot",
    "testreaktorer": "testreaktor",
    "testreaktorerna": "testreaktor",
    "testreaktorernas": "testreaktor",
    "testreaktorers": "testreaktor",
    "testreaktorn": "testreaktor",
    "testreaktorns": "testreaktor",
    "testreaktors": "testreaktor",
    "tests": "test",
    "testuggar": "testuggare",
    "testuggaren": "testuggare",
    "testuggarens": "testuggare",
    "testuggares": "testuggare",
    "testuggarna": "testuggare",
    "testuggarnas": "testuggare",
    "testvärden": "testvärde",
    "testvärdena": "testvärde",
    "testvärdenas": "testvärde",
    "testvärdens": "testvärde",
    "testvärdes": "testvärde",
    "testvärdet": "testvärde",
    "testvärdets": "testvärde",
    "tet": "te",
    "tetades": "tetas",
    "tetanien": "tetani",
    "tetaniens": "tetani",
    "tetanin": "tetani",
    "tetanins": "tetani",
    "tetanis": "tetani",
    "tetanusen": "tetanus",
    "tetanusens": "tetanus",
    "tetats": "tetas",
    "tetiga": "tetig",
    "tetigare": "tetig",
    "tetigares": "tetig",
    "tetigas": "tetig",
    "tetigast": "tetig",
    "tetigaste": "tetig",
    "tetigastes": "tetig",
    "tetigasts": "tetig",
    "tetige": "tetig",
    "tetiges": "tetig",
    "tetigs": "tetig",
    "tetigt": "tetig",
    "tetigts": "tetig",
    "tetraedern": "tetraeder",
    "tetraederns": "tetraeder",
    "tetraeders": "tetraeder",
    "tetraedrar": "tetraeder",
    "tetraedrarna": "tetraeder",
    "tetraedrarnas": "tetraeder",
    "tetraedrars": "tetraeder",
    "tetraetylblyet": "tetraetylbly",
    "tetraetylblyets": "tetraetylbly",
    "tetraetylblys": "tetraetylbly",
    "tetraetylblyt": "tetraetylbly",
    "tetraetylblyts": "tetraetylbly",
    "tetragonen": "tetragon",
    "tetragonens": "tetragon",
    "tetragoner": "tetragon",
    "tetragonerna": "tetragon",
    "tetragonernas": "tetragon",
    "tetragoners": "tetragon",
    "tetragons": "tetragon",
    "tetrakloriden": "tetraklorid",
    "tetrakloridens": "tetraklorid",
    "tetraklorider": "tetraklorid",
    "tetrakloriderna": "tetraklorid",
    "tetrakloridernas": "tetraklorid",
    "tetrakloriders": "tetraklorid",
    "tetraklorids": "tetraklorid",
    "tetran": "tetra",
    "tetrans": "tetra",
    "tetrapaken": "tetrapak",
    "tetrapakens": "tetrapak",
    "tetrapaket": "tetrapak",
    "tetrapakets": "tetrapak",
    "tetrapaks": "tetrapak",
    "tetraploida": "tetraploid",
    "tetraploidare": "tetraploid",
    "tetraploidares": "tetraploid",
    "tetraploidas": "tetraploid",
    "tetraploidast": "tetraploid",
    "tetraploidaste": "tetraploid",
    "tetraploidastes": "tetraploid",
    "tetraploidasts": "tetraploid",
    "tetraploide": "tetraploid",
    "tetraploides": "tetraploid",
    "tetraploids": "tetraploid",
    "tetrarken": "tetrark",
    "tetrarkens": "tetrark",
    "tetrarker": "tetrark",
    "tetrarkerna": "tetrark",
    "tetrarkernas": "tetrark",
    "tetrarkers": "tetrark",
    "tetrarks": "tetrark",
    "tetras": "tetra",
    "tetror": "tetra",
    "tetrorna": "tetra",
    "tetrornas": "tetra",
    "tetrors": "tetra",
    "tets": "te",
    "teutonen": "teuton",
    "teutonens": "teuton",
    "teutoner": "teuton",
    "teutonerna": "teuton",
    "teutonernas": "teuton",
    "teutoners": "teuton",
    "teutons": "teuton",
    "tevagnar": "tevagn",
    "tevagnarna": "tevagn",
    "tevagnarnas": "tevagn",
    "tevagnars": "tevagn",
    "tevagnen": "tevagn",
    "tevagnens": "tevagn",
    "tevagns": "tevagn",
    "tevattens": "tevatten",
    "tevattnet": "tevatten",
    "tevattnets": "tevatten",
    "teve-evangelisten": "teve-evangelist",
    "teve-evangelistens": "teve-evangelist",
    "teve-evangelister": "teve-evangelist",
    "teve-evangelisterna": "teve-evangelist",
    "teve-evangelisternas": "teve-evangelist",
    "teve-evangelisters": "teve-evangelist",
    "teve-evangelists": "teve-evangelist",
    "teveabonnemangen": "teveabonnemang",
    "teveabonnemangens": "teveabonnemang",
    "teveabonnemanget": "teveabonnemang",
    "teveabonnemangets": "teveabonnemang",
    "teveabonnemangs": "teveabonnemang",
    "teveantennen": "teveantenn",
    "teveantennens": "teveantenn",
    "teveantenner": "teveantenn",
    "teveantennerna": "teveantenn",
    "teveantennernas": "teveantenn",
    "teveantenners": "teveantenn",
    "teveantenns": "teveantenn",
    "teveapparaten": "teveapparat",
    "teveapparatens": "teveapparat",
    "teveapparater": "teveapparat",
    "teveapparaterna": "teveapparat",
    "teveapparaternas": "teveapparat",
    "teveapparaters": "teveapparat",
    "teveapparats": "teveapparat",
    "tevear": "teve",
    "tevearna": "teve",
    "tevearnas": "teve",
    "tevears": "teve",
    "tevebilden": "tevebild",
    "tevebildens": "tevebild",
    "tevebilder": "tevebild",
    "tevebilderna": "tevebild",
    "tevebildernas": "tevebild",
    "tevebilders": "tevebild",
    "tevebilds": "tevebild",
    "tevechefen": "tevechef",
    "tevechefens": "tevechef",
    "tevechefer": "tevechef",
    "tevecheferna": "tevechef",
    "tevechefernas": "tevechef",
    "tevechefers": "tevechef",
    "tevechefs": "tevechef",
    "teveevangelisten": "teveevangelist",
    "teveevangelistens": "teveevangelist",
    "teveevangelister": "teveevangelist",
    "teveevangelisterna": "teveevangelist",
    "teveevangelisternas": "teveevangelist",
    "teveevangelisters": "teveevangelist",
    "teveevangelists": "teveevangelist",
    "teveintervjuer": "teveintervju",
    "teveintervjuerna": "teveintervju",
    "teveintervjuernas": "teveintervju",
    "teveintervjuers": "teveintervju",
    "teveintervjun": "teveintervju",
    "teveintervjuns": "teveintervju",
    "teveintervjus": "teveintervju",
    "tevekameran": "tevekamera",
    "tevekamerans": "tevekamera",
    "tevekameras": "tevekamera",
    "tevekameror": "tevekamera",
    "tevekamerorna": "tevekamera",
    "tevekamerornas": "tevekamera",
    "tevekamerors": "tevekamera",
    "tevekanalen": "tevekanal",
    "tevekanalens": "tevekanal",
    "tevekanaler": "tevekanal",
    "tevekanalerna": "tevekanal",
    "tevekanalernas": "tevekanal",
    "tevekanalers": "tevekanal",
    "tevekanals": "tevekanal",
    "tevekonferensen": "tevekonferens",
    "tevekonferensens": "tevekonferens",
    "tevekonferenser": "tevekonferens",
    "tevekonferenserna": "tevekonferens",
    "tevekonferensernas": "tevekonferens",
    "tevekonferensers": "tevekonferens",
    "tevemottagar": "tevemottagare",
    "tevemottagaren": "tevemottagare",
    "tevemottagarens": "tevemottagare",
    "tevemottagares": "tevemottagare",
    "tevemottagarna": "tevemottagare",
    "tevemottagarnas": "tevemottagare",
    "teven": "teve",
    "tevena": "teve",
    "tevenas": "teve",
    "tevens": "teve",
    "tevenyheten": "tevenyhet",
    "tevenyhetens": "tevenyhet",
    "tevenyheter": "tevenyhet",
    "tevenyheterna": "tevenyhet",
    "tevenyheternas": "tevenyhet",
    "tevenyheters": "tevenyhet",
    "tevenyhets": "tevenyhet",
    "tevepredikanten": "tevepredikant",
    "tevepredikantens": "tevepredikant",
    "tevepredikanter": "tevepredikant",
    "tevepredikanterna": "tevepredikant",
    "tevepredikanternas": "tevepredikant",
    "tevepredikanters": "tevepredikant",
    "tevepredikants": "tevepredikant",
    "teveproducenten": "teveproducent",
    "teveproducentens": "teveproducent",
    "teveproducenter": "teveproducent",
    "teveproducenterna": "teveproducent",
    "teveproducenternas": "teveproducent",
    "teveproducenters": "teveproducent",
    "teveproducents": "teveproducent",
    "teveprofilen": "teveprofil",
    "teveprofilens": "teveprofil",
    "teveprofiler": "teveprofil",
    "teveprofilerna": "teveprofil",
    "teveprofilernas": "teveprofil",
    "teveprofilers": "teveprofil",
    "teveprofils": "teveprofil",
    "teveprogrammen": "teveprogram",
    "teveprogrammens": "teveprogram",
    "teveprogrammet": "teveprogram",
    "teveprogrammets": "teveprogram",
    "teveprograms": "teveprogram",
    "tevereparatören": "tevereparatör",
    "tevereparatörens": "tevereparatör",
    "tevereparatörer": "tevereparatör",
    "tevereparatörerna": "tevereparatör",
    "tevereparatörernas": "tevereparatör",
    "tevereparatörers": "tevereparatör",
    "tevereparatörs": "tevereparatör",
    "teveronik": "teveronika",
    "teveronikan": "teveronika",
    "teveronikans": "teveronika",
    "teveronikas": "teveronika",
    "teveronike": "teveronika",
    "teveronikor": "teveronika",
    "teveronikorna": "teveronika",
    "teveronikornas": "teveronika",
    "teveronikors": "teveronika",
    "teveroniks": "teveronika",
    "teverutan": "teveruta",
    "teverutans": "teveruta",
    "teverutas": "teveruta",
    "teverute": "teveruta",
    "teverutor": "teveruta",
    "teverutorna": "teveruta",
    "teverutornas": "teveruta",
    "teverutors": "teveruta",
    "teves": "teve",
    "teveserien": "teveserie",
    "teveseriens": "teveserie",
    "teveserier": "teveserie",
    "teveserierna": "teveserie",
    "teveseriernas": "teveserie",
    "teveseriers": "teveserie",
    "teveseries": "teveserie",
    "tevesignalen": "tevesignal",
    "tevesignalens": "tevesignal",
    "tevesignaler": "tevesignal",
    "tevesignalerna": "tevesignal",
    "tevesignalernas": "tevesignal",
    "tevesignalers": "tevesignal",
    "tevesignals": "tevesignal",
    "teveskärmar": "teveskärm",
    "teveskärmarna": "teveskärm",
    "teveskärmarnas": "teveskärm",
    "teveskärmars": "teveskärm",
    "teveskärmen": "teveskärm",
    "teveskärmens": "teveskärm",
    "teveskärms": "teveskärm",
    "tevesoff": "tevesoffa",
    "tevesoffan": "tevesoffa",
    "tevesoffans": "tevesoffa",
    "tevesoffas": "tevesoffa",
    "tevesoffe": "tevesoffa",
    "tevesoffor": "tevesoffa",
    "tevesofforna": "tevesoffa",
    "tevesoffornas": "tevesoffa",
    "tevesoffors": "tevesoffa",
    "tevesoffs": "tevesoffa",
    "tevestudion": "tevestudio",
    "tevestudions": "tevestudio",
    "tevestudior": "tevestudio",
    "tevestudiorna": "tevestudio",
    "tevestudiornas": "tevestudio",
    "tevestudiors": "tevestudio",
    "tevestudios": "tevestudio",
    "tevesändar": "tevesändare",
    "tevesändaren": "tevesändare",
    "tevesändarens": "tevesändare",
    "tevesändares": "tevesändare",
    "tevesändarna": "tevesändare",
    "tevesändarnas": "tevesändare",
    "tevesändningar": "tevesändning",
    "tevesändningarna": "tevesändning",
    "tevesändningarnas": "tevesändning",
    "tevesändningars": "tevesändning",
    "tevesändningen": "tevesändning",
    "tevesändningens": "tevesändning",
    "tevesändnings": "tevesändning",
    "tevetittanden": "tevetittande",
    "tevetittandena": "tevetittande",
    "tevetittandenas": "tevetittande",
    "tevetittandens": "tevetittande",
    "tevetittandes": "tevetittande",
    "tevetittandet": "tevetittande",
    "tevetittandets": "tevetittande",
    "tevetittar": "tevetittare",
    "tevetittaren": "tevetittare",
    "tevetittarens": "tevetittare",
    "tevetittares": "tevetittare",
    "tevetittarna": "tevetittare",
    "tevetittarnas": "tevetittare",
    "teveövervakningar": "teveövervakning",
    "teveövervakningarna": "teveövervakning",
    "teveövervakningarnas": "teveövervakning",
    "teveövervakningars": "teveövervakning",
    "teveövervakningen": "teveövervakning",
    "teveövervakningens": "teveövervakning",
    "teveövervaknings": "teveövervakning",
    "text": "texta",
    "text-TV-n": "text-TV",
    "text-TV-na": "text-TV",
    "text-TV-nas": "text-TV",
    "text-TV-ns": "text-TV",
    "text-TV-s": "text-TV",
    "text-TV:n": "text-TV",
    "text-TV:na": "text-TV",
    "text-TV:nas": "text-TV",
    "text-TV:ns": "text-TV",
    "text-TV:s": "text-TV",
    "text-TVn": "text-TV",
    "text-TVna": "text-TV",
    "text-TVnas": "text-TV",
    "text-TVns": "text-TV",
    "text-TVs": "text-TV",
    "textad": "texta",
    "textade": "texta",
    "textades": "texta",
    "textads": "texta",
    "textande": "texta",
    "textanden": "textande",
    "textandena": "textande",
    "textandenas": "textande",
    "textandens": "textande",
    "textandes": "textande",
    "textandet": "textande",
    "textandets": "textande",
    "textar": "texta",
    "textarkiven": "textarkiv",
    "textarkivens": "textarkiv",
    "textarkivet": "textarkiv",
    "textarkivets": "textarkiv",
    "textarkivs": "textarkiv",
    "textas": "texta",
    "textat": "texta",
    "textats": "texta",
    "textbearbetningar": "textbearbetning",
    "textbearbetningarna": "textbearbetning",
    "textbearbetningarnas": "textbearbetning",
    "textbearbetningars": "textbearbetning",
    "textbearbetningen": "textbearbetning",
    "textbearbetningens": "textbearbetning",
    "textbearbetnings": "textbearbetning",
    "textbehandlingar": "textbehandling",
    "textbehandlingarna": "textbehandling",
    "textbehandlingarnas": "textbehandling",
    "textbehandlingars": "textbehandling",
    "textbehandlingen": "textbehandling",
    "textbehandlingens": "textbehandling",
    "textbehandlings": "textbehandling",
    "textboken": "textbok",
    "textbokens": "textbok",
    "textboks": "textbok",
    "textböcker": "textbok",
    "textböckerna": "textbok",
    "textböckernas": "textbok",
    "textböckers": "textbok",
    "texten": "text",
    "textens": "text",
    "texter": "text",
    "texterna": "text",
    "texternas": "text",
    "texters": "text",
    "textila": "textil",
    "textilarbetar": "textilarbetare",
    "textilarbetaren": "textilarbetare",
    "textilarbetarens": "textilarbetare",
    "textilarbetares": "textilarbetare",
    "textilarbetarna": "textilarbetare",
    "textilarbetarnas": "textilarbetare",
    "textilare": "textil",
    "textilares": "textil",
    "textilas": "textil",
    "textilast": "textil",
    "textilaste": "textil",
    "textilastes": "textil",
    "textilasts": "textil",
    "textile": "textil",
    "textilen": "textil",
    "textilens": "textil",
    "textiler": "textil",
    "textilerna": "textil",
    "textilernas": "textil",
    "textilers": "textil",
    "textiles": "textil",
    "textilfabriken": "textilfabrik",
    "textilfabrikens": "textilfabrik",
    "textilfabriker": "textilfabrik",
    "textilfabrikerna": "textilfabrik",
    "textilfabrikernas": "textilfabrik",
    "textilfabrikers": "textilfabrik",
    "textilfabriks": "textilfabrik",
    "textilfibern": "textilfiber",
    "textilfiberns": "textilfiber",
    "textilfibers": "textilfiber",
    "textilfibrer": "textilfiber",
    "textilfibrerna": "textilfiber",
    "textilfibrernas": "textilfiber",
    "textilfibrers": "textilfiber",
    "textilie": "textilier",
    "textilierna": "textilier",
    "textiliernas": "textilier",
    "textiliers": "textilier",
    "textilindustrien": "textilindustri",
    "textilindustriens": "textilindustri",
    "textilindustrier": "textilindustri",
    "textilindustrierna": "textilindustri",
    "textilindustriernas": "textilindustri",
    "textilindustriers": "textilindustri",
    "textilindustrin": "textilindustri",
    "textilindustrins": "textilindustri",
    "textilindustris": "textilindustri",
    "textilkonsten": "textilkonst",
    "textilkonstens": "textilkonst",
    "textilkonsts": "textilkonst",
    "textilkursen": "textilkurs",
    "textilkursens": "textilkurs",
    "textilkurser": "textilkurs",
    "textilkurserna": "textilkurs",
    "textilkursernas": "textilkurs",
    "textilkursers": "textilkurs",
    "textillärar": "textillärare",
    "textilläraren": "textillärare",
    "textillärarens": "textillärare",
    "textillärares": "textillärare",
    "textillärarna": "textillärare",
    "textillärarnas": "textillärare",
    "textils": "textil",
    "textilslöjden": "textilslöjd",
    "textilslöjdens": "textilslöjd",
    "textilslöjds": "textilslöjd",
    "textilspillet": "textilspill",
    "textilspillets": "textilspill",
    "textilspills": "textilspill",
    "textilt": "textil",
    "textilts": "textil",
    "textkritiken": "textkritik",
    "textkritikens": "textkritik",
    "textkritiks": "textkritik",
    "textmässiga": "textmässig",
    "textmässigare": "textmässig",
    "textmässigares": "textmässig",
    "textmässigas": "textmässig",
    "textmässigast": "textmässig",
    "textmässigaste": "textmässig",
    "textmässigastes": "textmässig",
    "textmässigasts": "textmässig",
    "textmässige": "textmässig",
    "textmässiges": "textmässig",
    "textmässigs": "textmässig",
    "textmässigt": "textmässig",
    "textmässigts": "textmässig",
    "textraden": "textrad",
    "textradens": "textrad",
    "textrader": "textrad",
    "textraderna": "textrad",
    "textradernas": "textrad",
    "textraders": "textrad",
    "textrads": "textrad",
    "textreklamen": "textreklam",
    "textreklamens": "textreklam",
    "textreklams": "textreklam",
    "texts": "text",
    "textskärmar": "textskärm",
    "textskärmarna": "textskärm",
    "textskärmarnas": "textskärm",
    "textskärmars": "textskärm",
    "textskärmen": "textskärm",
    "textskärmens": "textskärm",
    "textskärms": "textskärm",
    "textstycken": "textstycke",
    "textstyckena": "textstycke",
    "textstyckenas": "textstycke",
    "textstyckens": "textstycke",
    "textstyckes": "textstycke",
    "textstycket": "textstycke",
    "textstyckets": "textstycke",
    "textstycks": "textstycke",
    "texttolkningar": "texttolkning",
    "texttolkningarna": "texttolkning",
    "texttolkningarnas": "texttolkning",
    "texttolkningars": "texttolkning",
    "texttolkningen": "texttolkning",
    "texttolkningens": "texttolkning",
    "texttolknings": "texttolkning",
    "texturen": "textur",
    "texturens": "textur",
    "texturer": "textur",
    "texturerna": "textur",
    "texturernas": "textur",
    "texturers": "textur",
    "texturs": "textur",
    "textytan": "textyta",
    "textytans": "textyta",
    "textytas": "textyta",
    "textyte": "textyta",
    "textytor": "textyta",
    "textytorna": "textyta",
    "textytornas": "textyta",
    "textytors": "textyta",
    "teärenprisen": "teärenpris",
    "teärenprisens": "teärenpris",
    "thailändar": "thailändare",
    "thailändaren": "thailändare",
    "thailändarens": "thailändare",
    "thailändares": "thailändare",
    "thailändarna": "thailändare",
    "thailändarnas": "thailändare",
    "thailändska": "thailändsk",
    "thailändskan": "thailändska",
    "thailändskans": "thailändska",
    "thailändskare": "thailändsk",
    "thailändskares": "thailändsk",
    "thailändskas": "thailändska",
    "thailändskast": "thailändsk",
    "thailändskaste": "thailändsk",
    "thailändskastes": "thailändsk",
    "thailändskasts": "thailändsk",
    "thailändske": "thailändska",
    "thailändskes": "thailändsk",
    "thailändskor": "thailändska",
    "thailändskorna": "thailändska",
    "thailändskornas": "thailändska",
    "thailändskors": "thailändska",
    "thailändsks": "thailändsk",
    "thailändskt": "thailändsk",
    "thailändskts": "thailändsk",
    "thaimaten": "thaimat",
    "thaimatens": "thaimat",
    "thaimats": "thaimat",
    "thairestaurangen": "thairestaurang",
    "thairestaurangens": "thairestaurang",
    "thairestauranger": "thairestaurang",
    "thairestaurangerna": "thairestaurang",
    "thairestaurangernas": "thairestaurang",
    "thairestaurangers": "thairestaurang",
    "thairestaurangs": "thairestaurang",
    "thais": "thai",
    "thaisidenet": "thaisiden",
    "thaisidenets": "thaisiden",
    "thaisidens": "thaisiden",
    "thaispråken": "thaispråk",
    "thaispråkens": "thaispråk",
    "thaispråket": "thaispråk",
    "thaispråkets": "thaispråk",
    "thaispråks": "thaispråk",
    "thalamusen": "thalamus",
    "thalamusens": "thalamus",
    "theer": "the",
    "theerna": "the",
    "theernas": "the",
    "theers": "the",
    "theet": "the",
    "theets": "the",
    "therie": "therier",
    "therierna": "therier",
    "theriernas": "therier",
    "theriers": "therier",
    "thes": "the",
    "thet": "the",
    "thetan": "theta",
    "thetana": "theta",
    "thetanas": "theta",
    "thetans": "theta",
    "thetas": "theta",
    "thetat": "theta",
    "thetats": "theta",
    "thets": "the",
    "thinnern": "thinner",
    "thinnerns": "thinner",
    "thinners": "thinner",
    "thomasfosfatet": "thomasfosfat",
    "thomasfosfatets": "thomasfosfat",
    "thomasfosfats": "thomasfosfat",
    "thomasprocessens": "thomasprocessen",
    "thoraxen": "thorax",
    "thoraxens": "thorax",
    "thrillerfilmen": "thrillerfilm",
    "thrillerfilmens": "thrillerfilm",
    "thrillerfilmer": "thrillerfilm",
    "thrillerfilmerna": "thrillerfilm",
    "thrillerfilmernas": "thrillerfilm",
    "thrillerfilmers": "thrillerfilm",
    "thrillerfilms": "thrillerfilm",
    "thrillern": "thriller",
    "thrillerns": "thriller",
    "thrillers": "thriller",
    "thrillersarna": "thriller",
    "thrillersarnas": "thriller",
    "thrillersen": "thriller",
    "thrillersens": "thriller",
    "thrillrar": "thriller",
    "thrillrarna": "thriller",
    "thrillrarnas": "thriller",
    "thrillrars": "thriller",
    "thymusen": "thymus",
    "thymusens": "thymus",
    "thyroxinen": "thyroxin",
    "thyroxinens": "thyroxin",
    "thyroxiner": "thyroxin",
    "thyroxinerna": "thyroxin",
    "thyroxinernas": "thyroxin",
    "thyroxiners": "thyroxin",
    "thyroxinet": "thyroxin",
    "thyroxinets": "thyroxin",
    "thyroxins": "thyroxin",
    "thätan": "thäta",
    "thätana": "thäta",
    "thätanas": "thäta",
    "thätans": "thäta",
    "thätas": "thäta",
    "thätat": "thäta",
    "thätats": "thäta",
    "tiaminen": "tiamin",
    "tiaminens": "tiamin",
    "tiaminer": "tiamin",
    "tiaminerna": "tiamin",
    "tiaminernas": "tiamin",
    "tiaminers": "tiamin",
    "tiamins": "tiamin",
    "tian": "tia",
    "tians": "tia",
    "tiar": "tiara",
    "tiaran": "tiara",
    "tiarans": "tiara",
    "tiaras": "tiara",
    "tiare": "tiara",
    "tiaror": "tiara",
    "tiarorna": "tiara",
    "tiarornas": "tiara",
    "tiarors": "tiara",
    "tiars": "tiara",
    "tias": "tia",
    "tibasten": "tibast",
    "tibastens": "tibast",
    "tibasts": "tibast",
    "tibetanar": "tibetanare",
    "tibetanaren": "tibetanare",
    "tibetanarens": "tibetanare",
    "tibetanares": "tibetanare",
    "tibetanarna": "tibetanare",
    "tibetanarnas": "tibetanare",
    "tibetanen": "tibetan",
    "tibetanens": "tibetan",
    "tibetaner": "tibetan",
    "tibetanerna": "tibetan",
    "tibetanernas": "tibetan",
    "tibetaners": "tibetan",
    "tibetans": "tibetan",
    "tibetansk": "tibetanska",
    "tibetanska": "tibetansk",
    "tibetanskan": "tibetanska",
    "tibetanskans": "tibetanska",
    "tibetanskare": "tibetansk",
    "tibetanskares": "tibetansk",
    "tibetanskas": "tibetanska",
    "tibetanskast": "tibetansk",
    "tibetanskaste": "tibetansk",
    "tibetanskastes": "tibetansk",
    "tibetanskasts": "tibetansk",
    "tibetanske": "tibetanska",
    "tibetanskes": "tibetansk",
    "tibetanskor": "tibetanska",
    "tibetanskorna": "tibetanska",
    "tibetanskornas": "tibetanska",
    "tibetanskors": "tibetanska",
    "tibetansks": "tibetansk",
    "tibetanskt": "tibetansk",
    "tibetanskts": "tibetansk",
    "ticen": "tic",
    "ticens": "tic",
    "tick": "ticka",
    "tick-tacken": "tick-tack",
    "tick-tackens": "tick-tack",
    "tick-tacket": "tick-tack",
    "tick-tackets": "tick-tack",
    "tick-tacks": "tick-tack",
    "tickad": "ticka",
    "tickade": "ticka",
    "tickades": "ticka",
    "tickads": "ticka",
    "tickan": "ticka",
    "tickande": "ticka",
    "tickanden": "tickande",
    "tickandena": "tickande",
    "tickandenas": "tickande",
    "tickandens": "tickande",
    "tickandes": "tickande",
    "tickandet": "tickande",
    "tickandets": "tickande",
    "tickans": "ticka",
    "tickar": "ticka",
    "tickas": "ticka",
    "tickat": "ticka",
    "tickats": "ticka",
    "ticke": "ticka",
    "ticken": "tick",
    "tickens": "tick",
    "ticket": "tick",
    "tickets": "tick",
    "tickor": "ticka",
    "tickorna": "ticka",
    "tickornas": "ticka",
    "tickors": "ticka",
    "ticks": "ticka",
    "tics": "tic",
    "ticsarna": "tic",
    "ticsarnas": "tic",
    "ticsen": "tic",
    "ticsens": "tic",
    "tideboken": "tidebok",
    "tidebokens": "tidebok",
    "tideboks": "tidebok",
    "tideböcker": "tidebok",
    "tideböckerna": "tidebok",
    "tideböckernas": "tidebok",
    "tideböckers": "tidebok",
    "tidegärden": "tidegärd",
    "tidegärdens": "tidegärd",
    "tidegärder": "tidegärd",
    "tidegärderna": "tidegärd",
    "tidegärdernas": "tidegärd",
    "tidegärders": "tidegärd",
    "tidegärds": "tidegärd",
    "tidelagen": "tidelag",
    "tidelagens": "tidelag",
    "tidelaget": "tidelag",
    "tidelagets": "tidelag",
    "tidelags": "tidelag",
    "tiden": "tid",
    "tidenderna": "tidender",
    "tidendernas": "tidender",
    "tidenders": "tidender",
    "tidens": "tid",
    "tider": "tid",
    "tiderna": "tid",
    "tidernas": "tid",
    "tiders": "tid",
    "tideräkningar": "tideräkning",
    "tideräkningarna": "tideräkning",
    "tideräkningarnas": "tideräkning",
    "tideräkningars": "tideräkning",
    "tideräkningen": "tideräkning",
    "tideräkningens": "tideräkning",
    "tideräknings": "tideräkning",
    "tidevarven": "tidevarv",
    "tidevarvens": "tidevarv",
    "tidevarvet": "tidevarv",
    "tidevarvets": "tidevarv",
    "tidevarvs": "tidevarv",
    "tidfäst": "tidfästa",
    "tidfästande": "tidfästa",
    "tidfästanden": "tidfästande",
    "tidfästandena": "tidfästande",
    "tidfästandenas": "tidfästande",
    "tidfästandens": "tidfästande",
    "tidfästandes": "tidfästande",
    "tidfästandet": "tidfästande",
    "tidfästandets": "tidfästande",
    "tidfästas": "tidfästa",
    "tidfäste": "tidfästa",
    "tidfäster": "tidfästa",
    "tidfästes": "tidfästa",
    "tidfästs": "tidfästa",
    "tidiga": "tidig",
    "tidigare": "tidig",
    "tidigarela": "tidigarelägga",
    "tidigarelade": "tidigarelägga",
    "tidigarelades": "tidigarelägga",
    "tidigarelagd": "tidigarelägga",
    "tidigarelagda": "tidigarelägga",
    "tidigarelagdas": "tidigarelägga",
    "tidigarelagde": "tidigarelägga",
    "tidigarelagdes": "tidigarelägga",
    "tidigarelagds": "tidigarelägga",
    "tidigarelagt": "tidigarelägga",
    "tidigarelagts": "tidigarelägga",
    "tidigarelas": "tidigarelägga",
    "tidigarelägg": "tidigarelägga",
    "tidigareläggande": "tidigarelägga",
    "tidigarelägganden": "tidigareläggande",
    "tidigareläggandena": "tidigareläggande",
    "tidigareläggandenas": "tidigareläggande",
    "tidigareläggandens": "tidigareläggande",
    "tidigareläggandes": "tidigareläggande",
    "tidigareläggandet": "tidigareläggande",
    "tidigareläggandets": "tidigareläggande",
    "tidigareläggas": "tidigarelägga",
    "tidigarelägger": "tidigarelägga",
    "tidigarelägges": "tidigarelägga",
    "tidigareläggningen": "tidigareläggning",
    "tidigareläggningens": "tidigareläggning",
    "tidigareläggnings": "tidigareläggning",
    "tidigareläggs": "tidigarelägga",
    "tidigares": "tidig",
    "tidigas": "tidig",
    "tidigast": "tidig",
    "tidigaste": "tidig",
    "tidigastes": "tidig",
    "tidigasts": "tidig",
    "tidige": "tidig",
    "tidiges": "tidig",
    "tidigs": "tidig",
    "tidigt": "tidig",
    "tidigts": "tidig",
    "tidjorden": "tidjord",
    "tidjordens": "tidjord",
    "tidjords": "tidjord",
    "tidjordsfenomenen": "tidjordsfenomen",
    "tidjordsfenomenens": "tidjordsfenomen",
    "tidjordsfenomenet": "tidjordsfenomen",
    "tidjordsfenomenets": "tidjordsfenomen",
    "tidjordsfenomens": "tidjordsfenomen",
    "tidjordsforskningar": "tidjordsforskning",
    "tidjordsforskningarna": "tidjordsforskning",
    "tidjordsforskningarnas": "tidjordsforskning",
    "tidjordsforskningars": "tidjordsforskning",
    "tidjordsforskningen": "tidjordsforskning",
    "tidjordsforskningens": "tidjordsforskning",
    "tidjordsforsknings": "tidjordsforskning",
    "tidjordskraften": "tidjordskraft",
    "tidjordskraftens": "tidjordskraft",
    "tidjordskrafter": "tidjordskraft",
    "tidjordskrafterna": "tidjordskraft",
    "tidjordskrafternas": "tidjordskraft",
    "tidjordskrafters": "tidjordskraft",
    "tidjordskrafts": "tidjordskraft",
    "tidkontrolluren": "tidkontrollur",
    "tidkontrollurens": "tidkontrollur",
    "tidkontrolluret": "tidkontrollur",
    "tidkontrollurets": "tidkontrollur",
    "tidkontrollurs": "tidkontrollur",
    "tidkorten": "tidkort",
    "tidkortens": "tidkort",
    "tidkortet": "tidkort",
    "tidkortets": "tidkort",
    "tidkorts": "tidkort",
    "tidliga": "tidlig",
    "tidligare": "tidlig",
    "tidligares": "tidlig",
    "tidligas": "tidlig",
    "tidligast": "tidlig",
    "tidligaste": "tidlig",
    "tidligastes": "tidlig",
    "tidligasts": "tidlig",
    "tidlige": "tidlig",
    "tidliges": "tidlig",
    "tidligheten": "tidlighet",
    "tidlighetens": "tidlighet",
    "tidlighets": "tidlighet",
    "tidligs": "tidlig",
    "tidligt": "tidlig",
    "tidligts": "tidlig",
    "tidlånen": "tidlån",
    "tidlånens": "tidlån",
    "tidlånet": "tidlån",
    "tidlånets": "tidlån",
    "tidlåns": "tidlån",
    "tidlönen": "tidlön",
    "tidlönens": "tidlön",
    "tidlöner": "tidlön",
    "tidlönerna": "tidlön",
    "tidlönernas": "tidlön",
    "tidlöners": "tidlön",
    "tidlöns": "tidlön",
    "tidlös": "tidlösa",
    "tidlösa": "tidlös",
    "tidlösan": "tidlösa",
    "tidlösans": "tidlösa",
    "tidlösare": "tidlös",
    "tidlösares": "tidlös",
    "tidlösas": "tidlösa",
    "tidlösast": "tidlös",
    "tidlösaste": "tidlös",
    "tidlösastes": "tidlös",
    "tidlösasts": "tidlös",
    "tidlöse": "tidlösa",
    "tidlöses": "tidlös",
    "tidlösheten": "tidlöshet",
    "tidlöshetens": "tidlöshet",
    "tidlösheter": "tidlöshet",
    "tidlösheterna": "tidlöshet",
    "tidlösheternas": "tidlöshet",
    "tidlösheters": "tidlöshet",
    "tidlöshets": "tidlöshet",
    "tidlösor": "tidlösa",
    "tidlösorna": "tidlösa",
    "tidlösornas": "tidlösa",
    "tidlösors": "tidlösa",
    "tidlöst": "tidlös",
    "tidlösts": "tidlös",
    "tidmån": "tidmåne",
    "tidmånar": "tidmåne",
    "tidmånarna": "tidmåne",
    "tidmånarnas": "tidmåne",
    "tidmånars": "tidmåne",
    "tidmånen": "tidmåne",
    "tidmånens": "tidmåne",
    "tidmånes": "tidmåne",
    "tidmåns": "tidmåne",
    "tidningar": "tidning",
    "tidningarna": "tidning",
    "tidningarnas": "tidning",
    "tidningars": "tidning",
    "tidningen": "tidning",
    "tidningens": "tidning",
    "tidnings": "tidning",
    "tidningsank": "tidningsanka",
    "tidningsankan": "tidningsanka",
    "tidningsankans": "tidningsanka",
    "tidningsankas": "tidningsanka",
    "tidningsanke": "tidningsanka",
    "tidningsankor": "tidningsanka",
    "tidningsankorna": "tidningsanka",
    "tidningsankornas": "tidningsanka",
    "tidningsankors": "tidningsanka",
    "tidningsanks": "tidningsanka",
    "tidningsartikeln": "tidningsartikel",
    "tidningsartikelns": "tidningsartikel",
    "tidningsartikels": "tidningsartikel",
    "tidningsartiklar": "tidningsartikel",
    "tidningsartiklarna": "tidningsartikel",
    "tidningsartiklarnas": "tidningsartikel",
    "tidningsartiklars": "tidningsartikel",
    "tidningsbilag": "tidningsbilaga",
    "tidningsbilagan": "tidningsbilaga",
    "tidningsbilagans": "tidningsbilaga",
    "tidningsbilagas": "tidningsbilaga",
    "tidningsbilage": "tidningsbilaga",
    "tidningsbilagor": "tidningsbilaga",
    "tidningsbilagorna": "tidningsbilaga",
    "tidningsbilagornas": "tidningsbilaga",
    "tidningsbilagors": "tidningsbilaga",
    "tidningsbilags": "tidningsbilaga",
    "tidningsbuden": "tidningsbud",
    "tidningsbudens": "tidningsbud",
    "tidningsbudet": "tidningsbud",
    "tidningsbudets": "tidningsbud",
    "tidningsbuds": "tidningsbud",
    "tidningsbuntar": "tidningsbunt",
    "tidningsbuntarna": "tidningsbunt",
    "tidningsbuntarnas": "tidningsbunt",
    "tidningsbuntars": "tidningsbunt",
    "tidningsbunten": "tidningsbunt",
    "tidningsbuntens": "tidningsbunt",
    "tidningsbunts": "tidningsbunt",
    "tidningsdöden": "tidningsdöd",
    "tidningsdödens": "tidningsdöd",
    "tidningsdöds": "tidningsdöd",
    "tidningskanten": "tidningskant",
    "tidningskantens": "tidningskant",
    "tidningskanter": "tidningskant",
    "tidningskanterna": "tidningskant",
    "tidningskanternas": "tidningskant",
    "tidningskanters": "tidningskant",
    "tidningskants": "tidningskant",
    "tidningskiosken": "tidningskiosk",
    "tidningskioskens": "tidningskiosk",
    "tidningskiosker": "tidningskiosk",
    "tidningskioskerna": "tidningskiosk",
    "tidningskioskernas": "tidningskiosk",
    "tidningskioskers": "tidningskiosk",
    "tidningskiosks": "tidningskiosk",
    "tidningsledar": "tidningsledare",
    "tidningsledaren": "tidningsledare",
    "tidningsledarens": "tidningsledare",
    "tidningsledares": "tidningsledare",
    "tidningsledarna": "tidningsledare",
    "tidningsledarnas": "tidningsledare",
    "tidningsmannen": "tidningsman",
    "tidningsmannens": "tidningsman",
    "tidningsmans": "tidningsman",
    "tidningsmän": "tidningsman",
    "tidningsmännen": "tidningsman",
    "tidningsmännens": "tidningsman",
    "tidningsmäns": "tidningsman",
    "tidningsnotisen": "tidningsnotis",
    "tidningsnotisens": "tidningsnotis",
    "tidningsnotiser": "tidningsnotis",
    "tidningsnotiserna": "tidningsnotis",
    "tidningsnotisernas": "tidningsnotis",
    "tidningsnotisers": "tidningsnotis",
    "tidningspapperet": "tidningspapper",
    "tidningspapperets": "tidningspapper",
    "tidningspappers": "tidningspapper",
    "tidningspappret": "tidningspapper",
    "tidningspapprets": "tidningspapper",
    "tidningsredaktionen": "tidningsredaktion",
    "tidningsredaktionens": "tidningsredaktion",
    "tidningsredaktioner": "tidningsredaktion",
    "tidningsredaktionerna": "tidningsredaktion",
    "tidningsredaktionernas": "tidningsredaktion",
    "tidningsredaktioners": "tidningsredaktion",
    "tidningsredaktions": "tidningsredaktion",
    "tidningsreferaten": "tidningsreferat",
    "tidningsreferatens": "tidningsreferat",
    "tidningsreferatet": "tidningsreferat",
    "tidningsreferatets": "tidningsreferat",
    "tidningsreferats": "tidningsreferat",
    "tidningssidan": "tidningssida",
    "tidningssidans": "tidningssida",
    "tidningssidas": "tidningssida",
    "tidningsside": "tidningssida",
    "tidningssides": "tidningssida",
    "tidningssidor": "tidningssida",
    "tidningssidorna": "tidningssida",
    "tidningssidornas": "tidningssida",
    "tidningssidors": "tidningssida",
    "tidningsspalten": "tidningsspalt",
    "tidningsspaltens": "tidningsspalt",
    "tidningsspalter": "tidningsspalt",
    "tidningsspalterna": "tidningsspalt",
    "tidningsspalternas": "tidningsspalt",
    "tidningsspalters": "tidningsspalt",
    "tidningsspalts": "tidningsspalt",
    "tidningsställen": "tidningsställ",
    "tidningsställens": "tidningsställ",
    "tidningsstället": "tidningsställ",
    "tidningsställets": "tidningsställ",
    "tidningsställs": "tidningsställ",
    "tidningstexten": "tidningstext",
    "tidningstextens": "tidningstext",
    "tidningstexter": "tidningstext",
    "tidningstexterna": "tidningstext",
    "tidningstexternas": "tidningstext",
    "tidningstexters": "tidningstext",
    "tidningstexts": "tidningstext",
    "tidningsuppgiften": "tidningsuppgift",
    "tidningsuppgiftens": "tidningsuppgift",
    "tidningsuppgifter": "tidningsuppgift",
    "tidningsuppgifterna": "tidningsuppgift",
    "tidningsuppgifternas": "tidningsuppgift",
    "tidningsuppgifters": "tidningsuppgift",
    "tidningsuppgifts": "tidningsuppgift",
    "tidningsupplagan": "tidningsupplaga",
    "tidningsupplagans": "tidningsupplaga",
    "tidningsupplagas": "tidningsupplaga",
    "tidningsupplage": "tidningsupplaga",
    "tidningsupplagor": "tidningsupplaga",
    "tidningsupplagorna": "tidningsupplaga",
    "tidningsupplagornas": "tidningsupplaga",
    "tidningsupplagors": "tidningsupplaga",
    "tidningsutbärningar": "tidningsutbärning",
    "tidningsutbärningarna": "tidningsutbärning",
    "tidningsutbärningarnas": "tidningsutbärning",
    "tidningsutbärningars": "tidningsutbärning",
    "tidningsutbärningen": "tidningsutbärning",
    "tidningsutbärningens": "tidningsutbärning",
    "tidningsutbärnings": "tidningsutbärning",
    "tidpunkten": "tidpunkt",
    "tidpunktens": "tidpunkt",
    "tidpunkter": "tidpunkt",
    "tidpunkterna": "tidpunkt",
    "tidpunkternas": "tidpunkt",
    "tidpunkters": "tidpunkt",
    "tidpunkts": "tidpunkt",
    "tidrymden": "tidrymd",
    "tidrymdens": "tidrymd",
    "tidrymder": "tidrymd",
    "tidrymderna": "tidrymd",
    "tidrymdernas": "tidrymd",
    "tidrymders": "tidrymd",
    "tidrymds": "tidrymd",
    "tidrören": "tidrör",
    "tidrörens": "tidrör",
    "tidröret": "tidrör",
    "tidrörets": "tidrör",
    "tidrörs": "tidrör",
    "tids": "tid",
    "tidsadverbialen": "tidsadverbial",
    "tidsadverbialens": "tidsadverbial",
    "tidsadverbialet": "tidsadverbial",
    "tidsadverbialets": "tidsadverbial",
    "tidsadverbials": "tidsadverbial",
    "tidsandan": "tidsanda",
    "tidsandans": "tidsanda",
    "tidsandas": "tidsanda",
    "tidsangivelsen": "tidsangivelse",
    "tidsangivelsens": "tidsangivelse",
    "tidsangivelser": "tidsangivelse",
    "tidsangivelserna": "tidsangivelse",
    "tidsangivelsernas": "tidsangivelse",
    "tidsangivelsers": "tidsangivelse",
    "tidsangivelses": "tidsangivelse",
    "tidsaspekten": "tidsaspekt",
    "tidsaspektens": "tidsaspekt",
    "tidsaspekter": "tidsaspekt",
    "tidsaspekterna": "tidsaspekt",
    "tidsaspekternas": "tidsaspekt",
    "tidsaspekters": "tidsaspekt",
    "tidsaspekts": "tidsaspekt",
    "tidsaxeln": "tidsaxel",
    "tidsaxelns": "tidsaxel",
    "tidsaxels": "tidsaxel",
    "tidsbefraktningar": "tidsbefraktning",
    "tidsbefraktningarna": "tidsbefraktning",
    "tidsbefraktningarnas": "tidsbefraktning",
    "tidsbefraktningars": "tidsbefraktning",
    "tidsbefraktningen": "tidsbefraktning",
    "tidsbefraktningens": "tidsbefraktning",
    "tidsbefraktnings": "tidsbefraktning",
    "tidsbegreppen": "tidsbegrepp",
    "tidsbegreppens": "tidsbegrepp",
    "tidsbegreppet": "tidsbegrepp",
    "tidsbegreppets": "tidsbegrepp",
    "tidsbegrepps": "tidsbegrepp",
    "tidsbegräns": "tidsbegränsa",
    "tidsbegränsad": "tidsbegränsa",
    "tidsbegränsade": "tidsbegränsad",
    "tidsbegränsades": "tidsbegränsad",
    "tidsbegränsads": "tidsbegränsad",
    "tidsbegränsande": "tidsbegränsa",
    "tidsbegränsanden": "tidsbegränsande",
    "tidsbegränsandena": "tidsbegränsande",
    "tidsbegränsandenas": "tidsbegränsande",
    "tidsbegränsandens": "tidsbegränsande",
    "tidsbegränsandes": "tidsbegränsande",
    "tidsbegränsandet": "tidsbegränsande",
    "tidsbegränsandets": "tidsbegränsande",
    "tidsbegränsar": "tidsbegränsa",
    "tidsbegränsas": "tidsbegränsa",
    "tidsbegränsat": "tidsbegränsad",
    "tidsbegränsats": "tidsbegränsad",
    "tidsbeställningar": "tidsbeställning",
    "tidsbeställningarna": "tidsbeställning",
    "tidsbeställningarnas": "tidsbeställning",
    "tidsbeställningars": "tidsbeställning",
    "tidsbeställningen": "tidsbeställning",
    "tidsbeställningens": "tidsbeställning",
    "tidsbeställnings": "tidsbeställning",
    "tidsbestäm": "tidsbestämma",
    "tidsbestämd": "tidsbestämma",
    "tidsbestämda": "tidsbestämma",
    "tidsbestämdas": "tidsbestämma",
    "tidsbestämde": "tidsbestämma",
    "tidsbestämdes": "tidsbestämma",
    "tidsbestämds": "tidsbestämma",
    "tidsbestämmande": "tidsbestämma",
    "tidsbestämmanden": "tidsbestämmande",
    "tidsbestämmandena": "tidsbestämmande",
    "tidsbestämmandenas": "tidsbestämmande",
    "tidsbestämmandens": "tidsbestämmande",
    "tidsbestämmandes": "tidsbestämmande",
    "tidsbestämmandet": "tidsbestämmande",
    "tidsbestämmandets": "tidsbestämmande",
    "tidsbestämmas": "tidsbestämma",
    "tidsbestämmer": "tidsbestämma",
    "tidsbestäms": "tidsbestämma",
    "tidsbestämt": "tidsbestämma",
    "tidsbestämts": "tidsbestämma",
    "tidsbilden": "tidsbild",
    "tidsbildens": "tidsbild",
    "tidsbilder": "tidsbild",
    "tidsbilderna": "tidsbild",
    "tidsbildernas": "tidsbild",
    "tidsbilders": "tidsbild",
    "tidsbilds": "tidsbild",
    "tidsbundens": "tidsbunden",
    "tidsbundet": "tidsbunden",
    "tidsbundets": "tidsbunden",
    "tidsbundna": "tidsbunden",
    "tidsbundnare": "tidsbunden",
    "tidsbundnares": "tidsbunden",
    "tidsbundnas": "tidsbunden",
    "tidsbundnast": "tidsbunden",
    "tidsbundnaste": "tidsbunden",
    "tidsbundnastes": "tidsbunden",
    "tidsbundnasts": "tidsbunden",
    "tidsbundne": "tidsbunden",
    "tidsbundnes": "tidsbunden",
    "tidsdelningar": "tidsdelning",
    "tidsdelningarna": "tidsdelning",
    "tidsdelningarnas": "tidsdelning",
    "tidsdelningars": "tidsdelning",
    "tidsdelningen": "tidsdelning",
    "tidsdelningens": "tidsdelning",
    "tidsdelnings": "tidsdelning",
    "tidsdokumenten": "tidsdokument",
    "tidsdokumentens": "tidsdokument",
    "tidsdokumentet": "tidsdokument",
    "tidsdokumentets": "tidsdokument",
    "tidsdokuments": "tidsdokument",
    "tidsekvationen": "tidsekvation",
    "tidsekvationens": "tidsekvation",
    "tidsekvationer": "tidsekvation",
    "tidsekvationerna": "tidsekvation",
    "tidsekvationernas": "tidsekvation",
    "tidsekvationers": "tidsekvation",
    "tidsekvations": "tidsekvation",
    "tidsenheten": "tidsenhet",
    "tidsenhetens": "tidsenhet",
    "tidsenheter": "tidsenhet",
    "tidsenheterna": "tidsenhet",
    "tidsenheternas": "tidsenhet",
    "tidsenheters": "tidsenhet",
    "tidsenhets": "tidsenhet",
    "tidsenliga": "tidsenlig",
    "tidsenligare": "tidsenlig",
    "tidsenligares": "tidsenlig",
    "tidsenligas": "tidsenlig",
    "tidsenligast": "tidsenlig",
    "tidsenligaste": "tidsenlig",
    "tidsenligastes": "tidsenlig",
    "tidsenligasts": "tidsenlig",
    "tidsenlige": "tidsenlig",
    "tidsenliges": "tidsenlig",
    "tidsenligheten": "tidsenlighet",
    "tidsenlighetens": "tidsenlighet",
    "tidsenlighets": "tidsenlighet",
    "tidsenligs": "tidsenlig",
    "tidsenligt": "tidsenlig",
    "tidsenligts": "tidsenlig",
    "tidsepoken": "tidsepok",
    "tidsepokens": "tidsepok",
    "tidsepoker": "tidsepok",
    "tidsepokerna": "tidsepok",
    "tidsepokernas": "tidsepok",
    "tidsepokers": "tidsepok",
    "tidsepoks": "tidsepok",
    "tidsfaktorer": "tidsfaktor",
    "tidsfaktorerna": "tidsfaktor",
    "tidsfaktorernas": "tidsfaktor",
    "tidsfaktorers": "tidsfaktor",
    "tidsfaktorn": "tidsfaktor",
    "tidsfaktorns": "tidsfaktor",
    "tidsfaktors": "tidsfaktor",
    "tidsfristen": "tidsfrist",
    "tidsfristens": "tidsfrist",
    "tidsfrister": "tidsfrist",
    "tidsfristerna": "tidsfrist",
    "tidsfristernas": "tidsfrist",
    "tidsfristers": "tidsfrist",
    "tidsfrists": "tidsfrist",
    "tidsfrågan": "tidsfråga",
    "tidsfrågans": "tidsfråga",
    "tidsfrågas": "tidsfråga",
    "tidsfråge": "tidsfråga",
    "tidsfrågor": "tidsfråga",
    "tidsfrågorna": "tidsfråga",
    "tidsfrågornas": "tidsfråga",
    "tidsfrågors": "tidsfråga",
    "tidsfördriven": "tidsfördriv",
    "tidsfördrivens": "tidsfördriv",
    "tidsfördrivet": "tidsfördriv",
    "tidsfördrivets": "tidsfördriv",
    "tidsfördrivs": "tidsfördriv",
    "tidsförloppen": "tidsförlopp",
    "tidsförloppens": "tidsförlopp",
    "tidsförloppet": "tidsförlopp",
    "tidsförloppets": "tidsförlopp",
    "tidsförlopps": "tidsförlopp",
    "tidsförlusten": "tidsförlust",
    "tidsförlustens": "tidsförlust",
    "tidsförluster": "tidsförlust",
    "tidsförlusterna": "tidsförlust",
    "tidsförlusternas": "tidsförlust",
    "tidsförlusters": "tidsförlust",
    "tidsförlusts": "tidsförlust",
    "tidsförskjutningar": "tidsförskjutning",
    "tidsförskjutningarna": "tidsförskjutning",
    "tidsförskjutningarnas": "tidsförskjutning",
    "tidsförskjutningars": "tidsförskjutning",
    "tidsförskjutningen": "tidsförskjutning",
    "tidsförskjutningens": "tidsförskjutning",
    "tidsförskjutnings": "tidsförskjutning",
    "tidsgränsen": "tidsgräns",
    "tidsgränsens": "tidsgräns",
    "tidsgränser": "tidsgräns",
    "tidsgränserna": "tidsgräns",
    "tidsgränsernas": "tidsgräns",
    "tidsgränsers": "tidsgräns",
    "tidsinställda": "tidsinställd",
    "tidsinställdare": "tidsinställd",
    "tidsinställdares": "tidsinställd",
    "tidsinställdas": "tidsinställd",
    "tidsinställdast": "tidsinställd",
    "tidsinställdaste": "tidsinställd",
    "tidsinställdastes": "tidsinställd",
    "tidsinställdasts": "tidsinställd",
    "tidsinställde": "tidsinställd",
    "tidsinställdes": "tidsinställd",
    "tidsinställds": "tidsinställd",
    "tidsinställt": "tidsinställd",
    "tidsinställts": "tidsinställd",
    "tidsintervallen": "tidsintervall",
    "tidsintervallens": "tidsintervall",
    "tidsintervaller": "tidsintervall",
    "tidsintervallerna": "tidsintervall",
    "tidsintervallernas": "tidsintervall",
    "tidsintervallers": "tidsintervall",
    "tidsintervallet": "tidsintervall",
    "tidsintervallets": "tidsintervall",
    "tidsintervalls": "tidsintervall",
    "tidskriften": "tidskrift",
    "tidskriftens": "tidskrift",
    "tidskrifter": "tidskrift",
    "tidskrifterna": "tidskrift",
    "tidskrifternas": "tidskrift",
    "tidskrifters": "tidskrift",
    "tidskrifts": "tidskrift",
    "tidskriftsartikeln": "tidskriftsartikel",
    "tidskriftsartikelns": "tidskriftsartikel",
    "tidskriftsartikels": "tidskriftsartikel",
    "tidskriftsartiklar": "tidskriftsartikel",
    "tidskriftsartiklarna": "tidskriftsartikel",
    "tidskriftsartiklarnas": "tidskriftsartikel",
    "tidskriftsartiklars": "tidskriftsartikel",
    "tidskriftsindexen": "tidskriftsindex",
    "tidskriftsindexens": "tidskriftsindex",
    "tidskriftsindexet": "tidskriftsindex",
    "tidskriftsindexets": "tidskriftsindex",
    "tidskriftsnummerna": "tidskriftsnummer",
    "tidskriftsnummernas": "tidskriftsnummer",
    "tidskriftsnummers": "tidskriftsnummer",
    "tidskriftsnumren": "tidskriftsnummer",
    "tidskriftsnumrens": "tidskriftsnummer",
    "tidskriftsnumret": "tidskriftsnummer",
    "tidskriftsnumrets": "tidskriftsnummer",
    "tidsliga": "tidslig",
    "tidsligare": "tidslig",
    "tidsligares": "tidslig",
    "tidsligas": "tidslig",
    "tidsligast": "tidslig",
    "tidsligaste": "tidslig",
    "tidsligastes": "tidslig",
    "tidsligasts": "tidslig",
    "tidslige": "tidslig",
    "tidsliges": "tidslig",
    "tidsligheten": "tidslighet",
    "tidslighetens": "tidslighet",
    "tidslighets": "tidslighet",
    "tidsligs": "tidslig",
    "tidsligt": "tidslig",
    "tidsligts": "tidslig",
    "tidsmarginalen": "tidsmarginal",
    "tidsmarginalens": "tidsmarginal",
    "tidsmarginaler": "tidsmarginal",
    "tidsmarginalerna": "tidsmarginal",
    "tidsmarginalernas": "tidsmarginal",
    "tidsmarginalers": "tidsmarginal",
    "tidsmarginals": "tidsmarginal",
    "tidsmaskinen": "tidsmaskin",
    "tidsmaskinens": "tidsmaskin",
    "tidsmaskiner": "tidsmaskin",
    "tidsmaskinerna": "tidsmaskin",
    "tidsmaskinernas": "tidsmaskin",
    "tidsmaskiners": "tidsmaskin",
    "tidsmaskins": "tidsmaskin",
    "tidsmedvetens": "tidsmedveten",
    "tidsmedvetet": "tidsmedveten",
    "tidsmedvetets": "tidsmedveten",
    "tidsmedvetna": "tidsmedveten",
    "tidsmedvetnare": "tidsmedveten",
    "tidsmedvetnares": "tidsmedveten",
    "tidsmedvetnas": "tidsmedveten",
    "tidsmedvetnast": "tidsmedveten",
    "tidsmedvetnaste": "tidsmedveten",
    "tidsmedvetnastes": "tidsmedveten",
    "tidsmedvetnasts": "tidsmedveten",
    "tidsmedvetne": "tidsmedveten",
    "tidsmedvetnes": "tidsmedveten",
    "tidsmässiga": "tidsmässig",
    "tidsmässigare": "tidsmässig",
    "tidsmässigares": "tidsmässig",
    "tidsmässigas": "tidsmässig",
    "tidsmässigast": "tidsmässig",
    "tidsmässigaste": "tidsmässig",
    "tidsmässigastes": "tidsmässig",
    "tidsmässigasts": "tidsmässig",
    "tidsmässige": "tidsmässig",
    "tidsmässiges": "tidsmässig",
    "tidsmässigheten": "tidsmässighet",
    "tidsmässighetens": "tidsmässighet",
    "tidsmässigheter": "tidsmässighet",
    "tidsmässigheterna": "tidsmässighet",
    "tidsmässigheternas": "tidsmässighet",
    "tidsmässigheters": "tidsmässighet",
    "tidsmässighets": "tidsmässighet",
    "tidsmässigs": "tidsmässig",
    "tidsmässigt": "tidsmässig",
    "tidsmässigts": "tidsmässig",
    "tidsmåtten": "tidsmått",
    "tidsmåttens": "tidsmått",
    "tidsmåttet": "tidsmått",
    "tidsmåttets": "tidsmått",
    "tidsmåtts": "tidsmått",
    "tidsnöden": "tidsnöd",
    "tidsnödens": "tidsnöd",
    "tidsnöds": "tidsnöd",
    "tidsomställningar": "tidsomställning",
    "tidsomställningarna": "tidsomställning",
    "tidsomställningarnas": "tidsomställning",
    "tidsomställningars": "tidsomställning",
    "tidsomställningen": "tidsomställning",
    "tidsomställningens": "tidsomställning",
    "tidsomställnings": "tidsomställning",
    "tidsperioden": "tidsperiod",
    "tidsperiodens": "tidsperiod",
    "tidsperioder": "tidsperiod",
    "tidsperioderna": "tidsperiod",
    "tidsperiodernas": "tidsperiod",
    "tidsperioders": "tidsperiod",
    "tidsperiods": "tidsperiod",
    "tidsperspektiven": "tidsperspektiv",
    "tidsperspektivens": "tidsperspektiv",
    "tidsperspektivet": "tidsperspektiv",
    "tidsperspektivets": "tidsperspektiv",
    "tidsperspektivs": "tidsperspektiv",
    "tidspilar": "tidspil",
    "tidspilarna": "tidspil",
    "tidspilarnas": "tidspil",
    "tidspilars": "tidspil",
    "tidspilen": "tidspil",
    "tidspilens": "tidspil",
    "tidspillans": "tidspillan",
    "tidspils": "tidspil",
    "tidsplane": "tidsplan",
    "tidsplanen": "tidsplan",
    "tidsplanens": "tidsplan",
    "tidsplaner": "tidsplan",
    "tidsplanerna": "tidsplan",
    "tidsplanernas": "tidsplan",
    "tidsplaners": "tidsplan",
    "tidsplanet": "tidsplan",
    "tidsplanets": "tidsplan",
    "tidsplans": "tidsplan",
    "tidspressen": "tidspress",
    "tidspressens": "tidspress",
    "tidsrymden": "tidsrymd",
    "tidsrymdens": "tidsrymd",
    "tidsrymder": "tidsrymd",
    "tidsrymderna": "tidsrymd",
    "tidsrymdernas": "tidsrymd",
    "tidsrymders": "tidsrymd",
    "tidsrymds": "tidsrymd",
    "tidsscheman": "tidsschema",
    "tidsschemana": "tidsschema",
    "tidsschemanas": "tidsschema",
    "tidsschemans": "tidsschema",
    "tidsschemas": "tidsschema",
    "tidsschemat": "tidsschema",
    "tidsschemats": "tidsschema",
    "tidssignalen": "tidssignal",
    "tidssignalens": "tidssignal",
    "tidssignaler": "tidssignal",
    "tidssignalerna": "tidssignal",
    "tidssignalernas": "tidssignal",
    "tidssignalers": "tidssignal",
    "tidssignals": "tidssignal",
    "tidsskal": "tidsskala",
    "tidsskalan": "tidsskala",
    "tidsskalans": "tidsskala",
    "tidsskalas": "tidsskala",
    "tidsskale": "tidsskala",
    "tidsskalor": "tidsskala",
    "tidsskalorna": "tidsskala",
    "tidsskalornas": "tidsskala",
    "tidsskalors": "tidsskala",
    "tidsskals": "tidsskala",
    "tidsskeden": "tidsskede",
    "tidsskedena": "tidsskede",
    "tidsskedenas": "tidsskede",
    "tidsskedens": "tidsskede",
    "tidsskedes": "tidsskede",
    "tidsskedet": "tidsskede",
    "tidsskedets": "tidsskede",
    "tidsskeds": "tidsskede",
    "tidsskillnaden": "tidsskillnad",
    "tidsskillnadens": "tidsskillnad",
    "tidsskillnader": "tidsskillnad",
    "tidsskillnaderna": "tidsskillnad",
    "tidsskillnadernas": "tidsskillnad",
    "tidsskillnaders": "tidsskillnad",
    "tidsskillnads": "tidsskillnad",
    "tidsspillans": "tidsspillan",
    "tidsstudie": "tidsstudier",
    "tidsstudiemannen": "tidsstudieman",
    "tidsstudiemannens": "tidsstudieman",
    "tidsstudiemans": "tidsstudieman",
    "tidsstudiemän": "tidsstudieman",
    "tidsstudiemännen": "tidsstudieman",
    "tidsstudiemännens": "tidsstudieman",
    "tidsstudiemäns": "tidsstudieman",
    "tidsstudierna": "tidsstudier",
    "tidsstudiernas": "tidsstudier",
    "tidsstudiers": "tidsstudier",
    "tidstrogens": "tidstrogen",
    "tidstroget": "tidstrogen",
    "tidstrogets": "tidstrogen",
    "tidstrogna": "tidstrogen",
    "tidstrognare": "tidstrogen",
    "tidstrognares": "tidstrogen",
    "tidstrognas": "tidstrogen",
    "tidstrognast": "tidstrogen",
    "tidstrognaste": "tidstrogen",
    "tidstrognastes": "tidstrogen",
    "tidstrognasts": "tidstrogen",
    "tidstrogne": "tidstrogen",
    "tidstrognes": "tidstrogen",
    "tidströmställar": "tidströmställare",
    "tidströmställaren": "tidströmställare",
    "tidströmställarens": "tidströmställare",
    "tidströmställares": "tidströmställare",
    "tidströmställarna": "tidströmställare",
    "tidströmställarnas": "tidströmställare",
    "tidstypiska": "tidstypisk",
    "tidstypiskare": "tidstypisk",
    "tidstypiskares": "tidstypisk",
    "tidstypiskas": "tidstypisk",
    "tidstypiskast": "tidstypisk",
    "tidstypiskaste": "tidstypisk",
    "tidstypiskastes": "tidstypisk",
    "tidstypiskasts": "tidstypisk",
    "tidstypiske": "tidstypisk",
    "tidstypiskes": "tidstypisk",
    "tidstypisks": "tidstypisk",
    "tidstypiskt": "tidstypisk",
    "tidstypiskts": "tidstypisk",
    "tidsuppfattningar": "tidsuppfattning",
    "tidsuppfattningarna": "tidsuppfattning",
    "tidsuppfattningarnas": "tidsuppfattning",
    "tidsuppfattningars": "tidsuppfattning",
    "tidsuppfattningen": "tidsuppfattning",
    "tidsuppfattningens": "tidsuppfattning",
    "tidsuppfattnings": "tidsuppfattning",
    "tidsutdräkten": "tidsutdräkt",
    "tidsutdräktens": "tidsutdräkt",
    "tidsutdräkts": "tidsutdräkt",
    "tidszonen": "tidszon",
    "tidszonens": "tidszon",
    "tidszoner": "tidszon",
    "tidszonerna": "tidszon",
    "tidszonernas": "tidszon",
    "tidszoners": "tidszon",
    "tidszons": "tidszon",
    "tidsåldern": "tidsålder",
    "tidsålderns": "tidsålder",
    "tidsålders": "tidsålder",
    "tidsåldrar": "tidsålder",
    "tidsåldrarna": "tidsålder",
    "tidsåldrarnas": "tidsålder",
    "tidsåldrars": "tidsålder",
    "tidsåtgången": "tidsåtgång",
    "tidsåtgångens": "tidsåtgång",
    "tidsåtgångs": "tidsåtgång",
    "tidsöverdragen": "tidsöverdrag",
    "tidsöverdragens": "tidsöverdrag",
    "tidsöverdraget": "tidsöverdrag",
    "tidsöverdragets": "tidsöverdrag",
    "tidsöverdrags": "tidsöverdrag",
    "tidtabellen": "tidtabell",
    "tidtabellens": "tidtabell",
    "tidtabeller": "tidtabell",
    "tidtabellerna": "tidtabell",
    "tidtabellernas": "tidtabell",
    "tidtabellers": "tidtabell",
    "tidtabells": "tidtabell",
    "tidtabellsmässiga": "tidtabellsmässig",
    "tidtabellsmässigare": "tidtabellsmässig",
    "tidtabellsmässigares": "tidtabellsmässig",
    "tidtabellsmässigas": "tidtabellsmässig",
    "tidtabellsmässigast": "tidtabellsmässig",
    "tidtabellsmässigaste": "tidtabellsmässig",
    "tidtabellsmässigastes": "tidtabellsmässig",
    "tidtabellsmässigasts": "tidtabellsmässig",
    "tidtabellsmässige": "tidtabellsmässig",
    "tidtabellsmässiges": "tidtabellsmässig",
    "tidtabellsmässigs": "tidtabellsmässig",
    "tidtabellsmässigt": "tidtabellsmässig",
    "tidtabellsmässigts": "tidtabellsmässig",
    "tidtagar": "tidtagare",
    "tidtagaren": "tidtagare",
    "tidtagarens": "tidtagare",
    "tidtagares": "tidtagare",
    "tidtagarna": "tidtagare",
    "tidtagarnas": "tidtagare",
    "tidtagaruren": "tidtagarur",
    "tidtagarurens": "tidtagarur",
    "tidtagaruret": "tidtagarur",
    "tidtagarurets": "tidtagarur",
    "tidtagarurs": "tidtagarur",
    "tidtagningar": "tidtagning",
    "tidtagningarna": "tidtagning",
    "tidtagningarnas": "tidtagning",
    "tidtagningars": "tidtagning",
    "tidtagningen": "tidtagning",
    "tidtagningens": "tidtagning",
    "tidtagnings": "tidtagning",
    "tiduren": "tidur",
    "tidurens": "tidur",
    "tiduret": "tidur",
    "tidurets": "tidur",
    "tidurs": "tidur",
    "tidvattenhöjden": "tidvattenhöjd",
    "tidvattenhöjdens": "tidvattenhöjd",
    "tidvattenhöjder": "tidvattenhöjd",
    "tidvattenhöjderna": "tidvattenhöjd",
    "tidvattenhöjdernas": "tidvattenhöjd",
    "tidvattenhöjders": "tidvattenhöjd",
    "tidvattenhöjds": "tidvattenhöjd",
    "tidvattenkraften": "tidvattenkraft",
    "tidvattenkraftens": "tidvattenkraft",
    "tidvattenkrafter": "tidvattenkraft",
    "tidvattenkrafterna": "tidvattenkraft",
    "tidvattenkrafternas": "tidvattenkraft",
    "tidvattenkrafters": "tidvattenkraft",
    "tidvattenkrafts": "tidvattenkraft",
    "tidvattenkraftverken": "tidvattenkraftverk",
    "tidvattenkraftverkens": "tidvattenkraftverk",
    "tidvattenkraftverket": "tidvattenkraftverk",
    "tidvattenkraftverkets": "tidvattenkraftverk",
    "tidvattenkraftverks": "tidvattenkraftverk",
    "tidvattens": "tidvatten",
    "tidvattenströmmar": "tidvattenström",
    "tidvattenströmmarna": "tidvattenström",
    "tidvattenströmmarnas": "tidvattenström",
    "tidvattenströmmars": "tidvattenström",
    "tidvattenströmmen": "tidvattenström",
    "tidvattenströmmens": "tidvattenström",
    "tidvattenströms": "tidvattenström",
    "tidvattnen": "tidvatten",
    "tidvattnens": "tidvatten",
    "tidvattnet": "tidvatten",
    "tidvattnets": "tidvatten",
    "tie-breaken": "tie-break",
    "tie-breakens": "tie-break",
    "tie-breaket": "tie-break",
    "tie-breakets": "tie-break",
    "tie-breaks": "tie-break",
    "ties": "tie",
    "tiesnårets": "tiesnåret",
    "tig": "tiga",
    "tigande": "tiga",
    "tiganden": "tigande",
    "tigandena": "tigande",
    "tigandenas": "tigande",
    "tigandens": "tigande",
    "tigandes": "tigande",
    "tigandet": "tigande",
    "tigandets": "tigande",
    "tigas": "tiga",
    "tige": "tiga",
    "tiger": "tiga",
    "tigerhajar": "tigerhaj",
    "tigerhajarna": "tigerhaj",
    "tigerhajarnas": "tigerhaj",
    "tigerhajars": "tigerhaj",
    "tigerhajen": "tigerhaj",
    "tigerhajens": "tigerhaj",
    "tigerhajs": "tigerhaj",
    "tigerhjärt": "tigerhjärta",
    "tigerhjärtan": "tigerhjärta",
    "tigerhjärtana": "tigerhjärta",
    "tigerhjärtanas": "tigerhjärta",
    "tigerhjärtans": "tigerhjärta",
    "tigerhjärtas": "tigerhjärta",
    "tigerhjärtat": "tigerhjärta",
    "tigerhjärtats": "tigerhjärta",
    "tigerhjärts": "tigerhjärta",
    "tigerkak": "tigerkaka",
    "tigerkakan": "tigerkaka",
    "tigerkakans": "tigerkaka",
    "tigerkakas": "tigerkaka",
    "tigerkake": "tigerkaka",
    "tigerkakor": "tigerkaka",
    "tigerkakorna": "tigerkaka",
    "tigerkakornas": "tigerkaka",
    "tigerkakors": "tigerkaka",
    "tigerkaks": "tigerkaka",
    "tigerkatten": "tigerkatt",
    "tigerkattens": "tigerkatt",
    "tigerkatter": "tigerkatt",
    "tigerkatterna": "tigerkatt",
    "tigerkatternas": "tigerkatt",
    "tigerkatters": "tigerkatt",
    "tigerkatts": "tigerkatt",
    "tigerliljan": "tigerlilja",
    "tigerliljans": "tigerlilja",
    "tigerliljas": "tigerlilja",
    "tigerlilje": "tigerlilja",
    "tigerliljor": "tigerlilja",
    "tigerliljorna": "tigerlilja",
    "tigerliljornas": "tigerlilja",
    "tigerliljors": "tigerlilja",
    "tigern": "tiger",
    "tigerns": "tiger",
    "tigerormar": "tigerorm",
    "tigerormarna": "tigerorm",
    "tigerormarnas": "tigerorm",
    "tigerormars": "tigerorm",
    "tigerormen": "tigerorm",
    "tigerormens": "tigerorm",
    "tigerorms": "tigerorm",
    "tigerrandiga": "tigerrandig",
    "tigerrandigare": "tigerrandig",
    "tigerrandigares": "tigerrandig",
    "tigerrandigas": "tigerrandig",
    "tigerrandigast": "tigerrandig",
    "tigerrandigaste": "tigerrandig",
    "tigerrandigastes": "tigerrandig",
    "tigerrandigasts": "tigerrandig",
    "tigerrandige": "tigerrandig",
    "tigerrandiges": "tigerrandig",
    "tigerrandigheten": "tigerrandighet",
    "tigerrandighetens": "tigerrandighet",
    "tigerrandighets": "tigerrandighet",
    "tigerrandigs": "tigerrandig",
    "tigerrandigt": "tigerrandig",
    "tigerrandigts": "tigerrandig",
    "tigers": "tiger",
    "tigerskinnen": "tigerskinn",
    "tigerskinnens": "tigerskinn",
    "tigerskinnet": "tigerskinn",
    "tigerskinnets": "tigerskinn",
    "tigerskinns": "tigerskinn",
    "tigersprången": "tigersprång",
    "tigersprångens": "tigersprång",
    "tigersprånget": "tigersprång",
    "tigersprångets": "tigersprång",
    "tigersprångs": "tigersprång",
    "tigerstrimmiga": "tigerstrimmig",
    "tigerstrimmigare": "tigerstrimmig",
    "tigerstrimmigares": "tigerstrimmig",
    "tigerstrimmigas": "tigerstrimmig",
    "tigerstrimmigast": "tigerstrimmig",
    "tigerstrimmigaste": "tigerstrimmig",
    "tigerstrimmigastes": "tigerstrimmig",
    "tigerstrimmigasts": "tigerstrimmig",
    "tigerstrimmige": "tigerstrimmig",
    "tigerstrimmiges": "tigerstrimmig",
    "tigerstrimmigheten": "tigerstrimmighet",
    "tigerstrimmighetens": "tigerstrimmighet",
    "tigerstrimmighets": "tigerstrimmighet",
    "tigerstrimmigs": "tigerstrimmig",
    "tigerstrimmigt": "tigerstrimmig",
    "tigerstrimmigts": "tigerstrimmig",
    "tigersågar": "tigersåg",
    "tigersågarna": "tigersåg",
    "tigersågarnas": "tigersåg",
    "tigersågars": "tigersåg",
    "tigersågen": "tigersåg",
    "tigersågens": "tigersåg",
    "tigersågs": "tigersåg",
    "tigerögas": "tigeröga",
    "tigerögat": "tigeröga",
    "tigerögats": "tigeröga",
    "tiges": "tiga",
    "tigg": "tigga",
    "tiggande": "tigga",
    "tigganden": "tiggande",
    "tiggandena": "tiggande",
    "tiggandenas": "tiggande",
    "tiggandens": "tiggande",
    "tiggandes": "tiggande",
    "tiggandet": "tiggande",
    "tiggandets": "tiggande",
    "tiggar": "tiggare",
    "tiggarbreven": "tiggarbrev",
    "tiggarbrevens": "tiggarbrev",
    "tiggarbrevet": "tiggarbrev",
    "tiggarbrevets": "tiggarbrev",
    "tiggarbrevs": "tiggarbrev",
    "tiggaren": "tiggare",
    "tiggarens": "tiggare",
    "tiggares": "tiggare",
    "tiggarligan": "tiggarliga",
    "tiggarligans": "tiggarliga",
    "tiggarligas": "tiggarliga",
    "tiggarlige": "tiggarliga",
    "tiggarligor": "tiggarliga",
    "tiggarligorna": "tiggarliga",
    "tiggarligornas": "tiggarliga",
    "tiggarligors": "tiggarliga",
    "tiggarmunkar": "tiggarmunk",
    "tiggarmunkarna": "tiggarmunk",
    "tiggarmunkarnas": "tiggarmunk",
    "tiggarmunkars": "tiggarmunk",
    "tiggarmunken": "tiggarmunk",
    "tiggarmunkens": "tiggarmunk",
    "tiggarmunks": "tiggarmunk",
    "tiggarna": "tiggare",
    "tiggarnas": "tiggare",
    "tiggarordens": "tiggarorden",
    "tiggarordnar": "tiggarorden",
    "tiggarordnarna": "tiggarorden",
    "tiggarordnarnas": "tiggarorden",
    "tiggarordnars": "tiggarorden",
    "tiggarordnen": "tiggarorden",
    "tiggarordnens": "tiggarorden",
    "tiggas": "tigga",
    "tiggd": "tigga",
    "tiggda": "tigga",
    "tiggdas": "tigga",
    "tiggde": "tigga",
    "tiggdes": "tigga",
    "tiggds": "tigga",
    "tigger": "tigga",
    "tiggerier": "tiggeri",
    "tiggerierna": "tiggeri",
    "tiggeriernas": "tiggeri",
    "tiggeriers": "tiggeri",
    "tiggeriet": "tiggeri",
    "tiggeriets": "tiggeri",
    "tiggeris": "tiggeri",
    "tiggerit": "tiggeri",
    "tiggerits": "tiggeri",
    "tigges": "tigga",
    "tiggs": "tigga",
    "tiggt": "tigga",
    "tiggts": "tigga",
    "tighta": "tight",
    "tightare": "tight",
    "tightares": "tight",
    "tightas": "tight",
    "tightast": "tight",
    "tightaste": "tight",
    "tightastes": "tight",
    "tightasts": "tight",
    "tighte": "tight",
    "tightes": "tight",
    "tightheten": "tighthet",
    "tighthetens": "tighthet",
    "tighthets": "tighthet",
    "tights": "tight",
    "tigit": "tiga",
    "tigits": "tiga",
    "tigrar": "tiger",
    "tigrarna": "tiger",
    "tigrarnas": "tiger",
    "tigrars": "tiger",
    "tigrerade": "tigrerad",
    "tigrerades": "tigrerad",
    "tigrerads": "tigrerad",
    "tigrerat": "tigrerad",
    "tigrerats": "tigrerad",
    "tigs": "tiga",
    "tikar": "tik",
    "tikarna": "tik",
    "tikarnas": "tik",
    "tikars": "tik",
    "tiken": "tik",
    "tikens": "tik",
    "tiks": "tik",
    "tilj": "tilja",
    "tiljan": "tilja",
    "tiljans": "tilja",
    "tiljas": "tilja",
    "tilje": "tilja",
    "tiljor": "tilja",
    "tiljorna": "tilja",
    "tiljornas": "tilja",
    "tiljors": "tilja",
    "tiljs": "tilja",
    "tilla": "tillägga",
    "tillade": "tillägga",
    "tillades": "tillägga",
    "tillag": "tillaga",
    "tillagad": "tillaga",
    "tillagade": "tillaga",
    "tillagades": "tillaga",
    "tillagads": "tillaga",
    "tillagande": "tillaga",
    "tillaganden": "tillagande",
    "tillagandena": "tillagande",
    "tillagandenas": "tillagande",
    "tillagandens": "tillagande",
    "tillagandes": "tillagande",
    "tillagandet": "tillagande",
    "tillagandets": "tillagande",
    "tillagar": "tillaga",
    "tillagas": "tillaga",
    "tillagat": "tillaga",
    "tillagats": "tillaga",
    "tillagd": "tillägga",
    "tillagda": "tillägga",
    "tillagdas": "tillägga",
    "tillagde": "tillägga",
    "tillagdes": "tillägga",
    "tillagds": "tillägga",
    "tillagt": "tillägga",
    "tillagts": "tillägga",
    "tillas": "tillägga",
    "tillbad": "tillbe",
    "tillbade": "tillbe",
    "tillbades": "tillbe",
    "tillbads": "tillbe",
    "tillbakabildades": "tillbakabildas",
    "tillbakabildats": "tillbakabildas",
    "tillbakablickar": "tillbakablick",
    "tillbakablickarna": "tillbakablick",
    "tillbakablickarnas": "tillbakablick",
    "tillbakablickars": "tillbakablick",
    "tillbakablicken": "tillbakablick",
    "tillbakablickens": "tillbakablick",
    "tillbakablicks": "tillbakablick",
    "tillbakadragandes": "tillbakadragande",
    "tillbakadragandet": "tillbakadragande",
    "tillbakadragandets": "tillbakadragande",
    "tillbakadragens": "tillbakadragen",
    "tillbakadraget": "tillbakadragen",
    "tillbakadragets": "tillbakadragen",
    "tillbakadragna": "tillbakadragen",
    "tillbakadragnare": "tillbakadragen",
    "tillbakadragnares": "tillbakadragen",
    "tillbakadragnas": "tillbakadragen",
    "tillbakadragnast": "tillbakadragen",
    "tillbakadragnaste": "tillbakadragen",
    "tillbakadragnastes": "tillbakadragen",
    "tillbakadragnasts": "tillbakadragen",
    "tillbakadragne": "tillbakadragen",
    "tillbakadragnes": "tillbakadragen",
    "tillbakagången": "tillbakagång",
    "tillbakagångens": "tillbakagång",
    "tillbakagångs": "tillbakagång",
    "tillbakalutade": "tillbakalutad",
    "tillbakalutades": "tillbakalutad",
    "tillbakalutads": "tillbakalutad",
    "tillbakalutat": "tillbakalutad",
    "tillbakalutats": "tillbakalutad",
    "tillbakasatta": "tillbakasatt",
    "tillbakasattare": "tillbakasatt",
    "tillbakasattares": "tillbakasatt",
    "tillbakasattas": "tillbakasatt",
    "tillbakasattast": "tillbakasatt",
    "tillbakasattaste": "tillbakasatt",
    "tillbakasattastes": "tillbakasatt",
    "tillbakasattasts": "tillbakasatt",
    "tillbakasatte": "tillbakasatt",
    "tillbakasattes": "tillbakasatt",
    "tillbakasatts": "tillbakasatt",
    "tillbakavis": "tillbakavisa",
    "tillbakavisad": "tillbakavisa",
    "tillbakavisade": "tillbakavisa",
    "tillbakavisades": "tillbakavisa",
    "tillbakavisads": "tillbakavisa",
    "tillbakavisande": "tillbakavisa",
    "tillbakavisanden": "tillbakavisande",
    "tillbakavisandena": "tillbakavisande",
    "tillbakavisandenas": "tillbakavisande",
    "tillbakavisandens": "tillbakavisande",
    "tillbakavisandes": "tillbakavisande",
    "tillbakavisandet": "tillbakavisande",
    "tillbakavisandets": "tillbakavisande",
    "tillbakavisar": "tillbakavisa",
    "tillbakavisas": "tillbakavisa",
    "tillbakavisat": "tillbakavisa",
    "tillbakavisats": "tillbakavisa",
    "tillbed": "tillbe",
    "tillbeda": "tillbe",
    "tillbedande": "tillbe",
    "tillbedandes": "tillbe",
    "tillbedas": "tillbe",
    "tillbedd": "tillbe",
    "tillbedda": "tillbe",
    "tillbeddas": "tillbe",
    "tillbedde": "tillbe",
    "tillbeddes": "tillbe",
    "tillbedds": "tillbe",
    "tillbede": "tillbe",
    "tillbeder": "tillbe",
    "tillbedes": "tillbe",
    "tillbedj": "tillbe",
    "tillbedja": "tillbe",
    "tillbedjande": "tillbe",
    "tillbedjanden": "tillbedjande",
    "tillbedjandena": "tillbedjande",
    "tillbedjandenas": "tillbedjande",
    "tillbedjandens": "tillbedjande",
    "tillbedjandes": "tillbedjande",
    "tillbedjandet": "tillbedjande",
    "tillbedjandets": "tillbedjande",
    "tillbedjans": "tillbedjan",
    "tillbedjar": "tillbedjare",
    "tillbedjaren": "tillbedjare",
    "tillbedjarens": "tillbedjare",
    "tillbedjares": "tillbedjare",
    "tillbedjarna": "tillbedjare",
    "tillbedjarnas": "tillbedjare",
    "tillbedjas": "tillbe",
    "tillbedje": "tillbe",
    "tillbedjer": "tillbe",
    "tillbedjes": "tillbe",
    "tillbeds": "tillbe",
    "tillbeende": "tillbe",
    "tillbeendes": "tillbe",
    "tillbehören": "tillbehör",
    "tillbehörens": "tillbehör",
    "tillbehöret": "tillbehör",
    "tillbehörets": "tillbehör",
    "tillbehörs": "tillbehör",
    "tillber": "tillbe",
    "tillbes": "tillbe",
    "tillbett": "tillbe",
    "tillbetts": "tillbe",
    "tillbland": "tillblanda",
    "tillblandad": "tillblanda",
    "tillblandade": "tillblanda",
    "tillblandades": "tillblanda",
    "tillblandads": "tillblanda",
    "tillblandande": "tillblanda",
    "tillblandanden": "tillblandande",
    "tillblandandena": "tillblandande",
    "tillblandandenas": "tillblandande",
    "tillblandandens": "tillblandande",
    "tillblandandes": "tillblandande",
    "tillblandandet": "tillblandande",
    "tillblandandets": "tillblandande",
    "tillblandar": "tillblanda",
    "tillblandas": "tillblanda",
    "tillblandat": "tillblanda",
    "tillblandats": "tillblanda",
    "tillblivelsen": "tillblivelse",
    "tillblivelsens": "tillblivelse",
    "tillblivelses": "tillblivelse",
    "tillbragt": "tillbringa",
    "tillbragte": "tillbringa",
    "tillbragtes": "tillbringa",
    "tillbragts": "tillbringa",
    "tillbring": "tillbringa",
    "tillbringad": "tillbringa",
    "tillbringade": "tillbringa",
    "tillbringades": "tillbringa",
    "tillbringads": "tillbringa",
    "tillbringande": "tillbringa",
    "tillbringanden": "tillbringande",
    "tillbringandena": "tillbringande",
    "tillbringandenas": "tillbringande",
    "tillbringandens": "tillbringande",
    "tillbringandes": "tillbringande",
    "tillbringandet": "tillbringande",
    "tillbringandets": "tillbringande",
    "tillbringar": "tillbringare",
    "tillbringaren": "tillbringare",
    "tillbringarens": "tillbringare",
    "tillbringares": "tillbringare",
    "tillbringarna": "tillbringare",
    "tillbringarnas": "tillbringare",
    "tillbringas": "tillbringa",
    "tillbringat": "tillbringa",
    "tillbringats": "tillbringa",
    "tillbucklade": "tillbucklad",
    "tillbucklades": "tillbucklad",
    "tillbucklads": "tillbucklad",
    "tillbucklat": "tillbucklad",
    "tillbucklats": "tillbucklad",
    "tillbuden": "tillbud",
    "tillbudens": "tillbud",
    "tillbudet": "tillbud",
    "tillbudets": "tillbud",
    "tillbuds": "tillbud",
    "tillbyggda": "tillbyggd",
    "tillbyggdare": "tillbyggd",
    "tillbyggdares": "tillbyggd",
    "tillbyggdas": "tillbyggd",
    "tillbyggdast": "tillbyggd",
    "tillbyggdaste": "tillbyggd",
    "tillbyggdastes": "tillbyggd",
    "tillbyggdasts": "tillbyggd",
    "tillbyggde": "tillbyggd",
    "tillbyggdes": "tillbyggd",
    "tillbyggds": "tillbyggd",
    "tillbyggnaden": "tillbyggnad",
    "tillbyggnadens": "tillbyggnad",
    "tillbyggnader": "tillbyggnad",
    "tillbyggnaderna": "tillbyggnad",
    "tillbyggnadernas": "tillbyggnad",
    "tillbyggnaders": "tillbyggnad",
    "tillbyggnads": "tillbyggnad",
    "tillbyggt": "tillbyggd",
    "tillbyggts": "tillbyggd",
    "tillbörliga": "tillbörlig",
    "tillbörligare": "tillbörlig",
    "tillbörligares": "tillbörlig",
    "tillbörligas": "tillbörlig",
    "tillbörligast": "tillbörlig",
    "tillbörligaste": "tillbörlig",
    "tillbörligastes": "tillbörlig",
    "tillbörligasts": "tillbörlig",
    "tillbörlige": "tillbörlig",
    "tillbörliges": "tillbörlig",
    "tillbörligheten": "tillbörlighet",
    "tillbörlighetens": "tillbörlighet",
    "tillbörlighets": "tillbörlighet",
    "tillbörligs": "tillbörlig",
    "tillbörligt": "tillbörlig",
    "tillbörligts": "tillbörlig",
    "tilldel": "tilldela",
    "tilldelad": "tilldela",
    "tilldelade": "tilldela",
    "tilldelades": "tilldela",
    "tilldelads": "tilldela",
    "tilldelande": "tilldela",
    "tilldelanden": "tilldelande",
    "tilldelandena": "tilldelande",
    "tilldelandenas": "tilldelande",
    "tilldelandens": "tilldelande",
    "tilldelandes": "tilldelande",
    "tilldelandet": "tilldelande",
    "tilldelandets": "tilldelande",
    "tilldelar": "tilldela",
    "tilldelas": "tilldela",
    "tilldelat": "tilldela",
    "tilldelats": "tilldela",
    "tilldelningar": "tilldelning",
    "tilldelningarna": "tilldelning",
    "tilldelningarnas": "tilldelning",
    "tilldelningars": "tilldelning",
    "tilldelningen": "tilldelning",
    "tilldelningens": "tilldelning",
    "tilldelnings": "tilldelning",
    "tilldragelsen": "tilldragelse",
    "tilldragelsens": "tilldragelse",
    "tilldragelser": "tilldragelse",
    "tilldragelserna": "tilldragelse",
    "tilldragelsernas": "tilldragelse",
    "tilldragelsers": "tilldragelse",
    "tilldragelses": "tilldragelse",
    "tilldöm": "tilldöma",
    "tilldömande": "tilldöma",
    "tilldömanden": "tilldömande",
    "tilldömandena": "tilldömande",
    "tilldömandenas": "tilldömande",
    "tilldömandens": "tilldömande",
    "tilldömandes": "tilldömande",
    "tilldömandet": "tilldömande",
    "tilldömandets": "tilldömande",
    "tilldömas": "tilldöma",
    "tilldömd": "tilldöma",
    "tilldömda": "tilldöma",
    "tilldömdas": "tilldöma",
    "tilldömde": "tilldöma",
    "tilldömdes": "tilldöma",
    "tilldömds": "tilldöma",
    "tilldömer": "tilldöma",
    "tilldöms": "tilldöma",
    "tilldömt": "tilldöma",
    "tilldömts": "tilldöma",
    "tiller": "tillra",
    "tillerkänd": "tillerkänna",
    "tillerkända": "tillerkänna",
    "tillerkändas": "tillerkänna",
    "tillerkände": "tillerkänna",
    "tillerkändes": "tillerkänna",
    "tillerkänds": "tillerkänna",
    "tillerkänn": "tillerkänna",
    "tillerkännande": "tillerkänna",
    "tillerkännanden": "tillerkännande",
    "tillerkännandena": "tillerkännande",
    "tillerkännandenas": "tillerkännande",
    "tillerkännandens": "tillerkännande",
    "tillerkännandes": "tillerkännande",
    "tillerkännandet": "tillerkännande",
    "tillerkännandets": "tillerkännande",
    "tillerkännas": "tillerkänna",
    "tillerkänner": "tillerkänna",
    "tillerkännes": "tillerkänna",
    "tillerkänns": "tillerkänna",
    "tillerkänt": "tillerkänna",
    "tillerkänts": "tillerkänna",
    "tillfall": "tillfalla",
    "tillfallande": "tillfalla",
    "tillfallanden": "tillfallande",
    "tillfallandena": "tillfallande",
    "tillfallandenas": "tillfallande",
    "tillfallandens": "tillfallande",
    "tillfallandes": "tillfallande",
    "tillfallandet": "tillfallande",
    "tillfallandets": "tillfallande",
    "tillfallas": "tillfalla",
    "tillfalle": "tillfalla",
    "tillfallen": "tillfalla",
    "tillfallens": "tillfalla",
    "tillfaller": "tillfalla",
    "tillfalles": "tillfalla",
    "tillfallet": "tillfalla",
    "tillfallets": "tillfalla",
    "tillfallit": "tillfalla",
    "tillfallits": "tillfalla",
    "tillfallna": "tillfalla",
    "tillfallnas": "tillfalla",
    "tillfallne": "tillfalla",
    "tillfallnes": "tillfalla",
    "tillfalls": "tillfalla",
    "tillfarten": "tillfart",
    "tillfartens": "tillfart",
    "tillfarter": "tillfart",
    "tillfarterna": "tillfart",
    "tillfarternas": "tillfart",
    "tillfarters": "tillfart",
    "tillfarts": "tillfart",
    "tillfartsvägar": "tillfartsväg",
    "tillfartsvägarna": "tillfartsväg",
    "tillfartsvägarnas": "tillfartsväg",
    "tillfartsvägars": "tillfartsväg",
    "tillfartsvägen": "tillfartsväg",
    "tillfartsvägens": "tillfartsväg",
    "tillfartsvägs": "tillfartsväg",
    "tillflykten": "tillflykt",
    "tillflyktens": "tillflykt",
    "tillflykts": "tillflykt",
    "tillflyktsorten": "tillflyktsort",
    "tillflyktsortens": "tillflyktsort",
    "tillflyktsorter": "tillflyktsort",
    "tillflyktsorterna": "tillflyktsort",
    "tillflyktsorternas": "tillflyktsort",
    "tillflyktsorters": "tillflyktsort",
    "tillflyktsorts": "tillflyktsort",
    "tillflöden": "tillflöde",
    "tillflödena": "tillflöde",
    "tillflödenas": "tillflöde",
    "tillflödens": "tillflöde",
    "tillflödes": "tillflöde",
    "tillflödet": "tillflöde",
    "tillflödets": "tillflöde",
    "tillfog": "tillfoga",
    "tillfogad": "tillfoga",
    "tillfogade": "tillfoga",
    "tillfogades": "tillfoga",
    "tillfogads": "tillfoga",
    "tillfogande": "tillfoga",
    "tillfoganden": "tillfogande",
    "tillfogandena": "tillfogande",
    "tillfogandenas": "tillfogande",
    "tillfogandens": "tillfogande",
    "tillfogandes": "tillfogande",
    "tillfogandet": "tillfogande",
    "tillfogandets": "tillfogande",
    "tillfogar": "tillfoga",
    "tillfogas": "tillfoga",
    "tillfogat": "tillfoga",
    "tillfogats": "tillfoga",
    "tillfredsställ": "tillfredsställa",
    "tillfredsställande": "tillfredsställa",
    "tillfredsställanden": "tillfredsställande",
    "tillfredsställandena": "tillfredsställande",
    "tillfredsställandenas": "tillfredsställande",
    "tillfredsställandens": "tillfredsställande",
    "tillfredsställandes": "tillfredsställande",
    "tillfredsställandet": "tillfredsställande",
    "tillfredsställandets": "tillfredsställande",
    "tillfredsställas": "tillfredsställa",
    "tillfredsställd": "tillfredsställa",
    "tillfredsställda": "tillfredsställd",
    "tillfredsställdare": "tillfredsställd",
    "tillfredsställdares": "tillfredsställd",
    "tillfredsställdas": "tillfredsställd",
    "tillfredsställdast": "tillfredsställd",
    "tillfredsställdaste": "tillfredsställd",
    "tillfredsställdastes": "tillfredsställd",
    "tillfredsställdasts": "tillfredsställd",
    "tillfredsställde": "tillfredsställd",
    "tillfredsställdes": "tillfredsställd",
    "tillfredsställds": "tillfredsställd",
    "tillfredsställelsen": "tillfredsställelse",
    "tillfredsställelsens": "tillfredsställelse",
    "tillfredsställelses": "tillfredsställelse",
    "tillfredsställer": "tillfredsställa",
    "tillfredsställes": "tillfredsställa",
    "tillfredsställs": "tillfredsställa",
    "tillfredsställt": "tillfredsställd",
    "tillfredsställts": "tillfredsställd",
    "tillfriskn": "tillfriskna",
    "tillfrisknad": "tillfriskna",
    "tillfrisknade": "tillfriskna",
    "tillfrisknades": "tillfriskna",
    "tillfrisknads": "tillfriskna",
    "tillfrisknande": "tillfriskna",
    "tillfrisknandes": "tillfrisknande",
    "tillfrisknandet": "tillfrisknande",
    "tillfrisknandets": "tillfrisknande",
    "tillfrisknar": "tillfriskna",
    "tillfrisknas": "tillfriskna",
    "tillfrisknat": "tillfriskna",
    "tillfrisknats": "tillfriskna",
    "tillfriskningsprogrammen": "tillfriskningsprogram",
    "tillfriskningsprogrammens": "tillfriskningsprogram",
    "tillfriskningsprogrammet": "tillfriskningsprogram",
    "tillfriskningsprogrammets": "tillfriskningsprogram",
    "tillfriskningsprograms": "tillfriskningsprogram",
    "tillfruse": "tillfrysa",
    "tillfrusen": "tillfrysa",
    "tillfrusens": "tillfrysa",
    "tillfruset": "tillfrysa",
    "tillfrusets": "tillfrysa",
    "tillfrusit": "tillfrysa",
    "tillfrusna": "tillfrysa",
    "tillfrusnas": "tillfrysa",
    "tillfrusne": "tillfrysa",
    "tillfrusnes": "tillfrysa",
    "tillfrys": "tillfrysa",
    "tillfrysande": "tillfrysa",
    "tillfrysanden": "tillfrysande",
    "tillfrysandena": "tillfrysande",
    "tillfrysandenas": "tillfrysande",
    "tillfrysandens": "tillfrysande",
    "tillfrysandes": "tillfrysande",
    "tillfrysandet": "tillfrysande",
    "tillfrysandets": "tillfrysande",
    "tillfryse": "tillfrysa",
    "tillfryser": "tillfrysa",
    "tillfryst": "tillfrysa",
    "tillfrysta": "tillfrysa",
    "tillfrystas": "tillfrysa",
    "tillfryste": "tillfrysa",
    "tillfrystes": "tillfrysa",
    "tillfrysts": "tillfrysa",
    "tillfråg": "tillfråga",
    "tillfrågad": "tillfråga",
    "tillfrågade": "tillfråga",
    "tillfrågades": "tillfråga",
    "tillfrågads": "tillfråga",
    "tillfrågande": "tillfråga",
    "tillfråganden": "tillfrågande",
    "tillfrågandena": "tillfrågande",
    "tillfrågandenas": "tillfrågande",
    "tillfrågandens": "tillfrågande",
    "tillfrågandes": "tillfrågande",
    "tillfrågandet": "tillfrågande",
    "tillfrågandets": "tillfrågande",
    "tillfrågar": "tillfråga",
    "tillfrågas": "tillfråga",
    "tillfrågat": "tillfråga",
    "tillfrågats": "tillfråga",
    "tillfrös": "tillfrysa",
    "tillfällen": "tillfälle",
    "tillfällena": "tillfälle",
    "tillfällenas": "tillfälle",
    "tillfällens": "tillfälle",
    "tillfälles": "tillfälle",
    "tillfället": "tillfälle",
    "tillfällets": "tillfälle",
    "tillfälliga": "tillfällig",
    "tillfälligare": "tillfällig",
    "tillfälligares": "tillfällig",
    "tillfälligas": "tillfällig",
    "tillfälligast": "tillfällig",
    "tillfälligaste": "tillfällig",
    "tillfälligastes": "tillfällig",
    "tillfälligasts": "tillfällig",
    "tillfällige": "tillfällig",
    "tillfälliges": "tillfällig",
    "tillfälligheten": "tillfällighet",
    "tillfällighetens": "tillfällighet",
    "tillfälligheter": "tillfällighet",
    "tillfälligheterna": "tillfällighet",
    "tillfälligheternas": "tillfällighet",
    "tillfälligheters": "tillfällighet",
    "tillfällighets": "tillfällighet",
    "tillfällighetsarbeten": "tillfällighetsarbete",
    "tillfällighetsarbetena": "tillfällighetsarbete",
    "tillfällighetsarbetenas": "tillfällighetsarbete",
    "tillfällighetsarbetens": "tillfällighetsarbete",
    "tillfällighetsarbetes": "tillfällighetsarbete",
    "tillfällighetsarbetet": "tillfällighetsarbete",
    "tillfällighetsarbetets": "tillfällighetsarbete",
    "tillfällighetsarbets": "tillfällighetsarbete",
    "tillfällighetsdikten": "tillfällighetsdikt",
    "tillfällighetsdiktens": "tillfällighetsdikt",
    "tillfällighetsdikter": "tillfällighetsdikt",
    "tillfällighetsdikterna": "tillfällighetsdikt",
    "tillfällighetsdikternas": "tillfällighetsdikt",
    "tillfällighetsdikters": "tillfällighetsdikt",
    "tillfällighetsdikts": "tillfällighetsdikt",
    "tillfällighetsförbrytar": "tillfällighetsförbrytare",
    "tillfällighetsförbrytaren": "tillfällighetsförbrytare",
    "tillfällighetsförbrytarens": "tillfällighetsförbrytare",
    "tillfällighetsförbrytares": "tillfällighetsförbrytare",
    "tillfällighetsförbrytarna": "tillfällighetsförbrytare",
    "tillfällighetsförbrytarnas": "tillfällighetsförbrytare",
    "tillfällighetsversar": "tillfällighetsvers",
    "tillfällighetsversarna": "tillfällighetsvers",
    "tillfällighetsversarnas": "tillfällighetsvers",
    "tillfällighetsversars": "tillfällighetsvers",
    "tillfällighetsversen": "tillfällighetsvers",
    "tillfällighetsversens": "tillfällighetsvers",
    "tillfällighetsverser": "tillfällighetsvers",
    "tillfällighetsverserna": "tillfällighetsvers",
    "tillfällighetsversernas": "tillfällighetsvers",
    "tillfällighetsversers": "tillfällighetsvers",
    "tillfälligs": "tillfällig",
    "tillfälligt": "tillfällig",
    "tillfälligts": "tillfällig",
    "tillfälls": "tillfälle",
    "tillfångatag": "tillfångata",
    "tillfångataga": "tillfångata",
    "tillfångatagande": "tillfångata",
    "tillfångataganden": "tillfångatagande",
    "tillfångatagandena": "tillfångatagande",
    "tillfångatagandenas": "tillfångatagande",
    "tillfångatagandens": "tillfångatagande",
    "tillfångatagandes": "tillfångatagande",
    "tillfångatagandet": "tillfångatagande",
    "tillfångatagandets": "tillfångatagande",
    "tillfångatagas": "tillfångata",
    "tillfångatage": "tillfångata",
    "tillfångatagen": "tillfångata",
    "tillfångatagens": "tillfångata",
    "tillfångatager": "tillfångata",
    "tillfångatages": "tillfångata",
    "tillfångataget": "tillfångata",
    "tillfångatagets": "tillfångata",
    "tillfångatagit": "tillfångata",
    "tillfångatagits": "tillfångata",
    "tillfångatagna": "tillfångata",
    "tillfångatagnas": "tillfångata",
    "tillfångatagne": "tillfångata",
    "tillfångatagnes": "tillfångata",
    "tillfångatags": "tillfångata",
    "tillfångatar": "tillfångata",
    "tillfångatas": "tillfångata",
    "tillfångatog": "tillfångata",
    "tillfångatoge": "tillfångata",
    "tillfångatoges": "tillfångata",
    "tillfångatogs": "tillfångata",
    "tillföll": "tillfalla",
    "tillfölle": "tillfalla",
    "tillfölles": "tillfalla",
    "tillfölls": "tillfalla",
    "tillför": "tillföra",
    "tillförande": "tillföra",
    "tillföranden": "tillförande",
    "tillförandena": "tillförande",
    "tillförandenas": "tillförande",
    "tillförandens": "tillförande",
    "tillförandes": "tillförande",
    "tillförandet": "tillförande",
    "tillförandets": "tillförande",
    "tillföras": "tillföra",
    "tillförd": "tillföra",
    "tillförda": "tillföra",
    "tillfördas": "tillföra",
    "tillförde": "tillföra",
    "tillfördes": "tillföra",
    "tillförds": "tillföra",
    "tillföres": "tillföra",
    "tillförlitliga": "tillförlitlig",
    "tillförlitligare": "tillförlitlig",
    "tillförlitligares": "tillförlitlig",
    "tillförlitligas": "tillförlitlig",
    "tillförlitligast": "tillförlitlig",
    "tillförlitligaste": "tillförlitlig",
    "tillförlitligastes": "tillförlitlig",
    "tillförlitligasts": "tillförlitlig",
    "tillförlitlige": "tillförlitlig",
    "tillförlitliges": "tillförlitlig",
    "tillförlitligheten": "tillförlitlighet",
    "tillförlitlighetens": "tillförlitlighet",
    "tillförlitligheter": "tillförlitlighet",
    "tillförlitligheterna": "tillförlitlighet",
    "tillförlitligheternas": "tillförlitlighet",
    "tillförlitligheters": "tillförlitlighet",
    "tillförlitlighets": "tillförlitlighet",
    "tillförlitlighetstävlingar": "tillförlitlighetstävling",
    "tillförlitlighetstävlingarna": "tillförlitlighetstävling",
    "tillförlitlighetstävlingarnas": "tillförlitlighetstävling",
    "tillförlitlighetstävlingars": "tillförlitlighetstävling",
    "tillförlitlighetstävlingen": "tillförlitlighetstävling",
    "tillförlitlighetstävlingens": "tillförlitlighetstävling",
    "tillförlitlighetstävlings": "tillförlitlighetstävling",
    "tillförlitligs": "tillförlitlig",
    "tillförlitligt": "tillförlitlig",
    "tillförlitligts": "tillförlitlig",
    "tillförordnade": "tillförordnad",
    "tillförordnades": "tillförordnad",
    "tillförordnads": "tillförordnad",
    "tillförordnat": "tillförordnad",
    "tillförordnats": "tillförordnad",
    "tillförs": "tillföra",
    "tillförseln": "tillförsel",
    "tillförselns": "tillförsel",
    "tillförsels": "tillförsel",
    "tillförsikten": "tillförsikt",
    "tillförsiktens": "tillförsikt",
    "tillförsikts": "tillförsikt",
    "tillförsäkrad": "tillförsäkra",
    "tillförsäkrade": "tillförsäkra",
    "tillförsäkrades": "tillförsäkra",
    "tillförsäkrads": "tillförsäkra",
    "tillförsäkrande": "tillförsäkra",
    "tillförsäkranden": "tillförsäkrande",
    "tillförsäkrandena": "tillförsäkrande",
    "tillförsäkrandenas": "tillförsäkrande",
    "tillförsäkrandens": "tillförsäkrande",
    "tillförsäkrandes": "tillförsäkrande",
    "tillförsäkrandet": "tillförsäkrande",
    "tillförsäkrandets": "tillförsäkrande",
    "tillförsäkrans": "tillförsäkran",
    "tillförsäkrar": "tillförsäkra",
    "tillförsäkras": "tillförsäkra",
    "tillförsäkrat": "tillförsäkra",
    "tillförsäkrats": "tillförsäkra",
    "tillfört": "tillföra",
    "tillförts": "tillföra",
    "tillgav": "tillge",
    "tillgavs": "tillge",
    "tillgeende": "tillge",
    "tillgeendes": "tillge",
    "tillger": "tillge",
    "tillges": "tillge",
    "tillgett": "tillge",
    "tillgetts": "tillge",
    "tillgick": "tillgå",
    "tillgicks": "tillgå",
    "tillgiften": "tillgift",
    "tillgiftens": "tillgift",
    "tillgifts": "tillgift",
    "tillginge": "tillgå",
    "tillginges": "tillgå",
    "tillgiv": "tillge",
    "tillgiva": "tillge",
    "tillgivande": "tillge",
    "tillgivanden": "tillgivande",
    "tillgivandena": "tillgivande",
    "tillgivandenas": "tillgivande",
    "tillgivandens": "tillgivande",
    "tillgivandes": "tillgivande",
    "tillgivandet": "tillgivande",
    "tillgivandets": "tillgivande",
    "tillgivas": "tillge",
    "tillgive": "tillge",
    "tillgiven": "tillge",
    "tillgivenheten": "tillgivenhet",
    "tillgivenhetens": "tillgivenhet",
    "tillgivenheter": "tillgivenhet",
    "tillgivenheterna": "tillgivenhet",
    "tillgivenheternas": "tillgivenhet",
    "tillgivenheters": "tillgivenhet",
    "tillgivenhets": "tillgivenhet",
    "tillgivens": "tillgiven",
    "tillgiver": "tillge",
    "tillgives": "tillge",
    "tillgivet": "tillgiven",
    "tillgivets": "tillgiven",
    "tillgivit": "tillge",
    "tillgivits": "tillge",
    "tillgivna": "tillgiven",
    "tillgivnare": "tillgiven",
    "tillgivnares": "tillgiven",
    "tillgivnas": "tillgiven",
    "tillgivnast": "tillgiven",
    "tillgivnaste": "tillgiven",
    "tillgivnastes": "tillgiven",
    "tillgivnasts": "tillgiven",
    "tillgivne": "tillgiven",
    "tillgivnes": "tillgiven",
    "tillgivs": "tillge",
    "tillgjorda": "tillgjord",
    "tillgjordare": "tillgjord",
    "tillgjordares": "tillgjord",
    "tillgjordas": "tillgjord",
    "tillgjordast": "tillgjord",
    "tillgjordaste": "tillgjord",
    "tillgjordastes": "tillgjord",
    "tillgjordasts": "tillgjord",
    "tillgjorde": "tillgjord",
    "tillgjordes": "tillgjord",
    "tillgjordheten": "tillgjordhet",
    "tillgjordhetens": "tillgjordhet",
    "tillgjordheter": "tillgjordhet",
    "tillgjordheterna": "tillgjordhet",
    "tillgjordheternas": "tillgjordhet",
    "tillgjordheters": "tillgjordhet",
    "tillgjordhets": "tillgjordhet",
    "tillgjords": "tillgjord",
    "tillgjort": "tillgjord",
    "tillgjorts": "tillgjord",
    "tillgodohavanden": "tillgodohavande",
    "tillgodohavandena": "tillgodohavande",
    "tillgodohavandenas": "tillgodohavande",
    "tillgodohavandens": "tillgodohavande",
    "tillgodohavandes": "tillgodohavande",
    "tillgodohavandet": "tillgodohavande",
    "tillgodohavandets": "tillgodohavande",
    "tillgodokvitton": "tillgodokvitto",
    "tillgodokvittona": "tillgodokvitto",
    "tillgodokvittonas": "tillgodokvitto",
    "tillgodokvittons": "tillgodokvitto",
    "tillgodokvittos": "tillgodokvitto",
    "tillgodokvittot": "tillgodokvitto",
    "tillgodokvittots": "tillgodokvitto",
    "tillgodoräkn": "tillgodoräkna",
    "tillgodoräknad": "tillgodoräkna",
    "tillgodoräknade": "tillgodoräkna",
    "tillgodoräknades": "tillgodoräkna",
    "tillgodoräknads": "tillgodoräkna",
    "tillgodoräknande": "tillgodoräkna",
    "tillgodoräknanden": "tillgodoräknande",
    "tillgodoräknandena": "tillgodoräknande",
    "tillgodoräknandenas": "tillgodoräknande",
    "tillgodoräknandens": "tillgodoräknande",
    "tillgodoräknandes": "tillgodoräknande",
    "tillgodoräknandet": "tillgodoräknande",
    "tillgodoräknandets": "tillgodoräknande",
    "tillgodoräknar": "tillgodoräkna",
    "tillgodoräknas": "tillgodoräkna",
    "tillgodoräknat": "tillgodoräkna",
    "tillgodoräknats": "tillgodoräkna",
    "tillgodosedd": "tillgodose",
    "tillgodosedda": "tillgodose",
    "tillgodoseddas": "tillgodose",
    "tillgodosedde": "tillgodose",
    "tillgodoseddes": "tillgodose",
    "tillgodosedds": "tillgodose",
    "tillgodoseende": "tillgodose",
    "tillgodoseenden": "tillgodoseende",
    "tillgodoseendena": "tillgodoseende",
    "tillgodoseendenas": "tillgodoseende",
    "tillgodoseendens": "tillgodoseende",
    "tillgodoseendes": "tillgodoseende",
    "tillgodoseendet": "tillgodoseende",
    "tillgodoseendets": "tillgodoseende",
    "tillgodoser": "tillgodose",
    "tillgodoses": "tillgodose",
    "tillgodosett": "tillgodose",
    "tillgodosetts": "tillgodose",
    "tillgodosåg": "tillgodose",
    "tillgodosåge": "tillgodose",
    "tillgodosåges": "tillgodose",
    "tillgodosågs": "tillgodose",
    "tillgrep": "tillgripa",
    "tillgreppen": "tillgrepp",
    "tillgreppens": "tillgrepp",
    "tillgreppet": "tillgrepp",
    "tillgreppets": "tillgrepp",
    "tillgrepps": "tillgrepp",
    "tillgreps": "tillgripa",
    "tillgrip": "tillgripa",
    "tillgripande": "tillgripa",
    "tillgripanden": "tillgripande",
    "tillgripandena": "tillgripande",
    "tillgripandenas": "tillgripande",
    "tillgripandens": "tillgripande",
    "tillgripandes": "tillgripande",
    "tillgripandet": "tillgripande",
    "tillgripandets": "tillgripande",
    "tillgripas": "tillgripa",
    "tillgripe": "tillgripa",
    "tillgripen": "tillgripa",
    "tillgripens": "tillgripa",
    "tillgriper": "tillgripa",
    "tillgripes": "tillgripa",
    "tillgripet": "tillgripa",
    "tillgripets": "tillgripa",
    "tillgripit": "tillgripa",
    "tillgripits": "tillgripa",
    "tillgripna": "tillgripa",
    "tillgripnas": "tillgripa",
    "tillgripne": "tillgripa",
    "tillgripnes": "tillgripa",
    "tillgrips": "tillgripa",
    "tillgängliga": "tillgänglig",
    "tillgängligare": "tillgänglig",
    "tillgängligares": "tillgänglig",
    "tillgängligas": "tillgänglig",
    "tillgängligast": "tillgänglig",
    "tillgängligaste": "tillgänglig",
    "tillgängligastes": "tillgänglig",
    "tillgängligasts": "tillgänglig",
    "tillgänglige": "tillgänglig",
    "tillgängliges": "tillgänglig",
    "tillgängligheten": "tillgänglighet",
    "tillgänglighetens": "tillgänglighet",
    "tillgänglighets": "tillgänglighet",
    "tillgängligs": "tillgänglig",
    "tillgängligt": "tillgänglig",
    "tillgängligts": "tillgänglig",
    "tillgående": "tillgå",
    "tillgåenden": "tillgående",
    "tillgåendena": "tillgående",
    "tillgåendenas": "tillgående",
    "tillgåendens": "tillgående",
    "tillgåendes": "tillgående",
    "tillgåendet": "tillgående",
    "tillgåendets": "tillgående",
    "tillgångar": "tillgång",
    "tillgångarna": "tillgångar",
    "tillgångarnas": "tillgångar",
    "tillgångars": "tillgångar",
    "tillgången": "tillgång",
    "tillgångens": "tillgång",
    "tillgångs": "tillgångar",
    "tillgår": "tillgå",
    "tillgås": "tillgå",
    "tillgått": "tillgå",
    "tillgåtts": "tillgå",
    "tillgåve": "tillge",
    "tillgåves": "tillge",
    "tillhandahåll": "tillhandahålla",
    "tillhandahållande": "tillhandahålla",
    "tillhandahållanden": "tillhandahållande",
    "tillhandahållandena": "tillhandahållande",
    "tillhandahållandenas": "tillhandahållande",
    "tillhandahållandens": "tillhandahållande",
    "tillhandahållandes": "tillhandahållande",
    "tillhandahållandet": "tillhandahållande",
    "tillhandahållandets": "tillhandahållande",
    "tillhandahållas": "tillhandahålla",
    "tillhandahålle": "tillhandahålla",
    "tillhandahållen": "tillhandahålla",
    "tillhandahållens": "tillhandahålla",
    "tillhandahåller": "tillhandahålla",
    "tillhandahålles": "tillhandahålla",
    "tillhandahållet": "tillhandahålla",
    "tillhandahållets": "tillhandahålla",
    "tillhandahållit": "tillhandahålla",
    "tillhandahållits": "tillhandahålla",
    "tillhandahållna": "tillhandahålla",
    "tillhandahållnas": "tillhandahålla",
    "tillhandahållne": "tillhandahålla",
    "tillhandahållnes": "tillhandahålla",
    "tillhandahålls": "tillhandahålla",
    "tillhandahöll": "tillhandahålla",
    "tillhandahölle": "tillhandahålla",
    "tillhandahölles": "tillhandahålla",
    "tillhandahölls": "tillhandahålla",
    "tillhjälpen": "tillhjälp",
    "tillhjälpens": "tillhjälp",
    "tillhjälps": "tillhjälp",
    "tillhyggen": "tillhygge",
    "tillhyggena": "tillhygge",
    "tillhyggenas": "tillhygge",
    "tillhyggens": "tillhygge",
    "tillhygges": "tillhygge",
    "tillhygget": "tillhygge",
    "tillhyggets": "tillhygge",
    "tillhyggs": "tillhygge",
    "tillhåll": "tillhålla",
    "tillhållande": "tillhålla",
    "tillhållanden": "tillhållande",
    "tillhållandena": "tillhållande",
    "tillhållandenas": "tillhållande",
    "tillhållandens": "tillhållande",
    "tillhållandes": "tillhållande",
    "tillhållandet": "tillhållande",
    "tillhållandets": "tillhållande",
    "tillhållarfjädern": "tillhållarfjäder",
    "tillhållarfjäderns": "tillhållarfjäder",
    "tillhållarfjäders": "tillhållarfjäder",
    "tillhållarfjädrar": "tillhållarfjäder",
    "tillhållarfjädrarna": "tillhållarfjäder",
    "tillhållarfjädrarnas": "tillhållarfjäder",
    "tillhållarfjädrars": "tillhållarfjäder",
    "tillhållas": "tillhålla",
    "tillhålle": "tillhålla",
    "tillhållen": "tillhålla",
    "tillhållens": "tillhålla",
    "tillhåller": "tillhålla",
    "tillhålles": "tillhålla",
    "tillhållet": "tillhålla",
    "tillhållets": "tillhålla",
    "tillhållit": "tillhålla",
    "tillhållits": "tillhålla",
    "tillhållna": "tillhålla",
    "tillhållnas": "tillhålla",
    "tillhållne": "tillhålla",
    "tillhållnes": "tillhålla",
    "tillhålls": "tillhålla",
    "tillhöll": "tillhålla",
    "tillhölle": "tillhålla",
    "tillhölles": "tillhålla",
    "tillhölls": "tillhålla",
    "tillhör": "tillhöra",
    "tillhörande": "tillhöra",
    "tillhöranden": "tillhörande",
    "tillhörandena": "tillhörande",
    "tillhörandenas": "tillhörande",
    "tillhörandens": "tillhörande",
    "tillhörandes": "tillhörande",
    "tillhörandet": "tillhörande",
    "tillhörandets": "tillhörande",
    "tillhöras": "tillhöra",
    "tillhörd": "tillhöra",
    "tillhörda": "tillhöra",
    "tillhördas": "tillhöra",
    "tillhörde": "tillhöra",
    "tillhördes": "tillhöra",
    "tillhörds": "tillhöra",
    "tillhöres": "tillhöra",
    "tillhöriga": "tillhörig",
    "tillhörigare": "tillhörig",
    "tillhörigares": "tillhörig",
    "tillhörigas": "tillhörig",
    "tillhörigast": "tillhörig",
    "tillhörigaste": "tillhörig",
    "tillhörigastes": "tillhörig",
    "tillhörigasts": "tillhörig",
    "tillhörige": "tillhörig",
    "tillhöriges": "tillhörig",
    "tillhörigheten": "tillhörighet",
    "tillhörighetens": "tillhörighet",
    "tillhörigheter": "tillhörighet",
    "tillhörigheterna": "tillhörigheter",
    "tillhörigheternas": "tillhörigheter",
    "tillhörigheters": "tillhörigheter",
    "tillhörighets": "tillhörigheter",
    "tillhörigs": "tillhörig",
    "tillhörigt": "tillhörig",
    "tillhörigts": "tillhörig",
    "tillhörs": "tillhöra",
    "tillhört": "tillhöra",
    "tillhörts": "tillhöra",
    "tillintetgjord": "tillintetgöra",
    "tillintetgjorda": "tillintetgöra",
    "tillintetgjordare": "tillintetgjord",
    "tillintetgjordares": "tillintetgjord",
    "tillintetgjordas": "tillintetgöra",
    "tillintetgjordast": "tillintetgjord",
    "tillintetgjordaste": "tillintetgjord",
    "tillintetgjordastes": "tillintetgjord",
    "tillintetgjordasts": "tillintetgjord",
    "tillintetgjorde": "tillintetgöra",
    "tillintetgjordes": "tillintetgöra",
    "tillintetgjords": "tillintetgöra",
    "tillintetgjort": "tillintetgöra",
    "tillintetgjorts": "tillintetgöra",
    "tillintetgör": "tillintetgöra",
    "tillintetgörande": "tillintetgöra",
    "tillintetgöranden": "tillintetgörande",
    "tillintetgörandena": "tillintetgörande",
    "tillintetgörandenas": "tillintetgörande",
    "tillintetgörandens": "tillintetgörande",
    "tillintetgörandes": "tillintetgörande",
    "tillintetgörandet": "tillintetgörande",
    "tillintetgörandets": "tillintetgörande",
    "tillintetgöras": "tillintetgöra",
    "tillintetgöres": "tillintetgöra",
    "tillintetgörs": "tillintetgöra",
    "tilliten": "tillit",
    "tillitens": "tillit",
    "tillits": "tillit",
    "tillitsfulla": "tillitsfull",
    "tillitsfullare": "tillitsfull",
    "tillitsfullares": "tillitsfull",
    "tillitsfullas": "tillitsfull",
    "tillitsfullast": "tillitsfull",
    "tillitsfullaste": "tillitsfull",
    "tillitsfullastes": "tillitsfull",
    "tillitsfullasts": "tillitsfull",
    "tillitsfulle": "tillitsfull",
    "tillitsfulles": "tillitsfull",
    "tillitsfullheten": "tillitsfullhet",
    "tillitsfullhetens": "tillitsfullhet",
    "tillitsfullhets": "tillitsfullhet",
    "tillitsfulls": "tillitsfull",
    "tillitsfullt": "tillitsfull",
    "tillitsfullts": "tillitsfull",
    "tilljämningar": "tilljämning",
    "tilljämningarna": "tilljämning",
    "tilljämningarnas": "tilljämning",
    "tilljämningars": "tilljämning",
    "tilljämningen": "tilljämning",
    "tilljämningens": "tilljämning",
    "tilljämnings": "tilljämning",
    "tillkall": "tillkalla",
    "tillkallad": "tillkalla",
    "tillkallade": "tillkalla",
    "tillkallades": "tillkalla",
    "tillkallads": "tillkalla",
    "tillkallande": "tillkalla",
    "tillkallanden": "tillkallande",
    "tillkallandena": "tillkallande",
    "tillkallandenas": "tillkallande",
    "tillkallandens": "tillkallande",
    "tillkallandes": "tillkallande",
    "tillkallandet": "tillkallande",
    "tillkallandets": "tillkallande",
    "tillkallar": "tillkalla",
    "tillkallas": "tillkalla",
    "tillkallat": "tillkalla",
    "tillkallats": "tillkalla",
    "tillklippta": "tillklippt",
    "tillklipptare": "tillklippt",
    "tillklipptares": "tillklippt",
    "tillklipptas": "tillklippt",
    "tillklipptast": "tillklippt",
    "tillklipptaste": "tillklippt",
    "tillklipptastes": "tillklippt",
    "tillklipptasts": "tillklippt",
    "tillklippte": "tillklippt",
    "tillklipptes": "tillklippt",
    "tillklippts": "tillklippt",
    "tillknycklade": "tillknycklad",
    "tillknycklades": "tillknycklad",
    "tillknycklads": "tillknycklad",
    "tillknycklat": "tillknycklad",
    "tillknycklats": "tillknycklad",
    "tillknäppta": "tillknäppt",
    "tillknäpptare": "tillknäppt",
    "tillknäpptares": "tillknäppt",
    "tillknäpptas": "tillknäppt",
    "tillknäpptast": "tillknäppt",
    "tillknäpptaste": "tillknäppt",
    "tillknäpptastes": "tillknäppt",
    "tillknäpptasts": "tillknäppt",
    "tillknäppte": "tillknäppt",
    "tillknäpptes": "tillknäppt",
    "tillknäpptheten": "tillknäppthet",
    "tillknäppthetens": "tillknäppthet",
    "tillknäppthets": "tillknäppthet",
    "tillknäppts": "tillknäppt",
    "tillkom": "tillkomma",
    "tillkomet": "tillkomma",
    "tillkomets": "tillkomma",
    "tillkommande": "tillkomma",
    "tillkommanden": "tillkommande",
    "tillkommandena": "tillkommande",
    "tillkommandenas": "tillkommande",
    "tillkommandens": "tillkommande",
    "tillkommandes": "tillkommande",
    "tillkommandet": "tillkommande",
    "tillkommandets": "tillkommande",
    "tillkommas": "tillkomma",
    "tillkomme": "tillkomma",
    "tillkommen": "tillkomma",
    "tillkommens": "tillkomma",
    "tillkommer": "tillkomma",
    "tillkommes": "tillkomma",
    "tillkommit": "tillkomma",
    "tillkommits": "tillkomma",
    "tillkomna": "tillkomma",
    "tillkomnas": "tillkomma",
    "tillkomne": "tillkomma",
    "tillkomnes": "tillkomma",
    "tillkoms": "tillkomma",
    "tillkomsten": "tillkomst",
    "tillkomstens": "tillkomst",
    "tillkomsts": "tillkomst",
    "tillkopplad": "tillkoppla",
    "tillkopplade": "tillkoppla",
    "tillkopplades": "tillkoppla",
    "tillkopplads": "tillkoppla",
    "tillkopplande": "tillkoppla",
    "tillkopplanden": "tillkopplande",
    "tillkopplandena": "tillkopplande",
    "tillkopplandenas": "tillkopplande",
    "tillkopplandens": "tillkopplande",
    "tillkopplandes": "tillkopplande",
    "tillkopplandet": "tillkopplande",
    "tillkopplandets": "tillkopplande",
    "tillkopplar": "tillkoppla",
    "tillkopplas": "tillkoppla",
    "tillkopplat": "tillkoppla",
    "tillkopplats": "tillkoppla",
    "tillkorkade": "tillkorkad",
    "tillkorkades": "tillkorkad",
    "tillkorkads": "tillkorkad",
    "tillkorkat": "tillkorkad",
    "tillkorkats": "tillkorkad",
    "tillkortakommanden": "tillkortakommande",
    "tillkortakommandena": "tillkortakommande",
    "tillkortakommandenas": "tillkortakommande",
    "tillkortakommandens": "tillkortakommande",
    "tillkortakommandes": "tillkortakommande",
    "tillkortakommandet": "tillkortakommande",
    "tillkortakommandets": "tillkortakommande",
    "tillkrånglade": "tillkrånglad",
    "tillkrånglades": "tillkrånglad",
    "tillkrånglads": "tillkrånglad",
    "tillkrånglat": "tillkrånglad",
    "tillkrånglats": "tillkrånglad",
    "tillkämpade": "tillkämpad",
    "tillkämpades": "tillkämpad",
    "tillkämpads": "tillkämpad",
    "tillkämpat": "tillkämpad",
    "tillkämpats": "tillkämpad",
    "tillkännagav": "tillkännage",
    "tillkännagavs": "tillkännage",
    "tillkännageende": "tillkännage",
    "tillkännageendes": "tillkännage",
    "tillkännager": "tillkännage",
    "tillkännages": "tillkännage",
    "tillkännagett": "tillkännage",
    "tillkännagetts": "tillkännage",
    "tillkännagiv": "tillkännage",
    "tillkännagiva": "tillkännage",
    "tillkännagivande": "tillkännage",
    "tillkännagivanden": "tillkännagivande",
    "tillkännagivandena": "tillkännagivande",
    "tillkännagivandenas": "tillkännagivande",
    "tillkännagivandens": "tillkännagivande",
    "tillkännagivandes": "tillkännagivande",
    "tillkännagivandet": "tillkännagivande",
    "tillkännagivandets": "tillkännagivande",
    "tillkännagivas": "tillkännage",
    "tillkännagive": "tillkännage",
    "tillkännagiven": "tillkännage",
    "tillkännagivens": "tillkännage",
    "tillkännagiver": "tillkännage",
    "tillkännagives": "tillkännage",
    "tillkännagivet": "tillkännage",
    "tillkännagivets": "tillkännage",
    "tillkännagivit": "tillkännage",
    "tillkännagivits": "tillkännage",
    "tillkännagivna": "tillkännage",
    "tillkännagivnas": "tillkännage",
    "tillkännagivne": "tillkännage",
    "tillkännagivnes": "tillkännage",
    "tillkännagivs": "tillkännage",
    "tillkännagåve": "tillkännage",
    "tillkännagåves": "tillkännage",
    "tillmakningar": "tillmakning",
    "tillmakningarna": "tillmakning",
    "tillmakningarnas": "tillmakning",
    "tillmakningars": "tillmakning",
    "tillmakningen": "tillmakning",
    "tillmakningens": "tillmakning",
    "tillmaknings": "tillmakning",
    "tillmälen": "tillmäle",
    "tillmälena": "tillmäle",
    "tillmälenas": "tillmäle",
    "tillmälens": "tillmäle",
    "tillmäles": "tillmäle",
    "tillmälet": "tillmäle",
    "tillmälets": "tillmäle",
    "tillmäls": "tillmäle",
    "tillmät": "tillmäta",
    "tillmätande": "tillmäta",
    "tillmätanden": "tillmätande",
    "tillmätandena": "tillmätande",
    "tillmätandenas": "tillmätande",
    "tillmätandens": "tillmätande",
    "tillmätandes": "tillmätande",
    "tillmätandet": "tillmätande",
    "tillmätandets": "tillmätande",
    "tillmätas": "tillmäta",
    "tillmäter": "tillmäta",
    "tillmätes": "tillmäta",
    "tillmäts": "tillmäta",
    "tillmätt": "tillmäta",
    "tillmätta": "tillmäta",
    "tillmättas": "tillmäta",
    "tillmätte": "tillmäta",
    "tillmättes": "tillmäta",
    "tillmätts": "tillmäta",
    "tillmötesgick": "tillmötesgå",
    "tillmötesgicks": "tillmötesgå",
    "tillmötesginge": "tillmötesgå",
    "tillmötesginges": "tillmötesgå",
    "tillmötesgående": "tillmötesgå",
    "tillmötesgåendes": "tillmötesgående",
    "tillmötesgåendet": "tillmötesgående",
    "tillmötesgåendets": "tillmötesgående",
    "tillmötesgår": "tillmötesgå",
    "tillmötesgås": "tillmötesgå",
    "tillmötesgått": "tillmötesgå",
    "tillmötesgåtts": "tillmötesgå",
    "tillnamnen": "tillnamn",
    "tillnamnens": "tillnamn",
    "tillnamnet": "tillnamn",
    "tillnamnets": "tillnamn",
    "tillnamns": "tillnamn",
    "tillnyktringar": "tillnyktring",
    "tillnyktringarna": "tillnyktring",
    "tillnyktringarnas": "tillnyktring",
    "tillnyktringars": "tillnyktring",
    "tillnyktringen": "tillnyktring",
    "tillnyktringens": "tillnyktring",
    "tillnyktrings": "tillnyktring",
    "tilloppen": "tillopp",
    "tilloppens": "tillopp",
    "tilloppet": "tillopp",
    "tilloppets": "tillopp",
    "tillopps": "tillopp",
    "tillpass": "tillpassa",
    "tillpassad": "tillpassa",
    "tillpassade": "tillpassa",
    "tillpassades": "tillpassa",
    "tillpassads": "tillpassa",
    "tillpassande": "tillpassa",
    "tillpassanden": "tillpassande",
    "tillpassandena": "tillpassande",
    "tillpassandenas": "tillpassande",
    "tillpassandens": "tillpassande",
    "tillpassandes": "tillpassande",
    "tillpassandet": "tillpassande",
    "tillpassandets": "tillpassande",
    "tillpassar": "tillpassa",
    "tillpassas": "tillpassa",
    "tillpassat": "tillpassa",
    "tillpassats": "tillpassa",
    "tillplatt": "tillplatta",
    "tillplattad": "tillplatta",
    "tillplattade": "tillplattad",
    "tillplattades": "tillplattad",
    "tillplattads": "tillplattad",
    "tillplattande": "tillplatta",
    "tillplattanden": "tillplattande",
    "tillplattandena": "tillplattande",
    "tillplattandenas": "tillplattande",
    "tillplattandens": "tillplattande",
    "tillplattandes": "tillplattande",
    "tillplattandet": "tillplattande",
    "tillplattandets": "tillplattande",
    "tillplattar": "tillplatta",
    "tillplattas": "tillplatta",
    "tillplattat": "tillplattad",
    "tillplattats": "tillplattad",
    "tillplattningar": "tillplattning",
    "tillplattningarna": "tillplattning",
    "tillplattningarnas": "tillplattning",
    "tillplattningars": "tillplattning",
    "tillplattningen": "tillplattning",
    "tillplattningens": "tillplattning",
    "tillplattnings": "tillplattning",
    "tillproppade": "tillproppad",
    "tillproppades": "tillproppad",
    "tillproppads": "tillproppad",
    "tillproppat": "tillproppad",
    "tillproppats": "tillproppad",
    "tillrad": "tillra",
    "tillrade": "tillra",
    "tillrades": "tillra",
    "tillrads": "tillra",
    "tillrande": "tillra",
    "tillranden": "tillrande",
    "tillrandena": "tillrande",
    "tillrandenas": "tillrande",
    "tillrandens": "tillrande",
    "tillrandes": "tillrande",
    "tillrandet": "tillrande",
    "tillrandets": "tillrande",
    "tillrar": "tillra",
    "tillras": "tillra",
    "tillrat": "tillra",
    "tillrats": "tillra",
    "tillred": "tillreda",
    "tillredande": "tillreda",
    "tillredanden": "tillredande",
    "tillredandena": "tillredande",
    "tillredandenas": "tillredande",
    "tillredandens": "tillredande",
    "tillredandes": "tillredande",
    "tillredandet": "tillredande",
    "tillredandets": "tillredande",
    "tillredas": "tillreda",
    "tillredd": "tillreda",
    "tillredda": "tillreda",
    "tillreddas": "tillreda",
    "tillredde": "tillreda",
    "tillreddes": "tillreda",
    "tillredds": "tillreda",
    "tillreder": "tillreda",
    "tillredes": "tillreda",
    "tillreds": "tillreda",
    "tillrett": "tillreda",
    "tillretts": "tillreda",
    "tillropen": "tillrop",
    "tillropens": "tillrop",
    "tillropet": "tillrop",
    "tillropets": "tillrop",
    "tillrops": "tillrop",
    "tillrufsade": "tillrufsad",
    "tillrufsades": "tillrufsad",
    "tillrufsads": "tillrufsad",
    "tillrufsat": "tillrufsad",
    "tillrufsats": "tillrufsad",
    "tillryggala": "tillryggalägga",
    "tillryggalade": "tillryggalägga",
    "tillryggalades": "tillryggalägga",
    "tillryggalagd": "tillryggalägga",
    "tillryggalagda": "tillryggalägga",
    "tillryggalagdas": "tillryggalägga",
    "tillryggalagde": "tillryggalägga",
    "tillryggalagdes": "tillryggalägga",
    "tillryggalagds": "tillryggalägga",
    "tillryggalagt": "tillryggalägga",
    "tillryggalagts": "tillryggalägga",
    "tillryggalas": "tillryggalägga",
    "tillryggalägg": "tillryggalägga",
    "tillryggaläggande": "tillryggalägga",
    "tillryggalägganden": "tillryggaläggande",
    "tillryggaläggandena": "tillryggaläggande",
    "tillryggaläggandenas": "tillryggaläggande",
    "tillryggaläggandens": "tillryggaläggande",
    "tillryggaläggandes": "tillryggaläggande",
    "tillryggaläggandet": "tillryggaläggande",
    "tillryggaläggandets": "tillryggaläggande",
    "tillryggaläggas": "tillryggalägga",
    "tillryggalägger": "tillryggalägga",
    "tillryggalägges": "tillryggalägga",
    "tillryggaläggs": "tillryggalägga",
    "tillrynkade": "tillrynkad",
    "tillrynkades": "tillrynkad",
    "tillrynkads": "tillrynkad",
    "tillrynkat": "tillrynkad",
    "tillrynkats": "tillrynkad",
    "tillräckliga": "tillräcklig",
    "tillräckligare": "tillräcklig",
    "tillräckligares": "tillräcklig",
    "tillräckligas": "tillräcklig",
    "tillräckligast": "tillräcklig",
    "tillräckligaste": "tillräcklig",
    "tillräckligastes": "tillräcklig",
    "tillräckligasts": "tillräcklig",
    "tillräcklige": "tillräcklig",
    "tillräckliges": "tillräcklig",
    "tillräckligheten": "tillräcklighet",
    "tillräcklighetens": "tillräcklighet",
    "tillräcklighets": "tillräcklighet",
    "tillräckligs": "tillräcklig",
    "tillräckligt": "tillräcklig",
    "tillräckligts": "tillräcklig",
    "tillräkn": "tillräkna",
    "tillräknad": "tillräkna",
    "tillräknade": "tillräkna",
    "tillräknades": "tillräkna",
    "tillräknads": "tillräkna",
    "tillräknande": "tillräkna",
    "tillräknanden": "tillräknande",
    "tillräknandena": "tillräknande",
    "tillräknandenas": "tillräknande",
    "tillräknandens": "tillräknande",
    "tillräknandes": "tillräknande",
    "tillräknandet": "tillräknande",
    "tillräknandets": "tillräknande",
    "tillräknar": "tillräkna",
    "tillräknas": "tillräkna",
    "tillräknat": "tillräkna",
    "tillräknats": "tillräkna",
    "tillräkneliga": "tillräknelig",
    "tillräkneligare": "tillräknelig",
    "tillräkneligares": "tillräknelig",
    "tillräkneligas": "tillräknelig",
    "tillräkneligast": "tillräknelig",
    "tillräkneligaste": "tillräknelig",
    "tillräkneligastes": "tillräknelig",
    "tillräkneligasts": "tillräknelig",
    "tillräknelige": "tillräknelig",
    "tillräkneliges": "tillräknelig",
    "tillräkneligheten": "tillräknelighet",
    "tillräknelighetens": "tillräknelighet",
    "tillräknelighets": "tillräknelighet",
    "tillräkneligs": "tillräknelig",
    "tillräkneligt": "tillräknelig",
    "tillräkneligts": "tillräknelig",
    "tillrättala": "tillrättalägga",
    "tillrättalade": "tillrättalägga",
    "tillrättalades": "tillrättalägga",
    "tillrättalagd": "tillrättalägga",
    "tillrättalagda": "tillrättalägga",
    "tillrättalagdas": "tillrättalägga",
    "tillrättalagde": "tillrättalägga",
    "tillrättalagdes": "tillrättalägga",
    "tillrättalagds": "tillrättalägga",
    "tillrättalagt": "tillrättalägga",
    "tillrättalagts": "tillrättalägga",
    "tillrättalas": "tillrättalägga",
    "tillrättalägg": "tillrättalägga",
    "tillrättaläggande": "tillrättalägga",
    "tillrättalägganden": "tillrättaläggande",
    "tillrättaläggandena": "tillrättaläggande",
    "tillrättaläggandenas": "tillrättaläggande",
    "tillrättaläggandens": "tillrättaläggande",
    "tillrättaläggandes": "tillrättaläggande",
    "tillrättaläggandet": "tillrättaläggande",
    "tillrättaläggandets": "tillrättaläggande",
    "tillrättaläggas": "tillrättalägga",
    "tillrättalägger": "tillrättalägga",
    "tillrättalägges": "tillrättalägga",
    "tillrättaläggs": "tillrättalägga",
    "tillrättavis": "tillrättavisa",
    "tillrättavisad": "tillrättavisa",
    "tillrättavisade": "tillrättavisa",
    "tillrättavisades": "tillrättavisa",
    "tillrättavisads": "tillrättavisa",
    "tillrättavisande": "tillrättavisa",
    "tillrättavisanden": "tillrättavisande",
    "tillrättavisandena": "tillrättavisande",
    "tillrättavisandenas": "tillrättavisande",
    "tillrättavisandens": "tillrättavisande",
    "tillrättavisandes": "tillrättavisande",
    "tillrättavisandet": "tillrättavisande",
    "tillrättavisandets": "tillrättavisande",
    "tillrättavisar": "tillrättavisa",
    "tillrättavisas": "tillrättavisa",
    "tillrättavisat": "tillrättavisa",
    "tillrättavisats": "tillrättavisa",
    "tillrättavisningar": "tillrättavisning",
    "tillrättavisningarna": "tillrättavisning",
    "tillrättavisningarnas": "tillrättavisning",
    "tillrättavisningars": "tillrättavisning",
    "tillrättavisningen": "tillrättavisning",
    "tillrättavisningens": "tillrättavisning",
    "tillrättavisnings": "tillrättavisning",
    "tillråd": "tillråda",
    "tillrådande": "tillråda",
    "tillrådanden": "tillrådande",
    "tillrådandena": "tillrådande",
    "tillrådandenas": "tillrådande",
    "tillrådandens": "tillrådande",
    "tillrådandes": "tillrådande",
    "tillrådandet": "tillrådande",
    "tillrådandets": "tillrådande",
    "tillrådans": "tillrådan",
    "tillrådas": "tillråda",
    "tillrådd": "tillråda",
    "tillrådda": "tillråda",
    "tillråddas": "tillråda",
    "tillrådde": "tillråda",
    "tillråddes": "tillråda",
    "tillrådds": "tillråda",
    "tillråder": "tillråda",
    "tillrådes": "tillråda",
    "tillrådliga": "tillrådlig",
    "tillrådligare": "tillrådlig",
    "tillrådligares": "tillrådlig",
    "tillrådligas": "tillrådlig",
    "tillrådligast": "tillrådlig",
    "tillrådligaste": "tillrådlig",
    "tillrådligastes": "tillrådlig",
    "tillrådligasts": "tillrådlig",
    "tillrådlige": "tillrådlig",
    "tillrådliges": "tillrådlig",
    "tillrådligheten": "tillrådlighet",
    "tillrådlighetens": "tillrådlighet",
    "tillrådlighets": "tillrådlighet",
    "tillrådligs": "tillrådlig",
    "tillrådligt": "tillrådlig",
    "tillrådligts": "tillrådlig",
    "tillråds": "tillråda",
    "tillrått": "tillråda",
    "tillråtts": "tillråda",
    "tillsade": "tillsäga",
    "tillsades": "tillsäga",
    "tillsagd": "tillsäga",
    "tillsagda": "tillsäga",
    "tillsagdas": "tillsäga",
    "tillsagde": "tillsäga",
    "tillsagdes": "tillsäga",
    "tillsagds": "tillsäga",
    "tillsagt": "tillsäga",
    "tillsagts": "tillsäga",
    "tillsammantagens": "tillsammantagen",
    "tillsammantaget": "tillsammantagen",
    "tillsammantagets": "tillsammantagen",
    "tillsammantagna": "tillsammantagen",
    "tillsammantagnare": "tillsammantagen",
    "tillsammantagnares": "tillsammantagen",
    "tillsammantagnas": "tillsammantagen",
    "tillsammantagnast": "tillsammantagen",
    "tillsammantagnaste": "tillsammantagen",
    "tillsammantagnastes": "tillsammantagen",
    "tillsammantagnasts": "tillsammantagen",
    "tillsammantagne": "tillsammantagen",
    "tillsammantagnes": "tillsammantagen",
    "tillsatsen": "tillsats",
    "tillsatsens": "tillsats",
    "tillsatser": "tillsats",
    "tillsatserna": "tillsats",
    "tillsatsernas": "tillsats",
    "tillsatsers": "tillsats",
    "tillsatslinsen": "tillsatslins",
    "tillsatslinsens": "tillsatslins",
    "tillsatslinser": "tillsatslins",
    "tillsatslinserna": "tillsatslins",
    "tillsatslinsernas": "tillsatslins",
    "tillsatslinsers": "tillsatslins",
    "tillsatsämnen": "tillsatsämne",
    "tillsatsämnena": "tillsatsämne",
    "tillsatsämnenas": "tillsatsämne",
    "tillsatsämnens": "tillsatsämne",
    "tillsatsämnes": "tillsatsämne",
    "tillsatsämnet": "tillsatsämne",
    "tillsatsämnets": "tillsatsämne",
    "tillsatt": "tillsätta",
    "tillsatta": "tillsätta",
    "tillsattas": "tillsätta",
    "tillsatte": "tillsätta",
    "tillsattes": "tillsätta",
    "tillsatts": "tillsätta",
    "tillsedd": "tillse",
    "tillsedda": "tillse",
    "tillseddas": "tillse",
    "tillsedde": "tillse",
    "tillseddes": "tillse",
    "tillsedds": "tillse",
    "tillseende": "tillse",
    "tillseenden": "tillseende",
    "tillseendena": "tillseende",
    "tillseendenas": "tillseende",
    "tillseendens": "tillseende",
    "tillseendes": "tillseende",
    "tillseendet": "tillseende",
    "tillseendets": "tillseende",
    "tillser": "tillse",
    "tillses": "tillse",
    "tillsett": "tillse",
    "tillsetts": "tillse",
    "tillskap": "tillskapa",
    "tillskapad": "tillskapa",
    "tillskapade": "tillskapa",
    "tillskapades": "tillskapa",
    "tillskapads": "tillskapa",
    "tillskapande": "tillskapa",
    "tillskapanden": "tillskapande",
    "tillskapandena": "tillskapande",
    "tillskapandenas": "tillskapande",
    "tillskapandens": "tillskapande",
    "tillskapandes": "tillskapande",
    "tillskapandet": "tillskapande",
    "tillskapandets": "tillskapande",
    "tillskapar": "tillskapa",
    "tillskapas": "tillskapa",
    "tillskapat": "tillskapa",
    "tillskapats": "tillskapa",
    "tillskar": "tillskära",
    "tillskars": "tillskära",
    "tillskjut": "tillskjuta",
    "tillskjutande": "tillskjuta",
    "tillskjutanden": "tillskjutande",
    "tillskjutandena": "tillskjutande",
    "tillskjutandenas": "tillskjutande",
    "tillskjutandens": "tillskjutande",
    "tillskjutandes": "tillskjutande",
    "tillskjutandet": "tillskjutande",
    "tillskjutandets": "tillskjutande",
    "tillskjutas": "tillskjuta",
    "tillskjute": "tillskjuta",
    "tillskjuten": "tillskjuta",
    "tillskjutens": "tillskjuta",
    "tillskjuter": "tillskjuta",
    "tillskjutes": "tillskjuta",
    "tillskjutet": "tillskjuta",
    "tillskjutets": "tillskjuta",
    "tillskjutit": "tillskjuta",
    "tillskjutits": "tillskjuta",
    "tillskjutna": "tillskjuta",
    "tillskjutnas": "tillskjuta",
    "tillskjutne": "tillskjuta",
    "tillskjutnes": "tillskjuta",
    "tillskjuts": "tillskjuta",
    "tillskotten": "tillskott",
    "tillskottens": "tillskott",
    "tillskottet": "tillskott",
    "tillskottets": "tillskott",
    "tillskotts": "tillskott",
    "tillskrev": "tillskriva",
    "tillskrevs": "tillskriva",
    "tillskriv": "tillskriva",
    "tillskrivande": "tillskriva",
    "tillskrivanden": "tillskrivande",
    "tillskrivandena": "tillskrivande",
    "tillskrivandenas": "tillskrivande",
    "tillskrivandens": "tillskrivande",
    "tillskrivandes": "tillskrivande",
    "tillskrivandet": "tillskrivande",
    "tillskrivandets": "tillskrivande",
    "tillskrivas": "tillskriva",
    "tillskrive": "tillskriva",
    "tillskriven": "tillskriva",
    "tillskrivens": "tillskriva",
    "tillskriver": "tillskriva",
    "tillskrives": "tillskriva",
    "tillskrivet": "tillskriva",
    "tillskrivets": "tillskriva",
    "tillskrivit": "tillskriva",
    "tillskrivits": "tillskriva",
    "tillskrivna": "tillskriva",
    "tillskrivnas": "tillskriva",
    "tillskrivne": "tillskriva",
    "tillskrivnes": "tillskriva",
    "tillskrivs": "tillskriva",
    "tillskrynklade": "tillskrynklad",
    "tillskrynklades": "tillskrynklad",
    "tillskrynklads": "tillskrynklad",
    "tillskrynklat": "tillskrynklad",
    "tillskrynklats": "tillskrynklad",
    "tillskure": "tillskära",
    "tillskuren": "tillskära",
    "tillskurens": "tillskära",
    "tillskures": "tillskära",
    "tillskuret": "tillskära",
    "tillskurets": "tillskära",
    "tillskurit": "tillskära",
    "tillskurits": "tillskära",
    "tillskurna": "tillskära",
    "tillskurnas": "tillskära",
    "tillskurne": "tillskära",
    "tillskurnes": "tillskära",
    "tillskynd": "tillskynda",
    "tillskyndad": "tillskynda",
    "tillskyndade": "tillskynda",
    "tillskyndades": "tillskynda",
    "tillskyndads": "tillskynda",
    "tillskyndande": "tillskynda",
    "tillskyndanden": "tillskyndande",
    "tillskyndandena": "tillskyndande",
    "tillskyndandenas": "tillskyndande",
    "tillskyndandens": "tillskyndande",
    "tillskyndandes": "tillskyndande",
    "tillskyndandet": "tillskyndande",
    "tillskyndandets": "tillskyndande",
    "tillskyndans": "tillskyndan",
    "tillskyndar": "tillskyndare",
    "tillskyndaren": "tillskyndare",
    "tillskyndarens": "tillskyndare",
    "tillskyndares": "tillskyndare",
    "tillskyndarna": "tillskyndare",
    "tillskyndarnas": "tillskyndare",
    "tillskyndas": "tillskynda",
    "tillskyndat": "tillskynda",
    "tillskyndats": "tillskynda",
    "tillskär": "tillskära",
    "tillskärande": "tillskära",
    "tillskäranden": "tillskärande",
    "tillskärandena": "tillskärande",
    "tillskärandenas": "tillskärande",
    "tillskärandens": "tillskärande",
    "tillskärandes": "tillskärande",
    "tillskärandet": "tillskärande",
    "tillskärandets": "tillskärande",
    "tillskärar": "tillskärare",
    "tillskäraren": "tillskärare",
    "tillskärarens": "tillskärare",
    "tillskärares": "tillskärare",
    "tillskärarknivar": "tillskärarkniv",
    "tillskärarknivarna": "tillskärarkniv",
    "tillskärarknivarnas": "tillskärarkniv",
    "tillskärarknivars": "tillskärarkniv",
    "tillskärarkniven": "tillskärarkniv",
    "tillskärarknivens": "tillskärarkniv",
    "tillskärarknivs": "tillskärarkniv",
    "tillskärarna": "tillskärare",
    "tillskärarnas": "tillskärare",
    "tillskäras": "tillskära",
    "tillskäre": "tillskära",
    "tillskäres": "tillskära",
    "tillskärningar": "tillskärning",
    "tillskärningarna": "tillskärning",
    "tillskärningarnas": "tillskärning",
    "tillskärningars": "tillskärning",
    "tillskärningen": "tillskärning",
    "tillskärningens": "tillskärning",
    "tillskärnings": "tillskärning",
    "tillskärs": "tillskära",
    "tillsköt": "tillskjuta",
    "tillsköte": "tillskjuta",
    "tillskötes": "tillskjuta",
    "tillsköts": "tillskjuta",
    "tillslagen": "tillslag",
    "tillslagens": "tillslagen",
    "tillslaget": "tillslagen",
    "tillslagets": "tillslagen",
    "tillslagna": "tillslagen",
    "tillslagnare": "tillslagen",
    "tillslagnares": "tillslagen",
    "tillslagnas": "tillslagen",
    "tillslagnast": "tillslagen",
    "tillslagnaste": "tillslagen",
    "tillslagnastes": "tillslagen",
    "tillslagnasts": "tillslagen",
    "tillslagne": "tillslagen",
    "tillslagnes": "tillslagen",
    "tillslagningar": "tillslagning",
    "tillslagningarna": "tillslagning",
    "tillslagningarnas": "tillslagning",
    "tillslagningars": "tillslagning",
    "tillslagningen": "tillslagning",
    "tillslagningens": "tillslagning",
    "tillslagnings": "tillslagning",
    "tillslagningstekniken": "tillslagningsteknik",
    "tillslagningsteknikens": "tillslagningsteknik",
    "tillslagningstekniker": "tillslagningsteknik",
    "tillslagningsteknikerna": "tillslagningsteknik",
    "tillslagningsteknikernas": "tillslagningsteknik",
    "tillslagningsteknikers": "tillslagningsteknik",
    "tillslagningstekniks": "tillslagningsteknik",
    "tillslags": "tillslag",
    "tillslut": "tillsluta",
    "tillslutande": "tillsluta",
    "tillslutanden": "tillslutande",
    "tillslutandena": "tillslutande",
    "tillslutandenas": "tillslutande",
    "tillslutandens": "tillslutande",
    "tillslutandes": "tillslutande",
    "tillslutandet": "tillslutande",
    "tillslutandets": "tillslutande",
    "tillslutar": "tillslutare",
    "tillslutaren": "tillslutare",
    "tillslutarens": "tillslutare",
    "tillslutares": "tillslutare",
    "tillslutarna": "tillslutare",
    "tillslutarnas": "tillslutare",
    "tillslutas": "tillsluta",
    "tillslute": "tillsluta",
    "tillsluten": "tillsluta",
    "tillslutens": "tillsluta",
    "tillsluter": "tillsluta",
    "tillslutes": "tillsluta",
    "tillslutet": "tillsluta",
    "tillslutets": "tillsluta",
    "tillslutit": "tillsluta",
    "tillslutits": "tillsluta",
    "tillslutna": "tillsluta",
    "tillslutnas": "tillsluta",
    "tillslutne": "tillsluta",
    "tillslutnes": "tillsluta",
    "tillslutningar": "tillslutning",
    "tillslutningarna": "tillslutning",
    "tillslutningarnas": "tillslutning",
    "tillslutningars": "tillslutning",
    "tillslutningen": "tillslutning",
    "tillslutningens": "tillslutning",
    "tillslutnings": "tillslutning",
    "tillsluts": "tillsluta",
    "tillslöt": "tillsluta",
    "tillslöte": "tillsluta",
    "tillslötes": "tillsluta",
    "tillslöts": "tillsluta",
    "tillspets": "tillspetsa",
    "tillspetsad": "tillspetsa",
    "tillspetsade": "tillspetsad",
    "tillspetsades": "tillspetsad",
    "tillspetsads": "tillspetsad",
    "tillspetsande": "tillspetsa",
    "tillspetsanden": "tillspetsande",
    "tillspetsandena": "tillspetsande",
    "tillspetsandenas": "tillspetsande",
    "tillspetsandens": "tillspetsande",
    "tillspetsandes": "tillspetsande",
    "tillspetsandet": "tillspetsande",
    "tillspetsandets": "tillspetsande",
    "tillspetsar": "tillspetsa",
    "tillspetsas": "tillspetsa",
    "tillspetsat": "tillspetsad",
    "tillspetsats": "tillspetsad",
    "tillspillogav": "tillspilloge",
    "tillspillogavs": "tillspilloge",
    "tillspillogeende": "tillspilloge",
    "tillspillogeendes": "tillspilloge",
    "tillspilloger": "tillspilloge",
    "tillspilloges": "tillspilloge",
    "tillspillogett": "tillspilloge",
    "tillspillogetts": "tillspilloge",
    "tillspillogiv": "tillspilloge",
    "tillspillogiva": "tillspilloge",
    "tillspillogivande": "tillspilloge",
    "tillspillogivanden": "tillspillogivande",
    "tillspillogivandena": "tillspillogivande",
    "tillspillogivandenas": "tillspillogivande",
    "tillspillogivandens": "tillspillogivande",
    "tillspillogivandes": "tillspillogivande",
    "tillspillogivandet": "tillspillogivande",
    "tillspillogivandets": "tillspillogivande",
    "tillspillogivas": "tillspilloge",
    "tillspillogive": "tillspilloge",
    "tillspillogiven": "tillspilloge",
    "tillspillogivens": "tillspillogiven",
    "tillspillogiver": "tillspilloge",
    "tillspillogives": "tillspilloge",
    "tillspillogivet": "tillspillogiven",
    "tillspillogivets": "tillspillogiven",
    "tillspillogivit": "tillspilloge",
    "tillspillogivits": "tillspilloge",
    "tillspillogivna": "tillspillogiven",
    "tillspillogivnare": "tillspillogiven",
    "tillspillogivnares": "tillspillogiven",
    "tillspillogivnas": "tillspillogiven",
    "tillspillogivnast": "tillspillogiven",
    "tillspillogivnaste": "tillspillogiven",
    "tillspillogivnastes": "tillspillogiven",
    "tillspillogivnasts": "tillspillogiven",
    "tillspillogivne": "tillspillogiven",
    "tillspillogivnes": "tillspillogiven",
    "tillspillogivs": "tillspilloge",
    "tillspillogåve": "tillspilloge",
    "tillspillogåves": "tillspilloge",
    "tillstadd": "tillstädja",
    "tillstadda": "tillstädja",
    "tillstaddas": "tillstädja",
    "tillstadde": "tillstädja",
    "tillstaddes": "tillstädja",
    "tillstadds": "tillstädja",
    "tillstatt": "tillstädja",
    "tillstatts": "tillstädja",
    "tillstod": "tillstå",
    "tillstode": "tillstå",
    "tillstodes": "tillstå",
    "tillstods": "tillstå",
    "tillströmmad": "tillströmma",
    "tillströmmade": "tillströmma",
    "tillströmmades": "tillströmma",
    "tillströmmads": "tillströmma",
    "tillströmmande": "tillströmma",
    "tillströmmanden": "tillströmmande",
    "tillströmmandena": "tillströmmande",
    "tillströmmandenas": "tillströmmande",
    "tillströmmandens": "tillströmmande",
    "tillströmmandes": "tillströmmande",
    "tillströmmandet": "tillströmmande",
    "tillströmmandets": "tillströmmande",
    "tillströmmar": "tillströmma",
    "tillströmmas": "tillströmma",
    "tillströmmat": "tillströmma",
    "tillströmmats": "tillströmma",
    "tillströmningar": "tillströmning",
    "tillströmningarna": "tillströmning",
    "tillströmningarnas": "tillströmning",
    "tillströmningars": "tillströmning",
    "tillströmningen": "tillströmning",
    "tillströmningens": "tillströmning",
    "tillströmnings": "tillströmning",
    "tillstukade": "tillstukad",
    "tillstukades": "tillstukad",
    "tillstukads": "tillstukad",
    "tillstukat": "tillstukad",
    "tillstukats": "tillstukad",
    "tillstund": "tillstunda",
    "tillstundad": "tillstunda",
    "tillstundade": "tillstunda",
    "tillstundades": "tillstunda",
    "tillstundads": "tillstunda",
    "tillstundande": "tillstunda",
    "tillstundanden": "tillstundande",
    "tillstundandena": "tillstundande",
    "tillstundandenas": "tillstundande",
    "tillstundandens": "tillstundande",
    "tillstundandes": "tillstundande",
    "tillstundandet": "tillstundande",
    "tillstundandets": "tillstundande",
    "tillstundar": "tillstunda",
    "tillstundas": "tillstunda",
    "tillstundat": "tillstunda",
    "tillstundats": "tillstunda",
    "tillstymmelsen": "tillstymmelse",
    "tillstymmelsens": "tillstymmelse",
    "tillstymmelser": "tillstymmelse",
    "tillstymmelserna": "tillstymmelse",
    "tillstymmelsernas": "tillstymmelse",
    "tillstymmelsers": "tillstymmelse",
    "tillstymmelses": "tillstymmelse",
    "tillstyrk": "tillstyrka",
    "tillstyrkande": "tillstyrka",
    "tillstyrkanden": "tillstyrkande",
    "tillstyrkandena": "tillstyrkande",
    "tillstyrkandenas": "tillstyrkande",
    "tillstyrkandens": "tillstyrkande",
    "tillstyrkandes": "tillstyrkande",
    "tillstyrkandet": "tillstyrkande",
    "tillstyrkandets": "tillstyrkande",
    "tillstyrkans": "tillstyrkan",
    "tillstyrkas": "tillstyrka",
    "tillstyrker": "tillstyrka",
    "tillstyrkes": "tillstyrka",
    "tillstyrks": "tillstyrka",
    "tillstyrkt": "tillstyrka",
    "tillstyrkta": "tillstyrka",
    "tillstyrktas": "tillstyrka",
    "tillstyrkte": "tillstyrka",
    "tillstyrktes": "tillstyrka",
    "tillstyrkts": "tillstyrka",
    "tillstäd": "tillstädja",
    "tillstäder": "tillstädja",
    "tillstädes": "tillstädja",
    "tillstädj": "tillstädja",
    "tillstädjande": "tillstädja",
    "tillstädjanden": "tillstädjande",
    "tillstädjandena": "tillstädjande",
    "tillstädjandenas": "tillstädjande",
    "tillstädjandens": "tillstädjande",
    "tillstädjandes": "tillstädjande",
    "tillstädjandet": "tillstädjande",
    "tillstädjandets": "tillstädjande",
    "tillstädjas": "tillstädja",
    "tillstädjer": "tillstädja",
    "tillstäds": "tillstädja",
    "tillställ": "tillställa",
    "tillställande": "tillställa",
    "tillställanden": "tillställande",
    "tillställandena": "tillställande",
    "tillställandenas": "tillställande",
    "tillställandens": "tillställande",
    "tillställandes": "tillställande",
    "tillställandet": "tillställande",
    "tillställandets": "tillställande",
    "tillställas": "tillställa",
    "tillställd": "tillställa",
    "tillställda": "tillställa",
    "tillställdas": "tillställa",
    "tillställde": "tillställa",
    "tillställdes": "tillställa",
    "tillställds": "tillställa",
    "tillställer": "tillställa",
    "tillställes": "tillställa",
    "tillställningar": "tillställning",
    "tillställningarna": "tillställning",
    "tillställningarnas": "tillställning",
    "tillställningars": "tillställning",
    "tillställningen": "tillställning",
    "tillställningens": "tillställning",
    "tillställnings": "tillställning",
    "tillställs": "tillställa",
    "tillställt": "tillställa",
    "tillställts": "tillställa",
    "tillständiga": "tillständig",
    "tillständigare": "tillständig",
    "tillständigares": "tillständig",
    "tillständigas": "tillständig",
    "tillständigast": "tillständig",
    "tillständigaste": "tillständig",
    "tillständigastes": "tillständig",
    "tillständigasts": "tillständig",
    "tillständige": "tillständig",
    "tillständiges": "tillständig",
    "tillständigs": "tillständig",
    "tillständigt": "tillständig",
    "tillständigts": "tillständig",
    "tillstående": "tillstå",
    "tillståenden": "tillstående",
    "tillståendena": "tillstående",
    "tillståendenas": "tillstående",
    "tillståendens": "tillstående",
    "tillståendes": "tillstående",
    "tillståendet": "tillstående",
    "tillståendets": "tillstående",
    "tillstånden": "tillstånd",
    "tillståndens": "tillstånd",
    "tillståndet": "tillstånd",
    "tillståndets": "tillstånd",
    "tillstånds": "tillstånd",
    "tillståndsbevisen": "tillståndsbevis",
    "tillståndsbevisens": "tillståndsbevis",
    "tillståndsbeviset": "tillståndsbevis",
    "tillståndsbevisets": "tillståndsbevis",
    "tillstår": "tillstå",
    "tillstås": "tillstå",
    "tillstått": "tillstå",
    "tillståtts": "tillstå",
    "tillstöt": "tillstöta",
    "tillstötande": "tillstöta",
    "tillstötanden": "tillstötande",
    "tillstötandena": "tillstötande",
    "tillstötandenas": "tillstötande",
    "tillstötandens": "tillstötande",
    "tillstötandes": "tillstötande",
    "tillstötandet": "tillstötande",
    "tillstötandets": "tillstötande",
    "tillstötas": "tillstöta",
    "tillstöter": "tillstöta",
    "tillstötes": "tillstöta",
    "tillstöts": "tillstöta",
    "tillstött": "tillstöta",
    "tillstötta": "tillstöta",
    "tillstöttas": "tillstöta",
    "tillstötte": "tillstöta",
    "tillstöttes": "tillstöta",
    "tillstötts": "tillstöta",
    "tillsvidareförordnanden": "tillsvidareförordnande",
    "tillsvidareförordnandena": "tillsvidareförordnande",
    "tillsvidareförordnandenas": "tillsvidareförordnande",
    "tillsvidareförordnandens": "tillsvidareförordnande",
    "tillsvidareförordnandes": "tillsvidareförordnande",
    "tillsvidareförordnandet": "tillsvidareförordnande",
    "tillsvidareförordnandets": "tillsvidareförordnande",
    "tillsynen": "tillsyn",
    "tillsynens": "tillsyn",
    "tillsyningsmannen": "tillsyningsman",
    "tillsyningsmannens": "tillsyningsman",
    "tillsyningsmans": "tillsyningsman",
    "tillsyningsmän": "tillsyningsman",
    "tillsyningsmännen": "tillsyningsman",
    "tillsyningsmännens": "tillsyningsman",
    "tillsyningsmäns": "tillsyningsman",
    "tillsyns": "tillsyn",
    "tillsynslärar": "tillsynslärare",
    "tillsynsläraren": "tillsynslärare",
    "tillsynslärarens": "tillsynslärare",
    "tillsynslärares": "tillsynslärare",
    "tillsynslärarna": "tillsynslärare",
    "tillsynslärarnas": "tillsynslärare",
    "tillsynsmannen": "tillsynsman",
    "tillsynsmannens": "tillsynsman",
    "tillsynsmans": "tillsynsman",
    "tillsynsmyndigheten": "tillsynsmyndighet",
    "tillsynsmyndighetens": "tillsynsmyndighet",
    "tillsynsmyndigheter": "tillsynsmyndighet",
    "tillsynsmyndigheterna": "tillsynsmyndighet",
    "tillsynsmyndigheternas": "tillsynsmyndighet",
    "tillsynsmyndigheters": "tillsynsmyndighet",
    "tillsynsmyndighets": "tillsynsmyndighet",
    "tillsynsmän": "tillsynsman",
    "tillsynsmännen": "tillsynsman",
    "tillsynsmännens": "tillsynsman",
    "tillsynsmäns": "tillsynsman",
    "tillsäg": "tillsäga",
    "tillsägande": "tillsäga",
    "tillsäganden": "tillsägande",
    "tillsägandena": "tillsägande",
    "tillsägandenas": "tillsägande",
    "tillsägandens": "tillsägande",
    "tillsägandes": "tillsägande",
    "tillsägandet": "tillsägande",
    "tillsägandets": "tillsägande",
    "tillsägas": "tillsäga",
    "tillsägelsen": "tillsägelse",
    "tillsägelsens": "tillsägelse",
    "tillsägelser": "tillsägelse",
    "tillsägelserna": "tillsägelse",
    "tillsägelsernas": "tillsägelse",
    "tillsägelsers": "tillsägelse",
    "tillsägelses": "tillsägelse",
    "tillsäger": "tillsäga",
    "tillsäges": "tillsäga",
    "tillsägs": "tillsäga",
    "tillsätt": "tillsätta",
    "tillsättande": "tillsätta",
    "tillsättanden": "tillsättande",
    "tillsättandena": "tillsättande",
    "tillsättandenas": "tillsättande",
    "tillsättandens": "tillsättande",
    "tillsättandes": "tillsättande",
    "tillsättandet": "tillsättande",
    "tillsättandets": "tillsättande",
    "tillsättas": "tillsätta",
    "tillsätter": "tillsätta",
    "tillsättes": "tillsätta",
    "tillsättningar": "tillsättning",
    "tillsättningarna": "tillsättning",
    "tillsättningarnas": "tillsättning",
    "tillsättningars": "tillsättning",
    "tillsättningen": "tillsättning",
    "tillsättningens": "tillsättning",
    "tillsättnings": "tillsättning",
    "tillsätts": "tillsätta",
    "tillsåg": "tillse",
    "tillsåge": "tillse",
    "tillsåges": "tillse",
    "tillsågs": "tillse",
    "tilltag": "tillta",
    "tilltaga": "tillta",
    "tilltagande": "tillta",
    "tilltagandes": "tilltagande",
    "tilltagandet": "tilltagande",
    "tilltagandets": "tilltagande",
    "tilltagas": "tillta",
    "tilltage": "tillta",
    "tilltagen": "tilltag",
    "tilltagens": "tilltagen",
    "tilltager": "tillta",
    "tilltages": "tillta",
    "tilltaget": "tilltagen",
    "tilltagets": "tilltagen",
    "tilltagit": "tillta",
    "tilltagits": "tillta",
    "tilltagna": "tilltagen",
    "tilltagnare": "tilltagen",
    "tilltagnares": "tilltagen",
    "tilltagnas": "tilltagen",
    "tilltagnast": "tilltagen",
    "tilltagnaste": "tilltagen",
    "tilltagnastes": "tilltagen",
    "tilltagnasts": "tilltagen",
    "tilltagne": "tilltagen",
    "tilltagnes": "tilltagen",
    "tilltags": "tilltag",
    "tilltagsens": "tilltagsen",
    "tilltagset": "tilltagsen",
    "tilltagsets": "tilltagsen",
    "tilltagsna": "tilltagsen",
    "tilltagsnare": "tilltagsen",
    "tilltagsnares": "tilltagsen",
    "tilltagsnas": "tilltagsen",
    "tilltagsnast": "tilltagsen",
    "tilltagsnaste": "tilltagsen",
    "tilltagsnastes": "tilltagsen",
    "tilltagsnasts": "tilltagsen",
    "tilltagsne": "tilltagsen",
    "tilltagsnes": "tilltagsen",
    "tilltal": "tilltala",
    "tilltalad": "tilltala",
    "tilltalade": "tilltala",
    "tilltalades": "tilltala",
    "tilltalads": "tilltala",
    "tilltalande": "tilltala",
    "tilltalanden": "tilltalande",
    "tilltalandena": "tilltalande",
    "tilltalandenas": "tilltalande",
    "tilltalandens": "tilltalande",
    "tilltalandes": "tilltalande",
    "tilltalandet": "tilltalande",
    "tilltalandets": "tilltalande",
    "tilltalar": "tilltala",
    "tilltalas": "tilltala",
    "tilltalat": "tilltala",
    "tilltalats": "tilltala",
    "tilltalet": "tilltal",
    "tilltalets": "tilltal",
    "tilltals": "tilltal",
    "tilltalsformen": "tilltalsform",
    "tilltalsformens": "tilltalsform",
    "tilltalsformer": "tilltalsform",
    "tilltalsformerna": "tilltalsform",
    "tilltalsformernas": "tilltalsform",
    "tilltalsformers": "tilltalsform",
    "tilltalsforms": "tilltalsform",
    "tilltalsnamnen": "tilltalsnamn",
    "tilltalsnamnens": "tilltalsnamn",
    "tilltalsnamnet": "tilltalsnamn",
    "tilltalsnamnets": "tilltalsnamn",
    "tilltalsnamns": "tilltalsnamn",
    "tilltalsorden": "tilltalsord",
    "tilltalsordens": "tilltalsord",
    "tilltalsordet": "tilltalsord",
    "tilltalsordets": "tilltalsord",
    "tilltalsords": "tilltalsord",
    "tilltar": "tillta",
    "tilltas": "tillta",
    "tilltog": "tillta",
    "tilltoge": "tillta",
    "tilltoges": "tillta",
    "tilltogs": "tillta",
    "tilltrasslade": "tilltrasslad",
    "tilltrasslades": "tilltrasslad",
    "tilltrasslads": "tilltrasslad",
    "tilltrasslat": "tilltrasslad",
    "tilltrasslats": "tilltrasslad",
    "tilltrodd": "tilltro",
    "tilltrodda": "tilltro",
    "tilltroddas": "tilltro",
    "tilltrodde": "tilltro",
    "tilltroddes": "tilltro",
    "tilltrodds": "tilltro",
    "tilltroende": "tilltro",
    "tilltroenden": "tilltroende",
    "tilltroendena": "tilltroende",
    "tilltroendenas": "tilltroende",
    "tilltroendens": "tilltroende",
    "tilltroendes": "tilltroende",
    "tilltroendet": "tilltroende",
    "tilltroendets": "tilltroende",
    "tilltron": "tilltro",
    "tilltrons": "tilltro",
    "tilltror": "tilltro",
    "tilltros": "tilltro",
    "tilltrott": "tilltro",
    "tilltrotts": "tilltro",
    "tillträd": "tillträda",
    "tillträdande": "tillträda",
    "tillträdanden": "tillträdande",
    "tillträdandena": "tillträdande",
    "tillträdandenas": "tillträdande",
    "tillträdandens": "tillträdande",
    "tillträdandes": "tillträdande",
    "tillträdandet": "tillträdande",
    "tillträdandets": "tillträdande",
    "tillträdas": "tillträda",
    "tillträdd": "tillträda",
    "tillträdda": "tillträda",
    "tillträddas": "tillträda",
    "tillträdde": "tillträda",
    "tillträddes": "tillträda",
    "tillträdds": "tillträda",
    "tillträden": "tillträde",
    "tillträdena": "tillträde",
    "tillträdenas": "tillträde",
    "tillträdens": "tillträde",
    "tillträder": "tillträda",
    "tillträdes": "tillträde",
    "tillträdet": "tillträde",
    "tillträdets": "tillträde",
    "tillträds": "tillträda",
    "tillträtt": "tillträda",
    "tillträtts": "tillträda",
    "tilltufsade": "tilltufsad",
    "tilltufsades": "tilltufsad",
    "tilltufsads": "tilltufsad",
    "tilltufsat": "tilltufsad",
    "tilltufsats": "tilltufsad",
    "tilltugget": "tilltugg",
    "tilltuggets": "tilltugg",
    "tilltuggs": "tilltugg",
    "tilltyg": "tilltyga",
    "tilltygad": "tilltyga",
    "tilltygade": "tilltyga",
    "tilltygades": "tilltyga",
    "tilltygads": "tilltyga",
    "tilltygande": "tilltyga",
    "tilltyganden": "tilltygande",
    "tilltygandena": "tilltygande",
    "tilltygandenas": "tilltygande",
    "tilltygandens": "tilltygande",
    "tilltygandes": "tilltygande",
    "tilltygandet": "tilltygande",
    "tilltygandets": "tilltygande",
    "tilltygar": "tilltyga",
    "tilltygas": "tilltyga",
    "tilltygat": "tilltyga",
    "tilltygats": "tilltyga",
    "tilltänkta": "tilltänkt",
    "tilltänktare": "tilltänkt",
    "tilltänktares": "tilltänkt",
    "tilltänktas": "tilltänkt",
    "tilltänktast": "tilltänkt",
    "tilltänktaste": "tilltänkt",
    "tilltänktastes": "tilltänkt",
    "tilltänktasts": "tilltänkt",
    "tilltänkte": "tilltänkt",
    "tilltänktes": "tilltänkt",
    "tilltänktheten": "tilltänkthet",
    "tilltänkthetens": "tilltänkthet",
    "tilltänkthets": "tilltänkthet",
    "tilltänkts": "tilltänkt",
    "tilltäpp": "tilltäppa",
    "tilltäppande": "tilltäppa",
    "tilltäppanden": "tilltäppande",
    "tilltäppandena": "tilltäppande",
    "tilltäppandenas": "tilltäppande",
    "tilltäppandens": "tilltäppande",
    "tilltäppandes": "tilltäppande",
    "tilltäppandet": "tilltäppande",
    "tilltäppandets": "tilltäppande",
    "tilltäppas": "tilltäppa",
    "tilltäpper": "tilltäppa",
    "tilltäppes": "tilltäppa",
    "tilltäppningar": "tilltäppning",
    "tilltäppningarna": "tilltäppning",
    "tilltäppningarnas": "tilltäppning",
    "tilltäppningars": "tilltäppning",
    "tilltäppningen": "tilltäppning",
    "tilltäppningens": "tilltäppning",
    "tilltäppnings": "tilltäppning",
    "tilltäpps": "tilltäppa",
    "tilltäppt": "tilltäppa",
    "tilltäppta": "tilltäppa",
    "tilltäpptas": "tilltäppa",
    "tilltäppte": "tilltäppa",
    "tilltäpptes": "tilltäppa",
    "tilltäppts": "tilltäppa",
    "tilluften": "tilluft",
    "tilluftens": "tilluft",
    "tillufts": "tilluft",
    "tillvalen": "tillval",
    "tillvalens": "tillval",
    "tillvalet": "tillval",
    "tillvalets": "tillval",
    "tillvals": "tillval",
    "tillvalsämnen": "tillvalsämne",
    "tillvalsämnena": "tillvalsämne",
    "tillvalsämnenas": "tillvalsämne",
    "tillvalsämnens": "tillvalsämne",
    "tillvalsämnes": "tillvalsämne",
    "tillvalsämnet": "tillvalsämne",
    "tillvalsämnets": "tillvalsämne",
    "tillvand": "tillvänja",
    "tillvanda": "tillvänja",
    "tillvandare": "tillvand",
    "tillvandares": "tillvand",
    "tillvandas": "tillvänja",
    "tillvandast": "tillvand",
    "tillvandaste": "tillvand",
    "tillvandastes": "tillvand",
    "tillvandasts": "tillvand",
    "tillvande": "tillvänja",
    "tillvandes": "tillvänja",
    "tillvandheten": "tillvandhet",
    "tillvandhetens": "tillvandhet",
    "tillvandhets": "tillvandhet",
    "tillvands": "tillvänja",
    "tillvant": "tillvänja",
    "tillvants": "tillvänja",
    "tillvaratag": "tillvarata",
    "tillvarataga": "tillvarata",
    "tillvaratagande": "tillvarata",
    "tillvarataganden": "tillvaratagande",
    "tillvaratagandena": "tillvaratagande",
    "tillvaratagandenas": "tillvaratagande",
    "tillvaratagandens": "tillvaratagande",
    "tillvaratagandes": "tillvaratagande",
    "tillvaratagandet": "tillvaratagande",
    "tillvaratagandets": "tillvaratagande",
    "tillvaratagas": "tillvarata",
    "tillvaratage": "tillvarata",
    "tillvaratagen": "tillvarata",
    "tillvaratagens": "tillvarata",
    "tillvaratager": "tillvarata",
    "tillvaratages": "tillvarata",
    "tillvarataget": "tillvarata",
    "tillvaratagets": "tillvarata",
    "tillvaratagit": "tillvarata",
    "tillvaratagits": "tillvarata",
    "tillvaratagna": "tillvarata",
    "tillvaratagnas": "tillvarata",
    "tillvaratagne": "tillvarata",
    "tillvaratagnes": "tillvarata",
    "tillvaratags": "tillvarata",
    "tillvaratar": "tillvarata",
    "tillvaratas": "tillvarata",
    "tillvaratog": "tillvarata",
    "tillvaratoge": "tillvarata",
    "tillvaratoges": "tillvarata",
    "tillvaratogs": "tillvarata",
    "tillvaron": "tillvaro",
    "tillvarons": "tillvaro",
    "tillvaros": "tillvaro",
    "tillverk": "tillverka",
    "tillverkad": "tillverka",
    "tillverkade": "tillverka",
    "tillverkades": "tillverka",
    "tillverkads": "tillverka",
    "tillverkande": "tillverka",
    "tillverkanden": "tillverkande",
    "tillverkandena": "tillverkande",
    "tillverkandenas": "tillverkande",
    "tillverkandens": "tillverkande",
    "tillverkandes": "tillverkande",
    "tillverkandet": "tillverkande",
    "tillverkandets": "tillverkande",
    "tillverkar": "tillverkare",
    "tillverkaren": "tillverkare",
    "tillverkarens": "tillverkare",
    "tillverkares": "tillverkare",
    "tillverkarna": "tillverkare",
    "tillverkarnas": "tillverkare",
    "tillverkas": "tillverka",
    "tillverkat": "tillverka",
    "tillverkats": "tillverka",
    "tillverkningar": "tillverkning",
    "tillverkningarna": "tillverkning",
    "tillverkningarnas": "tillverkning",
    "tillverkningars": "tillverkning",
    "tillverkningen": "tillverkning",
    "tillverkningens": "tillverkning",
    "tillverknings": "tillverkning",
    "tillverkningsindustrien": "tillverkningsindustri",
    "tillverkningsindustriens": "tillverkningsindustri",
    "tillverkningsindustrier": "tillverkningsindustri",
    "tillverkningsindustrierna": "tillverkningsindustri",
    "tillverkningsindustriernas": "tillverkningsindustri",
    "tillverkningsindustriers": "tillverkningsindustri",
    "tillverkningsindustrin": "tillverkningsindustri",
    "tillverkningsindustrins": "tillverkningsindustri",
    "tillverkningsindustris": "tillverkningsindustri",
    "tillverkningskostnaden": "tillverkningskostnad",
    "tillverkningskostnadens": "tillverkningskostnad",
    "tillverkningskostnader": "tillverkningskostnad",
    "tillverkningskostnaderna": "tillverkningskostnad",
    "tillverkningskostnadernas": "tillverkningskostnad",
    "tillverkningskostnaders": "tillverkningskostnad",
    "tillverkningskostnads": "tillverkningskostnad",
    "tillverkningsutrustningar": "tillverkningsutrustning",
    "tillverkningsutrustningarna": "tillverkningsutrustning",
    "tillverkningsutrustningarnas": "tillverkningsutrustning",
    "tillverkningsutrustningars": "tillverkningsutrustning",
    "tillverkningsutrustningen": "tillverkningsutrustning",
    "tillverkningsutrustningens": "tillverkningsutrustning",
    "tillverkningsutrustnings": "tillverkningsutrustning",
    "tillverkningsåren": "tillverkningsår",
    "tillverkningsårens": "tillverkningsår",
    "tillverkningsåret": "tillverkningsår",
    "tillverkningsårets": "tillverkningsår",
    "tillverkningsårs": "tillverkningsår",
    "tillvit": "tillvita",
    "tillvitad": "tillvita",
    "tillvitade": "tillvita",
    "tillvitades": "tillvita",
    "tillvitads": "tillvita",
    "tillvitande": "tillvita",
    "tillvitanden": "tillvitande",
    "tillvitandena": "tillvitande",
    "tillvitandenas": "tillvitande",
    "tillvitandens": "tillvitande",
    "tillvitandes": "tillvitande",
    "tillvitandet": "tillvitande",
    "tillvitandets": "tillvitande",
    "tillvitar": "tillvita",
    "tillvitas": "tillvita",
    "tillvitat": "tillvita",
    "tillvitats": "tillvita",
    "tillvitelsen": "tillvitelse",
    "tillvitelsens": "tillvitelse",
    "tillvitelser": "tillvitelse",
    "tillvitelserna": "tillvitelse",
    "tillvitelsernas": "tillvitelse",
    "tillvitelsers": "tillvitelse",
    "tillvitelses": "tillvitelse",
    "tillvuxe": "tillväxa",
    "tillvuxen": "tillväxa",
    "tillvuxens": "tillväxa",
    "tillvuxet": "tillväxa",
    "tillvuxets": "tillväxa",
    "tillvuxit": "tillväxa",
    "tillvuxna": "tillväxa",
    "tillvuxnas": "tillväxa",
    "tillvuxne": "tillväxa",
    "tillvuxnes": "tillväxa",
    "tillvägabragt": "tillvägabringa",
    "tillvägabragte": "tillvägabringa",
    "tillvägabragtes": "tillvägabringa",
    "tillvägabragts": "tillvägabringa",
    "tillvägabring": "tillvägabringa",
    "tillvägabringad": "tillvägabringa",
    "tillvägabringade": "tillvägabringa",
    "tillvägabringades": "tillvägabringa",
    "tillvägabringads": "tillvägabringa",
    "tillvägabringande": "tillvägabringa",
    "tillvägabringanden": "tillvägabringande",
    "tillvägabringandena": "tillvägabringande",
    "tillvägabringandenas": "tillvägabringande",
    "tillvägabringandens": "tillvägabringande",
    "tillvägabringandes": "tillvägabringande",
    "tillvägabringandet": "tillvägabringande",
    "tillvägabringandets": "tillvägabringande",
    "tillvägabringar": "tillvägabringa",
    "tillvägabringas": "tillvägabringa",
    "tillvägabringat": "tillvägabringa",
    "tillvägabringats": "tillvägabringa",
    "tillvägagångssätten": "tillvägagångssätt",
    "tillvägagångssättens": "tillvägagångssätt",
    "tillvägagångssättet": "tillvägagångssätt",
    "tillvägagångssättets": "tillvägagångssätt",
    "tillvägagångssätts": "tillvägagångssätt",
    "tillvänj": "tillvänja",
    "tillvänjande": "tillvänja",
    "tillvänjanden": "tillvänjande",
    "tillvänjandena": "tillvänjande",
    "tillvänjandenas": "tillvänjande",
    "tillvänjandens": "tillvänjande",
    "tillvänjandes": "tillvänjande",
    "tillvänjandet": "tillvänjande",
    "tillvänjandets": "tillvänjande",
    "tillvänjas": "tillvänja",
    "tillvänjer": "tillvänja",
    "tillvänjes": "tillvänja",
    "tillvänjningar": "tillvänjning",
    "tillvänjningarna": "tillvänjning",
    "tillvänjningarnas": "tillvänjning",
    "tillvänjningars": "tillvänjning",
    "tillvänjningen": "tillvänjning",
    "tillvänjningens": "tillvänjning",
    "tillvänjnings": "tillvänjning",
    "tillvänjs": "tillvänja",
    "tillväx": "tillväxa",
    "tillväxande": "tillväxa",
    "tillväxanden": "tillväxande",
    "tillväxandena": "tillväxande",
    "tillväxandenas": "tillväxande",
    "tillväxandens": "tillväxande",
    "tillväxandes": "tillväxande",
    "tillväxandet": "tillväxande",
    "tillväxandets": "tillväxande",
    "tillväxe": "tillväxa",
    "tillväxer": "tillväxa",
    "tillväxt": "tillväxa",
    "tillväxte": "tillväxa",
    "tillväxten": "tillväxt",
    "tillväxtens": "tillväxt",
    "tillväxtfrågan": "tillväxtfråga",
    "tillväxtfrågans": "tillväxtfråga",
    "tillväxtfrågas": "tillväxtfråga",
    "tillväxtfråge": "tillväxtfråga",
    "tillväxtfrågor": "tillväxtfråga",
    "tillväxtfrågorna": "tillväxtfråga",
    "tillväxtfrågornas": "tillväxtfråga",
    "tillväxtfrågors": "tillväxtfråga",
    "tillväxtförmågan": "tillväxtförmåga",
    "tillväxtförmågans": "tillväxtförmåga",
    "tillväxtförmågas": "tillväxtförmåga",
    "tillväxtförmåge": "tillväxtförmåga",
    "tillväxtförmågor": "tillväxtförmåga",
    "tillväxtförmågorna": "tillväxtförmåga",
    "tillväxtförmågornas": "tillväxtförmåga",
    "tillväxtförmågors": "tillväxtförmåga",
    "tillväxthastigheten": "tillväxthastighet",
    "tillväxthastighetens": "tillväxthastighet",
    "tillväxthastigheter": "tillväxthastighet",
    "tillväxthastigheterna": "tillväxthastighet",
    "tillväxthastigheternas": "tillväxthastighet",
    "tillväxthastigheters": "tillväxthastighet",
    "tillväxthastighets": "tillväxthastighet",
    "tillväxthormonen": "tillväxthormon",
    "tillväxthormonens": "tillväxthormon",
    "tillväxthormoner": "tillväxthormon",
    "tillväxthormonerna": "tillväxthormon",
    "tillväxthormonernas": "tillväxthormon",
    "tillväxthormoners": "tillväxthormon",
    "tillväxthormonet": "tillväxthormon",
    "tillväxthormonets": "tillväxthormon",
    "tillväxthormons": "tillväxthormon",
    "tillväxtkurv": "tillväxtkurva",
    "tillväxtkurvan": "tillväxtkurva",
    "tillväxtkurvans": "tillväxtkurva",
    "tillväxtkurvas": "tillväxtkurva",
    "tillväxtkurve": "tillväxtkurva",
    "tillväxtkurvor": "tillväxtkurva",
    "tillväxtkurvorna": "tillväxtkurva",
    "tillväxtkurvornas": "tillväxtkurva",
    "tillväxtkurvors": "tillväxtkurva",
    "tillväxtkurvs": "tillväxtkurva",
    "tillväxtmodellen": "tillväxtmodell",
    "tillväxtmodellens": "tillväxtmodell",
    "tillväxtmodeller": "tillväxtmodell",
    "tillväxtmodellerna": "tillväxtmodell",
    "tillväxtmodellernas": "tillväxtmodell",
    "tillväxtmodellers": "tillväxtmodell",
    "tillväxtmodells": "tillväxtmodell",
    "tillväxtorienterade": "tillväxtorienterad",
    "tillväxtorienterades": "tillväxtorienterad",
    "tillväxtorienterads": "tillväxtorienterad",
    "tillväxtorienterat": "tillväxtorienterad",
    "tillväxtorienterats": "tillväxtorienterad",
    "tillväxtperioden": "tillväxtperiod",
    "tillväxtperiodens": "tillväxtperiod",
    "tillväxtperioder": "tillväxtperiod",
    "tillväxtperioderna": "tillväxtperiod",
    "tillväxtperiodernas": "tillväxtperiod",
    "tillväxtperioders": "tillväxtperiod",
    "tillväxtperiods": "tillväxtperiod",
    "tillväxtprognosen": "tillväxtprognos",
    "tillväxtprognosens": "tillväxtprognos",
    "tillväxtprognoser": "tillväxtprognos",
    "tillväxtprognoserna": "tillväxtprognos",
    "tillväxtprognosernas": "tillväxtprognos",
    "tillväxtprognosers": "tillväxtprognos",
    "tillväxts": "tillväxt",
    "tillväxtstarka": "tillväxtstark",
    "tillväxtstarkas": "tillväxtstark",
    "tillväxtstarke": "tillväxtstark",
    "tillväxtstarkes": "tillväxtstark",
    "tillväxtstarks": "tillväxtstark",
    "tillväxtstarkt": "tillväxtstark",
    "tillväxtstarkts": "tillväxtstark",
    "tillväxtstyrkan": "tillväxtstyrka",
    "tillväxtstyrkans": "tillväxtstyrka",
    "tillväxtstyrkas": "tillväxtstyrka",
    "tillväxtstyrke": "tillväxtstyrka",
    "tillväxtstyrkor": "tillväxtstyrka",
    "tillväxtstyrkorna": "tillväxtstyrka",
    "tillväxtstyrkornas": "tillväxtstyrka",
    "tillväxtstyrkors": "tillväxtstyrka",
    "tillväxtämnen": "tillväxtämne",
    "tillväxtämnena": "tillväxtämne",
    "tillväxtämnenas": "tillväxtämne",
    "tillväxtämnens": "tillväxtämne",
    "tillväxtämnes": "tillväxtämne",
    "tillväxtämnet": "tillväxtämne",
    "tillväxtämnets": "tillväxtämne",
    "tillyx": "tillyxa",
    "tillyxad": "tillyxa",
    "tillyxade": "tillyxad",
    "tillyxades": "tillyxad",
    "tillyxads": "tillyxad",
    "tillyxande": "tillyxa",
    "tillyxanden": "tillyxande",
    "tillyxandena": "tillyxande",
    "tillyxandenas": "tillyxande",
    "tillyxandens": "tillyxande",
    "tillyxandes": "tillyxande",
    "tillyxandet": "tillyxande",
    "tillyxandets": "tillyxande",
    "tillyxar": "tillyxa",
    "tillyxas": "tillyxa",
    "tillyxat": "tillyxad",
    "tillyxats": "tillyxad",
    "tillägg": "tillägga",
    "tilläggande": "tillägga",
    "tillägganden": "tilläggande",
    "tilläggandena": "tilläggande",
    "tilläggandenas": "tilläggande",
    "tilläggandens": "tilläggande",
    "tilläggandes": "tilläggande",
    "tilläggandet": "tilläggande",
    "tilläggandets": "tilläggande",
    "tilläggas": "tillägga",
    "tilläggen": "tillägg",
    "tilläggens": "tillägg",
    "tillägger": "tillägga",
    "tillägges": "tillägga",
    "tillägget": "tillägg",
    "tilläggets": "tillägg",
    "tilläggs": "tillägga",
    "tilläggsbeloppen": "tilläggsbelopp",
    "tilläggsbeloppens": "tilläggsbelopp",
    "tilläggsbeloppet": "tilläggsbelopp",
    "tilläggsbeloppets": "tilläggsbelopp",
    "tilläggsbelopps": "tilläggsbelopp",
    "tilläggskostnaden": "tilläggskostnad",
    "tilläggskostnadens": "tilläggskostnad",
    "tilläggskostnader": "tilläggskostnad",
    "tilläggskostnaderna": "tilläggskostnad",
    "tilläggskostnadernas": "tilläggskostnad",
    "tilläggskostnaders": "tilläggskostnad",
    "tilläggskostnads": "tilläggskostnad",
    "tilläggsmandaten": "tilläggsmandat",
    "tilläggsmandatens": "tilläggsmandat",
    "tilläggsmandatet": "tilläggsmandat",
    "tilläggsmandatets": "tilläggsmandat",
    "tilläggsmandats": "tilläggsmandat",
    "tilläggspensionen": "tilläggspension",
    "tilläggspensionens": "tilläggspension",
    "tilläggspensioner": "tilläggspension",
    "tilläggspensionerna": "tilläggspension",
    "tilläggspensionernas": "tilläggspension",
    "tilläggspensioners": "tilläggspension",
    "tilläggspensions": "tilläggspension",
    "tilläggsplatsen": "tilläggsplats",
    "tilläggsplatsens": "tilläggsplats",
    "tilläggsplatser": "tilläggsplats",
    "tilläggsplatserna": "tilläggsplats",
    "tilläggsplatsernas": "tilläggsplats",
    "tilläggsplatsers": "tilläggsplats",
    "tilläggsstaten": "tilläggsstat",
    "tilläggsstatens": "tilläggsstat",
    "tilläggsstats": "tilläggsstat",
    "tillägn": "tillägna",
    "tillägnad": "tillägna",
    "tillägnade": "tillägna",
    "tillägnades": "tillägna",
    "tillägnads": "tillägna",
    "tillägnande": "tillägna",
    "tillägnanden": "tillägnande",
    "tillägnandena": "tillägnande",
    "tillägnandenas": "tillägnande",
    "tillägnandens": "tillägnande",
    "tillägnandes": "tillägnande",
    "tillägnandet": "tillägnande",
    "tillägnandets": "tillägnande",
    "tillägnans": "tillägnan",
    "tillägnar": "tillägna",
    "tillägnas": "tillägna",
    "tillägnat": "tillägna",
    "tillägnats": "tillägna",
    "tillägnelsen": "tillägnelse",
    "tillägnelsens": "tillägnelse",
    "tillägnelses": "tillägnelse",
    "tillämn": "tillämna",
    "tillämnad": "tillämna",
    "tillämnade": "tillämna",
    "tillämnades": "tillämna",
    "tillämnads": "tillämna",
    "tillämnande": "tillämna",
    "tillämnanden": "tillämnande",
    "tillämnandena": "tillämnande",
    "tillämnandenas": "tillämnande",
    "tillämnandens": "tillämnande",
    "tillämnandes": "tillämnande",
    "tillämnandet": "tillämnande",
    "tillämnandets": "tillämnande",
    "tillämnar": "tillämna",
    "tillämnas": "tillämna",
    "tillämnat": "tillämna",
    "tillämnats": "tillämna",
    "tillämp": "tillämpa",
    "tillämpad": "tillämpa",
    "tillämpade": "tillämpa",
    "tillämpades": "tillämpa",
    "tillämpads": "tillämpa",
    "tillämpande": "tillämpa",
    "tillämpanden": "tillämpande",
    "tillämpandena": "tillämpande",
    "tillämpandenas": "tillämpande",
    "tillämpandens": "tillämpande",
    "tillämpandes": "tillämpande",
    "tillämpandet": "tillämpande",
    "tillämpandets": "tillämpande",
    "tillämpar": "tillämpa",
    "tillämpas": "tillämpa",
    "tillämpat": "tillämpa",
    "tillämpats": "tillämpa",
    "tillämpliga": "tillämplig",
    "tillämpligare": "tillämplig",
    "tillämpligares": "tillämplig",
    "tillämpligas": "tillämplig",
    "tillämpligast": "tillämplig",
    "tillämpligaste": "tillämplig",
    "tillämpligastes": "tillämplig",
    "tillämpligasts": "tillämplig",
    "tillämplige": "tillämplig",
    "tillämpliges": "tillämplig",
    "tillämpligheten": "tillämplighet",
    "tillämplighetens": "tillämplighet",
    "tillämplighets": "tillämplighet",
    "tillämpligs": "tillämplig",
    "tillämpligt": "tillämplig",
    "tillämpligts": "tillämplig",
    "tillämpningar": "tillämpning",
    "tillämpningarna": "tillämpning",
    "tillämpningarnas": "tillämpning",
    "tillämpningars": "tillämpning",
    "tillämpningen": "tillämpning",
    "tillämpningens": "tillämpning",
    "tillämpnings": "tillämpning",
    "tillämpningsföreskriften": "tillämpningsföreskrift",
    "tillämpningsföreskriftens": "tillämpningsföreskrift",
    "tillämpningsföreskrifter": "tillämpningsföreskrift",
    "tillämpningsföreskrifterna": "tillämpningsföreskrift",
    "tillämpningsföreskrifternas": "tillämpningsföreskrift",
    "tillämpningsföreskrifters": "tillämpningsföreskrift",
    "tillämpningsföreskrifts": "tillämpningsföreskrift",
    "tilländalupens": "tilländalupen",
    "tilländalupet": "tilländalupen",
    "tilländalupets": "tilländalupen",
    "tilländalupna": "tilländalupen",
    "tilländalupnare": "tilländalupen",
    "tilländalupnares": "tilländalupen",
    "tilländalupnas": "tilländalupen",
    "tilländalupnast": "tilländalupen",
    "tilländalupnaste": "tilländalupen",
    "tilländalupnastes": "tilländalupen",
    "tilländalupnasts": "tilländalupen",
    "tilländalupne": "tilländalupen",
    "tilländalupnes": "tilländalupen",
    "tillät": "tillåta",
    "tilläts": "tillåta",
    "tillåt": "tillåta",
    "tillåtande": "tillåta",
    "tillåtanden": "tillåtande",
    "tillåtandena": "tillåtande",
    "tillåtandenas": "tillåtande",
    "tillåtandens": "tillåtande",
    "tillåtandes": "tillåtande",
    "tillåtandet": "tillåtande",
    "tillåtandets": "tillåtande",
    "tillåtas": "tillåta",
    "tillåte": "tillåta",
    "tillåtelsen": "tillåtelse",
    "tillåtelsens": "tillåtelse",
    "tillåtelses": "tillåtelse",
    "tillåten": "tillåta",
    "tillåtens": "tillåten",
    "tillåter": "tillåta",
    "tillåtes": "tillåta",
    "tillåtet": "tillåten",
    "tillåtets": "tillåten",
    "tillåtit": "tillåta",
    "tillåtits": "tillåta",
    "tillåtliga": "tillåtlig",
    "tillåtligare": "tillåtlig",
    "tillåtligares": "tillåtlig",
    "tillåtligas": "tillåtlig",
    "tillåtligast": "tillåtlig",
    "tillåtligaste": "tillåtlig",
    "tillåtligastes": "tillåtlig",
    "tillåtligasts": "tillåtlig",
    "tillåtlige": "tillåtlig",
    "tillåtliges": "tillåtlig",
    "tillåtligheten": "tillåtlighet",
    "tillåtlighetens": "tillåtlighet",
    "tillåtlighets": "tillåtlighet",
    "tillåtligs": "tillåtlig",
    "tillåtligt": "tillåtlig",
    "tillåtligts": "tillåtlig",
    "tillåtna": "tillåten",
    "tillåtnare": "tillåten",
    "tillåtnares": "tillåten",
    "tillåtnas": "tillåten",
    "tillåtnast": "tillåten",
    "tillåtnaste": "tillåten",
    "tillåtnastes": "tillåten",
    "tillåtnasts": "tillåten",
    "tillåtne": "tillåten",
    "tillåtnes": "tillåten",
    "tillåts": "tillåta",
    "tillökningar": "tillökning",
    "tillökningarna": "tillökning",
    "tillökningarnas": "tillökning",
    "tillökningars": "tillökning",
    "tillökningen": "tillökning",
    "tillökningens": "tillökning",
    "tillöknings": "tillökning",
    "tillönsk": "tillönska",
    "tillönskad": "tillönska",
    "tillönskade": "tillönska",
    "tillönskades": "tillönska",
    "tillönskads": "tillönska",
    "tillönskande": "tillönska",
    "tillönskanden": "tillönskande",
    "tillönskandena": "tillönskande",
    "tillönskandenas": "tillönskande",
    "tillönskandens": "tillönskande",
    "tillönskandes": "tillönskande",
    "tillönskandet": "tillönskande",
    "tillönskandets": "tillönskande",
    "tillönskans": "tillönskan",
    "tillönskar": "tillönska",
    "tillönskas": "tillönska",
    "tillönskat": "tillönska",
    "tillönskats": "tillönska",
    "tillönskningar": "tillönskning",
    "tillönskningarna": "tillönskning",
    "tillönskningarnas": "tillönskning",
    "tillönskningars": "tillönskning",
    "tillönskningen": "tillönskning",
    "tillönskningens": "tillönskning",
    "tillönsknings": "tillönskning",
    "tilt": "tilta",
    "tiltad": "tilta",
    "tiltade": "tilta",
    "tiltades": "tilta",
    "tiltads": "tilta",
    "tiltan": "tilta",
    "tiltande": "tilta",
    "tiltanden": "tiltande",
    "tiltandena": "tiltande",
    "tiltandenas": "tiltande",
    "tiltandens": "tiltande",
    "tiltandes": "tiltande",
    "tiltandet": "tiltande",
    "tiltandets": "tiltande",
    "tiltans": "tilta",
    "tiltar": "tilta",
    "tiltarna": "tilt",
    "tiltarnas": "tilt",
    "tiltars": "tilt",
    "tiltas": "tilta",
    "tiltat": "tilta",
    "tiltats": "tilta",
    "tilte": "tilta",
    "tilten": "tilt",
    "tiltens": "tilt",
    "tiltet": "tilt",
    "tiltets": "tilt",
    "tiltor": "tilta",
    "tiltorna": "tilta",
    "tiltornas": "tilta",
    "tiltors": "tilta",
    "tilts": "tilta",
    "tim": "timme",
    "timad": "tima",
    "timade": "tima",
    "timades": "tima",
    "timads": "tima",
    "timande": "tima",
    "timanden": "timande",
    "timandena": "timande",
    "timandenas": "timande",
    "timandens": "timande",
    "timandes": "timande",
    "timandet": "timande",
    "timandets": "timande",
    "timar": "tima",
    "timarvoden": "timarvode",
    "timarvodena": "timarvode",
    "timarvodenas": "timarvode",
    "timarvodens": "timarvode",
    "timarvodes": "timarvode",
    "timarvodet": "timarvode",
    "timarvodets": "timarvode",
    "timas": "tima",
    "timat": "tima",
    "timats": "tima",
    "timaxeln": "timaxel",
    "timaxelns": "timaxel",
    "timaxels": "timaxel",
    "timbalen": "timbal",
    "timbalens": "timbal",
    "timbaler": "timbal",
    "timbalerna": "timbal",
    "timbalernas": "timbal",
    "timbalers": "timbal",
    "timbals": "timbal",
    "timbren": "timbre",
    "timbrens": "timbre",
    "timbres": "timbre",
    "timcirkeln": "timcirkel",
    "timcirkelns": "timcirkel",
    "timcirkels": "timcirkel",
    "timcirklar": "timcirkel",
    "timcirklarna": "timcirkel",
    "timcirklarnas": "timcirkel",
    "timcirklars": "timcirkel",
    "timern": "timer",
    "timerns": "timer",
    "timers": "timer",
    "timglasen": "timglas",
    "timglasens": "timglas",
    "timglaset": "timglas",
    "timglasets": "timglas",
    "timida": "timid",
    "timidare": "timid",
    "timidares": "timid",
    "timidas": "timid",
    "timidast": "timid",
    "timidaste": "timid",
    "timidastes": "timid",
    "timidasts": "timid",
    "timide": "timid",
    "timides": "timid",
    "timids": "timid",
    "timingar": "timing",
    "timingarna": "timing",
    "timingarnas": "timing",
    "timingars": "timing",
    "timingen": "timing",
    "timingens": "timing",
    "timings": "timing",
    "timjanen": "timjan",
    "timjanens": "timjan",
    "timjans": "timjan",
    "timliga": "timlig",
    "timligare": "timlig",
    "timligares": "timlig",
    "timligas": "timlig",
    "timligast": "timlig",
    "timligaste": "timlig",
    "timligastes": "timlig",
    "timligasts": "timlig",
    "timlige": "timlig",
    "timliges": "timlig",
    "timligheten": "timlighet",
    "timlighetens": "timlighet",
    "timligheter": "timlighet",
    "timligheterna": "timlighet",
    "timligheternas": "timlighet",
    "timligheters": "timlighet",
    "timlighets": "timlighet",
    "timligs": "timlig",
    "timligt": "timlig",
    "timligts": "timlig",
    "timlärar": "timlärare",
    "timläraren": "timlärare",
    "timlärarens": "timlärare",
    "timlärares": "timlärare",
    "timlärarna": "timlärare",
    "timlärarnas": "timlärare",
    "timlönen": "timlön",
    "timlönens": "timlön",
    "timlöner": "timlön",
    "timlönerna": "timlön",
    "timlönernas": "timlön",
    "timlöners": "timlön",
    "timlöns": "timlön",
    "timman": "timma",
    "timmans": "timma",
    "timmar": "timme",
    "timmarna": "timme",
    "timmarnas": "timme",
    "timmars": "timme",
    "timmas": "timma",
    "timmen": "timme",
    "timmens": "timme",
    "timmeravläggen": "timmeravlägg",
    "timmeravläggens": "timmeravlägg",
    "timmeravlägget": "timmeravlägg",
    "timmeravläggets": "timmeravlägg",
    "timmeravläggs": "timmeravlägg",
    "timmerblädningar": "timmerblädning",
    "timmerblädningarna": "timmerblädning",
    "timmerblädningarnas": "timmerblädning",
    "timmerblädningars": "timmerblädning",
    "timmerblädningen": "timmerblädning",
    "timmerblädningens": "timmerblädning",
    "timmerblädnings": "timmerblädning",
    "timmerbrötar": "timmerbröt",
    "timmerbrötarna": "timmerbröt",
    "timmerbrötarnas": "timmerbröt",
    "timmerbrötars": "timmerbröt",
    "timmerbröten": "timmerbröt",
    "timmerbrötens": "timmerbröt",
    "timmerbröts": "timmerbröt",
    "timmerdoningar": "timmerdoning",
    "timmerdoningarna": "timmerdoning",
    "timmerdoningarnas": "timmerdoning",
    "timmerdoningars": "timmerdoning",
    "timmerdoningen": "timmerdoning",
    "timmerdoningens": "timmerdoning",
    "timmerdonings": "timmerdoning",
    "timmerflott": "timmerflotte",
    "timmerflottar": "timmerflotte",
    "timmerflottarna": "timmerflotte",
    "timmerflottarnas": "timmerflotte",
    "timmerflottars": "timmerflotte",
    "timmerflotten": "timmerflotte",
    "timmerflottens": "timmerflotte",
    "timmerflottes": "timmerflotte",
    "timmerflottningar": "timmerflottning",
    "timmerflottningarna": "timmerflottning",
    "timmerflottningarnas": "timmerflottning",
    "timmerflottningars": "timmerflottning",
    "timmerflottningen": "timmerflottning",
    "timmerflottningens": "timmerflottning",
    "timmerflottnings": "timmerflottning",
    "timmerflotts": "timmerflotte",
    "timmerhusen": "timmerhus",
    "timmerhusens": "timmerhus",
    "timmerhuset": "timmerhus",
    "timmerhusets": "timmerhus",
    "timmerkoj": "timmerkoja",
    "timmerkojan": "timmerkoja",
    "timmerkojans": "timmerkoja",
    "timmerkojas": "timmerkoja",
    "timmerkoje": "timmerkoja",
    "timmerkojor": "timmerkoja",
    "timmerkojorna": "timmerkoja",
    "timmerkojornas": "timmerkoja",
    "timmerkojors": "timmerkoja",
    "timmerkojs": "timmerkoja",
    "timmerläns": "timmerlänsa",
    "timmerlänsan": "timmerlänsa",
    "timmerlänsans": "timmerlänsa",
    "timmerlänsar": "timmerläns",
    "timmerlänsarna": "timmerläns",
    "timmerlänsarnas": "timmerläns",
    "timmerlänsars": "timmerläns",
    "timmerlänsas": "timmerlänsa",
    "timmerlänse": "timmerlänsa",
    "timmerlänsen": "timmerläns",
    "timmerlänsens": "timmerläns",
    "timmerlänsor": "timmerlänsa",
    "timmerlänsorna": "timmerlänsa",
    "timmerlänsornas": "timmerlänsa",
    "timmerlänsors": "timmerlänsa",
    "timmermagasinen": "timmermagasin",
    "timmermagasinens": "timmermagasin",
    "timmermagasinet": "timmermagasin",
    "timmermagasinets": "timmermagasin",
    "timmermagasins": "timmermagasin",
    "timmermannen": "timmerman",
    "timmermannens": "timmerman",
    "timmermans": "timmerman",
    "timmermän": "timmerman",
    "timmermännen": "timmerman",
    "timmermännens": "timmerman",
    "timmermäns": "timmerman",
    "timmerna": "timmer",
    "timmernas": "timmer",
    "timmers": "timmer",
    "timmersaxar": "timmersax",
    "timmersaxarna": "timmersax",
    "timmersaxarnas": "timmersax",
    "timmersaxars": "timmersax",
    "timmersaxen": "timmersax",
    "timmersaxens": "timmersax",
    "timmersläpen": "timmersläp",
    "timmersläpens": "timmersläp",
    "timmersläpet": "timmersläp",
    "timmersläpets": "timmersläp",
    "timmersläps": "timmersläp",
    "timmersteken": "timmerstek",
    "timmerstekens": "timmerstek",
    "timmersteket": "timmerstek",
    "timmerstekets": "timmerstek",
    "timmersteks": "timmerstek",
    "timmerstockar": "timmerstock",
    "timmerstockarna": "timmerstock",
    "timmerstockarnas": "timmerstock",
    "timmerstockars": "timmerstock",
    "timmerstocken": "timmerstock",
    "timmerstockens": "timmerstock",
    "timmerstocks": "timmerstock",
    "timmersvansar": "timmersvans",
    "timmersvansarna": "timmersvans",
    "timmersvansarnas": "timmersvans",
    "timmersvansars": "timmersvans",
    "timmersvansen": "timmersvans",
    "timmersvansens": "timmersvans",
    "timmes": "timme",
    "timotejen": "timotej",
    "timotejens": "timotej",
    "timotejs": "timotej",
    "timpenningar": "timpenning",
    "timpenningarna": "timpenning",
    "timpenningarnas": "timpenning",
    "timpenningars": "timpenning",
    "timpenningen": "timpenning",
    "timpenningens": "timpenning",
    "timpennings": "timpenning",
    "timrad": "timra",
    "timrade": "timra",
    "timrades": "timra",
    "timrads": "timra",
    "timrande": "timra",
    "timranden": "timrande",
    "timrandena": "timrande",
    "timrandenas": "timrande",
    "timrandens": "timrande",
    "timrandes": "timrande",
    "timrandet": "timrande",
    "timrandets": "timrande",
    "timrar": "timra",
    "timras": "timra",
    "timrat": "timra",
    "timrats": "timra",
    "timren": "timmer",
    "timrens": "timmer",
    "timret": "timmer",
    "timrets": "timmer",
    "tims": "timme",
    "timslagen": "timslag",
    "timslagens": "timslag",
    "timslaget": "timslag",
    "timslagets": "timslag",
    "timslags": "timslag",
    "timslånga": "timslång",
    "timslångare": "timslång",
    "timslångares": "timslång",
    "timslångas": "timslång",
    "timslångast": "timslång",
    "timslångaste": "timslång",
    "timslångastes": "timslång",
    "timslångasts": "timslång",
    "timslånge": "timslång",
    "timslånges": "timslång",
    "timslångs": "timslång",
    "timslångt": "timslång",
    "timslångts": "timslång",
    "timvisar": "timvisare",
    "timvisaren": "timvisare",
    "timvisarens": "timvisare",
    "timvisares": "timvisare",
    "timvisarna": "timvisare",
    "timvisarnas": "timvisare",
    "tin": "tina",
    "tinad": "tina",
    "tinade": "tina",
    "tinades": "tina",
    "tinads": "tina",
    "tinan": "tina",
    "tinande": "tina",
    "tinanden": "tinande",
    "tinandena": "tinande",
    "tinandenas": "tinande",
    "tinandens": "tinande",
    "tinandes": "tinande",
    "tinandet": "tinande",
    "tinandets": "tinande",
    "tinans": "tina",
    "tinar": "tina",
    "tinas": "tina",
    "tinat": "tina",
    "tinats": "tina",
    "tinder": "tindra",
    "tindrade": "tindra",
    "tindrades": "tindra",
    "tindrande": "tindra",
    "tindranden": "tindrande",
    "tindrandena": "tindrande",
    "tindrandenas": "tindrande",
    "tindrandens": "tindrande",
    "tindrandes": "tindrande",
    "tindrandet": "tindrande",
    "tindrandets": "tindrande",
    "tindrar": "tindra",
    "tindras": "tindra",
    "tindrat": "tindra",
    "tindrats": "tindra",
    "tine": "tina",
    "ting": "tinga",
    "tingad": "tinga",
    "tingade": "tinga",
    "tingades": "tinga",
    "tingads": "tinga",
    "tingande": "tinga",
    "tinganden": "tingande",
    "tingandena": "tingande",
    "tingandenas": "tingande",
    "tingandens": "tingande",
    "tingandes": "tingande",
    "tingandet": "tingande",
    "tingandets": "tingande",
    "tingar": "tinga",
    "tingas": "tinga",
    "tingat": "tinga",
    "tingats": "tinga",
    "tingeltangels": "tingeltangel",
    "tingeltanglet": "tingeltangel",
    "tingeltanglets": "tingeltangel",
    "tingen": "ting",
    "tingens": "ting",
    "tingestar": "tingest",
    "tingestarna": "tingest",
    "tingestarnas": "tingest",
    "tingestars": "tingest",
    "tingesten": "tingest",
    "tingestens": "tingest",
    "tingests": "tingest",
    "tinget": "ting",
    "tingets": "ting",
    "tingorden": "tingord",
    "tingordens": "tingord",
    "tingordet": "tingord",
    "tingordets": "tingord",
    "tingords": "tingord",
    "tings": "ting",
    "tingshusen": "tingshus",
    "tingshusens": "tingshus",
    "tingshuset": "tingshus",
    "tingshusets": "tingshus",
    "tingsmeriteringar": "tingsmeritering",
    "tingsmeriteringarna": "tingsmeritering",
    "tingsmeriteringarnas": "tingsmeritering",
    "tingsmeriteringars": "tingsmeritering",
    "tingsmeriteringen": "tingsmeritering",
    "tingsmeriteringens": "tingsmeritering",
    "tingsmeriterings": "tingsmeritering",
    "tingsrätten": "tingsrätt",
    "tingsrättens": "tingsrätt",
    "tingsrätter": "tingsrätt",
    "tingsrätterna": "tingsrätt",
    "tingsrätternas": "tingsrätt",
    "tingsrätters": "tingsrätt",
    "tingsrätts": "tingsrätt",
    "tingssalar": "tingssal",
    "tingssalarna": "tingssal",
    "tingssalarnas": "tingssal",
    "tingssalars": "tingssal",
    "tingssalen": "tingssal",
    "tingssalens": "tingssal",
    "tingssals": "tingssal",
    "tinkturen": "tinktur",
    "tinkturens": "tinktur",
    "tinkturer": "tinktur",
    "tinkturerna": "tinktur",
    "tinkturernas": "tinktur",
    "tinkturers": "tinktur",
    "tinkturs": "tinktur",
    "tinn": "tinne",
    "tinnar": "tinne",
    "tinnarna": "tinne",
    "tinnarnas": "tinne",
    "tinnars": "tinne",
    "tinnen": "tinne",
    "tinnens": "tinne",
    "tinnern": "tinner",
    "tinnerns": "tinner",
    "tinners": "tinner",
    "tinnes": "tinne",
    "tinningar": "tinning",
    "tinningarna": "tinning",
    "tinningarnas": "tinning",
    "tinningars": "tinning",
    "tinningbenen": "tinningben",
    "tinningbenens": "tinningben",
    "tinningbenet": "tinningben",
    "tinningbenets": "tinningben",
    "tinningbens": "tinningben",
    "tinningen": "tinning",
    "tinningens": "tinning",
    "tinningloben": "tinninglob",
    "tinninglobens": "tinninglob",
    "tinninglober": "tinninglob",
    "tinningloberna": "tinninglob",
    "tinninglobernas": "tinninglob",
    "tinninglobers": "tinninglob",
    "tinninglobs": "tinninglob",
    "tinnings": "tinning",
    "tinns": "tinne",
    "tinor": "tina",
    "tinorna": "tina",
    "tinornas": "tina",
    "tinors": "tina",
    "tins": "tina",
    "tiodubbels": "tiodubbel",
    "tiodubbelt": "tiodubbel",
    "tiodubbelts": "tiodubbel",
    "tiodubbla": "tiodubbel",
    "tiodubblad": "tiodubbla",
    "tiodubblade": "tiodubbla",
    "tiodubblades": "tiodubbla",
    "tiodubblads": "tiodubbla",
    "tiodubblande": "tiodubbla",
    "tiodubblanden": "tiodubblande",
    "tiodubblandena": "tiodubblande",
    "tiodubblandenas": "tiodubblande",
    "tiodubblandens": "tiodubblande",
    "tiodubblandes": "tiodubblande",
    "tiodubblandet": "tiodubblande",
    "tiodubblandets": "tiodubblande",
    "tiodubblar": "tiodubbla",
    "tiodubblare": "tiodubbel",
    "tiodubblares": "tiodubbel",
    "tiodubblas": "tiodubbla",
    "tiodubblast": "tiodubbel",
    "tiodubblaste": "tiodubbel",
    "tiodubblastes": "tiodubbel",
    "tiodubblasts": "tiodubbel",
    "tiodubblat": "tiodubbla",
    "tiodubblats": "tiodubbla",
    "tiodubble": "tiodubbel",
    "tiodubbles": "tiodubbel",
    "tiofaldig": "tiofaldiga",
    "tiofaldiga": "tiofaldig",
    "tiofaldigad": "tiofaldiga",
    "tiofaldigade": "tiofaldiga",
    "tiofaldigades": "tiofaldiga",
    "tiofaldigads": "tiofaldiga",
    "tiofaldigande": "tiofaldiga",
    "tiofaldiganden": "tiofaldigande",
    "tiofaldigandena": "tiofaldigande",
    "tiofaldigandenas": "tiofaldigande",
    "tiofaldigandens": "tiofaldigande",
    "tiofaldigandes": "tiofaldigande",
    "tiofaldigandet": "tiofaldigande",
    "tiofaldigandets": "tiofaldigande",
    "tiofaldigar": "tiofaldiga",
    "tiofaldigare": "tiofaldig",
    "tiofaldigares": "tiofaldig",
    "tiofaldigas": "tiofaldiga",
    "tiofaldigast": "tiofaldig",
    "tiofaldigaste": "tiofaldig",
    "tiofaldigastes": "tiofaldig",
    "tiofaldigasts": "tiofaldig",
    "tiofaldigat": "tiofaldiga",
    "tiofaldigats": "tiofaldiga",
    "tiofaldige": "tiofaldig",
    "tiofaldiges": "tiofaldig",
    "tiofaldigs": "tiofaldig",
    "tiofaldigt": "tiofaldig",
    "tiofaldigts": "tiofaldig",
    "tiofotingar": "tiofoting",
    "tiofotingarna": "tiofoting",
    "tiofotingarnas": "tiofoting",
    "tiofotingars": "tiofoting",
    "tiofotingen": "tiofoting",
    "tiofotingens": "tiofoting",
    "tiofotings": "tiofoting",
    "tiogradiga": "tiogradig",
    "tiogradigas": "tiogradig",
    "tiogradige": "tiogradig",
    "tiogradiges": "tiogradig",
    "tiogradigs": "tiogradig",
    "tiogradigt": "tiogradig",
    "tiogradigts": "tiogradig",
    "tiohundratalet": "tiohundratal",
    "tiohundratalets": "tiohundratal",
    "tiohundratals": "tiohundratal",
    "tiokampen": "tiokamp",
    "tiokampens": "tiokamp",
    "tiokamper": "tiokamp",
    "tiokamperna": "tiokamp",
    "tiokampernas": "tiokamp",
    "tiokampers": "tiokamp",
    "tiokamps": "tiokamp",
    "tiokron": "tiokrona",
    "tiokronan": "tiokrona",
    "tiokronans": "tiokrona",
    "tiokronas": "tiokrona",
    "tiokrone": "tiokrona",
    "tiokronor": "tiokrona",
    "tiokronorna": "tiokrona",
    "tiokronornas": "tiokrona",
    "tiokronors": "tiokrona",
    "tiokronorsmynten": "tiokronorsmynt",
    "tiokronorsmyntens": "tiokronorsmynt",
    "tiokronorsmyntet": "tiokronorsmynt",
    "tiokronorsmyntets": "tiokronorsmynt",
    "tiokronorsmynts": "tiokronorsmynt",
    "tiokronorssedeln": "tiokronorssedel",
    "tiokronorssedelns": "tiokronorssedel",
    "tiokronorssedels": "tiokronorssedel",
    "tiokronorssedlar": "tiokronorssedel",
    "tiokronorssedlarna": "tiokronorssedel",
    "tiokronorssedlarnas": "tiokronorssedel",
    "tiokronorssedlars": "tiokronorssedel",
    "tiokrons": "tiokrona",
    "tiominutersrasten": "tiominutersrast",
    "tiominutersrastens": "tiominutersrast",
    "tiominutersraster": "tiominutersrast",
    "tiominutersrasterna": "tiominutersrast",
    "tiominutersrasternas": "tiominutersrast",
    "tiominutersrasters": "tiominutersrast",
    "tiominutersrasts": "tiominutersrast",
    "tionde": "tio",
    "tiondedelar": "tiondedel",
    "tiondedelarna": "tiondedel",
    "tiondedelarnas": "tiondedel",
    "tiondedelars": "tiondedel",
    "tiondedelen": "tiondedel",
    "tiondedelens": "tiondedel",
    "tiondedels": "tiondedel",
    "tiondelar": "tiondel",
    "tiondelarna": "tiondel",
    "tiondelarnas": "tiondel",
    "tiondelars": "tiondel",
    "tiondelen": "tiondel",
    "tiondelens": "tiondel",
    "tiondels": "tiondel",
    "tiondes": "tionde",
    "tiondet": "tionde",
    "tiondets": "tionde",
    "tior": "tia",
    "tiorna": "tia",
    "tiornas": "tia",
    "tiors": "tia",
    "tios": "tio",
    "tiosnårets": "tiosnåret",
    "tiosyran": "tiosyra",
    "tiosyrans": "tiosyra",
    "tiosyras": "tiosyra",
    "tiosyre": "tiosyra",
    "tiosyror": "tiosyra",
    "tiosyrorna": "tiosyra",
    "tiosyrornas": "tiosyra",
    "tiosyrors": "tiosyra",
    "tiotalen": "tiotal",
    "tiotalens": "tiotal",
    "tiotalet": "tiotal",
    "tiotalets": "tiotal",
    "tiotalismen": "tiotalism",
    "tiotalismens": "tiotalism",
    "tiotalismer": "tiotalism",
    "tiotalismerna": "tiotalism",
    "tiotalismernas": "tiotalism",
    "tiotalismers": "tiotalism",
    "tiotalisms": "tiotalism",
    "tiotalisten": "tiotalist",
    "tiotalistens": "tiotalist",
    "tiotalister": "tiotalist",
    "tiotalisterna": "tiotalist",
    "tiotalisternas": "tiotalist",
    "tiotalisters": "tiotalist",
    "tiotalists": "tiotalist",
    "tiotals": "tiotal",
    "tiotusende": "tiotusen",
    "tiotusendes": "tiotusen",
    "tiotusens": "tiotusen",
    "tiotusentalen": "tiotusental",
    "tiotusentalens": "tiotusental",
    "tiotusentalet": "tiotusental",
    "tiotusentalets": "tiotusental",
    "tiotusentals": "tiotusental",
    "tioåriga": "tioårig",
    "tioårigas": "tioårig",
    "tioårige": "tioårig",
    "tioåriges": "tioårig",
    "tioårigs": "tioårig",
    "tioårigt": "tioårig",
    "tioårigts": "tioårig",
    "tioåringar": "tioåring",
    "tioåringarna": "tioåring",
    "tioåringarnas": "tioåring",
    "tioåringars": "tioåring",
    "tioåringen": "tioåring",
    "tioåringens": "tioåring",
    "tioårings": "tioåring",
    "tioöringar": "tioöring",
    "tioöringarna": "tioöring",
    "tioöringarnas": "tioöring",
    "tioöringars": "tioöring",
    "tioöringen": "tioöring",
    "tioöringens": "tioöring",
    "tioörings": "tioöring",
    "tipp": "tippa",
    "tippad": "tippa",
    "tippade": "tippa",
    "tippades": "tippa",
    "tippads": "tippa",
    "tippande": "tippa",
    "tippanden": "tippande",
    "tippandena": "tippande",
    "tippandenas": "tippande",
    "tippandens": "tippande",
    "tippandes": "tippande",
    "tippandet": "tippande",
    "tippandets": "tippande",
    "tippar": "tippare",
    "tipparen": "tippare",
    "tipparens": "tippare",
    "tippares": "tippare",
    "tipparna": "tippare",
    "tipparnas": "tippare",
    "tippars": "tipp",
    "tippas": "tippa",
    "tippat": "tippa",
    "tippats": "tippa",
    "tippen": "tipp",
    "tippens": "tipp",
    "tippflaken": "tippflak",
    "tippflakens": "tippflak",
    "tippflaket": "tippflak",
    "tippflakets": "tippflak",
    "tippflaks": "tippflak",
    "tipps": "tipp",
    "tippskydden": "tippskydd",
    "tippskyddens": "tippskydd",
    "tippskyddet": "tippskydd",
    "tippskyddets": "tippskydd",
    "tippskydds": "tippskydd",
    "tippvagnar": "tippvagn",
    "tippvagnarna": "tippvagn",
    "tippvagnarnas": "tippvagn",
    "tippvagnars": "tippvagn",
    "tippvagnen": "tippvagn",
    "tippvagnens": "tippvagn",
    "tippvagns": "tippvagn",
    "tips": "tipsa",
    "tipsad": "tipsa",
    "tipsade": "tipsa",
    "tipsades": "tipsa",
    "tipsads": "tipsa",
    "tipsande": "tipsa",
    "tipsanden": "tipsande",
    "tipsandena": "tipsande",
    "tipsandenas": "tipsande",
    "tipsandens": "tipsande",
    "tipsandes": "tipsande",
    "tipsandet": "tipsande",
    "tipsandets": "tipsande",
    "tipsar": "tipsa",
    "tipsas": "tipsa",
    "tipsat": "tipsa",
    "tipsats": "tipsa",
    "tipsen": "tips",
    "tipsens": "tips",
    "tipset": "tips",
    "tipsets": "tips",
    "tipskupongen": "tipskupong",
    "tipskupongens": "tipskupong",
    "tipskuponger": "tipskupong",
    "tipskupongerna": "tipskupong",
    "tipskupongernas": "tipskupong",
    "tipskupongers": "tipskupong",
    "tipskupongs": "tipskupong",
    "tipspromenaden": "tipspromenad",
    "tipspromenadens": "tipspromenad",
    "tipspromenader": "tipspromenad",
    "tipspromenaderna": "tipspromenad",
    "tipspromenadernas": "tipspromenad",
    "tipspromenaders": "tipspromenad",
    "tipspromenads": "tipspromenad",
    "tipsraden": "tipsrad",
    "tipsradens": "tipsrad",
    "tipsrader": "tipsrad",
    "tipsraderna": "tipsrad",
    "tipsradernas": "tipsrad",
    "tipsraders": "tipsrad",
    "tipsrads": "tipsrad",
    "tipsrundan": "tipsrunda",
    "tipsrundans": "tipsrunda",
    "tipsrundas": "tipsrunda",
    "tipsrunde": "tipsrunda",
    "tipsrundor": "tipsrunda",
    "tipsrundorna": "tipsrunda",
    "tipsrundornas": "tipsrunda",
    "tipsrundors": "tipsrunda",
    "tipstjänsts": "tipstjänst",
    "tipstävlingar": "tipstävling",
    "tipstävlingarna": "tipstävling",
    "tipstävlingarnas": "tipstävling",
    "tipstävlingars": "tipstävling",
    "tipstävlingen": "tipstävling",
    "tipstävlingens": "tipstävling",
    "tipstävlings": "tipstävling",
    "tir": "tira",
    "tirad": "tira",
    "tirade": "tira",
    "tiraden": "tirad",
    "tiradens": "tirad",
    "tirader": "tirad",
    "tiraderna": "tirad",
    "tiradernas": "tirad",
    "tiraders": "tirad",
    "tirades": "tira",
    "tirads": "tirad",
    "tirande": "tira",
    "tiranden": "tirande",
    "tirandena": "tirande",
    "tirandenas": "tirande",
    "tirandens": "tirande",
    "tirandes": "tirande",
    "tirandet": "tirande",
    "tirandets": "tirande",
    "tirar": "tira",
    "tirarna": "tir",
    "tirarnas": "tir",
    "tirars": "tir",
    "tiras": "tira",
    "tirat": "tira",
    "tirats": "tira",
    "tiren": "tir",
    "tirens": "tir",
    "tirs": "tir",
    "tischan": "tischa",
    "tischans": "tischa",
    "tischas": "tischa",
    "tischor": "tischa",
    "tischorna": "tischa",
    "tischornas": "tischa",
    "tischors": "tischa",
    "tisdagar": "tisdag",
    "tisdagarna": "tisdag",
    "tisdagarnas": "tisdag",
    "tisdagars": "tisdag",
    "tisdageftermiddagar": "tisdageftermiddag",
    "tisdageftermiddagarna": "tisdageftermiddag",
    "tisdageftermiddagarnas": "tisdageftermiddag",
    "tisdageftermiddagars": "tisdageftermiddag",
    "tisdageftermiddagen": "tisdageftermiddag",
    "tisdageftermiddagens": "tisdageftermiddag",
    "tisdageftermiddags": "tisdageftermiddag",
    "tisdagen": "tisdag",
    "tisdagens": "tisdag",
    "tisdagkvällar": "tisdagkväll",
    "tisdagkvällarna": "tisdagkväll",
    "tisdagkvällarnas": "tisdagkväll",
    "tisdagkvällars": "tisdagkväll",
    "tisdagkvällen": "tisdagkväll",
    "tisdagkvällens": "tisdagkväll",
    "tisdagkvälls": "tisdagkväll",
    "tisdagmorgnar": "tisdagmorgon",
    "tisdagmorgnarna": "tisdagmorgon",
    "tisdagmorgnarnas": "tisdagmorgon",
    "tisdagmorgnars": "tisdagmorgon",
    "tisdagmorgonen": "tisdagmorgon",
    "tisdagmorgonens": "tisdagmorgon",
    "tisdagmorgons": "tisdagmorgon",
    "tisdagmornar": "tisdagmorgon",
    "tisdagmornarna": "tisdagmorgon",
    "tisdagmornarnas": "tisdagmorgon",
    "tisdagmornars": "tisdagmorgon",
    "tisdags": "tisdag",
    "tisdagseftermiddagar": "tisdagseftermiddag",
    "tisdagseftermiddagarna": "tisdagseftermiddag",
    "tisdagseftermiddagarnas": "tisdagseftermiddag",
    "tisdagseftermiddagars": "tisdagseftermiddag",
    "tisdagseftermiddagen": "tisdagseftermiddag",
    "tisdagseftermiddagens": "tisdagseftermiddag",
    "tisdagseftermiddags": "tisdagseftermiddag",
    "tisdagskvällar": "tisdagskväll",
    "tisdagskvällarna": "tisdagskväll",
    "tisdagskvällarnas": "tisdagskväll",
    "tisdagskvällars": "tisdagskväll",
    "tisdagskvällen": "tisdagskväll",
    "tisdagskvällens": "tisdagskväll",
    "tisdagskvälls": "tisdagskväll",
    "tisdagsmorgnar": "tisdagsmorgon",
    "tisdagsmorgnarna": "tisdagsmorgon",
    "tisdagsmorgnarnas": "tisdagsmorgon",
    "tisdagsmorgnars": "tisdagsmorgon",
    "tisdagsmorgonen": "tisdagsmorgon",
    "tisdagsmorgonens": "tisdagsmorgon",
    "tisdagsmorgons": "tisdagsmorgon",
    "tisdagsmornar": "tisdagsmorgon",
    "tisdagsmornarna": "tisdagsmorgon",
    "tisdagsmornarnas": "tisdagsmorgon",
    "tisdagsmornars": "tisdagsmorgon",
    "tisdagssoppan": "tisdagssoppa",
    "tisdagssoppans": "tisdagssoppa",
    "tisdagssoppas": "tisdagssoppa",
    "tishan": "tisha",
    "tishans": "tisha",
    "tishas": "tisha",
    "tishor": "tisha",
    "tishorna": "tisha",
    "tishornas": "tisha",
    "tishors": "tisha",
    "tissel": "tissla",
    "tissels": "tissel",
    "tisslade": "tissla",
    "tisslades": "tissla",
    "tisslande": "tissla",
    "tisslanden": "tisslande",
    "tisslandena": "tisslande",
    "tisslandenas": "tisslande",
    "tisslandens": "tisslande",
    "tisslandes": "tisslande",
    "tisslandet": "tisslande",
    "tisslandets": "tisslande",
    "tisslar": "tissla",
    "tisslas": "tissla",
    "tisslat": "tissla",
    "tisslats": "tissla",
    "tisslet": "tissel",
    "tisslets": "tissel",
    "tistelborr": "tistelborre",
    "tistelborrar": "tistelborre",
    "tistelborrarna": "tistelborre",
    "tistelborrarnas": "tistelborre",
    "tistelborrars": "tistelborre",
    "tistelborren": "tistelborre",
    "tistelborrens": "tistelborre",
    "tistelborres": "tistelborre",
    "tistelborrs": "tistelborre",
    "tisteln": "tistel",
    "tistelns": "tistel",
    "tistels": "tistel",
    "tistelstänger": "tistelstång",
    "tistelstängerna": "tistelstång",
    "tistelstängernas": "tistelstång",
    "tistelstängers": "tistelstång",
    "tistelstången": "tistelstång",
    "tistelstångens": "tistelstång",
    "tistelstångs": "tistelstång",
    "tistlar": "tistel",
    "tistlarna": "tistel",
    "tistlarnas": "tistel",
    "tistlars": "tistel",
    "tistronen": "tistron",
    "tistronens": "tistron",
    "tistronet": "tistron",
    "tistronets": "tistron",
    "tistrons": "tistron",
    "tit": "tita",
    "titan": "tita",
    "titanen": "titan",
    "titanens": "titan",
    "titaner": "titan",
    "titanerna": "titan",
    "titanernas": "titan",
    "titaners": "titan",
    "titanet": "titan",
    "titanets": "titan",
    "titaniska": "titanisk",
    "titaniskare": "titanisk",
    "titaniskares": "titanisk",
    "titaniskas": "titanisk",
    "titaniskast": "titanisk",
    "titaniskaste": "titanisk",
    "titaniskastes": "titanisk",
    "titaniskasts": "titanisk",
    "titaniske": "titanisk",
    "titaniskes": "titanisk",
    "titanisks": "titanisk",
    "titaniskt": "titanisk",
    "titaniskts": "titanisk",
    "titans": "titan",
    "titanskruvar": "titanskruv",
    "titanskruvarna": "titanskruv",
    "titanskruvarnas": "titanskruv",
    "titanskruvars": "titanskruv",
    "titanskruven": "titanskruv",
    "titanskruvens": "titanskruv",
    "titanskruvs": "titanskruv",
    "titanvitts": "titanvitt",
    "titas": "tita",
    "tite": "tita",
    "titelbladen": "titelblad",
    "titelbladens": "titelblad",
    "titelbladet": "titelblad",
    "titelbladets": "titelblad",
    "titelblads": "titelblad",
    "titelbortläggningar": "titelbortläggning",
    "titelbortläggningarna": "titelbortläggning",
    "titelbortläggningarnas": "titelbortläggning",
    "titelbortläggningars": "titelbortläggning",
    "titelbortläggningen": "titelbortläggning",
    "titelbortläggningens": "titelbortläggning",
    "titelbortläggnings": "titelbortläggning",
    "titeldikten": "titeldikt",
    "titeldiktens": "titeldikt",
    "titeldikter": "titeldikt",
    "titeldikterna": "titeldikt",
    "titeldikternas": "titeldikt",
    "titeldikters": "titeldikt",
    "titeldikts": "titeldikt",
    "titelförsvarar": "titelförsvarare",
    "titelförsvararen": "titelförsvarare",
    "titelförsvararens": "titelförsvarare",
    "titelförsvarares": "titelförsvarare",
    "titelförsvararna": "titelförsvarare",
    "titelförsvararnas": "titelförsvarare",
    "titelmatchen": "titelmatch",
    "titelmatchens": "titelmatch",
    "titelmatcher": "titelmatch",
    "titelmatcherna": "titelmatch",
    "titelmatchernas": "titelmatch",
    "titelmatchers": "titelmatch",
    "titelmatchs": "titelmatch",
    "titeln": "titel",
    "titelnovellen": "titelnovell",
    "titelnovellens": "titelnovell",
    "titelnoveller": "titelnovell",
    "titelnovellerna": "titelnovell",
    "titelnovellernas": "titelnovell",
    "titelnovellers": "titelnovell",
    "titelnovells": "titelnovell",
    "titelns": "titel",
    "titelrollen": "titelroll",
    "titelrollens": "titelroll",
    "titelroller": "titelroll",
    "titelrollerna": "titelroll",
    "titelrollernas": "titelroll",
    "titelrollers": "titelroll",
    "titelrolls": "titelroll",
    "titels": "titel",
    "titelsidan": "titelsida",
    "titelsidans": "titelsida",
    "titelsidas": "titelsida",
    "titelside": "titelsida",
    "titelsides": "titelsida",
    "titelsidor": "titelsida",
    "titelsidorna": "titelsida",
    "titelsidornas": "titelsida",
    "titelsidors": "titelsida",
    "titelsjuka": "titelsjuk",
    "titelsjukan": "titelsjuka",
    "titelsjukans": "titelsjuka",
    "titelsjukare": "titelsjuk",
    "titelsjukares": "titelsjuk",
    "titelsjukas": "titelsjuka",
    "titelsjukast": "titelsjuk",
    "titelsjukaste": "titelsjuk",
    "titelsjukastes": "titelsjuk",
    "titelsjukasts": "titelsjuk",
    "titelsjuke": "titelsjuka",
    "titelsjukes": "titelsjuk",
    "titelsjukheten": "titelsjukhet",
    "titelsjukhetens": "titelsjukhet",
    "titelsjukhets": "titelsjukhet",
    "titelsjuks": "titelsjuka",
    "titelsjukt": "titelsjuk",
    "titelsjukts": "titelsjuk",
    "titlar": "titel",
    "titlarna": "titel",
    "titlarnas": "titel",
    "titlars": "titel",
    "titor": "tita",
    "titorna": "tita",
    "titornas": "tita",
    "titors": "tita",
    "titrerad": "titrera",
    "titrerade": "titrera",
    "titrerades": "titrera",
    "titrerads": "titrera",
    "titrerande": "titrera",
    "titreranden": "titrerande",
    "titrerandena": "titrerande",
    "titrerandenas": "titrerande",
    "titrerandens": "titrerande",
    "titrerandes": "titrerande",
    "titrerandet": "titrerande",
    "titrerandets": "titrerande",
    "titrerar": "titrera",
    "titreras": "titrera",
    "titrerat": "titrera",
    "titrerats": "titrera",
    "titrerbara": "titrerbar",
    "titrerbarare": "titrerbar",
    "titrerbarares": "titrerbar",
    "titrerbaras": "titrerbar",
    "titrerbarast": "titrerbar",
    "titrerbaraste": "titrerbar",
    "titrerbarastes": "titrerbar",
    "titrerbarasts": "titrerbar",
    "titrerbare": "titrerbar",
    "titrerbares": "titrerbar",
    "titrerbarheten": "titrerbarhet",
    "titrerbarhetens": "titrerbarhet",
    "titrerbarhets": "titrerbarhet",
    "titrerbars": "titrerbar",
    "titrerbart": "titrerbar",
    "titrerbarts": "titrerbar",
    "titreringar": "titrering",
    "titreringarna": "titrering",
    "titreringarnas": "titrering",
    "titreringars": "titrering",
    "titreringen": "titrering",
    "titreringens": "titrering",
    "titrerings": "titrering",
    "tits": "tita",
    "titt": "titta",
    "tittad": "titta",
    "tittade": "titta",
    "tittades": "titta",
    "tittads": "titta",
    "tittande": "titta",
    "tittanden": "tittande",
    "tittandena": "tittande",
    "tittandenas": "tittande",
    "tittandens": "tittande",
    "tittandes": "tittande",
    "tittandet": "tittande",
    "tittandets": "tittande",
    "tittar": "tittare",
    "tittaren": "tittare",
    "tittarens": "tittare",
    "tittares": "tittare",
    "tittarfloppar": "tittarflopp",
    "tittarflopparna": "tittarflopp",
    "tittarflopparnas": "tittarflopp",
    "tittarfloppars": "tittarflopp",
    "tittarfloppen": "tittarflopp",
    "tittarfloppens": "tittarflopp",
    "tittarflopps": "tittarflopp",
    "tittarframgångar": "tittarframgång",
    "tittarframgångarna": "tittarframgång",
    "tittarframgångarnas": "tittarframgång",
    "tittarframgångars": "tittarframgång",
    "tittarframgången": "tittarframgång",
    "tittarframgångens": "tittarframgång",
    "tittarframgångs": "tittarframgång",
    "tittarmässiga": "tittarmässig",
    "tittarmässigare": "tittarmässig",
    "tittarmässigares": "tittarmässig",
    "tittarmässigas": "tittarmässig",
    "tittarmässigast": "tittarmässig",
    "tittarmässigaste": "tittarmässig",
    "tittarmässigastes": "tittarmässig",
    "tittarmässigasts": "tittarmässig",
    "tittarmässige": "tittarmässig",
    "tittarmässiges": "tittarmässig",
    "tittarmässigs": "tittarmässig",
    "tittarmässigt": "tittarmässig",
    "tittarmässigts": "tittarmässig",
    "tittarna": "tittare",
    "tittarnas": "tittare",
    "tittars": "titt",
    "tittarstormar": "tittarstorm",
    "tittarstormarna": "tittarstorm",
    "tittarstormarnas": "tittarstorm",
    "tittarstormars": "tittarstorm",
    "tittarstormen": "tittarstorm",
    "tittarstormens": "tittarstorm",
    "tittarstorms": "tittarstorm",
    "tittarsuccéer": "tittarsuccé",
    "tittarsuccéerna": "tittarsuccé",
    "tittarsuccéernas": "tittarsuccé",
    "tittarsuccéers": "tittarsuccé",
    "tittarsuccén": "tittarsuccé",
    "tittarsuccéns": "tittarsuccé",
    "tittarsuccés": "tittarsuccé",
    "tittartävlingar": "tittartävling",
    "tittartävlingarna": "tittartävling",
    "tittartävlingarnas": "tittartävling",
    "tittartävlingars": "tittartävling",
    "tittartävlingen": "tittartävling",
    "tittartävlingens": "tittartävling",
    "tittartävlings": "tittartävling",
    "tittas": "titta",
    "tittat": "titta",
    "tittats": "titta",
    "titten": "titt",
    "tittens": "titt",
    "tittgluggar": "tittglugg",
    "tittgluggarna": "tittglugg",
    "tittgluggarnas": "tittglugg",
    "tittgluggars": "tittglugg",
    "tittgluggen": "tittglugg",
    "tittgluggens": "tittglugg",
    "tittgluggs": "tittglugg",
    "titthålen": "titthål",
    "titthålens": "titthål",
    "titthålet": "titthål",
    "titthålets": "titthål",
    "titthåls": "titthål",
    "titthålskirurgien": "titthålskirurgi",
    "titthålskirurgiens": "titthålskirurgi",
    "titthålskirurgin": "titthålskirurgi",
    "titthålskirurgins": "titthålskirurgi",
    "titthålskirurgis": "titthålskirurgi",
    "titthålsoperationen": "titthålsoperation",
    "titthålsoperationens": "titthålsoperation",
    "titthålsoperationer": "titthålsoperation",
    "titthålsoperationerna": "titthålsoperation",
    "titthålsoperationernas": "titthålsoperation",
    "titthålsoperationers": "titthålsoperation",
    "titthålsoperations": "titthålsoperation",
    "titts": "titt",
    "tittskåpen": "tittskåp",
    "tittskåpens": "tittskåp",
    "tittskåpet": "tittskåp",
    "tittskåpets": "tittskåp",
    "tittskåps": "tittskåp",
    "tittuts": "tittut",
    "titulaturen": "titulatur",
    "titulaturens": "titulatur",
    "titulaturer": "titulatur",
    "titulaturerna": "titulatur",
    "titulaturernas": "titulatur",
    "titulaturers": "titulatur",
    "titulaturs": "titulatur",
    "titulerad": "titulera",
    "titulerade": "titulera",
    "titulerades": "titulera",
    "titulerads": "titulera",
    "titulerande": "titulera",
    "tituleranden": "titulerande",
    "titulerandena": "titulerande",
    "titulerandenas": "titulerande",
    "titulerandens": "titulerande",
    "titulerandes": "titulerande",
    "titulerandet": "titulerande",
    "titulerandets": "titulerande",
    "titulerar": "titulera",
    "tituleras": "titulera",
    "titulerat": "titulera",
    "titulerats": "titulera",
    "titulerbara": "titulerbar",
    "titulerbarare": "titulerbar",
    "titulerbarares": "titulerbar",
    "titulerbaras": "titulerbar",
    "titulerbarast": "titulerbar",
    "titulerbaraste": "titulerbar",
    "titulerbarastes": "titulerbar",
    "titulerbarasts": "titulerbar",
    "titulerbare": "titulerbar",
    "titulerbares": "titulerbar",
    "titulerbarheten": "titulerbarhet",
    "titulerbarhetens": "titulerbarhet",
    "titulerbarhets": "titulerbarhet",
    "titulerbars": "titulerbar",
    "titulerbart": "titulerbar",
    "titulerbarts": "titulerbar",
    "tituleringar": "titulering",
    "tituleringarna": "titulering",
    "tituleringarnas": "titulering",
    "tituleringars": "titulering",
    "tituleringen": "titulering",
    "tituleringens": "titulering",
    "titulerings": "titulering",
    "titulärkonsuler": "titulärkonsul",
    "titulärkonsulerna": "titulärkonsul",
    "titulärkonsulernas": "titulärkonsul",
    "titulärkonsulers": "titulärkonsul",
    "titulärkonsuln": "titulärkonsul",
    "titulärkonsulns": "titulärkonsul",
    "titulärkonsuls": "titulärkonsul",
    "tivolin": "tivoli",
    "tivolina": "tivoli",
    "tivolinas": "tivoli",
    "tivolins": "tivoli",
    "tivolis": "tivoli",
    "tivolit": "tivoli",
    "tivolits": "tivoli",
    "tixotropa": "tixotrop",
    "tixotropare": "tixotrop",
    "tixotropares": "tixotrop",
    "tixotropas": "tixotrop",
    "tixotropast": "tixotrop",
    "tixotropaste": "tixotrop",
    "tixotropastes": "tixotrop",
    "tixotropasts": "tixotrop",
    "tixotrope": "tixotrop",
    "tixotropes": "tixotrop",
    "tixotrops": "tixotrop",
    "tixotropt": "tixotrop",
    "tixotropts": "tixotrop",
    "tjack": "tjacka",
    "tjackad": "tjacka",
    "tjackade": "tjacka",
    "tjackades": "tjacka",
    "tjackads": "tjacka",
    "tjackande": "tjacka",
    "tjackanden": "tjackande",
    "tjackandena": "tjackande",
    "tjackandenas": "tjackande",
    "tjackandens": "tjackande",
    "tjackandes": "tjackande",
    "tjackandet": "tjackande",
    "tjackandets": "tjackande",
    "tjackar": "tjacka",
    "tjackas": "tjacka",
    "tjackat": "tjacka",
    "tjackats": "tjacka",
    "tjacken": "tjack",
    "tjackens": "tjack",
    "tjacket": "tjack",
    "tjackets": "tjack",
    "tjacks": "tjack",
    "tjafs": "tjafsa",
    "tjafsad": "tjafsa",
    "tjafsade": "tjafsa",
    "tjafsades": "tjafsa",
    "tjafsads": "tjafsa",
    "tjafsande": "tjafsa",
    "tjafsanden": "tjafsande",
    "tjafsandena": "tjafsande",
    "tjafsandenas": "tjafsande",
    "tjafsandens": "tjafsande",
    "tjafsandes": "tjafsande",
    "tjafsandet": "tjafsande",
    "tjafsandets": "tjafsande",
    "tjafsar": "tjafsa",
    "tjafsas": "tjafsa",
    "tjafsat": "tjafsa",
    "tjafsats": "tjafsa",
    "tjafset": "tjafs",
    "tjafsets": "tjafs",
    "tjafsiga": "tjafsig",
    "tjafsigare": "tjafsig",
    "tjafsigares": "tjafsig",
    "tjafsigas": "tjafsig",
    "tjafsigast": "tjafsig",
    "tjafsigaste": "tjafsig",
    "tjafsigastes": "tjafsig",
    "tjafsigasts": "tjafsig",
    "tjafsige": "tjafsig",
    "tjafsiges": "tjafsig",
    "tjafsigheten": "tjafsighet",
    "tjafsighetens": "tjafsighet",
    "tjafsighets": "tjafsighet",
    "tjafsigs": "tjafsig",
    "tjafsigt": "tjafsig",
    "tjafsigts": "tjafsig",
    "tjalkar": "tjalk",
    "tjalkarna": "tjalk",
    "tjalkarnas": "tjalk",
    "tjalkars": "tjalk",
    "tjalken": "tjalk",
    "tjalkens": "tjalk",
    "tjalks": "tjalk",
    "tjall": "tjalla",
    "tjallad": "tjalla",
    "tjallade": "tjalla",
    "tjallades": "tjalla",
    "tjallads": "tjalla",
    "tjallande": "tjalla",
    "tjallanden": "tjallande",
    "tjallandena": "tjallande",
    "tjallandenas": "tjallande",
    "tjallandens": "tjallande",
    "tjallandes": "tjallande",
    "tjallandet": "tjallande",
    "tjallandets": "tjallande",
    "tjallar": "tjallare",
    "tjallaren": "tjallare",
    "tjallarens": "tjallare",
    "tjallares": "tjallare",
    "tjallarna": "tjallare",
    "tjallarnas": "tjallare",
    "tjallas": "tjalla",
    "tjallat": "tjalla",
    "tjallats": "tjalla",
    "tjallet": "tjall",
    "tjallets": "tjall",
    "tjalls": "tjall",
    "tjat": "tjata",
    "tjatad": "tjata",
    "tjatade": "tjata",
    "tjatades": "tjata",
    "tjatads": "tjata",
    "tjatande": "tjata",
    "tjatanden": "tjatande",
    "tjatandena": "tjatande",
    "tjatandenas": "tjatande",
    "tjatandens": "tjatande",
    "tjatandes": "tjatande",
    "tjatandet": "tjatande",
    "tjatandets": "tjatande",
    "tjatar": "tjata",
    "tjatas": "tjata",
    "tjatat": "tjata",
    "tjatats": "tjata",
    "tjatet": "tjat",
    "tjatets": "tjat",
    "tjatiga": "tjatig",
    "tjatigare": "tjatig",
    "tjatigares": "tjatig",
    "tjatigas": "tjatig",
    "tjatigast": "tjatig",
    "tjatigaste": "tjatig",
    "tjatigastes": "tjatig",
    "tjatigasts": "tjatig",
    "tjatige": "tjatig",
    "tjatiges": "tjatig",
    "tjatigs": "tjatig",
    "tjatigt": "tjatig",
    "tjatigts": "tjatig",
    "tjats": "tjat",
    "tjatter": "tjattra",
    "tjatters": "tjatter",
    "tjattrade": "tjattra",
    "tjattrades": "tjattra",
    "tjattrande": "tjattra",
    "tjattranden": "tjattrande",
    "tjattrandena": "tjattrande",
    "tjattrandenas": "tjattrande",
    "tjattrandens": "tjattrande",
    "tjattrandes": "tjattrande",
    "tjattrandet": "tjattrande",
    "tjattrandets": "tjattrande",
    "tjattrar": "tjattra",
    "tjattras": "tjattra",
    "tjattrat": "tjattra",
    "tjattrats": "tjattra",
    "tjattret": "tjatter",
    "tjattrets": "tjatter",
    "tjecken": "tjeck",
    "tjeckens": "tjeck",
    "tjecker": "tjeck",
    "tjeckerna": "tjeck",
    "tjeckernas": "tjeck",
    "tjeckers": "tjeck",
    "tjeckisk": "tjeckiska",
    "tjeckiska": "tjeckisk",
    "tjeckiskan": "tjeckiska",
    "tjeckiskans": "tjeckiska",
    "tjeckiskare": "tjeckisk",
    "tjeckiskares": "tjeckisk",
    "tjeckiskas": "tjeckiska",
    "tjeckiskast": "tjeckisk",
    "tjeckiskaste": "tjeckisk",
    "tjeckiskastes": "tjeckisk",
    "tjeckiskasts": "tjeckisk",
    "tjeckiske": "tjeckiska",
    "tjeckiskes": "tjeckisk",
    "tjeckiskor": "tjeckiska",
    "tjeckiskorna": "tjeckiska",
    "tjeckiskornas": "tjeckiska",
    "tjeckiskors": "tjeckiska",
    "tjeckisks": "tjeckisk",
    "tjeckiskt": "tjeckisk",
    "tjeckiskts": "tjeckisk",
    "tjeckoslovaken": "tjeckoslovak",
    "tjeckoslovakens": "tjeckoslovak",
    "tjeckoslovaker": "tjeckoslovak",
    "tjeckoslovakerna": "tjeckoslovak",
    "tjeckoslovakernas": "tjeckoslovak",
    "tjeckoslovakers": "tjeckoslovak",
    "tjeckoslovakiska": "tjeckoslovakisk",
    "tjeckoslovakiskan": "tjeckoslovakiska",
    "tjeckoslovakiskans": "tjeckoslovakiska",
    "tjeckoslovakiskare": "tjeckoslovakisk",
    "tjeckoslovakiskares": "tjeckoslovakisk",
    "tjeckoslovakiskas": "tjeckoslovakiska",
    "tjeckoslovakiskast": "tjeckoslovakisk",
    "tjeckoslovakiskaste": "tjeckoslovakisk",
    "tjeckoslovakiskastes": "tjeckoslovakisk",
    "tjeckoslovakiskasts": "tjeckoslovakisk",
    "tjeckoslovakiske": "tjeckoslovakiska",
    "tjeckoslovakiskes": "tjeckoslovakisk",
    "tjeckoslovakiskor": "tjeckoslovakiska",
    "tjeckoslovakiskorna": "tjeckoslovakiska",
    "tjeckoslovakiskornas": "tjeckoslovakiska",
    "tjeckoslovakiskors": "tjeckoslovakiska",
    "tjeckoslovakisks": "tjeckoslovakisk",
    "tjeckoslovakiskt": "tjeckoslovakisk",
    "tjeckoslovakiskts": "tjeckoslovakisk",
    "tjeckoslovaks": "tjeckoslovak",
    "tjecks": "tjeck",
    "tjejen": "tjej",
    "tjejens": "tjej",
    "tjejer": "tjej",
    "tjejerna": "tjej",
    "tjejernas": "tjej",
    "tjejers": "tjej",
    "tjejs": "tjej",
    "tjejslakten": "tjejslakt",
    "tjejslaktens": "tjejslakt",
    "tjejslakter": "tjejslakt",
    "tjejslakterna": "tjejslakt",
    "tjejslakternas": "tjejslakt",
    "tjejslakters": "tjejslakt",
    "tjejslakts": "tjejslakt",
    "tjekan": "tjeka",
    "tjekans": "tjeka",
    "tjekas": "tjeka",
    "tjetjenen": "tjetjen",
    "tjetjenens": "tjetjen",
    "tjetjener": "tjetjen",
    "tjetjenerna": "tjetjen",
    "tjetjenernas": "tjetjen",
    "tjetjeners": "tjetjen",
    "tjetjens": "tjetjen",
    "tjetjensk": "tjetjenska",
    "tjetjenska": "tjetjensk",
    "tjetjenskan": "tjetjenska",
    "tjetjenskans": "tjetjenska",
    "tjetjenskare": "tjetjensk",
    "tjetjenskares": "tjetjensk",
    "tjetjenskas": "tjetjenska",
    "tjetjenskast": "tjetjensk",
    "tjetjenskaste": "tjetjensk",
    "tjetjenskastes": "tjetjensk",
    "tjetjenskasts": "tjetjensk",
    "tjetjenske": "tjetjenska",
    "tjetjenskes": "tjetjensk",
    "tjetjenskor": "tjetjenska",
    "tjetjenskorna": "tjetjenska",
    "tjetjenskornas": "tjetjenska",
    "tjetjenskors": "tjetjenska",
    "tjetjensks": "tjetjensk",
    "tjetjenskt": "tjetjensk",
    "tjetjenskts": "tjetjensk",
    "tjill": "tjilla",
    "tjillade": "tjilla",
    "tjillades": "tjilla",
    "tjillande": "tjilla",
    "tjillanden": "tjillande",
    "tjillandena": "tjillande",
    "tjillandenas": "tjillande",
    "tjillandens": "tjillande",
    "tjillandes": "tjillande",
    "tjillandet": "tjillande",
    "tjillandets": "tjillande",
    "tjillar": "tjilla",
    "tjillas": "tjilla",
    "tjillat": "tjilla",
    "tjillats": "tjilla",
    "tjimmade": "tjimma",
    "tjimmades": "tjimma",
    "tjimmande": "tjimma",
    "tjimmanden": "tjimmande",
    "tjimmandena": "tjimmande",
    "tjimmandenas": "tjimmande",
    "tjimmandens": "tjimmande",
    "tjimmandes": "tjimmande",
    "tjimmandet": "tjimmande",
    "tjimmandets": "tjimmande",
    "tjimmar": "tjimma",
    "tjimmas": "tjimma",
    "tjimmat": "tjimma",
    "tjimmats": "tjimma",
    "tjimmet": "tjim",
    "tjimmets": "tjim",
    "tjims": "tjim",
    "tjing": "tjinga",
    "tjingad": "tjinga",
    "tjingade": "tjinga",
    "tjingades": "tjinga",
    "tjingads": "tjinga",
    "tjingande": "tjinga",
    "tjinganden": "tjingande",
    "tjingandena": "tjingande",
    "tjingandenas": "tjingande",
    "tjingandens": "tjingande",
    "tjingandes": "tjingande",
    "tjingandet": "tjingande",
    "tjingandets": "tjingande",
    "tjingar": "tjinga",
    "tjingas": "tjinga",
    "tjingat": "tjinga",
    "tjingats": "tjinga",
    "tjirrar": "tjirre",
    "tjirrarna": "tjirre",
    "tjirrarnas": "tjirre",
    "tjirrars": "tjirre",
    "tjirren": "tjirre",
    "tjirrens": "tjirre",
    "tjirres": "tjirre",
    "tjo": "tjoa",
    "tjoad": "tjoa",
    "tjoade": "tjoa",
    "tjoades": "tjoa",
    "tjoads": "tjoa",
    "tjoande": "tjoa",
    "tjoanden": "tjoande",
    "tjoandena": "tjoande",
    "tjoandenas": "tjoande",
    "tjoandens": "tjoande",
    "tjoandes": "tjoande",
    "tjoandet": "tjoande",
    "tjoandets": "tjoande",
    "tjoar": "tjoa",
    "tjoas": "tjoa",
    "tjoat": "tjoa",
    "tjoats": "tjoa",
    "tjocka": "tjock",
    "tjockan": "tjocka",
    "tjockans": "tjocka",
    "tjockare": "tjock",
    "tjockares": "tjock",
    "tjockas": "tjocka",
    "tjockast": "tjock",
    "tjockaste": "tjock",
    "tjockastes": "tjock",
    "tjockasts": "tjock",
    "tjocke": "tjock",
    "tjockes": "tjock",
    "tjockheten": "tjockhet",
    "tjockhetens": "tjockhet",
    "tjockhets": "tjockhet",
    "tjockhudade": "tjockhudad",
    "tjockhudades": "tjockhudad",
    "tjockhudads": "tjockhudad",
    "tjockhudat": "tjockhudad",
    "tjockhudats": "tjockhudad",
    "tjockhudingar": "tjockhuding",
    "tjockhudingarna": "tjockhuding",
    "tjockhudingarnas": "tjockhuding",
    "tjockhudingars": "tjockhuding",
    "tjockhudingen": "tjockhuding",
    "tjockhudingens": "tjockhuding",
    "tjockhudings": "tjockhuding",
    "tjockisar": "tjockis",
    "tjockisarna": "tjockis",
    "tjockisarnas": "tjockis",
    "tjockisars": "tjockis",
    "tjockisen": "tjockis",
    "tjockisens": "tjockis",
    "tjocklekar": "tjocklek",
    "tjocklekarna": "tjocklek",
    "tjocklekarnas": "tjocklek",
    "tjocklekars": "tjocklek",
    "tjockleken": "tjocklek",
    "tjocklekens": "tjocklek",
    "tjockleks": "tjocklek",
    "tjockmagade": "tjockmagad",
    "tjockmagades": "tjockmagad",
    "tjockmagads": "tjockmagad",
    "tjockmagat": "tjockmagad",
    "tjockmagats": "tjockmagad",
    "tjockmjölken": "tjockmjölk",
    "tjockmjölkens": "tjockmjölk",
    "tjockmjölks": "tjockmjölk",
    "tjockn": "tjockna",
    "tjocknad": "tjockna",
    "tjocknade": "tjockna",
    "tjocknades": "tjockna",
    "tjocknads": "tjockna",
    "tjocknande": "tjockna",
    "tjocknanden": "tjocknande",
    "tjocknandena": "tjocknande",
    "tjocknandenas": "tjocknande",
    "tjocknandens": "tjocknande",
    "tjocknandes": "tjocknande",
    "tjocknandet": "tjocknande",
    "tjocknandets": "tjocknande",
    "tjocknar": "tjockna",
    "tjocknas": "tjockna",
    "tjocknat": "tjockna",
    "tjocknats": "tjockna",
    "tjockoljan": "tjockolja",
    "tjockoljans": "tjockolja",
    "tjockoljas": "tjockolja",
    "tjockolje": "tjockolja",
    "tjocks": "tjock",
    "tjockskall": "tjockskalle",
    "tjockskallar": "tjockskalle",
    "tjockskallarna": "tjockskalle",
    "tjockskallarnas": "tjockskalle",
    "tjockskallars": "tjockskalle",
    "tjockskallen": "tjockskalle",
    "tjockskallens": "tjockskalle",
    "tjockskalles": "tjockskalle",
    "tjockskalliga": "tjockskallig",
    "tjockskalligare": "tjockskallig",
    "tjockskalligares": "tjockskallig",
    "tjockskalligas": "tjockskallig",
    "tjockskalligast": "tjockskallig",
    "tjockskalligaste": "tjockskallig",
    "tjockskalligastes": "tjockskallig",
    "tjockskalligasts": "tjockskallig",
    "tjockskallige": "tjockskallig",
    "tjockskalliges": "tjockskallig",
    "tjockskalligheten": "tjockskallighet",
    "tjockskallighetens": "tjockskallighet",
    "tjockskalligheter": "tjockskallighet",
    "tjockskalligheterna": "tjockskallighet",
    "tjockskalligheternas": "tjockskallighet",
    "tjockskalligheters": "tjockskallighet",
    "tjockskallighets": "tjockskallighet",
    "tjockskalligs": "tjockskallig",
    "tjockskalligt": "tjockskallig",
    "tjockskalligts": "tjockskallig",
    "tjockskalls": "tjockskalle",
    "tjockt": "tjock",
    "tjocktarmar": "tjocktarm",
    "tjocktarmarna": "tjocktarm",
    "tjocktarmarnas": "tjocktarm",
    "tjocktarmars": "tjocktarm",
    "tjocktarmen": "tjocktarm",
    "tjocktarmens": "tjocktarm",
    "tjocktarms": "tjocktarm",
    "tjocktarmstumören": "tjocktarmstumör",
    "tjocktarmstumörens": "tjocktarmstumör",
    "tjocktarmstumörer": "tjocktarmstumör",
    "tjocktarmstumörerna": "tjocktarmstumör",
    "tjocktarmstumörernas": "tjocktarmstumör",
    "tjocktarmstumörers": "tjocktarmstumör",
    "tjocktarmstumörs": "tjocktarmstumör",
    "tjockts": "tjock",
    "tjoet": "tjo",
    "tjoets": "tjo",
    "tjogen": "tjog",
    "tjogens": "tjog",
    "tjoget": "tjog",
    "tjogets": "tjog",
    "tjogs": "tjog",
    "tjom": "tjomme",
    "tjommar": "tjomme",
    "tjommarna": "tjomme",
    "tjommarnas": "tjomme",
    "tjommars": "tjomme",
    "tjommen": "tjomme",
    "tjommens": "tjomme",
    "tjommes": "tjomme",
    "tjoms": "tjomme",
    "tjongad": "tjonga",
    "tjongade": "tjonga",
    "tjongades": "tjonga",
    "tjongads": "tjonga",
    "tjongande": "tjonga",
    "tjonganden": "tjongande",
    "tjongandena": "tjongande",
    "tjongandenas": "tjongande",
    "tjongandens": "tjongande",
    "tjongandes": "tjongande",
    "tjongandet": "tjongande",
    "tjongandets": "tjongande",
    "tjongar": "tjonga",
    "tjongas": "tjonga",
    "tjongat": "tjonga",
    "tjongats": "tjonga",
    "tjorrar": "tjorre",
    "tjorrarna": "tjorre",
    "tjorrarnas": "tjorre",
    "tjorrars": "tjorre",
    "tjorren": "tjorre",
    "tjorrens": "tjorre",
    "tjorres": "tjorre",
    "tjorv": "tjorva",
    "tjorvad": "tjorva",
    "tjorvade": "tjorva",
    "tjorvades": "tjorva",
    "tjorvads": "tjorva",
    "tjorvande": "tjorva",
    "tjorvanden": "tjorvande",
    "tjorvandena": "tjorvande",
    "tjorvandenas": "tjorvande",
    "tjorvandens": "tjorvande",
    "tjorvandes": "tjorvande",
    "tjorvandet": "tjorvande",
    "tjorvandets": "tjorvande",
    "tjorvar": "tjorva",
    "tjorvas": "tjorva",
    "tjorvat": "tjorva",
    "tjorvats": "tjorva",
    "tjos": "tjo",
    "tjotaheitis": "tjotaheiti",
    "tjotahejtis": "tjotahejti",
    "tjottablängar": "tjottablängare",
    "tjottablängaren": "tjottablängare",
    "tjottablängarens": "tjottablängare",
    "tjottablängares": "tjottablängare",
    "tjottablängarna": "tjottablängare",
    "tjottablängarnas": "tjottablängare",
    "tjottaheitis": "tjottaheiti",
    "tjottahejtis": "tjottahejti",
    "tjuderna": "tjuder",
    "tjudernas": "tjuder",
    "tjuders": "tjuder",
    "tjudrad": "tjudra",
    "tjudrade": "tjudra",
    "tjudrades": "tjudra",
    "tjudrads": "tjudra",
    "tjudrande": "tjudra",
    "tjudranden": "tjudrande",
    "tjudrandena": "tjudrande",
    "tjudrandenas": "tjudrande",
    "tjudrandens": "tjudrande",
    "tjudrandes": "tjudrande",
    "tjudrandet": "tjudrande",
    "tjudrandets": "tjudrande",
    "tjudrar": "tjudra",
    "tjudras": "tjudra",
    "tjudrat": "tjudra",
    "tjudrats": "tjudra",
    "tjudren": "tjuder",
    "tjudrens": "tjuder",
    "tjudret": "tjuder",
    "tjudrets": "tjuder",
    "tjug": "tjuga",
    "tjugan": "tjuga",
    "tjugans": "tjuga",
    "tjugas": "tjuga",
    "tjuge": "tjuga",
    "tjuges": "tjuge",
    "tjugoandra": "tjugotvå",
    "tjugoandras": "tjugotvå",
    "tjugoandre": "tjugotvå",
    "tjugoandres": "tjugotvå",
    "tjugoens": "tjugoen",
    "tjugoett": "tjugoen",
    "tjugoetts": "tjugoett",
    "tjugoettsnårets": "tjugoettsnåret",
    "tjugoettåriga": "tjugoettårig",
    "tjugoettårigas": "tjugoettårig",
    "tjugoettårige": "tjugoettårig",
    "tjugoettåriges": "tjugoettårig",
    "tjugoettårigs": "tjugoettårig",
    "tjugoettårigt": "tjugoettårig",
    "tjugoettårigts": "tjugoettårig",
    "tjugoettåringar": "tjugoettåring",
    "tjugoettåringarna": "tjugoettåring",
    "tjugoettåringarnas": "tjugoettåring",
    "tjugoettåringars": "tjugoettåring",
    "tjugoettåringen": "tjugoettåring",
    "tjugoettåringens": "tjugoettåring",
    "tjugoettårings": "tjugoettåring",
    "tjugofaldiga": "tjugofaldig",
    "tjugofaldigad": "tjugofaldiga",
    "tjugofaldigade": "tjugofaldiga",
    "tjugofaldigades": "tjugofaldiga",
    "tjugofaldigads": "tjugofaldiga",
    "tjugofaldigande": "tjugofaldiga",
    "tjugofaldiganden": "tjugofaldigande",
    "tjugofaldigandena": "tjugofaldigande",
    "tjugofaldigandenas": "tjugofaldigande",
    "tjugofaldigandens": "tjugofaldigande",
    "tjugofaldigandes": "tjugofaldigande",
    "tjugofaldigandet": "tjugofaldigande",
    "tjugofaldigandets": "tjugofaldigande",
    "tjugofaldigar": "tjugofaldiga",
    "tjugofaldigas": "tjugofaldiga",
    "tjugofaldigat": "tjugofaldiga",
    "tjugofaldigats": "tjugofaldiga",
    "tjugofaldige": "tjugofaldig",
    "tjugofaldiges": "tjugofaldig",
    "tjugofaldigs": "tjugofaldig",
    "tjugofaldigt": "tjugofaldig",
    "tjugofaldigts": "tjugofaldig",
    "tjugofems": "tjugofem",
    "tjugofemte": "tjugofem",
    "tjugofemtes": "tjugofem",
    "tjugofemåriga": "tjugofemårig",
    "tjugofemårigas": "tjugofemårig",
    "tjugofemårige": "tjugofemårig",
    "tjugofemåriges": "tjugofemårig",
    "tjugofemårigs": "tjugofemårig",
    "tjugofemårigt": "tjugofemårig",
    "tjugofemårigts": "tjugofemårig",
    "tjugofemåringar": "tjugofemåring",
    "tjugofemåringarna": "tjugofemåring",
    "tjugofemåringarnas": "tjugofemåring",
    "tjugofemåringars": "tjugofemåring",
    "tjugofemåringen": "tjugofemåring",
    "tjugofemåringens": "tjugofemåring",
    "tjugofemårings": "tjugofemåring",
    "tjugofemöringar": "tjugofemöring",
    "tjugofemöringarna": "tjugofemöring",
    "tjugofemöringarnas": "tjugofemöring",
    "tjugofemöringars": "tjugofemöring",
    "tjugofemöringen": "tjugofemöring",
    "tjugofemöringens": "tjugofemöring",
    "tjugofemörings": "tjugofemöring",
    "tjugofjärde": "tjugofyra",
    "tjugofjärdes": "tjugofyra",
    "tjugofyras": "tjugofyra",
    "tjugofyrasnårets": "tjugofyrasnåret",
    "tjugofyraåriga": "tjugofyraårig",
    "tjugofyraårigas": "tjugofyraårig",
    "tjugofyraårige": "tjugofyraårig",
    "tjugofyraåriges": "tjugofyraårig",
    "tjugofyraårigs": "tjugofyraårig",
    "tjugofyraårigt": "tjugofyraårig",
    "tjugofyraårigts": "tjugofyraårig",
    "tjugofyraåringar": "tjugofyraåring",
    "tjugofyraåringarna": "tjugofyraåring",
    "tjugofyraåringarnas": "tjugofyraåring",
    "tjugofyraåringars": "tjugofyraåring",
    "tjugofyraåringen": "tjugofyraåring",
    "tjugofyraåringens": "tjugofyraåring",
    "tjugofyraårings": "tjugofyraåring",
    "tjugoförsta": "tjugoen",
    "tjugoförstas": "tjugoen",
    "tjugoförste": "tjugoen",
    "tjugoförstes": "tjugoen",
    "tjugohundratalet": "tjugohundratal",
    "tjugohundratalets": "tjugohundratal",
    "tjugohundratals": "tjugohundratal",
    "tjugokilossäckar": "tjugokilossäck",
    "tjugokilossäckarna": "tjugokilossäck",
    "tjugokilossäckarnas": "tjugokilossäck",
    "tjugokilossäckars": "tjugokilossäck",
    "tjugokilossäcken": "tjugokilossäck",
    "tjugokilossäckens": "tjugokilossäck",
    "tjugokilossäcks": "tjugokilossäck",
    "tjugondagen": "tjugondag",
    "tjugondagens": "tjugondag",
    "tjugondags": "tjugondag",
    "tjugonde": "tjugo",
    "tjugondedagar": "tjugondedag",
    "tjugondedagarna": "tjugondedag",
    "tjugondedagarnas": "tjugondedag",
    "tjugondedagars": "tjugondedag",
    "tjugondedagen": "tjugondedag",
    "tjugondedagens": "tjugondedag",
    "tjugondedags": "tjugondedag",
    "tjugondedelar": "tjugondedel",
    "tjugondedelarna": "tjugondedel",
    "tjugondedelarnas": "tjugondedel",
    "tjugondedelars": "tjugondedel",
    "tjugondedelen": "tjugondedel",
    "tjugondedelens": "tjugondedel",
    "tjugondedels": "tjugondedel",
    "tjugondelar": "tjugondel",
    "tjugondelarna": "tjugondel",
    "tjugondelarnas": "tjugondel",
    "tjugondelars": "tjugondel",
    "tjugondelen": "tjugondel",
    "tjugondelens": "tjugondel",
    "tjugondels": "tjugondel",
    "tjugondes": "tjugo",
    "tjugoplaniga": "tjugoplanig",
    "tjugoplanigare": "tjugoplanig",
    "tjugoplanigares": "tjugoplanig",
    "tjugoplanigas": "tjugoplanig",
    "tjugoplanigast": "tjugoplanig",
    "tjugoplanigaste": "tjugoplanig",
    "tjugoplanigastes": "tjugoplanig",
    "tjugoplanigasts": "tjugoplanig",
    "tjugoplanige": "tjugoplanig",
    "tjugoplaniges": "tjugoplanig",
    "tjugoplanigs": "tjugoplanig",
    "tjugoplanigt": "tjugoplanig",
    "tjugoplanigts": "tjugoplanig",
    "tjugor": "tjuga",
    "tjugorna": "tjuga",
    "tjugornas": "tjuga",
    "tjugors": "tjuga",
    "tjugos": "tjugo",
    "tjugosjunde": "tjugosju",
    "tjugosjundes": "tjugosju",
    "tjugosjus": "tjugosju",
    "tjugosnårets": "tjugosnåret",
    "tjugotalen": "tjugotal",
    "tjugotalens": "tjugotal",
    "tjugotalet": "tjugotal",
    "tjugotalets": "tjugotal",
    "tjugotals": "tjugotal",
    "tjugotredje": "tjugotre",
    "tjugotredjes": "tjugotre",
    "tjugotres": "tjugotre",
    "tjugotresnårets": "tjugotresnåret",
    "tjugotreåriga": "tjugotreårig",
    "tjugotreårigas": "tjugotreårig",
    "tjugotreårige": "tjugotreårig",
    "tjugotreåriges": "tjugotreårig",
    "tjugotreårigs": "tjugotreårig",
    "tjugotreårigt": "tjugotreårig",
    "tjugotreårigts": "tjugotreårig",
    "tjugotreåringar": "tjugotreåring",
    "tjugotreåringarna": "tjugotreåring",
    "tjugotreåringarnas": "tjugotreåring",
    "tjugotreåringars": "tjugotreåring",
    "tjugotreåringen": "tjugotreåring",
    "tjugotreåringens": "tjugotreåring",
    "tjugotreårings": "tjugotreåring",
    "tjugotvås": "tjugotvå",
    "tjugotvåsnårets": "tjugotvåsnåret",
    "tjugotvååriga": "tjugotvåårig",
    "tjugotvåårigas": "tjugotvåårig",
    "tjugotvåårige": "tjugotvåårig",
    "tjugotvååriges": "tjugotvåårig",
    "tjugotvåårigs": "tjugotvåårig",
    "tjugotvåårigt": "tjugotvåårig",
    "tjugotvåårigts": "tjugotvåårig",
    "tjugotvååringar": "tjugotvååring",
    "tjugotvååringarna": "tjugotvååring",
    "tjugotvååringarnas": "tjugotvååring",
    "tjugotvååringars": "tjugotvååring",
    "tjugotvååringen": "tjugotvååring",
    "tjugotvååringens": "tjugotvååring",
    "tjugotvåårings": "tjugotvååring",
    "tjugoåriga": "tjugoårig",
    "tjugoårigas": "tjugoårig",
    "tjugoårige": "tjugoårig",
    "tjugoåriges": "tjugoårig",
    "tjugoårigs": "tjugoårig",
    "tjugoårigt": "tjugoårig",
    "tjugoårigts": "tjugoårig",
    "tjugoåringar": "tjugoåring",
    "tjugoåringarna": "tjugoåring",
    "tjugoåringarnas": "tjugoåring",
    "tjugoåringars": "tjugoåring",
    "tjugoåringen": "tjugoåring",
    "tjugoåringens": "tjugoåring",
    "tjugoårings": "tjugoåring",
    "tjugs": "tjuga",
    "tjugus": "tjugu",
    "tjur": "tjura",
    "tjurad": "tjura",
    "tjurade": "tjura",
    "tjurades": "tjura",
    "tjurads": "tjura",
    "tjurande": "tjura",
    "tjuranden": "tjurande",
    "tjurandena": "tjurande",
    "tjurandenas": "tjurande",
    "tjurandens": "tjurande",
    "tjurandes": "tjurande",
    "tjurandet": "tjurande",
    "tjurandets": "tjurande",
    "tjurar": "tjura",
    "tjurarna": "tjur",
    "tjurarnas": "tjur",
    "tjurars": "tjur",
    "tjuras": "tjura",
    "tjurat": "tjura",
    "tjurats": "tjura",
    "tjuren": "tjur",
    "tjurens": "tjur",
    "tjurfäktar": "tjurfäktare",
    "tjurfäktaren": "tjurfäktare",
    "tjurfäktarens": "tjurfäktare",
    "tjurfäktares": "tjurfäktare",
    "tjurfäktarna": "tjurfäktare",
    "tjurfäktarnas": "tjurfäktare",
    "tjurfäktningar": "tjurfäktning",
    "tjurfäktningarna": "tjurfäktning",
    "tjurfäktningarnas": "tjurfäktning",
    "tjurfäktningars": "tjurfäktning",
    "tjurfäktningen": "tjurfäktning",
    "tjurfäktningens": "tjurfäktning",
    "tjurfäktnings": "tjurfäktning",
    "tjurfäktningsförsvaret": "tjurfäktningsförsvar",
    "tjurfäktningsförsvarets": "tjurfäktningsförsvar",
    "tjurfäktningsförsvars": "tjurfäktningsförsvar",
    "tjurfäktningsmotståndar": "tjurfäktningsmotståndare",
    "tjurfäktningsmotståndaren": "tjurfäktningsmotståndare",
    "tjurfäktningsmotståndarens": "tjurfäktningsmotståndare",
    "tjurfäktningsmotståndares": "tjurfäktningsmotståndare",
    "tjurfäktningsmotståndarna": "tjurfäktningsmotståndare",
    "tjurfäktningsmotståndarnas": "tjurfäktningsmotståndare",
    "tjuriga": "tjurig",
    "tjurigare": "tjurig",
    "tjurigares": "tjurig",
    "tjurigas": "tjurig",
    "tjurigast": "tjurig",
    "tjurigaste": "tjurig",
    "tjurigastes": "tjurig",
    "tjurigasts": "tjurig",
    "tjurige": "tjurig",
    "tjuriges": "tjurig",
    "tjurigs": "tjurig",
    "tjurigt": "tjurig",
    "tjurigts": "tjurig",
    "tjurnack": "tjurnacke",
    "tjurnackar": "tjurnacke",
    "tjurnackarna": "tjurnacke",
    "tjurnackarnas": "tjurnacke",
    "tjurnackars": "tjurnacke",
    "tjurnacken": "tjurnacke",
    "tjurnackens": "tjurnacke",
    "tjurnackes": "tjurnacke",
    "tjurnacks": "tjurnacke",
    "tjurrusningar": "tjurrusning",
    "tjurrusningarna": "tjurrusning",
    "tjurrusningarnas": "tjurrusning",
    "tjurrusningars": "tjurrusning",
    "tjurrusningen": "tjurrusning",
    "tjurrusningens": "tjurrusning",
    "tjurrusnings": "tjurrusning",
    "tjurs": "tjur",
    "tjurskall": "tjurskalle",
    "tjurskallar": "tjurskalle",
    "tjurskallarna": "tjurskalle",
    "tjurskallarnas": "tjurskalle",
    "tjurskallars": "tjurskalle",
    "tjurskallen": "tjurskalle",
    "tjurskallens": "tjurskalle",
    "tjurskalles": "tjurskalle",
    "tjurskalliga": "tjurskallig",
    "tjurskalligare": "tjurskallig",
    "tjurskalligares": "tjurskallig",
    "tjurskalligas": "tjurskallig",
    "tjurskalligast": "tjurskallig",
    "tjurskalligaste": "tjurskallig",
    "tjurskalligastes": "tjurskallig",
    "tjurskalligasts": "tjurskallig",
    "tjurskallige": "tjurskallig",
    "tjurskalliges": "tjurskallig",
    "tjurskalligheten": "tjurskallighet",
    "tjurskallighetens": "tjurskallighet",
    "tjurskalligheter": "tjurskallighet",
    "tjurskalligheterna": "tjurskallighet",
    "tjurskalligheternas": "tjurskallighet",
    "tjurskalligheters": "tjurskallighet",
    "tjurskallighets": "tjurskallighet",
    "tjurskalligs": "tjurskallig",
    "tjurskalligt": "tjurskallig",
    "tjurskalligts": "tjurskallig",
    "tjurskalls": "tjurskalle",
    "tjurveden": "tjurved",
    "tjurvedens": "tjurved",
    "tjurveds": "tjurved",
    "tjus": "tjusa",
    "tjusad": "tjusa",
    "tjusade": "tjusa",
    "tjusades": "tjusa",
    "tjusads": "tjusa",
    "tjusande": "tjusa",
    "tjusanden": "tjusande",
    "tjusandena": "tjusande",
    "tjusandenas": "tjusande",
    "tjusandens": "tjusande",
    "tjusandes": "tjusande",
    "tjusandet": "tjusande",
    "tjusandets": "tjusande",
    "tjusar": "tjusa",
    "tjusarlockar": "tjusarlock",
    "tjusarlockarna": "tjusarlock",
    "tjusarlockarnas": "tjusarlock",
    "tjusarlockars": "tjusarlock",
    "tjusarlocken": "tjusarlock",
    "tjusarlockens": "tjusarlock",
    "tjusarlocks": "tjusarlock",
    "tjusas": "tjusa",
    "tjusat": "tjusa",
    "tjusats": "tjusa",
    "tjusd": "tjusa",
    "tjusda": "tjusa",
    "tjusdas": "tjusa",
    "tjusde": "tjusa",
    "tjusdes": "tjusa",
    "tjusds": "tjusa",
    "tjusiga": "tjusig",
    "tjusigare": "tjusig",
    "tjusigares": "tjusig",
    "tjusigas": "tjusig",
    "tjusigast": "tjusig",
    "tjusigaste": "tjusig",
    "tjusigastes": "tjusig",
    "tjusigasts": "tjusig",
    "tjusige": "tjusig",
    "tjusiges": "tjusig",
    "tjusigs": "tjusig",
    "tjusigt": "tjusig",
    "tjusigts": "tjusig",
    "tjuskraften": "tjuskraft",
    "tjuskraftens": "tjuskraft",
    "tjuskrafts": "tjuskraft",
    "tjusningar": "tjusning",
    "tjusningarna": "tjusning",
    "tjusningarnas": "tjusning",
    "tjusningars": "tjusning",
    "tjusningen": "tjusning",
    "tjusningens": "tjusning",
    "tjusnings": "tjusning",
    "tjust": "tjusa",
    "tjuste": "tjusa",
    "tjustes": "tjusa",
    "tjusts": "tjusa",
    "tjut": "tjuta",
    "tjutande": "tjuta",
    "tjutanden": "tjutande",
    "tjutandena": "tjutande",
    "tjutandenas": "tjutande",
    "tjutandens": "tjutande",
    "tjutandes": "tjutande",
    "tjutandet": "tjutande",
    "tjutandets": "tjutande",
    "tjutas": "tjuta",
    "tjute": "tjuta",
    "tjuten": "tjut",
    "tjutens": "tjut",
    "tjuter": "tjuta",
    "tjutes": "tjuta",
    "tjutet": "tjut",
    "tjutets": "tjut",
    "tjutit": "tjuta",
    "tjutits": "tjuta",
    "tjuts": "tjuta",
    "tjuv": "tjuva",
    "tjuvad": "tjuva",
    "tjuvade": "tjuva",
    "tjuvades": "tjuva",
    "tjuvads": "tjuva",
    "tjuvaktiga": "tjuvaktig",
    "tjuvaktigare": "tjuvaktig",
    "tjuvaktigares": "tjuvaktig",
    "tjuvaktigas": "tjuvaktig",
    "tjuvaktigast": "tjuvaktig",
    "tjuvaktigaste": "tjuvaktig",
    "tjuvaktigastes": "tjuvaktig",
    "tjuvaktigasts": "tjuvaktig",
    "tjuvaktige": "tjuvaktig",
    "tjuvaktiges": "tjuvaktig",
    "tjuvaktigheten": "tjuvaktighet",
    "tjuvaktighetens": "tjuvaktighet",
    "tjuvaktighets": "tjuvaktighet",
    "tjuvaktigs": "tjuvaktig",
    "tjuvaktigt": "tjuvaktig",
    "tjuvaktigts": "tjuvaktig",
    "tjuvalarmen": "tjuvalarm",
    "tjuvalarmens": "tjuvalarm",
    "tjuvalarmet": "tjuvalarm",
    "tjuvalarmets": "tjuvalarm",
    "tjuvalarms": "tjuvalarm",
    "tjuvande": "tjuva",
    "tjuvanden": "tjuvande",
    "tjuvandena": "tjuvande",
    "tjuvandenas": "tjuvande",
    "tjuvandens": "tjuvande",
    "tjuvandes": "tjuvande",
    "tjuvandet": "tjuvande",
    "tjuvandets": "tjuvande",
    "tjuvar": "tjuva",
    "tjuvarna": "tjuv",
    "tjuvarnas": "tjuv",
    "tjuvars": "tjuv",
    "tjuvas": "tjuva",
    "tjuvat": "tjuva",
    "tjuvats": "tjuva",
    "tjuvbagg": "tjuvbagge",
    "tjuvbaggar": "tjuvbagge",
    "tjuvbaggarna": "tjuvbagge",
    "tjuvbaggarnas": "tjuvbagge",
    "tjuvbaggars": "tjuvbagge",
    "tjuvbaggen": "tjuvbagge",
    "tjuvbaggens": "tjuvbagge",
    "tjuvbagges": "tjuvbagge",
    "tjuvbaggs": "tjuvbagge",
    "tjuven": "tjuv",
    "tjuvens": "tjuv",
    "tjuverier": "tjuveri",
    "tjuverierna": "tjuveri",
    "tjuveriernas": "tjuveri",
    "tjuveriers": "tjuveri",
    "tjuveriet": "tjuveri",
    "tjuveriets": "tjuveri",
    "tjuveris": "tjuveri",
    "tjuverit": "tjuveri",
    "tjuverits": "tjuveri",
    "tjuvfiskes": "tjuvfiske",
    "tjuvfisket": "tjuvfiske",
    "tjuvfiskets": "tjuvfiske",
    "tjuvgodset": "tjuvgods",
    "tjuvgodsets": "tjuvgods",
    "tjuvgöm": "tjuvgömma",
    "tjuvgömman": "tjuvgömma",
    "tjuvgömmans": "tjuvgömma",
    "tjuvgömmar": "tjuvgömmare",
    "tjuvgömmaren": "tjuvgömmare",
    "tjuvgömmarens": "tjuvgömmare",
    "tjuvgömmares": "tjuvgömmare",
    "tjuvgömmarna": "tjuvgömmare",
    "tjuvgömmarnas": "tjuvgömmare",
    "tjuvgömmas": "tjuvgömma",
    "tjuvgömme": "tjuvgömma",
    "tjuvgömmor": "tjuvgömma",
    "tjuvgömmorna": "tjuvgömma",
    "tjuvgömmornas": "tjuvgömma",
    "tjuvgömmors": "tjuvgömma",
    "tjuvgöms": "tjuvgömma",
    "tjuvhåll": "tjuvhålla",
    "tjuvhållande": "tjuvhålla",
    "tjuvhållanden": "tjuvhållande",
    "tjuvhållandena": "tjuvhållande",
    "tjuvhållandenas": "tjuvhållande",
    "tjuvhållandens": "tjuvhållande",
    "tjuvhållandes": "tjuvhållande",
    "tjuvhållandet": "tjuvhållande",
    "tjuvhållandets": "tjuvhållande",
    "tjuvhållas": "tjuvhålla",
    "tjuvhålle": "tjuvhålla",
    "tjuvhållen": "tjuvhålla",
    "tjuvhållens": "tjuvhålla",
    "tjuvhåller": "tjuvhålla",
    "tjuvhålles": "tjuvhålla",
    "tjuvhållet": "tjuvhålla",
    "tjuvhållets": "tjuvhålla",
    "tjuvhållit": "tjuvhålla",
    "tjuvhållits": "tjuvhålla",
    "tjuvhållna": "tjuvhålla",
    "tjuvhållnas": "tjuvhålla",
    "tjuvhållne": "tjuvhålla",
    "tjuvhållnes": "tjuvhålla",
    "tjuvhålls": "tjuvhålla",
    "tjuvhöll": "tjuvhålla",
    "tjuvhölle": "tjuvhålla",
    "tjuvhölles": "tjuvhålla",
    "tjuvhölls": "tjuvhålla",
    "tjuvknepen": "tjuvknep",
    "tjuvknepens": "tjuvknep",
    "tjuvknepet": "tjuvknep",
    "tjuvknepets": "tjuvknep",
    "tjuvkneps": "tjuvknep",
    "tjuvkopplad": "tjuvkoppla",
    "tjuvkopplade": "tjuvkoppla",
    "tjuvkopplades": "tjuvkoppla",
    "tjuvkopplads": "tjuvkoppla",
    "tjuvkopplande": "tjuvkoppla",
    "tjuvkopplanden": "tjuvkopplande",
    "tjuvkopplandena": "tjuvkopplande",
    "tjuvkopplandenas": "tjuvkopplande",
    "tjuvkopplandens": "tjuvkopplande",
    "tjuvkopplandes": "tjuvkopplande",
    "tjuvkopplandet": "tjuvkopplande",
    "tjuvkopplandets": "tjuvkopplande",
    "tjuvkopplar": "tjuvkoppla",
    "tjuvkopplas": "tjuvkoppla",
    "tjuvkopplat": "tjuvkoppla",
    "tjuvkopplats": "tjuvkoppla",
    "tjuvlarmen": "tjuvlarm",
    "tjuvlarmens": "tjuvlarm",
    "tjuvlarmet": "tjuvlarm",
    "tjuvlarmets": "tjuvlarm",
    "tjuvlarms": "tjuvlarm",
    "tjuvlyssnad": "tjuvlyssna",
    "tjuvlyssnade": "tjuvlyssna",
    "tjuvlyssnades": "tjuvlyssna",
    "tjuvlyssnads": "tjuvlyssna",
    "tjuvlyssnande": "tjuvlyssna",
    "tjuvlyssnanden": "tjuvlyssnande",
    "tjuvlyssnandena": "tjuvlyssnande",
    "tjuvlyssnandenas": "tjuvlyssnande",
    "tjuvlyssnandens": "tjuvlyssnande",
    "tjuvlyssnandes": "tjuvlyssnande",
    "tjuvlyssnandet": "tjuvlyssnande",
    "tjuvlyssnandets": "tjuvlyssnande",
    "tjuvlyssnar": "tjuvlyssna",
    "tjuvlyssnas": "tjuvlyssna",
    "tjuvlyssnat": "tjuvlyssna",
    "tjuvlyssnats": "tjuvlyssna",
    "tjuvmjölk": "tjuvmjölka",
    "tjuvmjölkad": "tjuvmjölka",
    "tjuvmjölkade": "tjuvmjölka",
    "tjuvmjölkades": "tjuvmjölka",
    "tjuvmjölkads": "tjuvmjölka",
    "tjuvmjölkande": "tjuvmjölka",
    "tjuvmjölkanden": "tjuvmjölkande",
    "tjuvmjölkandena": "tjuvmjölkande",
    "tjuvmjölkandenas": "tjuvmjölkande",
    "tjuvmjölkandens": "tjuvmjölkande",
    "tjuvmjölkandes": "tjuvmjölkande",
    "tjuvmjölkandet": "tjuvmjölkande",
    "tjuvmjölkandets": "tjuvmjölkande",
    "tjuvmjölkar": "tjuvmjölka",
    "tjuvmjölkas": "tjuvmjölka",
    "tjuvmjölkat": "tjuvmjölka",
    "tjuvmjölkats": "tjuvmjölka",
    "tjuvnaden": "tjuvnad",
    "tjuvnadens": "tjuvnad",
    "tjuvnader": "tjuvnad",
    "tjuvnaderna": "tjuvnad",
    "tjuvnadernas": "tjuvnad",
    "tjuvnaders": "tjuvnad",
    "tjuvnads": "tjuvnad",
    "tjuvnypen": "tjuvnyp",
    "tjuvnypens": "tjuvnyp",
    "tjuvnypet": "tjuvnyp",
    "tjuvnypets": "tjuvnyp",
    "tjuvnyps": "tjuvnyp",
    "tjuvpojk": "tjuvpojke",
    "tjuvpojkar": "tjuvpojke",
    "tjuvpojkarna": "tjuvpojke",
    "tjuvpojkarnas": "tjuvpojke",
    "tjuvpojkars": "tjuvpojke",
    "tjuvpojken": "tjuvpojke",
    "tjuvpojkens": "tjuvpojke",
    "tjuvpojkes": "tjuvpojke",
    "tjuvpojks": "tjuvpojke",
    "tjuvpojksglimtar": "tjuvpojksglimt",
    "tjuvpojksglimtarna": "tjuvpojksglimt",
    "tjuvpojksglimtarnas": "tjuvpojksglimt",
    "tjuvpojksglimtars": "tjuvpojksglimt",
    "tjuvpojksglimten": "tjuvpojksglimt",
    "tjuvpojksglimtens": "tjuvpojksglimt",
    "tjuvpojksglimts": "tjuvpojksglimt",
    "tjuvs": "tjuv",
    "tjuvsamhällen": "tjuvsamhälle",
    "tjuvsamhällena": "tjuvsamhälle",
    "tjuvsamhällenas": "tjuvsamhälle",
    "tjuvsamhällens": "tjuvsamhälle",
    "tjuvsamhälles": "tjuvsamhälle",
    "tjuvsamhället": "tjuvsamhälle",
    "tjuvsamhällets": "tjuvsamhälle",
    "tjuvsamhälls": "tjuvsamhälle",
    "tjuvsen": "tjuvsena",
    "tjuvsenan": "tjuvsena",
    "tjuvsenans": "tjuvsena",
    "tjuvsenas": "tjuvsena",
    "tjuvsene": "tjuvsena",
    "tjuvsenor": "tjuvsena",
    "tjuvsenorna": "tjuvsena",
    "tjuvsenornas": "tjuvsena",
    "tjuvsenors": "tjuvsena",
    "tjuvsens": "tjuvsena",
    "tjuvskyttar": "tjuvskytt",
    "tjuvskyttarna": "tjuvskytt",
    "tjuvskyttarnas": "tjuvskytt",
    "tjuvskyttars": "tjuvskytt",
    "tjuvskytten": "tjuvskytt",
    "tjuvskyttens": "tjuvskytt",
    "tjuvskyttes": "tjuvskytte",
    "tjuvskyttet": "tjuvskytte",
    "tjuvskyttets": "tjuvskytte",
    "tjuvskytts": "tjuvskytt",
    "tjuvspråket": "tjuvspråk",
    "tjuvspråkets": "tjuvspråk",
    "tjuvspråks": "tjuvspråk",
    "tjuvstart": "tjuvstarta",
    "tjuvstartad": "tjuvstarta",
    "tjuvstartade": "tjuvstarta",
    "tjuvstartades": "tjuvstarta",
    "tjuvstartads": "tjuvstarta",
    "tjuvstartande": "tjuvstarta",
    "tjuvstartanden": "tjuvstartande",
    "tjuvstartandena": "tjuvstartande",
    "tjuvstartandenas": "tjuvstartande",
    "tjuvstartandens": "tjuvstartande",
    "tjuvstartandes": "tjuvstartande",
    "tjuvstartandet": "tjuvstartande",
    "tjuvstartandets": "tjuvstartande",
    "tjuvstartar": "tjuvstarta",
    "tjuvstartas": "tjuvstarta",
    "tjuvstartat": "tjuvstarta",
    "tjuvstartats": "tjuvstarta",
    "tjuvstarten": "tjuvstart",
    "tjuvstartens": "tjuvstart",
    "tjuvstarter": "tjuvstart",
    "tjuvstarterna": "tjuvstart",
    "tjuvstarternas": "tjuvstart",
    "tjuvstarters": "tjuvstart",
    "tjuvstarts": "tjuvstart",
    "tjuvstrecken": "tjuvstreck",
    "tjuvstreckens": "tjuvstreck",
    "tjuvstrecket": "tjuvstreck",
    "tjuvstreckets": "tjuvstreck",
    "tjuvstrecks": "tjuvstreck",
    "tjuvstrykern": "tjuvstryker",
    "tjuvstrykerns": "tjuvstryker",
    "tjuvstrykers": "tjuvstryker",
    "tjuvstrykrar": "tjuvstryker",
    "tjuvstrykrarna": "tjuvstryker",
    "tjuvstrykrarnas": "tjuvstryker",
    "tjuvstrykrars": "tjuvstryker",
    "tjuvtitt": "tjuvtitta",
    "tjuvtittad": "tjuvtitta",
    "tjuvtittade": "tjuvtitta",
    "tjuvtittades": "tjuvtitta",
    "tjuvtittads": "tjuvtitta",
    "tjuvtittande": "tjuvtitta",
    "tjuvtittanden": "tjuvtittande",
    "tjuvtittandena": "tjuvtittande",
    "tjuvtittandenas": "tjuvtittande",
    "tjuvtittandens": "tjuvtittande",
    "tjuvtittandes": "tjuvtittande",
    "tjuvtittandet": "tjuvtittande",
    "tjuvtittandets": "tjuvtittande",
    "tjuvtittar": "tjuvtitta",
    "tjuvtittarna": "tjuvtitt",
    "tjuvtittarnas": "tjuvtitt",
    "tjuvtittars": "tjuvtitt",
    "tjuvtittas": "tjuvtitta",
    "tjuvtittat": "tjuvtitta",
    "tjuvtittats": "tjuvtitta",
    "tjuvtitten": "tjuvtitt",
    "tjuvtittens": "tjuvtitt",
    "tjuvtitts": "tjuvtitt",
    "tjuvtjocka": "tjuvtjock",
    "tjuvtjockare": "tjuvtjock",
    "tjuvtjockares": "tjuvtjock",
    "tjuvtjockas": "tjuvtjock",
    "tjuvtjockast": "tjuvtjock",
    "tjuvtjockaste": "tjuvtjock",
    "tjuvtjockastes": "tjuvtjock",
    "tjuvtjockasts": "tjuvtjock",
    "tjuvtjocke": "tjuvtjock",
    "tjuvtjockes": "tjuvtjock",
    "tjuvtjockheten": "tjuvtjockhet",
    "tjuvtjockhetens": "tjuvtjockhet",
    "tjuvtjockhets": "tjuvtjockhet",
    "tjuvtjocks": "tjuvtjock",
    "tjuvtjockt": "tjuvtjock",
    "tjuvtjockts": "tjuvtjock",
    "tjuvtrycken": "tjuvtryck",
    "tjuvtryckens": "tjuvtryck",
    "tjuvtrycket": "tjuvtryck",
    "tjuvtryckets": "tjuvtryck",
    "tjuvtrycks": "tjuvtryck",
    "tjuvträn": "tjuvträna",
    "tjuvtränad": "tjuvträna",
    "tjuvtränade": "tjuvträna",
    "tjuvtränades": "tjuvträna",
    "tjuvtränads": "tjuvträna",
    "tjuvtränande": "tjuvträna",
    "tjuvtränanden": "tjuvtränande",
    "tjuvtränandena": "tjuvtränande",
    "tjuvtränandenas": "tjuvtränande",
    "tjuvtränandens": "tjuvtränande",
    "tjuvtränandes": "tjuvtränande",
    "tjuvtränandet": "tjuvtränande",
    "tjuvtränandets": "tjuvtränande",
    "tjuvtränar": "tjuvträna",
    "tjuvtränas": "tjuvträna",
    "tjuvtränat": "tjuvträna",
    "tjuvtränats": "tjuvträna",
    "tjyvar": "tjyv",
    "tjyvarna": "tjyv",
    "tjyvarnas": "tjyv",
    "tjyvars": "tjyv",
    "tjyven": "tjyv",
    "tjyvens": "tjyv",
    "tjyvnypen": "tjyvnyp",
    "tjyvnypens": "tjyvnyp",
    "tjyvnypet": "tjyvnyp",
    "tjyvnypets": "tjyvnyp",
    "tjyvnyps": "tjyvnyp",
    "tjyvs": "tjyv",
    "tjyvsamhällen": "tjyvsamhälle",
    "tjyvsamhällena": "tjyvsamhälle",
    "tjyvsamhällenas": "tjyvsamhälle",
    "tjyvsamhällens": "tjyvsamhälle",
    "tjyvsamhälles": "tjyvsamhälle",
    "tjyvsamhället": "tjyvsamhälle",
    "tjyvsamhällets": "tjyvsamhälle",
    "tjyvsamhälls": "tjyvsamhälle",
    "tjyvtjocka": "tjyvtjock",
    "tjyvtjockare": "tjyvtjock",
    "tjyvtjockares": "tjyvtjock",
    "tjyvtjockas": "tjyvtjock",
    "tjyvtjockast": "tjyvtjock",
    "tjyvtjockaste": "tjyvtjock",
    "tjyvtjockastes": "tjyvtjock",
    "tjyvtjockasts": "tjyvtjock",
    "tjyvtjocke": "tjyvtjock",
    "tjyvtjockes": "tjyvtjock",
    "tjyvtjockheten": "tjyvtjockhet",
    "tjyvtjockhetens": "tjyvtjockhet",
    "tjyvtjockhets": "tjyvtjockhet",
    "tjyvtjocks": "tjyvtjock",
    "tjyvtjockt": "tjyvtjock",
    "tjyvtjockts": "tjyvtjock",
    "tjädern": "tjäder",
    "tjäderns": "tjäder",
    "tjäders": "tjäder",
    "tjäderspelet": "tjäderspel",
    "tjäderspelets": "tjäderspel",
    "tjäderspels": "tjäderspel",
    "tjädertuppar": "tjädertupp",
    "tjädertupparna": "tjädertupp",
    "tjädertupparnas": "tjädertupp",
    "tjädertuppars": "tjädertupp",
    "tjädertuppen": "tjädertupp",
    "tjädertuppens": "tjädertupp",
    "tjädertupps": "tjädertupp",
    "tjädrar": "tjäder",
    "tjädrarna": "tjäder",
    "tjädrarnas": "tjäder",
    "tjädrars": "tjäder",
    "tjäl": "tjäla",
    "tjälad": "tjäla",
    "tjälade": "tjäla",
    "tjälades": "tjäla",
    "tjälads": "tjäla",
    "tjälande": "tjäla",
    "tjälanden": "tjälande",
    "tjälandena": "tjälande",
    "tjälandenas": "tjälande",
    "tjälandens": "tjälande",
    "tjälandes": "tjälande",
    "tjälandet": "tjälande",
    "tjälandets": "tjälande",
    "tjälar": "tjäla",
    "tjälas": "tjäla",
    "tjälat": "tjäla",
    "tjälats": "tjäla",
    "tjälen": "tjäle",
    "tjälens": "tjäle",
    "tjäles": "tjäle",
    "tjälfrusens": "tjälfrusen",
    "tjälfruset": "tjälfrusen",
    "tjälfrusets": "tjälfrusen",
    "tjälfrusna": "tjälfrusen",
    "tjälfrusnare": "tjälfrusen",
    "tjälfrusnares": "tjälfrusen",
    "tjälfrusnas": "tjälfrusen",
    "tjälfrusnast": "tjälfrusen",
    "tjälfrusnaste": "tjälfrusen",
    "tjälfrusnastes": "tjälfrusen",
    "tjälfrusnasts": "tjälfrusen",
    "tjälfrusne": "tjälfrusen",
    "tjälfrusnes": "tjälfrusen",
    "tjälknölar": "tjälknöl",
    "tjälknölarna": "tjälknöl",
    "tjälknölarnas": "tjälknöl",
    "tjälknölars": "tjälknöl",
    "tjälknölen": "tjälknöl",
    "tjälknölens": "tjälknöl",
    "tjälknöls": "tjälknöl",
    "tjällen": "tjäll",
    "tjällens": "tjäll",
    "tjället": "tjäll",
    "tjällets": "tjäll",
    "tjällossningar": "tjällossning",
    "tjällossningarna": "tjällossning",
    "tjällossningarnas": "tjällossning",
    "tjällossningars": "tjällossning",
    "tjällossningen": "tjällossning",
    "tjällossningens": "tjällossning",
    "tjällossnings": "tjällossning",
    "tjälls": "tjäll",
    "tjälskotten": "tjälskott",
    "tjälskottens": "tjälskott",
    "tjälskottet": "tjälskott",
    "tjälskottets": "tjälskott",
    "tjälskotts": "tjälskott",
    "tjän": "tjäna",
    "tjänad": "tjäna",
    "tjänade": "tjäna",
    "tjänades": "tjäna",
    "tjänads": "tjäna",
    "tjänande": "tjäna",
    "tjänanden": "tjänande",
    "tjänandena": "tjänande",
    "tjänandenas": "tjänande",
    "tjänandens": "tjänande",
    "tjänandes": "tjänande",
    "tjänandet": "tjänande",
    "tjänandets": "tjänande",
    "tjänar": "tjänare",
    "tjänaren": "tjänare",
    "tjänarens": "tjänare",
    "tjänares": "tjänare",
    "tjänarinnan": "tjänarinna",
    "tjänarinnans": "tjänarinna",
    "tjänarinnas": "tjänarinna",
    "tjänarinne": "tjänarinna",
    "tjänarinnor": "tjänarinna",
    "tjänarinnorna": "tjänarinna",
    "tjänarinnornas": "tjänarinna",
    "tjänarinnors": "tjänarinna",
    "tjänarna": "tjänare",
    "tjänarnas": "tjänare",
    "tjänas": "tjäna",
    "tjänat": "tjäna",
    "tjänats": "tjäna",
    "tjänliga": "tjänlig",
    "tjänligare": "tjänlig",
    "tjänligares": "tjänlig",
    "tjänligas": "tjänlig",
    "tjänligast": "tjänlig",
    "tjänligaste": "tjänlig",
    "tjänligastes": "tjänlig",
    "tjänligasts": "tjänlig",
    "tjänlige": "tjänlig",
    "tjänliges": "tjänlig",
    "tjänligheten": "tjänlighet",
    "tjänlighetens": "tjänlighet",
    "tjänlighets": "tjänlighet",
    "tjänligs": "tjänlig",
    "tjänligt": "tjänlig",
    "tjänligts": "tjänlig",
    "tjänstaktiga": "tjänstaktig",
    "tjänstaktigare": "tjänstaktig",
    "tjänstaktigares": "tjänstaktig",
    "tjänstaktigas": "tjänstaktig",
    "tjänstaktigast": "tjänstaktig",
    "tjänstaktigaste": "tjänstaktig",
    "tjänstaktigastes": "tjänstaktig",
    "tjänstaktigasts": "tjänstaktig",
    "tjänstaktige": "tjänstaktig",
    "tjänstaktiges": "tjänstaktig",
    "tjänstaktigs": "tjänstaktig",
    "tjänstaktigt": "tjänstaktig",
    "tjänstaktigts": "tjänstaktig",
    "tjänstbara": "tjänstbar",
    "tjänstbarare": "tjänstbar",
    "tjänstbarares": "tjänstbar",
    "tjänstbaras": "tjänstbar",
    "tjänstbarast": "tjänstbar",
    "tjänstbaraste": "tjänstbar",
    "tjänstbarastes": "tjänstbar",
    "tjänstbarasts": "tjänstbar",
    "tjänstbare": "tjänstbar",
    "tjänstbares": "tjänstbar",
    "tjänstbarheten": "tjänstbarhet",
    "tjänstbarhetens": "tjänstbarhet",
    "tjänstbarhets": "tjänstbarhet",
    "tjänstbars": "tjänstbar",
    "tjänstbart": "tjänstbar",
    "tjänstbarts": "tjänstbar",
    "tjänste": "tjänst",
    "tjänsteandar": "tjänsteande",
    "tjänsteandarna": "tjänsteande",
    "tjänsteandarnas": "tjänsteande",
    "tjänsteandars": "tjänsteande",
    "tjänsteanden": "tjänsteande",
    "tjänsteandens": "tjänsteande",
    "tjänsteandes": "tjänsteande",
    "tjänsteavtalen": "tjänsteavtal",
    "tjänsteavtalens": "tjänsteavtal",
    "tjänsteavtalet": "tjänsteavtal",
    "tjänsteavtalets": "tjänsteavtal",
    "tjänsteavtals": "tjänsteavtal",
    "tjänstebilar": "tjänstebil",
    "tjänstebilarna": "tjänstebil",
    "tjänstebilarnas": "tjänstebil",
    "tjänstebilars": "tjänstebil",
    "tjänstebilen": "tjänstebil",
    "tjänstebilens": "tjänstebil",
    "tjänstebils": "tjänstebil",
    "tjänstebostaden": "tjänstebostad",
    "tjänstebostadens": "tjänstebostad",
    "tjänstebostads": "tjänstebostad",
    "tjänstebostan": "tjänstebostad",
    "tjänstebostans": "tjänstebostad",
    "tjänstebostäder": "tjänstebostad",
    "tjänstebostäderna": "tjänstebostad",
    "tjänstebostädernas": "tjänstebostad",
    "tjänstebostäders": "tjänstebostad",
    "tjänstebreven": "tjänstebrev",
    "tjänstebrevens": "tjänstebrev",
    "tjänstebrevet": "tjänstebrev",
    "tjänstebrevets": "tjänstebrev",
    "tjänstebrevs": "tjänstebrev",
    "tjänstebrevsrätten": "tjänstebrevsrätt",
    "tjänstebrevsrättens": "tjänstebrevsrätt",
    "tjänstebrevsrätter": "tjänstebrevsrätt",
    "tjänstebrevsrätterna": "tjänstebrevsrätt",
    "tjänstebrevsrätternas": "tjänstebrevsrätt",
    "tjänstebrevsrätters": "tjänstebrevsrätt",
    "tjänstebrevsrätts": "tjänstebrevsrätt",
    "tjänstefelen": "tjänstefel",
    "tjänstefelens": "tjänstefel",
    "tjänstefelet": "tjänstefel",
    "tjänstefelets": "tjänstefel",
    "tjänstefels": "tjänstefel",
    "tjänsteflick": "tjänsteflicka",
    "tjänsteflickan": "tjänsteflicka",
    "tjänsteflickans": "tjänsteflicka",
    "tjänsteflickas": "tjänsteflicka",
    "tjänsteflicke": "tjänsteflicka",
    "tjänsteflickor": "tjänsteflicka",
    "tjänsteflickorna": "tjänsteflicka",
    "tjänsteflickornas": "tjänsteflicka",
    "tjänsteflickors": "tjänsteflicka",
    "tjänsteflicks": "tjänsteflicka",
    "tjänstefolket": "tjänstefolk",
    "tjänstefolkets": "tjänstefolk",
    "tjänstefolks": "tjänstefolk",
    "tjänsteförrättar": "tjänsteförrättare",
    "tjänsteförrättaren": "tjänsteförrättare",
    "tjänsteförrättarens": "tjänsteförrättare",
    "tjänsteförrättares": "tjänsteförrättare",
    "tjänsteförrättarna": "tjänsteförrättare",
    "tjänsteförrättarnas": "tjänsteförrättare",
    "tjänsteförrättningar": "tjänsteförrättning",
    "tjänsteförrättningarna": "tjänsteförrättning",
    "tjänsteförrättningarnas": "tjänsteförrättning",
    "tjänsteförrättningars": "tjänsteförrättning",
    "tjänsteförrättningen": "tjänsteförrättning",
    "tjänsteförrättningens": "tjänsteförrättning",
    "tjänsteförrättnings": "tjänsteförrättning",
    "tjänsteförseelsen": "tjänsteförseelse",
    "tjänsteförseelsens": "tjänsteförseelse",
    "tjänsteförseelser": "tjänsteförseelse",
    "tjänsteförseelserna": "tjänsteförseelse",
    "tjänsteförseelsernas": "tjänsteförseelse",
    "tjänsteförseelsers": "tjänsteförseelse",
    "tjänsteförseelses": "tjänsteförseelse",
    "tjänsteförsändelsen": "tjänsteförsändelse",
    "tjänsteförsändelsens": "tjänsteförsändelse",
    "tjänsteförsändelser": "tjänsteförsändelse",
    "tjänsteförsändelserna": "tjänsteförsändelse",
    "tjänsteförsändelsernas": "tjänsteförsändelse",
    "tjänsteförsändelsers": "tjänsteförsändelse",
    "tjänsteförsändelses": "tjänsteförsändelse",
    "tjänstegraden": "tjänstegrad",
    "tjänstegradens": "tjänstegrad",
    "tjänstegrader": "tjänstegrad",
    "tjänstegraderna": "tjänstegrad",
    "tjänstegradernas": "tjänstegrad",
    "tjänstegraders": "tjänstegrad",
    "tjänstegrads": "tjänstegrad",
    "tjänstekvinnan": "tjänstekvinna",
    "tjänstekvinnans": "tjänstekvinna",
    "tjänstekvinnas": "tjänstekvinna",
    "tjänstekvinne": "tjänstekvinna",
    "tjänstekvinno": "tjänstekvinna",
    "tjänstekvinnor": "tjänstekvinna",
    "tjänstekvinnorna": "tjänstekvinna",
    "tjänstekvinnornas": "tjänstekvinna",
    "tjänstekvinnors": "tjänstekvinna",
    "tjänstemannamässiga": "tjänstemannamässig",
    "tjänstemannamässigare": "tjänstemannamässig",
    "tjänstemannamässigares": "tjänstemannamässig",
    "tjänstemannamässigas": "tjänstemannamässig",
    "tjänstemannamässigast": "tjänstemannamässig",
    "tjänstemannamässigaste": "tjänstemannamässig",
    "tjänstemannamässigastes": "tjänstemannamässig",
    "tjänstemannamässigasts": "tjänstemannamässig",
    "tjänstemannamässige": "tjänstemannamässig",
    "tjänstemannamässiges": "tjänstemannamässig",
    "tjänstemannamässigs": "tjänstemannamässig",
    "tjänstemannamässigt": "tjänstemannamässig",
    "tjänstemannamässigts": "tjänstemannamässig",
    "tjänstemannaorganisationen": "tjänstemannaorganisation",
    "tjänstemannaorganisationens": "tjänstemannaorganisation",
    "tjänstemannaorganisationer": "tjänstemannaorganisation",
    "tjänstemannaorganisationerna": "tjänstemannaorganisation",
    "tjänstemannaorganisationernas": "tjänstemannaorganisation",
    "tjänstemannaorganisationers": "tjänstemannaorganisation",
    "tjänstemannaorganisations": "tjänstemannaorganisation",
    "tjänstemannen": "tjänsteman",
    "tjänstemannens": "tjänsteman",
    "tjänstemans": "tjänsteman",
    "tjänstemän": "tjänsteman",
    "tjänstemännen": "tjänsteman",
    "tjänstemännens": "tjänsteman",
    "tjänstemäns": "tjänsteman",
    "tjänsten": "tjänst",
    "tjänstens": "tjänst",
    "tjänstepensionen": "tjänstepension",
    "tjänstepensionens": "tjänstepension",
    "tjänstepensioner": "tjänstepension",
    "tjänstepensionerna": "tjänstepension",
    "tjänstepensionernas": "tjänstepension",
    "tjänstepensioners": "tjänstepension",
    "tjänstepensions": "tjänstepension",
    "tjänsteplikten": "tjänsteplikt",
    "tjänstepliktens": "tjänsteplikt",
    "tjänsteplikts": "tjänsteplikt",
    "tjänster": "tjänst",
    "tjänsteresan": "tjänsteresa",
    "tjänsteresans": "tjänsteresa",
    "tjänsteresas": "tjänsteresa",
    "tjänsterese": "tjänsteresa",
    "tjänsteresor": "tjänsteresa",
    "tjänsteresorna": "tjänsteresa",
    "tjänsteresornas": "tjänsteresa",
    "tjänsteresors": "tjänsteresa",
    "tjänsterna": "tjänst",
    "tjänsternas": "tjänst",
    "tjänsters": "tjänst",
    "tjänsterummen": "tjänsterum",
    "tjänsterummens": "tjänsterum",
    "tjänsterummet": "tjänsterum",
    "tjänsterummets": "tjänsterum",
    "tjänsterums": "tjänsterum",
    "tjänsteställningar": "tjänsteställning",
    "tjänsteställningarna": "tjänsteställning",
    "tjänsteställningarnas": "tjänsteställning",
    "tjänsteställningars": "tjänsteställning",
    "tjänsteställningen": "tjänsteställning",
    "tjänsteställningens": "tjänsteställning",
    "tjänsteställnings": "tjänsteställning",
    "tjänstetiden": "tjänstetid",
    "tjänstetidens": "tjänstetid",
    "tjänstetider": "tjänstetid",
    "tjänstetiderna": "tjänstetid",
    "tjänstetidernas": "tjänstetid",
    "tjänstetiders": "tjänstetid",
    "tjänstetids": "tjänstetid",
    "tjänstevapens": "tjänstevapen",
    "tjänstevapnen": "tjänstevapen",
    "tjänstevapnens": "tjänstevapen",
    "tjänstevapnet": "tjänstevapen",
    "tjänstevapnets": "tjänstevapen",
    "tjänstevikten": "tjänstevikt",
    "tjänsteviktens": "tjänstevikt",
    "tjänstevikts": "tjänstevikt",
    "tjänsteärenden": "tjänsteärende",
    "tjänsteärendena": "tjänsteärende",
    "tjänsteärendenas": "tjänsteärende",
    "tjänsteärendens": "tjänsteärende",
    "tjänsteärendes": "tjänsteärende",
    "tjänsteärendet": "tjänsteärende",
    "tjänsteärendets": "tjänsteärende",
    "tjänsteåren": "tjänsteår",
    "tjänsteårens": "tjänsteår",
    "tjänsteåret": "tjänsteår",
    "tjänsteårets": "tjänsteår",
    "tjänsteårs": "tjänsteår",
    "tjänstgjord": "tjänstgöra",
    "tjänstgjorda": "tjänstgöra",
    "tjänstgjordas": "tjänstgöra",
    "tjänstgjorde": "tjänstgöra",
    "tjänstgjordes": "tjänstgöra",
    "tjänstgjords": "tjänstgöra",
    "tjänstgjort": "tjänstgöra",
    "tjänstgjorts": "tjänstgöra",
    "tjänstgör": "tjänstgöra",
    "tjänstgörande": "tjänstgöra",
    "tjänstgöranden": "tjänstgörande",
    "tjänstgörandena": "tjänstgörande",
    "tjänstgörandenas": "tjänstgörande",
    "tjänstgörandens": "tjänstgörande",
    "tjänstgörandes": "tjänstgörande",
    "tjänstgörandet": "tjänstgörande",
    "tjänstgörandets": "tjänstgörande",
    "tjänstgöras": "tjänstgöra",
    "tjänstgöres": "tjänstgöra",
    "tjänstgöringar": "tjänstgöring",
    "tjänstgöringarna": "tjänstgöring",
    "tjänstgöringarnas": "tjänstgöring",
    "tjänstgöringars": "tjänstgöring",
    "tjänstgöringen": "tjänstgöring",
    "tjänstgöringens": "tjänstgöring",
    "tjänstgörings": "tjänstgöring",
    "tjänstgöringsnummerna": "tjänstgöringsnummer",
    "tjänstgöringsnummernas": "tjänstgöringsnummer",
    "tjänstgöringsnummers": "tjänstgöringsnummer",
    "tjänstgöringsnumren": "tjänstgöringsnummer",
    "tjänstgöringsnumrens": "tjänstgöringsnummer",
    "tjänstgöringsnumret": "tjänstgöringsnummer",
    "tjänstgöringsnumrets": "tjänstgöringsnummer",
    "tjänstgörs": "tjänstgöra",
    "tjänstlediga": "tjänstledig",
    "tjänstledigare": "tjänstledig",
    "tjänstledigares": "tjänstledig",
    "tjänstledigas": "tjänstledig",
    "tjänstledigast": "tjänstledig",
    "tjänstledigaste": "tjänstledig",
    "tjänstledigastes": "tjänstledig",
    "tjänstledigasts": "tjänstledig",
    "tjänstledige": "tjänstledig",
    "tjänstlediges": "tjänstledig",
    "tjänstledigheten": "tjänstledighet",
    "tjänstledighetens": "tjänstledighet",
    "tjänstledigheter": "tjänstledighet",
    "tjänstledigheterna": "tjänstledighet",
    "tjänstledigheternas": "tjänstledighet",
    "tjänstledigheters": "tjänstledighet",
    "tjänstledighets": "tjänstledighet",
    "tjänstledigs": "tjänstledig",
    "tjänstledigt": "tjänstledig",
    "tjänstledigts": "tjänstledig",
    "tjänsts": "tjänst",
    "tjänstvilliga": "tjänstvillig",
    "tjänstvilligare": "tjänstvillig",
    "tjänstvilligares": "tjänstvillig",
    "tjänstvilligas": "tjänstvillig",
    "tjänstvilligast": "tjänstvillig",
    "tjänstvilligaste": "tjänstvillig",
    "tjänstvilligastes": "tjänstvillig",
    "tjänstvilligasts": "tjänstvillig",
    "tjänstvillige": "tjänstvillig",
    "tjänstvilliges": "tjänstvillig",
    "tjänstvilligheten": "tjänstvillighet",
    "tjänstvillighetens": "tjänstvillighet",
    "tjänstvillighets": "tjänstvillighet",
    "tjänstvilligs": "tjänstvillig",
    "tjänstvilligt": "tjänstvillig",
    "tjänstvilligts": "tjänstvillig",
    "tjär": "tjära",
    "tjärad": "tjära",
    "tjärade": "tjära",
    "tjärades": "tjära",
    "tjärads": "tjära",
    "tjäran": "tjära",
    "tjärande": "tjära",
    "tjäranden": "tjärande",
    "tjärandena": "tjärande",
    "tjärandenas": "tjärande",
    "tjärandens": "tjärande",
    "tjärandes": "tjärande",
    "tjärandet": "tjärande",
    "tjärandets": "tjärande",
    "tjärans": "tjära",
    "tjärar": "tjära",
    "tjäras": "tjära",
    "tjärat": "tjära",
    "tjärats": "tjära",
    "tjärblomsterna": "tjärblomster",
    "tjärblomsternas": "tjärblomster",
    "tjärblomsters": "tjärblomster",
    "tjärblomstren": "tjärblomster",
    "tjärblomstrens": "tjärblomster",
    "tjärblomstret": "tjärblomster",
    "tjärblomstrets": "tjärblomster",
    "tjärblossen": "tjärbloss",
    "tjärblossens": "tjärbloss",
    "tjärblosset": "tjärbloss",
    "tjärblossets": "tjärbloss",
    "tjärdalar": "tjärdal",
    "tjärdalarna": "tjärdal",
    "tjärdalarnas": "tjärdal",
    "tjärdalars": "tjärdal",
    "tjärdalen": "tjärdal",
    "tjärdalens": "tjärdal",
    "tjärdals": "tjärdal",
    "tjärdrevet": "tjärdrev",
    "tjärdrevets": "tjärdrev",
    "tjärdrevs": "tjärdrev",
    "tjäre": "tjära",
    "tjärframställningar": "tjärframställning",
    "tjärframställningarna": "tjärframställning",
    "tjärframställningarnas": "tjärframställning",
    "tjärframställningars": "tjärframställning",
    "tjärframställningen": "tjärframställning",
    "tjärframställningens": "tjärframställning",
    "tjärframställnings": "tjärframställning",
    "tjärimpregneringen": "tjärimpregnering",
    "tjärimpregneringens": "tjärimpregnering",
    "tjärimpregnerings": "tjärimpregnering",
    "tjärnar": "tjärn",
    "tjärnarna": "tjärn",
    "tjärnarnas": "tjärn",
    "tjärnars": "tjärn",
    "tjärnen": "tjärn",
    "tjärnens": "tjärn",
    "tjärnet": "tjärn",
    "tjärnets": "tjärn",
    "tjärns": "tjärn",
    "tjäror": "tjära",
    "tjärorna": "tjära",
    "tjärornas": "tjära",
    "tjärors": "tjära",
    "tjärpappen": "tjärpapp",
    "tjärpappens": "tjärpapp",
    "tjärpapps": "tjärpapp",
    "tjärs": "tjära",
    "tjärveden": "tjärved",
    "tjärvedens": "tjärved",
    "tjärveds": "tjärved",
    "tjöt": "tjuta",
    "tjöte": "tjuta",
    "tjötes": "tjuta",
    "tjöts": "tjuta",
    "to": "toa",
    "toalettartikeln": "toalettartikel",
    "toalettartikelns": "toalettartikel",
    "toalettartikels": "toalettartikel",
    "toalettartiklar": "toalettartikel",
    "toalettartiklarna": "toalettartikel",
    "toalettartiklarnas": "toalettartikel",
    "toalettartiklars": "toalettartikel",
    "toalettbesöken": "toalettbesök",
    "toalettbesökens": "toalettbesök",
    "toalettbesöket": "toalettbesök",
    "toalettbesökets": "toalettbesök",
    "toalettbesöks": "toalettbesök",
    "toalettborden": "toalettbord",
    "toalettbordens": "toalettbord",
    "toalettbordet": "toalettbord",
    "toalettbordets": "toalettbord",
    "toalettbords": "toalettbord",
    "toaletten": "toalett",
    "toalettens": "toalett",
    "toaletter": "toalett",
    "toaletterna": "toalett",
    "toaletternas": "toalett",
    "toaletters": "toalett",
    "toalettlocken": "toalettlock",
    "toalettlockens": "toalettlock",
    "toalettlocket": "toalettlock",
    "toalettlockets": "toalettlock",
    "toalettlocks": "toalettlock",
    "toalettpapperet": "toalettpapper",
    "toalettpapperets": "toalettpapper",
    "toalettpappers": "toalettpapper",
    "toalettpappret": "toalettpapper",
    "toalettpapprets": "toalettpapper",
    "toalettringar": "toalettring",
    "toalettringarna": "toalettring",
    "toalettringarnas": "toalettring",
    "toalettringars": "toalettring",
    "toalettringen": "toalettring",
    "toalettringens": "toalettring",
    "toalettrings": "toalettring",
    "toaletts": "toalett",
    "toalettsakerna": "toalettsaker",
    "toalettsakernas": "toalettsaker",
    "toalettsakers": "toalettsaker",
    "toalettsaks": "toalettsaker",
    "toalettsitsar": "toalettsits",
    "toalettsitsarna": "toalettsits",
    "toalettsitsarnas": "toalettsits",
    "toalettsitsars": "toalettsits",
    "toalettsitsen": "toalettsits",
    "toalettsitsens": "toalettsits",
    "toalettskåpen": "toalettskåp",
    "toalettskåpens": "toalettskåp",
    "toalettskåpet": "toalettskåp",
    "toalettskåpets": "toalettskåp",
    "toalettskåps": "toalettskåp",
    "toalettstolar": "toalettstol",
    "toalettstolarna": "toalettstol",
    "toalettstolarnas": "toalettstol",
    "toalettstolars": "toalettstol",
    "toalettstolen": "toalettstol",
    "toalettstolens": "toalettstol",
    "toalettstols": "toalettstol",
    "toalettvålar": "toalettvål",
    "toalettvålarna": "toalettvål",
    "toalettvålarnas": "toalettvål",
    "toalettvålars": "toalettvål",
    "toalettvålen": "toalettvål",
    "toalettvålens": "toalettvål",
    "toalettvåls": "toalettvål",
    "toan": "toa",
    "toans": "toa",
    "toapapperet": "toapapper",
    "toapapperets": "toapapper",
    "toapappers": "toapapper",
    "toapappret": "toapapper",
    "toapapprets": "toapapper",
    "toas": "toa",
    "toasten": "toast",
    "toastens": "toast",
    "toastmastern": "toastmaster",
    "toastmasterns": "toastmaster",
    "toastmasters": "toastmaster",
    "toastmastrar": "toastmaster",
    "toastmastrarna": "toastmaster",
    "toastmastrarnas": "toastmaster",
    "toastmastrars": "toastmaster",
    "toasts": "toast",
    "tobaken": "tobak",
    "tobakens": "tobak",
    "tobakisten": "tobakist",
    "tobakistens": "tobakist",
    "tobakister": "tobakist",
    "tobakisterna": "tobakist",
    "tobakisternas": "tobakist",
    "tobakisters": "tobakist",
    "tobakists": "tobakist",
    "tobaks": "tobak",
    "tobaksaffären": "tobaksaffär",
    "tobaksaffärens": "tobaksaffär",
    "tobaksaffärer": "tobaksaffär",
    "tobaksaffärerna": "tobaksaffär",
    "tobaksaffärernas": "tobaksaffär",
    "tobaksaffärers": "tobaksaffär",
    "tobaksaffärs": "tobaksaffär",
    "tobaksbruket": "tobaksbruk",
    "tobaksbrukets": "tobaksbruk",
    "tobaksbruks": "tobaksbruk",
    "tobaksbutiken": "tobaksbutik",
    "tobaksbutikens": "tobaksbutik",
    "tobaksbutiker": "tobaksbutik",
    "tobaksbutikerna": "tobaksbutik",
    "tobaksbutikernas": "tobaksbutik",
    "tobaksbutikers": "tobaksbutik",
    "tobaksbutiks": "tobaksbutik",
    "tobakshandlar": "tobakshandlare",
    "tobakshandlaren": "tobakshandlare",
    "tobakshandlarens": "tobakshandlare",
    "tobakshandlares": "tobakshandlare",
    "tobakshandlarna": "tobakshandlare",
    "tobakshandlarnas": "tobakshandlare",
    "tobakskiosken": "tobakskiosk",
    "tobakskioskens": "tobakskiosk",
    "tobakskiosker": "tobakskiosk",
    "tobakskioskerna": "tobakskiosk",
    "tobakskioskernas": "tobakskiosk",
    "tobakskioskers": "tobakskiosk",
    "tobakskiosks": "tobakskiosk",
    "tobaksmonopolen": "tobaksmonopol",
    "tobaksmonopolens": "tobaksmonopol",
    "tobaksmonopolet": "tobaksmonopol",
    "tobaksmonopolets": "tobaksmonopol",
    "tobaksmonopols": "tobaksmonopol",
    "tobaksodlingar": "tobaksodling",
    "tobaksodlingarna": "tobaksodling",
    "tobaksodlingarnas": "tobaksodling",
    "tobaksodlingars": "tobaksodling",
    "tobaksodlingen": "tobaksodling",
    "tobaksodlingens": "tobaksodling",
    "tobaksodlings": "tobaksodling",
    "tobakspip": "tobakspipa",
    "tobakspipan": "tobakspipa",
    "tobakspipans": "tobakspipa",
    "tobakspipas": "tobakspipa",
    "tobakspipe": "tobakspipa",
    "tobakspipor": "tobakspipa",
    "tobakspiporna": "tobakspipa",
    "tobakspipornas": "tobakspipa",
    "tobakspipors": "tobakspipa",
    "tobakspips": "tobakspipa",
    "tobaksplant": "tobaksplanta",
    "tobaksplantan": "tobaksplanta",
    "tobaksplantans": "tobaksplanta",
    "tobaksplantas": "tobaksplanta",
    "tobaksplante": "tobaksplanta",
    "tobaksplantor": "tobaksplanta",
    "tobaksplantorna": "tobaksplanta",
    "tobaksplantornas": "tobaksplanta",
    "tobaksplantors": "tobaksplanta",
    "tobaksplants": "tobaksplanta",
    "tobaksvar": "tobaksvara",
    "tobaksvaran": "tobaksvara",
    "tobaksvarans": "tobaksvara",
    "tobaksvaras": "tobaksvara",
    "tobaksvaror": "tobaksvara",
    "tobaksvarorna": "tobaksvara",
    "tobaksvarornas": "tobaksvara",
    "tobaksvarors": "tobaksvara",
    "tobaksvaru": "tobaksvara",
    "tobisar": "tobis",
    "tobisarna": "tobis",
    "tobisarnas": "tobis",
    "tobisars": "tobis",
    "tobisen": "tobis",
    "tobisens": "tobis",
    "tobisgrissl": "tobisgrissla",
    "tobisgrisslan": "tobisgrissla",
    "tobisgrisslans": "tobisgrissla",
    "tobisgrisslas": "tobisgrissla",
    "tobisgrissle": "tobisgrissla",
    "tobisgrisslor": "tobisgrissla",
    "tobisgrisslorna": "tobisgrissla",
    "tobisgrisslornas": "tobisgrissla",
    "tobisgrisslors": "tobisgrissla",
    "tobiskungar": "tobiskung",
    "tobiskungarna": "tobiskung",
    "tobiskungarnas": "tobiskung",
    "tobiskungars": "tobiskung",
    "tobiskungen": "tobiskung",
    "tobiskungens": "tobiskung",
    "tobiskungs": "tobiskung",
    "toccat": "toccata",
    "toccatan": "toccata",
    "toccatans": "toccata",
    "toccatas": "toccata",
    "toccate": "toccata",
    "toccator": "toccata",
    "toccatorna": "toccata",
    "toccatornas": "toccata",
    "toccators": "toccata",
    "toccats": "toccata",
    "tock": "tocka",
    "tockad": "tocka",
    "tockade": "tocka",
    "tockades": "tocka",
    "tockads": "tocka",
    "tockande": "tocka",
    "tockanden": "tockande",
    "tockandena": "tockande",
    "tockandenas": "tockande",
    "tockandens": "tockande",
    "tockandes": "tockande",
    "tockandet": "tockande",
    "tockandets": "tockande",
    "tockar": "tocka",
    "tockas": "tocka",
    "tockat": "tocka",
    "tockats": "tocka",
    "tockens": "tocken",
    "tocket": "tocken",
    "tockets": "tocken",
    "tockna": "tocken",
    "tocknare": "tocken",
    "tocknares": "tocken",
    "tocknas": "tocken",
    "tocknast": "tocken",
    "tocknaste": "tocken",
    "tocknastes": "tocken",
    "tocknasts": "tocken",
    "tockne": "tocken",
    "tocknes": "tocken",
    "toddar": "toddy",
    "toddarna": "toddy",
    "toddarnas": "toddy",
    "toddars": "toddy",
    "toddyar": "toddy",
    "toddyarna": "toddy",
    "toddyarnas": "toddy",
    "toddyars": "toddy",
    "toddyn": "toddy",
    "toddyns": "toddy",
    "toddys": "toddy",
    "toe": "toa",
    "toffel": "toffla",
    "toffelblom": "toffelblomma",
    "toffelblomman": "toffelblomma",
    "toffelblommans": "toffelblomma",
    "toffelblommas": "toffelblomma",
    "toffelblomme": "toffelblomma",
    "toffelblommor": "toffelblomma",
    "toffelblommorna": "toffelblomma",
    "toffelblommornas": "toffelblomma",
    "toffelblommors": "toffelblomma",
    "toffelbloms": "toffelblomma",
    "toffeldjuren": "toffeldjur",
    "toffeldjurens": "toffeldjur",
    "toffeldjuret": "toffeldjur",
    "toffeldjurets": "toffeldjur",
    "toffeldjurs": "toffeldjur",
    "toffelhjältar": "toffelhjälte",
    "toffelhjältarna": "toffelhjälte",
    "toffelhjältarnas": "toffelhjälte",
    "toffelhjältars": "toffelhjälte",
    "toffelhjälten": "toffelhjälte",
    "toffelhjältens": "toffelhjälte",
    "toffelhjältes": "toffelhjälte",
    "toffeln": "toffel",
    "toffelns": "toffel",
    "toffels": "toffel",
    "toffla": "toffel",
    "tofflad": "toffla",
    "tofflade": "toffla",
    "tofflades": "toffla",
    "tofflads": "toffla",
    "tofflan": "toffel",
    "tofflande": "toffla",
    "tofflanden": "tofflande",
    "tofflandena": "tofflande",
    "tofflandenas": "tofflande",
    "tofflandens": "tofflande",
    "tofflandes": "tofflande",
    "tofflandet": "tofflande",
    "tofflandets": "tofflande",
    "tofflans": "toffel",
    "tofflar": "toffla",
    "tofflas": "toffla",
    "tofflat": "toffla",
    "tofflats": "toffla",
    "toffle": "toffel",
    "tofflor": "toffel",
    "tofflorna": "toffel",
    "tofflornas": "toffel",
    "tofflors": "toffel",
    "tofsar": "tofs",
    "tofsarna": "tofs",
    "tofsarnas": "tofs",
    "tofsars": "tofs",
    "tofsen": "tofs",
    "tofsens": "tofs",
    "tofsiga": "tofsig",
    "tofsigare": "tofsig",
    "tofsigares": "tofsig",
    "tofsigas": "tofsig",
    "tofsigast": "tofsig",
    "tofsigaste": "tofsig",
    "tofsigastes": "tofsig",
    "tofsigasts": "tofsig",
    "tofsige": "tofsig",
    "tofsiges": "tofsig",
    "tofsigheten": "tofsighet",
    "tofsighetens": "tofsighet",
    "tofsighets": "tofsighet",
    "tofsigs": "tofsig",
    "tofsigt": "tofsig",
    "tofsigts": "tofsig",
    "tofslärk": "tofslärka",
    "tofslärkan": "tofslärka",
    "tofslärkans": "tofslärka",
    "tofslärkas": "tofslärka",
    "tofslärke": "tofslärka",
    "tofslärkor": "tofslärka",
    "tofslärkorna": "tofslärka",
    "tofslärkornas": "tofslärka",
    "tofslärkors": "tofslärka",
    "tofslärks": "tofslärka",
    "tofsmesar": "tofsmes",
    "tofsmesarna": "tofsmes",
    "tofsmesarnas": "tofsmes",
    "tofsmesars": "tofsmes",
    "tofsmesen": "tofsmes",
    "tofsmesens": "tofsmes",
    "tofsskivlingar": "tofsskivling",
    "tofsskivlingarna": "tofsskivling",
    "tofsskivlingarnas": "tofsskivling",
    "tofsskivlingars": "tofsskivling",
    "tofsskivlingen": "tofsskivling",
    "tofsskivlingens": "tofsskivling",
    "tofsskivlings": "tofsskivling",
    "tofsvip": "tofsvipa",
    "tofsvipan": "tofsvipa",
    "tofsvipans": "tofsvipa",
    "tofsvipas": "tofsvipa",
    "tofsvipe": "tofsvipa",
    "tofsvipor": "tofsvipa",
    "tofsviporna": "tofsvipa",
    "tofsvipornas": "tofsvipa",
    "tofsvipors": "tofsvipa",
    "tofsvips": "tofsvipa",
    "tofsöras": "tofsöra",
    "tofsörat": "tofsöra",
    "tofsörats": "tofsöra",
    "tofsöron": "tofsöra",
    "tofsöronen": "tofsöra",
    "tofsöronens": "tofsöra",
    "tofsörons": "tofsöra",
    "toften": "toft",
    "toftens": "toft",
    "tofter": "toft",
    "tofterna": "toft",
    "tofternas": "toft",
    "tofters": "toft",
    "tofts": "toft",
    "toftvägar": "toftvägare",
    "toftvägaren": "toftvägare",
    "toftvägarens": "toftvägare",
    "toftvägares": "toftvägare",
    "toftvägarna": "toftvägare",
    "toftvägarnas": "toftvägare",
    "tofun": "tofu",
    "tofuns": "tofu",
    "tofus": "tofu",
    "tog": "toga",
    "togan": "toga",
    "togans": "toga",
    "togas": "toga",
    "toge": "toga",
    "toges": "ta",
    "togolesen": "togoles",
    "togolesens": "togoles",
    "togoleser": "togoles",
    "togoleserna": "togoles",
    "togolesernas": "togoles",
    "togolesers": "togoles",
    "togolesiska": "togolesisk",
    "togolesiskan": "togolesiska",
    "togolesiskans": "togolesiska",
    "togolesiskare": "togolesisk",
    "togolesiskares": "togolesisk",
    "togolesiskas": "togolesiska",
    "togolesiskast": "togolesisk",
    "togolesiskaste": "togolesisk",
    "togolesiskastes": "togolesisk",
    "togolesiskasts": "togolesisk",
    "togolesiske": "togolesiska",
    "togolesiskes": "togolesisk",
    "togolesiskflaggade": "togolesiskflaggad",
    "togolesiskflaggades": "togolesiskflaggad",
    "togolesiskflaggads": "togolesiskflaggad",
    "togolesiskflaggat": "togolesiskflaggad",
    "togolesiskflaggats": "togolesiskflaggad",
    "togolesiskor": "togolesiska",
    "togolesiskorna": "togolesiska",
    "togolesiskornas": "togolesiska",
    "togolesiskors": "togolesiska",
    "togolesisks": "togolesisk",
    "togolesiskt": "togolesisk",
    "togolesiskts": "togolesisk",
    "togor": "toga",
    "togorna": "toga",
    "togornas": "toga",
    "togors": "toga",
    "togs": "toga",
    "tok": "toka",
    "tokajern": "tokajer",
    "tokajerns": "tokajer",
    "tokajers": "tokajer",
    "tokan": "toka",
    "tokans": "toka",
    "tokar": "toker",
    "tokarna": "toker",
    "tokarnas": "toker",
    "tokars": "toker",
    "tokas": "toka",
    "toke": "toka",
    "token": "tok",
    "tokens": "tok",
    "tokerier": "tokeri",
    "tokerierna": "tokeri",
    "tokeriernas": "tokeri",
    "tokeriers": "tokeri",
    "tokeriet": "tokeri",
    "tokeriets": "tokeri",
    "tokeris": "tokeri",
    "tokerit": "tokeri",
    "tokerits": "tokeri",
    "tokern": "toker",
    "tokerns": "toker",
    "tokers": "toker",
    "tokiga": "tokig",
    "tokigare": "tokig",
    "tokigares": "tokig",
    "tokigas": "tokig",
    "tokigast": "tokig",
    "tokigaste": "tokig",
    "tokigastes": "tokig",
    "tokigasts": "tokig",
    "tokige": "tokig",
    "tokiges": "tokig",
    "tokigheten": "tokighet",
    "tokighetens": "tokighet",
    "tokigheter": "tokighet",
    "tokigheterna": "tokighet",
    "tokigheternas": "tokighet",
    "tokigheters": "tokighet",
    "tokighets": "tokighet",
    "tokigs": "tokig",
    "tokigt": "tokig",
    "tokigts": "tokig",
    "tokor": "toka",
    "tokorna": "toka",
    "tokornas": "toka",
    "tokors": "toka",
    "tokrar": "toker",
    "tokrarna": "toker",
    "tokrarnas": "toker",
    "tokrars": "toker",
    "tokroliga": "tokrolig",
    "tokroligare": "tokrolig",
    "tokroligares": "tokrolig",
    "tokroligas": "tokrolig",
    "tokroligast": "tokrolig",
    "tokroligaste": "tokrolig",
    "tokroligastes": "tokrolig",
    "tokroligasts": "tokrolig",
    "tokrolige": "tokrolig",
    "tokroliges": "tokrolig",
    "tokroligheten": "tokrolighet",
    "tokrolighetens": "tokrolighet",
    "tokroligheter": "tokrolighet",
    "tokroligheterna": "tokrolighet",
    "tokroligheternas": "tokrolighet",
    "tokroligheters": "tokrolighet",
    "tokrolighets": "tokrolighet",
    "tokroligs": "tokrolig",
    "tokroligt": "tokrolig",
    "tokroligts": "tokrolig",
    "toks": "toka",
    "tokstoll": "tokstolle",
    "tokstollar": "tokstolle",
    "tokstollarna": "tokstolle",
    "tokstollarnas": "tokstolle",
    "tokstollars": "tokstolle",
    "tokstollen": "tokstolle",
    "tokstollens": "tokstolle",
    "tokstolles": "tokstolle",
    "tokstolls": "tokstolle",
    "tokvänstern": "tokvänster",
    "tokvänsterns": "tokvänster",
    "tokvänsters": "tokvänster",
    "tolerabels": "tolerabel",
    "tolerabelt": "tolerabel",
    "tolerabelts": "tolerabel",
    "tolerabla": "tolerabel",
    "tolerablare": "tolerabel",
    "tolerablares": "tolerabel",
    "tolerablas": "tolerabel",
    "tolerablast": "tolerabel",
    "tolerablaste": "tolerabel",
    "tolerablastes": "tolerabel",
    "tolerablasts": "tolerabel",
    "tolerable": "tolerabel",
    "tolerables": "tolerabel",
    "toleransen": "tolerans",
    "toleransens": "tolerans",
    "toleranser": "tolerans",
    "toleranserna": "tolerans",
    "toleransernas": "tolerans",
    "toleransers": "tolerans",
    "toleranta": "tolerant",
    "tolerantare": "tolerant",
    "tolerantares": "tolerant",
    "tolerantas": "tolerant",
    "tolerantast": "tolerant",
    "tolerantaste": "tolerant",
    "tolerantastes": "tolerant",
    "tolerantasts": "tolerant",
    "tolerante": "tolerant",
    "tolerantes": "tolerant",
    "tolerants": "tolerant",
    "tolererad": "tolerera",
    "tolererade": "tolerera",
    "tolererades": "tolerera",
    "tolererads": "tolerera",
    "tolererande": "tolerera",
    "tolereranden": "tolererande",
    "tolererandena": "tolererande",
    "tolererandenas": "tolererande",
    "tolererandens": "tolererande",
    "tolererandes": "tolererande",
    "tolererandet": "tolererande",
    "tolererandets": "tolererande",
    "tolererar": "tolerera",
    "tolereras": "tolerera",
    "tolererat": "tolerera",
    "tolererats": "tolerera",
    "tolererbara": "tolererbar",
    "tolererbarare": "tolererbar",
    "tolererbarares": "tolererbar",
    "tolererbaras": "tolererbar",
    "tolererbarast": "tolererbar",
    "tolererbaraste": "tolererbar",
    "tolererbarastes": "tolererbar",
    "tolererbarasts": "tolererbar",
    "tolererbare": "tolererbar",
    "tolererbares": "tolererbar",
    "tolererbarheten": "tolererbarhet",
    "tolererbarhetens": "tolererbarhet",
    "tolererbarhets": "tolererbarhet",
    "tolererbars": "tolererbar",
    "tolererbart": "tolererbar",
    "tolererbarts": "tolererbar",
    "tolereringar": "tolerering",
    "tolereringarna": "tolerering",
    "tolereringarnas": "tolerering",
    "tolereringars": "tolerering",
    "tolereringen": "tolerering",
    "tolereringens": "tolerering",
    "tolererings": "tolerering",
    "tolfte": "tolv",
    "tolftedelar": "tolftedel",
    "tolftedelarna": "tolftedel",
    "tolftedelarnas": "tolftedel",
    "tolftedelars": "tolftedel",
    "tolftedelen": "tolftedel",
    "tolftedelens": "tolftedel",
    "tolftedels": "tolftedel",
    "tolften": "tolft",
    "tolftens": "tolft",
    "tolfter": "tolft",
    "tolfterna": "tolft",
    "tolfternas": "tolft",
    "tolfters": "tolft",
    "tolftes": "tolv",
    "tolfts": "tolft",
    "tolk": "tolka",
    "tolkad": "tolka",
    "tolkade": "tolka",
    "tolkades": "tolka",
    "tolkads": "tolka",
    "tolkande": "tolka",
    "tolkanden": "tolkande",
    "tolkandena": "tolkande",
    "tolkandenas": "tolkande",
    "tolkandens": "tolkande",
    "tolkandes": "tolkande",
    "tolkandet": "tolkande",
    "tolkandets": "tolkande",
    "tolkar": "tolkare",
    "tolkaren": "tolkare",
    "tolkarens": "tolkare",
    "tolkares": "tolkare",
    "tolkarna": "tolkare",
    "tolkarnas": "tolkare",
    "tolkars": "tolk",
    "tolkas": "tolka",
    "tolkat": "tolka",
    "tolkats": "tolka",
    "tolken": "tolk",
    "tolkens": "tolk",
    "tolklin": "tolklina",
    "tolklinan": "tolklina",
    "tolklinans": "tolklina",
    "tolklinas": "tolklina",
    "tolkline": "tolklina",
    "tolklinor": "tolklina",
    "tolklinorna": "tolklina",
    "tolklinornas": "tolklina",
    "tolklinors": "tolklina",
    "tolklins": "tolklina",
    "tolkningar": "tolkning",
    "tolkningarna": "tolkning",
    "tolkningarnas": "tolkning",
    "tolkningars": "tolkning",
    "tolkningen": "tolkning",
    "tolkningens": "tolkning",
    "tolknings": "tolkning",
    "tolkningsfrågan": "tolkningsfråga",
    "tolkningsfrågans": "tolkningsfråga",
    "tolkningsfrågas": "tolkningsfråga",
    "tolkningsfråge": "tolkningsfråga",
    "tolkningsfrågor": "tolkningsfråga",
    "tolkningsfrågorna": "tolkningsfråga",
    "tolkningsfrågornas": "tolkningsfråga",
    "tolkningsfrågors": "tolkningsfråga",
    "tolkningsföreträdes": "tolkningsföreträde",
    "tolkningsföreträdet": "tolkningsföreträde",
    "tolkningsföreträdets": "tolkningsföreträde",
    "tolkningsmässiga": "tolkningsmässig",
    "tolkningsmässigare": "tolkningsmässig",
    "tolkningsmässigares": "tolkningsmässig",
    "tolkningsmässigas": "tolkningsmässig",
    "tolkningsmässigast": "tolkningsmässig",
    "tolkningsmässigaste": "tolkningsmässig",
    "tolkningsmässigastes": "tolkningsmässig",
    "tolkningsmässigasts": "tolkningsmässig",
    "tolkningsmässige": "tolkningsmässig",
    "tolkningsmässiges": "tolkningsmässig",
    "tolkningsmässigs": "tolkningsmässig",
    "tolkningsmässigt": "tolkningsmässig",
    "tolkningsmässigts": "tolkningsmässig",
    "tolkningsmöjligheten": "tolkningsmöjlighet",
    "tolkningsmöjlighetens": "tolkningsmöjlighet",
    "tolkningsmöjligheter": "tolkningsmöjlighet",
    "tolkningsmöjligheterna": "tolkningsmöjlighet",
    "tolkningsmöjligheternas": "tolkningsmöjlighet",
    "tolkningsmöjligheters": "tolkningsmöjlighet",
    "tolkningsmöjlighets": "tolkningsmöjlighet",
    "tolks": "tolk",
    "tolt": "tolta",
    "toltan": "tolta",
    "toltans": "tolta",
    "toltas": "tolta",
    "tolte": "tolta",
    "toltor": "tolta",
    "toltorna": "tolta",
    "toltornas": "tolta",
    "toltors": "tolta",
    "tolts": "tolta",
    "toluenet": "toluen",
    "toluenets": "toluen",
    "toluens": "toluen",
    "tolvan": "tolva",
    "tolvans": "tolva",
    "tolvas": "tolva",
    "tolvfingertarmar": "tolvfingertarm",
    "tolvfingertarmarna": "tolvfingertarm",
    "tolvfingertarmarnas": "tolvfingertarm",
    "tolvfingertarmars": "tolvfingertarm",
    "tolvfingertarmen": "tolvfingertarm",
    "tolvfingertarmens": "tolvfingertarm",
    "tolvfingertarms": "tolvfingertarm",
    "tolvhundratalet": "tolvhundratal",
    "tolvhundratalets": "tolvhundratal",
    "tolvhundratals": "tolvhundratal",
    "tolvhundratalsmunkar": "tolvhundratalsmunk",
    "tolvhundratalsmunkarna": "tolvhundratalsmunk",
    "tolvhundratalsmunkarnas": "tolvhundratalsmunk",
    "tolvhundratalsmunkars": "tolvhundratalsmunk",
    "tolvhundratalsmunken": "tolvhundratalsmunk",
    "tolvhundratalsmunkens": "tolvhundratalsmunk",
    "tolvhundratalsmunks": "tolvhundratalsmunk",
    "tolvkanthyls": "tolvkanthylsa",
    "tolvkanthylsan": "tolvkanthylsa",
    "tolvkanthylsans": "tolvkanthylsa",
    "tolvkanthylsas": "tolvkanthylsa",
    "tolvkanthylse": "tolvkanthylsa",
    "tolvkanthylsor": "tolvkanthylsa",
    "tolvkanthylsorna": "tolvkanthylsa",
    "tolvkanthylsornas": "tolvkanthylsa",
    "tolvkanthylsors": "tolvkanthylsa",
    "tolvkantshyls": "tolvkantshylsa",
    "tolvkantshylsan": "tolvkantshylsa",
    "tolvkantshylsans": "tolvkantshylsa",
    "tolvkantshylsas": "tolvkantshylsa",
    "tolvkantshylse": "tolvkantshylsa",
    "tolvkantshylsor": "tolvkantshylsa",
    "tolvkantshylsorna": "tolvkantshylsa",
    "tolvkantshylsornas": "tolvkantshylsa",
    "tolvkantshylsors": "tolvkantshylsa",
    "tolvmannen": "tolvman",
    "tolvmannens": "tolvman",
    "tolvmans": "tolvman",
    "tolvmilsgränsen": "tolvmilsgräns",
    "tolvmilsgränsens": "tolvmilsgräns",
    "tolvmilsgränser": "tolvmilsgräns",
    "tolvmilsgränserna": "tolvmilsgräns",
    "tolvmilsgränsernas": "tolvmilsgräns",
    "tolvmilsgränsers": "tolvmilsgräns",
    "tolvmän": "tolvman",
    "tolvmännen": "tolvman",
    "tolvmännens": "tolvman",
    "tolvmäns": "tolvman",
    "tolvor": "tolva",
    "tolvorna": "tolva",
    "tolvornas": "tolva",
    "tolvors": "tolva",
    "tolvs": "tolv",
    "tolvskillingar": "tolvskilling",
    "tolvskillingarna": "tolvskilling",
    "tolvskillingarnas": "tolvskilling",
    "tolvskillingars": "tolvskilling",
    "tolvskillingen": "tolvskilling",
    "tolvskillingens": "tolvskilling",
    "tolvskillings": "tolvskilling",
    "tolvsnårets": "tolvsnåret",
    "tolvtaggar": "tolvtaggare",
    "tolvtaggaren": "tolvtaggare",
    "tolvtaggarens": "tolvtaggare",
    "tolvtaggares": "tolvtaggare",
    "tolvtaggarna": "tolvtaggare",
    "tolvtaggarnas": "tolvtaggare",
    "tolvtonsmusiken": "tolvtonsmusik",
    "tolvtonsmusikens": "tolvtonsmusik",
    "tolvtonsmusiks": "tolvtonsmusik",
    "tolvvoltsbatterier": "tolvvoltsbatteri",
    "tolvvoltsbatterierna": "tolvvoltsbatteri",
    "tolvvoltsbatteriernas": "tolvvoltsbatteri",
    "tolvvoltsbatteriers": "tolvvoltsbatteri",
    "tolvvoltsbatteriet": "tolvvoltsbatteri",
    "tolvvoltsbatteriets": "tolvvoltsbatteri",
    "tolvvoltsbatteris": "tolvvoltsbatteri",
    "tolvvoltsbatterit": "tolvvoltsbatteri",
    "tolvvoltsbatterits": "tolvvoltsbatteri",
    "tolvåriga": "tolvårig",
    "tolvårigas": "tolvårig",
    "tolvårige": "tolvårig",
    "tolvåriges": "tolvårig",
    "tolvårigs": "tolvårig",
    "tolvårigt": "tolvårig",
    "tolvårigts": "tolvårig",
    "tolvåringar": "tolvåring",
    "tolvåringarna": "tolvåring",
    "tolvåringarnas": "tolvåring",
    "tolvåringars": "tolvåring",
    "tolvåringen": "tolvåring",
    "tolvåringens": "tolvåring",
    "tolvårings": "tolvåring",
    "tomahawken": "tomahawk",
    "tomahawkens": "tomahawk",
    "tomahawker": "tomahawk",
    "tomahawkerna": "tomahawk",
    "tomahawkernas": "tomahawk",
    "tomahawkers": "tomahawk",
    "tomahawks": "tomahawk",
    "tomahåken": "tomahåk",
    "tomahåkens": "tomahåk",
    "tomahåker": "tomahåk",
    "tomahåkerna": "tomahåk",
    "tomahåkernas": "tomahåk",
    "tomahåkers": "tomahåk",
    "tomahåks": "tomahåk",
    "tomaten": "tomat",
    "tomatens": "tomat",
    "tomater": "tomat",
    "tomaterna": "tomat",
    "tomaternas": "tomat",
    "tomaters": "tomat",
    "tomatodlingar": "tomatodling",
    "tomatodlingarna": "tomatodling",
    "tomatodlingarnas": "tomatodling",
    "tomatodlingars": "tomatodling",
    "tomatodlingen": "tomatodling",
    "tomatodlingens": "tomatodling",
    "tomatodlings": "tomatodling",
    "tomats": "tomat",
    "tomatsåsen": "tomatsås",
    "tomatsåsens": "tomatsås",
    "tombaken": "tombak",
    "tombakens": "tombak",
    "tombaks": "tombak",
    "tombol": "tombola",
    "tombolan": "tombola",
    "tombolans": "tombola",
    "tombolas": "tombola",
    "tombole": "tombola",
    "tombolor": "tombola",
    "tombolorna": "tombola",
    "tombolornas": "tombola",
    "tombolors": "tombola",
    "tombols": "tombola",
    "tombuteljen": "tombutelj",
    "tombuteljens": "tombutelj",
    "tombuteljer": "tombutelj",
    "tombuteljerna": "tombutelj",
    "tombuteljernas": "tombutelj",
    "tombuteljers": "tombutelj",
    "tombuteljs": "tombutelj",
    "tomen": "tom",
    "tomens": "tom",
    "tomer": "tom",
    "tomerna": "tom",
    "tomernas": "tom",
    "tomers": "tom",
    "tomflask": "tomflaska",
    "tomflaskan": "tomflaska",
    "tomflaskans": "tomflaska",
    "tomflaskas": "tomflaska",
    "tomflaske": "tomflaska",
    "tomflaskor": "tomflaska",
    "tomflaskorna": "tomflaska",
    "tomflaskornas": "tomflaska",
    "tomflaskors": "tomflaska",
    "tomglasen": "tomglas",
    "tomglasens": "tomglas",
    "tomglaset": "tomglas",
    "tomglasets": "tomglas",
    "tomgången": "tomgång",
    "tomgångens": "tomgång",
    "tomgångs": "tomgång",
    "tomgångsförbrukningar": "tomgångsförbrukning",
    "tomgångsförbrukningarna": "tomgångsförbrukning",
    "tomgångsförbrukningarnas": "tomgångsförbrukning",
    "tomgångsförbrukningars": "tomgångsförbrukning",
    "tomgångsförbrukningen": "tomgångsförbrukning",
    "tomgångsförbrukningens": "tomgångsförbrukning",
    "tomgångsförbruknings": "tomgångsförbrukning",
    "tomheten": "tomhet",
    "tomhetens": "tomhet",
    "tomheter": "tomhet",
    "tomheterna": "tomhet",
    "tomheternas": "tomhet",
    "tomheters": "tomhet",
    "tomhets": "tomhet",
    "tomhetskänslan": "tomhetskänsla",
    "tomhetskänslans": "tomhetskänsla",
    "tomhetskänslas": "tomhetskänsla",
    "tomhetskänsle": "tomhetskänsla",
    "tomhetskänslo": "tomhetskänsla",
    "tomhänta": "tomhänt",
    "tomhäntare": "tomhänt",
    "tomhäntares": "tomhänt",
    "tomhäntas": "tomhänt",
    "tomhäntast": "tomhänt",
    "tomhäntaste": "tomhänt",
    "tomhäntastes": "tomhänt",
    "tomhäntasts": "tomhänt",
    "tomhänte": "tomhänt",
    "tomhäntes": "tomhänt",
    "tomhäntheten": "tomhänthet",
    "tomhänthetens": "tomhänthet",
    "tomhänthets": "tomhänthet",
    "tomhänts": "tomhänt",
    "tomkartongen": "tomkartong",
    "tomkartongens": "tomkartong",
    "tomkartonger": "tomkartong",
    "tomkartongerna": "tomkartong",
    "tomkartongernas": "tomkartong",
    "tomkartongers": "tomkartong",
    "tomkartongs": "tomkartong",
    "tomlåd": "tomlåda",
    "tomlådan": "tomlåda",
    "tomlådans": "tomlåda",
    "tomlådas": "tomlåda",
    "tomlåde": "tomlåda",
    "tomlådor": "tomlåda",
    "tomlådorna": "tomlåda",
    "tomlådornas": "tomlåda",
    "tomlådors": "tomlåda",
    "tomlåds": "tomlåda",
    "tomma": "tom",
    "tommare": "tom",
    "tommares": "tom",
    "tommas": "tom",
    "tommast": "tom",
    "tommaste": "tom",
    "tommastes": "tom",
    "tommasts": "tom",
    "tomme": "tom",
    "tommes": "tom",
    "tomografien": "tomografi",
    "tomografiens": "tomografi",
    "tomografier": "tomografi",
    "tomografierna": "tomografi",
    "tomografiernas": "tomografi",
    "tomografiers": "tomografi",
    "tomografin": "tomografi",
    "tomografins": "tomografi",
    "tomografis": "tomografi",
    "tomrummen": "tomrum",
    "tomrummens": "tomrum",
    "tomrummet": "tomrum",
    "tomrummets": "tomrum",
    "tomrums": "tomrum",
    "tomt": "tomta",
    "tomtad": "tomta",
    "tomtade": "tomta",
    "tomtades": "tomta",
    "tomtads": "tomta",
    "tomtande": "tomta",
    "tomtanden": "tomtande",
    "tomtandena": "tomtande",
    "tomtandenas": "tomtande",
    "tomtandens": "tomtande",
    "tomtandes": "tomtande",
    "tomtandet": "tomtande",
    "tomtandets": "tomtande",
    "tomtar": "tomte",
    "tomtarna": "tomte",
    "tomtarnas": "tomte",
    "tomtars": "tomte",
    "tomtas": "tomta",
    "tomtat": "tomta",
    "tomtats": "tomta",
    "tomtebissar": "tomtebisse",
    "tomtebissarna": "tomtebisse",
    "tomtebissarnas": "tomtebisse",
    "tomtebissars": "tomtebisse",
    "tomtebissen": "tomtebisse",
    "tomtebissens": "tomtebisse",
    "tomtebisses": "tomtebisse",
    "tomteblossen": "tomtebloss",
    "tomteblossens": "tomtebloss",
    "tomteblosset": "tomtebloss",
    "tomteblossets": "tomtebloss",
    "tomtebolyckan": "tomtebolycka",
    "tomtebolyckans": "tomtebolycka",
    "tomtebolyckas": "tomtebolycka",
    "tomtedräkten": "tomtedräkt",
    "tomtedräktens": "tomtedräkt",
    "tomtedräkter": "tomtedräkt",
    "tomtedräkterna": "tomtedräkt",
    "tomtedräkternas": "tomtedräkt",
    "tomtedräkters": "tomtedräkt",
    "tomtedräkts": "tomtedräkt",
    "tomtefars": "tomtefar",
    "tomteluvan": "tomteluva",
    "tomteluvans": "tomteluva",
    "tomteluvas": "tomteluva",
    "tomteluve": "tomteluva",
    "tomteluvor": "tomteluva",
    "tomteluvorna": "tomteluva",
    "tomteluvornas": "tomteluva",
    "tomteluvors": "tomteluva",
    "tomtemasken": "tomtemask",
    "tomtemaskens": "tomtemask",
    "tomtemasker": "tomtemask",
    "tomtemaskerna": "tomtemask",
    "tomtemaskernas": "tomtemask",
    "tomtemaskers": "tomtemask",
    "tomtemasks": "tomtemask",
    "tomten": "tomte",
    "tomtenissar": "tomtenisse",
    "tomtenissarna": "tomtenisse",
    "tomtenissarnas": "tomtenisse",
    "tomtenissars": "tomtenisse",
    "tomtenissen": "tomtenisse",
    "tomtenissens": "tomtenisse",
    "tomtenisses": "tomtenisse",
    "tomtens": "tomte",
    "tomter": "tomt",
    "tomterna": "tomt",
    "tomternas": "tomt",
    "tomters": "tomt",
    "tomtes": "tomte",
    "tomteverkstaden": "tomteverkstad",
    "tomteverkstadens": "tomteverkstad",
    "tomteverkstads": "tomteverkstad",
    "tomteverkstan": "tomteverkstad",
    "tomteverkstans": "tomteverkstad",
    "tomteverkstäder": "tomteverkstad",
    "tomteverkstäderna": "tomteverkstad",
    "tomteverkstädernas": "tomteverkstad",
    "tomteverkstäders": "tomteverkstad",
    "tomtjobbar": "tomtjobbare",
    "tomtjobbaren": "tomtjobbare",
    "tomtjobbarens": "tomtjobbare",
    "tomtjobbares": "tomtjobbare",
    "tomtjobbarna": "tomtjobbare",
    "tomtjobbarnas": "tomtjobbare",
    "tomtjobberiet": "tomtjobberi",
    "tomtjobberiets": "tomtjobberi",
    "tomtjobberis": "tomtjobberi",
    "tomtjobberit": "tomtjobberi",
    "tomtjobberits": "tomtjobberi",
    "tomtlösens": "tomtlösen",
    "tomtmarken": "tomtmark",
    "tomtmarkens": "tomtmark",
    "tomtmarker": "tomtmark",
    "tomtmarkerna": "tomtmark",
    "tomtmarkernas": "tomtmark",
    "tomtmarkers": "tomtmark",
    "tomtmarks": "tomtmark",
    "tomträtten": "tomträtt",
    "tomträttens": "tomträtt",
    "tomträtts": "tomträtt",
    "tomträttsavgälden": "tomträttsavgäld",
    "tomträttsavgäldens": "tomträttsavgäld",
    "tomträttsavgälder": "tomträttsavgäld",
    "tomträttsavgälderna": "tomträttsavgäld",
    "tomträttsavgäldernas": "tomträttsavgäld",
    "tomträttsavgälders": "tomträttsavgäld",
    "tomträttsavgälds": "tomträttsavgäld",
    "tomts": "tomt",
    "ton": "tona",
    "tonad": "tona",
    "tonade": "tona",
    "tonades": "tona",
    "tonads": "tona",
    "tonala": "tonal",
    "tonalare": "tonal",
    "tonalares": "tonal",
    "tonalas": "tonal",
    "tonalast": "tonal",
    "tonalaste": "tonal",
    "tonalastes": "tonal",
    "tonalasts": "tonal",
    "tonale": "tonal",
    "tonales": "tonal",
    "tonaliteten": "tonalitet",
    "tonalitetens": "tonalitet",
    "tonaliteter": "tonalitet",
    "tonaliteterna": "tonalitet",
    "tonaliteternas": "tonalitet",
    "tonaliteters": "tonalitet",
    "tonalitets": "tonalitet",
    "tonals": "tonal",
    "tonalt": "tonal",
    "tonalts": "tonal",
    "tonande": "tona",
    "tonanden": "tonande",
    "tonandena": "tonande",
    "tonandenas": "tonande",
    "tonandens": "tonande",
    "tonandes": "tonande",
    "tonandet": "tonande",
    "tonandets": "tonande",
    "tonar": "tona",
    "tonarmar": "tonarm",
    "tonarmarna": "tonarm",
    "tonarmarnas": "tonarm",
    "tonarmars": "tonarm",
    "tonarmen": "tonarm",
    "tonarmens": "tonarm",
    "tonarms": "tonarm",
    "tonarten": "tonart",
    "tonartens": "tonart",
    "tonarter": "tonart",
    "tonarterna": "tonart",
    "tonarternas": "tonart",
    "tonarters": "tonart",
    "tonarts": "tonart",
    "tonas": "tona",
    "tonat": "tona",
    "tonats": "tona",
    "tonbanden": "tonband",
    "tonbandens": "tonband",
    "tonbandet": "tonband",
    "tonbandets": "tonband",
    "tonbands": "tonband",
    "tonbildningar": "tonbildning",
    "tonbildningarna": "tonbildning",
    "tonbildningarnas": "tonbildning",
    "tonbildningars": "tonbildning",
    "tonbildningen": "tonbildning",
    "tonbildningens": "tonbildning",
    "tonbildnings": "tonbildning",
    "tondöva": "tondöv",
    "tondövare": "tondöv",
    "tondövares": "tondöv",
    "tondövas": "tondöv",
    "tondövast": "tondöv",
    "tondövaste": "tondöv",
    "tondövastes": "tondöv",
    "tondövasts": "tondöv",
    "tondöve": "tondöv",
    "tondöves": "tondöv",
    "tondövheten": "tondövhet",
    "tondövhetens": "tondövhet",
    "tondövhets": "tondövhet",
    "tondövs": "tondöv",
    "tondövt": "tondöv",
    "tondövts": "tondöv",
    "tonemen": "tonem",
    "tonemens": "tonem",
    "tonemet": "tonem",
    "tonemets": "tonem",
    "tonems": "tonem",
    "tonen": "ton",
    "tonens": "ton",
    "toner": "ton",
    "tonerna": "ton",
    "tonernas": "ton",
    "toners": "ton",
    "tonetsningar": "tonetsning",
    "tonetsningarna": "tonetsning",
    "tonetsningarnas": "tonetsning",
    "tonetsningars": "tonetsning",
    "tonetsningen": "tonetsning",
    "tonetsningens": "tonetsning",
    "tonetsnings": "tonetsning",
    "tonetten": "tonett",
    "tonettens": "tonett",
    "tonetter": "tonett",
    "tonetterna": "tonett",
    "tonetternas": "tonett",
    "tonetters": "tonett",
    "tonetts": "tonett",
    "tonfallen": "tonfall",
    "tonfallens": "tonfall",
    "tonfallet": "tonfall",
    "tonfallets": "tonfall",
    "tonfalls": "tonfall",
    "tonfiskar": "tonfisk",
    "tonfiskarna": "tonfisk",
    "tonfiskarnas": "tonfisk",
    "tonfiskars": "tonfisk",
    "tonfisken": "tonfisk",
    "tonfiskens": "tonfisk",
    "tonfisks": "tonfisk",
    "tonföljden": "tonföljd",
    "tonföljdens": "tonföljd",
    "tonföljder": "tonföljd",
    "tonföljderna": "tonföljd",
    "tonföljdernas": "tonföljd",
    "tonföljders": "tonföljd",
    "tonföljds": "tonföljd",
    "tonganen": "tongan",
    "tonganens": "tongan",
    "tonganer": "tongan",
    "tonganerna": "tongan",
    "tonganernas": "tongan",
    "tonganers": "tongan",
    "tongans": "tongan",
    "tongansk": "tonganska",
    "tonganska": "tongansk",
    "tonganskan": "tonganska",
    "tonganskans": "tonganska",
    "tonganskare": "tongansk",
    "tonganskares": "tongansk",
    "tonganskas": "tonganska",
    "tonganskast": "tongansk",
    "tonganskaste": "tongansk",
    "tonganskastes": "tongansk",
    "tonganskasts": "tongansk",
    "tonganske": "tonganska",
    "tonganskes": "tongansk",
    "tonganskor": "tonganska",
    "tonganskorna": "tonganska",
    "tonganskornas": "tonganska",
    "tonganskors": "tonganska",
    "tongansks": "tongansk",
    "tonganskt": "tongansk",
    "tonganskts": "tongansk",
    "tongångar": "tongång",
    "tongångarna": "tongång",
    "tongångarnas": "tongång",
    "tongångars": "tongång",
    "tongången": "tongång",
    "tongångens": "tongång",
    "tongångs": "tongång",
    "tonhöjden": "tonhöjd",
    "tonhöjdens": "tonhöjd",
    "tonhöjder": "tonhöjd",
    "tonhöjderna": "tonhöjd",
    "tonhöjdernas": "tonhöjd",
    "tonhöjders": "tonhöjd",
    "tonhöjds": "tonhöjd",
    "tonicen": "tonic",
    "tonicens": "tonic",
    "tonics": "tonic",
    "tonik": "tonika",
    "tonikan": "tonika",
    "tonikans": "tonika",
    "tonikas": "tonika",
    "tonike": "tonika",
    "tonikor": "tonika",
    "tonikorna": "tonika",
    "tonikornas": "tonika",
    "tonikors": "tonika",
    "toniks": "tonika",
    "tonikumen": "tonikum",
    "tonikumens": "tonikum",
    "tonikumet": "tonikum",
    "tonikumets": "tonikum",
    "tonikums": "tonikum",
    "toningar": "toning",
    "toningarna": "toning",
    "toningarnas": "toning",
    "toningars": "toning",
    "toningen": "toning",
    "toningens": "toning",
    "tonings": "toning",
    "toniska": "tonisk",
    "toniskare": "tonisk",
    "toniskares": "tonisk",
    "toniskas": "tonisk",
    "toniskast": "tonisk",
    "toniskaste": "tonisk",
    "toniskastes": "tonisk",
    "toniskasts": "tonisk",
    "toniske": "tonisk",
    "toniskes": "tonisk",
    "tonisks": "tonisk",
    "toniskt": "tonisk",
    "toniskts": "tonisk",
    "tonkilometern": "tonkilometer",
    "tonkilometerna": "tonkilometer",
    "tonkilometernas": "tonkilometer",
    "tonkilometerns": "tonkilometer",
    "tonkilometers": "tonkilometer",
    "tonkonsten": "tonkonst",
    "tonkonstens": "tonkonst",
    "tonkonsts": "tonkonst",
    "tonlägen": "tonläge",
    "tonlägena": "tonläge",
    "tonlägenas": "tonläge",
    "tonlägens": "tonläge",
    "tonläges": "tonläge",
    "tonläget": "tonläge",
    "tonlägets": "tonläge",
    "tonlösa": "tonlös",
    "tonlösare": "tonlös",
    "tonlösares": "tonlös",
    "tonlösas": "tonlös",
    "tonlösast": "tonlös",
    "tonlösaste": "tonlös",
    "tonlösastes": "tonlös",
    "tonlösasts": "tonlös",
    "tonlöse": "tonlös",
    "tonlöses": "tonlös",
    "tonlösheten": "tonlöshet",
    "tonlöshetens": "tonlöshet",
    "tonlöshets": "tonlöshet",
    "tonlöst": "tonlös",
    "tonlösts": "tonlös",
    "tonmålningar": "tonmålning",
    "tonmålningarna": "tonmålning",
    "tonmålningarnas": "tonmålning",
    "tonmålningars": "tonmålning",
    "tonmålningen": "tonmålning",
    "tonmålningens": "tonmålning",
    "tonmålnings": "tonmålning",
    "tonnages": "tonnage",
    "tonnaget": "tonnage",
    "tonnagets": "tonnage",
    "tonnar": "tonnare",
    "tonnaren": "tonnare",
    "tonnarens": "tonnare",
    "tonnares": "tonnare",
    "tonnarna": "tonnare",
    "tonnarnas": "tonnare",
    "tonnars": "tonnare",
    "tonnen": "ton",
    "tonnens": "ton",
    "tonnet": "ton",
    "tonnets": "ton",
    "tonomfången": "tonomfång",
    "tonomfångens": "tonomfång",
    "tonomfånget": "tonomfång",
    "tonomfångets": "tonomfång",
    "tonomfångs": "tonomfång",
    "tonområden": "tonområde",
    "tonområdena": "tonområde",
    "tonområdenas": "tonområde",
    "tonområdens": "tonområde",
    "tonområdes": "tonområde",
    "tonområdet": "tonområde",
    "tonområdets": "tonområde",
    "tons": "ton",
    "tonsatt": "tonsätta",
    "tonsatta": "tonsätta",
    "tonsattas": "tonsätta",
    "tonsatte": "tonsätta",
    "tonsattes": "tonsätta",
    "tonsatts": "tonsätta",
    "tonsillen": "tonsill",
    "tonsillens": "tonsill",
    "tonsiller": "tonsill",
    "tonsillerna": "tonsill",
    "tonsillernas": "tonsill",
    "tonsillers": "tonsill",
    "tonsills": "tonsill",
    "tonskal": "tonskala",
    "tonskalan": "tonskala",
    "tonskalans": "tonskala",
    "tonskalas": "tonskala",
    "tonskale": "tonskala",
    "tonskalor": "tonskala",
    "tonskalorna": "tonskala",
    "tonskalornas": "tonskala",
    "tonskalors": "tonskala",
    "tonskals": "tonskala",
    "tonspråken": "tonspråk",
    "tonspråkens": "tonspråk",
    "tonspråket": "tonspråk",
    "tonspråkets": "tonspråk",
    "tonspråks": "tonspråk",
    "tonstegen": "tonsteg",
    "tonstegens": "tonsteg",
    "tonsteget": "tonsteg",
    "tonstegets": "tonsteg",
    "tonstegs": "tonsteg",
    "tonstyrkan": "tonstyrka",
    "tonstyrkans": "tonstyrka",
    "tonstyrkas": "tonstyrka",
    "tonstyrke": "tonstyrka",
    "tonstyrkor": "tonstyrka",
    "tonstyrkorna": "tonstyrka",
    "tonstyrkornas": "tonstyrka",
    "tonstyrkors": "tonstyrka",
    "tonsuren": "tonsur",
    "tonsurens": "tonsur",
    "tonsurer": "tonsur",
    "tonsurerna": "tonsur",
    "tonsurernas": "tonsur",
    "tonsurers": "tonsur",
    "tonsurs": "tonsur",
    "tonsystemen": "tonsystem",
    "tonsystemens": "tonsystem",
    "tonsystemet": "tonsystem",
    "tonsystemets": "tonsystem",
    "tonsystems": "tonsystem",
    "tonsäkerheten": "tonsäkerhet",
    "tonsäkerhetens": "tonsäkerhet",
    "tonsäkerhets": "tonsäkerhet",
    "tonsäkers": "tonsäker",
    "tonsäkert": "tonsäker",
    "tonsäkerts": "tonsäker",
    "tonsäkra": "tonsäker",
    "tonsäkrare": "tonsäker",
    "tonsäkrares": "tonsäker",
    "tonsäkras": "tonsäker",
    "tonsäkrast": "tonsäker",
    "tonsäkraste": "tonsäker",
    "tonsäkrastes": "tonsäker",
    "tonsäkrasts": "tonsäker",
    "tonsäkre": "tonsäker",
    "tonsäkres": "tonsäker",
    "tonsätt": "tonsätta",
    "tonsättande": "tonsätta",
    "tonsättanden": "tonsättande",
    "tonsättandena": "tonsättande",
    "tonsättandenas": "tonsättande",
    "tonsättandens": "tonsättande",
    "tonsättandes": "tonsättande",
    "tonsättandet": "tonsättande",
    "tonsättandets": "tonsättande",
    "tonsättar": "tonsättare",
    "tonsättaren": "tonsättare",
    "tonsättarens": "tonsättare",
    "tonsättares": "tonsättare",
    "tonsättarna": "tonsättare",
    "tonsättarnas": "tonsättare",
    "tonsättas": "tonsätta",
    "tonsätter": "tonsätta",
    "tonsättes": "tonsätta",
    "tonsättningar": "tonsättning",
    "tonsättningarna": "tonsättning",
    "tonsättningarnas": "tonsättning",
    "tonsättningars": "tonsättning",
    "tonsättningen": "tonsättning",
    "tonsättningens": "tonsättning",
    "tonsättnings": "tonsättning",
    "tonsätts": "tonsätta",
    "tonträffningar": "tonträffning",
    "tonträffningarna": "tonträffning",
    "tonträffningarnas": "tonträffning",
    "tonträffningars": "tonträffning",
    "tonträffningen": "tonträffning",
    "tonträffningens": "tonträffning",
    "tonträffnings": "tonträffning",
    "tonusen": "tonus",
    "tonusens": "tonus",
    "tonvalet": "tonval",
    "tonvalets": "tonval",
    "tonvals": "tonval",
    "tonvikten": "tonvikt",
    "tonviktens": "tonvikt",
    "tonvikts": "tonvikt",
    "tonåren": "tonår",
    "tonårens": "tonår",
    "tonåriga": "tonårig",
    "tonårigas": "tonårig",
    "tonårige": "tonårig",
    "tonåriges": "tonårig",
    "tonårigs": "tonårig",
    "tonårigt": "tonårig",
    "tonårigts": "tonårig",
    "tonåringar": "tonåring",
    "tonåringarna": "tonåring",
    "tonåringarnas": "tonåring",
    "tonåringars": "tonåring",
    "tonåringen": "tonåring",
    "tonåringens": "tonåring",
    "tonårings": "tonåring",
    "tonårs": "tonår",
    "tonårsflick": "tonårsflicka",
    "tonårsflickan": "tonårsflicka",
    "tonårsflickans": "tonårsflicka",
    "tonårsflickas": "tonårsflicka",
    "tonårsflicke": "tonårsflicka",
    "tonårsflickor": "tonårsflicka",
    "tonårsflickorna": "tonårsflicka",
    "tonårsflickornas": "tonårsflicka",
    "tonårsflickors": "tonårsflicka",
    "tonårsflicks": "tonårsflicka",
    "tonårsförövar": "tonårsförövare",
    "tonårsförövaren": "tonårsförövare",
    "tonårsförövarens": "tonårsförövare",
    "tonårsförövares": "tonårsförövare",
    "tonårsförövarna": "tonårsförövare",
    "tonårsförövarnas": "tonårsförövare",
    "tonårsgängen": "tonårsgäng",
    "tonårsgängens": "tonårsgäng",
    "tonårsgänget": "tonårsgäng",
    "tonårsgängets": "tonårsgäng",
    "tonårsgängs": "tonårsgäng",
    "tonårsidolen": "tonårsidol",
    "tonårsidolens": "tonårsidol",
    "tonårsidoler": "tonårsidol",
    "tonårsidolerna": "tonårsidol",
    "tonårsidolernas": "tonårsidol",
    "tonårsidolers": "tonårsidol",
    "tonårsidols": "tonårsidol",
    "tonårsperioden": "tonårsperiod",
    "tonårsperiodens": "tonårsperiod",
    "tonårsperioder": "tonårsperiod",
    "tonårsperioderna": "tonårsperiod",
    "tonårsperiodernas": "tonårsperiod",
    "tonårsperioders": "tonårsperiod",
    "tonårsperiods": "tonårsperiod",
    "tonårspojk": "tonårspojke",
    "tonårspojkar": "tonårspojke",
    "tonårspojkarna": "tonårspojke",
    "tonårspojkarnas": "tonårspojke",
    "tonårspojkars": "tonårspojke",
    "tonårspojken": "tonårspojke",
    "tonårspojkens": "tonårspojke",
    "tonårspojkes": "tonårspojke",
    "tonårspojks": "tonårspojke",
    "toor": "toa",
    "toorna": "toa",
    "toornas": "toa",
    "toors": "toa",
    "topasen": "topas",
    "topasens": "topas",
    "topaser": "topas",
    "topaserna": "topas",
    "topasernas": "topas",
    "topasers": "topas",
    "topografen": "topograf",
    "topografens": "topograf",
    "topografer": "topograf",
    "topograferna": "topograf",
    "topografernas": "topograf",
    "topografers": "topograf",
    "topografien": "topografi",
    "topografiens": "topografi",
    "topografin": "topografi",
    "topografins": "topografi",
    "topografis": "topografi",
    "topografiska": "topografisk",
    "topografiskare": "topografisk",
    "topografiskares": "topografisk",
    "topografiskas": "topografisk",
    "topografiskast": "topografisk",
    "topografiskaste": "topografisk",
    "topografiskastes": "topografisk",
    "topografiskasts": "topografisk",
    "topografiske": "topografisk",
    "topografiskes": "topografisk",
    "topografisks": "topografisk",
    "topografiskt": "topografisk",
    "topografiskts": "topografisk",
    "topografs": "topograf",
    "topologien": "topologi",
    "topologiens": "topologi",
    "topologier": "topologi",
    "topologierna": "topologi",
    "topologiernas": "topologi",
    "topologiers": "topologi",
    "topologin": "topologi",
    "topologins": "topologi",
    "topologis": "topologi",
    "topologiska": "topologisk",
    "topologiskare": "topologisk",
    "topologiskares": "topologisk",
    "topologiskas": "topologisk",
    "topologiskast": "topologisk",
    "topologiskaste": "topologisk",
    "topologiskastes": "topologisk",
    "topologiskasts": "topologisk",
    "topologiske": "topologisk",
    "topologiskes": "topologisk",
    "topologisks": "topologisk",
    "topologiskt": "topologisk",
    "topologiskts": "topologisk",
    "topp": "toppa",
    "toppad": "toppa",
    "toppade": "toppa",
    "toppades": "toppa",
    "toppads": "toppa",
    "toppande": "toppa",
    "toppanden": "toppande",
    "toppandena": "toppande",
    "toppandenas": "toppande",
    "toppandens": "toppande",
    "toppandes": "toppande",
    "toppandet": "toppande",
    "toppandets": "toppande",
    "toppar": "toppa",
    "topparna": "topp",
    "topparnas": "topp",
    "toppars": "topp",
    "toppas": "toppa",
    "toppat": "toppa",
    "toppats": "toppa",
    "toppbefattningar": "toppbefattning",
    "toppbefattningarna": "toppbefattning",
    "toppbefattningarnas": "toppbefattning",
    "toppbefattningars": "toppbefattning",
    "toppbefattningen": "toppbefattning",
    "toppbefattningens": "toppbefattning",
    "toppbefattnings": "toppbefattning",
    "toppbegåvningar": "toppbegåvning",
    "toppbegåvningarna": "toppbegåvning",
    "toppbegåvningarnas": "toppbegåvning",
    "toppbegåvningars": "toppbegåvning",
    "toppbegåvningen": "toppbegåvning",
    "toppbegåvningens": "toppbegåvning",
    "toppbegåvnings": "toppbegåvning",
    "toppbranden": "toppbrand",
    "toppbrandens": "toppbrand",
    "toppbrands": "toppbrand",
    "toppdomänen": "toppdomän",
    "toppdomänens": "toppdomän",
    "toppdomäner": "toppdomän",
    "toppdomänerna": "toppdomän",
    "toppdomänernas": "toppdomän",
    "toppdomäners": "toppdomän",
    "toppdomäns": "toppdomän",
    "toppduon": "toppduo",
    "toppduons": "toppduo",
    "toppduor": "toppduo",
    "toppduorna": "toppduo",
    "toppduornas": "toppduo",
    "toppduors": "toppduo",
    "toppduos": "toppduo",
    "toppduosen": "toppduo",
    "toppduosens": "toppduo",
    "toppelden": "toppeld",
    "toppeldens": "toppeld",
    "toppelds": "toppeld",
    "toppen": "topp",
    "toppenergien": "toppenergi",
    "toppenergiens": "toppenergi",
    "toppenergier": "toppenergi",
    "toppenergierna": "toppenergi",
    "toppenergiernas": "toppenergi",
    "toppenergiers": "toppenergi",
    "toppenergin": "toppenergi",
    "toppenergins": "toppenergi",
    "toppenergis": "toppenergi",
    "toppens": "toppen",
    "toppet": "toppen",
    "toppets": "toppen",
    "toppfarten": "toppfart",
    "toppfartens": "toppfart",
    "toppfarts": "toppfart",
    "toppformen": "toppform",
    "toppformens": "toppform",
    "toppformiga": "toppformig",
    "toppformigare": "toppformig",
    "toppformigares": "toppformig",
    "toppformigas": "toppformig",
    "toppformigast": "toppformig",
    "toppformigaste": "toppformig",
    "toppformigastes": "toppformig",
    "toppformigasts": "toppformig",
    "toppformige": "toppformig",
    "toppformiges": "toppformig",
    "toppformigheten": "toppformighet",
    "toppformighetens": "toppformighet",
    "toppformighets": "toppformighet",
    "toppformigs": "toppformig",
    "toppformigt": "toppformig",
    "toppformigts": "toppformig",
    "toppforms": "toppform",
    "toppförstärkningar": "toppförstärkning",
    "toppförstärkningarna": "toppförstärkning",
    "toppförstärkningarnas": "toppförstärkning",
    "toppförstärkningars": "toppförstärkning",
    "toppförstärkningen": "toppförstärkning",
    "toppförstärkningens": "toppförstärkning",
    "toppförstärknings": "toppförstärkning",
    "topphugg": "topphugga",
    "topphuggande": "topphugga",
    "topphugganden": "topphuggande",
    "topphuggandena": "topphuggande",
    "topphuggandenas": "topphuggande",
    "topphuggandens": "topphuggande",
    "topphuggandes": "topphuggande",
    "topphuggandet": "topphuggande",
    "topphuggandets": "topphuggande",
    "topphuggas": "topphugga",
    "topphugge": "topphugga",
    "topphuggen": "topphugga",
    "topphuggens": "topphugga",
    "topphugger": "topphugga",
    "topphugges": "topphugga",
    "topphugget": "topphugga",
    "topphuggets": "topphugga",
    "topphuggit": "topphugga",
    "topphuggits": "topphugga",
    "topphuggna": "topphugga",
    "topphuggnas": "topphugga",
    "topphuggne": "topphugga",
    "topphuggnes": "topphugga",
    "topphuggs": "topphugga",
    "topphästar": "topphäst",
    "topphästarna": "topphäst",
    "topphästarnas": "topphäst",
    "topphästars": "topphäst",
    "topphästen": "topphäst",
    "topphästens": "topphäst",
    "topphästs": "topphäst",
    "topphögg": "topphugga",
    "topphögge": "topphugga",
    "topphögges": "topphugga",
    "topphöggs": "topphugga",
    "toppiga": "toppig",
    "toppigare": "toppig",
    "toppigares": "toppig",
    "toppigas": "toppig",
    "toppigast": "toppig",
    "toppigaste": "toppig",
    "toppigastes": "toppig",
    "toppigasts": "toppig",
    "toppige": "toppig",
    "toppiges": "toppig",
    "toppigheten": "toppighet",
    "toppighetens": "toppighet",
    "toppighets": "toppighet",
    "toppigs": "toppig",
    "toppigt": "toppig",
    "toppigts": "toppig",
    "toppingar": "topping",
    "toppingarna": "topping",
    "toppingarnas": "topping",
    "toppingars": "topping",
    "toppingen": "topping",
    "toppingens": "topping",
    "toppings": "topping",
    "toppjobben": "toppjobb",
    "toppjobbens": "toppjobb",
    "toppjobbet": "toppjobb",
    "toppjobbets": "toppjobb",
    "toppjobbs": "toppjobb",
    "toppklassen": "toppklass",
    "toppklassens": "toppklass",
    "toppknoppar": "toppknopp",
    "toppknopparna": "toppknopp",
    "toppknopparnas": "toppknopp",
    "toppknoppars": "toppknopp",
    "toppknoppen": "toppknopp",
    "toppknoppens": "toppknopp",
    "toppknopps": "toppknopp",
    "toppkonferensen": "toppkonferens",
    "toppkonferensens": "toppkonferens",
    "toppkonferenser": "toppkonferens",
    "toppkonferenserna": "toppkonferens",
    "toppkonferensernas": "toppkonferens",
    "toppkonferensers": "toppkonferens",
    "toppkraften": "toppkraft",
    "toppkraftens": "toppkraft",
    "toppkrafter": "toppkraft",
    "toppkrafterna": "toppkraft",
    "toppkrafternas": "toppkraft",
    "toppkrafters": "toppkraft",
    "toppkrafts": "toppkraft",
    "topplanternan": "topplanterna",
    "topplanternans": "topplanterna",
    "topplanternas": "topplanterna",
    "topplanterne": "topplanterna",
    "topplanternor": "topplanterna",
    "topplanternorna": "topplanterna",
    "topplanternornas": "topplanterna",
    "topplanternors": "topplanterna",
    "topplocken": "topplock",
    "topplockens": "topplock",
    "topplocket": "topplock",
    "topplockets": "topplock",
    "topplocks": "topplock",
    "toppluvan": "toppluva",
    "toppluvans": "toppluva",
    "toppluvas": "toppluva",
    "toppluve": "toppluva",
    "toppluvor": "toppluva",
    "toppluvorna": "toppluva",
    "toppluvornas": "toppluva",
    "toppluvors": "toppluva",
    "toppläntan": "topplänta",
    "toppläntans": "topplänta",
    "toppläntas": "topplänta",
    "topplänte": "topplänta",
    "toppläntor": "topplänta",
    "toppläntorna": "topplänta",
    "toppläntornas": "topplänta",
    "toppläntors": "topplänta",
    "topplärk": "topplärka",
    "topplärkan": "topplärka",
    "topplärkans": "topplärka",
    "topplärkas": "topplärka",
    "topplärke": "topplärka",
    "topplärkor": "topplärka",
    "topplärkorna": "topplärka",
    "topplärkornas": "topplärka",
    "topplärkors": "topplärka",
    "topplärks": "topplärka",
    "topplånen": "topplån",
    "topplånens": "topplån",
    "topplånet": "topplån",
    "topplånets": "topplån",
    "topplåns": "topplån",
    "topplös": "topplösa",
    "topplösan": "topplösa",
    "topplösans": "topplösa",
    "topplösas": "topplösa",
    "topplöse": "topplösa",
    "topplösor": "topplösa",
    "topplösorna": "topplösa",
    "topplösornas": "topplösa",
    "topplösors": "topplösa",
    "toppmannen": "toppman",
    "toppmannens": "toppman",
    "toppmans": "toppman",
    "toppmasten": "toppmast",
    "toppmastens": "toppmast",
    "toppmaster": "toppmast",
    "toppmasterna": "toppmast",
    "toppmasternas": "toppmast",
    "toppmasters": "toppmast",
    "toppmasts": "toppmast",
    "toppmatade": "toppmatad",
    "toppmatades": "toppmatad",
    "toppmatads": "toppmatad",
    "toppmatat": "toppmatad",
    "toppmatats": "toppmatad",
    "toppmoderna": "toppmodern",
    "toppmodernare": "toppmodern",
    "toppmodernares": "toppmodern",
    "toppmodernas": "toppmodern",
    "toppmodernast": "toppmodern",
    "toppmodernaste": "toppmodern",
    "toppmodernastes": "toppmodern",
    "toppmodernasts": "toppmodern",
    "toppmoderne": "toppmodern",
    "toppmodernes": "toppmodern",
    "toppmoderns": "toppmodern",
    "toppmodernt": "toppmodern",
    "toppmodernts": "toppmodern",
    "toppmurkel": "toppmurkla",
    "toppmurklan": "toppmurkla",
    "toppmurklans": "toppmurkla",
    "toppmurklas": "toppmurkla",
    "toppmurkle": "toppmurkla",
    "toppmurklor": "toppmurkla",
    "toppmurklorna": "toppmurkla",
    "toppmurklornas": "toppmurkla",
    "toppmurklors": "toppmurkla",
    "toppmän": "toppman",
    "toppmännen": "toppman",
    "toppmännens": "toppman",
    "toppmäns": "toppman",
    "toppmöten": "toppmöte",
    "toppmötena": "toppmöte",
    "toppmötenas": "toppmöte",
    "toppmötens": "toppmöte",
    "toppmötes": "toppmöte",
    "toppmötet": "toppmöte",
    "toppmötets": "toppmöte",
    "toppna": "toppen",
    "toppnare": "toppen",
    "toppnares": "toppen",
    "toppnas": "toppen",
    "toppnast": "toppen",
    "toppnaste": "toppen",
    "toppnastes": "toppen",
    "toppnasts": "toppen",
    "toppne": "toppen",
    "toppnes": "toppen",
    "toppningar": "toppning",
    "toppningarna": "toppning",
    "toppningarnas": "toppning",
    "toppningars": "toppning",
    "toppningen": "toppning",
    "toppningens": "toppning",
    "toppnings": "toppning",
    "toppnivåer": "toppnivå",
    "toppnivåerna": "toppnivå",
    "toppnivåernas": "toppnivå",
    "toppnivåers": "toppnivå",
    "toppnivån": "toppnivå",
    "toppnivåns": "toppnivå",
    "toppnivås": "toppnivå",
    "toppolitikern": "toppolitiker",
    "toppolitikerna": "toppolitiker",
    "toppolitikernas": "toppolitiker",
    "toppolitikerns": "toppolitiker",
    "toppolitikers": "toppolitiker",
    "toppred": "topprida",
    "toppreds": "topprida",
    "topprid": "topprida",
    "toppridande": "topprida",
    "toppridanden": "toppridande",
    "toppridandena": "toppridande",
    "toppridandenas": "toppridande",
    "toppridandens": "toppridande",
    "toppridandes": "toppridande",
    "toppridandet": "toppridande",
    "toppridandets": "toppridande",
    "toppridas": "topprida",
    "toppride": "topprida",
    "toppriden": "topprida",
    "toppridens": "topprida",
    "topprider": "topprida",
    "topprides": "topprida",
    "toppridet": "topprida",
    "toppridets": "topprida",
    "toppridit": "topprida",
    "toppridits": "topprida",
    "toppridna": "topprida",
    "toppridnas": "topprida",
    "toppridne": "topprida",
    "toppridnes": "topprida",
    "topprids": "topprida",
    "topprötan": "toppröta",
    "topprötans": "toppröta",
    "topprötas": "toppröta",
    "toppröte": "toppröta",
    "topps": "topp",
    "toppsegels": "toppsegel",
    "toppseglen": "toppsegel",
    "toppseglens": "toppsegel",
    "toppseglet": "toppsegel",
    "toppseglets": "toppsegel",
    "toppskotten": "toppskott",
    "toppskottens": "toppskott",
    "toppskottet": "toppskott",
    "toppskottets": "toppskott",
    "toppskotts": "toppskott",
    "toppstyrda": "toppstyrd",
    "toppstyrdare": "toppstyrd",
    "toppstyrdares": "toppstyrd",
    "toppstyrdas": "toppstyrd",
    "toppstyrdast": "toppstyrd",
    "toppstyrdaste": "toppstyrd",
    "toppstyrdastes": "toppstyrd",
    "toppstyrdasts": "toppstyrd",
    "toppstyrde": "toppstyrd",
    "toppstyrdes": "toppstyrd",
    "toppstyrdheten": "toppstyrdhet",
    "toppstyrdhetens": "toppstyrdhet",
    "toppstyrdhets": "toppstyrdhet",
    "toppstyrds": "toppstyrd",
    "toppstyrt": "toppstyrd",
    "toppstyrts": "toppstyrd",
    "topptrimmet": "topptrim",
    "topptrimmets": "topptrim",
    "topptrims": "topptrim",
    "toppänd": "toppända",
    "toppändan": "toppända",
    "toppändans": "toppända",
    "toppändar": "toppände",
    "toppändarna": "toppände",
    "toppändarnas": "toppände",
    "toppändars": "toppände",
    "toppändas": "toppända",
    "toppände": "toppända",
    "toppänden": "toppände",
    "toppändens": "toppände",
    "toppändes": "toppände",
    "toppändor": "toppända",
    "toppändorna": "toppända",
    "toppändornas": "toppända",
    "toppändors": "toppända",
    "toppänds": "toppända",
    "topsad": "topsa",
    "topsade": "topsa",
    "topsades": "topsa",
    "topsads": "topsa",
    "topsande": "topsa",
    "topsanden": "topsande",
    "topsandena": "topsande",
    "topsandenas": "topsande",
    "topsandens": "topsande",
    "topsandes": "topsande",
    "topsandet": "topsande",
    "topsandets": "topsande",
    "topsar": "topsa",
    "topsarna": "tops",
    "topsarnas": "tops",
    "topsars": "tops",
    "topsas": "topsa",
    "topsat": "topsa",
    "topsats": "topsa",
    "topsen": "tops",
    "topsens": "tops",
    "topspins": "topspin",
    "toquen": "toque",
    "toquens": "toque",
    "toquer": "toque",
    "toquerna": "toque",
    "toquernas": "toque",
    "toquers": "toque",
    "toques": "toque",
    "tordas": "töras",
    "tordeenden": "tordeende",
    "tordeendena": "tordeende",
    "tordeendenas": "tordeende",
    "tordeendens": "tordeende",
    "tordeendes": "tordeende",
    "tordeendet": "tordeende",
    "tordeendets": "tordeende",
    "torderad": "tordera",
    "torderade": "tordera",
    "torderades": "tordera",
    "torderads": "tordera",
    "torderande": "tordera",
    "torderanden": "torderande",
    "torderandena": "torderande",
    "torderandenas": "torderande",
    "torderandens": "torderande",
    "torderandes": "torderande",
    "torderandet": "torderande",
    "torderandets": "torderande",
    "torderar": "tordera",
    "torderas": "tordera",
    "torderat": "tordera",
    "torderats": "tordera",
    "torderbara": "torderbar",
    "torderbarare": "torderbar",
    "torderbarares": "torderbar",
    "torderbaras": "torderbar",
    "torderbarast": "torderbar",
    "torderbaraste": "torderbar",
    "torderbarastes": "torderbar",
    "torderbarasts": "torderbar",
    "torderbare": "torderbar",
    "torderbares": "torderbar",
    "torderbarheten": "torderbarhet",
    "torderbarhetens": "torderbarhet",
    "torderbarhets": "torderbarhet",
    "torderbars": "torderbar",
    "torderbart": "torderbar",
    "torderbarts": "torderbar",
    "torderingar": "tordering",
    "torderingarna": "tordering",
    "torderingarnas": "tordering",
    "torderingars": "tordering",
    "torderingen": "tordering",
    "torderingens": "tordering",
    "torderings": "tordering",
    "tordes": "torde",
    "tordmul": "tordmule",
    "tordmular": "tordmule",
    "tordmularna": "tordmule",
    "tordmularnas": "tordmule",
    "tordmulars": "tordmule",
    "tordmulen": "tordmule",
    "tordmulens": "tordmule",
    "tordmules": "tordmule",
    "tordmuls": "tordmule",
    "tordyveln": "tordyvel",
    "tordyvelns": "tordyvel",
    "tordyvels": "tordyvel",
    "tordyvlar": "tordyvel",
    "tordyvlarna": "tordyvel",
    "tordyvlarnas": "tordyvel",
    "tordyvlars": "tordyvel",
    "tordönen": "tordön",
    "tordönens": "tordön",
    "tordönet": "tordön",
    "tordönets": "tordön",
    "tordöns": "tordön",
    "tordönsrösten": "tordönsröst",
    "tordönsröstens": "tordönsröst",
    "tordönsröster": "tordönsröst",
    "tordönsrösterna": "tordönsröst",
    "tordönsrösternas": "tordönsröst",
    "tordönsrösters": "tordönsröst",
    "tordönsrösts": "tordönsröst",
    "tordönsstämman": "tordönsstämma",
    "tordönsstämmans": "tordönsstämma",
    "tordönsstämmas": "tordönsstämma",
    "tordönsstämme": "tordönsstämma",
    "tordönsstämmo": "tordönsstämma",
    "tordönsstämmor": "tordönsstämma",
    "tordönsstämmorna": "tordönsstämma",
    "tordönsstämmornas": "tordönsstämma",
    "tordönsstämmors": "tordönsstämma",
    "toreadoren": "toreador",
    "toreadorens": "toreador",
    "toreadorer": "toreador",
    "toreadorerna": "toreador",
    "toreadorernas": "toreador",
    "toreadorers": "toreador",
    "toreadors": "toreador",
    "toreroer": "torero",
    "toreroerna": "torero",
    "toreroernas": "torero",
    "toreroers": "torero",
    "toreron": "torero",
    "torerons": "torero",
    "toreror": "torero",
    "torerorna": "torero",
    "torerornas": "torero",
    "torerors": "torero",
    "toreros": "torero",
    "torftiga": "torftig",
    "torftigare": "torftig",
    "torftigares": "torftig",
    "torftigas": "torftig",
    "torftigast": "torftig",
    "torftigaste": "torftig",
    "torftigastes": "torftig",
    "torftigasts": "torftig",
    "torftige": "torftig",
    "torftiges": "torftig",
    "torftigheten": "torftighet",
    "torftighetens": "torftighet",
    "torftigheter": "torftighet",
    "torftigheterna": "torftighet",
    "torftigheternas": "torftighet",
    "torftigheters": "torftighet",
    "torftighets": "torftighet",
    "torftigs": "torftig",
    "torftigt": "torftig",
    "torftigts": "torftig",
    "torgdagar": "torgdag",
    "torgdagarna": "torgdag",
    "torgdagarnas": "torgdag",
    "torgdagars": "torgdag",
    "torgdagen": "torgdag",
    "torgdagens": "torgdag",
    "torgdags": "torgdag",
    "torgen": "torg",
    "torgens": "torg",
    "torget": "torg",
    "torgets": "torg",
    "torgför": "torgföra",
    "torgförande": "torgföra",
    "torgföranden": "torgförande",
    "torgförandena": "torgförande",
    "torgförandenas": "torgförande",
    "torgförandens": "torgförande",
    "torgförandes": "torgförande",
    "torgförandet": "torgförande",
    "torgförandets": "torgförande",
    "torgföras": "torgföra",
    "torgförd": "torgföra",
    "torgförda": "torgföra",
    "torgfördas": "torgföra",
    "torgförde": "torgföra",
    "torgfördes": "torgföra",
    "torgförds": "torgföra",
    "torgföres": "torgföra",
    "torgförs": "torgföra",
    "torgfört": "torgföra",
    "torgförts": "torgföra",
    "torggum": "torggumma",
    "torggumman": "torggumma",
    "torggummans": "torggumma",
    "torggummas": "torggumma",
    "torggumme": "torggumma",
    "torggummor": "torggumma",
    "torggummorna": "torggumma",
    "torggummornas": "torggumma",
    "torggummors": "torggumma",
    "torggums": "torggumma",
    "torghandeln": "torghandel",
    "torghandelns": "torghandel",
    "torghandels": "torghandel",
    "torgmarknaden": "torgmarknad",
    "torgmarknadens": "torgmarknad",
    "torgmarknader": "torgmarknad",
    "torgmarknaderna": "torgmarknad",
    "torgmarknadernas": "torgmarknad",
    "torgmarknaders": "torgmarknad",
    "torgmarknads": "torgmarknad",
    "torgs": "torg",
    "torgskräcken": "torgskräck",
    "torgskräckens": "torgskräck",
    "torgskräcks": "torgskräck",
    "torgstånden": "torgstånd",
    "torgståndens": "torgstånd",
    "torgståndet": "torgstånd",
    "torgståndets": "torgstånd",
    "torgstånds": "torgstånd",
    "tories": "tory",
    "toriesarna": "tory",
    "toriesarnas": "tory",
    "toriet": "torium",
    "toriets": "torium",
    "toriumet": "torium",
    "toriumets": "torium",
    "toriums": "torium",
    "tork": "torka",
    "torkad": "torka",
    "torkade": "torka",
    "torkades": "torka",
    "torkads": "torka",
    "torkan": "torka",
    "torkande": "torka",
    "torkanden": "torkande",
    "torkandena": "torkande",
    "torkandenas": "torkande",
    "torkandens": "torkande",
    "torkandes": "torkande",
    "torkandet": "torkande",
    "torkandets": "torkande",
    "torkans": "torka",
    "torkar": "torka",
    "torkarbladen": "torkarblad",
    "torkarbladens": "torkarblad",
    "torkarbladet": "torkarblad",
    "torkarbladets": "torkarblad",
    "torkarblads": "torkarblad",
    "torkarna": "tork",
    "torkarnas": "tork",
    "torkars": "tork",
    "torkas": "torka",
    "torkat": "torka",
    "torkats": "torka",
    "torkblocken": "torkblock",
    "torkblockens": "torkblock",
    "torkblocket": "torkblock",
    "torkblockets": "torkblock",
    "torkblocks": "torkblock",
    "torkcentrifugen": "torkcentrifug",
    "torkcentrifugens": "torkcentrifug",
    "torkcentrifuger": "torkcentrifug",
    "torkcentrifugerna": "torkcentrifug",
    "torkcentrifugernas": "torkcentrifug",
    "torkcentrifugers": "torkcentrifug",
    "torkcentrifugs": "torkcentrifug",
    "torkdukar": "torkduk",
    "torkdukarna": "torkduk",
    "torkdukarnas": "torkduk",
    "torkdukars": "torkduk",
    "torkduken": "torkduk",
    "torkdukens": "torkduk",
    "torkduks": "torkduk",
    "torken": "tork",
    "torkens": "tork",
    "torkerier": "torkeri",
    "torkerierna": "torkeri",
    "torkeriernas": "torkeri",
    "torkeriers": "torkeri",
    "torkeriet": "torkeri",
    "torkeriets": "torkeri",
    "torkeris": "torkeri",
    "torkerit": "torkeri",
    "torkerits": "torkeri",
    "torkfläckar": "torkfläck",
    "torkfläckarna": "torkfläck",
    "torkfläckarnas": "torkfläck",
    "torkfläckars": "torkfläck",
    "torkfläcken": "torkfläck",
    "torkfläckens": "torkfläck",
    "torkfläcks": "torkfläck",
    "torkhanddukar": "torkhandduk",
    "torkhanddukarna": "torkhandduk",
    "torkhanddukarnas": "torkhandduk",
    "torkhanddukars": "torkhandduk",
    "torkhandduken": "torkhandduk",
    "torkhanddukens": "torkhandduk",
    "torkhandduks": "torkhandduk",
    "torkhuvar": "torkhuv",
    "torkhuvarna": "torkhuv",
    "torkhuvarnas": "torkhuv",
    "torkhuvars": "torkhuv",
    "torkhuven": "torkhuv",
    "torkhuvens": "torkhuv",
    "torkhuvs": "torkhuv",
    "torkkatastrofen": "torkkatastrof",
    "torkkatastrofens": "torkkatastrof",
    "torkkatastrofer": "torkkatastrof",
    "torkkatastroferna": "torkkatastrof",
    "torkkatastrofernas": "torkkatastrof",
    "torkkatastrofers": "torkkatastrof",
    "torkkatastrofs": "torkkatastrof",
    "torklin": "torklina",
    "torklinan": "torklina",
    "torklinans": "torklina",
    "torklinas": "torklina",
    "torkline": "torklina",
    "torklinor": "torklina",
    "torklinorna": "torklina",
    "torklinornas": "torklina",
    "torklinors": "torklina",
    "torklins": "torklina",
    "torklåd": "torklåda",
    "torklådan": "torklåda",
    "torklådans": "torklåda",
    "torklådas": "torklåda",
    "torklåde": "torklåda",
    "torklådor": "torklåda",
    "torklådorna": "torklåda",
    "torklådornas": "torklåda",
    "torklådors": "torklåda",
    "torklåds": "torklåda",
    "torkningar": "torkning",
    "torkningarna": "torkning",
    "torkningarnas": "torkning",
    "torkningars": "torkning",
    "torkningen": "torkning",
    "torkningens": "torkning",
    "torknings": "torkning",
    "torkpapperen": "torkpapper",
    "torkpapperens": "torkpapper",
    "torkpapperet": "torkpapper",
    "torkpapperets": "torkpapper",
    "torkpapperna": "torkpapper",
    "torkpappernas": "torkpapper",
    "torkpappers": "torkpapper",
    "torkpappren": "torkpapper",
    "torkpapprens": "torkpapper",
    "torkpappret": "torkpapper",
    "torkpapprets": "torkpapper",
    "torkperioden": "torkperiod",
    "torkperiodens": "torkperiod",
    "torkperioder": "torkperiod",
    "torkperioderna": "torkperiod",
    "torkperiodernas": "torkperiod",
    "torkperioders": "torkperiod",
    "torkperiods": "torkperiod",
    "torkrummen": "torkrum",
    "torkrummens": "torkrum",
    "torkrummet": "torkrum",
    "torkrummets": "torkrum",
    "torkrums": "torkrum",
    "torks": "tork",
    "torkskåpen": "torkskåp",
    "torkskåpens": "torkskåp",
    "torkskåpet": "torkskåp",
    "torkskåpets": "torkskåp",
    "torkskåps": "torkskåp",
    "torkstrecken": "torkstreck",
    "torkstreckens": "torkstreck",
    "torkstrecket": "torkstreck",
    "torkstreckets": "torkstreck",
    "torkstrecks": "torkstreck",
    "torkställen": "torkställ",
    "torkställens": "torkställ",
    "torkstället": "torkställ",
    "torkställets": "torkställ",
    "torkställs": "torkställ",
    "torktumlad": "torktumla",
    "torktumlade": "torktumla",
    "torktumlades": "torktumla",
    "torktumlads": "torktumla",
    "torktumlande": "torktumla",
    "torktumlanden": "torktumlande",
    "torktumlandena": "torktumlande",
    "torktumlandenas": "torktumlande",
    "torktumlandens": "torktumlande",
    "torktumlandes": "torktumlande",
    "torktumlandet": "torktumlande",
    "torktumlandets": "torktumlande",
    "torktumlar": "torktumlare",
    "torktumlaren": "torktumlare",
    "torktumlarens": "torktumlare",
    "torktumlares": "torktumlare",
    "torktumlarfilterna": "torktumlarfilter",
    "torktumlarfilternas": "torktumlarfilter",
    "torktumlarfilters": "torktumlarfilter",
    "torktumlarfiltren": "torktumlarfilter",
    "torktumlarfiltrens": "torktumlarfilter",
    "torktumlarfiltret": "torktumlarfilter",
    "torktumlarfiltrets": "torktumlarfilter",
    "torktumlarludden": "torktumlarludd",
    "torktumlarluddens": "torktumlarludd",
    "torktumlarluddet": "torktumlarludd",
    "torktumlarluddets": "torktumlarludd",
    "torktumlarludds": "torktumlarludd",
    "torktumlarna": "torktumlare",
    "torktumlarnas": "torktumlare",
    "torktumlas": "torktumla",
    "torktumlat": "torktumla",
    "torktumlats": "torktumla",
    "torkämnen": "torkämne",
    "torkämnena": "torkämne",
    "torkämnenas": "torkämne",
    "torkämnens": "torkämne",
    "torkämnes": "torkämne",
    "torkämnet": "torkämne",
    "torkämnets": "torkämne",
    "torn": "torna",
    "tornad": "torna",
    "tornade": "torna",
    "tornades": "torna",
    "tornadon": "tornado",
    "tornadons": "tornado",
    "tornador": "tornado",
    "tornadorna": "tornado",
    "tornadornas": "tornado",
    "tornadors": "tornado",
    "tornados": "tornado",
    "tornadosen": "tornado",
    "tornadosens": "tornado",
    "tornads": "torna",
    "tornande": "torna",
    "tornanden": "tornande",
    "tornandena": "tornande",
    "tornandenas": "tornande",
    "tornandens": "tornande",
    "tornandes": "tornande",
    "tornandet": "tornande",
    "tornandets": "tornande",
    "tornar": "torna",
    "tornarna": "torn",
    "tornarnas": "torn",
    "tornars": "torn",
    "tornas": "torna",
    "tornat": "torna",
    "tornats": "torna",
    "tornavslutningar": "tornavslutning",
    "tornavslutningarna": "tornavslutning",
    "tornavslutningarnas": "tornavslutning",
    "tornavslutningars": "tornavslutning",
    "tornavslutningen": "tornavslutning",
    "tornavslutningens": "tornavslutning",
    "tornavslutnings": "tornavslutning",
    "tornen": "torn",
    "tornens": "torn",
    "tornerade": "tornera",
    "tornerades": "tornera",
    "tornerande": "tornera",
    "torneranden": "tornerande",
    "tornerandena": "tornerande",
    "tornerandenas": "tornerande",
    "tornerandens": "tornerande",
    "tornerandes": "tornerande",
    "tornerandet": "tornerande",
    "tornerandets": "tornerande",
    "tornerar": "tornera",
    "torneras": "tornera",
    "tornerat": "tornera",
    "tornerats": "tornera",
    "torneringar": "tornering",
    "torneringarna": "tornering",
    "torneringarnas": "tornering",
    "torneringars": "tornering",
    "torneringen": "tornering",
    "torneringens": "tornering",
    "tornerings": "tornering",
    "tornerspelen": "tornerspel",
    "tornerspelens": "tornerspel",
    "tornerspelet": "tornerspel",
    "tornerspelets": "tornerspel",
    "tornerspels": "tornerspel",
    "tornet": "torn",
    "tornets": "torn",
    "tornfalkar": "tornfalk",
    "tornfalkarna": "tornfalk",
    "tornfalkarnas": "tornfalk",
    "tornfalkars": "tornfalk",
    "tornfalken": "tornfalk",
    "tornfalkens": "tornfalk",
    "tornfalks": "tornfalk",
    "tornfönsterna": "tornfönster",
    "tornfönsternas": "tornfönster",
    "tornfönsters": "tornfönster",
    "tornfönstren": "tornfönster",
    "tornfönstrens": "tornfönster",
    "tornfönstret": "tornfönster",
    "tornfönstrets": "tornfönster",
    "tornistern": "tornister",
    "tornisterns": "tornister",
    "tornisters": "tornister",
    "tornistrar": "tornister",
    "tornistrarna": "tornister",
    "tornistrarnas": "tornister",
    "tornistrars": "tornister",
    "torns": "torn",
    "tornseglar": "tornseglare",
    "tornseglaren": "tornseglare",
    "tornseglarens": "tornseglare",
    "tornseglares": "tornseglare",
    "tornseglarna": "tornseglare",
    "tornseglarnas": "tornseglare",
    "tornsnäck": "tornsnäcka",
    "tornsnäckan": "tornsnäcka",
    "tornsnäckans": "tornsnäcka",
    "tornsnäckas": "tornsnäcka",
    "tornsnäcke": "tornsnäcka",
    "tornsnäckor": "tornsnäcka",
    "tornsnäckorna": "tornsnäcka",
    "tornsnäckornas": "tornsnäcka",
    "tornsnäckors": "tornsnäcka",
    "tornsnäcks": "tornsnäcka",
    "tornspir": "tornspira",
    "tornspiran": "tornspira",
    "tornspirans": "tornspira",
    "tornspiras": "tornspira",
    "tornspire": "tornspira",
    "tornspiror": "tornspira",
    "tornspirorna": "tornspira",
    "tornspirornas": "tornspira",
    "tornspirors": "tornspira",
    "tornspirs": "tornspira",
    "tornsval": "tornsvala",
    "tornsvalan": "tornsvala",
    "tornsvalans": "tornsvala",
    "tornsvalas": "tornsvala",
    "tornsvale": "tornsvala",
    "tornsvalor": "tornsvala",
    "tornsvalorna": "tornsvala",
    "tornsvalornas": "tornsvala",
    "tornsvalors": "tornsvala",
    "tornsvals": "tornsvala",
    "tornugglan": "tornuggla",
    "tornugglans": "tornuggla",
    "tornugglas": "tornuggla",
    "tornuggle": "tornuggla",
    "tornugglor": "tornuggla",
    "tornugglorna": "tornuggla",
    "tornugglornas": "tornuggla",
    "tornugglors": "tornuggla",
    "tornuren": "tornur",
    "tornurens": "tornur",
    "tornuret": "tornur",
    "tornurets": "tornur",
    "tornurs": "tornur",
    "tornväktar": "tornväktare",
    "tornväktaren": "tornväktare",
    "tornväktarens": "tornväktare",
    "tornväktares": "tornväktare",
    "tornväktarna": "tornväktare",
    "tornväktarnas": "tornväktare",
    "torpar": "torpare",
    "torparen": "torpare",
    "torparens": "torpare",
    "torpares": "torpare",
    "torparna": "torpare",
    "torparnas": "torpare",
    "torpedattacken": "torpedattack",
    "torpedattackens": "torpedattack",
    "torpedattacker": "torpedattack",
    "torpedattackerna": "torpedattack",
    "torpedattackernas": "torpedattack",
    "torpedattackers": "torpedattack",
    "torpedattacks": "torpedattack",
    "torpedbåtar": "torpedbåt",
    "torpedbåtarna": "torpedbåt",
    "torpedbåtarnas": "torpedbåt",
    "torpedbåtars": "torpedbåt",
    "torpedbåten": "torpedbåt",
    "torpedbåtens": "torpedbåt",
    "torpedbåts": "torpedbåt",
    "torpeden": "torped",
    "torpedens": "torped",
    "torpeder": "torped",
    "torpederad": "torpedera",
    "torpederade": "torpedera",
    "torpederades": "torpedera",
    "torpederads": "torpedera",
    "torpederande": "torpedera",
    "torpederanden": "torpederande",
    "torpederandena": "torpederande",
    "torpederandenas": "torpederande",
    "torpederandens": "torpederande",
    "torpederandes": "torpederande",
    "torpederandet": "torpederande",
    "torpederandets": "torpederande",
    "torpederar": "torpedera",
    "torpederas": "torpedera",
    "torpederat": "torpedera",
    "torpederats": "torpedera",
    "torpederbara": "torpederbar",
    "torpederbarare": "torpederbar",
    "torpederbarares": "torpederbar",
    "torpederbaras": "torpederbar",
    "torpederbarast": "torpederbar",
    "torpederbaraste": "torpederbar",
    "torpederbarastes": "torpederbar",
    "torpederbarasts": "torpederbar",
    "torpederbare": "torpederbar",
    "torpederbares": "torpederbar",
    "torpederbarheten": "torpederbarhet",
    "torpederbarhetens": "torpederbarhet",
    "torpederbarhets": "torpederbarhet",
    "torpederbars": "torpederbar",
    "torpederbart": "torpederbar",
    "torpederbarts": "torpederbar",
    "torpederingar": "torpedering",
    "torpederingarna": "torpedering",
    "torpederingarnas": "torpedering",
    "torpederingars": "torpedering",
    "torpederingen": "torpedering",
    "torpederingens": "torpedering",
    "torpederings": "torpedering",
    "torpederna": "torped",
    "torpedernas": "torped",
    "torpeders": "torped",
    "torpedkul": "torpedkula",
    "torpedkulan": "torpedkula",
    "torpedkulans": "torpedkula",
    "torpedkulas": "torpedkula",
    "torpedkule": "torpedkula",
    "torpedkulor": "torpedkula",
    "torpedkulorna": "torpedkula",
    "torpedkulornas": "torpedkula",
    "torpedkulors": "torpedkula",
    "torpedkuls": "torpedkula",
    "torpeds": "torped",
    "torpedtuben": "torpedtub",
    "torpedtubens": "torpedtub",
    "torpedtuber": "torpedtub",
    "torpedtuberna": "torpedtub",
    "torpedtubernas": "torpedtub",
    "torpedtubers": "torpedtub",
    "torpedtubs": "torpedtub",
    "torpedövningar": "torpedövning",
    "torpedövningarna": "torpedövning",
    "torpedövningarnas": "torpedövning",
    "torpedövningars": "torpedövning",
    "torpedövningen": "torpedövning",
    "torpedövningens": "torpedövning",
    "torpedövnings": "torpedövning",
    "torpen": "torp",
    "torpens": "torp",
    "torpet": "torp",
    "torpets": "torp",
    "torpruinen": "torpruin",
    "torpruinens": "torpruin",
    "torpruiner": "torpruin",
    "torpruinerna": "torpruin",
    "torpruinernas": "torpruin",
    "torpruiners": "torpruin",
    "torpruins": "torpruin",
    "torps": "torp",
    "torpstugan": "torpstuga",
    "torpstugans": "torpstuga",
    "torpstugas": "torpstuga",
    "torpstuge": "torpstuga",
    "torpstugor": "torpstuga",
    "torpstugorna": "torpstuga",
    "torpstugornas": "torpstuga",
    "torpstugors": "torpstuga",
    "torpstugu": "torpstuga",
    "torpägar": "torpägare",
    "torpägaren": "torpägare",
    "torpägarens": "torpägare",
    "torpägares": "torpägare",
    "torpägarna": "torpägare",
    "torpägarnas": "torpägare",
    "torra": "torr",
    "torrak": "torraka",
    "torrakan": "torraka",
    "torrakans": "torraka",
    "torrakas": "torraka",
    "torrake": "torraka",
    "torrakor": "torraka",
    "torrakorna": "torraka",
    "torrakornas": "torraka",
    "torrakors": "torraka",
    "torraks": "torraka",
    "torrare": "torr",
    "torrares": "torr",
    "torras": "torr",
    "torrast": "torr",
    "torraste": "torr",
    "torrastes": "torr",
    "torrasts": "torr",
    "torrbatterier": "torrbatteri",
    "torrbatterierna": "torrbatteri",
    "torrbatteriernas": "torrbatteri",
    "torrbatteriers": "torrbatteri",
    "torrbatteriet": "torrbatteri",
    "torrbatteriets": "torrbatteri",
    "torrbatteris": "torrbatteri",
    "torrbatterit": "torrbatteri",
    "torrbatterits": "torrbatteri",
    "torrbollar": "torrboll",
    "torrbollarna": "torrboll",
    "torrbollarnas": "torrboll",
    "torrbollars": "torrboll",
    "torrbollen": "torrboll",
    "torrbollens": "torrboll",
    "torrbolls": "torrboll",
    "torrdassen": "torrdass",
    "torrdassens": "torrdass",
    "torrdasset": "torrdass",
    "torrdassets": "torrdass",
    "torrdestillationen": "torrdestillation",
    "torrdestillationens": "torrdestillation",
    "torrdestillationer": "torrdestillation",
    "torrdestillationerna": "torrdestillation",
    "torrdestillationernas": "torrdestillation",
    "torrdestillationers": "torrdestillation",
    "torrdestillations": "torrdestillation",
    "torrdestillerad": "torrdestillera",
    "torrdestillerade": "torrdestillera",
    "torrdestillerades": "torrdestillera",
    "torrdestillerads": "torrdestillera",
    "torrdestillerande": "torrdestillera",
    "torrdestilleranden": "torrdestillerande",
    "torrdestillerandena": "torrdestillerande",
    "torrdestillerandenas": "torrdestillerande",
    "torrdestillerandens": "torrdestillerande",
    "torrdestillerandes": "torrdestillerande",
    "torrdestillerandet": "torrdestillerande",
    "torrdestillerandets": "torrdestillerande",
    "torrdestillerar": "torrdestillera",
    "torrdestilleras": "torrdestillera",
    "torrdestillerat": "torrdestillera",
    "torrdestillerats": "torrdestillera",
    "torrdestillerbara": "torrdestillerbar",
    "torrdestillerbarare": "torrdestillerbar",
    "torrdestillerbarares": "torrdestillerbar",
    "torrdestillerbaras": "torrdestillerbar",
    "torrdestillerbarast": "torrdestillerbar",
    "torrdestillerbaraste": "torrdestillerbar",
    "torrdestillerbarastes": "torrdestillerbar",
    "torrdestillerbarasts": "torrdestillerbar",
    "torrdestillerbare": "torrdestillerbar",
    "torrdestillerbares": "torrdestillerbar",
    "torrdestillerbarheten": "torrdestillerbarhet",
    "torrdestillerbarhetens": "torrdestillerbarhet",
    "torrdestillerbarhets": "torrdestillerbarhet",
    "torrdestillerbars": "torrdestillerbar",
    "torrdestillerbart": "torrdestillerbar",
    "torrdestillerbarts": "torrdestillerbar",
    "torrdestilleringar": "torrdestillering",
    "torrdestilleringarna": "torrdestillering",
    "torrdestilleringarnas": "torrdestillering",
    "torrdestilleringars": "torrdestillering",
    "torrdestilleringen": "torrdestillering",
    "torrdestilleringens": "torrdestillering",
    "torrdestillerings": "torrdestillering",
    "torrdiset": "torrdis",
    "torrdisets": "torrdis",
    "torrdock": "torrdocka",
    "torrdockan": "torrdocka",
    "torrdockans": "torrdocka",
    "torrdockas": "torrdocka",
    "torrdocke": "torrdocka",
    "torrdockor": "torrdocka",
    "torrdockorna": "torrdocka",
    "torrdockornas": "torrdocka",
    "torrdockors": "torrdocka",
    "torrdocks": "torrdocka",
    "torre": "torr",
    "torrelementen": "torrelement",
    "torrelementens": "torrelement",
    "torrelementet": "torrelement",
    "torrelementets": "torrelement",
    "torrelements": "torrelement",
    "torres": "torr",
    "torrfisken": "torrfisk",
    "torrfiskens": "torrfisk",
    "torrfisks": "torrfisk",
    "torrfoders": "torrfoder",
    "torrfodret": "torrfoder",
    "torrfodrets": "torrfoder",
    "torrheten": "torrhet",
    "torrhetens": "torrhet",
    "torrhets": "torrhet",
    "torrhost": "torrhosta",
    "torrhostad": "torrhosta",
    "torrhostade": "torrhosta",
    "torrhostades": "torrhosta",
    "torrhostads": "torrhosta",
    "torrhostan": "torrhosta",
    "torrhostande": "torrhosta",
    "torrhostanden": "torrhostande",
    "torrhostandena": "torrhostande",
    "torrhostandenas": "torrhostande",
    "torrhostandens": "torrhostande",
    "torrhostandes": "torrhostande",
    "torrhostandet": "torrhostande",
    "torrhostandets": "torrhostande",
    "torrhostans": "torrhosta",
    "torrhostar": "torrhosta",
    "torrhostas": "torrhosta",
    "torrhostat": "torrhosta",
    "torrhostats": "torrhosta",
    "torrhoste": "torrhosta",
    "torrisar": "torris",
    "torrisarna": "torris",
    "torrisarnas": "torris",
    "torrisars": "torris",
    "torrisen": "torris",
    "torrisens": "torris",
    "torrjästen": "torrjäst",
    "torrjästens": "torrjäst",
    "torrjästs": "torrjäst",
    "torrklosetten": "torrklosett",
    "torrklosettens": "torrklosett",
    "torrklosetter": "torrklosett",
    "torrklosetterna": "torrklosett",
    "torrklosetternas": "torrklosett",
    "torrklosetters": "torrklosett",
    "torrklosetts": "torrklosett",
    "torrkok": "torrkoka",
    "torrkokad": "torrkoka",
    "torrkokade": "torrkoka",
    "torrkokades": "torrkoka",
    "torrkokads": "torrkoka",
    "torrkokande": "torrkoka",
    "torrkokanden": "torrkokande",
    "torrkokandena": "torrkokande",
    "torrkokandenas": "torrkokande",
    "torrkokandens": "torrkokande",
    "torrkokandes": "torrkokande",
    "torrkokandet": "torrkokande",
    "torrkokandets": "torrkokande",
    "torrkokar": "torrkoka",
    "torrkokas": "torrkoka",
    "torrkokat": "torrkoka",
    "torrkokats": "torrkoka",
    "torrkoker": "torrkoka",
    "torrkokes": "torrkoka",
    "torrkoks": "torrkoka",
    "torrkokt": "torrkoka",
    "torrkokta": "torrkoka",
    "torrkoktas": "torrkoka",
    "torrkokte": "torrkoka",
    "torrkoktes": "torrkoka",
    "torrkokts": "torrkoka",
    "torrla": "torrlägga",
    "torrladdade": "torrladdad",
    "torrladdades": "torrladdad",
    "torrladdads": "torrladdad",
    "torrladdat": "torrladdad",
    "torrladdats": "torrladdad",
    "torrlade": "torrlägga",
    "torrlades": "torrlägga",
    "torrlagd": "torrlägga",
    "torrlagda": "torrlägga",
    "torrlagdas": "torrlägga",
    "torrlagde": "torrlägga",
    "torrlagdes": "torrlägga",
    "torrlagds": "torrlägga",
    "torrlagt": "torrlägga",
    "torrlagts": "torrlägga",
    "torrlas": "torrlägga",
    "torrlägg": "torrlägga",
    "torrläggande": "torrlägga",
    "torrlägganden": "torrläggande",
    "torrläggandena": "torrläggande",
    "torrläggandenas": "torrläggande",
    "torrläggandens": "torrläggande",
    "torrläggandes": "torrläggande",
    "torrläggandet": "torrläggande",
    "torrläggandets": "torrläggande",
    "torrläggas": "torrlägga",
    "torrlägger": "torrlägga",
    "torrlägges": "torrlägga",
    "torrläggningar": "torrläggning",
    "torrläggningarna": "torrläggning",
    "torrläggningarnas": "torrläggning",
    "torrläggningars": "torrläggning",
    "torrläggningen": "torrläggning",
    "torrläggningens": "torrläggning",
    "torrläggnings": "torrläggning",
    "torrläggs": "torrlägga",
    "torrmjölken": "torrmjölk",
    "torrmjölkens": "torrmjölk",
    "torrmjölks": "torrmjölk",
    "torrnålar": "torrnål",
    "torrnålarna": "torrnål",
    "torrnålarnas": "torrnål",
    "torrnålars": "torrnål",
    "torrnålen": "torrnål",
    "torrnålens": "torrnål",
    "torrnåls": "torrnål",
    "torrnålsgravyren": "torrnålsgravyr",
    "torrnålsgravyrens": "torrnålsgravyr",
    "torrnålsgravyrs": "torrnålsgravyr",
    "torroliga": "torrolig",
    "torroligare": "torrolig",
    "torroligares": "torrolig",
    "torroligas": "torrolig",
    "torroligast": "torrolig",
    "torroligaste": "torrolig",
    "torroligastes": "torrolig",
    "torroligasts": "torrolig",
    "torrolige": "torrolig",
    "torroliges": "torrolig",
    "torroligheten": "torrolighet",
    "torrolighetens": "torrolighet",
    "torroligheter": "torrolighet",
    "torroligheterna": "torrolighet",
    "torroligheternas": "torrolighet",
    "torroligheters": "torrolighet",
    "torrolighets": "torrolighet",
    "torroligs": "torrolig",
    "torroligt": "torrolig",
    "torroligts": "torrolig",
    "torrperioden": "torrperiod",
    "torrperiodens": "torrperiod",
    "torrperioder": "torrperiod",
    "torrperioderna": "torrperiod",
    "torrperiodernas": "torrperiod",
    "torrperioders": "torrperiod",
    "torrperiods": "torrperiod",
    "torrs": "torr",
    "torrschampon": "torrschampo",
    "torrschampona": "torrschampo",
    "torrschamponas": "torrschampo",
    "torrschamponerad": "torrschamponera",
    "torrschamponerade": "torrschamponera",
    "torrschamponerades": "torrschamponera",
    "torrschamponerads": "torrschamponera",
    "torrschamponerande": "torrschamponera",
    "torrschamponeranden": "torrschamponerande",
    "torrschamponerandena": "torrschamponerande",
    "torrschamponerandenas": "torrschamponerande",
    "torrschamponerandens": "torrschamponerande",
    "torrschamponerandes": "torrschamponerande",
    "torrschamponerandet": "torrschamponerande",
    "torrschamponerandets": "torrschamponerande",
    "torrschamponerar": "torrschamponera",
    "torrschamponeras": "torrschamponera",
    "torrschamponerat": "torrschamponera",
    "torrschamponerats": "torrschamponera",
    "torrschamponerbara": "torrschamponerbar",
    "torrschamponerbarare": "torrschamponerbar",
    "torrschamponerbarares": "torrschamponerbar",
    "torrschamponerbaras": "torrschamponerbar",
    "torrschamponerbarast": "torrschamponerbar",
    "torrschamponerbaraste": "torrschamponerbar",
    "torrschamponerbarastes": "torrschamponerbar",
    "torrschamponerbarasts": "torrschamponerbar",
    "torrschamponerbare": "torrschamponerbar",
    "torrschamponerbares": "torrschamponerbar",
    "torrschamponerbarheten": "torrschamponerbarhet",
    "torrschamponerbarhetens": "torrschamponerbarhet",
    "torrschamponerbarhets": "torrschamponerbarhet",
    "torrschamponerbars": "torrschamponerbar",
    "torrschamponerbart": "torrschamponerbar",
    "torrschamponerbarts": "torrschamponerbar",
    "torrschamponeringar": "torrschamponering",
    "torrschamponeringarna": "torrschamponering",
    "torrschamponeringarnas": "torrschamponering",
    "torrschamponeringars": "torrschamponering",
    "torrschamponeringen": "torrschamponering",
    "torrschamponeringens": "torrschamponering",
    "torrschamponerings": "torrschamponering",
    "torrschampons": "torrschampo",
    "torrschampos": "torrschampo",
    "torrschampot": "torrschampo",
    "torrschampots": "torrschampo",
    "torrsimmet": "torrsim",
    "torrsimmets": "torrsim",
    "torrsims": "torrsim",
    "torrskaffningar": "torrskaffning",
    "torrskaffningarna": "torrskaffning",
    "torrskaffningarnas": "torrskaffning",
    "torrskaffningars": "torrskaffning",
    "torrskaffningen": "torrskaffning",
    "torrskaffningens": "torrskaffning",
    "torrskaffnings": "torrskaffning",
    "torrskodda": "torrskodd",
    "torrskoddare": "torrskodd",
    "torrskoddares": "torrskodd",
    "torrskoddas": "torrskodd",
    "torrskoddast": "torrskodd",
    "torrskoddaste": "torrskodd",
    "torrskoddastes": "torrskodd",
    "torrskoddasts": "torrskodd",
    "torrskodde": "torrskodd",
    "torrskoddes": "torrskodd",
    "torrskoddheten": "torrskoddhet",
    "torrskoddhetens": "torrskoddhet",
    "torrskoddhets": "torrskoddhet",
    "torrskodds": "torrskodd",
    "torrskott": "torrskodd",
    "torrskotts": "torrskodd",
    "torrslip": "torrslipa",
    "torrslipad": "torrslipa",
    "torrslipade": "torrslipa",
    "torrslipades": "torrslipa",
    "torrslipads": "torrslipa",
    "torrslipande": "torrslipa",
    "torrslipanden": "torrslipande",
    "torrslipandena": "torrslipande",
    "torrslipandenas": "torrslipande",
    "torrslipandens": "torrslipande",
    "torrslipandes": "torrslipande",
    "torrslipandet": "torrslipande",
    "torrslipandets": "torrslipande",
    "torrslipar": "torrslipa",
    "torrslipas": "torrslipa",
    "torrslipat": "torrslipa",
    "torrslipats": "torrslipa",
    "torrsprick": "torrspricka",
    "torrsprickan": "torrspricka",
    "torrsprickans": "torrspricka",
    "torrsprickas": "torrspricka",
    "torrspricke": "torrspricka",
    "torrsprickor": "torrspricka",
    "torrsprickorna": "torrspricka",
    "torrsprickornas": "torrspricka",
    "torrsprickors": "torrspricka",
    "torrspricks": "torrspricka",
    "torrspriten": "torrsprit",
    "torrspritens": "torrsprit",
    "torrsprits": "torrsprit",
    "torrsubstansen": "torrsubstans",
    "torrsubstansens": "torrsubstans",
    "torrt": "torr",
    "torrtiden": "torrtid",
    "torrtidens": "torrtid",
    "torrtider": "torrtid",
    "torrtiderna": "torrtid",
    "torrtidernas": "torrtid",
    "torrtiders": "torrtid",
    "torrtids": "torrtid",
    "torrts": "torr",
    "torrveden": "torrved",
    "torrvedens": "torrved",
    "torrveds": "torrved",
    "torrvedsstick": "torrvedssticka",
    "torrvedsstickan": "torrvedssticka",
    "torrvedsstickans": "torrvedssticka",
    "torrvedsstickas": "torrvedssticka",
    "torrvedssticke": "torrvedssticka",
    "torrvedsstickor": "torrvedssticka",
    "torrvedsstickorna": "torrvedssticka",
    "torrvedsstickornas": "torrvedssticka",
    "torrvedsstickors": "torrvedssticka",
    "torrvedssticks": "torrvedssticka",
    "torrämnes": "torrämne",
    "torrämnet": "torrämne",
    "torrämnets": "torrämne",
    "torrögda": "torrögd",
    "torrögdare": "torrögd",
    "torrögdares": "torrögd",
    "torrögdas": "torrögd",
    "torrögdast": "torrögd",
    "torrögdaste": "torrögd",
    "torrögdastes": "torrögd",
    "torrögdasts": "torrögd",
    "torrögde": "torrögd",
    "torrögdes": "torrögd",
    "torrögdheten": "torrögdhet",
    "torrögdhetens": "torrögdhet",
    "torrögdhets": "torrögdhet",
    "torrögds": "torrögd",
    "torrögt": "torrögd",
    "torrögts": "torrögd",
    "torrök": "torröka",
    "torrökande": "torröka",
    "torrökanden": "torrökande",
    "torrökandena": "torrökande",
    "torrökandenas": "torrökande",
    "torrökandens": "torrökande",
    "torrökandes": "torrökande",
    "torrökandet": "torrökande",
    "torrökandets": "torrökande",
    "torrökas": "torröka",
    "torröker": "torröka",
    "torrökes": "torröka",
    "torröks": "torröka",
    "torrökt": "torröka",
    "torrökta": "torröka",
    "torröktas": "torröka",
    "torrökte": "torröka",
    "torröktes": "torröka",
    "torrökts": "torröka",
    "torrötan": "torröta",
    "torrötans": "torröta",
    "torrötas": "torröta",
    "torröte": "torröta",
    "torsdagar": "torsdag",
    "torsdagarna": "torsdag",
    "torsdagarnas": "torsdag",
    "torsdagars": "torsdag",
    "torsdageftermiddagar": "torsdageftermiddag",
    "torsdageftermiddagarna": "torsdageftermiddag",
    "torsdageftermiddagarnas": "torsdageftermiddag",
    "torsdageftermiddagars": "torsdageftermiddag",
    "torsdageftermiddagen": "torsdageftermiddag",
    "torsdageftermiddagens": "torsdageftermiddag",
    "torsdageftermiddags": "torsdageftermiddag",
    "torsdagen": "torsdag",
    "torsdagens": "torsdag",
    "torsdagkvällar": "torsdagkväll",
    "torsdagkvällarna": "torsdagkväll",
    "torsdagkvällarnas": "torsdagkväll",
    "torsdagkvällars": "torsdagkväll",
    "torsdagkvällen": "torsdagkväll",
    "torsdagkvällens": "torsdagkväll",
    "torsdagkvälls": "torsdagkväll",
    "torsdagmorgnar": "torsdagmorgon",
    "torsdagmorgnarna": "torsdagmorgon",
    "torsdagmorgnarnas": "torsdagmorgon",
    "torsdagmorgnars": "torsdagmorgon",
    "torsdagmorgonen": "torsdagmorgon",
    "torsdagmorgonens": "torsdagmorgon",
    "torsdagmorgons": "torsdagmorgon",
    "torsdagmornar": "torsdagmorgon",
    "torsdagmornarna": "torsdagmorgon",
    "torsdagmornarnas": "torsdagmorgon",
    "torsdagmornars": "torsdagmorgon",
    "torsdags": "torsdag",
    "torsdagseftermiddagar": "torsdagseftermiddag",
    "torsdagseftermiddagarna": "torsdagseftermiddag",
    "torsdagseftermiddagarnas": "torsdagseftermiddag",
    "torsdagseftermiddagars": "torsdagseftermiddag",
    "torsdagseftermiddagen": "torsdagseftermiddag",
    "torsdagseftermiddagens": "torsdagseftermiddag",
    "torsdagseftermiddags": "torsdagseftermiddag",
    "torsdagskvällar": "torsdagskväll",
    "torsdagskvällarna": "torsdagskväll",
    "torsdagskvällarnas": "torsdagskväll",
    "torsdagskvällars": "torsdagskväll",
    "torsdagskvällen": "torsdagskväll",
    "torsdagskvällens": "torsdagskväll",
    "torsdagskvälls": "torsdagskväll",
    "torsdagsmorgnar": "torsdagsmorgon",
    "torsdagsmorgnarna": "torsdagsmorgon",
    "torsdagsmorgnarnas": "torsdagsmorgon",
    "torsdagsmorgnars": "torsdagsmorgon",
    "torsdagsmorgonen": "torsdagsmorgon",
    "torsdagsmorgonens": "torsdagsmorgon",
    "torsdagsmorgons": "torsdagsmorgon",
    "torsdagsmornar": "torsdagsmorgon",
    "torsdagsmornarna": "torsdagsmorgon",
    "torsdagsmornarnas": "torsdagsmorgon",
    "torsdagsmornars": "torsdagsmorgon",
    "torsdagstidningar": "torsdagstidning",
    "torsdagstidningarna": "torsdagstidning",
    "torsdagstidningarnas": "torsdagstidning",
    "torsdagstidningars": "torsdagstidning",
    "torsdagstidningen": "torsdagstidning",
    "torsdagstidningens": "torsdagstidning",
    "torsdagstidnings": "torsdagstidning",
    "torsdagsärterna": "torsdagsärter",
    "torsdagsärternas": "torsdagsärter",
    "torsdagsärters": "torsdagsärter",
    "torsdagsärts": "torsdagsärter",
    "torser": "torso",
    "torserna": "torso",
    "torsernas": "torso",
    "torsers": "torso",
    "torsionen": "torsion",
    "torsionens": "torsion",
    "torsioner": "torsion",
    "torsionerna": "torsion",
    "torsionernas": "torsion",
    "torsioners": "torsion",
    "torsions": "torsion",
    "torsionsfjädringar": "torsionsfjädring",
    "torsionsfjädringarna": "torsionsfjädring",
    "torsionsfjädringarnas": "torsionsfjädring",
    "torsionsfjädringars": "torsionsfjädring",
    "torsionsfjädringen": "torsionsfjädring",
    "torsionsfjädringens": "torsionsfjädring",
    "torsionsfjädrings": "torsionsfjädring",
    "torsk": "torska",
    "torskad": "torska",
    "torskade": "torska",
    "torskades": "torska",
    "torskads": "torska",
    "torskande": "torska",
    "torskanden": "torskande",
    "torskandena": "torskande",
    "torskandenas": "torskande",
    "torskandens": "torskande",
    "torskandes": "torskande",
    "torskandet": "torskande",
    "torskandets": "torskande",
    "torskar": "torska",
    "torskarna": "torsk",
    "torskarnas": "torsk",
    "torskars": "torsk",
    "torskas": "torska",
    "torskat": "torska",
    "torskats": "torska",
    "torsken": "torsk",
    "torskens": "torsk",
    "torskfiskar": "torskfisk",
    "torskfiskarna": "torskfisk",
    "torskfiskarnas": "torskfisk",
    "torskfiskars": "torskfisk",
    "torskfisken": "torskfisk",
    "torskfiskens": "torskfisk",
    "torskfisks": "torskfisk",
    "torskleveroljan": "torskleverolja",
    "torskleveroljans": "torskleverolja",
    "torskleveroljas": "torskleverolja",
    "torskleverolje": "torskleverolja",
    "torsklevertranet": "torsklevertran",
    "torsklevertranets": "torsklevertran",
    "torsklevertrans": "torsklevertran",
    "torsks": "torsk",
    "torskögas": "torsköga",
    "torskögat": "torsköga",
    "torskögats": "torsköga",
    "torskögon": "torsköga",
    "torskögonen": "torsköga",
    "torskögonens": "torsköga",
    "torskögons": "torsköga",
    "torsoer": "torso",
    "torsoerna": "torso",
    "torsoernas": "torso",
    "torsoers": "torso",
    "torson": "torso",
    "torsons": "torso",
    "torsor": "torso",
    "torsorna": "torso",
    "torsornas": "torso",
    "torsors": "torso",
    "torsos": "torso",
    "tort": "torta",
    "tortan": "torta",
    "tortans": "torta",
    "tortas": "torta",
    "torte": "torta",
    "torterad": "tortera",
    "torterade": "tortera",
    "torterades": "tortera",
    "torterads": "tortera",
    "torterande": "tortera",
    "torteranden": "torterande",
    "torterandena": "torterande",
    "torterandenas": "torterande",
    "torterandens": "torterande",
    "torterandes": "torterande",
    "torterandet": "torterande",
    "torterandets": "torterande",
    "torterar": "tortera",
    "torteras": "tortera",
    "torterat": "tortera",
    "torterats": "tortera",
    "torterbara": "torterbar",
    "torterbarare": "torterbar",
    "torterbarares": "torterbar",
    "torterbaras": "torterbar",
    "torterbarast": "torterbar",
    "torterbaraste": "torterbar",
    "torterbarastes": "torterbar",
    "torterbarasts": "torterbar",
    "torterbare": "torterbar",
    "torterbares": "torterbar",
    "torterbarheten": "torterbarhet",
    "torterbarhetens": "torterbarhet",
    "torterbarhets": "torterbarhet",
    "torterbars": "torterbar",
    "torterbart": "torterbar",
    "torterbarts": "torterbar",
    "torteringar": "tortering",
    "torteringarna": "tortering",
    "torteringarnas": "tortering",
    "torteringars": "tortering",
    "torteringen": "tortering",
    "torteringens": "tortering",
    "torterings": "tortering",
    "tortillan": "tortilla",
    "tortillans": "tortilla",
    "tortillas": "tortilla",
    "tortillasarna": "tortilla",
    "tortillasarnas": "tortilla",
    "tortillasen": "tortilla",
    "tortillasena": "tortilla",
    "tortillasenas": "tortilla",
    "tortillasens": "tortilla",
    "tortillor": "tortilla",
    "tortillorna": "tortilla",
    "tortillornas": "tortilla",
    "tortillors": "tortilla",
    "tortor": "torta",
    "tortorna": "torta",
    "tortornas": "torta",
    "tortors": "torta",
    "torts": "torta",
    "tortyranklagelsen": "tortyranklagelse",
    "tortyranklagelsens": "tortyranklagelse",
    "tortyranklagelser": "tortyranklagelse",
    "tortyranklagelserna": "tortyranklagelse",
    "tortyranklagelsernas": "tortyranklagelse",
    "tortyranklagelsers": "tortyranklagelse",
    "tortyranklagelses": "tortyranklagelse",
    "tortyren": "tortyr",
    "tortyrens": "tortyr",
    "tortyrer": "tortyr",
    "tortyrerna": "tortyr",
    "tortyrernas": "tortyr",
    "tortyrers": "tortyr",
    "tortyrkammar": "tortyrkammare",
    "tortyrkammaren": "tortyrkammare",
    "tortyrkammarens": "tortyrkammare",
    "tortyrkammares": "tortyrkammare",
    "tortyrkamrar": "tortyrkammare",
    "tortyrkamrarna": "tortyrkammare",
    "tortyrkamrarnas": "tortyrkammare",
    "tortyrkamrars": "tortyrkammare",
    "tortyrmisstänkta": "tortyrmisstänkt",
    "tortyrmisstänktas": "tortyrmisstänkt",
    "tortyrmisstänkte": "tortyrmisstänkt",
    "tortyrmisstänktes": "tortyrmisstänkt",
    "tortyrmisstänkts": "tortyrmisstänkt",
    "tortyrredskapen": "tortyrredskap",
    "tortyrredskapens": "tortyrredskap",
    "tortyrredskapet": "tortyrredskap",
    "tortyrredskapets": "tortyrredskap",
    "tortyrredskaps": "tortyrredskap",
    "tortyrs": "tortyr",
    "torv": "torva",
    "torvad": "torva",
    "torvade": "torva",
    "torvades": "torva",
    "torvads": "torva",
    "torvaktiga": "torvaktig",
    "torvaktigare": "torvaktig",
    "torvaktigares": "torvaktig",
    "torvaktigas": "torvaktig",
    "torvaktigast": "torvaktig",
    "torvaktigaste": "torvaktig",
    "torvaktigastes": "torvaktig",
    "torvaktigasts": "torvaktig",
    "torvaktige": "torvaktig",
    "torvaktiges": "torvaktig",
    "torvaktigheten": "torvaktighet",
    "torvaktighetens": "torvaktighet",
    "torvaktighets": "torvaktighet",
    "torvaktigs": "torvaktig",
    "torvaktigt": "torvaktig",
    "torvaktigts": "torvaktig",
    "torvan": "torva",
    "torvande": "torva",
    "torvanden": "torvande",
    "torvandena": "torvande",
    "torvandenas": "torvande",
    "torvandens": "torvande",
    "torvandes": "torvande",
    "torvandet": "torvande",
    "torvandets": "torvande",
    "torvans": "torva",
    "torvar": "torva",
    "torvas": "torva",
    "torvat": "torva",
    "torvats": "torva",
    "torvbriketten": "torvbrikett",
    "torvbrikettens": "torvbrikett",
    "torvbriketter": "torvbrikett",
    "torvbriketterna": "torvbrikett",
    "torvbriketternas": "torvbrikett",
    "torvbriketters": "torvbrikett",
    "torvbrikettfabriken": "torvbrikettfabrik",
    "torvbrikettfabrikens": "torvbrikettfabrik",
    "torvbrikettfabriker": "torvbrikettfabrik",
    "torvbrikettfabrikerna": "torvbrikettfabrik",
    "torvbrikettfabrikernas": "torvbrikettfabrik",
    "torvbrikettfabrikers": "torvbrikettfabrik",
    "torvbrikettfabriks": "torvbrikettfabrik",
    "torvbriketts": "torvbrikett",
    "torvdiken": "torvdike",
    "torvdikena": "torvdike",
    "torvdikenas": "torvdike",
    "torvdikens": "torvdike",
    "torvdikes": "torvdike",
    "torvdiket": "torvdike",
    "torvdikets": "torvdike",
    "torve": "torva",
    "torven": "torv",
    "torvens": "torv",
    "torvgravar": "torvgrav",
    "torvgravarna": "torvgrav",
    "torvgravarnas": "torvgrav",
    "torvgravars": "torvgrav",
    "torvgraven": "torvgrav",
    "torvgravens": "torvgrav",
    "torvgravs": "torvgrav",
    "torvjordar": "torvjord",
    "torvjordarna": "torvjord",
    "torvjordarnas": "torvjord",
    "torvjordars": "torvjord",
    "torvjorden": "torvjord",
    "torvjordens": "torvjord",
    "torvjords": "torvjord",
    "torvmoss": "torvmosse",
    "torvmossar": "torvmosse",
    "torvmossarna": "torvmosse",
    "torvmossarnas": "torvmosse",
    "torvmossars": "torvmosse",
    "torvmossen": "torvmosse",
    "torvmossens": "torvmosse",
    "torvmosses": "torvmosse",
    "torvmossfynden": "torvmossfynd",
    "torvmossfyndens": "torvmossfynd",
    "torvmossfyndet": "torvmossfynd",
    "torvmossfyndets": "torvmossfynd",
    "torvmossfynds": "torvmossfynd",
    "torvmullen": "torvmull",
    "torvmullens": "torvmull",
    "torvmulls": "torvmull",
    "torvmullsklosetten": "torvmullsklosett",
    "torvmullsklosettens": "torvmullsklosett",
    "torvmullsklosetter": "torvmullsklosett",
    "torvmullsklosetterna": "torvmullsklosett",
    "torvmullsklosetternas": "torvmullsklosett",
    "torvmullsklosetters": "torvmullsklosett",
    "torvmullsklosetts": "torvmullsklosett",
    "torvor": "torva",
    "torvorna": "torva",
    "torvornas": "torva",
    "torvors": "torva",
    "torvs": "torva",
    "torvspad": "torvspade",
    "torvspadar": "torvspade",
    "torvspadarna": "torvspade",
    "torvspadarnas": "torvspade",
    "torvspadars": "torvspade",
    "torvspaden": "torvspade",
    "torvspadens": "torvspade",
    "torvspades": "torvspade",
    "torvspads": "torvspade",
    "torvströet": "torvströ",
    "torvströets": "torvströ",
    "torvströs": "torvströ",
    "torvströt": "torvströ",
    "torvströts": "torvströ",
    "torvtaken": "torvtak",
    "torvtakens": "torvtak",
    "torvtaket": "torvtak",
    "torvtakets": "torvtak",
    "torvtaks": "torvtak",
    "torvtäck": "torvtäcka",
    "torvtäckande": "torvtäcka",
    "torvtäckanden": "torvtäckande",
    "torvtäckandena": "torvtäckande",
    "torvtäckandenas": "torvtäckande",
    "torvtäckandens": "torvtäckande",
    "torvtäckandes": "torvtäckande",
    "torvtäckandet": "torvtäckande",
    "torvtäckandets": "torvtäckande",
    "torvtäckas": "torvtäcka",
    "torvtäcker": "torvtäcka",
    "torvtäckes": "torvtäcka",
    "torvtäcks": "torvtäcka",
    "torvtäckt": "torvtäcka",
    "torvtäckta": "torvtäcka",
    "torvtäcktas": "torvtäcka",
    "torvtäckte": "torvtäcka",
    "torvtäcktes": "torvtäcka",
    "torvtäckts": "torvtäcka",
    "torvtäkten": "torvtäkt",
    "torvtäktens": "torvtäkt",
    "torvtäkter": "torvtäkt",
    "torvtäkterna": "torvtäkt",
    "torvtäkternas": "torvtäkt",
    "torvtäkters": "torvtäkt",
    "torvtäkts": "torvtäkt",
    "torvutvinningar": "torvutvinning",
    "torvutvinningarna": "torvutvinning",
    "torvutvinningarnas": "torvutvinning",
    "torvutvinningars": "torvutvinning",
    "torvutvinningen": "torvutvinning",
    "torvutvinningens": "torvutvinning",
    "torvutvinnings": "torvutvinning",
    "toryn": "tory",
    "toryns": "tory",
    "torys": "tory",
    "tos": "tosa",
    "tosan": "tosa",
    "tosans": "tosa",
    "tosas": "tosa",
    "tose": "tosa",
    "tosiga": "tosig",
    "tosigare": "tosig",
    "tosigares": "tosig",
    "tosigas": "tosig",
    "tosigast": "tosig",
    "tosigaste": "tosig",
    "tosigastes": "tosig",
    "tosigasts": "tosig",
    "tosige": "tosig",
    "tosiges": "tosig",
    "tosigheten": "tosighet",
    "tosighetens": "tosighet",
    "tosigheter": "tosighet",
    "tosigheterna": "tosighet",
    "tosigheternas": "tosighet",
    "tosigheters": "tosighet",
    "tosighets": "tosighet",
    "tosigs": "tosig",
    "tosigt": "tosig",
    "tosigts": "tosig",
    "tosingar": "tosing",
    "tosingarna": "tosing",
    "tosingarnas": "tosing",
    "tosingars": "tosing",
    "tosingen": "tosing",
    "tosingens": "tosing",
    "tosings": "tosing",
    "toskanska": "toskansk",
    "toskanskare": "toskansk",
    "toskanskares": "toskansk",
    "toskanskas": "toskansk",
    "toskanskast": "toskansk",
    "toskanskaste": "toskansk",
    "toskanskastes": "toskansk",
    "toskanskasts": "toskansk",
    "toskanske": "toskansk",
    "toskanskes": "toskansk",
    "toskansks": "toskansk",
    "toskanskt": "toskansk",
    "toskanskts": "toskansk",
    "tosken": "tosk",
    "toskens": "tosk",
    "tosker": "tosk",
    "toskerna": "tosk",
    "toskernas": "tosk",
    "toskers": "tosk",
    "tosks": "tosk",
    "tosor": "tosa",
    "tosorna": "tosa",
    "tosornas": "tosa",
    "tosors": "tosa",
    "toss": "tossa",
    "tossan": "tossa",
    "tossans": "tossa",
    "tossas": "tossa",
    "tosse": "tossa",
    "tossiga": "tossig",
    "tossigare": "tossig",
    "tossigares": "tossig",
    "tossigas": "tossig",
    "tossigast": "tossig",
    "tossigaste": "tossig",
    "tossigastes": "tossig",
    "tossigasts": "tossig",
    "tossige": "tossig",
    "tossiges": "tossig",
    "tossigheten": "tossighet",
    "tossighetens": "tossighet",
    "tossigheter": "tossighet",
    "tossigheterna": "tossighet",
    "tossigheternas": "tossighet",
    "tossigheters": "tossighet",
    "tossighets": "tossighet",
    "tossigs": "tossig",
    "tossigt": "tossig",
    "tossigts": "tossig",
    "tossor": "tossa",
    "tossorna": "tossa",
    "tossornas": "tossa",
    "tossors": "tossa",
    "totala": "total",
    "totalare": "total",
    "totalares": "total",
    "totalas": "total",
    "totalast": "total",
    "totalaste": "total",
    "totalastes": "total",
    "totalasts": "total",
    "totale": "total",
    "totales": "total",
    "totalfinansierad": "totalfinansiera",
    "totalfinansierade": "totalfinansiera",
    "totalfinansierades": "totalfinansiera",
    "totalfinansierads": "totalfinansiera",
    "totalfinansierande": "totalfinansiera",
    "totalfinansieranden": "totalfinansierande",
    "totalfinansierandena": "totalfinansierande",
    "totalfinansierandenas": "totalfinansierande",
    "totalfinansierandens": "totalfinansierande",
    "totalfinansierandes": "totalfinansierande",
    "totalfinansierandet": "totalfinansierande",
    "totalfinansierandets": "totalfinansierande",
    "totalfinansierar": "totalfinansiera",
    "totalfinansieras": "totalfinansiera",
    "totalfinansierat": "totalfinansiera",
    "totalfinansierats": "totalfinansiera",
    "totalfinansierbara": "totalfinansierbar",
    "totalfinansierbarare": "totalfinansierbar",
    "totalfinansierbarares": "totalfinansierbar",
    "totalfinansierbaras": "totalfinansierbar",
    "totalfinansierbarast": "totalfinansierbar",
    "totalfinansierbaraste": "totalfinansierbar",
    "totalfinansierbarastes": "totalfinansierbar",
    "totalfinansierbarasts": "totalfinansierbar",
    "totalfinansierbare": "totalfinansierbar",
    "totalfinansierbares": "totalfinansierbar",
    "totalfinansierbarheten": "totalfinansierbarhet",
    "totalfinansierbarhetens": "totalfinansierbarhet",
    "totalfinansierbarhets": "totalfinansierbarhet",
    "totalfinansierbars": "totalfinansierbar",
    "totalfinansierbart": "totalfinansierbar",
    "totalfinansierbarts": "totalfinansierbar",
    "totalfinansieringar": "totalfinansiering",
    "totalfinansieringarna": "totalfinansiering",
    "totalfinansieringarnas": "totalfinansiering",
    "totalfinansieringars": "totalfinansiering",
    "totalfinansieringen": "totalfinansiering",
    "totalfinansieringens": "totalfinansiering",
    "totalfinansierings": "totalfinansiering",
    "totalfotbollen": "totalfotboll",
    "totalfotbollens": "totalfotboll",
    "totalfotbolls": "totalfotboll",
    "totalförbjud": "totalförbjuda",
    "totalförbjudande": "totalförbjuda",
    "totalförbjudanden": "totalförbjudande",
    "totalförbjudandena": "totalförbjudande",
    "totalförbjudandenas": "totalförbjudande",
    "totalförbjudandens": "totalförbjudande",
    "totalförbjudandes": "totalförbjudande",
    "totalförbjudandet": "totalförbjudande",
    "totalförbjudandets": "totalförbjudande",
    "totalförbjudas": "totalförbjuda",
    "totalförbjude": "totalförbjuda",
    "totalförbjuden": "totalförbjuda",
    "totalförbjudens": "totalförbjuda",
    "totalförbjuder": "totalförbjuda",
    "totalförbjudes": "totalförbjuda",
    "totalförbjudet": "totalförbjuda",
    "totalförbjudets": "totalförbjuda",
    "totalförbjudit": "totalförbjuda",
    "totalförbjudits": "totalförbjuda",
    "totalförbjudna": "totalförbjuda",
    "totalförbjudnas": "totalförbjuda",
    "totalförbjudne": "totalförbjuda",
    "totalförbjudnes": "totalförbjuda",
    "totalförbjuds": "totalförbjuda",
    "totalförbjöd": "totalförbjuda",
    "totalförbjöde": "totalförbjuda",
    "totalförbjödes": "totalförbjuda",
    "totalförbjöds": "totalförbjuda",
    "totalförbuden": "totalförbud",
    "totalförbudens": "totalförbud",
    "totalförbudet": "totalförbud",
    "totalförbudets": "totalförbud",
    "totalförbuds": "totalförbud",
    "totalförlamad": "totalförlama",
    "totalförlamade": "totalförlama",
    "totalförlamades": "totalförlama",
    "totalförlamads": "totalförlama",
    "totalförlamande": "totalförlama",
    "totalförlamanden": "totalförlamande",
    "totalförlamandena": "totalförlamande",
    "totalförlamandenas": "totalförlamande",
    "totalförlamandens": "totalförlamande",
    "totalförlamandes": "totalförlamande",
    "totalförlamandet": "totalförlamande",
    "totalförlamandets": "totalförlamande",
    "totalförlamar": "totalförlama",
    "totalförlamas": "totalförlama",
    "totalförlamat": "totalförlama",
    "totalförlamats": "totalförlama",
    "totalförmörkelsen": "totalförmörkelse",
    "totalförmörkelsens": "totalförmörkelse",
    "totalförmörkelser": "totalförmörkelse",
    "totalförmörkelserna": "totalförmörkelse",
    "totalförmörkelsernas": "totalförmörkelse",
    "totalförmörkelsers": "totalförmörkelse",
    "totalförmörkelses": "totalförmörkelse",
    "totalförstör": "totalförstöra",
    "totalförstörande": "totalförstöra",
    "totalförstöranden": "totalförstörande",
    "totalförstörandena": "totalförstörande",
    "totalförstörandenas": "totalförstörande",
    "totalförstörandens": "totalförstörande",
    "totalförstörandes": "totalförstörande",
    "totalförstörandet": "totalförstörande",
    "totalförstörandets": "totalförstörande",
    "totalförstöras": "totalförstöra",
    "totalförstörd": "totalförstöra",
    "totalförstörda": "totalförstöra",
    "totalförstördas": "totalförstöra",
    "totalförstörde": "totalförstöra",
    "totalförstördes": "totalförstöra",
    "totalförstörds": "totalförstöra",
    "totalförstöres": "totalförstöra",
    "totalförstörs": "totalförstöra",
    "totalförstört": "totalförstöra",
    "totalförstörts": "totalförstöra",
    "totalförsvaret": "totalförsvar",
    "totalförsvarets": "totalförsvar",
    "totalförsvars": "totalförsvar",
    "totalhavererad": "totalhaverera",
    "totalhavererade": "totalhaverera",
    "totalhavererades": "totalhaverera",
    "totalhavererads": "totalhaverera",
    "totalhavererande": "totalhaverera",
    "totalhavereranden": "totalhavererande",
    "totalhavererandena": "totalhavererande",
    "totalhavererandenas": "totalhavererande",
    "totalhavererandens": "totalhavererande",
    "totalhavererandes": "totalhavererande",
    "totalhavererandet": "totalhavererande",
    "totalhavererandets": "totalhavererande",
    "totalhavererar": "totalhaverera",
    "totalhavereras": "totalhaverera",
    "totalhavererat": "totalhaverera",
    "totalhavererats": "totalhaverera",
    "totalhavereringar": "totalhaverering",
    "totalhavereringarna": "totalhaverering",
    "totalhavereringarnas": "totalhaverering",
    "totalhavereringars": "totalhaverering",
    "totalhavereringen": "totalhaverering",
    "totalhavereringens": "totalhaverering",
    "totalhavererings": "totalhaverering",
    "totalhaverier": "totalhaveri",
    "totalhaverierna": "totalhaveri",
    "totalhaveriernas": "totalhaveri",
    "totalhaveriers": "totalhaveri",
    "totalhaveriet": "totalhaveri",
    "totalhaveriets": "totalhaveri",
    "totalhaveris": "totalhaveri",
    "totalhaverit": "totalhaveri",
    "totalhaverits": "totalhaveri",
    "totalintrycket": "totalintryck",
    "totalintryckets": "totalintryck",
    "totalintrycks": "totalintryck",
    "totalisatorer": "totalisator",
    "totalisatorerna": "totalisator",
    "totalisatorernas": "totalisator",
    "totalisatorers": "totalisator",
    "totalisatorn": "totalisator",
    "totalisatorns": "totalisator",
    "totalisators": "totalisator",
    "totalitarismen": "totalitarism",
    "totalitarismens": "totalitarism",
    "totalitarismer": "totalitarism",
    "totalitarismerna": "totalitarism",
    "totalitarismernas": "totalitarism",
    "totalitarismers": "totalitarism",
    "totalitarisms": "totalitarism",
    "totalitaristiska": "totalitaristisk",
    "totalitaristiskas": "totalitaristisk",
    "totalitaristiske": "totalitaristisk",
    "totalitaristiskes": "totalitaristisk",
    "totalitaristisks": "totalitaristisk",
    "totalitaristiskt": "totalitaristisk",
    "totalitaristiskts": "totalitaristisk",
    "totaliteten": "totalitet",
    "totalitetens": "totalitet",
    "totaliteter": "totalitet",
    "totaliteterna": "totalitet",
    "totaliteternas": "totalitet",
    "totaliteters": "totalitet",
    "totalitets": "totalitet",
    "totalitetsbetydelsen": "totalitetsbetydelse",
    "totalitetsbetydelsens": "totalitetsbetydelse",
    "totalitetsbetydelses": "totalitetsbetydelse",
    "totalitära": "totalitär",
    "totalitärare": "totalitär",
    "totalitärares": "totalitär",
    "totalitäras": "totalitär",
    "totalitärast": "totalitär",
    "totalitäraste": "totalitär",
    "totalitärastes": "totalitär",
    "totalitärasts": "totalitär",
    "totalitäre": "totalitär",
    "totalitäres": "totalitär",
    "totalitärs": "totalitär",
    "totalitärt": "totalitär",
    "totalitärts": "totalitär",
    "totalkaosen": "totalkaos",
    "totalkaosens": "totalkaos",
    "totalkaoset": "totalkaos",
    "totalkaosets": "totalkaos",
    "totalreflexionen": "totalreflexion",
    "totalreflexionens": "totalreflexion",
    "totalreflexioner": "totalreflexion",
    "totalreflexionerna": "totalreflexion",
    "totalreflexionernas": "totalreflexion",
    "totalreflexioners": "totalreflexion",
    "totalreflexions": "totalreflexion",
    "totals": "total",
    "totalskuggan": "totalskugga",
    "totalskuggans": "totalskugga",
    "totalskuggas": "totalskugga",
    "totalt": "total",
    "totalts": "total",
    "totalvikten": "totalvikt",
    "totalviktens": "totalvikt",
    "totalvikter": "totalvikt",
    "totalvikterna": "totalvikt",
    "totalvikternas": "totalvikt",
    "totalvikters": "totalvikt",
    "totalvikts": "totalvikt",
    "totalvägrad": "totalvägra",
    "totalvägrade": "totalvägra",
    "totalvägrades": "totalvägra",
    "totalvägrads": "totalvägra",
    "totalvägrande": "totalvägra",
    "totalvägranden": "totalvägrande",
    "totalvägrandena": "totalvägrande",
    "totalvägrandenas": "totalvägrande",
    "totalvägrandens": "totalvägrande",
    "totalvägrandes": "totalvägrande",
    "totalvägrandet": "totalvägrande",
    "totalvägrandets": "totalvägrande",
    "totalvägrar": "totalvägra",
    "totalvägras": "totalvägra",
    "totalvägrat": "totalvägra",
    "totalvägrats": "totalvägra",
    "totalvärden": "totalvärde",
    "totalvärdena": "totalvärde",
    "totalvärdenas": "totalvärde",
    "totalvärdens": "totalvärde",
    "totalvärdes": "totalvärde",
    "totalvärdet": "totalvärde",
    "totalvärdets": "totalvärde",
    "totalytan": "totalyta",
    "totalytans": "totalyta",
    "totalytas": "totalyta",
    "totalyte": "totalyta",
    "totalytor": "totalyta",
    "totalytorna": "totalyta",
    "totalytornas": "totalyta",
    "totalytors": "totalyta",
    "totemen": "totem",
    "totemens": "totem",
    "totemet": "totem",
    "totemets": "totem",
    "totemismen": "totemism",
    "totemismens": "totemism",
    "totemismer": "totemism",
    "totemismerna": "totemism",
    "totemismernas": "totemism",
    "totemismers": "totemism",
    "totemisms": "totemism",
    "totemistiska": "totemistisk",
    "totemistiskas": "totemistisk",
    "totemistiske": "totemistisk",
    "totemistiskes": "totemistisk",
    "totemistisks": "totemistisk",
    "totemistiskt": "totemistisk",
    "totemistiskts": "totemistisk",
    "totempelar": "totempelare",
    "totempelaren": "totempelare",
    "totempelarens": "totempelare",
    "totempelares": "totempelare",
    "totempelarna": "totempelare",
    "totempelarnas": "totempelare",
    "totempål": "totempåle",
    "totempålar": "totempåle",
    "totempålarna": "totempåle",
    "totempålarnas": "totempåle",
    "totempålars": "totempåle",
    "totempålen": "totempåle",
    "totempålens": "totempåle",
    "totempåles": "totempåle",
    "totempåls": "totempåle",
    "totems": "totem",
    "totoar": "toto",
    "totoarna": "toto",
    "totoarnas": "toto",
    "totoars": "toto",
    "toton": "toto",
    "totons": "toto",
    "totos": "toto",
    "totospelen": "totospel",
    "totospelens": "totospel",
    "totospelet": "totospel",
    "totospelets": "totospel",
    "totospels": "totospel",
    "tottar": "tott",
    "tottarna": "tott",
    "tottarnas": "tott",
    "tottars": "tott",
    "totten": "tott",
    "tottens": "tott",
    "totts": "tott",
    "touch": "toucha",
    "touchad": "toucha",
    "touchade": "toucha",
    "touchades": "toucha",
    "touchads": "toucha",
    "touchande": "toucha",
    "touchanden": "touchande",
    "touchandena": "touchande",
    "touchandenas": "touchande",
    "touchandens": "touchande",
    "touchandes": "touchande",
    "touchandet": "touchande",
    "touchandets": "touchande",
    "touchar": "toucha",
    "touchas": "toucha",
    "touchat": "toucha",
    "touchats": "toucha",
    "touchen": "touche",
    "touchens": "touche",
    "toucher": "touche",
    "toucherad": "touchera",
    "toucherade": "touchera",
    "toucherades": "touchera",
    "toucherads": "touchera",
    "toucherande": "touchera",
    "toucheranden": "toucherande",
    "toucherandena": "toucherande",
    "toucherandenas": "toucherande",
    "toucherandens": "toucherande",
    "toucherandes": "toucherande",
    "toucherandet": "toucherande",
    "toucherandets": "toucherande",
    "toucherar": "touchera",
    "toucheras": "touchera",
    "toucherat": "touchera",
    "toucherats": "touchera",
    "toucherbara": "toucherbar",
    "toucherbarare": "toucherbar",
    "toucherbarares": "toucherbar",
    "toucherbaras": "toucherbar",
    "toucherbarast": "toucherbar",
    "toucherbaraste": "toucherbar",
    "toucherbarastes": "toucherbar",
    "toucherbarasts": "toucherbar",
    "toucherbare": "toucherbar",
    "toucherbares": "toucherbar",
    "toucherbarheten": "toucherbarhet",
    "toucherbarhetens": "toucherbarhet",
    "toucherbarhets": "toucherbarhet",
    "toucherbars": "toucherbar",
    "toucherbart": "toucherbar",
    "toucherbarts": "toucherbar",
    "toucheringar": "touchering",
    "toucheringarna": "touchering",
    "toucheringarnas": "touchering",
    "toucheringars": "touchering",
    "toucheringen": "touchering",
    "toucheringens": "touchering",
    "toucherings": "touchering",
    "toucherna": "touche",
    "touchernas": "touche",
    "touchers": "touche",
    "touches": "touche",
    "touchmetoden": "touchmetod",
    "touchmetodens": "touchmetod",
    "touchmetods": "touchmetod",
    "touperad": "toupera",
    "touperade": "toupera",
    "touperades": "toupera",
    "touperads": "toupera",
    "touperande": "toupera",
    "touperanden": "touperande",
    "touperandena": "touperande",
    "touperandenas": "touperande",
    "touperandens": "touperande",
    "touperandes": "touperande",
    "touperandet": "touperande",
    "touperandets": "touperande",
    "touperar": "toupera",
    "touperas": "toupera",
    "touperat": "toupera",
    "touperats": "toupera",
    "touperbara": "touperbar",
    "touperbarare": "touperbar",
    "touperbarares": "touperbar",
    "touperbaras": "touperbar",
    "touperbarast": "touperbar",
    "touperbaraste": "touperbar",
    "touperbarastes": "touperbar",
    "touperbarasts": "touperbar",
    "touperbare": "touperbar",
    "touperbares": "touperbar",
    "touperbarheten": "touperbarhet",
    "touperbarhetens": "touperbarhet",
    "touperbarhets": "touperbarhet",
    "touperbars": "touperbar",
    "touperbart": "touperbar",
    "touperbarts": "touperbar",
    "touperingar": "toupering",
    "touperingarna": "toupering",
    "touperingarnas": "toupering",
    "touperingars": "toupering",
    "touperingen": "toupering",
    "touperingens": "toupering",
    "touperings": "toupering",
    "toupéer": "toupé",
    "toupéerna": "toupé",
    "toupéernas": "toupé",
    "toupéers": "toupé",
    "toupén": "toupé",
    "toupéns": "toupé",
    "toupés": "toupé",
    "touren": "tour",
    "tourens": "tour",
    "tourer": "tour",
    "tourerna": "tour",
    "tourernas": "tour",
    "tourers": "tour",
    "tournedosen": "tournedos",
    "tournedosens": "tournedos",
    "tournedoser": "tournedos",
    "tournedoserna": "tournedos",
    "tournedosernas": "tournedos",
    "tournedosers": "tournedos",
    "tours": "tour",
    "tov": "tova",
    "tovad": "tova",
    "tovade": "tova",
    "tovades": "tova",
    "tovads": "tova",
    "tovan": "tova",
    "tovande": "tova",
    "tovanden": "tovande",
    "tovandena": "tovande",
    "tovandenas": "tovande",
    "tovandens": "tovande",
    "tovandes": "tovande",
    "tovandet": "tovande",
    "tovandets": "tovande",
    "tovans": "tova",
    "tovar": "tova",
    "tovas": "tova",
    "tovat": "tova",
    "tovats": "tova",
    "tove": "tova",
    "toviga": "tovig",
    "tovigare": "tovig",
    "tovigares": "tovig",
    "tovigas": "tovig",
    "tovigast": "tovig",
    "tovigaste": "tovig",
    "tovigastes": "tovig",
    "tovigasts": "tovig",
    "tovige": "tovig",
    "toviges": "tovig",
    "tovigs": "tovig",
    "tovigt": "tovig",
    "tovigts": "tovig",
    "tovor": "tova",
    "tovorna": "tova",
    "tovornas": "tova",
    "tovors": "tova",
    "tovs": "tova",
    "toxafener": "toxafen",
    "toxafenerna": "toxafen",
    "toxafenernas": "toxafen",
    "toxafeners": "toxafen",
    "toxafenet": "toxafen",
    "toxafenets": "toxafen",
    "toxafens": "toxafen",
    "toxiciteten": "toxicitet",
    "toxicitetens": "toxicitet",
    "toxiciteter": "toxicitet",
    "toxiciteterna": "toxicitet",
    "toxiciteternas": "toxicitet",
    "toxiciteters": "toxicitet",
    "toxicitets": "toxicitet",
    "toxikologien": "toxikologi",
    "toxikologiens": "toxikologi",
    "toxikologin": "toxikologi",
    "toxikologins": "toxikologi",
    "toxikologis": "toxikologi",
    "toxikologiska": "toxikologisk",
    "toxikologiskare": "toxikologisk",
    "toxikologiskares": "toxikologisk",
    "toxikologiskas": "toxikologisk",
    "toxikologiskast": "toxikologisk",
    "toxikologiskaste": "toxikologisk",
    "toxikologiskastes": "toxikologisk",
    "toxikologiskasts": "toxikologisk",
    "toxikologiske": "toxikologisk",
    "toxikologiskes": "toxikologisk",
    "toxikologisks": "toxikologisk",
    "toxikologiskt": "toxikologisk",
    "toxikologiskts": "toxikologisk",
    "toxikomanien": "toxikomani",
    "toxikomaniens": "toxikomani",
    "toxikomanin": "toxikomani",
    "toxikomanins": "toxikomani",
    "toxikomanis": "toxikomani",
    "toxinen": "toxin",
    "toxinens": "toxin",
    "toxinet": "toxin",
    "toxinets": "toxin",
    "toxins": "toxin",
    "toxiska": "toxisk",
    "toxiskare": "toxisk",
    "toxiskares": "toxisk",
    "toxiskas": "toxisk",
    "toxiskast": "toxisk",
    "toxiskaste": "toxisk",
    "toxiskastes": "toxisk",
    "toxiskasts": "toxisk",
    "toxiske": "toxisk",
    "toxiskes": "toxisk",
    "toxisks": "toxisk",
    "toxiskt": "toxisk",
    "toxiskts": "toxisk",
    "trackad": "tracka",
    "trackade": "tracka",
    "trackades": "tracka",
    "trackads": "tracka",
    "trackande": "tracka",
    "trackanden": "trackande",
    "trackandena": "trackande",
    "trackandenas": "trackande",
    "trackandens": "trackande",
    "trackandes": "trackande",
    "trackandet": "trackande",
    "trackandets": "trackande",
    "trackar": "tracka",
    "trackas": "tracka",
    "trackat": "tracka",
    "trackats": "tracka",
    "traden": "trad",
    "tradens": "trad",
    "trader": "trad",
    "traderad": "tradera",
    "traderade": "tradera",
    "traderades": "tradera",
    "traderads": "tradera",
    "traderande": "tradera",
    "traderanden": "traderande",
    "traderandena": "traderande",
    "traderandenas": "traderande",
    "traderandens": "traderande",
    "traderandes": "traderande",
    "traderandet": "traderande",
    "traderandets": "traderande",
    "traderar": "tradera",
    "traderas": "tradera",
    "traderat": "tradera",
    "traderats": "tradera",
    "traderbara": "traderbar",
    "traderbarare": "traderbar",
    "traderbarares": "traderbar",
    "traderbaras": "traderbar",
    "traderbarast": "traderbar",
    "traderbaraste": "traderbar",
    "traderbarastes": "traderbar",
    "traderbarasts": "traderbar",
    "traderbare": "traderbar",
    "traderbares": "traderbar",
    "traderbarheten": "traderbarhet",
    "traderbarhetens": "traderbarhet",
    "traderbarhets": "traderbarhet",
    "traderbars": "traderbar",
    "traderbart": "traderbar",
    "traderbarts": "traderbar",
    "traderingar": "tradering",
    "traderingarna": "tradering",
    "traderingarnas": "tradering",
    "traderingars": "tradering",
    "traderingen": "tradering",
    "traderingens": "tradering",
    "traderings": "tradering",
    "traderna": "trad",
    "tradernas": "trad",
    "traders": "trad",
    "tradiga": "tradig",
    "tradigare": "tradig",
    "tradigares": "tradig",
    "tradigas": "tradig",
    "tradigast": "tradig",
    "tradigaste": "tradig",
    "tradigastes": "tradig",
    "tradigasts": "tradig",
    "tradige": "tradig",
    "tradiges": "tradig",
    "tradigs": "tradig",
    "tradigt": "tradig",
    "tradigts": "tradig",
    "traditionalismen": "traditionalism",
    "traditionalismens": "traditionalism",
    "traditionalismer": "traditionalism",
    "traditionalismerna": "traditionalism",
    "traditionalismernas": "traditionalism",
    "traditionalismers": "traditionalism",
    "traditionalisms": "traditionalism",
    "traditionalisten": "traditionalist",
    "traditionalistens": "traditionalist",
    "traditionalister": "traditionalist",
    "traditionalisterna": "traditionalist",
    "traditionalisternas": "traditionalist",
    "traditionalisters": "traditionalist",
    "traditionalistiska": "traditionalistisk",
    "traditionalistiskas": "traditionalistisk",
    "traditionalistiske": "traditionalistisk",
    "traditionalistiskes": "traditionalistisk",
    "traditionalistisks": "traditionalistisk",
    "traditionalistiskt": "traditionalistisk",
    "traditionalistiskts": "traditionalistisk",
    "traditionalists": "traditionalist",
    "traditionella": "traditionell",
    "traditionellare": "traditionell",
    "traditionellares": "traditionell",
    "traditionellas": "traditionell",
    "traditionellast": "traditionell",
    "traditionellaste": "traditionell",
    "traditionellastes": "traditionell",
    "traditionellasts": "traditionell",
    "traditionelle": "traditionell",
    "traditionelles": "traditionell",
    "traditionells": "traditionell",
    "traditionellt": "traditionell",
    "traditionellts": "traditionell",
    "traditionen": "tradition",
    "traditionens": "tradition",
    "traditioner": "tradition",
    "traditionerna": "tradition",
    "traditionernas": "tradition",
    "traditioners": "tradition",
    "traditions": "tradition",
    "traditionsbrotten": "traditionsbrott",
    "traditionsbrottens": "traditionsbrott",
    "traditionsbrottet": "traditionsbrott",
    "traditionsbrottets": "traditionsbrott",
    "traditionsbrotts": "traditionsbrott",
    "traditionsbundens": "traditionsbunden",
    "traditionsbundet": "traditionsbunden",
    "traditionsbundets": "traditionsbunden",
    "traditionsbundna": "traditionsbunden",
    "traditionsbundnare": "traditionsbunden",
    "traditionsbundnares": "traditionsbunden",
    "traditionsbundnas": "traditionsbunden",
    "traditionsbundnast": "traditionsbunden",
    "traditionsbundnaste": "traditionsbunden",
    "traditionsbundnastes": "traditionsbunden",
    "traditionsbundnasts": "traditionsbunden",
    "traditionsbundne": "traditionsbunden",
    "traditionsbundnes": "traditionsbunden",
    "traditionsbärar": "traditionsbärare",
    "traditionsbäraren": "traditionsbärare",
    "traditionsbärarens": "traditionsbärare",
    "traditionsbärares": "traditionsbärare",
    "traditionsbärarna": "traditionsbärare",
    "traditionsbärarnas": "traditionsbärare",
    "traditionsenliga": "traditionsenlig",
    "traditionsenligare": "traditionsenlig",
    "traditionsenligares": "traditionsenlig",
    "traditionsenligas": "traditionsenlig",
    "traditionsenligast": "traditionsenlig",
    "traditionsenligaste": "traditionsenlig",
    "traditionsenligastes": "traditionsenlig",
    "traditionsenligasts": "traditionsenlig",
    "traditionsenlige": "traditionsenlig",
    "traditionsenliges": "traditionsenlig",
    "traditionsenligheten": "traditionsenlighet",
    "traditionsenlighetens": "traditionsenlighet",
    "traditionsenlighets": "traditionsenlighet",
    "traditionsenligs": "traditionsenlig",
    "traditionsenligt": "traditionsenlig",
    "traditionsenligts": "traditionsenlig",
    "traditionsrika": "traditionsrik",
    "traditionsrikare": "traditionsrik",
    "traditionsrikares": "traditionsrik",
    "traditionsrikas": "traditionsrik",
    "traditionsrikast": "traditionsrik",
    "traditionsrikaste": "traditionsrik",
    "traditionsrikastes": "traditionsrik",
    "traditionsrikasts": "traditionsrik",
    "traditionsrike": "traditionsrik",
    "traditionsrikes": "traditionsrik",
    "traditionsriks": "traditionsrik",
    "traditionsrikt": "traditionsrik",
    "traditionsrikts": "traditionsrik",
    "tradjazzen": "tradjazz",
    "tradjazzens": "tradjazz",
    "trads": "trad",
    "traffickingen": "trafficking",
    "traffickingens": "trafficking",
    "traffickings": "trafficking",
    "trafikabels": "trafikabel",
    "trafikabelt": "trafikabel",
    "trafikabelts": "trafikabel",
    "trafikabla": "trafikabel",
    "trafikablare": "trafikabel",
    "trafikablares": "trafikabel",
    "trafikablas": "trafikabel",
    "trafikablast": "trafikabel",
    "trafikablaste": "trafikabel",
    "trafikablastes": "trafikabel",
    "trafikablasts": "trafikabel",
    "trafikable": "trafikabel",
    "trafikables": "trafikabel",
    "trafikanten": "trafikant",
    "trafikantens": "trafikant",
    "trafikanter": "trafikant",
    "trafikanterna": "trafikant",
    "trafikanternas": "trafikant",
    "trafikanters": "trafikant",
    "trafikants": "trafikant",
    "trafikbruset": "trafikbrus",
    "trafikbrusets": "trafikbrus",
    "trafikbullers": "trafikbuller",
    "trafikbullret": "trafikbuller",
    "trafikbullrets": "trafikbuller",
    "trafikdelar": "trafikdelare",
    "trafikdelaren": "trafikdelare",
    "trafikdelarens": "trafikdelare",
    "trafikdelares": "trafikdelare",
    "trafikdelarna": "trafikdelare",
    "trafikdelarnas": "trafikdelare",
    "trafikdödade": "trafikdödad",
    "trafikdödades": "trafikdödad",
    "trafikdödads": "trafikdödad",
    "trafikdödat": "trafikdödad",
    "trafikdödats": "trafikdödad",
    "trafikdöden": "trafikdöd",
    "trafikdödens": "trafikdöd",
    "trafikdöds": "trafikdöd",
    "trafiken": "trafik",
    "trafikens": "trafik",
    "trafikerad": "trafikera",
    "trafikerade": "trafikera",
    "trafikerades": "trafikera",
    "trafikerads": "trafikera",
    "trafikerande": "trafikera",
    "trafikeranden": "trafikerande",
    "trafikerandena": "trafikerande",
    "trafikerandenas": "trafikerande",
    "trafikerandens": "trafikerande",
    "trafikerandes": "trafikerande",
    "trafikerandet": "trafikerande",
    "trafikerandets": "trafikerande",
    "trafikerar": "trafikera",
    "trafikeras": "trafikera",
    "trafikerat": "trafikera",
    "trafikerats": "trafikera",
    "trafikerbara": "trafikerbar",
    "trafikerbarare": "trafikerbar",
    "trafikerbarares": "trafikerbar",
    "trafikerbaras": "trafikerbar",
    "trafikerbarast": "trafikerbar",
    "trafikerbaraste": "trafikerbar",
    "trafikerbarastes": "trafikerbar",
    "trafikerbarasts": "trafikerbar",
    "trafikerbare": "trafikerbar",
    "trafikerbares": "trafikerbar",
    "trafikerbarheten": "trafikerbarhet",
    "trafikerbarhetens": "trafikerbarhet",
    "trafikerbarhets": "trafikerbarhet",
    "trafikerbars": "trafikerbar",
    "trafikerbart": "trafikerbar",
    "trafikerbarts": "trafikerbar",
    "trafikeringar": "trafikering",
    "trafikeringarna": "trafikering",
    "trafikeringarnas": "trafikering",
    "trafikeringars": "trafikering",
    "trafikeringen": "trafikering",
    "trafikeringens": "trafikering",
    "trafikerings": "trafikering",
    "trafikexperten": "trafikexpert",
    "trafikexpertens": "trafikexpert",
    "trafikexperter": "trafikexpert",
    "trafikexperterna": "trafikexpert",
    "trafikexperternas": "trafikexpert",
    "trafikexperters": "trafikexpert",
    "trafikexperts": "trafikexpert",
    "trafikfarliga": "trafikfarlig",
    "trafikfarligare": "trafikfarlig",
    "trafikfarligares": "trafikfarlig",
    "trafikfarligas": "trafikfarlig",
    "trafikfarligast": "trafikfarlig",
    "trafikfarligaste": "trafikfarlig",
    "trafikfarligastes": "trafikfarlig",
    "trafikfarligasts": "trafikfarlig",
    "trafikfarlige": "trafikfarlig",
    "trafikfarliges": "trafikfarlig",
    "trafikfarligheten": "trafikfarlighet",
    "trafikfarlighetens": "trafikfarlighet",
    "trafikfarlighets": "trafikfarlighet",
    "trafikfarligs": "trafikfarlig",
    "trafikfarligt": "trafikfarlig",
    "trafikfarligts": "trafikfarlig",
    "trafikflygar": "trafikflygare",
    "trafikflygaren": "trafikflygare",
    "trafikflygarens": "trafikflygare",
    "trafikflygares": "trafikflygare",
    "trafikflygarna": "trafikflygare",
    "trafikflygarnas": "trafikflygare",
    "trafikflyget": "trafikflyg",
    "trafikflygets": "trafikflyg",
    "trafikflygplanen": "trafikflygplan",
    "trafikflygplanens": "trafikflygplan",
    "trafikflygplanet": "trafikflygplan",
    "trafikflygplanets": "trafikflygplan",
    "trafikflygplans": "trafikflygplan",
    "trafikflygs": "trafikflyg",
    "trafikfyrar": "trafikfyr",
    "trafikfyrarna": "trafikfyr",
    "trafikfyrarnas": "trafikfyr",
    "trafikfyrars": "trafikfyr",
    "trafikfyren": "trafikfyr",
    "trafikfyrens": "trafikfyr",
    "trafikfyrs": "trafikfyr",
    "trafikförsäkringar": "trafikförsäkring",
    "trafikförsäkringarna": "trafikförsäkring",
    "trafikförsäkringarnas": "trafikförsäkring",
    "trafikförsäkringars": "trafikförsäkring",
    "trafikförsäkringen": "trafikförsäkring",
    "trafikförsäkringens": "trafikförsäkring",
    "trafikförsäkrings": "trafikförsäkring",
    "trafikkontrollen": "trafikkontroll",
    "trafikkontrollens": "trafikkontroll",
    "trafikkontroller": "trafikkontroll",
    "trafikkontrollerna": "trafikkontroll",
    "trafikkontrollernas": "trafikkontroll",
    "trafikkontrollers": "trafikkontroll",
    "trafikkontrolls": "trafikkontroll",
    "trafikkorten": "trafikkort",
    "trafikkortens": "trafikkort",
    "trafikkortet": "trafikkort",
    "trafikkortets": "trafikkort",
    "trafikkorts": "trafikkort",
    "trafikledar": "trafikledare",
    "trafikledaren": "trafikledare",
    "trafikledarens": "trafikledare",
    "trafikledares": "trafikledare",
    "trafikledarna": "trafikledare",
    "trafikledarnas": "trafikledare",
    "trafikleden": "trafikled",
    "trafikledens": "trafikled",
    "trafikleder": "trafikled",
    "trafiklederna": "trafikled",
    "trafikledernas": "trafikled",
    "trafikleders": "trafikled",
    "trafikleds": "trafikled",
    "trafikljusen": "trafikljus",
    "trafikljusens": "trafikljus",
    "trafikljuset": "trafikljus",
    "trafikljusets": "trafikljus",
    "trafiklägen": "trafikläge",
    "trafiklägena": "trafikläge",
    "trafiklägenas": "trafikläge",
    "trafiklägens": "trafikläge",
    "trafikläges": "trafikläge",
    "trafikläget": "trafikläge",
    "trafiklägets": "trafikläge",
    "trafikmärken": "trafikmärke",
    "trafikmärkena": "trafikmärke",
    "trafikmärkenas": "trafikmärke",
    "trafikmärkens": "trafikmärke",
    "trafikmärkes": "trafikmärke",
    "trafikmärket": "trafikmärke",
    "trafikmärkets": "trafikmärke",
    "trafikmässiga": "trafikmässig",
    "trafikmässigare": "trafikmässig",
    "trafikmässigares": "trafikmässig",
    "trafikmässigas": "trafikmässig",
    "trafikmässigast": "trafikmässig",
    "trafikmässigaste": "trafikmässig",
    "trafikmässigastes": "trafikmässig",
    "trafikmässigasts": "trafikmässig",
    "trafikmässige": "trafikmässig",
    "trafikmässiges": "trafikmässig",
    "trafikmässigs": "trafikmässig",
    "trafikmässigt": "trafikmässig",
    "trafikmässigts": "trafikmässig",
    "trafikolyck": "trafikolycka",
    "trafikolyckan": "trafikolycka",
    "trafikolyckans": "trafikolycka",
    "trafikolyckas": "trafikolycka",
    "trafikolycke": "trafikolycka",
    "trafikolyckor": "trafikolycka",
    "trafikolyckorna": "trafikolycka",
    "trafikolyckornas": "trafikolycka",
    "trafikolyckors": "trafikolycka",
    "trafikolycks": "trafikolycka",
    "trafikpiloten": "trafikpilot",
    "trafikpilotens": "trafikpilot",
    "trafikpiloter": "trafikpilot",
    "trafikpiloterna": "trafikpilot",
    "trafikpiloternas": "trafikpilot",
    "trafikpiloters": "trafikpilot",
    "trafikpilots": "trafikpilot",
    "trafikplatsen": "trafikplats",
    "trafikplatsens": "trafikplats",
    "trafikplatser": "trafikplats",
    "trafikplatserna": "trafikplats",
    "trafikplatsernas": "trafikplats",
    "trafikplatsers": "trafikplats",
    "trafikpolitiken": "trafikpolitik",
    "trafikpolitikens": "trafikpolitik",
    "trafikpolitiks": "trafikpolitik",
    "trafikpolitiska": "trafikpolitisk",
    "trafikpolitiskas": "trafikpolitisk",
    "trafikpolitiske": "trafikpolitisk",
    "trafikpolitiskes": "trafikpolitisk",
    "trafikpolitisks": "trafikpolitisk",
    "trafikpolitiskt": "trafikpolitisk",
    "trafikpolitiskts": "trafikpolitisk",
    "trafikpulsådern": "trafikpulsåder",
    "trafikpulsåderns": "trafikpulsåder",
    "trafikpulsåders": "trafikpulsåder",
    "trafikregeln": "trafikregel",
    "trafikregelns": "trafikregel",
    "trafikregels": "trafikregel",
    "trafikregler": "trafikregel",
    "trafikreglerad": "trafikreglera",
    "trafikreglerade": "trafikreglera",
    "trafikreglerades": "trafikreglera",
    "trafikreglerads": "trafikreglera",
    "trafikreglerande": "trafikreglera",
    "trafikregleranden": "trafikreglerande",
    "trafikreglerandena": "trafikreglerande",
    "trafikreglerandenas": "trafikreglerande",
    "trafikreglerandens": "trafikreglerande",
    "trafikreglerandes": "trafikreglerande",
    "trafikreglerandet": "trafikreglerande",
    "trafikreglerandets": "trafikreglerande",
    "trafikreglerar": "trafikreglera",
    "trafikregleras": "trafikreglera",
    "trafikreglerat": "trafikreglera",
    "trafikreglerats": "trafikreglera",
    "trafikreglerbara": "trafikreglerbar",
    "trafikreglerbarare": "trafikreglerbar",
    "trafikreglerbarares": "trafikreglerbar",
    "trafikreglerbaras": "trafikreglerbar",
    "trafikreglerbarast": "trafikreglerbar",
    "trafikreglerbaraste": "trafikreglerbar",
    "trafikreglerbarastes": "trafikreglerbar",
    "trafikreglerbarasts": "trafikreglerbar",
    "trafikreglerbare": "trafikreglerbar",
    "trafikreglerbares": "trafikreglerbar",
    "trafikreglerbarheten": "trafikreglerbarhet",
    "trafikreglerbarhetens": "trafikreglerbarhet",
    "trafikreglerbarhets": "trafikreglerbarhet",
    "trafikreglerbars": "trafikreglerbar",
    "trafikreglerbart": "trafikreglerbar",
    "trafikreglerbarts": "trafikreglerbar",
    "trafikregleringar": "trafikreglering",
    "trafikregleringarna": "trafikreglering",
    "trafikregleringarnas": "trafikreglering",
    "trafikregleringars": "trafikreglering",
    "trafikregleringen": "trafikreglering",
    "trafikregleringens": "trafikreglering",
    "trafikreglerings": "trafikreglering",
    "trafikreglerna": "trafikregel",
    "trafikreglernas": "trafikregel",
    "trafikreglers": "trafikregel",
    "trafiks": "trafik",
    "trafiksignalen": "trafiksignal",
    "trafiksignalens": "trafiksignal",
    "trafiksignaler": "trafiksignal",
    "trafiksignalerna": "trafiksignal",
    "trafiksignalernas": "trafiksignal",
    "trafiksignalers": "trafiksignal",
    "trafiksignals": "trafiksignal",
    "trafiksituationen": "trafiksituation",
    "trafiksituationens": "trafiksituation",
    "trafiksituationer": "trafiksituation",
    "trafiksituationerna": "trafiksituation",
    "trafiksituationernas": "trafiksituation",
    "trafiksituationers": "trafiksituation",
    "trafiksituations": "trafiksituation",
    "trafikstockningar": "trafikstockning",
    "trafikstockningarna": "trafikstockning",
    "trafikstockningarnas": "trafikstockning",
    "trafikstockningars": "trafikstockning",
    "trafikstockningen": "trafikstockning",
    "trafikstockningens": "trafikstockning",
    "trafikstocknings": "trafikstockning",
    "trafiksäkerheten": "trafiksäkerhet",
    "trafiksäkerhetens": "trafiksäkerhet",
    "trafiksäkerheter": "trafiksäkerhet",
    "trafiksäkerheterna": "trafiksäkerhet",
    "trafiksäkerheternas": "trafiksäkerhet",
    "trafiksäkerheters": "trafiksäkerhet",
    "trafiksäkerhets": "trafiksäkerhet",
    "trafiksäkerhetschefen": "trafiksäkerhetschef",
    "trafiksäkerhetschefens": "trafiksäkerhetschef",
    "trafiksäkerhetschefer": "trafiksäkerhetschef",
    "trafiksäkerhetscheferna": "trafiksäkerhetschef",
    "trafiksäkerhetschefernas": "trafiksäkerhetschef",
    "trafiksäkerhetschefers": "trafiksäkerhetschef",
    "trafiksäkerhetschefs": "trafiksäkerhetschef",
    "trafiksäkerhetsmässiga": "trafiksäkerhetsmässig",
    "trafiksäkerhetsmässigare": "trafiksäkerhetsmässig",
    "trafiksäkerhetsmässigares": "trafiksäkerhetsmässig",
    "trafiksäkerhetsmässigas": "trafiksäkerhetsmässig",
    "trafiksäkerhetsmässigast": "trafiksäkerhetsmässig",
    "trafiksäkerhetsmässigaste": "trafiksäkerhetsmässig",
    "trafiksäkerhetsmässigastes": "trafiksäkerhetsmässig",
    "trafiksäkerhetsmässigasts": "trafiksäkerhetsmässig",
    "trafiksäkerhetsmässige": "trafiksäkerhetsmässig",
    "trafiksäkerhetsmässiges": "trafiksäkerhetsmässig",
    "trafiksäkerhetsmässigs": "trafiksäkerhetsmässig",
    "trafiksäkerhetsmässigt": "trafiksäkerhetsmässig",
    "trafiksäkerhetsmässigts": "trafiksäkerhetsmässig",
    "trafiksäkerhetsverken": "trafiksäkerhetsverk",
    "trafiksäkerhetsverkens": "trafiksäkerhetsverk",
    "trafiksäkerhetsverket": "trafiksäkerhetsverk",
    "trafiksäkerhetsverks": "trafiksäkerhetsverk",
    "trafiksäkers": "trafiksäker",
    "trafiksäkert": "trafiksäker",
    "trafiksäkerts": "trafiksäker",
    "trafiksäkra": "trafiksäker",
    "trafiksäkrare": "trafiksäker",
    "trafiksäkrares": "trafiksäker",
    "trafiksäkras": "trafiksäker",
    "trafiksäkrast": "trafiksäker",
    "trafiksäkraste": "trafiksäker",
    "trafiksäkrastes": "trafiksäker",
    "trafiksäkrasts": "trafiksäker",
    "trafiksäkre": "trafiksäker",
    "trafiksäkres": "trafiksäker",
    "trafiktillstånden": "trafiktillstånd",
    "trafiktillståndens": "trafiktillstånd",
    "trafiktillståndet": "trafiktillstånd",
    "trafiktillståndets": "trafiktillstånd",
    "trafiktillstånds": "trafiktillstånd",
    "trafikvakten": "trafikvakt",
    "trafikvaktens": "trafikvakt",
    "trafikvakter": "trafikvakt",
    "trafikvakterna": "trafikvakt",
    "trafikvakternas": "trafikvakt",
    "trafikvakters": "trafikvakt",
    "trafikvakts": "trafikvakt",
    "tragedien": "tragedi",
    "tragediennen": "tragedienn",
    "tragediennens": "tragedienn",
    "tragedienner": "tragedienn",
    "tragediennerna": "tragedienn",
    "tragediennernas": "tragedienn",
    "tragedienners": "tragedienn",
    "tragedienns": "tragedienn",
    "tragediens": "tragedi",
    "tragedier": "tragedi",
    "tragedierna": "tragedi",
    "tragediernas": "tragedi",
    "tragediers": "tragedi",
    "tragediförfattar": "tragediförfattare",
    "tragediförfattaren": "tragediförfattare",
    "tragediförfattarens": "tragediförfattare",
    "tragediförfattares": "tragediförfattare",
    "tragediförfattarna": "tragediförfattare",
    "tragediförfattarnas": "tragediförfattare",
    "tragedin": "tragedi",
    "tragedins": "tragedi",
    "tragedis": "tragedi",
    "traggel": "traggla",
    "traggels": "traggel",
    "tragglad": "traggla",
    "tragglade": "traggla",
    "tragglades": "traggla",
    "tragglads": "traggla",
    "tragglande": "traggla",
    "tragglanden": "tragglande",
    "tragglandena": "tragglande",
    "tragglandenas": "tragglande",
    "tragglandens": "tragglande",
    "tragglandes": "tragglande",
    "tragglandet": "tragglande",
    "tragglandets": "tragglande",
    "tragglar": "traggla",
    "tragglas": "traggla",
    "tragglat": "traggla",
    "tragglats": "traggla",
    "tragglet": "traggel",
    "tragglets": "traggel",
    "traggliga": "tragglig",
    "traggligare": "tragglig",
    "traggligares": "tragglig",
    "traggligas": "tragglig",
    "traggligast": "tragglig",
    "traggligaste": "tragglig",
    "traggligastes": "tragglig",
    "traggligasts": "tragglig",
    "tragglige": "tragglig",
    "traggliges": "tragglig",
    "traggligheten": "tragglighet",
    "tragglighetens": "tragglighet",
    "tragglighets": "tragglighet",
    "traggligs": "tragglig",
    "traggligt": "tragglig",
    "traggligts": "tragglig",
    "tragiken": "tragik",
    "tragikens": "tragik",
    "tragikern": "tragiker",
    "tragikerna": "tragiker",
    "tragikernas": "tragiker",
    "tragikerns": "tragiker",
    "tragikers": "tragiker",
    "tragikomedien": "tragikomedi",
    "tragikomediens": "tragikomedi",
    "tragikomedier": "tragikomedi",
    "tragikomedierna": "tragikomedi",
    "tragikomediernas": "tragikomedi",
    "tragikomediers": "tragikomedi",
    "tragikomedin": "tragikomedi",
    "tragikomedins": "tragikomedi",
    "tragikomedis": "tragikomedi",
    "tragikomiska": "tragikomisk",
    "tragikomiskare": "tragikomisk",
    "tragikomiskares": "tragikomisk",
    "tragikomiskas": "tragikomisk",
    "tragikomiskast": "tragikomisk",
    "tragikomiskaste": "tragikomisk",
    "tragikomiskastes": "tragikomisk",
    "tragikomiskasts": "tragikomisk",
    "tragikomiske": "tragikomisk",
    "tragikomiskes": "tragikomisk",
    "tragikomisks": "tragikomisk",
    "tragikomiskt": "tragikomisk",
    "tragikomiskts": "tragikomisk",
    "tragiks": "tragik",
    "tragiska": "tragisk",
    "tragiskare": "tragisk",
    "tragiskares": "tragisk",
    "tragiskas": "tragisk",
    "tragiskast": "tragisk",
    "tragiskaste": "tragisk",
    "tragiskastes": "tragisk",
    "tragiskasts": "tragisk",
    "tragiske": "tragisk",
    "tragiskes": "tragisk",
    "tragisks": "tragisk",
    "tragiskt": "tragisk",
    "tragiskts": "tragisk",
    "tragöden": "tragöd",
    "tragödens": "tragöd",
    "tragöder": "tragöd",
    "tragöderna": "tragöd",
    "tragödernas": "tragöd",
    "tragöders": "tragöd",
    "tragöds": "tragöd",
    "trailern": "trailer",
    "trailerna": "trailer",
    "trailernas": "trailer",
    "trailerns": "trailer",
    "trailers": "trailer",
    "trailersarna": "trailer",
    "trailersarnas": "trailer",
    "trailrar": "trailer",
    "trailrarna": "trailer",
    "trailrarnas": "trailer",
    "trailrars": "trailer",
    "traineen": "trainee",
    "traineens": "trainee",
    "trainees": "trainee",
    "traineesarna": "trainee",
    "traineesarnas": "trainee",
    "traineesen": "trainee",
    "traineesens": "trainee",
    "traj": "traja",
    "trajad": "traja",
    "trajade": "traja",
    "trajades": "traja",
    "trajads": "traja",
    "trajande": "traja",
    "trajanden": "trajande",
    "trajandena": "trajande",
    "trajandenas": "trajande",
    "trajandens": "trajande",
    "trajandes": "trajande",
    "trajandet": "trajande",
    "trajandets": "trajande",
    "trajar": "traja",
    "trajas": "traja",
    "trajat": "traja",
    "trajats": "traja",
    "trajen": "traj",
    "trajens": "traj",
    "trajet": "traj",
    "trajets": "traj",
    "trajs": "traj",
    "trakasserad": "trakassera",
    "trakasserade": "trakassera",
    "trakasserades": "trakassera",
    "trakasserads": "trakassera",
    "trakasserande": "trakassera",
    "trakasseranden": "trakasserande",
    "trakasserandena": "trakasserande",
    "trakasserandenas": "trakasserande",
    "trakasserandens": "trakasserande",
    "trakasserandes": "trakasserande",
    "trakasserandet": "trakasserande",
    "trakasserandets": "trakasserande",
    "trakasserar": "trakassera",
    "trakasseras": "trakassera",
    "trakasserat": "trakassera",
    "trakasserats": "trakassera",
    "trakasserbara": "trakasserbar",
    "trakasserbarare": "trakasserbar",
    "trakasserbarares": "trakasserbar",
    "trakasserbaras": "trakasserbar",
    "trakasserbarast": "trakasserbar",
    "trakasserbaraste": "trakasserbar",
    "trakasserbarastes": "trakasserbar",
    "trakasserbarasts": "trakasserbar",
    "trakasserbare": "trakasserbar",
    "trakasserbares": "trakasserbar",
    "trakasserbarheten": "trakasserbarhet",
    "trakasserbarhetens": "trakasserbarhet",
    "trakasserbarhets": "trakasserbarhet",
    "trakasserbars": "trakasserbar",
    "trakasserbart": "trakasserbar",
    "trakasserbarts": "trakasserbar",
    "trakasserier": "trakasseri",
    "trakasserierna": "trakasseri",
    "trakasseriernas": "trakasseri",
    "trakasseriers": "trakasseri",
    "trakasseriet": "trakasseri",
    "trakasseriets": "trakasseri",
    "trakasseringar": "trakassering",
    "trakasseringarna": "trakassering",
    "trakasseringarnas": "trakassering",
    "trakasseringars": "trakassering",
    "trakasseringen": "trakassering",
    "trakasseringens": "trakassering",
    "trakasserings": "trakassering",
    "trakasseris": "trakasseri",
    "trakasserit": "trakasseri",
    "trakasserits": "trakasseri",
    "trakomen": "trakom",
    "trakomens": "trakom",
    "trakomet": "trakom",
    "trakomets": "trakom",
    "trakoms": "trakom",
    "trakt": "trakta",
    "traktad": "trakta",
    "traktade": "trakta",
    "traktades": "trakta",
    "traktads": "trakta",
    "traktamenten": "traktamente",
    "traktamentena": "traktamente",
    "traktamentenas": "traktamente",
    "traktamentens": "traktamente",
    "traktamentes": "traktamente",
    "traktamentet": "traktamente",
    "traktamentets": "traktamente",
    "traktaments": "traktamente",
    "traktande": "trakta",
    "traktanden": "traktande",
    "traktandena": "traktande",
    "traktandenas": "traktande",
    "traktandens": "traktande",
    "traktandes": "traktande",
    "traktandet": "traktande",
    "traktandets": "traktande",
    "traktans": "traktan",
    "traktar": "trakta",
    "traktas": "trakta",
    "traktat": "trakta",
    "traktaten": "traktat",
    "traktatens": "traktat",
    "traktater": "traktat",
    "traktaterna": "traktat",
    "traktaternas": "traktat",
    "traktaters": "traktat",
    "traktats": "traktat",
    "traktblädningar": "traktblädning",
    "traktblädningarna": "traktblädning",
    "traktblädningarnas": "traktblädning",
    "traktblädningars": "traktblädning",
    "traktblädningen": "traktblädning",
    "traktblädningens": "traktblädning",
    "traktblädnings": "traktblädning",
    "trakten": "trakt",
    "traktens": "trakt",
    "trakter": "trakt",
    "trakterad": "traktera",
    "trakterade": "trakterad",
    "trakterades": "trakterad",
    "trakterads": "trakterad",
    "trakterande": "traktera",
    "trakteranden": "trakterande",
    "trakterandena": "trakterande",
    "trakterandenas": "trakterande",
    "trakterandens": "trakterande",
    "trakterandes": "trakterande",
    "trakterandet": "trakterande",
    "trakterandets": "trakterande",
    "trakterar": "traktera",
    "trakteras": "traktera",
    "trakterat": "trakterad",
    "trakterats": "trakterad",
    "trakterbara": "trakterbar",
    "trakterbarare": "trakterbar",
    "trakterbarares": "trakterbar",
    "trakterbaras": "trakterbar",
    "trakterbarast": "trakterbar",
    "trakterbaraste": "trakterbar",
    "trakterbarastes": "trakterbar",
    "trakterbarasts": "trakterbar",
    "trakterbare": "trakterbar",
    "trakterbares": "trakterbar",
    "trakterbarheten": "trakterbarhet",
    "trakterbarhetens": "trakterbarhet",
    "trakterbarhets": "trakterbarhet",
    "trakterbars": "trakterbar",
    "trakterbart": "trakterbar",
    "trakterbarts": "trakterbar",
    "trakteringar": "traktering",
    "trakteringarna": "traktering",
    "trakteringarnas": "traktering",
    "trakteringars": "traktering",
    "trakteringen": "traktering",
    "trakteringens": "traktering",
    "trakterings": "traktering",
    "trakterna": "trakt",
    "trakternas": "trakt",
    "trakters": "trakt",
    "trakthugg": "trakthugga",
    "trakthuggande": "trakthugga",
    "trakthugganden": "trakthuggande",
    "trakthuggandena": "trakthuggande",
    "trakthuggandenas": "trakthuggande",
    "trakthuggandens": "trakthuggande",
    "trakthuggandes": "trakthuggande",
    "trakthuggandet": "trakthuggande",
    "trakthuggandets": "trakthuggande",
    "trakthuggas": "trakthugga",
    "trakthugge": "trakthugga",
    "trakthuggen": "trakthugga",
    "trakthuggens": "trakthugga",
    "trakthugger": "trakthugga",
    "trakthugges": "trakthugga",
    "trakthugget": "trakthugga",
    "trakthuggets": "trakthugga",
    "trakthuggit": "trakthugga",
    "trakthuggits": "trakthugga",
    "trakthuggna": "trakthugga",
    "trakthuggnas": "trakthugga",
    "trakthuggne": "trakthugga",
    "trakthuggnes": "trakthugga",
    "trakthuggs": "trakthugga",
    "trakthögg": "trakthugga",
    "trakthögge": "trakthugga",
    "trakthögges": "trakthugga",
    "trakthöggs": "trakthugga",
    "traktordäcken": "traktordäck",
    "traktordäckens": "traktordäck",
    "traktordäcket": "traktordäck",
    "traktordäckets": "traktordäck",
    "traktordäcks": "traktordäck",
    "traktorer": "traktor",
    "traktorerna": "traktor",
    "traktorernas": "traktor",
    "traktorers": "traktor",
    "traktorkärr": "traktorkärra",
    "traktorkärran": "traktorkärra",
    "traktorkärrans": "traktorkärra",
    "traktorkärras": "traktorkärra",
    "traktorkärre": "traktorkärra",
    "traktorkärror": "traktorkärra",
    "traktorkärrorna": "traktorkärra",
    "traktorkärrornas": "traktorkärra",
    "traktorkärrors": "traktorkärra",
    "traktorkärrs": "traktorkärra",
    "traktorn": "traktor",
    "traktorns": "traktor",
    "traktors": "traktor",
    "trakts": "trakt",
    "trakturen": "traktur",
    "trakturens": "traktur",
    "trakturer": "traktur",
    "trakturerna": "traktur",
    "trakturernas": "traktur",
    "trakturers": "traktur",
    "trakturs": "traktur",
    "traktören": "traktör",
    "traktörens": "traktör",
    "traktörer": "traktör",
    "traktörerna": "traktör",
    "traktörernas": "traktör",
    "traktörers": "traktör",
    "traktörpann": "traktörpanna",
    "traktörpannan": "traktörpanna",
    "traktörpannans": "traktörpanna",
    "traktörpannas": "traktörpanna",
    "traktörpanne": "traktörpanna",
    "traktörpannor": "traktörpanna",
    "traktörpannorna": "traktörpanna",
    "traktörpannornas": "traktörpanna",
    "traktörpannors": "traktörpanna",
    "traktörpanns": "traktörpanna",
    "traktörs": "traktör",
    "trakyten": "trakyt",
    "trakytens": "trakyt",
    "trakyter": "trakyt",
    "trakyterna": "trakyt",
    "trakyternas": "trakyt",
    "trakyters": "trakyt",
    "trakyts": "trakyt",
    "trakéer": "traké",
    "trakéerna": "traké",
    "trakéernas": "traké",
    "trakéers": "traké",
    "trakégälar": "trakégäl",
    "trakégälarna": "trakégäl",
    "trakégälarnas": "trakégäl",
    "trakégälars": "trakégäl",
    "trakégälen": "trakégäl",
    "trakégälens": "trakégäl",
    "trakégäls": "trakégäl",
    "trakén": "traké",
    "trakéns": "traké",
    "trakés": "traké",
    "trall": "tralla",
    "trallad": "tralla",
    "trallade": "tralla",
    "trallades": "tralla",
    "trallads": "tralla",
    "trallan": "tralla",
    "trallande": "tralla",
    "trallanden": "trallande",
    "trallandena": "trallande",
    "trallandenas": "trallande",
    "trallandens": "trallande",
    "trallandes": "trallande",
    "trallandet": "trallande",
    "trallandets": "trallande",
    "trallans": "tralla",
    "trallar": "tralla",
    "trallarna": "trall",
    "trallarnas": "trall",
    "trallars": "trall",
    "trallas": "tralla",
    "trallat": "tralla",
    "trallats": "tralla",
    "tralle": "tralla",
    "trallen": "trall",
    "trallens": "trall",
    "trallet": "trall",
    "trallets": "trall",
    "trallor": "tralla",
    "trallorna": "tralla",
    "trallornas": "tralla",
    "trallors": "tralla",
    "tralls": "tralla",
    "trallvagnar": "trallvagn",
    "trallvagnarna": "trallvagn",
    "trallvagnarnas": "trallvagn",
    "trallvagnars": "trallvagn",
    "trallvagnen": "trallvagn",
    "trallvagnens": "trallvagn",
    "trallvagns": "trallvagn",
    "tramp": "trampa",
    "trampad": "trampa",
    "trampade": "trampa",
    "trampades": "trampa",
    "trampads": "trampa",
    "trampan": "trampa",
    "trampande": "trampa",
    "trampanden": "trampande",
    "trampandena": "trampande",
    "trampandenas": "trampande",
    "trampandens": "trampande",
    "trampandes": "trampande",
    "trampandet": "trampande",
    "trampandets": "trampande",
    "trampans": "trampa",
    "trampar": "trampa",
    "trampas": "trampa",
    "trampat": "trampa",
    "trampats": "trampa",
    "trampbilar": "trampbil",
    "trampbilarna": "trampbil",
    "trampbilarnas": "trampbil",
    "trampbilars": "trampbil",
    "trampbilen": "trampbil",
    "trampbilens": "trampbil",
    "trampbils": "trampbil",
    "trampbåtar": "trampbåt",
    "trampbåtarna": "trampbåt",
    "trampbåtarnas": "trampbåt",
    "trampbåtars": "trampbåt",
    "trampbåten": "trampbåt",
    "trampbåtens": "trampbåt",
    "trampbåts": "trampbåt",
    "trampcykeln": "trampcykel",
    "trampcykelns": "trampcykel",
    "trampcykels": "trampcykel",
    "trampcyklar": "trampcykel",
    "trampcyklarna": "trampcykel",
    "trampcyklarnas": "trampcykel",
    "trampcyklars": "trampcykel",
    "trampdyn": "trampdyna",
    "trampdynan": "trampdyna",
    "trampdynans": "trampdyna",
    "trampdynas": "trampdyna",
    "trampdyne": "trampdyna",
    "trampdynor": "trampdyna",
    "trampdynorna": "trampdyna",
    "trampdynornas": "trampdyna",
    "trampdynors": "trampdyna",
    "trampdyns": "trampdyna",
    "trampe": "trampa",
    "trampet": "tramp",
    "trampets": "tramp",
    "trampfarten": "trampfart",
    "trampfartens": "trampfart",
    "trampfarts": "trampfart",
    "trampfartygen": "trampfartyg",
    "trampfartygens": "trampfartyg",
    "trampfartyget": "trampfartyg",
    "trampfartygets": "trampfartyg",
    "trampfartygs": "trampfartyg",
    "trampgräset": "trampgräs",
    "trampgräsets": "trampgräs",
    "tramphjulen": "tramphjul",
    "tramphjulens": "tramphjul",
    "tramphjulet": "tramphjul",
    "tramphjulets": "tramphjul",
    "tramphjuls": "tramphjul",
    "trampkvarnar": "trampkvarn",
    "trampkvarnarna": "trampkvarn",
    "trampkvarnarnas": "trampkvarn",
    "trampkvarnars": "trampkvarn",
    "trampkvarnen": "trampkvarn",
    "trampkvarnens": "trampkvarn",
    "trampkvarns": "trampkvarn",
    "trampmin": "trampmina",
    "trampminan": "trampmina",
    "trampminans": "trampmina",
    "trampminas": "trampmina",
    "trampmine": "trampmina",
    "trampminor": "trampmina",
    "trampminorna": "trampmina",
    "trampminornas": "trampmina",
    "trampminors": "trampmina",
    "trampmins": "trampmina",
    "trampolinen": "trampolin",
    "trampolinens": "trampolin",
    "trampoliner": "trampolin",
    "trampolinerna": "trampolin",
    "trampolinernas": "trampolin",
    "trampoliners": "trampolin",
    "trampolins": "trampolin",
    "trampor": "trampa",
    "tramporna": "trampa",
    "trampornas": "trampa",
    "trampors": "trampa",
    "tramps": "trampa",
    "trampsaxar": "trampsax",
    "trampsaxarna": "trampsax",
    "trampsaxarnas": "trampsax",
    "trampsaxars": "trampsax",
    "trampsaxen": "trampsax",
    "trampsaxens": "trampsax",
    "trampörten": "trampört",
    "trampörtens": "trampört",
    "trampörter": "trampört",
    "trampörterna": "trampört",
    "trampörternas": "trampört",
    "trampörters": "trampört",
    "trampörts": "trampört",
    "trams": "tramsa",
    "tramsad": "tramsa",
    "tramsade": "tramsa",
    "tramsades": "tramsa",
    "tramsads": "tramsa",
    "tramsande": "tramsa",
    "tramsanden": "tramsande",
    "tramsandena": "tramsande",
    "tramsandenas": "tramsande",
    "tramsandens": "tramsande",
    "tramsandes": "tramsande",
    "tramsandet": "tramsande",
    "tramsandets": "tramsande",
    "tramsar": "tramsa",
    "tramsas": "tramsa",
    "tramsat": "tramsa",
    "tramsats": "tramsa",
    "tramset": "trams",
    "tramsets": "trams",
    "tramsiga": "tramsig",
    "tramsigare": "tramsig",
    "tramsigares": "tramsig",
    "tramsigas": "tramsig",
    "tramsigast": "tramsig",
    "tramsigaste": "tramsig",
    "tramsigastes": "tramsig",
    "tramsigasts": "tramsig",
    "tramsige": "tramsig",
    "tramsiges": "tramsig",
    "tramsigheten": "tramsighet",
    "tramsighetens": "tramsighet",
    "tramsigheter": "tramsighet",
    "tramsigheterna": "tramsighet",
    "tramsigheternas": "tramsighet",
    "tramsigheters": "tramsighet",
    "tramsighets": "tramsighet",
    "tramsigs": "tramsig",
    "tramsigt": "tramsig",
    "tramsigts": "tramsig",
    "tran": "trana",
    "tranan": "trana",
    "tranans": "trana",
    "tranas": "trana",
    "tranbenen": "tranben",
    "tranbenens": "tranben",
    "tranbenet": "tranben",
    "tranbenets": "tranben",
    "tranbens": "tranben",
    "tranbären": "tranbär",
    "tranbärens": "tranbär",
    "tranbäret": "tranbär",
    "tranbärets": "tranbär",
    "tranbärs": "tranbär",
    "tranbärssaften": "tranbärssaft",
    "tranbärssaftens": "tranbärssaft",
    "tranbärssafter": "tranbärssaft",
    "tranbärssafterna": "tranbärssaft",
    "tranbärssafternas": "tranbärssaft",
    "tranbärssafters": "tranbärssaft",
    "tranbärssafts": "tranbärssaft",
    "trancen": "trance",
    "trancens": "trance",
    "trances": "trance",
    "tranchen": "tranch",
    "tranchens": "tranch",
    "trancher": "tranchera",
    "trancherad": "tranchera",
    "trancherade": "tranchera",
    "trancherades": "tranchera",
    "trancherads": "tranchera",
    "trancherande": "tranchera",
    "trancheranden": "trancherande",
    "trancherandena": "trancherande",
    "trancherandenas": "trancherande",
    "trancherandens": "trancherande",
    "trancherandes": "trancherande",
    "trancherandet": "trancherande",
    "trancherandets": "trancherande",
    "trancherar": "tranchera",
    "trancheras": "tranchera",
    "trancherat": "tranchera",
    "trancherats": "tranchera",
    "trancherbara": "trancherbar",
    "trancherbarare": "trancherbar",
    "trancherbarares": "trancherbar",
    "trancherbaras": "trancherbar",
    "trancherbarast": "trancherbar",
    "trancherbaraste": "trancherbar",
    "trancherbarastes": "trancherbar",
    "trancherbarasts": "trancherbar",
    "trancherbare": "trancherbar",
    "trancherbares": "trancherbar",
    "trancherbarheten": "trancherbarhet",
    "trancherbarhetens": "trancherbarhet",
    "trancherbarhets": "trancherbarhet",
    "trancherbars": "trancherbar",
    "trancherbart": "trancherbar",
    "trancherbarts": "trancherbar",
    "trancherna": "tranch",
    "tranchernas": "tranch",
    "tranchers": "tranch",
    "tranchs": "tranch",
    "trandansen": "trandans",
    "trandansens": "trandans",
    "trane": "trana",
    "tranedansen": "tranedans",
    "tranedansens": "tranedans",
    "tranen": "tran",
    "tranens": "tran",
    "trankila": "trankil",
    "trankilare": "trankil",
    "trankilares": "trankil",
    "trankilas": "trankil",
    "trankilast": "trankil",
    "trankilaste": "trankil",
    "trankilastes": "trankil",
    "trankilasts": "trankil",
    "trankile": "trankil",
    "trankiles": "trankil",
    "trankiliteten": "trankilitet",
    "trankilitetens": "trankilitet",
    "trankiliteter": "trankilitet",
    "trankiliteterna": "trankilitet",
    "trankiliteternas": "trankilitet",
    "trankiliteters": "trankilitet",
    "trankilitets": "trankilitet",
    "trankils": "trankil",
    "trankilt": "trankil",
    "trankilts": "trankil",
    "tranlamp": "tranlampa",
    "tranlampan": "tranlampa",
    "tranlampans": "tranlampa",
    "tranlampas": "tranlampa",
    "tranlampe": "tranlampa",
    "tranlampor": "tranlampa",
    "tranlamporna": "tranlampa",
    "tranlampornas": "tranlampa",
    "tranlampors": "tranlampa",
    "tranlamps": "tranlampa",
    "tranor": "trana",
    "tranorna": "trana",
    "tranornas": "trana",
    "tranors": "trana",
    "trans": "transa",
    "transaktionen": "transaktion",
    "transaktionens": "transaktion",
    "transaktioner": "transaktion",
    "transaktionerna": "transaktion",
    "transaktionernas": "transaktion",
    "transaktioners": "transaktion",
    "transaktions": "transaktion",
    "transaktionsanalysen": "transaktionsanalys",
    "transaktionsanalysens": "transaktionsanalys",
    "transaktionsanalyser": "transaktionsanalys",
    "transaktionsanalyserna": "transaktionsanalys",
    "transaktionsanalysernas": "transaktionsanalys",
    "transaktionsanalysers": "transaktionsanalys",
    "transalpina": "transalpin",
    "transalpinare": "transalpin",
    "transalpinares": "transalpin",
    "transalpinas": "transalpin",
    "transalpinast": "transalpin",
    "transalpinaste": "transalpin",
    "transalpinastes": "transalpin",
    "transalpinasts": "transalpin",
    "transalpine": "transalpin",
    "transalpines": "transalpin",
    "transalpins": "transalpin",
    "transalpinska": "transalpinsk",
    "transalpinskare": "transalpinsk",
    "transalpinskares": "transalpinsk",
    "transalpinskas": "transalpinsk",
    "transalpinskast": "transalpinsk",
    "transalpinskaste": "transalpinsk",
    "transalpinskastes": "transalpinsk",
    "transalpinskasts": "transalpinsk",
    "transalpinske": "transalpinsk",
    "transalpinskes": "transalpinsk",
    "transalpinsks": "transalpinsk",
    "transalpinskt": "transalpinsk",
    "transalpinskts": "transalpinsk",
    "transalpint": "transalpin",
    "transalpints": "transalpin",
    "transan": "transa",
    "transans": "transa",
    "transas": "transa",
    "transatlantiska": "transatlantisk",
    "transatlantiskare": "transatlantisk",
    "transatlantiskares": "transatlantisk",
    "transatlantiskas": "transatlantisk",
    "transatlantiskast": "transatlantisk",
    "transatlantiskaste": "transatlantisk",
    "transatlantiskastes": "transatlantisk",
    "transatlantiskasts": "transatlantisk",
    "transatlantiske": "transatlantisk",
    "transatlantiskes": "transatlantisk",
    "transatlantisks": "transatlantisk",
    "transatlantiskt": "transatlantisk",
    "transatlantiskts": "transatlantisk",
    "transcendensen": "transcendens",
    "transcendensens": "transcendens",
    "transcendenta": "transcendent",
    "transcendentala": "transcendental",
    "transcendentalare": "transcendental",
    "transcendentalares": "transcendental",
    "transcendentalas": "transcendental",
    "transcendentalast": "transcendental",
    "transcendentalaste": "transcendental",
    "transcendentalastes": "transcendental",
    "transcendentalasts": "transcendental",
    "transcendentale": "transcendental",
    "transcendentales": "transcendental",
    "transcendentals": "transcendental",
    "transcendentalt": "transcendental",
    "transcendentalts": "transcendental",
    "transcendentare": "transcendent",
    "transcendentares": "transcendent",
    "transcendentas": "transcendent",
    "transcendentast": "transcendent",
    "transcendentaste": "transcendent",
    "transcendentastes": "transcendent",
    "transcendentasts": "transcendent",
    "transcendente": "transcendent",
    "transcendentes": "transcendent",
    "transcendentheten": "transcendenthet",
    "transcendenthetens": "transcendenthet",
    "transcendenthets": "transcendenthet",
    "transcendents": "transcendent",
    "transduktorer": "transduktor",
    "transduktorerna": "transduktor",
    "transduktorernas": "transduktor",
    "transduktorers": "transduktor",
    "transduktorn": "transduktor",
    "transduktorns": "transduktor",
    "transduktors": "transduktor",
    "transe": "transa",
    "transen": "trans",
    "transens": "trans",
    "transfererad": "transferera",
    "transfererade": "transferera",
    "transfererades": "transferera",
    "transfererads": "transferera",
    "transfererande": "transferera",
    "transfereranden": "transfererande",
    "transfererandena": "transfererande",
    "transfererandenas": "transfererande",
    "transfererandens": "transfererande",
    "transfererandes": "transfererande",
    "transfererandet": "transfererande",
    "transfererandets": "transfererande",
    "transfererar": "transferera",
    "transfereras": "transferera",
    "transfererat": "transferera",
    "transfererats": "transferera",
    "transfererbara": "transfererbar",
    "transfererbarare": "transfererbar",
    "transfererbarares": "transfererbar",
    "transfererbaras": "transfererbar",
    "transfererbarast": "transfererbar",
    "transfererbaraste": "transfererbar",
    "transfererbarastes": "transfererbar",
    "transfererbarasts": "transfererbar",
    "transfererbare": "transfererbar",
    "transfererbares": "transfererbar",
    "transfererbarheten": "transfererbarhet",
    "transfererbarhetens": "transfererbarhet",
    "transfererbarhets": "transfererbarhet",
    "transfererbars": "transfererbar",
    "transfererbart": "transfererbar",
    "transfererbarts": "transfererbar",
    "transfereringar": "transferering",
    "transfereringarna": "transferering",
    "transfereringarnas": "transferering",
    "transfereringars": "transferering",
    "transfereringen": "transferering",
    "transfereringens": "transferering",
    "transfererings": "transferering",
    "transfern": "transfer",
    "transferns": "transfer",
    "transfers": "transfer",
    "transfetter": "transfett",
    "transfetterna": "transfett",
    "transfetternas": "transfett",
    "transfetters": "transfett",
    "transfettet": "transfett",
    "transfettets": "transfett",
    "transfetts": "transfett",
    "transfigurationen": "transfiguration",
    "transfigurationens": "transfiguration",
    "transfigurationer": "transfiguration",
    "transfigurationerna": "transfiguration",
    "transfigurationernas": "transfiguration",
    "transfigurationers": "transfiguration",
    "transfigurations": "transfiguration",
    "transformationen": "transformation",
    "transformationens": "transformation",
    "transformationer": "transformation",
    "transformationerna": "transformation",
    "transformationernas": "transformation",
    "transformationers": "transformation",
    "transformations": "transformation",
    "transformationsgrammatiken": "transformationsgrammatik",
    "transformationsgrammatikens": "transformationsgrammatik",
    "transformationsgrammatiker": "transformationsgrammatik",
    "transformationsgrammatikerna": "transformationsgrammatik",
    "transformationsgrammatikernas": "transformationsgrammatik",
    "transformationsgrammatikers": "transformationsgrammatik",
    "transformationsgrammatiks": "transformationsgrammatik",
    "transformatorbranden": "transformatorbrand",
    "transformatorbrandens": "transformatorbrand",
    "transformatorbrands": "transformatorbrand",
    "transformatorbränder": "transformatorbrand",
    "transformatorbränderna": "transformatorbrand",
    "transformatorbrändernas": "transformatorbrand",
    "transformatorbränders": "transformatorbrand",
    "transformatorer": "transformator",
    "transformatorerna": "transformator",
    "transformatorernas": "transformator",
    "transformatorers": "transformator",
    "transformatorn": "transformator",
    "transformatorns": "transformator",
    "transformators": "transformator",
    "transformatorstationen": "transformatorstation",
    "transformatorstationens": "transformatorstation",
    "transformatorstationer": "transformatorstation",
    "transformatorstationerna": "transformatorstation",
    "transformatorstationernas": "transformatorstation",
    "transformatorstationers": "transformatorstation",
    "transformatorstations": "transformatorstation",
    "transformerad": "transformera",
    "transformerade": "transformera",
    "transformerades": "transformera",
    "transformerads": "transformera",
    "transformerande": "transformera",
    "transformeranden": "transformerande",
    "transformerandena": "transformerande",
    "transformerandenas": "transformerande",
    "transformerandens": "transformerande",
    "transformerandes": "transformerande",
    "transformerandet": "transformerande",
    "transformerandets": "transformerande",
    "transformerar": "transformera",
    "transformeras": "transformera",
    "transformerat": "transformera",
    "transformerats": "transformera",
    "transformerbara": "transformerbar",
    "transformerbarare": "transformerbar",
    "transformerbarares": "transformerbar",
    "transformerbaras": "transformerbar",
    "transformerbarast": "transformerbar",
    "transformerbaraste": "transformerbar",
    "transformerbarastes": "transformerbar",
    "transformerbarasts": "transformerbar",
    "transformerbare": "transformerbar",
    "transformerbares": "transformerbar",
    "transformerbarheten": "transformerbarhet",
    "transformerbarhetens": "transformerbarhet",
    "transformerbarhets": "transformerbarhet",
    "transformerbars": "transformerbar",
    "transformerbart": "transformerbar",
    "transformerbarts": "transformerbar",
    "transformeringar": "transformering",
    "transformeringarna": "transformering",
    "transformeringarnas": "transformering",
    "transformeringars": "transformering",
    "transformeringen": "transformering",
    "transformeringens": "transformering",
    "transformerings": "transformering",
    "transfusionen": "transfusion",
    "transfusionens": "transfusion",
    "transfusioner": "transfusion",
    "transfusionerna": "transfusion",
    "transfusionernas": "transfusion",
    "transfusioners": "transfusion",
    "transfusions": "transfusion",
    "transgena": "transgen",
    "transgenare": "transgen",
    "transgenares": "transgen",
    "transgenas": "transgen",
    "transgenast": "transgen",
    "transgenaste": "transgen",
    "transgenastes": "transgen",
    "transgenasts": "transgen",
    "transgene": "transgen",
    "transgenes": "transgen",
    "transgens": "transgen",
    "transgent": "transgen",
    "transgents": "transgen",
    "transgressionen": "transgression",
    "transgressionens": "transgression",
    "transgressioner": "transgression",
    "transgressionerna": "transgression",
    "transgressionernas": "transgression",
    "transgressioners": "transgression",
    "transgressions": "transgression",
    "transistorer": "transistor",
    "transistorerna": "transistor",
    "transistorernas": "transistor",
    "transistorers": "transistor",
    "transistorn": "transistor",
    "transistorns": "transistor",
    "transistorradion": "transistorradio",
    "transistorradions": "transistorradio",
    "transistorradios": "transistorradio",
    "transistors": "transistor",
    "transiterad": "transitera",
    "transiterade": "transitera",
    "transiterades": "transitera",
    "transiterads": "transitera",
    "transiterande": "transitera",
    "transiteranden": "transiterande",
    "transiterandena": "transiterande",
    "transiterandenas": "transiterande",
    "transiterandens": "transiterande",
    "transiterandes": "transiterande",
    "transiterandet": "transiterande",
    "transiterandets": "transiterande",
    "transiterar": "transitera",
    "transiteras": "transitera",
    "transiterat": "transitera",
    "transiterats": "transitera",
    "transiterbara": "transiterbar",
    "transiterbarare": "transiterbar",
    "transiterbarares": "transiterbar",
    "transiterbaras": "transiterbar",
    "transiterbarast": "transiterbar",
    "transiterbaraste": "transiterbar",
    "transiterbarastes": "transiterbar",
    "transiterbarasts": "transiterbar",
    "transiterbare": "transiterbar",
    "transiterbares": "transiterbar",
    "transiterbarheten": "transiterbarhet",
    "transiterbarhetens": "transiterbarhet",
    "transiterbarhets": "transiterbarhet",
    "transiterbars": "transiterbar",
    "transiterbart": "transiterbar",
    "transiterbarts": "transiterbar",
    "transiteringar": "transitering",
    "transiteringarna": "transitering",
    "transiteringarnas": "transitering",
    "transiteringars": "transitering",
    "transiteringen": "transitering",
    "transiteringens": "transitering",
    "transiterings": "transitering",
    "transithallar": "transithall",
    "transithallarna": "transithall",
    "transithallarnas": "transithall",
    "transithallars": "transithall",
    "transithallen": "transithall",
    "transithallens": "transithall",
    "transithalls": "transithall",
    "transitiva": "transitiv",
    "transitivare": "transitiv",
    "transitivares": "transitiv",
    "transitivas": "transitiv",
    "transitivast": "transitiv",
    "transitivaste": "transitiv",
    "transitivastes": "transitiv",
    "transitivasts": "transitiv",
    "transitive": "transitiv",
    "transitives": "transitiv",
    "transitivs": "transitiv",
    "transitivt": "transitiv",
    "transitivts": "transitiv",
    "transitlasten": "transitlast",
    "transitlastens": "transitlast",
    "transitlaster": "transitlast",
    "transitlasterna": "transitlast",
    "transitlasternas": "transitlast",
    "transitlasters": "transitlast",
    "transitlasts": "transitlast",
    "transitohamnar": "transitohamn",
    "transitohamnarna": "transitohamn",
    "transitohamnarnas": "transitohamn",
    "transitohamnars": "transitohamn",
    "transitohamnen": "transitohamn",
    "transitohamnens": "transitohamn",
    "transitohamns": "transitohamn",
    "transitoriska": "transitorisk",
    "transitoriskare": "transitorisk",
    "transitoriskares": "transitorisk",
    "transitoriskas": "transitorisk",
    "transitoriskast": "transitorisk",
    "transitoriskaste": "transitorisk",
    "transitoriskastes": "transitorisk",
    "transitoriskasts": "transitorisk",
    "transitoriske": "transitorisk",
    "transitoriskes": "transitorisk",
    "transitorisks": "transitorisk",
    "transitoriskt": "transitorisk",
    "transitoriskts": "transitorisk",
    "transitresan": "transitresa",
    "transitresans": "transitresa",
    "transitresas": "transitresa",
    "transitrese": "transitresa",
    "transitresor": "transitresa",
    "transitresorna": "transitresa",
    "transitresornas": "transitresa",
    "transitresors": "transitresa",
    "transkontinentala": "transkontinental",
    "transkontinentalare": "transkontinental",
    "transkontinentalares": "transkontinental",
    "transkontinentalas": "transkontinental",
    "transkontinentalast": "transkontinental",
    "transkontinentalaste": "transkontinental",
    "transkontinentalastes": "transkontinental",
    "transkontinentalasts": "transkontinental",
    "transkontinentale": "transkontinental",
    "transkontinentales": "transkontinental",
    "transkontinentals": "transkontinental",
    "transkontinentalt": "transkontinental",
    "transkontinentalts": "transkontinental",
    "transkriberad": "transkribera",
    "transkriberade": "transkribera",
    "transkriberades": "transkribera",
    "transkriberads": "transkribera",
    "transkriberande": "transkribera",
    "transkriberanden": "transkriberande",
    "transkriberandena": "transkriberande",
    "transkriberandenas": "transkriberande",
    "transkriberandens": "transkriberande",
    "transkriberandes": "transkriberande",
    "transkriberandet": "transkriberande",
    "transkriberandets": "transkriberande",
    "transkriberar": "transkribera",
    "transkriberas": "transkribera",
    "transkriberat": "transkribera",
    "transkriberats": "transkribera",
    "transkriberbara": "transkriberbar",
    "transkriberbarare": "transkriberbar",
    "transkriberbarares": "transkriberbar",
    "transkriberbaras": "transkriberbar",
    "transkriberbarast": "transkriberbar",
    "transkriberbaraste": "transkriberbar",
    "transkriberbarastes": "transkriberbar",
    "transkriberbarasts": "transkriberbar",
    "transkriberbare": "transkriberbar",
    "transkriberbares": "transkriberbar",
    "transkriberbarheten": "transkriberbarhet",
    "transkriberbarhetens": "transkriberbarhet",
    "transkriberbarhets": "transkriberbarhet",
    "transkriberbars": "transkriberbar",
    "transkriberbart": "transkriberbar",
    "transkriberbarts": "transkriberbar",
    "transkriberingar": "transkribering",
    "transkriberingarna": "transkribering",
    "transkriberingarnas": "transkribering",
    "transkriberingars": "transkribering",
    "transkriberingen": "transkribering",
    "transkriberingens": "transkribering",
    "transkriberings": "transkribering",
    "transkriptionen": "transkription",
    "transkriptionens": "transkription",
    "transkriptioner": "transkription",
    "transkriptionerna": "transkription",
    "transkriptionernas": "transkription",
    "transkriptioners": "transkription",
    "transkriptions": "transkription",
    "translativen": "translativ",
    "translativens": "translativ",
    "translativer": "translativ",
    "translativerna": "translativ",
    "translativernas": "translativ",
    "translativers": "translativ",
    "translativs": "translativ",
    "translatorer": "translator",
    "translatorerna": "translator",
    "translatorernas": "translator",
    "translatorers": "translator",
    "translatorn": "translator",
    "translatorns": "translator",
    "translators": "translator",
    "translitterationen": "translitteration",
    "translitterationens": "translitteration",
    "translitterationer": "translitteration",
    "translitterationerna": "translitteration",
    "translitterationernas": "translitteration",
    "translitterationers": "translitteration",
    "translitterations": "translitteration",
    "translittererad": "translitterera",
    "translittererade": "translitterera",
    "translittererades": "translitterera",
    "translittererads": "translitterera",
    "translittererande": "translitterera",
    "translittereranden": "translittererande",
    "translittererandena": "translittererande",
    "translittererandenas": "translittererande",
    "translittererandens": "translittererande",
    "translittererandes": "translittererande",
    "translittererandet": "translittererande",
    "translittererandets": "translittererande",
    "translittererar": "translitterera",
    "translittereras": "translitterera",
    "translittererat": "translitterera",
    "translittererats": "translitterera",
    "translittererbara": "translittererbar",
    "translittererbarare": "translittererbar",
    "translittererbarares": "translittererbar",
    "translittererbaras": "translittererbar",
    "translittererbarast": "translittererbar",
    "translittererbaraste": "translittererbar",
    "translittererbarastes": "translittererbar",
    "translittererbarasts": "translittererbar",
    "translittererbare": "translittererbar",
    "translittererbares": "translittererbar",
    "translittererbarheten": "translittererbarhet",
    "translittererbarhetens": "translittererbarhet",
    "translittererbarhets": "translittererbarhet",
    "translittererbars": "translittererbar",
    "translittererbart": "translittererbar",
    "translittererbarts": "translittererbar",
    "translittereringar": "translitterering",
    "translittereringarna": "translitterering",
    "translittereringarnas": "translitterering",
    "translittereringars": "translitterering",
    "translittereringen": "translitterering",
    "translittereringens": "translitterering",
    "translittererings": "translitterering",
    "transmissionen": "transmission",
    "transmissionens": "transmission",
    "transmissioner": "transmission",
    "transmissionerna": "transmission",
    "transmissionernas": "transmission",
    "transmissioners": "transmission",
    "transmissions": "transmission",
    "transmitterad": "transmittera",
    "transmitterade": "transmittera",
    "transmitterades": "transmittera",
    "transmitterads": "transmittera",
    "transmitterande": "transmittera",
    "transmitteranden": "transmitterande",
    "transmitterandena": "transmitterande",
    "transmitterandenas": "transmitterande",
    "transmitterandens": "transmitterande",
    "transmitterandes": "transmitterande",
    "transmitterandet": "transmitterande",
    "transmitterandets": "transmitterande",
    "transmitterar": "transmittera",
    "transmitteras": "transmittera",
    "transmitterat": "transmittera",
    "transmitterats": "transmittera",
    "transmitterbara": "transmitterbar",
    "transmitterbarare": "transmitterbar",
    "transmitterbarares": "transmitterbar",
    "transmitterbaras": "transmitterbar",
    "transmitterbarast": "transmitterbar",
    "transmitterbaraste": "transmitterbar",
    "transmitterbarastes": "transmitterbar",
    "transmitterbarasts": "transmitterbar",
    "transmitterbare": "transmitterbar",
    "transmitterbares": "transmitterbar",
    "transmitterbarheten": "transmitterbarhet",
    "transmitterbarhetens": "transmitterbarhet",
    "transmitterbarhets": "transmitterbarhet",
    "transmitterbars": "transmitterbar",
    "transmitterbart": "transmitterbar",
    "transmitterbarts": "transmitterbar",
    "transmitteringar": "transmittering",
    "transmitteringarna": "transmittering",
    "transmitteringarnas": "transmittering",
    "transmitteringars": "transmittering",
    "transmitteringen": "transmittering",
    "transmitteringens": "transmittering",
    "transmitterings": "transmittering",
    "transmittern": "transmitter",
    "transmitterns": "transmitter",
    "transmitters": "transmitter",
    "transmittrar": "transmitter",
    "transmittrarna": "transmitter",
    "transmittrarnas": "transmitter",
    "transmittrars": "transmitter",
    "transmutationen": "transmutation",
    "transmutationens": "transmutation",
    "transmutationer": "transmutation",
    "transmutationerna": "transmutation",
    "transmutationernas": "transmutation",
    "transmutationers": "transmutation",
    "transmutations": "transmutation",
    "transmuterad": "transmutera",
    "transmuterade": "transmutera",
    "transmuterades": "transmutera",
    "transmuterads": "transmutera",
    "transmuterande": "transmutera",
    "transmuteranden": "transmuterande",
    "transmuterandena": "transmuterande",
    "transmuterandenas": "transmuterande",
    "transmuterandens": "transmuterande",
    "transmuterandes": "transmuterande",
    "transmuterandet": "transmuterande",
    "transmuterandets": "transmuterande",
    "transmuterar": "transmutera",
    "transmuteras": "transmutera",
    "transmuterat": "transmutera",
    "transmuterats": "transmutera",
    "transmuterbara": "transmuterbar",
    "transmuterbarare": "transmuterbar",
    "transmuterbarares": "transmuterbar",
    "transmuterbaras": "transmuterbar",
    "transmuterbarast": "transmuterbar",
    "transmuterbaraste": "transmuterbar",
    "transmuterbarastes": "transmuterbar",
    "transmuterbarasts": "transmuterbar",
    "transmuterbare": "transmuterbar",
    "transmuterbares": "transmuterbar",
    "transmuterbarheten": "transmuterbarhet",
    "transmuterbarhetens": "transmuterbarhet",
    "transmuterbarhets": "transmuterbarhet",
    "transmuterbars": "transmuterbar",
    "transmuterbart": "transmuterbar",
    "transmuterbarts": "transmuterbar",
    "transmuteringar": "transmutering",
    "transmuteringarna": "transmutering",
    "transmuteringarnas": "transmutering",
    "transmuteringars": "transmutering",
    "transmuteringen": "transmutering",
    "transmuteringens": "transmutering",
    "transmuterings": "transmutering",
    "transoceana": "transocean",
    "transoceanare": "transocean",
    "transoceanares": "transocean",
    "transoceanas": "transocean",
    "transoceanast": "transocean",
    "transoceanaste": "transocean",
    "transoceanastes": "transocean",
    "transoceanasts": "transocean",
    "transoceane": "transocean",
    "transoceanes": "transocean",
    "transoceans": "transocean",
    "transoceanska": "transoceansk",
    "transoceanskare": "transoceansk",
    "transoceanskares": "transoceansk",
    "transoceanskas": "transoceansk",
    "transoceanskast": "transoceansk",
    "transoceanskaste": "transoceansk",
    "transoceanskastes": "transoceansk",
    "transoceanskasts": "transoceansk",
    "transoceanske": "transoceansk",
    "transoceanskes": "transoceansk",
    "transoceansks": "transoceansk",
    "transoceanskt": "transoceansk",
    "transoceanskts": "transoceansk",
    "transoceant": "transocean",
    "transoceants": "transocean",
    "transor": "transa",
    "transorna": "transa",
    "transornas": "transa",
    "transors": "transa",
    "transparangen": "transparang",
    "transparangens": "transparang",
    "transparanger": "transparang",
    "transparangerna": "transparang",
    "transparangernas": "transparang",
    "transparangers": "transparang",
    "transparangs": "transparang",
    "transparenta": "transparent",
    "transparentare": "transparent",
    "transparentares": "transparent",
    "transparentas": "transparent",
    "transparentast": "transparent",
    "transparentaste": "transparent",
    "transparentastes": "transparent",
    "transparentasts": "transparent",
    "transparente": "transparent",
    "transparentes": "transparent",
    "transparentheten": "transparenthet",
    "transparenthetens": "transparenthet",
    "transparenthets": "transparenthet",
    "transparents": "transparent",
    "transpersonen": "transperson",
    "transpersonens": "transperson",
    "transpersoner": "transperson",
    "transpersonerna": "transperson",
    "transpersonernas": "transperson",
    "transpersoners": "transperson",
    "transpersons": "transperson",
    "transpirationen": "transpiration",
    "transpirationens": "transpiration",
    "transpirationer": "transpiration",
    "transpirationerna": "transpiration",
    "transpirationernas": "transpiration",
    "transpirationers": "transpiration",
    "transpirations": "transpiration",
    "transpirerade": "transpirera",
    "transpirerades": "transpirera",
    "transpirerande": "transpirera",
    "transpireranden": "transpirerande",
    "transpirerandena": "transpirerande",
    "transpirerandenas": "transpirerande",
    "transpirerandens": "transpirerande",
    "transpirerandes": "transpirerande",
    "transpirerandet": "transpirerande",
    "transpirerandets": "transpirerande",
    "transpirerar": "transpirera",
    "transpireras": "transpirera",
    "transpirerat": "transpirera",
    "transpirerats": "transpirera",
    "transpireringar": "transpirering",
    "transpireringarna": "transpirering",
    "transpireringarnas": "transpirering",
    "transpireringars": "transpirering",
    "transpireringen": "transpirering",
    "transpireringens": "transpirering",
    "transpirerings": "transpirering",
    "transplantaten": "transplantat",
    "transplantatens": "transplantat",
    "transplantatet": "transplantat",
    "transplantatets": "transplantat",
    "transplantationen": "transplantation",
    "transplantationens": "transplantation",
    "transplantationer": "transplantation",
    "transplantationerna": "transplantation",
    "transplantationernas": "transplantation",
    "transplantationers": "transplantation",
    "transplantations": "transplantation",
    "transplantats": "transplantat",
    "transplanterad": "transplantera",
    "transplanterade": "transplantera",
    "transplanterades": "transplantera",
    "transplanterads": "transplantera",
    "transplanterande": "transplantera",
    "transplanteranden": "transplanterande",
    "transplanterandena": "transplanterande",
    "transplanterandenas": "transplanterande",
    "transplanterandens": "transplanterande",
    "transplanterandes": "transplanterande",
    "transplanterandet": "transplanterande",
    "transplanterandets": "transplanterande",
    "transplanterar": "transplantera",
    "transplanteras": "transplantera",
    "transplanterat": "transplantera",
    "transplanterats": "transplantera",
    "transplanterbara": "transplanterbar",
    "transplanterbarare": "transplanterbar",
    "transplanterbarares": "transplanterbar",
    "transplanterbaras": "transplanterbar",
    "transplanterbarast": "transplanterbar",
    "transplanterbaraste": "transplanterbar",
    "transplanterbarastes": "transplanterbar",
    "transplanterbarasts": "transplanterbar",
    "transplanterbare": "transplanterbar",
    "transplanterbares": "transplanterbar",
    "transplanterbarheten": "transplanterbarhet",
    "transplanterbarhetens": "transplanterbarhet",
    "transplanterbarhets": "transplanterbarhet",
    "transplanterbars": "transplanterbar",
    "transplanterbart": "transplanterbar",
    "transplanterbarts": "transplanterbar",
    "transplanteringar": "transplantering",
    "transplanteringarna": "transplantering",
    "transplanteringarnas": "transplantering",
    "transplanteringars": "transplantering",
    "transplanteringen": "transplantering",
    "transplanteringens": "transplantering",
    "transplanterings": "transplantering",
    "transpondern": "transponder",
    "transponderns": "transponder",
    "transponders": "transponder",
    "transpondersarna": "transponder",
    "transpondersarnas": "transponder",
    "transpondersen": "transponder",
    "transpondersens": "transponder",
    "transpondrar": "transponder",
    "transpondrarna": "transponder",
    "transpondrarnas": "transponder",
    "transpondrars": "transponder",
    "transponerad": "transponera",
    "transponerade": "transponera",
    "transponerades": "transponera",
    "transponerads": "transponera",
    "transponerande": "transponera",
    "transponeranden": "transponerande",
    "transponerandena": "transponerande",
    "transponerandenas": "transponerande",
    "transponerandens": "transponerande",
    "transponerandes": "transponerande",
    "transponerandet": "transponerande",
    "transponerandets": "transponerande",
    "transponerar": "transponera",
    "transponeras": "transponera",
    "transponerat": "transponera",
    "transponerats": "transponera",
    "transponerbara": "transponerbar",
    "transponerbarare": "transponerbar",
    "transponerbarares": "transponerbar",
    "transponerbaras": "transponerbar",
    "transponerbarast": "transponerbar",
    "transponerbaraste": "transponerbar",
    "transponerbarastes": "transponerbar",
    "transponerbarasts": "transponerbar",
    "transponerbare": "transponerbar",
    "transponerbares": "transponerbar",
    "transponerbarheten": "transponerbarhet",
    "transponerbarhetens": "transponerbarhet",
    "transponerbarhets": "transponerbarhet",
    "transponerbars": "transponerbar",
    "transponerbart": "transponerbar",
    "transponerbarts": "transponerbar",
    "transponeringar": "transponering",
    "transponeringarna": "transponering",
    "transponeringarnas": "transponering",
    "transponeringars": "transponering",
    "transponeringen": "transponering",
    "transponeringens": "transponering",
    "transponerings": "transponering",
    "transportabels": "transportabel",
    "transportabelt": "transportabel",
    "transportabelts": "transportabel",
    "transportabla": "transportabel",
    "transportablare": "transportabel",
    "transportablares": "transportabel",
    "transportablas": "transportabel",
    "transportablast": "transportabel",
    "transportablaste": "transportabel",
    "transportablastes": "transportabel",
    "transportablasts": "transportabel",
    "transportable": "transportabel",
    "transportables": "transportabel",
    "transportanordningar": "transportanordning",
    "transportanordningarna": "transportanordning",
    "transportanordningarnas": "transportanordning",
    "transportanordningars": "transportanordning",
    "transportanordningen": "transportanordning",
    "transportanordningens": "transportanordning",
    "transportanordnings": "transportanordning",
    "transportarbetar": "transportarbetare",
    "transportarbetaren": "transportarbetare",
    "transportarbetarens": "transportarbetare",
    "transportarbetares": "transportarbetare",
    "transportarbetarna": "transportarbetare",
    "transportarbetarnas": "transportarbetare",
    "transportavtalen": "transportavtal",
    "transportavtalens": "transportavtal",
    "transportavtalet": "transportavtal",
    "transportavtalets": "transportavtal",
    "transportavtals": "transportavtal",
    "transportbanan": "transportbana",
    "transportbanans": "transportbana",
    "transportbanas": "transportbana",
    "transportbanden": "transportband",
    "transportbandens": "transportband",
    "transportbandet": "transportband",
    "transportbandets": "transportband",
    "transportbands": "transportband",
    "transportbane": "transportbana",
    "transportbanor": "transportbana",
    "transportbanorna": "transportbana",
    "transportbanornas": "transportbana",
    "transportbanors": "transportbana",
    "transporten": "transport",
    "transportens": "transport",
    "transporter": "transport",
    "transporterad": "transportera",
    "transporterade": "transportera",
    "transporterades": "transportera",
    "transporterads": "transportera",
    "transporterande": "transportera",
    "transporteranden": "transporterande",
    "transporterandena": "transporterande",
    "transporterandenas": "transporterande",
    "transporterandens": "transporterande",
    "transporterandes": "transporterande",
    "transporterandet": "transporterande",
    "transporterandets": "transporterande",
    "transporterar": "transportera",
    "transporteras": "transportera",
    "transporterat": "transportera",
    "transporterats": "transportera",
    "transporterbara": "transporterbar",
    "transporterbarare": "transporterbar",
    "transporterbarares": "transporterbar",
    "transporterbaras": "transporterbar",
    "transporterbarast": "transporterbar",
    "transporterbaraste": "transporterbar",
    "transporterbarastes": "transporterbar",
    "transporterbarasts": "transporterbar",
    "transporterbare": "transporterbar",
    "transporterbares": "transporterbar",
    "transporterbarheten": "transporterbarhet",
    "transporterbarhetens": "transporterbarhet",
    "transporterbarhets": "transporterbarhet",
    "transporterbars": "transporterbar",
    "transporterbart": "transporterbar",
    "transporterbarts": "transporterbar",
    "transporteringar": "transportering",
    "transporteringarna": "transportering",
    "transporteringarnas": "transportering",
    "transporteringars": "transportering",
    "transporteringen": "transportering",
    "transporteringens": "transportering",
    "transporterings": "transportering",
    "transporterna": "transport",
    "transporternas": "transport",
    "transporters": "transport",
    "transportförbuden": "transportförbud",
    "transportförbudens": "transportförbud",
    "transportförbudet": "transportförbud",
    "transportförbudets": "transportförbud",
    "transportförbuds": "transportförbud",
    "transportföretagen": "transportföretag",
    "transportföretagens": "transportföretag",
    "transportföretaget": "transportföretag",
    "transportföretagets": "transportföretag",
    "transportföretags": "transportföretag",
    "transporthjulen": "transporthjul",
    "transporthjulens": "transporthjul",
    "transporthjulet": "transporthjul",
    "transporthjulets": "transporthjul",
    "transporthjuls": "transporthjul",
    "transportlägen": "transportläge",
    "transportlägena": "transportläge",
    "transportlägenas": "transportläge",
    "transportlägens": "transportläge",
    "transportläges": "transportläge",
    "transportläget": "transportläge",
    "transportlägets": "transportläge",
    "transportmedels": "transportmedel",
    "transportmedlen": "transportmedel",
    "transportmedlens": "transportmedel",
    "transportmedlet": "transportmedel",
    "transportmedlets": "transportmedel",
    "transportmekanismen": "transportmekanism",
    "transportmekanismens": "transportmekanism",
    "transportmekanismer": "transportmekanism",
    "transportmekanismerna": "transportmekanism",
    "transportmekanismernas": "transportmekanism",
    "transportmekanismers": "transportmekanism",
    "transportmekanisms": "transportmekanism",
    "transportmässiga": "transportmässig",
    "transportmässigare": "transportmässig",
    "transportmässigares": "transportmässig",
    "transportmässigas": "transportmässig",
    "transportmässigast": "transportmässig",
    "transportmässigaste": "transportmässig",
    "transportmässigastes": "transportmässig",
    "transportmässigasts": "transportmässig",
    "transportmässige": "transportmässig",
    "transportmässiges": "transportmässig",
    "transportmässigs": "transportmässig",
    "transportmässigt": "transportmässig",
    "transportmässigts": "transportmässig",
    "transportnäten": "transportnät",
    "transportnätens": "transportnät",
    "transportnätet": "transportnät",
    "transportnätets": "transportnät",
    "transportnäts": "transportnät",
    "transportprocessen": "transportprocess",
    "transportprocessens": "transportprocess",
    "transportprocesser": "transportprocess",
    "transportprocesserna": "transportprocess",
    "transportprocessernas": "transportprocess",
    "transportprocessers": "transportprocess",
    "transports": "transport",
    "transportsträck": "transportsträcka",
    "transportsträckan": "transportsträcka",
    "transportsträckans": "transportsträcka",
    "transportsträckas": "transportsträcka",
    "transportsträcke": "transportsträcka",
    "transportsträckor": "transportsträcka",
    "transportsträckorna": "transportsträcka",
    "transportsträckornas": "transportsträcka",
    "transportsträckors": "transportsträcka",
    "transportsträcks": "transportsträcka",
    "transportsystemen": "transportsystem",
    "transportsystemens": "transportsystem",
    "transportsystemet": "transportsystem",
    "transportsystemets": "transportsystem",
    "transportsystems": "transportsystem",
    "transportsäkerheten": "transportsäkerhet",
    "transportsäkerhetens": "transportsäkerhet",
    "transportsäkerheter": "transportsäkerhet",
    "transportsäkerheterna": "transportsäkerhet",
    "transportsäkerheternas": "transportsäkerhet",
    "transportsäkerheters": "transportsäkerhet",
    "transportsäkerhets": "transportsäkerhet",
    "transportvagnar": "transportvagn",
    "transportvagnarna": "transportvagn",
    "transportvagnarnas": "transportvagn",
    "transportvagnars": "transportvagn",
    "transportvagnen": "transportvagn",
    "transportvagnens": "transportvagn",
    "transportvagns": "transportvagn",
    "transportväsendet": "transportväsen",
    "transportväsendets": "transportväsen",
    "transportväsenet": "transportväsen",
    "transportväsenets": "transportväsen",
    "transportväsens": "transportväsen",
    "transportören": "transportör",
    "transportörens": "transportör",
    "transportörer": "transportör",
    "transportörerna": "transportör",
    "transportörernas": "transportör",
    "transportörers": "transportör",
    "transportörs": "transportör",
    "transpositionen": "transposition",
    "transpositionens": "transposition",
    "transpositioner": "transposition",
    "transpositionerna": "transposition",
    "transpositionernas": "transposition",
    "transpositioners": "transposition",
    "transpositions": "transposition",
    "transsexuella": "transsexuell",
    "transsexuellare": "transsexuell",
    "transsexuellares": "transsexuell",
    "transsexuellas": "transsexuell",
    "transsexuellast": "transsexuell",
    "transsexuellaste": "transsexuell",
    "transsexuellastes": "transsexuell",
    "transsexuellasts": "transsexuell",
    "transsexuelle": "transsexuell",
    "transsexuelles": "transsexuell",
    "transsexuells": "transsexuell",
    "transsexuellt": "transsexuell",
    "transsexuellts": "transsexuell",
    "transsibiriska": "transsibirisk",
    "transsibiriskare": "transsibirisk",
    "transsibiriskares": "transsibirisk",
    "transsibiriskas": "transsibirisk",
    "transsibiriskast": "transsibirisk",
    "transsibiriskaste": "transsibirisk",
    "transsibiriskastes": "transsibirisk",
    "transsibiriskasts": "transsibirisk",
    "transsibiriske": "transsibirisk",
    "transsibiriskes": "transsibirisk",
    "transsibirisks": "transsibirisk",
    "transsibiriskt": "transsibirisk",
    "transsibiriskts": "transsibirisk",
    "transsubstantiationen": "transsubstantiation",
    "transsubstantiationens": "transsubstantiation",
    "transsubstantiationer": "transsubstantiation",
    "transsubstantiationerna": "transsubstantiation",
    "transsubstantiationernas": "transsubstantiation",
    "transsubstantiationers": "transsubstantiation",
    "transsubstantiations": "transsubstantiation",
    "transsubstantiationsläran": "transsubstantiationslära",
    "transsubstantiationslärans": "transsubstantiationslära",
    "transsubstantiationsläras": "transsubstantiationslära",
    "transsubstantiationsläre": "transsubstantiationslära",
    "transsubstantiationsläror": "transsubstantiationslära",
    "transsubstantiationslärorna": "transsubstantiationslära",
    "transsubstantiationslärornas": "transsubstantiationslära",
    "transsubstantiationslärors": "transsubstantiationslära",
    "transsubstantierades": "transsubstantieras",
    "transsubstantierats": "transsubstantieras",
    "transubstantiationen": "transubstantiation",
    "transubstantiationens": "transubstantiation",
    "transubstantiationer": "transubstantiation",
    "transubstantiationerna": "transubstantiation",
    "transubstantiationernas": "transubstantiation",
    "transubstantiationers": "transubstantiation",
    "transubstantiations": "transubstantiation",
    "transubstantiationsläran": "transubstantiationslära",
    "transubstantiationslärans": "transubstantiationslära",
    "transubstantiationsläras": "transubstantiationslära",
    "transubstantiationsläre": "transubstantiationslära",
    "transubstantiationsläror": "transubstantiationslära",
    "transubstantiationslärorna": "transubstantiationslära",
    "transubstantiationslärornas": "transubstantiationslära",
    "transubstantiationslärors": "transubstantiationslära",
    "transubstantierades": "transubstantieras",
    "transubstantierats": "transubstantieras",
    "transumerad": "transumera",
    "transumerade": "transumera",
    "transumerades": "transumera",
    "transumerads": "transumera",
    "transumerande": "transumera",
    "transumeranden": "transumerande",
    "transumerandena": "transumerande",
    "transumerandenas": "transumerande",
    "transumerandens": "transumerande",
    "transumerandes": "transumerande",
    "transumerandet": "transumerande",
    "transumerandets": "transumerande",
    "transumerar": "transumera",
    "transumeras": "transumera",
    "transumerat": "transumera",
    "transumerats": "transumera",
    "transumerbara": "transumerbar",
    "transumerbarare": "transumerbar",
    "transumerbarares": "transumerbar",
    "transumerbaras": "transumerbar",
    "transumerbarast": "transumerbar",
    "transumerbaraste": "transumerbar",
    "transumerbarastes": "transumerbar",
    "transumerbarasts": "transumerbar",
    "transumerbare": "transumerbar",
    "transumerbares": "transumerbar",
    "transumerbarheten": "transumerbarhet",
    "transumerbarhetens": "transumerbarhet",
    "transumerbarhets": "transumerbarhet",
    "transumerbars": "transumerbar",
    "transumerbart": "transumerbar",
    "transumerbarts": "transumerbar",
    "transumeringar": "transumering",
    "transumeringarna": "transumering",
    "transumeringarnas": "transumering",
    "transumeringars": "transumering",
    "transumeringen": "transumering",
    "transumeringens": "transumering",
    "transumerings": "transumering",
    "transumten": "transumt",
    "transumtens": "transumt",
    "transumtet": "transumt",
    "transumtets": "transumt",
    "transumts": "transumt",
    "transuranen": "transuran",
    "transuranens": "transuran",
    "transuraner": "transuran",
    "transuranerna": "transuran",
    "transuranernas": "transuran",
    "transuraners": "transuran",
    "transuranet": "transuran",
    "transuranets": "transuran",
    "transurans": "transuran",
    "transversala": "transversal",
    "transversalare": "transversal",
    "transversalares": "transversal",
    "transversalas": "transversal",
    "transversalast": "transversal",
    "transversalaste": "transversal",
    "transversalastes": "transversal",
    "transversalasts": "transversal",
    "transversalaxeln": "transversalaxel",
    "transversalaxelns": "transversalaxel",
    "transversalaxels": "transversalaxel",
    "transversalaxlar": "transversalaxel",
    "transversalaxlarna": "transversalaxel",
    "transversalaxlarnas": "transversalaxel",
    "transversalaxlars": "transversalaxel",
    "transversale": "transversal",
    "transversalen": "transversal",
    "transversalens": "transversal",
    "transversaler": "transversal",
    "transversalerna": "transversal",
    "transversalernas": "transversal",
    "transversalers": "transversal",
    "transversales": "transversal",
    "transversals": "transversal",
    "transversalt": "transversal",
    "transversalts": "transversal",
    "transversella": "transversell",
    "transversellare": "transversell",
    "transversellares": "transversell",
    "transversellas": "transversell",
    "transversellast": "transversell",
    "transversellaste": "transversell",
    "transversellastes": "transversell",
    "transversellasts": "transversell",
    "transverselle": "transversell",
    "transverselles": "transversell",
    "transversells": "transversell",
    "transversellt": "transversell",
    "transversellts": "transversell",
    "transvestismen": "transvestism",
    "transvestismens": "transvestism",
    "transvestismer": "transvestism",
    "transvestismerna": "transvestism",
    "transvestismernas": "transvestism",
    "transvestismers": "transvestism",
    "transvestisms": "transvestism",
    "transvestiten": "transvestit",
    "transvestitens": "transvestit",
    "transvestiter": "transvestit",
    "transvestiterna": "transvestit",
    "transvestiternas": "transvestit",
    "transvestiters": "transvestit",
    "transvestitismen": "transvestitism",
    "transvestitismens": "transvestitism",
    "transvestitismer": "transvestitism",
    "transvestitismerna": "transvestitism",
    "transvestitismernas": "transvestitism",
    "transvestitismers": "transvestitism",
    "transvestitisms": "transvestitism",
    "transvestits": "transvestit",
    "trapetsen": "trapets",
    "trapetsens": "trapets",
    "trapetser": "trapets",
    "trapetserna": "trapets",
    "trapetsernas": "trapets",
    "trapetsers": "trapets",
    "trapetset": "trapets",
    "trapetsets": "trapets",
    "trapetsoiden": "trapetsoid",
    "trapetsoidens": "trapetsoid",
    "trapetsoider": "trapetsoid",
    "trapetsoiderna": "trapetsoid",
    "trapetsoidernas": "trapetsoid",
    "trapetsoiders": "trapetsoid",
    "trapetsoids": "trapetsoid",
    "trapp": "trappa",
    "trappan": "trappa",
    "trappans": "trappa",
    "trappar": "trapp",
    "trapparna": "trapp",
    "trapparnas": "trapp",
    "trappars": "trapp",
    "trappas": "trappa",
    "trappavsatsen": "trappavsats",
    "trappavsatsens": "trappavsats",
    "trappavsatser": "trappavsats",
    "trappavsatserna": "trappavsats",
    "trappavsatsernas": "trappavsats",
    "trappavsatsers": "trappavsats",
    "trappe": "trappa",
    "trappen": "trapp",
    "trappens": "trapp",
    "trappern": "trapper",
    "trapperna": "trapper",
    "trappernas": "trapper",
    "trapperns": "trapper",
    "trappers": "trapper",
    "trappfunktionen": "trappfunktion",
    "trappfunktionens": "trappfunktion",
    "trappfunktioner": "trappfunktion",
    "trappfunktionerna": "trappfunktion",
    "trappfunktionernas": "trappfunktion",
    "trappfunktioners": "trappfunktion",
    "trappfunktions": "trappfunktion",
    "trappgaveln": "trappgavel",
    "trappgavelns": "trappgavel",
    "trappgavels": "trappgavel",
    "trappgavlar": "trappgavel",
    "trappgavlarna": "trappgavel",
    "trappgavlarnas": "trappgavel",
    "trappgavlars": "trappgavel",
    "trapphusen": "trapphus",
    "trapphusens": "trapphus",
    "trapphuset": "trapphus",
    "trapphusets": "trapphus",
    "trappkärr": "trappkärra",
    "trappkärran": "trappkärra",
    "trappkärrans": "trappkärra",
    "trappkärras": "trappkärra",
    "trappkärre": "trappkärra",
    "trappkärror": "trappkärra",
    "trappkärrorna": "trappkärra",
    "trappkärrornas": "trappkärra",
    "trappkärrors": "trappkärra",
    "trappkärrs": "trappkärra",
    "trappor": "trappa",
    "trapporna": "trappa",
    "trappornas": "trappa",
    "trappors": "trappa",
    "trappräcken": "trappräcke",
    "trappräckena": "trappräcke",
    "trappräckenas": "trappräcke",
    "trappräckens": "trappräcke",
    "trappräckes": "trappräcke",
    "trappräcket": "trappräcke",
    "trappräckets": "trappräcke",
    "trapps": "trappa",
    "trappskivan": "trappskiva",
    "trappskivans": "trappskiva",
    "trappskivas": "trappskiva",
    "trappskive": "trappskiva",
    "trappskivor": "trappskiva",
    "trappskivorna": "trappskiva",
    "trappskivornas": "trappskiva",
    "trappskivors": "trappskiva",
    "trappsmygar": "trappsmyg",
    "trappsmygarna": "trappsmyg",
    "trappsmygarnas": "trappsmyg",
    "trappsmygars": "trappsmyg",
    "trappsmygen": "trappsmyg",
    "trappsmygens": "trappsmyg",
    "trappsmygs": "trappsmyg",
    "trappsteg": "trappstege",
    "trappstegar": "trappstege",
    "trappstegarna": "trappstege",
    "trappstegarnas": "trappstege",
    "trappstegars": "trappstege",
    "trappstegen": "trappstege",
    "trappstegens": "trappstege",
    "trappsteges": "trappstege",
    "trappsteget": "trappsteg",
    "trappstegets": "trappsteg",
    "trappstegs": "trappstege",
    "trappstegsformade": "trappstegsformad",
    "trappstegsformades": "trappstegsformad",
    "trappstegsformads": "trappstegsformad",
    "trappstegsformat": "trappstegsformad",
    "trappstegsformats": "trappstegsformad",
    "trappstädningen": "trappstädning",
    "trappstädningens": "trappstädning",
    "trappstädnings": "trappstädning",
    "trapptornen": "trapptorn",
    "trapptornens": "trapptorn",
    "trapptornet": "trapptorn",
    "trapptornets": "trapptorn",
    "trapptorns": "trapptorn",
    "trappuppgångar": "trappuppgång",
    "trappuppgångarna": "trappuppgång",
    "trappuppgångarnas": "trappuppgång",
    "trappuppgångars": "trappuppgång",
    "trappuppgången": "trappuppgång",
    "trappuppgångens": "trappuppgång",
    "trappuppgångs": "trappuppgång",
    "tras": "trasa",
    "trasad": "trasa",
    "trasade": "trasa",
    "trasades": "trasa",
    "trasads": "trasa",
    "trasan": "trasa",
    "trasande": "trasa",
    "trasanden": "trasande",
    "trasandena": "trasande",
    "trasandenas": "trasande",
    "trasandens": "trasande",
    "trasandes": "trasande",
    "trasandet": "trasande",
    "trasandets": "trasande",
    "trasans": "trasa",
    "trasar": "trasa",
    "trasas": "trasa",
    "trasat": "trasa",
    "trasats": "trasa",
    "trasdock": "trasdocka",
    "trasdockan": "trasdocka",
    "trasdockans": "trasdocka",
    "trasdockas": "trasdocka",
    "trasdocke": "trasdocka",
    "trasdockor": "trasdocka",
    "trasdockorna": "trasdocka",
    "trasdockornas": "trasdocka",
    "trasdockors": "trasdocka",
    "trasdocks": "trasdocka",
    "trase": "trasa",
    "traselegansen": "traselegans",
    "traselegansens": "traselegans",
    "traseleganta": "traselegant",
    "traselegantare": "traselegant",
    "traselegantares": "traselegant",
    "traselegantas": "traselegant",
    "traselegantast": "traselegant",
    "traselegantaste": "traselegant",
    "traselegantastes": "traselegant",
    "traselegantasts": "traselegant",
    "traselegante": "traselegant",
    "traselegantes": "traselegant",
    "traselegants": "traselegant",
    "trasgranna": "trasgrann",
    "trasgrannare": "trasgrann",
    "trasgrannares": "trasgrann",
    "trasgrannas": "trasgrann",
    "trasgrannast": "trasgrann",
    "trasgrannaste": "trasgrann",
    "trasgrannastes": "trasgrann",
    "trasgrannasts": "trasgrann",
    "trasgranne": "trasgrann",
    "trasgrannes": "trasgrann",
    "trasgranns": "trasgrann",
    "trasgrant": "trasgrann",
    "trasgrants": "trasgrann",
    "trashad": "trasha",
    "trashade": "trasha",
    "trashades": "trasha",
    "trashads": "trasha",
    "trashande": "trasha",
    "trashanden": "trashande",
    "trashandena": "trashande",
    "trashandenas": "trashande",
    "trashandens": "trashande",
    "trashandes": "trashande",
    "trashandet": "trashande",
    "trashandets": "trashande",
    "trashankar": "trashank",
    "trashankarna": "trashank",
    "trashankarnas": "trashank",
    "trashankars": "trashank",
    "trashanken": "trashank",
    "trashankens": "trashank",
    "trashanks": "trashank",
    "trashar": "trasha",
    "trashas": "trasha",
    "trashat": "trasha",
    "trashats": "trasha",
    "trasiga": "trasig",
    "trasigare": "trasig",
    "trasigares": "trasig",
    "trasigas": "trasig",
    "trasigast": "trasig",
    "trasigaste": "trasig",
    "trasigastes": "trasig",
    "trasigasts": "trasig",
    "trasige": "trasig",
    "trasiges": "trasig",
    "trasigs": "trasig",
    "trasigt": "trasig",
    "trasigts": "trasig",
    "trask": "traska",
    "traskad": "traska",
    "traskade": "traska",
    "traskades": "traska",
    "traskads": "traska",
    "traskande": "traska",
    "traskanden": "traskande",
    "traskandena": "traskande",
    "traskandenas": "traskande",
    "traskandens": "traskande",
    "traskandes": "traskande",
    "traskandet": "traskande",
    "traskandets": "traskande",
    "traskar": "traska",
    "traskas": "traska",
    "traskat": "traska",
    "traskats": "traska",
    "trasmaj": "trasmaja",
    "trasmajan": "trasmaja",
    "trasmajans": "trasmaja",
    "trasmajas": "trasmaja",
    "trasmaje": "trasmaja",
    "trasmajor": "trasmaja",
    "trasmajorna": "trasmaja",
    "trasmajornas": "trasmaja",
    "trasmajors": "trasmaja",
    "trasmajs": "trasmaja",
    "trasmatt": "trasmatta",
    "trasmattan": "trasmatta",
    "trasmattans": "trasmatta",
    "trasmattas": "trasmatta",
    "trasmatte": "trasmatta",
    "trasmattor": "trasmatta",
    "trasmattorna": "trasmatta",
    "trasmattornas": "trasmatta",
    "trasmattors": "trasmatta",
    "trasmatts": "trasmatta",
    "trasor": "trasa",
    "trasorna": "trasa",
    "trasornas": "trasa",
    "trasors": "trasa",
    "trasproletariatet": "trasproletariat",
    "trasproletariatets": "trasproletariat",
    "trasproletariats": "trasproletariat",
    "trassaten": "trassat",
    "trassatens": "trassat",
    "trassater": "trassat",
    "trassaterna": "trassat",
    "trassaternas": "trassat",
    "trassaters": "trassat",
    "trassats": "trassat",
    "trassel": "trassla",
    "trassels": "trassel",
    "trasselsuddar": "trasselsudd",
    "trasselsuddarna": "trasselsudd",
    "trasselsuddarnas": "trasselsudd",
    "trasselsuddars": "trasselsudd",
    "trasselsudden": "trasselsudd",
    "trasselsuddens": "trasselsudd",
    "trasselsudds": "trasselsudd",
    "trassenten": "trassent",
    "trassentens": "trassent",
    "trassenter": "trassent",
    "trassenterna": "trassent",
    "trassenternas": "trassent",
    "trassenters": "trassent",
    "trassents": "trassent",
    "trasserad": "trassera",
    "trasserade": "trassera",
    "trasserades": "trassera",
    "trasserads": "trassera",
    "trasserande": "trassera",
    "trasseranden": "trasserande",
    "trasserandena": "trasserande",
    "trasserandenas": "trasserande",
    "trasserandens": "trasserande",
    "trasserandes": "trasserande",
    "trasserandet": "trasserande",
    "trasserandets": "trasserande",
    "trasserar": "trassera",
    "trasseras": "trassera",
    "trasserat": "trassera",
    "trasserats": "trassera",
    "trasserbara": "trasserbar",
    "trasserbarare": "trasserbar",
    "trasserbarares": "trasserbar",
    "trasserbaras": "trasserbar",
    "trasserbarast": "trasserbar",
    "trasserbaraste": "trasserbar",
    "trasserbarastes": "trasserbar",
    "trasserbarasts": "trasserbar",
    "trasserbare": "trasserbar",
    "trasserbares": "trasserbar",
    "trasserbarheten": "trasserbarhet",
    "trasserbarhetens": "trasserbarhet",
    "trasserbarhets": "trasserbarhet",
    "trasserbars": "trasserbar",
    "trasserbart": "trasserbar",
    "trasserbarts": "trasserbar",
    "trasseringar": "trassering",
    "trasseringarna": "trassering",
    "trasseringarnas": "trassering",
    "trasseringars": "trassering",
    "trasseringen": "trassering",
    "trasseringens": "trassering",
    "trasserings": "trassering",
    "trasslad": "trassla",
    "trasslade": "trassla",
    "trasslades": "trassla",
    "trasslads": "trassla",
    "trasslande": "trassla",
    "trasslanden": "trasslande",
    "trasslandena": "trasslande",
    "trasslandenas": "trasslande",
    "trasslandens": "trasslande",
    "trasslandes": "trasslande",
    "trasslandet": "trasslande",
    "trasslandets": "trasslande",
    "trasslar": "trassla",
    "trasslas": "trassla",
    "trasslat": "trassla",
    "trasslats": "trassla",
    "trasslet": "trassel",
    "trasslets": "trassel",
    "trassliga": "trasslig",
    "trassligare": "trasslig",
    "trassligares": "trasslig",
    "trassligas": "trasslig",
    "trassligast": "trasslig",
    "trassligaste": "trasslig",
    "trassligastes": "trasslig",
    "trassligasts": "trasslig",
    "trasslige": "trasslig",
    "trassliges": "trasslig",
    "trassligheten": "trasslighet",
    "trasslighetens": "trasslighet",
    "trassligheter": "trasslighet",
    "trassligheterna": "trasslighet",
    "trassligheternas": "trasslighet",
    "trassligheters": "trasslighet",
    "trasslighets": "trasslighet",
    "trassligs": "trasslig",
    "trassligt": "trasslig",
    "trassligts": "trasslig",
    "trastar": "trast",
    "trastarna": "trast",
    "trastarnas": "trast",
    "trastars": "trast",
    "trasten": "trast",
    "trastens": "trast",
    "trastfågeln": "trastfågel",
    "trastfågelns": "trastfågel",
    "trastfågels": "trastfågel",
    "trastfåglar": "trastfågel",
    "trastfåglarna": "trastfågel",
    "trastfåglarnas": "trastfågel",
    "trastfåglars": "trastfågel",
    "trasts": "trast",
    "trasungar": "trasunge",
    "trasungarna": "trasunge",
    "trasungarnas": "trasunge",
    "trasungars": "trasunge",
    "trasungen": "trasunge",
    "trasungens": "trasunge",
    "trasunges": "trasunge",
    "tratt": "tratta",
    "trattad": "tratta",
    "trattade": "tratta",
    "trattades": "tratta",
    "trattads": "tratta",
    "trattan": "tratta",
    "trattande": "tratta",
    "trattanden": "trattande",
    "trattandena": "trattande",
    "trattandenas": "trattande",
    "trattandens": "trattande",
    "trattandes": "trattande",
    "trattandet": "trattande",
    "trattandets": "trattande",
    "trattans": "tratta",
    "trattar": "tratta",
    "trattarna": "tratt",
    "trattarnas": "tratt",
    "trattars": "tratt",
    "trattas": "tratta",
    "trattat": "tratta",
    "trattats": "tratta",
    "tratte": "tratta",
    "tratten": "tratt",
    "trattens": "tratt",
    "trattformiga": "trattformig",
    "trattformigare": "trattformig",
    "trattformigares": "trattformig",
    "trattformigas": "trattformig",
    "trattformigast": "trattformig",
    "trattformigaste": "trattformig",
    "trattformigastes": "trattformig",
    "trattformigasts": "trattformig",
    "trattformige": "trattformig",
    "trattformiges": "trattformig",
    "trattformigheten": "trattformighet",
    "trattformighetens": "trattformighet",
    "trattformighets": "trattformighet",
    "trattformigs": "trattformig",
    "trattformigt": "trattformig",
    "trattformigts": "trattformig",
    "trattkantarellen": "trattkantarell",
    "trattkantarellens": "trattkantarell",
    "trattkantareller": "trattkantarell",
    "trattkantarellerna": "trattkantarell",
    "trattkantarellernas": "trattkantarell",
    "trattkantarellers": "trattkantarell",
    "trattkantarells": "trattkantarell",
    "trattor": "tratta",
    "trattorna": "tratta",
    "trattornas": "tratta",
    "trattors": "tratta",
    "trattprickar": "trattprick",
    "trattprickarna": "trattprick",
    "trattprickarnas": "trattprick",
    "trattprickars": "trattprick",
    "trattpricken": "trattprick",
    "trattprickens": "trattprick",
    "trattpricks": "trattprick",
    "tratts": "tratta",
    "trattskivlingar": "trattskivling",
    "trattskivlingarna": "trattskivling",
    "trattskivlingarnas": "trattskivling",
    "trattskivlingars": "trattskivling",
    "trattskivlingen": "trattskivling",
    "trattskivlingens": "trattskivling",
    "trattskivlings": "trattskivling",
    "trauman": "trauma",
    "traumana": "trauma",
    "traumanas": "trauma",
    "traumans": "trauma",
    "traumas": "trauma",
    "traumat": "trauma",
    "traumatiska": "traumatisk",
    "traumatiskare": "traumatisk",
    "traumatiskares": "traumatisk",
    "traumatiskas": "traumatisk",
    "traumatiskast": "traumatisk",
    "traumatiskaste": "traumatisk",
    "traumatiskastes": "traumatisk",
    "traumatiskasts": "traumatisk",
    "traumatiske": "traumatisk",
    "traumatiskes": "traumatisk",
    "traumatisks": "traumatisk",
    "traumatiskt": "traumatisk",
    "traumatiskts": "traumatisk",
    "traumats": "trauma",
    "traumer": "trauma",
    "traumerna": "trauma",
    "traumernas": "trauma",
    "traumers": "trauma",
    "trav": "trave",
    "travad": "trava",
    "travade": "trava",
    "travades": "trava",
    "travads": "trava",
    "travande": "trava",
    "travanden": "travande",
    "travandena": "travande",
    "travandenas": "travande",
    "travandens": "travande",
    "travandes": "travande",
    "travandet": "travande",
    "travandets": "travande",
    "travar": "trave",
    "travaren": "travare",
    "travarens": "travare",
    "travares": "travare",
    "travarna": "trave",
    "travarnas": "trave",
    "travars": "trave",
    "travas": "trava",
    "travat": "trava",
    "travats": "trava",
    "travbanan": "travbana",
    "travbanans": "travbana",
    "travbanas": "travbana",
    "travbane": "travbana",
    "travbanor": "travbana",
    "travbanorna": "travbana",
    "travbanornas": "travbana",
    "travbanors": "travbana",
    "traven": "trave",
    "travens": "trave",
    "traversen": "travers",
    "traversens": "travers",
    "traverser": "travers",
    "traverserna": "travers",
    "traversernas": "travers",
    "traversers": "travers",
    "traves": "trave",
    "travesterad": "travestera",
    "travesterade": "travestera",
    "travesterades": "travestera",
    "travesterads": "travestera",
    "travesterande": "travestera",
    "travesteranden": "travesterande",
    "travesterandena": "travesterande",
    "travesterandenas": "travesterande",
    "travesterandens": "travesterande",
    "travesterandes": "travesterande",
    "travesterandet": "travesterande",
    "travesterandets": "travesterande",
    "travesterar": "travestera",
    "travesteras": "travestera",
    "travesterat": "travestera",
    "travesterats": "travestera",
    "travesterbara": "travesterbar",
    "travesterbarare": "travesterbar",
    "travesterbarares": "travesterbar",
    "travesterbaras": "travesterbar",
    "travesterbarast": "travesterbar",
    "travesterbaraste": "travesterbar",
    "travesterbarastes": "travesterbar",
    "travesterbarasts": "travesterbar",
    "travesterbare": "travesterbar",
    "travesterbares": "travesterbar",
    "travesterbarheten": "travesterbarhet",
    "travesterbarhetens": "travesterbarhet",
    "travesterbarhets": "travesterbarhet",
    "travesterbars": "travesterbar",
    "travesterbart": "travesterbar",
    "travesterbarts": "travesterbar",
    "travesteringar": "travestering",
    "travesteringarna": "travestering",
    "travesteringarnas": "travestering",
    "travesteringars": "travestering",
    "travesteringen": "travestering",
    "travesteringens": "travestering",
    "travesterings": "travestering",
    "travestien": "travesti",
    "travestiens": "travesti",
    "travestier": "travesti",
    "travestierna": "travesti",
    "travestiernas": "travesti",
    "travestiers": "travesti",
    "travestin": "travesti",
    "travestins": "travesti",
    "travestis": "travesti",
    "travet": "trav",
    "travets": "trav",
    "travhästar": "travhäst",
    "travhästarna": "travhäst",
    "travhästarnas": "travhäst",
    "travhästars": "travhäst",
    "travhästen": "travhäst",
    "travhästens": "travhäst",
    "travhästs": "travhäst",
    "travs": "trave",
    "travsporten": "travsport",
    "travsportens": "travsport",
    "travsports": "travsport",
    "travtävlingar": "travtävling",
    "travtävlingarna": "travtävling",
    "travtävlingarnas": "travtävling",
    "travtävlingars": "travtävling",
    "travtävlingen": "travtävling",
    "travtävlingens": "travtävling",
    "travtävlings": "travtävling",
    "treaktar": "treaktare",
    "treaktaren": "treaktare",
    "treaktarens": "treaktare",
    "treaktares": "treaktare",
    "treaktarna": "treaktare",
    "treaktarnas": "treaktare",
    "trean": "trea",
    "treans": "trea",
    "treas": "trea",
    "trebenta": "trebent",
    "trebentare": "trebent",
    "trebentares": "trebent",
    "trebentas": "trebent",
    "trebentast": "trebent",
    "trebentaste": "trebent",
    "trebentastes": "trebent",
    "trebentasts": "trebent",
    "trebente": "trebent",
    "trebentes": "trebent",
    "trebentheten": "trebenthet",
    "trebenthetens": "trebenthet",
    "trebenthets": "trebenthet",
    "trebents": "trebent",
    "trebetygskursen": "trebetygskurs",
    "trebetygskursens": "trebetygskurs",
    "trebetygskurser": "trebetygskurs",
    "trebetygskurserna": "trebetygskurs",
    "trebetygskursernas": "trebetygskurs",
    "trebetygskursers": "trebetygskurs",
    "tredagarsfebern": "tredagarsfeber",
    "tredagarsfeberns": "tredagarsfeber",
    "tredagarsfebers": "tredagarsfeber",
    "tredelade": "tredelad",
    "tredelades": "tredelad",
    "tredelads": "tredelad",
    "tredelat": "tredelad",
    "tredelats": "tredelad",
    "tredelningar": "tredelning",
    "tredelningarna": "tredelning",
    "tredelningarnas": "tredelning",
    "tredelningars": "tredelning",
    "tredelningen": "tredelning",
    "tredelningens": "tredelning",
    "tredelnings": "tredelning",
    "tredimensionella": "tredimensionell",
    "tredimensionellare": "tredimensionell",
    "tredimensionellares": "tredimensionell",
    "tredimensionellas": "tredimensionell",
    "tredimensionellast": "tredimensionell",
    "tredimensionellaste": "tredimensionell",
    "tredimensionellastes": "tredimensionell",
    "tredimensionellasts": "tredimensionell",
    "tredimensionelle": "tredimensionell",
    "tredimensionelles": "tredimensionell",
    "tredimensionells": "tredimensionell",
    "tredimensionellt": "tredimensionell",
    "tredimensionellts": "tredimensionell",
    "tredje": "tre",
    "tredjedagar": "tredjedag",
    "tredjedagarna": "tredjedag",
    "tredjedagarnas": "tredjedag",
    "tredjedagars": "tredjedag",
    "tredjedagen": "tredjedag",
    "tredjedagens": "tredjedag",
    "tredjedags": "tredjedag",
    "tredjedagsfrossan": "tredjedagsfrossa",
    "tredjedagsfrossans": "tredjedagsfrossa",
    "tredjedagsfrossas": "tredjedagsfrossa",
    "tredjedelar": "tredjedel",
    "tredjedelarna": "tredjedel",
    "tredjedelarnas": "tredjedel",
    "tredjedelars": "tredjedel",
    "tredjedelen": "tredjedel",
    "tredjedelens": "tredjedel",
    "tredjedels": "tredjedel",
    "tredjegångstillsättningar": "tredjegångstillsättning",
    "tredjegångstillsättningarna": "tredjegångstillsättning",
    "tredjegångstillsättningarnas": "tredjegångstillsättning",
    "tredjegångstillsättningars": "tredjegångstillsättning",
    "tredjegångstillsättningen": "tredjegångstillsättning",
    "tredjegångstillsättningens": "tredjegångstillsättning",
    "tredjegångstillsättnings": "tredjegångstillsättning",
    "tredjeopponenten": "tredjeopponent",
    "tredjeopponentens": "tredjeopponent",
    "tredjeopponenter": "tredjeopponent",
    "tredjeopponenterna": "tredjeopponent",
    "tredjeopponenternas": "tredjeopponent",
    "tredjeopponenters": "tredjeopponent",
    "tredjeopponents": "tredjeopponent",
    "tredjeplatsen": "tredjeplats",
    "tredjeplatsens": "tredjeplats",
    "tredjeplatser": "tredjeplats",
    "tredjeplatserna": "tredjeplats",
    "tredjeplatsernas": "tredjeplats",
    "tredjeplatsers": "tredjeplats",
    "tredjes": "tre",
    "tredska": "tredsk",
    "tredskades": "tredskas",
    "tredskan": "tredska",
    "tredskans": "tredska",
    "tredskare": "tredsk",
    "tredskares": "tredsk",
    "tredskas": "tredska",
    "tredskast": "tredsk",
    "tredskaste": "tredsk",
    "tredskastes": "tredsk",
    "tredskasts": "tredsk",
    "tredskats": "tredskas",
    "tredske": "tredsk",
    "tredskes": "tredsk",
    "tredskheten": "tredskhet",
    "tredskhetens": "tredskhet",
    "tredskhets": "tredskhet",
    "tredskodomar": "tredskodom",
    "tredskodomarna": "tredskodom",
    "tredskodomarnas": "tredskodom",
    "tredskodomars": "tredskodom",
    "tredskodomen": "tredskodom",
    "tredskodomens": "tredskodom",
    "tredskodoms": "tredskodom",
    "tredsks": "tredsk",
    "tredskt": "tredsk",
    "tredskts": "tredsk",
    "tredubbels": "tredubbel",
    "tredubbelt": "tredubbel",
    "tredubbelts": "tredubbel",
    "tredubbla": "tredubbel",
    "tredubblad": "tredubbla",
    "tredubblade": "tredubbla",
    "tredubblades": "tredubbla",
    "tredubblads": "tredubbla",
    "tredubblande": "tredubbla",
    "tredubblanden": "tredubblande",
    "tredubblandena": "tredubblande",
    "tredubblandenas": "tredubblande",
    "tredubblandens": "tredubblande",
    "tredubblandes": "tredubblande",
    "tredubblandet": "tredubblande",
    "tredubblandets": "tredubblande",
    "tredubblar": "tredubbla",
    "tredubblare": "tredubbel",
    "tredubblares": "tredubbel",
    "tredubblas": "tredubbla",
    "tredubblast": "tredubbel",
    "tredubblaste": "tredubbel",
    "tredubblastes": "tredubbel",
    "tredubblasts": "tredubbel",
    "tredubblat": "tredubbla",
    "tredubblats": "tredubbla",
    "tredubble": "tredubbel",
    "tredubbles": "tredubbel",
    "tredubblingar": "tredubbling",
    "tredubblingarna": "tredubbling",
    "tredubblingarnas": "tredubbling",
    "tredubblingars": "tredubbling",
    "tredubblingen": "tredubbling",
    "tredubblingens": "tredubbling",
    "tredubblings": "tredubbling",
    "treeniga": "treenig",
    "treenigare": "treenig",
    "treenigares": "treenig",
    "treenigas": "treenig",
    "treenigast": "treenig",
    "treenigaste": "treenig",
    "treenigastes": "treenig",
    "treenigasts": "treenig",
    "treenige": "treenig",
    "treeniges": "treenig",
    "treenigheten": "treenighet",
    "treenighetens": "treenighet",
    "treenigheter": "treenighet",
    "treenigheterna": "treenighet",
    "treenigheternas": "treenighet",
    "treenigheters": "treenighet",
    "treenighets": "treenighet",
    "treenighetsmystiken": "treenighetsmystik",
    "treenighetsmystikens": "treenighetsmystik",
    "treenighetsmystiks": "treenighetsmystik",
    "treenigs": "treenig",
    "treenigt": "treenig",
    "treenigts": "treenig",
    "trefalden": "trefald",
    "trefaldens": "trefald",
    "trefalder": "trefald",
    "trefalderna": "trefald",
    "trefaldernas": "trefald",
    "trefalders": "trefald",
    "trefaldig": "trefaldiga",
    "trefaldiga": "trefaldig",
    "trefaldigad": "trefaldiga",
    "trefaldigade": "trefaldiga",
    "trefaldigades": "trefaldiga",
    "trefaldigads": "trefaldiga",
    "trefaldigande": "trefaldiga",
    "trefaldiganden": "trefaldigande",
    "trefaldigandena": "trefaldigande",
    "trefaldigandenas": "trefaldigande",
    "trefaldigandens": "trefaldigande",
    "trefaldigandes": "trefaldigande",
    "trefaldigandet": "trefaldigande",
    "trefaldigandets": "trefaldigande",
    "trefaldigar": "trefaldiga",
    "trefaldigare": "trefaldig",
    "trefaldigares": "trefaldig",
    "trefaldigas": "trefaldiga",
    "trefaldigast": "trefaldig",
    "trefaldigaste": "trefaldig",
    "trefaldigastes": "trefaldig",
    "trefaldigasts": "trefaldig",
    "trefaldigat": "trefaldiga",
    "trefaldigats": "trefaldiga",
    "trefaldige": "trefaldig",
    "trefaldiges": "trefaldig",
    "trefaldigheten": "trefaldighet",
    "trefaldighetens": "trefaldighet",
    "trefaldigheter": "trefaldighet",
    "trefaldigheterna": "trefaldighet",
    "trefaldigheternas": "trefaldighet",
    "trefaldigheters": "trefaldighet",
    "trefaldighets": "trefaldighet",
    "trefaldighetssöndagen": "trefaldighetssöndag",
    "trefaldighetssöndagens": "trefaldighetssöndag",
    "trefaldighetssöndags": "trefaldighetssöndag",
    "trefaldigs": "trefaldig",
    "trefaldigt": "trefaldig",
    "trefaldigts": "trefaldig",
    "trefalds": "trefald",
    "trefasiga": "trefasig",
    "trefasigare": "trefasig",
    "trefasigares": "trefasig",
    "trefasigas": "trefasig",
    "trefasigast": "trefasig",
    "trefasigaste": "trefasig",
    "trefasigastes": "trefasig",
    "trefasigasts": "trefasig",
    "trefasige": "trefasig",
    "trefasiges": "trefasig",
    "trefasigs": "trefasig",
    "trefasigt": "trefasig",
    "trefasigts": "trefasig",
    "trefasströmmar": "trefasström",
    "trefasströmmarna": "trefasström",
    "trefasströmmarnas": "trefasström",
    "trefasströmmars": "trefasström",
    "trefasströmmen": "trefasström",
    "trefasströmmens": "trefasström",
    "trefasströms": "trefasström",
    "trefiliga": "trefilig",
    "trefiligare": "trefilig",
    "trefiligares": "trefilig",
    "trefiligas": "trefilig",
    "trefiligast": "trefilig",
    "trefiligaste": "trefilig",
    "trefiligastes": "trefilig",
    "trefiligasts": "trefilig",
    "trefilige": "trefilig",
    "trefiliges": "trefilig",
    "trefiligheten": "trefilighet",
    "trefilighetens": "trefilighet",
    "trefilighets": "trefilighet",
    "trefiligs": "trefilig",
    "trefiligt": "trefilig",
    "trefiligts": "trefilig",
    "trefjärdedelstakten": "trefjärdedelstakt",
    "trefjärdedelstaktens": "trefjärdedelstakt",
    "trefjärdedelstakts": "trefjärdedelstakt",
    "trefoten": "trefot",
    "trefotens": "trefot",
    "trefots": "trefot",
    "trefärgstrycken": "trefärgstryck",
    "trefärgstryckens": "trefärgstryck",
    "trefärgstrycket": "trefärgstryck",
    "trefärgstryckets": "trefärgstryck",
    "trefärgstrycks": "trefärgstryck",
    "treglasfönsterna": "treglasfönster",
    "treglasfönsternas": "treglasfönster",
    "treglasfönsters": "treglasfönster",
    "treglasfönstren": "treglasfönster",
    "treglasfönstrens": "treglasfönster",
    "treglasfönstret": "treglasfönster",
    "treglasfönstrets": "treglasfönster",
    "trehjulingar": "trehjuling",
    "trehjulingarna": "trehjuling",
    "trehjulingarnas": "trehjuling",
    "trehjulingars": "trehjuling",
    "trehjulingen": "trehjuling",
    "trehjulingens": "trehjuling",
    "trehjulings": "trehjuling",
    "trehundratalet": "trehundratal",
    "trehundratalets": "trehundratal",
    "trehundratals": "trehundratal",
    "trehörningar": "trehörning",
    "trehörningarna": "trehörning",
    "trehörningarnas": "trehörning",
    "trehörningars": "trehörning",
    "trehörningen": "trehörning",
    "trehörningens": "trehörning",
    "trehörnings": "trehörning",
    "trehövdade": "trehövdad",
    "trehövdades": "trehövdad",
    "trehövdads": "trehövdad",
    "trehövdat": "trehövdad",
    "trehövdats": "trehövdad",
    "trekanten": "trekant",
    "trekantens": "trekant",
    "trekanter": "trekant",
    "trekanterna": "trekant",
    "trekanternas": "trekant",
    "trekanters": "trekant",
    "trekantiga": "trekantig",
    "trekantigare": "trekantig",
    "trekantigares": "trekantig",
    "trekantigas": "trekantig",
    "trekantigast": "trekantig",
    "trekantigaste": "trekantig",
    "trekantigastes": "trekantig",
    "trekantigasts": "trekantig",
    "trekantige": "trekantig",
    "trekantiges": "trekantig",
    "trekantigs": "trekantig",
    "trekantigt": "trekantig",
    "trekantigts": "trekantig",
    "trekants": "trekant",
    "trekantsprofilen": "trekantsprofil",
    "trekantsprofilens": "trekantsprofil",
    "trekantsprofiler": "trekantsprofil",
    "trekantsprofilerna": "trekantsprofil",
    "trekantsprofilernas": "trekantsprofil",
    "trekantsprofilers": "trekantsprofil",
    "trekantsprofils": "trekantsprofil",
    "trekarlspolskan": "trekarlspolska",
    "trekarlspolskans": "trekarlspolska",
    "trekarlspolskas": "trekarlspolska",
    "trekarlspolske": "trekarlspolska",
    "trekarlspolskor": "trekarlspolska",
    "trekarlspolskorna": "trekarlspolska",
    "trekarlspolskornas": "trekarlspolska",
    "trekarlspolskors": "trekarlspolska",
    "treklangen": "treklang",
    "treklangens": "treklang",
    "treklanger": "treklang",
    "treklangerna": "treklang",
    "treklangernas": "treklang",
    "treklangers": "treklang",
    "treklangs": "treklang",
    "treklövern": "treklöver",
    "treklöverns": "treklöver",
    "treklövers": "treklöver",
    "trekropparsproblemets": "trekropparsproblemet",
    "trekvarts": "trekvart",
    "trekvartslånga": "trekvartslång",
    "trekvartslångare": "trekvartslång",
    "trekvartslångares": "trekvartslång",
    "trekvartslångas": "trekvartslång",
    "trekvartslångast": "trekvartslång",
    "trekvartslångaste": "trekvartslång",
    "trekvartslångastes": "trekvartslång",
    "trekvartslångasts": "trekvartslång",
    "trekvartslånge": "trekvartslång",
    "trekvartslånges": "trekvartslång",
    "trekvartslångs": "trekvartslång",
    "trekvartslångt": "trekvartslång",
    "trekvartslångts": "trekvartslång",
    "trekvartsstrump": "trekvartsstrumpa",
    "trekvartsstrumpan": "trekvartsstrumpa",
    "trekvartsstrumpans": "trekvartsstrumpa",
    "trekvartsstrumpas": "trekvartsstrumpa",
    "trekvartsstrumpe": "trekvartsstrumpa",
    "trekvartsstrumpor": "trekvartsstrumpa",
    "trekvartsstrumporna": "trekvartsstrumpa",
    "trekvartsstrumpornas": "trekvartsstrumpa",
    "trekvartsstrumpors": "trekvartsstrumpa",
    "trekvartsstrumps": "trekvartsstrumpa",
    "treledade": "treledad",
    "treledades": "treledad",
    "treledads": "treledad",
    "treledarsystemen": "treledarsystem",
    "treledarsystemens": "treledarsystem",
    "treledarsystemet": "treledarsystem",
    "treledarsystemets": "treledarsystem",
    "treledarsystems": "treledarsystem",
    "treledat": "treledad",
    "treledats": "treledad",
    "treläkarstationen": "treläkarstation",
    "treläkarstationens": "treläkarstation",
    "treläkarstationer": "treläkarstation",
    "treläkarstationerna": "treläkarstation",
    "treläkarstationernas": "treläkarstation",
    "treläkarstationers": "treläkarstation",
    "treläkarstations": "treläkarstation",
    "treman": "trema",
    "tremana": "trema",
    "tremanas": "trema",
    "tremans": "trema",
    "tremas": "trema",
    "tremastade": "tremastad",
    "tremastades": "tremastad",
    "tremastads": "tremastad",
    "tremastar": "tremastare",
    "tremastaren": "tremastare",
    "tremastarens": "tremastare",
    "tremastares": "tremastare",
    "tremastarna": "tremastare",
    "tremastarnas": "tremastare",
    "tremastat": "tremastad",
    "tremastats": "tremastad",
    "tremat": "trema",
    "tremats": "trema",
    "tremiljarderssatsningar": "tremiljarderssatsning",
    "tremiljarderssatsningarna": "tremiljarderssatsning",
    "tremiljarderssatsningarnas": "tremiljarderssatsning",
    "tremiljarderssatsningars": "tremiljarderssatsning",
    "tremiljarderssatsningen": "tremiljarderssatsning",
    "tremiljarderssatsningens": "tremiljarderssatsning",
    "tremiljarderssatsnings": "tremiljarderssatsning",
    "tremilsgränsen": "tremilsgräns",
    "tremilsgränsens": "tremilsgräns",
    "tremilsgränser": "tremilsgräns",
    "tremilsgränserna": "tremilsgräns",
    "tremilsgränsernas": "tremilsgräns",
    "tremilsgränsers": "tremilsgräns",
    "tremolon": "tremolo",
    "tremolona": "tremolo",
    "tremolonas": "tremolo",
    "tremolons": "tremolo",
    "tremolos": "tremolo",
    "tremolot": "tremolo",
    "tremolots": "tremolo",
    "tremulanten": "tremulant",
    "tremulantens": "tremulant",
    "tremulanter": "tremulant",
    "tremulanterna": "tremulant",
    "tremulanternas": "tremulant",
    "tremulanters": "tremulant",
    "tremulants": "tremulant",
    "tremulerade": "tremulera",
    "tremulerades": "tremulera",
    "tremulerande": "tremulera",
    "tremuleranden": "tremulerande",
    "tremulerandena": "tremulerande",
    "tremulerandenas": "tremulerande",
    "tremulerandens": "tremulerande",
    "tremulerandes": "tremulerande",
    "tremulerandet": "tremulerande",
    "tremulerandets": "tremulerande",
    "tremulerar": "tremulera",
    "tremuleras": "tremulera",
    "tremulerat": "tremulera",
    "tremulerats": "tremulera",
    "tremuleringar": "tremulering",
    "tremuleringarna": "tremulering",
    "tremuleringarnas": "tremulering",
    "tremuleringars": "tremulering",
    "tremuleringen": "tremulering",
    "tremuleringens": "tremulering",
    "tremulerings": "tremulering",
    "tremänningar": "tremänning",
    "tremänningarna": "tremänning",
    "tremänningarnas": "tremänning",
    "tremänningars": "tremänning",
    "tremänningen": "tremänning",
    "tremänningens": "tremänning",
    "tremännings": "tremänning",
    "tremånadersperioden": "tremånadersperiod",
    "tremånadersperiodens": "tremånadersperiod",
    "tremånadersperioder": "tremånadersperiod",
    "tremånadersperioderna": "tremånadersperiod",
    "tremånadersperiodernas": "tremånadersperiod",
    "tremånadersperioders": "tremånadersperiod",
    "tremånadersperiods": "tremånadersperiod",
    "trenchar": "trench",
    "trencharna": "trench",
    "trencharnas": "trench",
    "trenchars": "trench",
    "trenchcoatar": "trenchcoat",
    "trenchcoatarna": "trenchcoat",
    "trenchcoatarnas": "trenchcoat",
    "trenchcoatars": "trenchcoat",
    "trenchcoaten": "trenchcoat",
    "trenchcoatens": "trenchcoat",
    "trenchcoats": "trenchcoat",
    "trenchen": "trench",
    "trenchens": "trench",
    "trenchs": "trench",
    "trendanalysen": "trendanalys",
    "trendanalysens": "trendanalys",
    "trendanalyser": "trendanalys",
    "trendanalyserna": "trendanalys",
    "trendanalysernas": "trendanalys",
    "trendanalysers": "trendanalys",
    "trendanalysföretagen": "trendanalysföretag",
    "trendanalysföretagens": "trendanalysföretag",
    "trendanalysföretaget": "trendanalysföretag",
    "trendanalysföretagets": "trendanalysföretag",
    "trendanalysföretags": "trendanalysföretag",
    "trendbrotten": "trendbrott",
    "trendbrottens": "trendbrott",
    "trendbrottet": "trendbrott",
    "trendbrottets": "trendbrott",
    "trendbrotts": "trendbrott",
    "trenden": "trend",
    "trendens": "trend",
    "trender": "trend",
    "trenderna": "trend",
    "trendernas": "trend",
    "trenders": "trend",
    "trendiga": "trendig",
    "trendigare": "trendig",
    "trendigares": "trendig",
    "trendigas": "trendig",
    "trendigast": "trendig",
    "trendigaste": "trendig",
    "trendigastes": "trendig",
    "trendigasts": "trendig",
    "trendige": "trendig",
    "trendiges": "trendig",
    "trendigheten": "trendighet",
    "trendighetens": "trendighet",
    "trendigheter": "trendighet",
    "trendigheterna": "trendighet",
    "trendigheternas": "trendighet",
    "trendigheters": "trendighet",
    "trendighets": "trendighet",
    "trendigs": "trendig",
    "trendigt": "trendig",
    "trendigts": "trendig",
    "trendkänsliga": "trendkänslig",
    "trendkänsligare": "trendkänslig",
    "trendkänsligares": "trendkänslig",
    "trendkänsligas": "trendkänslig",
    "trendkänsligast": "trendkänslig",
    "trendkänsligaste": "trendkänslig",
    "trendkänsligastes": "trendkänslig",
    "trendkänsligasts": "trendkänslig",
    "trendkänslige": "trendkänslig",
    "trendkänsliges": "trendkänslig",
    "trendkänsligheten": "trendkänslighet",
    "trendkänslighetens": "trendkänslighet",
    "trendkänslighets": "trendkänslighet",
    "trendkänsligs": "trendkänslig",
    "trendkänsligt": "trendkänslig",
    "trendkänsligts": "trendkänslig",
    "trendmässiga": "trendmässig",
    "trendmässigare": "trendmässig",
    "trendmässigares": "trendmässig",
    "trendmässigas": "trendmässig",
    "trendmässigast": "trendmässig",
    "trendmässigaste": "trendmässig",
    "trendmässigastes": "trendmässig",
    "trendmässigasts": "trendmässig",
    "trendmässige": "trendmässig",
    "trendmässiges": "trendmässig",
    "trendmässigs": "trendmässig",
    "trendmässigt": "trendmässig",
    "trendmässigts": "trendmässig",
    "trendnissar": "trendnisse",
    "trendnissarna": "trendnisse",
    "trendnissarnas": "trendnisse",
    "trendnissars": "trendnisse",
    "trendnissen": "trendnisse",
    "trendnissens": "trendnisse",
    "trendnisses": "trendnisse",
    "trendriktiga": "trendriktig",
    "trendriktigare": "trendriktig",
    "trendriktigares": "trendriktig",
    "trendriktigas": "trendriktig",
    "trendriktigast": "trendriktig",
    "trendriktigaste": "trendriktig",
    "trendriktigastes": "trendriktig",
    "trendriktigasts": "trendriktig",
    "trendriktige": "trendriktig",
    "trendriktiges": "trendriktig",
    "trendriktigheten": "trendriktighet",
    "trendriktighetens": "trendriktighet",
    "trendriktighets": "trendriktighet",
    "trendriktigs": "trendriktig",
    "trendriktigt": "trendriktig",
    "trendriktigts": "trendriktig",
    "trends": "trend",
    "trendsättar": "trendsättare",
    "trendsättaren": "trendsättare",
    "trendsättarens": "trendsättare",
    "trendsättares": "trendsättare",
    "trendsättarna": "trendsättare",
    "trendsättarnas": "trendsättare",
    "trennes": "trenne",
    "treor": "trea",
    "treorna": "trea",
    "treornas": "trea",
    "treors": "trea",
    "trepanationen": "trepanation",
    "trepanationens": "trepanation",
    "trepanationer": "trepanation",
    "trepanationerna": "trepanation",
    "trepanationernas": "trepanation",
    "trepanationers": "trepanation",
    "trepanations": "trepanation",
    "trepanen": "trepan",
    "trepanens": "trepan",
    "trepaner": "trepan",
    "trepanerad": "trepanera",
    "trepanerade": "trepanera",
    "trepanerades": "trepanera",
    "trepanerads": "trepanera",
    "trepanerande": "trepanera",
    "trepaneranden": "trepanerande",
    "trepanerandena": "trepanerande",
    "trepanerandenas": "trepanerande",
    "trepanerandens": "trepanerande",
    "trepanerandes": "trepanerande",
    "trepanerandet": "trepanerande",
    "trepanerandets": "trepanerande",
    "trepanerar": "trepanera",
    "trepaneras": "trepanera",
    "trepanerat": "trepanera",
    "trepanerats": "trepanera",
    "trepanerbara": "trepanerbar",
    "trepanerbarare": "trepanerbar",
    "trepanerbarares": "trepanerbar",
    "trepanerbaras": "trepanerbar",
    "trepanerbarast": "trepanerbar",
    "trepanerbaraste": "trepanerbar",
    "trepanerbarastes": "trepanerbar",
    "trepanerbarasts": "trepanerbar",
    "trepanerbare": "trepanerbar",
    "trepanerbares": "trepanerbar",
    "trepanerbarheten": "trepanerbarhet",
    "trepanerbarhetens": "trepanerbarhet",
    "trepanerbarhets": "trepanerbarhet",
    "trepanerbars": "trepanerbar",
    "trepanerbart": "trepanerbar",
    "trepanerbarts": "trepanerbar",
    "trepaneringar": "trepanering",
    "trepaneringarna": "trepanering",
    "trepaneringarnas": "trepanering",
    "trepaneringars": "trepanering",
    "trepaneringen": "trepanering",
    "trepaneringens": "trepanering",
    "trepanerings": "trepanering",
    "trepanerna": "trepan",
    "trepanernas": "trepan",
    "trepaners": "trepan",
    "trepans": "trepan",
    "trepassen": "trepass",
    "trepassens": "trepass",
    "trepasset": "trepass",
    "trepassets": "trepass",
    "trepunktsbälten": "trepunktsbälte",
    "trepunktsbältena": "trepunktsbälte",
    "trepunktsbältenas": "trepunktsbälte",
    "trepunktsbältens": "trepunktsbälte",
    "trepunktsbältes": "trepunktsbälte",
    "trepunktsbältet": "trepunktsbälte",
    "trepunktsbältets": "trepunktsbälte",
    "treradiga": "treradig",
    "treradigare": "treradig",
    "treradigares": "treradig",
    "treradigas": "treradig",
    "treradigast": "treradig",
    "treradigaste": "treradig",
    "treradigastes": "treradig",
    "treradigasts": "treradig",
    "treradige": "treradig",
    "treradiges": "treradig",
    "treradigs": "treradig",
    "treradigt": "treradig",
    "treradigts": "treradig",
    "treradingar": "trerading",
    "treradingarna": "trerading",
    "treradingarnas": "trerading",
    "treradingars": "trerading",
    "treradingen": "trerading",
    "treradingens": "trerading",
    "treradings": "trerading",
    "trerummar": "trerummare",
    "trerummaren": "trerummare",
    "trerummarens": "trerummare",
    "trerummares": "trerummare",
    "trerummarna": "trerummare",
    "trerummarnas": "trerummare",
    "trerumslägenheten": "trerumslägenhet",
    "trerumslägenhetens": "trerumslägenhet",
    "trerumslägenheter": "trerumslägenhet",
    "trerumslägenheterna": "trerumslägenhet",
    "trerumslägenheternas": "trerumslägenhet",
    "trerumslägenheters": "trerumslägenhet",
    "trerumslägenhets": "trerumslägenhet",
    "trerättersmiddagar": "trerättersmiddag",
    "trerättersmiddagarna": "trerättersmiddag",
    "trerättersmiddagarnas": "trerättersmiddag",
    "trerättersmiddagars": "trerättersmiddag",
    "trerättersmiddagen": "trerättersmiddag",
    "trerättersmiddagens": "trerättersmiddag",
    "trerättersmiddags": "trerättersmiddag",
    "tres": "tre",
    "tresiffriga": "tresiffrig",
    "tresiffrigare": "tresiffrig",
    "tresiffrigares": "tresiffrig",
    "tresiffrigas": "tresiffrig",
    "tresiffrigast": "tresiffrig",
    "tresiffrigaste": "tresiffrig",
    "tresiffrigastes": "tresiffrig",
    "tresiffrigasts": "tresiffrig",
    "tresiffrige": "tresiffrig",
    "tresiffriges": "tresiffrig",
    "tresiffrigs": "tresiffrig",
    "tresiffrigt": "tresiffrig",
    "tresiffrigts": "tresiffrig",
    "treskiftes": "treskifte",
    "treskiftesbruket": "treskiftesbruk",
    "treskiftesbrukets": "treskiftesbruk",
    "treskiftesbruks": "treskiftesbruk",
    "treskiftet": "treskifte",
    "treskiftets": "treskifte",
    "treskifts": "treskift",
    "tresnibbar": "tresnibb",
    "tresnibbarna": "tresnibb",
    "tresnibbarnas": "tresnibb",
    "tresnibbars": "tresnibb",
    "tresnibben": "tresnibb",
    "tresnibbens": "tresnibb",
    "tresnibbs": "tresnibb",
    "tresnårets": "tresnåret",
    "trespannen": "trespann",
    "trespannens": "trespann",
    "trespannet": "trespann",
    "trespannets": "trespann",
    "trespanns": "trespann",
    "trespända": "trespänd",
    "trespändare": "trespänd",
    "trespändares": "trespänd",
    "trespändas": "trespänd",
    "trespändast": "trespänd",
    "trespändaste": "trespänd",
    "trespändastes": "trespänd",
    "trespändasts": "trespänd",
    "trespände": "trespänd",
    "trespändes": "trespänd",
    "trespänds": "trespänd",
    "trespänt": "trespänd",
    "trespänts": "trespänd",
    "trestaviga": "trestavig",
    "trestavigare": "trestavig",
    "trestavigares": "trestavig",
    "trestavigas": "trestavig",
    "trestavigast": "trestavig",
    "trestavigaste": "trestavig",
    "trestavigastes": "trestavig",
    "trestavigasts": "trestavig",
    "trestavige": "trestavig",
    "trestaviges": "trestavig",
    "trestavigheten": "trestavighet",
    "trestavighetens": "trestavighet",
    "trestavighets": "trestavighet",
    "trestavigs": "trestavig",
    "trestavigt": "trestavig",
    "trestavigts": "trestavig",
    "tresteget": "tresteg",
    "trestegets": "tresteg",
    "trestegs": "tresteg",
    "trestegshoppen": "trestegshopp",
    "trestegshoppens": "trestegshopp",
    "trestegshoppet": "trestegshopp",
    "trestegshoppets": "trestegshopp",
    "trestegshopps": "trestegshopp",
    "trestegsraketen": "trestegsraket",
    "trestegsraketens": "trestegsraket",
    "trestegsraketer": "trestegsraket",
    "trestegsraketerna": "trestegsraket",
    "trestegsraketernas": "trestegsraket",
    "trestegsraketers": "trestegsraket",
    "trestegsrakets": "trestegsraket",
    "trestjärniga": "trestjärnig",
    "trestjärnigare": "trestjärnig",
    "trestjärnigares": "trestjärnig",
    "trestjärnigas": "trestjärnig",
    "trestjärnigast": "trestjärnig",
    "trestjärnigaste": "trestjärnig",
    "trestjärnigastes": "trestjärnig",
    "trestjärnigasts": "trestjärnig",
    "trestjärnige": "trestjärnig",
    "trestjärniges": "trestjärnig",
    "trestjärnigs": "trestjärnig",
    "trestjärnigt": "trestjärnig",
    "trestjärnigts": "trestjärnig",
    "trestrukens": "trestruken",
    "trestruket": "trestruken",
    "trestrukets": "trestruken",
    "trestrukna": "trestruken",
    "trestruknare": "trestruken",
    "trestruknares": "trestruken",
    "trestruknas": "trestruken",
    "trestruknast": "trestruken",
    "trestruknaste": "trestruken",
    "trestruknastes": "trestruken",
    "trestruknasts": "trestruken",
    "trestrukne": "trestruken",
    "trestruknes": "trestruken",
    "tretakten": "tretakt",
    "tretaktens": "tretakt",
    "tretakts": "tretakt",
    "tretalen": "tretal",
    "tretalens": "tretal",
    "tretalet": "tretal",
    "tretalets": "tretal",
    "tretals": "tretal",
    "tretanden": "tretand",
    "tretandens": "tretand",
    "tretands": "tretand",
    "trettiodagarsperioden": "trettiodagarsperiod",
    "trettiodagarsperiodens": "trettiodagarsperiod",
    "trettiodagarsperioder": "trettiodagarsperiod",
    "trettiodagarsperioderna": "trettiodagarsperiod",
    "trettiodagarsperiodernas": "trettiodagarsperiod",
    "trettiodagarsperioders": "trettiodagarsperiod",
    "trettiodagarsperiods": "trettiodagarsperiod",
    "trettiofems": "trettiofem",
    "trettiofemte": "trettiofem",
    "trettiofemtes": "trettiofem",
    "trettiofemårsåldern": "trettiofemårsålder",
    "trettiofemårsålderns": "trettiofemårsålder",
    "trettiofemårsålders": "trettiofemårsålder",
    "trettionde": "trettio",
    "trettiondelar": "trettiondel",
    "trettiondelarna": "trettiondel",
    "trettiondelarnas": "trettiondel",
    "trettiondelars": "trettiondel",
    "trettiondelen": "trettiondel",
    "trettiondelens": "trettiondel",
    "trettiondels": "trettiondel",
    "trettiondes": "trettio",
    "trettios": "trettio",
    "trettiotalen": "trettiotal",
    "trettiotalens": "trettiotal",
    "trettiotalet": "trettiotal",
    "trettiotalets": "trettiotal",
    "trettiotals": "trettiotal",
    "trettioåriga": "trettioårig",
    "trettioårigas": "trettioårig",
    "trettioårige": "trettioårig",
    "trettioåriges": "trettioårig",
    "trettioårigs": "trettioårig",
    "trettioårigt": "trettioårig",
    "trettioårigts": "trettioårig",
    "trettioåttas": "trettioåtta",
    "trettioåttonde": "trettioåtta",
    "trettioåttondes": "trettioåtta",
    "trettis": "tretti",
    "trettitalen": "trettital",
    "trettitalens": "trettital",
    "trettitalet": "trettital",
    "trettitalets": "trettital",
    "trettitals": "trettital",
    "trettiåriga": "trettiårig",
    "trettiårigas": "trettiårig",
    "trettiårige": "trettiårig",
    "trettiåriges": "trettiårig",
    "trettiårigs": "trettiårig",
    "trettiårigt": "trettiårig",
    "trettiårigts": "trettiårig",
    "trettondagen": "trettondag",
    "trettondagens": "trettondag",
    "trettondags": "trettondag",
    "trettondagsaftnar": "trettondagsafton",
    "trettondagsaftnarna": "trettondagsafton",
    "trettondagsaftnarnas": "trettondagsafton",
    "trettondagsaftnars": "trettondagsafton",
    "trettondagsaftonen": "trettondagsafton",
    "trettondagsaftonens": "trettondagsafton",
    "trettondagsaftons": "trettondagsafton",
    "trettonde": "tretton",
    "trettondedagen": "trettondedag",
    "trettondedagens": "trettondedag",
    "trettondedags": "trettondedag",
    "trettondelar": "trettondel",
    "trettondelarna": "trettondel",
    "trettondelarnas": "trettondel",
    "trettondelars": "trettondel",
    "trettondelen": "trettondel",
    "trettondelens": "trettondel",
    "trettondels": "trettondel",
    "trettondes": "tretton",
    "trettonhundratalet": "trettonhundratal",
    "trettonhundratalets": "trettonhundratal",
    "trettonhundratals": "trettonhundratal",
    "trettons": "tretton",
    "trettonsnårets": "trettonsnåret",
    "trettonåriga": "trettonårig",
    "trettonårigas": "trettonårig",
    "trettonårige": "trettonårig",
    "trettonåriges": "trettonårig",
    "trettonårigs": "trettonårig",
    "trettonårigt": "trettonårig",
    "trettonårigts": "trettonårig",
    "trettonåringar": "trettonåring",
    "trettonåringarna": "trettonåring",
    "trettonåringarnas": "trettonåring",
    "trettonåringars": "trettonåring",
    "trettonåringen": "trettonåring",
    "trettonåringens": "trettonåring",
    "trettonårings": "trettonåring",
    "tretumsspikar": "tretumsspik",
    "tretumsspikarna": "tretumsspik",
    "tretumsspikarnas": "tretumsspik",
    "tretumsspikars": "tretumsspik",
    "tretumsspiken": "tretumsspik",
    "tretumsspikens": "tretumsspik",
    "tretumsspiks": "tretumsspik",
    "tretungade": "tretungad",
    "tretungades": "tretungad",
    "tretungads": "tretungad",
    "tretungat": "tretungad",
    "tretungats": "tretungad",
    "tretårar": "tretår",
    "tretårarna": "tretår",
    "tretårarnas": "tretår",
    "tretårars": "tretår",
    "tretåren": "tretår",
    "tretårens": "tretår",
    "tretårs": "tretår",
    "treuddar": "treudd",
    "treuddarna": "treudd",
    "treuddarnas": "treudd",
    "treuddars": "treudd",
    "treudden": "treudd",
    "treuddens": "treudd",
    "treudds": "treudd",
    "trev": "treva",
    "trevad": "treva",
    "trevade": "treva",
    "trevades": "treva",
    "trevads": "treva",
    "trevande": "treva",
    "trevanden": "trevande",
    "trevandena": "trevande",
    "trevandenas": "trevande",
    "trevandens": "trevande",
    "trevandes": "trevande",
    "trevandet": "trevande",
    "trevandets": "trevande",
    "trevar": "trevare",
    "trevaren": "trevare",
    "trevarens": "trevare",
    "trevares": "trevare",
    "trevarna": "trevare",
    "trevarnas": "trevare",
    "trevas": "treva",
    "trevat": "treva",
    "trevats": "treva",
    "trevens": "treven",
    "trevet": "treven",
    "trevets": "treven",
    "trevinkliga": "trevinklig",
    "trevinkligare": "trevinklig",
    "trevinkligares": "trevinklig",
    "trevinkligas": "trevinklig",
    "trevinkligast": "trevinklig",
    "trevinkligaste": "trevinklig",
    "trevinkligastes": "trevinklig",
    "trevinkligasts": "trevinklig",
    "trevinklige": "trevinklig",
    "trevinkliges": "trevinklig",
    "trevinkligheten": "trevinklighet",
    "trevinklighetens": "trevinklighet",
    "trevinklighets": "trevinklighet",
    "trevinkligs": "trevinklig",
    "trevinkligt": "trevinklig",
    "trevinkligts": "trevinklig",
    "trevliga": "trevlig",
    "trevligare": "trevlig",
    "trevligares": "trevlig",
    "trevligas": "trevlig",
    "trevligast": "trevlig",
    "trevligaste": "trevlig",
    "trevligastes": "trevlig",
    "trevligasts": "trevlig",
    "trevlige": "trevlig",
    "trevliges": "trevlig",
    "trevligheten": "trevlighet",
    "trevlighetens": "trevlighet",
    "trevligheter": "trevlighet",
    "trevligheterna": "trevlighet",
    "trevligheternas": "trevlighet",
    "trevligheters": "trevlighet",
    "trevlighets": "trevlighet",
    "trevligs": "trevlig",
    "trevligt": "trevlig",
    "trevligts": "trevlig",
    "trevna": "treven",
    "trevnaden": "trevnad",
    "trevnadens": "trevnad",
    "trevnader": "trevnad",
    "trevnaderna": "trevnad",
    "trevnadernas": "trevnad",
    "trevnaders": "trevnad",
    "trevnads": "trevnad",
    "trevnare": "treven",
    "trevnares": "treven",
    "trevnas": "treven",
    "trevnast": "treven",
    "trevnaste": "treven",
    "trevnastes": "treven",
    "trevnasts": "treven",
    "trevne": "treven",
    "trevnes": "treven",
    "trevägskranar": "trevägskran",
    "trevägskranarna": "trevägskran",
    "trevägskranarnas": "trevägskran",
    "trevägskranars": "trevägskran",
    "trevägskranen": "trevägskran",
    "trevägskranens": "trevägskran",
    "trevägskrans": "trevägskran",
    "trevåningshusen": "trevåningshus",
    "trevåningshusens": "trevåningshus",
    "trevåningshuset": "trevåningshus",
    "trevåningshusets": "trevåningshus",
    "treåriga": "treårig",
    "treårigas": "treårig",
    "treårige": "treårig",
    "treåriges": "treårig",
    "treårigs": "treårig",
    "treårigt": "treårig",
    "treårigts": "treårig",
    "treåringar": "treåring",
    "treåringarna": "treåring",
    "treåringarnas": "treåring",
    "treåringars": "treåring",
    "treåringen": "treåring",
    "treåringens": "treåring",
    "treårings": "treåring",
    "triaden": "triad",
    "triadens": "triad",
    "triader": "triad",
    "triaderna": "triad",
    "triadernas": "triad",
    "triaders": "triad",
    "triads": "triad",
    "triagen": "triage",
    "triagens": "triage",
    "triager": "triage",
    "triagerna": "triage",
    "triagernas": "triage",
    "triagers": "triage",
    "triages": "triage",
    "triaget": "triage",
    "triagets": "triage",
    "trial-and-errors": "trial-and-error",
    "trialen": "trial",
    "trialens": "trial",
    "trials": "trial",
    "triangelbyten": "triangelbyte",
    "triangelbytena": "triangelbyte",
    "triangelbytenas": "triangelbyte",
    "triangelbytens": "triangelbyte",
    "triangelbytes": "triangelbyte",
    "triangelbytet": "triangelbyte",
    "triangelbytets": "triangelbyte",
    "triangeldraman": "triangeldrama",
    "triangeldramana": "triangeldrama",
    "triangeldramanas": "triangeldrama",
    "triangeldramans": "triangeldrama",
    "triangeldramas": "triangeldrama",
    "triangeldramat": "triangeldrama",
    "triangeldramats": "triangeldrama",
    "triangeldramer": "triangeldrama",
    "triangeldramerna": "triangeldrama",
    "triangeldramernas": "triangeldrama",
    "triangeldramers": "triangeldrama",
    "triangelkopplingar": "triangelkoppling",
    "triangelkopplingarna": "triangelkoppling",
    "triangelkopplingarnas": "triangelkoppling",
    "triangelkopplingars": "triangelkoppling",
    "triangelkopplingen": "triangelkoppling",
    "triangelkopplingens": "triangelkoppling",
    "triangelkopplings": "triangelkoppling",
    "triangelmatchen": "triangelmatch",
    "triangelmatchens": "triangelmatch",
    "triangelmatcher": "triangelmatch",
    "triangelmatcherna": "triangelmatch",
    "triangelmatchernas": "triangelmatch",
    "triangelmatchers": "triangelmatch",
    "triangelmatchs": "triangelmatch",
    "triangelmätningar": "triangelmätning",
    "triangelmätningarna": "triangelmätning",
    "triangelmätningarnas": "triangelmätning",
    "triangelmätningars": "triangelmätning",
    "triangelmätningen": "triangelmätning",
    "triangelmätningens": "triangelmätning",
    "triangelmätnings": "triangelmätning",
    "triangeln": "triangel",
    "triangelns": "triangel",
    "triangelpunkten": "triangelpunkt",
    "triangelpunktens": "triangelpunkt",
    "triangelpunkter": "triangelpunkt",
    "triangelpunkterna": "triangelpunkt",
    "triangelpunkternas": "triangelpunkt",
    "triangelpunkters": "triangelpunkt",
    "triangelpunkts": "triangelpunkt",
    "triangelreflexen": "triangelreflex",
    "triangelreflexens": "triangelreflex",
    "triangelreflexer": "triangelreflex",
    "triangelreflexerna": "triangelreflex",
    "triangelreflexernas": "triangelreflex",
    "triangelreflexers": "triangelreflex",
    "triangels": "triangel",
    "triangelsidan": "triangelsida",
    "triangelsidans": "triangelsida",
    "triangelsidas": "triangelsida",
    "triangelside": "triangelsida",
    "triangelsides": "triangelsida",
    "triangelsidor": "triangelsida",
    "triangelsidorna": "triangelsida",
    "triangelsidornas": "triangelsida",
    "triangelsidors": "triangelsida",
    "trianglar": "triangel",
    "trianglarna": "triangel",
    "trianglarnas": "triangel",
    "trianglars": "triangel",
    "triangulerad": "triangulera",
    "triangulerade": "triangulera",
    "triangulerades": "triangulera",
    "triangulerads": "triangulera",
    "triangulerande": "triangulera",
    "trianguleranden": "triangulerande",
    "triangulerandena": "triangulerande",
    "triangulerandenas": "triangulerande",
    "triangulerandens": "triangulerande",
    "triangulerandes": "triangulerande",
    "triangulerandet": "triangulerande",
    "triangulerandets": "triangulerande",
    "triangulerar": "triangulera",
    "trianguleras": "triangulera",
    "triangulerat": "triangulera",
    "triangulerats": "triangulera",
    "triangulerbara": "triangulerbar",
    "triangulerbarare": "triangulerbar",
    "triangulerbarares": "triangulerbar",
    "triangulerbaras": "triangulerbar",
    "triangulerbarast": "triangulerbar",
    "triangulerbaraste": "triangulerbar",
    "triangulerbarastes": "triangulerbar",
    "triangulerbarasts": "triangulerbar",
    "triangulerbare": "triangulerbar",
    "triangulerbares": "triangulerbar",
    "triangulerbarheten": "triangulerbarhet",
    "triangulerbarhetens": "triangulerbarhet",
    "triangulerbarhets": "triangulerbarhet",
    "triangulerbars": "triangulerbar",
    "triangulerbart": "triangulerbar",
    "triangulerbarts": "triangulerbar",
    "trianguleringar": "triangulering",
    "trianguleringarna": "triangulering",
    "trianguleringarnas": "triangulering",
    "trianguleringars": "triangulering",
    "trianguleringen": "triangulering",
    "trianguleringens": "triangulering",
    "triangulerings": "triangulering",
    "triangulära": "triangulär",
    "triangulärare": "triangulär",
    "triangulärares": "triangulär",
    "trianguläras": "triangulär",
    "triangulärast": "triangulär",
    "trianguläraste": "triangulär",
    "triangulärastes": "triangulär",
    "triangulärasts": "triangulär",
    "trianguläre": "triangulär",
    "trianguläres": "triangulär",
    "triangulärs": "triangulär",
    "triangulärt": "triangulär",
    "triangulärts": "triangulär",
    "tribaden": "tribad",
    "tribadens": "tribad",
    "tribader": "tribad",
    "tribaderna": "tribad",
    "tribadernas": "tribad",
    "tribaders": "tribad",
    "tribadiska": "tribadisk",
    "tribadiskare": "tribadisk",
    "tribadiskares": "tribadisk",
    "tribadiskas": "tribadisk",
    "tribadiskast": "tribadisk",
    "tribadiskaste": "tribadisk",
    "tribadiskastes": "tribadisk",
    "tribadiskasts": "tribadisk",
    "tribadiske": "tribadisk",
    "tribadiskes": "tribadisk",
    "tribadisks": "tribadisk",
    "tribadiskt": "tribadisk",
    "tribadiskts": "tribadisk",
    "tribadismen": "tribadism",
    "tribadismens": "tribadism",
    "tribadismer": "tribadism",
    "tribadismerna": "tribadism",
    "tribadismernas": "tribadism",
    "tribadismers": "tribadism",
    "tribadisms": "tribadism",
    "tribads": "tribad",
    "tribalismen": "tribalism",
    "tribalismens": "tribalism",
    "tribalismer": "tribalism",
    "tribalismerna": "tribalism",
    "tribalismernas": "tribalism",
    "tribalismers": "tribalism",
    "tribalisms": "tribalism",
    "tribalistiska": "tribalistisk",
    "tribalistiskas": "tribalistisk",
    "tribalistiske": "tribalistisk",
    "tribalistiskes": "tribalistisk",
    "tribalistisks": "tribalistisk",
    "tribalistiskt": "tribalistisk",
    "tribalistiskts": "tribalistisk",
    "tribunalen": "tribunal",
    "tribunalens": "tribunal",
    "tribunaler": "tribunal",
    "tribunalerna": "tribunal",
    "tribunalernas": "tribunal",
    "tribunalers": "tribunal",
    "tribunals": "tribunal",
    "tribunaten": "tribunat",
    "tribunatens": "tribunat",
    "tribunatet": "tribunat",
    "tribunatets": "tribunat",
    "tribunats": "tribunat",
    "tribunen": "tribun",
    "tribunens": "tribun",
    "tribuner": "tribun",
    "tribunerna": "tribun",
    "tribunernas": "tribun",
    "tribuners": "tribun",
    "tribuns": "tribun",
    "tributen": "tribut",
    "tributens": "tribut",
    "tributer": "tribut",
    "tributerna": "tribut",
    "tributernas": "tribut",
    "tributers": "tribut",
    "tributs": "tribut",
    "tricepsmuskeln": "tricepsmuskel",
    "tricepsmuskelns": "tricepsmuskel",
    "tricepsmuskels": "tricepsmuskel",
    "tricepsmuskler": "tricepsmuskel",
    "tricepsmusklerna": "tricepsmuskel",
    "tricepsmusklernas": "tricepsmuskel",
    "tricepsmusklers": "tricepsmuskel",
    "trickar": "trick",
    "trickarna": "trick",
    "trickarnas": "trick",
    "trickars": "trick",
    "tricken": "trick",
    "trickens": "trick",
    "tricket": "trick",
    "trickets": "trick",
    "trickfilmen": "trickfilm",
    "trickfilmens": "trickfilm",
    "trickfilmer": "trickfilm",
    "trickfilmerna": "trickfilm",
    "trickfilmernas": "trickfilm",
    "trickfilmers": "trickfilm",
    "trickfilms": "trickfilm",
    "tricks": "tricksa",
    "tricksad": "tricksa",
    "tricksade": "tricksa",
    "tricksades": "tricksa",
    "tricksads": "tricksa",
    "tricksande": "tricksa",
    "tricksanden": "tricksande",
    "tricksandena": "tricksande",
    "tricksandenas": "tricksande",
    "tricksandens": "tricksande",
    "tricksandes": "tricksande",
    "tricksandet": "tricksande",
    "tricksandets": "tricksande",
    "tricksar": "tricksa",
    "tricksas": "tricksa",
    "tricksat": "tricksa",
    "tricksats": "tricksa",
    "tricksen": "tricks",
    "tricksens": "tricks",
    "trickset": "tricks",
    "tricksets": "tricks",
    "triennalen": "triennal",
    "triennalens": "triennal",
    "triennaler": "triennal",
    "triennalerna": "triennal",
    "triennalernas": "triennal",
    "triennalers": "triennal",
    "triennals": "triennal",
    "trierad": "triera",
    "trierade": "triera",
    "trierades": "triera",
    "trierads": "triera",
    "trierande": "triera",
    "trieranden": "trierande",
    "trierandena": "trierande",
    "trierandenas": "trierande",
    "trierandens": "trierande",
    "trierandes": "trierande",
    "trierandet": "trierande",
    "trierandets": "trierande",
    "trierar": "triera",
    "trieras": "triera",
    "trierat": "triera",
    "trierats": "triera",
    "trierbara": "trierbar",
    "trierbarare": "trierbar",
    "trierbarares": "trierbar",
    "trierbaras": "trierbar",
    "trierbarast": "trierbar",
    "trierbaraste": "trierbar",
    "trierbarastes": "trierbar",
    "trierbarasts": "trierbar",
    "trierbare": "trierbar",
    "trierbares": "trierbar",
    "trierbarheten": "trierbarhet",
    "trierbarhetens": "trierbarhet",
    "trierbarhets": "trierbarhet",
    "trierbars": "trierbar",
    "trierbart": "trierbar",
    "trierbarts": "trierbar",
    "trieringar": "triering",
    "trieringarna": "triering",
    "trieringarnas": "triering",
    "trieringars": "triering",
    "trieringen": "triering",
    "trieringens": "triering",
    "trierings": "triering",
    "triften": "trift",
    "triftens": "trift",
    "triftongen": "triftong",
    "triftongens": "triftong",
    "triftonger": "triftong",
    "triftongerna": "triftong",
    "triftongernas": "triftong",
    "triftongers": "triftong",
    "triftongs": "triftong",
    "trifts": "trift",
    "triggad": "trigga",
    "triggade": "trigga",
    "triggades": "trigga",
    "triggads": "trigga",
    "triggande": "trigga",
    "trigganden": "triggande",
    "triggandena": "triggande",
    "triggandenas": "triggande",
    "triggandens": "triggande",
    "triggandes": "triggande",
    "triggandet": "triggande",
    "triggandets": "triggande",
    "triggar": "trigga",
    "triggas": "trigga",
    "triggat": "trigga",
    "triggats": "trigga",
    "triggningar": "triggning",
    "triggningarna": "triggning",
    "triggningarnas": "triggning",
    "triggningars": "triggning",
    "triggningen": "triggning",
    "triggningens": "triggning",
    "triggnings": "triggning",
    "triglyfen": "triglyf",
    "triglyfens": "triglyf",
    "triglyfer": "triglyf",
    "triglyferna": "triglyf",
    "triglyfernas": "triglyf",
    "triglyfers": "triglyf",
    "triglyfs": "triglyf",
    "trigonometrien": "trigonometri",
    "trigonometriens": "trigonometri",
    "trigonometrin": "trigonometri",
    "trigonometrins": "trigonometri",
    "trigonometris": "trigonometri",
    "trigonometriska": "trigonometrisk",
    "trigonometriskare": "trigonometrisk",
    "trigonometriskares": "trigonometrisk",
    "trigonometriskas": "trigonometrisk",
    "trigonometriskast": "trigonometrisk",
    "trigonometriskaste": "trigonometrisk",
    "trigonometriskastes": "trigonometrisk",
    "trigonometriskasts": "trigonometrisk",
    "trigonometriske": "trigonometrisk",
    "trigonometriskes": "trigonometrisk",
    "trigonometrisks": "trigonometrisk",
    "trigonometriskt": "trigonometrisk",
    "trigonometriskts": "trigonometrisk",
    "trigrammen": "trigram",
    "trigrammens": "trigram",
    "trigrammet": "trigram",
    "trigrammets": "trigram",
    "trigrams": "trigram",
    "trikinen": "trikin",
    "trikinens": "trikin",
    "trikiner": "trikin",
    "trikinerna": "trikin",
    "trikinernas": "trikin",
    "trikiners": "trikin",
    "trikinosen": "trikinos",
    "trikinosens": "trikinos",
    "trikins": "trikin",
    "trikinösa": "trikinös",
    "trikinösare": "trikinös",
    "trikinösares": "trikinös",
    "trikinösas": "trikinös",
    "trikinösast": "trikinös",
    "trikinösaste": "trikinös",
    "trikinösastes": "trikinös",
    "trikinösasts": "trikinös",
    "trikinöse": "trikinös",
    "trikinöses": "trikinös",
    "trikinöst": "trikinös",
    "trikinösts": "trikinös",
    "trikloretylenen": "trikloretylen",
    "trikloretylenens": "trikloretylen",
    "trikloretylenet": "trikloretylen",
    "trikloretylenets": "trikloretylen",
    "trikloretylens": "trikloretylen",
    "trikoloren": "trikolor",
    "trikolorens": "trikolor",
    "trikolorer": "trikolor",
    "trikolorerna": "trikolor",
    "trikolorernas": "trikolor",
    "trikolorers": "trikolor",
    "trikolors": "trikolor",
    "trikotages": "trikotage",
    "trikotaget": "trikotage",
    "trikotagets": "trikotage",
    "trikåer": "trikå",
    "trikåerna": "trikå",
    "trikåernas": "trikå",
    "trikåers": "trikå",
    "trikån": "trikå",
    "trikåns": "trikå",
    "trikås": "trikå",
    "trikåvar": "trikåvara",
    "trikåvaran": "trikåvara",
    "trikåvarans": "trikåvara",
    "trikåvaras": "trikåvara",
    "trikåvaror": "trikåvara",
    "trikåvarorna": "trikåvara",
    "trikåvarornas": "trikåvara",
    "trikåvarors": "trikåvara",
    "trikåvaru": "trikåvara",
    "trilaterala": "trilateral",
    "trilateralare": "trilateral",
    "trilateralares": "trilateral",
    "trilateralas": "trilateral",
    "trilateralast": "trilateral",
    "trilateralaste": "trilateral",
    "trilateralastes": "trilateral",
    "trilateralasts": "trilateral",
    "trilaterale": "trilateral",
    "trilaterales": "trilateral",
    "trilaterals": "trilateral",
    "trilateralt": "trilateral",
    "trilateralts": "trilateral",
    "triljondelar": "triljondel",
    "triljondelarna": "triljondel",
    "triljondelarnas": "triljondel",
    "triljondelars": "triljondel",
    "triljondelen": "triljondel",
    "triljondelens": "triljondel",
    "triljondels": "triljondel",
    "triljonen": "triljon",
    "triljonens": "triljon",
    "triljoner": "triljon",
    "triljonerna": "triljon",
    "triljonernas": "triljon",
    "triljoners": "triljon",
    "triljons": "triljon",
    "triljonte": "triljon",
    "triljontes": "triljon",
    "trill": "trilla",
    "trillad": "trilla",
    "trillade": "trilla",
    "trillades": "trilla",
    "trillads": "trilla",
    "trillan": "trilla",
    "trillande": "trilla",
    "trillanden": "trillande",
    "trillandena": "trillande",
    "trillandenas": "trillande",
    "trillandens": "trillande",
    "trillandes": "trillande",
    "trillandet": "trillande",
    "trillandets": "trillande",
    "trillans": "trilla",
    "trillar": "trilla",
    "trillas": "trilla",
    "trillat": "trilla",
    "trillats": "trilla",
    "trille": "trilla",
    "trillingar": "trilling",
    "trillingarna": "trilling",
    "trillingarnas": "trilling",
    "trillingars": "trilling",
    "trillingen": "trilling",
    "trillingens": "trilling",
    "trillingkristallen": "trillingkristall",
    "trillingkristallens": "trillingkristall",
    "trillingkristaller": "trillingkristall",
    "trillingkristallerna": "trillingkristall",
    "trillingkristallernas": "trillingkristall",
    "trillingkristallers": "trillingkristall",
    "trillingkristalls": "trillingkristall",
    "trillingnerven": "trillingnerv",
    "trillingnervens": "trillingnerv",
    "trillingnerver": "trillingnerv",
    "trillingnerverna": "trillingnerv",
    "trillingnervernas": "trillingnerv",
    "trillingnervers": "trillingnerv",
    "trillingnervs": "trillingnerv",
    "trillings": "trilling",
    "trillionen": "trillion",
    "trillionens": "trillion",
    "trillioner": "trillion",
    "trillionerna": "trillion",
    "trillionernas": "trillion",
    "trillioners": "trillion",
    "trillions": "trillion",
    "trillionte": "trillion",
    "trilliontes": "trillion",
    "trillor": "trilla",
    "trillorna": "trilla",
    "trillornas": "trilla",
    "trillors": "trilla",
    "trills": "trilla",
    "trilobiten": "trilobit",
    "trilobitens": "trilobit",
    "trilobiter": "trilobit",
    "trilobiterna": "trilobit",
    "trilobiternas": "trilobit",
    "trilobiters": "trilobit",
    "trilobits": "trilobit",
    "trilogien": "trilogi",
    "trilogiens": "trilogi",
    "trilogier": "trilogi",
    "trilogierna": "trilogi",
    "trilogiernas": "trilogi",
    "trilogiers": "trilogi",
    "trilogin": "trilogi",
    "trilogins": "trilogi",
    "trilogis": "trilogi",
    "trilska": "trilsk",
    "trilskades": "trilskas",
    "trilskan": "trilska",
    "trilskans": "trilska",
    "trilskare": "trilsk",
    "trilskares": "trilsk",
    "trilskas": "trilska",
    "trilskast": "trilsk",
    "trilskaste": "trilsk",
    "trilskastes": "trilsk",
    "trilskasts": "trilsk",
    "trilskats": "trilskas",
    "trilske": "trilsk",
    "trilskens": "trilsken",
    "trilskes": "trilsk",
    "trilsket": "trilsken",
    "trilskets": "trilsken",
    "trilskheten": "trilskhet",
    "trilskhetens": "trilskhet",
    "trilskhets": "trilskhet",
    "trilskna": "trilsken",
    "trilsknare": "trilsken",
    "trilsknares": "trilsken",
    "trilsknas": "trilsken",
    "trilsknast": "trilsken",
    "trilsknaste": "trilsken",
    "trilsknastes": "trilsken",
    "trilsknasts": "trilsken",
    "trilskne": "trilsken",
    "trilsknes": "trilsken",
    "trilsks": "trilsk",
    "trilskt": "trilsk",
    "trilskts": "trilsk",
    "trim": "trimma",
    "trimetern": "trimeter",
    "trimeterns": "trimeter",
    "trimeters": "trimeter",
    "trimetrar": "trimeter",
    "trimetrarna": "trimeter",
    "trimetrarnas": "trimeter",
    "trimetrars": "trimeter",
    "trimhuvuden": "trimhuvud",
    "trimhuvudena": "trimhuvud",
    "trimhuvudenas": "trimhuvud",
    "trimhuvudens": "trimhuvud",
    "trimhuvudet": "trimhuvud",
    "trimhuvudets": "trimhuvud",
    "trimhuvuds": "trimhuvud",
    "trimmad": "trimma",
    "trimmade": "trimma",
    "trimmades": "trimma",
    "trimmads": "trimma",
    "trimmande": "trimma",
    "trimmanden": "trimmande",
    "trimmandena": "trimmande",
    "trimmandenas": "trimmande",
    "trimmandens": "trimmande",
    "trimmandes": "trimmande",
    "trimmandet": "trimmande",
    "trimmandets": "trimmande",
    "trimmar": "trimma",
    "trimmas": "trimma",
    "trimmat": "trimma",
    "trimmats": "trimma",
    "trimmen": "trim",
    "trimmens": "trim",
    "trimmern": "trimmer",
    "trimmerns": "trimmer",
    "trimmers": "trimmer",
    "trimmersarna": "trimmer",
    "trimmersarnas": "trimmer",
    "trimmersen": "trimmer",
    "trimmersens": "trimmer",
    "trimmerspol": "trimmerspole",
    "trimmerspolar": "trimmerspole",
    "trimmerspolarna": "trimmerspole",
    "trimmerspolarnas": "trimmerspole",
    "trimmerspolars": "trimmerspole",
    "trimmerspolen": "trimmerspole",
    "trimmerspolens": "trimmerspole",
    "trimmerspoles": "trimmerspole",
    "trimmerspols": "trimmerspole",
    "trimmertrådar": "trimmertråd",
    "trimmertrådarna": "trimmertråd",
    "trimmertrådarnas": "trimmertråd",
    "trimmertrådars": "trimmertråd",
    "trimmertråden": "trimmertråd",
    "trimmertrådens": "trimmertråd",
    "trimmertråds": "trimmertråd",
    "trimmet": "trim",
    "trimmets": "trim",
    "trimningar": "trimning",
    "trimningarna": "trimning",
    "trimningarnas": "trimning",
    "trimningars": "trimning",
    "trimningen": "trimning",
    "trimningens": "trimning",
    "trimnings": "trimning",
    "trimningsfunktionen": "trimningsfunktion",
    "trimningsfunktionens": "trimningsfunktion",
    "trimningsfunktioner": "trimningsfunktion",
    "trimningsfunktionerna": "trimningsfunktion",
    "trimningsfunktionernas": "trimningsfunktion",
    "trimningsfunktioners": "trimningsfunktion",
    "trimningsfunktions": "trimningsfunktion",
    "trimrar": "trimmer",
    "trimrarna": "trimmer",
    "trimrarnas": "trimmer",
    "trimrars": "trimmer",
    "trims": "trim",
    "trimtankar": "trimtank",
    "trimtankarna": "trimtank",
    "trimtankarnas": "trimtank",
    "trimtankars": "trimtank",
    "trimtanken": "trimtank",
    "trimtankens": "trimtank",
    "trimtanks": "trimtank",
    "trin": "tri",
    "trinda": "trind",
    "trindare": "trind",
    "trindares": "trind",
    "trindas": "trind",
    "trindast": "trind",
    "trindaste": "trind",
    "trindastes": "trind",
    "trindasts": "trind",
    "trindbladiga": "trindbladig",
    "trindbladigare": "trindbladig",
    "trindbladigares": "trindbladig",
    "trindbladigas": "trindbladig",
    "trindbladigast": "trindbladig",
    "trindbladigaste": "trindbladig",
    "trindbladigastes": "trindbladig",
    "trindbladigasts": "trindbladig",
    "trindbladige": "trindbladig",
    "trindbladiges": "trindbladig",
    "trindbladigs": "trindbladig",
    "trindbladigt": "trindbladig",
    "trindbladigts": "trindbladig",
    "trinde": "trind",
    "trindes": "trind",
    "trindheten": "trindhet",
    "trindhetens": "trindhet",
    "trindhets": "trindhet",
    "trindmaskar": "trindmask",
    "trindmaskarna": "trindmask",
    "trindmaskarnas": "trindmask",
    "trindmaskars": "trindmask",
    "trindmasken": "trindmask",
    "trindmaskens": "trindmask",
    "trindmasks": "trindmask",
    "trinds": "trind",
    "trindsnön": "trindsnö",
    "trindsnöns": "trindsnö",
    "trindsnös": "trindsnö",
    "trindsäden": "trindsäd",
    "trindsädens": "trindsäd",
    "trindsädes": "trindsäd",
    "trindsäds": "trindsäd",
    "trindyx": "trindyxa",
    "trindyxan": "trindyxa",
    "trindyxans": "trindyxa",
    "trindyxas": "trindyxa",
    "trindyxe": "trindyxa",
    "trindyxor": "trindyxa",
    "trindyxorna": "trindyxa",
    "trindyxornas": "trindyxa",
    "trindyxors": "trindyxa",
    "trinidadiern": "trinidadier",
    "trinidadierna": "trinidadier",
    "trinidadiernas": "trinidadier",
    "trinidadierns": "trinidadier",
    "trinidadiers": "trinidadier",
    "trinidadiska": "trinidadisk",
    "trinidadiskan": "trinidadiska",
    "trinidadiskans": "trinidadiska",
    "trinidadiskare": "trinidadisk",
    "trinidadiskares": "trinidadisk",
    "trinidadiskas": "trinidadiska",
    "trinidadiskast": "trinidadisk",
    "trinidadiskaste": "trinidadisk",
    "trinidadiskastes": "trinidadisk",
    "trinidadiskasts": "trinidadisk",
    "trinidadiske": "trinidadiska",
    "trinidadiskes": "trinidadisk",
    "trinidadiskor": "trinidadiska",
    "trinidadiskorna": "trinidadiska",
    "trinidadiskornas": "trinidadiska",
    "trinidadiskors": "trinidadiska",
    "trinidadisks": "trinidadisk",
    "trinidadiskt": "trinidadisk",
    "trinidadiskts": "trinidadisk",
    "trins": "tri",
    "trint": "trind",
    "trints": "trind",
    "trioden": "triod",
    "triodens": "triod",
    "trioder": "triod",
    "trioderna": "triod",
    "triodernas": "triod",
    "trioders": "triod",
    "triods": "triod",
    "triolen": "triol",
    "triolens": "triol",
    "trioler": "triol",
    "triolerna": "triol",
    "triolernas": "triol",
    "triolers": "triol",
    "triols": "triol",
    "trion": "trio",
    "trions": "trio",
    "trior": "trio",
    "triorna": "trio",
    "triornas": "trio",
    "triors": "trio",
    "trios": "trio",
    "triosen": "trio",
    "triosens": "trio",
    "trioxipurinen": "trioxipurin",
    "trioxipurinens": "trioxipurin",
    "trioxipuriner": "trioxipurin",
    "trioxipurinerna": "trioxipurin",
    "trioxipurinernas": "trioxipurin",
    "trioxipuriners": "trioxipurin",
    "trioxipurinet": "trioxipurin",
    "trioxipurinets": "trioxipurin",
    "trioxipurins": "trioxipurin",
    "tripletten": "triplett",
    "triplettens": "triplett",
    "tripletter": "triplett",
    "tripletterna": "triplett",
    "tripletternas": "triplett",
    "tripletters": "triplett",
    "tripletts": "triplett",
    "triploida": "triploid",
    "triploidare": "triploid",
    "triploidares": "triploid",
    "triploidas": "triploid",
    "triploidast": "triploid",
    "triploidaste": "triploid",
    "triploidastes": "triploid",
    "triploidasts": "triploid",
    "triploide": "triploid",
    "triploides": "triploid",
    "triploids": "triploid",
    "tripoden": "tripod",
    "tripodens": "tripod",
    "tripoder": "tripod",
    "tripoderna": "tripod",
    "tripodernas": "tripod",
    "tripoders": "tripod",
    "tripods": "tripod",
    "tripp": "trippa",
    "trippad": "trippa",
    "trippade": "trippa",
    "trippades": "trippa",
    "trippads": "trippa",
    "trippande": "trippa",
    "trippanden": "trippande",
    "trippandena": "trippande",
    "trippandenas": "trippande",
    "trippandens": "trippande",
    "trippandes": "trippande",
    "trippandet": "trippande",
    "trippandets": "trippande",
    "trippar": "trippa",
    "tripparna": "tripp",
    "tripparnas": "tripp",
    "trippars": "tripp",
    "trippas": "trippa",
    "trippat": "trippa",
    "trippats": "trippa",
    "trippelalliansen": "trippelallians",
    "trippelalliansens": "trippelallians",
    "trippelallianser": "trippelallians",
    "trippelallianserna": "trippelallians",
    "trippelalliansernas": "trippelallians",
    "trippelalliansers": "trippelallians",
    "trippelkrockar": "trippelkrock",
    "trippelkrockarna": "trippelkrock",
    "trippelkrockarnas": "trippelkrock",
    "trippelkrockars": "trippelkrock",
    "trippelkrocken": "trippelkrock",
    "trippelkrockens": "trippelkrock",
    "trippelkrocks": "trippelkrock",
    "trippeln": "trippel",
    "trippelns": "trippel",
    "trippelpunkten": "trippelpunkt",
    "trippelpunktens": "trippelpunkt",
    "trippelpunkter": "trippelpunkt",
    "trippelpunkterna": "trippelpunkt",
    "trippelpunkternas": "trippelpunkt",
    "trippelpunkters": "trippelpunkt",
    "trippelpunkts": "trippelpunkt",
    "trippels": "trippel",
    "trippelsegern": "trippelseger",
    "trippelsegerns": "trippelseger",
    "trippelsegers": "trippelseger",
    "trippelsegrar": "trippelseger",
    "trippelsegrarna": "trippelseger",
    "trippelsegrarnas": "trippelseger",
    "trippelsegrars": "trippelseger",
    "trippelstjärnan": "trippelstjärna",
    "trippelstjärnans": "trippelstjärna",
    "trippelstjärnas": "trippelstjärna",
    "trippelstjärne": "trippelstjärna",
    "trippelstjärnor": "trippelstjärna",
    "trippelstjärnorna": "trippelstjärna",
    "trippelstjärnornas": "trippelstjärna",
    "trippelstjärnors": "trippelstjärna",
    "trippelt": "trippel",
    "trippelts": "trippel",
    "trippelvaccinen": "trippelvaccin",
    "trippelvaccinens": "trippelvaccin",
    "trippelvaccinet": "trippelvaccin",
    "trippelvaccinets": "trippelvaccin",
    "trippelvaccins": "trippelvaccin",
    "trippen": "tripp",
    "trippens": "tripp",
    "tripper": "tripp",
    "tripperna": "tripp",
    "trippernas": "tripp",
    "trippers": "tripp",
    "trippet": "tripp",
    "trippets": "tripp",
    "trippla": "trippel",
    "tripplad": "trippla",
    "tripplade": "trippla",
    "tripplades": "trippla",
    "tripplads": "trippla",
    "tripplande": "trippla",
    "tripplanden": "tripplande",
    "tripplandena": "tripplande",
    "tripplandenas": "tripplande",
    "tripplandens": "tripplande",
    "tripplandes": "tripplande",
    "tripplandet": "tripplande",
    "tripplandets": "tripplande",
    "tripplar": "tripplare",
    "tripplare": "trippel",
    "tripplaren": "tripplare",
    "tripplarens": "tripplare",
    "tripplares": "tripplare",
    "tripplarna": "tripplare",
    "tripplarnas": "tripplare",
    "tripplars": "trippel",
    "tripplas": "trippla",
    "tripplast": "trippel",
    "tripplaste": "trippel",
    "tripplastes": "trippel",
    "tripplasts": "trippel",
    "tripplat": "trippla",
    "tripplats": "trippla",
    "tripple": "trippel",
    "trippler": "trippel",
    "tripplerna": "trippel",
    "tripplernas": "trippel",
    "tripplers": "trippel",
    "tripples": "trippel",
    "trippmätar": "trippmätare",
    "trippmätaren": "trippmätare",
    "trippmätarens": "trippmätare",
    "trippmätares": "trippmätare",
    "trippmätarna": "trippmätare",
    "trippmätarnas": "trippmätare",
    "tripps": "tripp",
    "tripsar": "trips",
    "tripsarna": "trips",
    "tripsarnas": "trips",
    "tripsars": "trips",
    "tripsen": "trips",
    "tripsens": "trips",
    "triptyken": "triptyk",
    "triptykens": "triptyk",
    "triptyker": "triptyk",
    "triptykerna": "triptyk",
    "triptykernas": "triptyk",
    "triptykers": "triptyk",
    "triptyks": "triptyk",
    "tris": "tri",
    "triss": "trissa",
    "trissan": "trissa",
    "trissans": "trissa",
    "trissas": "trissa",
    "trisse": "trissa",
    "trissen": "triss",
    "trissens": "triss",
    "trisslotten": "trisslott",
    "trisslottens": "trisslott",
    "trisslotter": "trisslott",
    "trisslotterna": "trisslott",
    "trisslotternas": "trisslott",
    "trisslotters": "trisslott",
    "trisslotts": "trisslott",
    "trissor": "trissa",
    "trissorna": "trissa",
    "trissornas": "trissa",
    "trissors": "trissa",
    "trista": "trist",
    "tristare": "trist",
    "tristares": "trist",
    "tristas": "trist",
    "tristast": "trist",
    "tristaste": "trist",
    "tristastes": "trist",
    "tristasts": "trist",
    "triste": "trist",
    "tristes": "trist",
    "tristessen": "tristess",
    "tristessens": "tristess",
    "tristheten": "tristhet",
    "tristhetens": "tristhet",
    "tristhets": "tristhet",
    "trists": "trist",
    "tritiet": "tritium",
    "tritiets": "tritium",
    "tritiumet": "tritium",
    "tritiumets": "tritium",
    "tritiums": "tritium",
    "tritonen": "triton",
    "tritonens": "triton",
    "tritoner": "triton",
    "tritonerna": "triton",
    "tritonernas": "triton",
    "tritoners": "triton",
    "tritons": "triton",
    "triumfatorer": "triumfator",
    "triumfatorerna": "triumfator",
    "triumfatorernas": "triumfator",
    "triumfatorers": "triumfator",
    "triumfatoriska": "triumfatorisk",
    "triumfatoriskare": "triumfatorisk",
    "triumfatoriskares": "triumfatorisk",
    "triumfatoriskas": "triumfatorisk",
    "triumfatoriskast": "triumfatorisk",
    "triumfatoriskaste": "triumfatorisk",
    "triumfatoriskastes": "triumfatorisk",
    "triumfatoriskasts": "triumfatorisk",
    "triumfatoriske": "triumfatorisk",
    "triumfatoriskes": "triumfatorisk",
    "triumfatorisks": "triumfatorisk",
    "triumfatoriskt": "triumfatorisk",
    "triumfatoriskts": "triumfatorisk",
    "triumfatorn": "triumfator",
    "triumfatorns": "triumfator",
    "triumfators": "triumfator",
    "triumfbåg": "triumfbåge",
    "triumfbågar": "triumfbåge",
    "triumfbågarna": "triumfbåge",
    "triumfbågarnas": "triumfbåge",
    "triumfbågars": "triumfbåge",
    "triumfbågen": "triumfbåge",
    "triumfbågens": "triumfbåge",
    "triumfbåges": "triumfbåge",
    "triumfbågs": "triumfbåge",
    "triumfen": "triumf",
    "triumfens": "triumf",
    "triumfer": "triumf",
    "triumferade": "triumfera",
    "triumferades": "triumfera",
    "triumferande": "triumfera",
    "triumferanden": "triumferande",
    "triumferandena": "triumferande",
    "triumferandenas": "triumferande",
    "triumferandens": "triumferande",
    "triumferandes": "triumferande",
    "triumferandet": "triumferande",
    "triumferandets": "triumferande",
    "triumferar": "triumfera",
    "triumferas": "triumfera",
    "triumferat": "triumfera",
    "triumferats": "triumfera",
    "triumferingar": "triumfering",
    "triumferingarna": "triumfering",
    "triumferingarnas": "triumfering",
    "triumferingars": "triumfering",
    "triumferingen": "triumfering",
    "triumferingens": "triumfering",
    "triumferings": "triumfering",
    "triumferna": "triumf",
    "triumfernas": "triumf",
    "triumfers": "triumf",
    "triumfs": "triumf",
    "triumviraten": "triumvirat",
    "triumviratens": "triumvirat",
    "triumviratet": "triumvirat",
    "triumviratets": "triumvirat",
    "triumvirats": "triumvirat",
    "triumviren": "triumvir",
    "triumvirens": "triumvir",
    "triumvirer": "triumvir",
    "triumvirerna": "triumvir",
    "triumvirernas": "triumvir",
    "triumvirers": "triumvir",
    "triumvirs": "triumvir",
    "trivdes": "trivas",
    "triviala": "trivial",
    "trivialare": "trivial",
    "trivialares": "trivial",
    "trivialas": "trivial",
    "trivialast": "trivial",
    "trivialaste": "trivial",
    "trivialastes": "trivial",
    "trivialasts": "trivial",
    "triviale": "trivial",
    "triviales": "trivial",
    "trivialiserad": "trivialisera",
    "trivialiserade": "trivialisera",
    "trivialiserades": "trivialisera",
    "trivialiserads": "trivialisera",
    "trivialiserande": "trivialisera",
    "trivialiseranden": "trivialiserande",
    "trivialiserandena": "trivialiserande",
    "trivialiserandenas": "trivialiserande",
    "trivialiserandens": "trivialiserande",
    "trivialiserandes": "trivialiserande",
    "trivialiserandet": "trivialiserande",
    "trivialiserandets": "trivialiserande",
    "trivialiserar": "trivialisera",
    "trivialiseras": "trivialisera",
    "trivialiserat": "trivialisera",
    "trivialiserats": "trivialisera",
    "trivialiserbara": "trivialiserbar",
    "trivialiserbarare": "trivialiserbar",
    "trivialiserbarares": "trivialiserbar",
    "trivialiserbaras": "trivialiserbar",
    "trivialiserbarast": "trivialiserbar",
    "trivialiserbaraste": "trivialiserbar",
    "trivialiserbarastes": "trivialiserbar",
    "trivialiserbarasts": "trivialiserbar",
    "trivialiserbare": "trivialiserbar",
    "trivialiserbares": "trivialiserbar",
    "trivialiserbarheten": "trivialiserbarhet",
    "trivialiserbarhetens": "trivialiserbarhet",
    "trivialiserbarhets": "trivialiserbarhet",
    "trivialiserbars": "trivialiserbar",
    "trivialiserbart": "trivialiserbar",
    "trivialiserbarts": "trivialiserbar",
    "trivialiseringar": "trivialisering",
    "trivialiseringarna": "trivialisering",
    "trivialiseringarnas": "trivialisering",
    "trivialiseringars": "trivialisering",
    "trivialiseringen": "trivialisering",
    "trivialiseringens": "trivialisering",
    "trivialiserings": "trivialisering",
    "trivialiteten": "trivialitet",
    "trivialitetens": "trivialitet",
    "trivialiteter": "trivialitet",
    "trivialiteterna": "trivialitet",
    "trivialiteternas": "trivialitet",
    "trivialiteters": "trivialitet",
    "trivialitets": "trivialitet",
    "trivialnamnen": "trivialnamn",
    "trivialnamnens": "trivialnamn",
    "trivialnamnet": "trivialnamn",
    "trivialnamnets": "trivialnamn",
    "trivialnamns": "trivialnamn",
    "trivials": "trivial",
    "trivialskolan": "trivialskola",
    "trivialskolans": "trivialskola",
    "trivialskolas": "trivialskola",
    "trivialt": "trivial",
    "trivialts": "trivial",
    "trivs": "trivas",
    "trivsamheten": "trivsamhet",
    "trivsamhetens": "trivsamhet",
    "trivsamheter": "trivsamhet",
    "trivsamheterna": "trivsamhet",
    "trivsamheternas": "trivsamhet",
    "trivsamheters": "trivsamhet",
    "trivsamhets": "trivsamhet",
    "trivsamma": "trivsam",
    "trivsammare": "trivsam",
    "trivsammares": "trivsam",
    "trivsammas": "trivsam",
    "trivsammast": "trivsam",
    "trivsammaste": "trivsam",
    "trivsammastes": "trivsam",
    "trivsammasts": "trivsam",
    "trivsamme": "trivsam",
    "trivsammes": "trivsam",
    "trivsams": "trivsam",
    "trivsamt": "trivsam",
    "trivsamts": "trivsam",
    "trivselfaktorer": "trivselfaktor",
    "trivselfaktorerna": "trivselfaktor",
    "trivselfaktorernas": "trivselfaktor",
    "trivselfaktorers": "trivselfaktor",
    "trivselfaktorn": "trivselfaktor",
    "trivselfaktorns": "trivselfaktor",
    "trivselfaktors": "trivselfaktor",
    "trivseln": "trivsel",
    "trivselns": "trivsel",
    "trivselregeln": "trivselregel",
    "trivselregelns": "trivselregel",
    "trivselregels": "trivselregel",
    "trivselregler": "trivselregel",
    "trivselreglerna": "trivselregel",
    "trivselreglernas": "trivselregel",
    "trivselreglers": "trivselregel",
    "trivsels": "trivsel",
    "trivselvikten": "trivselvikt",
    "trivselviktens": "trivselvikt",
    "trivselvikter": "trivselvikt",
    "trivselvikterna": "trivselvikt",
    "trivselvikternas": "trivselvikt",
    "trivselvikters": "trivselvikt",
    "trivselvikts": "trivselvikt",
    "trivts": "trivas",
    "triören": "triör",
    "triörens": "triör",
    "triörer": "triör",
    "triörerna": "triör",
    "triörernas": "triör",
    "triörers": "triör",
    "triörs": "triör",
    "trodd": "tro",
    "trodda": "tro",
    "troddas": "tro",
    "trodde": "tro",
    "troddes": "tro",
    "trodds": "tro",
    "troende": "tro",
    "troenden": "troende",
    "troendena": "troende",
    "troendenas": "troende",
    "troendens": "troende",
    "troendes": "troende",
    "troendet": "troende",
    "troendets": "troende",
    "trofasta": "trofast",
    "trofastare": "trofast",
    "trofastares": "trofast",
    "trofastas": "trofast",
    "trofastast": "trofast",
    "trofastaste": "trofast",
    "trofastastes": "trofast",
    "trofastasts": "trofast",
    "trofaste": "trofast",
    "trofastes": "trofast",
    "trofastheten": "trofasthet",
    "trofasthetens": "trofasthet",
    "trofastheter": "trofasthet",
    "trofastheterna": "trofasthet",
    "trofastheternas": "trofasthet",
    "trofastheters": "trofasthet",
    "trofasthets": "trofasthet",
    "trofasts": "trofast",
    "troféer": "trofé",
    "troféerna": "trofé",
    "troféernas": "trofé",
    "troféers": "trofé",
    "trofén": "trofé",
    "troféns": "trofé",
    "trofés": "trofé",
    "trogens": "trogen",
    "troget": "trogen",
    "trogets": "trogen",
    "troglodyten": "troglodyt",
    "troglodytens": "troglodyt",
    "troglodyter": "troglodyt",
    "troglodyterna": "troglodyt",
    "troglodyternas": "troglodyt",
    "troglodyters": "troglodyt",
    "troglodyts": "troglodyt",
    "trogna": "trogen",
    "trognare": "trogen",
    "trognares": "trogen",
    "trognas": "trogen",
    "trognast": "trogen",
    "trognaste": "trogen",
    "trognastes": "trogen",
    "trognasts": "trogen",
    "trogne": "trogen",
    "trognes": "trogen",
    "troheten": "trohet",
    "trohetens": "trohet",
    "troheter": "trohet",
    "troheterna": "trohet",
    "troheternas": "trohet",
    "troheters": "trohet",
    "trohets": "trohet",
    "trohetseden": "trohetsed",
    "trohetsedens": "trohetsed",
    "trohetseder": "trohetsed",
    "trohetsederna": "trohetsed",
    "trohetsedernas": "trohetsed",
    "trohetseders": "trohetsed",
    "trohetseds": "trohetsed",
    "trohjärtade": "trohjärtad",
    "trohjärtades": "trohjärtad",
    "trohjärtads": "trohjärtad",
    "trohjärtat": "trohjärtad",
    "trohjärtats": "trohjärtad",
    "trohjärtenheten": "trohjärtenhet",
    "trohjärtenhetens": "trohjärtenhet",
    "trohjärtenheter": "trohjärtenhet",
    "trohjärtenheterna": "trohjärtenhet",
    "trohjärtenheternas": "trohjärtenhet",
    "trohjärtenheters": "trohjärtenhet",
    "trohjärtenhets": "trohjärtenhet",
    "trojanen": "trojan",
    "trojanens": "trojan",
    "trojaner": "trojan",
    "trojanerna": "trojan",
    "trojanernas": "trojan",
    "trojaners": "trojan",
    "trojans": "trojan",
    "trojanska": "trojansk",
    "trojanskare": "trojansk",
    "trojanskares": "trojansk",
    "trojanskas": "trojansk",
    "trojanskast": "trojansk",
    "trojanskaste": "trojansk",
    "trojanskastes": "trojansk",
    "trojanskasts": "trojansk",
    "trojanske": "trojansk",
    "trojanskes": "trojansk",
    "trojansks": "trojansk",
    "trojanskt": "trojansk",
    "trojanskts": "trojansk",
    "trojeborgar": "trojeborg",
    "trojeborgarna": "trojeborg",
    "trojeborgarnas": "trojeborg",
    "trojeborgars": "trojeborg",
    "trojeborgen": "trojeborg",
    "trojeborgens": "trojeborg",
    "trojeborgs": "trojeborg",
    "trojk": "trojka",
    "trojkan": "trojka",
    "trojkans": "trojka",
    "trojkas": "trojka",
    "trojke": "trojka",
    "trojkor": "trojka",
    "trojkorna": "trojka",
    "trojkornas": "trojka",
    "trojkors": "trojka",
    "trojks": "trojka",
    "trokaiska": "trokaisk",
    "trokaiskare": "trokaisk",
    "trokaiskares": "trokaisk",
    "trokaiskas": "trokaisk",
    "trokaiskast": "trokaisk",
    "trokaiskaste": "trokaisk",
    "trokaiskastes": "trokaisk",
    "trokaiskasts": "trokaisk",
    "trokaiske": "trokaisk",
    "trokaiskes": "trokaisk",
    "trokaisks": "trokaisk",
    "trokaiskt": "trokaisk",
    "trokaiskts": "trokaisk",
    "trokéer": "troké",
    "trokéerna": "troké",
    "trokéernas": "troké",
    "trokéers": "troké",
    "trokéiska": "trokéisk",
    "trokéiskare": "trokéisk",
    "trokéiskares": "trokéisk",
    "trokéiskas": "trokéisk",
    "trokéiskast": "trokéisk",
    "trokéiskaste": "trokéisk",
    "trokéiskastes": "trokéisk",
    "trokéiskasts": "trokéisk",
    "trokéiske": "trokéisk",
    "trokéiskes": "trokéisk",
    "trokéisks": "trokéisk",
    "trokéiskt": "trokéisk",
    "trokéiskts": "trokéisk",
    "trokén": "troké",
    "trokéns": "troké",
    "trokés": "troké",
    "troliga": "trolig",
    "troligare": "trolig",
    "troligares": "trolig",
    "troligas": "trolig",
    "troligast": "trolig",
    "troligaste": "trolig",
    "troligastes": "trolig",
    "troligasts": "trolig",
    "trolige": "trolig",
    "troliges": "trolig",
    "troligheten": "trolighet",
    "trolighetens": "trolighet",
    "trolighets": "trolighet",
    "troligs": "trolig",
    "troligt": "trolig",
    "troligts": "trolig",
    "troll": "trolla",
    "trollad": "trolla",
    "trollade": "trolla",
    "trollades": "trolla",
    "trollads": "trolla",
    "trollande": "trolla",
    "trollanden": "trollande",
    "trollandena": "trollande",
    "trollandenas": "trollande",
    "trollandens": "trollande",
    "trollandes": "trollande",
    "trollandet": "trollande",
    "trollandets": "trollande",
    "trollar": "trolla",
    "trollas": "trolla",
    "trollat": "trolla",
    "trollats": "trolla",
    "trollband": "trollbinda",
    "trollbands": "trollbinda",
    "trollbarnen": "trollbarn",
    "trollbarnens": "trollbarn",
    "trollbarnet": "trollbarn",
    "trollbarnets": "trollbarn",
    "trollbarns": "trollbarn",
    "trollbind": "trollbinda",
    "trollbindande": "trollbinda",
    "trollbindanden": "trollbindande",
    "trollbindandena": "trollbindande",
    "trollbindandenas": "trollbindande",
    "trollbindandens": "trollbindande",
    "trollbindandes": "trollbindande",
    "trollbindandet": "trollbindande",
    "trollbindandets": "trollbindande",
    "trollbindas": "trollbinda",
    "trollbinde": "trollbinda",
    "trollbinder": "trollbinda",
    "trollbindes": "trollbinda",
    "trollbinds": "trollbinda",
    "trollbunde": "trollbinda",
    "trollbunden": "trollbinda",
    "trollbundens": "trollbinda",
    "trollbundes": "trollbinda",
    "trollbundet": "trollbinda",
    "trollbundets": "trollbinda",
    "trollbundit": "trollbinda",
    "trollbundits": "trollbinda",
    "trollbundna": "trollbinda",
    "trollbundnas": "trollbinda",
    "trollbundne": "trollbinda",
    "trollbundnes": "trollbinda",
    "trollbären": "trollbär",
    "trollbärens": "trollbär",
    "trollbäret": "trollbär",
    "trollbärets": "trollbär",
    "trollbärs": "trollbär",
    "trollcirkeln": "trollcirkel",
    "trollcirkelns": "trollcirkel",
    "trollcirkels": "trollcirkel",
    "trolldegar": "trolldeg",
    "trolldegarna": "trolldeg",
    "trolldegarnas": "trolldeg",
    "trolldegars": "trolldeg",
    "trolldegen": "trolldeg",
    "trolldegens": "trolldeg",
    "trolldegs": "trolldeg",
    "trolldomar": "trolldom",
    "trolldomarna": "trolldom",
    "trolldomarnas": "trolldom",
    "trolldomars": "trolldom",
    "trolldomen": "trolldom",
    "trolldomens": "trolldom",
    "trolldoms": "trolldom",
    "trolldomsriten": "trolldomsrit",
    "trolldomsritens": "trolldomsrit",
    "trolldomsriter": "trolldomsrit",
    "trolldomsriterna": "trolldomsrit",
    "trolldomsriternas": "trolldomsrit",
    "trolldomsriters": "trolldomsrit",
    "trolldomsrits": "trolldomsrit",
    "trolldrycken": "trolldryck",
    "trolldryckens": "trolldryck",
    "trolldrycker": "trolldryck",
    "trolldryckerna": "trolldryck",
    "trolldryckernas": "trolldryck",
    "trolldryckers": "trolldryck",
    "trolldrycks": "trolldryck",
    "trollen": "troll",
    "trollens": "troll",
    "trollerier": "trolleri",
    "trollerierna": "trolleri",
    "trolleriernas": "trolleri",
    "trolleriers": "trolleri",
    "trolleriet": "trolleri",
    "trolleriets": "trolleri",
    "trollerikonsten": "trollerikonst",
    "trollerikonstens": "trollerikonst",
    "trollerikonster": "trollerikonst",
    "trollerikonsterna": "trollerikonst",
    "trollerikonsternas": "trollerikonst",
    "trollerikonsters": "trollerikonst",
    "trollerikonsts": "trollerikonst",
    "trolleris": "trolleri",
    "trollerit": "trolleri",
    "trolleritricken": "trolleritrick",
    "trolleritrickens": "trolleritrick",
    "trolleritricket": "trolleritrick",
    "trolleritrickets": "trolleritrick",
    "trolleritricks": "trolleritrick",
    "trollerits": "trolleri",
    "trollet": "troll",
    "trollets": "troll",
    "trolleybussar": "trolleybuss",
    "trolleybussarna": "trolleybuss",
    "trolleybussarnas": "trolleybuss",
    "trolleybussars": "trolleybuss",
    "trolleybussen": "trolleybuss",
    "trolleybussens": "trolleybuss",
    "trolleyn": "trolley",
    "trolleyns": "trolley",
    "trolleys": "trolley",
    "trollformeln": "trollformel",
    "trollformelns": "trollformel",
    "trollformels": "trollformel",
    "trollformler": "trollformel",
    "trollformlerna": "trollformel",
    "trollformlernas": "trollformel",
    "trollformlers": "trollformel",
    "trollhar": "trollhare",
    "trollharar": "trollhare",
    "trollhararna": "trollhare",
    "trollhararnas": "trollhare",
    "trollharars": "trollhare",
    "trollharen": "trollhare",
    "trollharens": "trollhare",
    "trollhares": "trollhare",
    "trollhars": "trollhare",
    "trollhopp": "trollhoppa",
    "trollhoppan": "trollhoppa",
    "trollhoppans": "trollhoppa",
    "trollhoppas": "trollhoppa",
    "trollhoppe": "trollhoppa",
    "trollhoppor": "trollhoppa",
    "trollhopporna": "trollhoppa",
    "trollhoppornas": "trollhoppa",
    "trollhoppors": "trollhoppa",
    "trollhopps": "trollhoppa",
    "trollkarlar": "trollkarl",
    "trollkarlarna": "trollkarl",
    "trollkarlarnas": "trollkarl",
    "trollkarlars": "trollkarl",
    "trollkarlen": "trollkarl",
    "trollkarlens": "trollkarl",
    "trollkarls": "trollkarl",
    "trollkonsten": "trollkonst",
    "trollkonstens": "trollkonst",
    "trollkonster": "trollkonst",
    "trollkonsterna": "trollkonst",
    "trollkonsternas": "trollkonst",
    "trollkonsters": "trollkonst",
    "trollkonstnären": "trollkonstnär",
    "trollkonstnärens": "trollkonstnär",
    "trollkonstnärer": "trollkonstnär",
    "trollkonstnärerna": "trollkonstnär",
    "trollkonstnärernas": "trollkonstnär",
    "trollkonstnärers": "trollkonstnär",
    "trollkonstnärs": "trollkonstnär",
    "trollkonsts": "trollkonst",
    "trollkraften": "trollkraft",
    "trollkraftens": "trollkraft",
    "trollkrafts": "trollkraft",
    "trollkretsen": "trollkrets",
    "trollkretsens": "trollkrets",
    "trollkunniga": "trollkunnig",
    "trollkunnigare": "trollkunnig",
    "trollkunnigares": "trollkunnig",
    "trollkunnigas": "trollkunnig",
    "trollkunnigast": "trollkunnig",
    "trollkunnigaste": "trollkunnig",
    "trollkunnigastes": "trollkunnig",
    "trollkunnigasts": "trollkunnig",
    "trollkunnige": "trollkunnig",
    "trollkunniges": "trollkunnig",
    "trollkunnigheten": "trollkunnighet",
    "trollkunnighetens": "trollkunnighet",
    "trollkunnighets": "trollkunnighet",
    "trollkunnigs": "trollkunnig",
    "trollkunnigt": "trollkunnig",
    "trollkunnigts": "trollkunnig",
    "trollkäringar": "trollkäring",
    "trollkäringarna": "trollkäring",
    "trollkäringarnas": "trollkäring",
    "trollkäringars": "trollkäring",
    "trollkäringen": "trollkäring",
    "trollkäringens": "trollkäring",
    "trollkärings": "trollkäring",
    "trollkärringar": "trollkärring",
    "trollkärringarna": "trollkärring",
    "trollkärringarnas": "trollkärring",
    "trollkärringars": "trollkärring",
    "trollkärringen": "trollkärring",
    "trollkärringens": "trollkärring",
    "trollkärrings": "trollkärring",
    "trollmakten": "trollmakt",
    "trollmaktens": "trollmakt",
    "trollmakts": "trollmakt",
    "trollmoset": "trollmos",
    "trollmosets": "trollmos",
    "trollpack": "trollpacka",
    "trollpackan": "trollpacka",
    "trollpackans": "trollpacka",
    "trollpackas": "trollpacka",
    "trollpacke": "trollpacka",
    "trollpackor": "trollpacka",
    "trollpackorna": "trollpacka",
    "trollpackornas": "trollpacka",
    "trollpackors": "trollpacka",
    "trollpacks": "trollpacka",
    "trollrun": "trollruna",
    "trollrunan": "trollruna",
    "trollrunans": "trollruna",
    "trollrunas": "trollruna",
    "trollrune": "trollruna",
    "trollrunor": "trollruna",
    "trollrunorna": "trollruna",
    "trollrunornas": "trollruna",
    "trollrunors": "trollruna",
    "trollruns": "trollruna",
    "trolls": "troll",
    "trollskotten": "trollskott",
    "trollskottens": "trollskott",
    "trollskottet": "trollskott",
    "trollskottets": "trollskott",
    "trollskotts": "trollskott",
    "trollslagen": "trollslag",
    "trollslagens": "trollslag",
    "trollslaget": "trollslag",
    "trollslagets": "trollslag",
    "trollslags": "trollslag",
    "trollsländ": "trollslända",
    "trollsländan": "trollslända",
    "trollsländans": "trollslända",
    "trollsländas": "trollslända",
    "trollslände": "trollslända",
    "trollsländor": "trollslända",
    "trollsländorna": "trollslända",
    "trollsländornas": "trollslända",
    "trollsländors": "trollslända",
    "trollsländs": "trollslända",
    "trollspöet": "trollspö",
    "trollspöets": "trollspö",
    "trollspön": "trollspö",
    "trollspöna": "trollspö",
    "trollspönas": "trollspö",
    "trollspöns": "trollspö",
    "trollspös": "trollspö",
    "trollspöt": "trollspö",
    "trollspöts": "trollspö",
    "trollstavar": "trollstav",
    "trollstavarna": "trollstav",
    "trollstavarnas": "trollstav",
    "trollstavars": "trollstav",
    "trollstaven": "trollstav",
    "trollstavens": "trollstav",
    "trollstavs": "trollstav",
    "trollsången": "trollsång",
    "trollsångens": "trollsång",
    "trollsånger": "trollsång",
    "trollsångerna": "trollsång",
    "trollsångernas": "trollsång",
    "trollsångers": "trollsång",
    "trollsångs": "trollsång",
    "trolltrum": "trolltrumma",
    "trolltrumman": "trolltrumma",
    "trolltrummans": "trolltrumma",
    "trolltrummas": "trolltrumma",
    "trolltrumme": "trolltrumma",
    "trolltrummor": "trolltrumma",
    "trolltrummorna": "trolltrumma",
    "trolltrummornas": "trolltrumma",
    "trolltrummors": "trolltrumma",
    "trolltrums": "trolltrumma",
    "trolov": "trolova",
    "trolovad": "trolova",
    "trolovade": "trolovad",
    "trolovades": "trolovad",
    "trolovads": "trolovad",
    "trolovande": "trolova",
    "trolovanden": "trolovande",
    "trolovandena": "trolovande",
    "trolovandenas": "trolovande",
    "trolovandens": "trolovande",
    "trolovandes": "trolovande",
    "trolovandet": "trolovande",
    "trolovandets": "trolovande",
    "trolovar": "trolova",
    "trolovas": "trolova",
    "trolovat": "trolovad",
    "trolovats": "trolovad",
    "trolovningar": "trolovning",
    "trolovningarna": "trolovning",
    "trolovningarnas": "trolovning",
    "trolovningars": "trolovning",
    "trolovningen": "trolovning",
    "trolovningens": "trolovning",
    "trolovnings": "trolovning",
    "trolovningsbarnen": "trolovningsbarn",
    "trolovningsbarnens": "trolovningsbarn",
    "trolovningsbarnet": "trolovningsbarn",
    "trolovningsbarnets": "trolovningsbarn",
    "trolovningsbarns": "trolovningsbarn",
    "trolovningslöften": "trolovningslöfte",
    "trolovningslöftena": "trolovningslöfte",
    "trolovningslöftenas": "trolovningslöfte",
    "trolovningslöftens": "trolovningslöfte",
    "trolovningslöftes": "trolovningslöfte",
    "trolovningslöftet": "trolovningslöfte",
    "trolovningslöftets": "trolovningslöfte",
    "trolska": "trolsk",
    "trolskare": "trolsk",
    "trolskares": "trolsk",
    "trolskas": "trolsk",
    "trolskast": "trolsk",
    "trolskaste": "trolsk",
    "trolskastes": "trolsk",
    "trolskasts": "trolsk",
    "trolske": "trolsk",
    "trolskes": "trolsk",
    "trolskheten": "trolskhet",
    "trolskhetens": "trolskhet",
    "trolskhets": "trolskhet",
    "trolsks": "trolsk",
    "trolskt": "trolsk",
    "trolskts": "trolsk",
    "trolösa": "trolös",
    "trolösare": "trolös",
    "trolösares": "trolös",
    "trolösas": "trolös",
    "trolösast": "trolös",
    "trolösaste": "trolös",
    "trolösastes": "trolös",
    "trolösasts": "trolös",
    "trolöse": "trolös",
    "trolöses": "trolös",
    "trolösheten": "trolöshet",
    "trolöshetens": "trolöshet",
    "trolösheter": "trolöshet",
    "trolösheterna": "trolöshet",
    "trolösheternas": "trolöshet",
    "trolösheters": "trolöshet",
    "trolöshets": "trolöshet",
    "trolöst": "trolös",
    "trolösts": "trolös",
    "tromannen": "troman",
    "tromannens": "troman",
    "tromans": "troman",
    "tromben": "tromb",
    "trombens": "tromb",
    "tromber": "tromb",
    "tromberna": "tromb",
    "trombernas": "tromb",
    "trombers": "tromb",
    "trombocyten": "trombocyt",
    "trombocytens": "trombocyt",
    "trombocyter": "trombocyt",
    "trombocyterna": "trombocyt",
    "trombocyternas": "trombocyt",
    "trombocyters": "trombocyt",
    "trombocyts": "trombocyt",
    "trombonen": "trombon",
    "trombonens": "trombon",
    "tromboner": "trombon",
    "trombonerna": "trombon",
    "trombonernas": "trombon",
    "tromboners": "trombon",
    "trombonisten": "trombonist",
    "trombonistens": "trombonist",
    "trombonister": "trombonist",
    "trombonisterna": "trombonist",
    "trombonisternas": "trombonist",
    "trombonisters": "trombonist",
    "trombonists": "trombonist",
    "trombons": "trombon",
    "trombosen": "trombos",
    "trombosens": "trombos",
    "tromboser": "trombos",
    "tromboserna": "trombos",
    "trombosernas": "trombos",
    "trombosers": "trombos",
    "trombs": "tromb",
    "tromel": "tromla",
    "tromlan": "tromla",
    "tromlans": "tromla",
    "tromlas": "tromla",
    "tromle": "tromla",
    "tromlor": "tromla",
    "tromlorna": "tromla",
    "tromlornas": "tromla",
    "tromlors": "tromla",
    "tromän": "troman",
    "tromännen": "troman",
    "tromännens": "troman",
    "tromäns": "troman",
    "tron": "trona",
    "tronad": "trona",
    "tronade": "trona",
    "tronades": "trona",
    "tronads": "trona",
    "tronande": "trona",
    "tronanden": "tronande",
    "tronandena": "tronande",
    "tronandenas": "tronande",
    "tronandens": "tronande",
    "tronandes": "tronande",
    "tronandet": "tronande",
    "tronandets": "tronande",
    "tronar": "trona",
    "tronarvingar": "tronarvinge",
    "tronarvingarna": "tronarvinge",
    "tronarvingarnas": "tronarvinge",
    "tronarvingars": "tronarvinge",
    "tronarvingen": "tronarvinge",
    "tronarvingens": "tronarvinge",
    "tronarvinges": "tronarvinge",
    "tronas": "trona",
    "tronat": "trona",
    "tronats": "trona",
    "tronavsägelsen": "tronavsägelse",
    "tronavsägelsens": "tronavsägelse",
    "tronavsägelser": "tronavsägelse",
    "tronavsägelserna": "tronavsägelse",
    "tronavsägelsernas": "tronavsägelse",
    "tronavsägelsers": "tronavsägelse",
    "tronavsägelses": "tronavsägelse",
    "tronbestigningar": "tronbestigning",
    "tronbestigningarna": "tronbestigning",
    "tronbestigningarnas": "tronbestigning",
    "tronbestigningars": "tronbestigning",
    "tronbestigningen": "tronbestigning",
    "tronbestigningens": "tronbestigning",
    "tronbestignings": "tronbestigning",
    "tronen": "tron",
    "tronens": "tron",
    "troner": "tron",
    "tronerna": "tron",
    "tronernas": "tron",
    "troners": "tron",
    "tronföljar": "tronföljare",
    "tronföljaren": "tronföljare",
    "tronföljarens": "tronföljare",
    "tronföljares": "tronföljare",
    "tronföljarna": "tronföljare",
    "tronföljarnas": "tronföljare",
    "tronföljden": "tronföljd",
    "tronföljdens": "tronföljd",
    "tronföljder": "tronföljd",
    "tronföljderna": "tronföljd",
    "tronföljdernas": "tronföljd",
    "tronföljders": "tronföljd",
    "tronföljds": "tronföljd",
    "tronföljerskan": "tronföljerska",
    "tronföljerskans": "tronföljerska",
    "tronföljerskas": "tronföljerska",
    "tronföljerske": "tronföljerska",
    "tronföljerskor": "tronföljerska",
    "tronföljerskorna": "tronföljerska",
    "tronföljerskornas": "tronföljerska",
    "tronföljerskors": "tronföljerska",
    "tronhimlar": "tronhimmel",
    "tronhimlarna": "tronhimmel",
    "tronhimlarnas": "tronhimmel",
    "tronhimlars": "tronhimmel",
    "tronhimlen": "tronhimmel",
    "tronhimlens": "tronhimmel",
    "tronhimmelen": "tronhimmel",
    "tronhimmelens": "tronhimmel",
    "tronhimmeln": "tronhimmel",
    "tronhimmelns": "tronhimmel",
    "tronhimmels": "tronhimmel",
    "troninnehaven": "troninnehav",
    "troninnehavens": "troninnehav",
    "troninnehavet": "troninnehav",
    "troninnehavets": "troninnehav",
    "troninnehavs": "troninnehav",
    "tronpretendenten": "tronpretendent",
    "tronpretendentens": "tronpretendent",
    "tronpretendenter": "tronpretendent",
    "tronpretendenterna": "tronpretendent",
    "tronpretendenternas": "tronpretendent",
    "tronpretendenters": "tronpretendent",
    "tronpretendents": "tronpretendent",
    "trons": "tron",
    "tronsalar": "tronsal",
    "tronsalarna": "tronsal",
    "tronsalarnas": "tronsal",
    "tronsalars": "tronsal",
    "tronsalen": "tronsal",
    "tronsalens": "tronsal",
    "tronsals": "tronsal",
    "tronskiften": "tronskifte",
    "tronskiftena": "tronskifte",
    "tronskiftenas": "tronskifte",
    "tronskiftens": "tronskifte",
    "tronskiftes": "tronskifte",
    "tronskiftet": "tronskifte",
    "tronskiftets": "tronskifte",
    "trontalen": "trontal",
    "trontalens": "trontal",
    "trontalet": "trontal",
    "trontalets": "trontal",
    "trontals": "trontal",
    "trontillträden": "trontillträde",
    "trontillträdena": "trontillträde",
    "trontillträdenas": "trontillträde",
    "trontillträdens": "trontillträde",
    "trontillträdes": "trontillträde",
    "trontillträdet": "trontillträde",
    "trontillträdets": "trontillträde",
    "tropen": "trop",
    "tropens": "trop",
    "troper": "trop",
    "troperna": "trop",
    "tropernas": "trop",
    "tropers": "trop",
    "tropiken": "tropik",
    "tropikens": "tropik",
    "tropiker": "tropik",
    "tropikerna": "tropik",
    "tropikernas": "tropikerna",
    "tropikers": "tropik",
    "tropikfågeln": "tropikfågel",
    "tropikfågelns": "tropikfågel",
    "tropikfågels": "tropikfågel",
    "tropikfåglar": "tropikfågel",
    "tropikfåglarna": "tropikfågel",
    "tropikfåglarnas": "tropikfågel",
    "tropikfåglars": "tropikfågel",
    "tropikhjälmar": "tropikhjälm",
    "tropikhjälmarna": "tropikhjälm",
    "tropikhjälmarnas": "tropikhjälm",
    "tropikhjälmars": "tropikhjälm",
    "tropikhjälmen": "tropikhjälm",
    "tropikhjälmens": "tropikhjälm",
    "tropikhjälms": "tropikhjälm",
    "tropikkläderna": "tropikkläder",
    "tropikklädernas": "tropikkläder",
    "tropikkläders": "tropikkläder",
    "tropikklädes": "tropikkläder",
    "tropikkläds": "tropikkläder",
    "tropiks": "tropik",
    "tropiska": "tropisk",
    "tropiskare": "tropisk",
    "tropiskares": "tropisk",
    "tropiskas": "tropisk",
    "tropiskast": "tropisk",
    "tropiskaste": "tropisk",
    "tropiskastes": "tropisk",
    "tropiskasts": "tropisk",
    "tropiske": "tropisk",
    "tropiskes": "tropisk",
    "tropisks": "tropisk",
    "tropiskt": "tropisk",
    "tropiskts": "tropisk",
    "tropismen": "tropism",
    "tropismens": "tropism",
    "tropismer": "tropism",
    "tropismerna": "tropism",
    "tropismernas": "tropism",
    "tropismers": "tropism",
    "tropisms": "tropism",
    "tropistiska": "tropistisk",
    "tropistiskas": "tropistisk",
    "tropistiske": "tropistisk",
    "tropistiskes": "tropistisk",
    "tropistisks": "tropistisk",
    "tropistiskt": "tropistisk",
    "tropistiskts": "tropistisk",
    "troposfären": "troposfär",
    "troposfärens": "troposfär",
    "troposfärer": "troposfär",
    "troposfärerna": "troposfär",
    "troposfärernas": "troposfär",
    "troposfärers": "troposfär",
    "troposfärs": "troposfär",
    "tropp": "troppa",
    "troppad": "troppa",
    "troppade": "troppa",
    "troppades": "troppa",
    "troppads": "troppa",
    "troppande": "troppa",
    "troppanden": "troppande",
    "troppandena": "troppande",
    "troppandenas": "troppande",
    "troppandens": "troppande",
    "troppandes": "troppande",
    "troppandet": "troppande",
    "troppandets": "troppande",
    "troppar": "troppa",
    "tropparna": "tropp",
    "tropparnas": "tropp",
    "troppars": "tropp",
    "troppas": "troppa",
    "troppat": "troppa",
    "troppats": "troppa",
    "troppen": "tropp",
    "troppens": "tropp",
    "tropps": "tropp",
    "trops": "trop",
    "tror": "tro",
    "tros": "trosa",
    "trosan": "trosa",
    "trosans": "trosa",
    "trosartikeln": "trosartikel",
    "trosartikelns": "trosartikel",
    "trosartikels": "trosartikel",
    "trosartiklar": "trosartikel",
    "trosartiklarna": "trosartikel",
    "trosartiklarnas": "trosartikel",
    "trosartiklars": "trosartikel",
    "trosas": "trosa",
    "trosbekännar": "trosbekännare",
    "trosbekännaren": "trosbekännare",
    "trosbekännarens": "trosbekännare",
    "trosbekännares": "trosbekännare",
    "trosbekännarna": "trosbekännare",
    "trosbekännarnas": "trosbekännare",
    "trosbekännelsen": "trosbekännelse",
    "trosbekännelsens": "trosbekännelse",
    "trosbekännelser": "trosbekännelse",
    "trosbekännelserna": "trosbekännelse",
    "trosbekännelsernas": "trosbekännelse",
    "trosbekännelsers": "trosbekännelse",
    "trosbekännelses": "trosbekännelse",
    "trose": "trosa",
    "trosfasta": "trosfast",
    "trosfastare": "trosfast",
    "trosfastares": "trosfast",
    "trosfastas": "trosfast",
    "trosfastast": "trosfast",
    "trosfastaste": "trosfast",
    "trosfastastes": "trosfast",
    "trosfastasts": "trosfast",
    "trosfaste": "trosfast",
    "trosfastes": "trosfast",
    "trosfastheten": "trosfasthet",
    "trosfasthetens": "trosfasthet",
    "trosfasthets": "trosfasthet",
    "trosfasts": "trosfast",
    "trosfriden": "trosfrid",
    "trosfridens": "trosfrid",
    "trosfrids": "trosfrid",
    "trosfriheten": "trosfrihet",
    "trosfrihetens": "trosfrihet",
    "trosfriheter": "trosfrihet",
    "trosfriheterna": "trosfrihet",
    "trosfriheternas": "trosfrihet",
    "trosfriheters": "trosfrihet",
    "trosfrihets": "trosfrihet",
    "trosfränden": "trosfrände",
    "trosfrändens": "trosfrände",
    "trosfränder": "trosfrände",
    "trosfränderna": "trosfrände",
    "trosfrändernas": "trosfrände",
    "trosfränders": "trosfrände",
    "trosfrändes": "trosfrände",
    "trosföreställningar": "trosföreställning",
    "trosföreställningarna": "trosföreställning",
    "trosföreställningarnas": "trosföreställning",
    "trosföreställningars": "trosföreställning",
    "trosföreställningen": "trosföreställning",
    "trosföreställningens": "trosföreställning",
    "trosföreställnings": "trosföreställning",
    "trosglöden": "trosglöd",
    "trosglödens": "trosglöd",
    "trosglöds": "trosglöd",
    "trosgördeln": "trosgördel",
    "trosgördelns": "trosgördel",
    "trosgördels": "trosgördel",
    "trosgördlar": "trosgördel",
    "trosgördlarna": "trosgördel",
    "trosgördlarnas": "trosgördel",
    "trosgördlars": "trosgördel",
    "trosivrar": "trosivrare",
    "trosivraren": "trosivrare",
    "trosivrarens": "trosivrare",
    "trosivrares": "trosivrare",
    "trosivrarna": "trosivrare",
    "trosivrarnas": "trosivrare",
    "troskyldiga": "troskyldig",
    "troskyldigare": "troskyldig",
    "troskyldigares": "troskyldig",
    "troskyldigas": "troskyldig",
    "troskyldigast": "troskyldig",
    "troskyldigaste": "troskyldig",
    "troskyldigastes": "troskyldig",
    "troskyldigasts": "troskyldig",
    "troskyldige": "troskyldig",
    "troskyldiges": "troskyldig",
    "troskyldigheten": "troskyldighet",
    "troskyldighetens": "troskyldighet",
    "troskyldighets": "troskyldighet",
    "troskyldigs": "troskyldig",
    "troskyldigt": "troskyldig",
    "troskyldigts": "troskyldig",
    "trosletar": "trosletare",
    "trosletaren": "trosletare",
    "trosletarens": "trosletare",
    "trosletares": "trosletare",
    "trosletarna": "trosletare",
    "trosletarnas": "trosletare",
    "trosmässiga": "trosmässig",
    "trosmässigare": "trosmässig",
    "trosmässigares": "trosmässig",
    "trosmässigas": "trosmässig",
    "trosmässigast": "trosmässig",
    "trosmässigaste": "trosmässig",
    "trosmässigastes": "trosmässig",
    "trosmässigasts": "trosmässig",
    "trosmässige": "trosmässig",
    "trosmässiges": "trosmässig",
    "trosmässigs": "trosmässig",
    "trosmässigt": "trosmässig",
    "trosmässigts": "trosmässig",
    "trosor": "trosa",
    "trosorna": "trosa",
    "trosornas": "trosa",
    "trosors": "trosa",
    "trosrörelsen": "trosrörelse",
    "trosrörelsens": "trosrörelse",
    "trosrörelser": "trosrörelse",
    "trosrörelserna": "trosrörelse",
    "trosrörelsernas": "trosrörelse",
    "trosrörelsers": "trosrörelse",
    "trosrörelses": "trosrörelse",
    "trossamfunden": "trossamfund",
    "trossamfundens": "trossamfund",
    "trossamfundet": "trossamfund",
    "trossamfundets": "trossamfund",
    "trossamfunds": "trossamfund",
    "trossar": "tross",
    "trossarna": "tross",
    "trossarnas": "tross",
    "trossars": "tross",
    "trossatsen": "trossats",
    "trossatsens": "trossats",
    "trossatser": "trossats",
    "trossatserna": "trossats",
    "trossatsernas": "trossats",
    "trossatsers": "trossats",
    "trossbottens": "trossbotten",
    "trossbottnar": "trossbotten",
    "trossbottnarna": "trossbotten",
    "trossbottnarnas": "trossbotten",
    "trossbottnars": "trossbotten",
    "trossbottnen": "trossbotten",
    "trossbottnens": "trossbotten",
    "trossdäcken": "trossdäck",
    "trossdäckens": "trossdäck",
    "trossdäcket": "trossdäck",
    "trossdäckets": "trossdäck",
    "trossdäcks": "trossdäck",
    "trossen": "tross",
    "trossens": "tross",
    "trossfyllningar": "trossfyllning",
    "trossfyllningarna": "trossfyllning",
    "trossfyllningarnas": "trossfyllning",
    "trossfyllningars": "trossfyllning",
    "trossfyllningen": "trossfyllning",
    "trossfyllningens": "trossfyllning",
    "trossfyllnings": "trossfyllning",
    "trosshästar": "trosshäst",
    "trosshästarna": "trosshäst",
    "trosshästarnas": "trosshäst",
    "trosshästars": "trosshäst",
    "trosshästen": "trosshäst",
    "trosshästens": "trosshäst",
    "trosshästs": "trosshäst",
    "trosskvinnan": "trosskvinna",
    "trosskvinnans": "trosskvinna",
    "trosskvinnas": "trosskvinna",
    "trosskvinne": "trosskvinna",
    "trosskvinno": "trosskvinna",
    "trosskvinnor": "trosskvinna",
    "trosskvinnorna": "trosskvinna",
    "trosskvinnornas": "trosskvinna",
    "trosskvinnors": "trosskvinna",
    "trosslagens": "trosslagen",
    "trosslaget": "trosslagen",
    "trosslagets": "trosslagen",
    "trosslagna": "trosslagen",
    "trosslagnare": "trosslagen",
    "trosslagnares": "trosslagen",
    "trosslagnas": "trosslagen",
    "trosslagnast": "trosslagen",
    "trosslagnaste": "trosslagen",
    "trosslagnastes": "trosslagen",
    "trosslagnasts": "trosslagen",
    "trosslagne": "trosslagen",
    "trosslagnes": "trosslagen",
    "trossningar": "trossning",
    "trossningarna": "trossning",
    "trossningarnas": "trossning",
    "trossningars": "trossning",
    "trossningen": "trossning",
    "trossningens": "trossning",
    "trossnings": "trossning",
    "trosuppfattningar": "trosuppfattning",
    "trosuppfattningarna": "trosuppfattning",
    "trosuppfattningarnas": "trosuppfattning",
    "trosuppfattningars": "trosuppfattning",
    "trosuppfattningen": "trosuppfattning",
    "trosuppfattningens": "trosuppfattning",
    "trosuppfattnings": "trosuppfattning",
    "trosvissa": "trosviss",
    "trosvissare": "trosviss",
    "trosvissares": "trosviss",
    "trosvissas": "trosviss",
    "trosvissast": "trosviss",
    "trosvissaste": "trosviss",
    "trosvissastes": "trosviss",
    "trosvissasts": "trosviss",
    "trosvisse": "trosviss",
    "trosvisses": "trosviss",
    "trosvissheten": "trosvisshet",
    "trosvisshetens": "trosvisshet",
    "trosvisshets": "trosvisshet",
    "trosvisst": "trosviss",
    "trosvissts": "trosviss",
    "trotjänar": "trotjänare",
    "trotjänaren": "trotjänare",
    "trotjänarens": "trotjänare",
    "trotjänares": "trotjänare",
    "trotjänarna": "trotjänare",
    "trotjänarnas": "trotjänare",
    "trots": "trotsa",
    "trotsad": "trotsa",
    "trotsade": "trotsa",
    "trotsades": "trotsa",
    "trotsads": "trotsa",
    "trotsande": "trotsa",
    "trotsanden": "trotsande",
    "trotsandena": "trotsande",
    "trotsandenas": "trotsande",
    "trotsandens": "trotsande",
    "trotsandes": "trotsande",
    "trotsandet": "trotsande",
    "trotsandets": "trotsande",
    "trotsar": "trotsa",
    "trotsas": "trotsa",
    "trotsat": "trotsa",
    "trotsats": "trotsa",
    "trotset": "trots",
    "trotsets": "trots",
    "trotsiga": "trotsig",
    "trotsigare": "trotsig",
    "trotsigares": "trotsig",
    "trotsigas": "trotsig",
    "trotsigast": "trotsig",
    "trotsigaste": "trotsig",
    "trotsigastes": "trotsig",
    "trotsigasts": "trotsig",
    "trotsige": "trotsig",
    "trotsiges": "trotsig",
    "trotsigheten": "trotsighet",
    "trotsighetens": "trotsighet",
    "trotsighets": "trotsighet",
    "trotsigs": "trotsig",
    "trotsigt": "trotsig",
    "trotsigts": "trotsig",
    "trotskismen": "trotskism",
    "trotskismens": "trotskism",
    "trotskismer": "trotskism",
    "trotskismerna": "trotskism",
    "trotskismernas": "trotskism",
    "trotskismers": "trotskism",
    "trotskisms": "trotskism",
    "trotskisten": "trotskist",
    "trotskistens": "trotskist",
    "trotskister": "trotskist",
    "trotskisterna": "trotskist",
    "trotskisternas": "trotskist",
    "trotskisters": "trotskist",
    "trotskistiska": "trotskistisk",
    "trotskistiskas": "trotskistisk",
    "trotskistiske": "trotskistisk",
    "trotskistiskes": "trotskistisk",
    "trotskistisks": "trotskistisk",
    "trotskistiskt": "trotskistisk",
    "trotskistiskts": "trotskistisk",
    "trotskists": "trotskist",
    "trotsåldern": "trotsålder",
    "trotsålderns": "trotsålder",
    "trotsålders": "trotsålder",
    "trotsåldrar": "trotsålder",
    "trotsåldrarna": "trotsålder",
    "trotsåldrarnas": "trotsålder",
    "trotsåldrars": "trotsålder",
    "trott": "tro",
    "trottoarbond": "trottoarbonde",
    "trottoarbonden": "trottoarbonde",
    "trottoarbondens": "trottoarbonde",
    "trottoarbondes": "trottoarbonde",
    "trottoarbonds": "trottoarbonde",
    "trottoarbönder": "trottoarbonde",
    "trottoarbönderna": "trottoarbonde",
    "trottoarböndernas": "trottoarbonde",
    "trottoarbönders": "trottoarbonde",
    "trottoaren": "trottoar",
    "trottoarens": "trottoar",
    "trottoarer": "trottoar",
    "trottoarerna": "trottoar",
    "trottoarernas": "trottoar",
    "trottoarers": "trottoar",
    "trottoarkanten": "trottoarkant",
    "trottoarkantens": "trottoarkant",
    "trottoarkanter": "trottoarkant",
    "trottoarkanterna": "trottoarkant",
    "trottoarkanternas": "trottoarkant",
    "trottoarkanters": "trottoarkant",
    "trottoarkants": "trottoarkant",
    "trottoars": "trottoar",
    "trottoarserveringar": "trottoarservering",
    "trottoarserveringarna": "trottoarservering",
    "trottoarserveringarnas": "trottoarservering",
    "trottoarserveringars": "trottoarservering",
    "trottoarserveringen": "trottoarservering",
    "trottoarserveringens": "trottoarservering",
    "trottoarserverings": "trottoarservering",
    "trotts": "tro",
    "trotylen": "trotyl",
    "trotylens": "trotyl",
    "trotyls": "trotyl",
    "trovärda": "trovärd",
    "trovärdare": "trovärd",
    "trovärdares": "trovärd",
    "trovärdas": "trovärd",
    "trovärdast": "trovärd",
    "trovärdaste": "trovärd",
    "trovärdastes": "trovärd",
    "trovärdasts": "trovärd",
    "trovärde": "trovärd",
    "trovärdes": "trovärd",
    "trovärdheten": "trovärdhet",
    "trovärdhetens": "trovärdhet",
    "trovärdhets": "trovärdhet",
    "trovärdiga": "trovärdig",
    "trovärdigare": "trovärdig",
    "trovärdigares": "trovärdig",
    "trovärdigas": "trovärdig",
    "trovärdigast": "trovärdig",
    "trovärdigaste": "trovärdig",
    "trovärdigastes": "trovärdig",
    "trovärdigasts": "trovärdig",
    "trovärdige": "trovärdig",
    "trovärdiges": "trovärdig",
    "trovärdigheten": "trovärdighet",
    "trovärdighetens": "trovärdighet",
    "trovärdighets": "trovärdighet",
    "trovärdigs": "trovärdig",
    "trovärdigt": "trovärdig",
    "trovärdigts": "trovärdig",
    "trovärds": "trovärd",
    "trovärt": "trovärd",
    "trovärts": "trovärd",
    "trubadurdiktningar": "trubadurdiktning",
    "trubadurdiktningarna": "trubadurdiktning",
    "trubadurdiktningarnas": "trubadurdiktning",
    "trubadurdiktningars": "trubadurdiktning",
    "trubadurdiktningen": "trubadurdiktning",
    "trubadurdiktningens": "trubadurdiktning",
    "trubadurdiktnings": "trubadurdiktning",
    "trubaduren": "trubadur",
    "trubadurens": "trubadur",
    "trubadurer": "trubadur",
    "trubadurerna": "trubadur",
    "trubadurernas": "trubadur",
    "trubadurers": "trubadur",
    "trubadurs": "trubadur",
    "trubbels": "trubbel",
    "trubbiga": "trubbig",
    "trubbigare": "trubbig",
    "trubbigares": "trubbig",
    "trubbigas": "trubbig",
    "trubbigast": "trubbig",
    "trubbigaste": "trubbig",
    "trubbigastes": "trubbig",
    "trubbigasts": "trubbig",
    "trubbige": "trubbig",
    "trubbiges": "trubbig",
    "trubbigheten": "trubbighet",
    "trubbighetens": "trubbighet",
    "trubbighets": "trubbighet",
    "trubbigs": "trubbig",
    "trubbigt": "trubbig",
    "trubbigts": "trubbig",
    "trubblen": "trubbel",
    "trubblens": "trubbel",
    "trubblet": "trubbel",
    "trubblets": "trubbel",
    "trubbnosar": "trubbnos",
    "trubbnosarna": "trubbnos",
    "trubbnosarnas": "trubbnos",
    "trubbnosars": "trubbnos",
    "trubbnosen": "trubbnos",
    "trubbnosens": "trubbnos",
    "trubbnosiga": "trubbnosig",
    "trubbnosigare": "trubbnosig",
    "trubbnosigares": "trubbnosig",
    "trubbnosigas": "trubbnosig",
    "trubbnosigast": "trubbnosig",
    "trubbnosigaste": "trubbnosig",
    "trubbnosigastes": "trubbnosig",
    "trubbnosigasts": "trubbnosig",
    "trubbnosige": "trubbnosig",
    "trubbnosiges": "trubbnosig",
    "trubbnosigheten": "trubbnosighet",
    "trubbnosighetens": "trubbnosighet",
    "trubbnosighets": "trubbnosighet",
    "trubbnosigs": "trubbnosig",
    "trubbnosigt": "trubbnosig",
    "trubbnosigts": "trubbnosig",
    "trubbnäs": "trubbnäsa",
    "trubbnäsan": "trubbnäsa",
    "trubbnäsans": "trubbnäsa",
    "trubbnäsas": "trubbnäsa",
    "trubbnäse": "trubbnäsa",
    "trubbnäsor": "trubbnäsa",
    "trubbnäsorna": "trubbnäsa",
    "trubbnäsornas": "trubbnäsa",
    "trubbnäsors": "trubbnäsa",
    "trubbnästa": "trubbnäst",
    "trubbnästare": "trubbnäst",
    "trubbnästares": "trubbnäst",
    "trubbnästas": "trubbnäst",
    "trubbnästast": "trubbnäst",
    "trubbnästaste": "trubbnäst",
    "trubbnästastes": "trubbnäst",
    "trubbnästasts": "trubbnäst",
    "trubbnäste": "trubbnäst",
    "trubbnästes": "trubbnäst",
    "trubbnästheten": "trubbnästhet",
    "trubbnästhetens": "trubbnästhet",
    "trubbnästhets": "trubbnästhet",
    "trubbnästs": "trubbnäst",
    "trubbvinkliga": "trubbvinklig",
    "trubbvinkligare": "trubbvinklig",
    "trubbvinkligares": "trubbvinklig",
    "trubbvinkligas": "trubbvinklig",
    "trubbvinkligast": "trubbvinklig",
    "trubbvinkligaste": "trubbvinklig",
    "trubbvinkligastes": "trubbvinklig",
    "trubbvinkligasts": "trubbvinklig",
    "trubbvinklige": "trubbvinklig",
    "trubbvinkliges": "trubbvinklig",
    "trubbvinkligheten": "trubbvinklighet",
    "trubbvinklighetens": "trubbvinklighet",
    "trubbvinklighets": "trubbvinklighet",
    "trubbvinkligs": "trubbvinklig",
    "trubbvinkligt": "trubbvinklig",
    "trubbvinkligts": "trubbvinklig",
    "truckar": "truck",
    "truckarna": "truck",
    "truckarnas": "truck",
    "truckars": "truck",
    "trucken": "truck",
    "truckens": "truck",
    "trucks": "truck",
    "trudelutten": "trudelutt",
    "trudeluttens": "trudelutt",
    "trudelutter": "trudelutt",
    "trudelutterna": "trudelutt",
    "trudelutternas": "trudelutt",
    "trudelutters": "trudelutt",
    "trudelutts": "trudelutt",
    "trug": "truga",
    "trugad": "truga",
    "trugade": "truga",
    "trugades": "truga",
    "trugads": "truga",
    "trugan": "truga",
    "trugande": "truga",
    "truganden": "trugande",
    "trugandena": "trugande",
    "trugandenas": "trugande",
    "trugandens": "trugande",
    "trugandes": "trugande",
    "trugandet": "trugande",
    "trugandets": "trugande",
    "trugans": "truga",
    "trugar": "truga",
    "trugas": "truga",
    "trugat": "truga",
    "trugats": "truga",
    "truge": "truga",
    "truget": "trug",
    "trugets": "trug",
    "trugor": "truga",
    "trugorna": "truga",
    "trugornas": "truga",
    "trugors": "truga",
    "trugs": "truga",
    "truismen": "truism",
    "truismens": "truism",
    "truismer": "truism",
    "truismerna": "truism",
    "truismernas": "truism",
    "truismers": "truism",
    "truisms": "truism",
    "truistiska": "truistisk",
    "truistiskare": "truistisk",
    "truistiskares": "truistisk",
    "truistiskas": "truistisk",
    "truistiskast": "truistisk",
    "truistiskaste": "truistisk",
    "truistiskastes": "truistisk",
    "truistiskasts": "truistisk",
    "truistiske": "truistisk",
    "truistiskes": "truistisk",
    "truistisks": "truistisk",
    "truistiskt": "truistisk",
    "truistiskts": "truistisk",
    "trul": "trula",
    "trulad": "trula",
    "trulade": "trula",
    "trulades": "trula",
    "trulads": "trula",
    "trulande": "trula",
    "trulanden": "trulande",
    "trulandena": "trulande",
    "trulandenas": "trulande",
    "trulandens": "trulande",
    "trulandes": "trulande",
    "trulandet": "trulande",
    "trulandets": "trulande",
    "trular": "trula",
    "trulas": "trula",
    "trulat": "trula",
    "trulats": "trula",
    "truliga": "trulig",
    "truligare": "trulig",
    "truligares": "trulig",
    "truligas": "trulig",
    "truligast": "trulig",
    "truligaste": "trulig",
    "truligastes": "trulig",
    "truligasts": "trulig",
    "trulige": "trulig",
    "truliges": "trulig",
    "truligheten": "trulighet",
    "trulighetens": "trulighet",
    "trulighets": "trulighet",
    "truligs": "trulig",
    "truligt": "trulig",
    "truligts": "trulig",
    "trulsar": "truls",
    "trulsarna": "truls",
    "trulsarnas": "truls",
    "trulsars": "truls",
    "trulsen": "truls",
    "trulsens": "truls",
    "trulsiga": "trulsig",
    "trulsigare": "trulsig",
    "trulsigares": "trulsig",
    "trulsigas": "trulsig",
    "trulsigast": "trulsig",
    "trulsigaste": "trulsig",
    "trulsigastes": "trulsig",
    "trulsigasts": "trulsig",
    "trulsige": "trulsig",
    "trulsiges": "trulsig",
    "trulsigheten": "trulsighet",
    "trulsighetens": "trulsighet",
    "trulsighets": "trulsighet",
    "trulsigs": "trulsig",
    "trulsigt": "trulsig",
    "trulsigts": "trulsig",
    "trum": "trumma",
    "trumbromsar": "trumbroms",
    "trumbromsarna": "trumbroms",
    "trumbromsarnas": "trumbroms",
    "trumbromsars": "trumbroms",
    "trumbromsen": "trumbroms",
    "trumbromsens": "trumbroms",
    "trumelden": "trumeld",
    "trumeldens": "trumeld",
    "trumelds": "trumeld",
    "trumf": "trumfa",
    "trumfad": "trumfa",
    "trumfade": "trumfa",
    "trumfades": "trumfa",
    "trumfads": "trumfa",
    "trumfande": "trumfa",
    "trumfanden": "trumfande",
    "trumfandena": "trumfande",
    "trumfandenas": "trumfande",
    "trumfandens": "trumfande",
    "trumfandes": "trumfande",
    "trumfandet": "trumfande",
    "trumfandets": "trumfande",
    "trumfar": "trumfa",
    "trumfarna": "trumf",
    "trumfarnas": "trumf",
    "trumfars": "trumf",
    "trumfas": "trumfa",
    "trumfat": "trumfa",
    "trumfats": "trumfa",
    "trumfen": "trumf",
    "trumfens": "trumf",
    "trumfet": "trumf",
    "trumfets": "trumf",
    "trumfkorten": "trumfkort",
    "trumfkortens": "trumfkort",
    "trumfkortet": "trumfkort",
    "trumfkortets": "trumfkort",
    "trumfkorts": "trumfkort",
    "trumfs": "trumf",
    "trumhinnan": "trumhinna",
    "trumhinnans": "trumhinna",
    "trumhinnas": "trumhinna",
    "trumhinne": "trumhinna",
    "trumhinnor": "trumhinna",
    "trumhinnorna": "trumhinna",
    "trumhinnornas": "trumhinna",
    "trumhinnors": "trumhinna",
    "trumhål": "trumhåla",
    "trumhålan": "trumhåla",
    "trumhålans": "trumhåla",
    "trumhålas": "trumhåla",
    "trumhåle": "trumhåla",
    "trumhålor": "trumhåla",
    "trumhålorna": "trumhåla",
    "trumhålornas": "trumhåla",
    "trumhålors": "trumhåla",
    "trumhåls": "trumhåla",
    "trumlad": "trumla",
    "trumlade": "trumla",
    "trumlades": "trumla",
    "trumlads": "trumla",
    "trumlande": "trumla",
    "trumlanden": "trumlande",
    "trumlandena": "trumlande",
    "trumlandenas": "trumlande",
    "trumlandens": "trumlande",
    "trumlandes": "trumlande",
    "trumlandet": "trumlande",
    "trumlandets": "trumlande",
    "trumlar": "trumla",
    "trumlas": "trumla",
    "trumlat": "trumla",
    "trumlats": "trumla",
    "trummad": "trumma",
    "trummade": "trumma",
    "trummades": "trumma",
    "trummads": "trumma",
    "trumman": "trumma",
    "trummande": "trumma",
    "trummanden": "trummande",
    "trummandena": "trummande",
    "trummandenas": "trummande",
    "trummandens": "trummande",
    "trummandes": "trummande",
    "trummandet": "trummande",
    "trummandets": "trummande",
    "trummans": "trumma",
    "trummar": "trumma",
    "trummas": "trumma",
    "trummat": "trumma",
    "trummats": "trumma",
    "trumme": "trumma",
    "trummel": "trumla",
    "trumminnen": "trumminne",
    "trumminnena": "trumminne",
    "trumminnenas": "trumminne",
    "trumminnens": "trumminne",
    "trumminnes": "trumminne",
    "trumminnet": "trumminne",
    "trumminnets": "trumminne",
    "trummor": "trumma",
    "trummorna": "trumma",
    "trummornas": "trumma",
    "trummors": "trumma",
    "trumpens": "trumpen",
    "trumpet": "trumpeta",
    "trumpetad": "trumpeta",
    "trumpetade": "trumpeta",
    "trumpetades": "trumpeta",
    "trumpetads": "trumpeta",
    "trumpetande": "trumpeta",
    "trumpetanden": "trumpetande",
    "trumpetandena": "trumpetande",
    "trumpetandenas": "trumpetande",
    "trumpetandens": "trumpetande",
    "trumpetandes": "trumpetande",
    "trumpetandet": "trumpetande",
    "trumpetandets": "trumpetande",
    "trumpetar": "trumpetare",
    "trumpetaren": "trumpetare",
    "trumpetarens": "trumpetare",
    "trumpetares": "trumpetare",
    "trumpetarna": "trumpetare",
    "trumpetarnas": "trumpetare",
    "trumpetas": "trumpeta",
    "trumpetat": "trumpeta",
    "trumpetats": "trumpeta",
    "trumpetblom": "trumpetblomma",
    "trumpetblomman": "trumpetblomma",
    "trumpetblommans": "trumpetblomma",
    "trumpetblommas": "trumpetblomma",
    "trumpetblomme": "trumpetblomma",
    "trumpetblommor": "trumpetblomma",
    "trumpetblommorna": "trumpetblomma",
    "trumpetblommornas": "trumpetblomma",
    "trumpetblommors": "trumpetblomma",
    "trumpetbloms": "trumpetblomma",
    "trumpeten": "trumpet",
    "trumpetens": "trumpet",
    "trumpeter": "trumpet",
    "trumpeterna": "trumpet",
    "trumpeternas": "trumpet",
    "trumpeters": "trumpet",
    "trumpetkonserten": "trumpetkonsert",
    "trumpetkonsertens": "trumpetkonsert",
    "trumpetkonserter": "trumpetkonsert",
    "trumpetkonserterna": "trumpetkonsert",
    "trumpetkonserternas": "trumpetkonsert",
    "trumpetkonserters": "trumpetkonsert",
    "trumpetkonserts": "trumpetkonsert",
    "trumpets": "trumpet",
    "trumpetsignalen": "trumpetsignal",
    "trumpetsignalens": "trumpetsignal",
    "trumpetsignaler": "trumpetsignal",
    "trumpetsignalerna": "trumpetsignal",
    "trumpetsignalernas": "trumpetsignal",
    "trumpetsignalers": "trumpetsignal",
    "trumpetsignals": "trumpetsignal",
    "trumpetstötar": "trumpetstöt",
    "trumpetstötarna": "trumpetstöt",
    "trumpetstötarnas": "trumpetstöt",
    "trumpetstötars": "trumpetstöt",
    "trumpetstöten": "trumpetstöt",
    "trumpetstötens": "trumpetstöt",
    "trumpetstöts": "trumpetstöt",
    "trumpinn": "trumpinne",
    "trumpinnar": "trumpinne",
    "trumpinnarna": "trumpinne",
    "trumpinnarnas": "trumpinne",
    "trumpinnars": "trumpinne",
    "trumpinnen": "trumpinne",
    "trumpinnens": "trumpinne",
    "trumpinnes": "trumpinne",
    "trumpinns": "trumpinne",
    "trumpna": "trumpen",
    "trumpnare": "trumpen",
    "trumpnares": "trumpen",
    "trumpnas": "trumpen",
    "trumpnast": "trumpen",
    "trumpnaste": "trumpen",
    "trumpnastes": "trumpen",
    "trumpnasts": "trumpen",
    "trumpne": "trumpen",
    "trumpnes": "trumpen",
    "trums": "trumma",
    "trumsjukan": "trumsjuka",
    "trumsjukans": "trumsjuka",
    "trumsjukas": "trumsjuka",
    "trumsjuke": "trumsjuka",
    "trumsjuks": "trumsjuka",
    "trumslagar": "trumslagare",
    "trumslagaren": "trumslagare",
    "trumslagarens": "trumslagare",
    "trumslagares": "trumslagare",
    "trumslagarna": "trumslagare",
    "trumslagarnas": "trumslagare",
    "trumslagen": "trumslag",
    "trumslagens": "trumslag",
    "trumslaget": "trumslag",
    "trumslagets": "trumslag",
    "trumslags": "trumslag",
    "trumstockar": "trumstock",
    "trumstockarna": "trumstock",
    "trumstockarnas": "trumstock",
    "trumstockars": "trumstock",
    "trumstocken": "trumstock",
    "trumstockens": "trumstock",
    "trumstocks": "trumstock",
    "trumvirveln": "trumvirvel",
    "trumvirvelns": "trumvirvel",
    "trumvirvels": "trumvirvel",
    "trumvirvlar": "trumvirvel",
    "trumvirvlarna": "trumvirvel",
    "trumvirvlarnas": "trumvirvel",
    "trumvirvlars": "trumvirvel",
    "trunkar": "trunk",
    "trunkarna": "trunk",
    "trunkarnas": "trunk",
    "trunkars": "trunk",
    "trunken": "trunk",
    "trunkens": "trunk",
    "trunkmaskinen": "trunkmaskin",
    "trunkmaskinens": "trunkmaskin",
    "trunkmaskiner": "trunkmaskin",
    "trunkmaskinerna": "trunkmaskin",
    "trunkmaskinernas": "trunkmaskin",
    "trunkmaskiners": "trunkmaskin",
    "trunkmaskins": "trunkmaskin",
    "trunks": "trunk",
    "truppen": "trupp",
    "truppens": "trupp",
    "trupper": "trupp",
    "trupperna": "trupp",
    "truppernas": "trupp",
    "truppers": "trupp",
    "truppförbanden": "truppförband",
    "truppförbandens": "truppförband",
    "truppförbandet": "truppförband",
    "truppförbandets": "truppförband",
    "truppförbands": "truppförband",
    "truppförflyttningar": "truppförflyttning",
    "truppförflyttningarna": "truppförflyttning",
    "truppförflyttningarnas": "truppförflyttning",
    "truppförflyttningars": "truppförflyttning",
    "truppförflyttningen": "truppförflyttning",
    "truppförflyttningens": "truppförflyttning",
    "truppförflyttnings": "truppförflyttning",
    "truppföringar": "truppföring",
    "truppföringarna": "truppföring",
    "truppföringarnas": "truppföring",
    "truppföringars": "truppföring",
    "truppföringen": "truppföring",
    "truppföringens": "truppföring",
    "truppförings": "truppföring",
    "truppförstärkningar": "truppförstärkning",
    "truppförstärkningarna": "truppförstärkning",
    "truppförstärkningarnas": "truppförstärkning",
    "truppförstärkningars": "truppförstärkning",
    "truppförstärkningen": "truppförstärkning",
    "truppförstärkningens": "truppförstärkning",
    "truppförstärknings": "truppförstärkning",
    "truppnärvaron": "truppnärvaro",
    "truppnärvarons": "truppnärvaro",
    "truppnärvaros": "truppnärvaro",
    "trupprörelsen": "trupprörelse",
    "trupprörelsens": "trupprörelse",
    "trupprörelser": "trupprörelse",
    "trupprörelserna": "trupprörelse",
    "trupprörelsernas": "trupprörelse",
    "trupprörelsers": "trupprörelse",
    "trupprörelses": "trupprörelse",
    "trupps": "trupp",
    "truppslagen": "truppslag",
    "truppslagens": "truppslag",
    "truppslaget": "truppslag",
    "truppslagets": "truppslag",
    "truppslags": "truppslag",
    "truppstyrkan": "truppstyrka",
    "truppstyrkans": "truppstyrka",
    "truppstyrkas": "truppstyrka",
    "truppstyrke": "truppstyrka",
    "truppstyrkor": "truppstyrka",
    "truppstyrkorna": "truppstyrka",
    "truppstyrkornas": "truppstyrka",
    "truppstyrkors": "truppstyrka",
    "trupptjänsten": "trupptjänst",
    "trupptjänstens": "trupptjänst",
    "trupptjänsts": "trupptjänst",
    "trupptransporten": "trupptransport",
    "trupptransportens": "trupptransport",
    "trupptransporter": "trupptransport",
    "trupptransporterna": "trupptransport",
    "trupptransporternas": "trupptransport",
    "trupptransporters": "trupptransport",
    "trupptransportfartygen": "trupptransportfartyg",
    "trupptransportfartygens": "trupptransportfartyg",
    "trupptransportfartyget": "trupptransportfartyg",
    "trupptransportfartygets": "trupptransportfartyg",
    "trupptransportfartygs": "trupptransportfartyg",
    "trupptransports": "trupptransport",
    "trupptransporttågen": "trupptransporttåg",
    "trupptransporttågens": "trupptransporttåg",
    "trupptransporttåget": "trupptransporttåg",
    "trupptransporttågets": "trupptransporttåg",
    "trupptransporttågs": "trupptransporttåg",
    "trusten": "trust",
    "trustens": "trust",
    "truster": "trust",
    "trusterna": "trust",
    "trusternas": "trust",
    "trusters": "trust",
    "trusts": "trust",
    "trut": "truta",
    "trutad": "truta",
    "trutade": "truta",
    "trutades": "truta",
    "trutads": "truta",
    "trutande": "truta",
    "trutanden": "trutande",
    "trutandena": "trutande",
    "trutandenas": "trutande",
    "trutandens": "trutande",
    "trutandes": "trutande",
    "trutandet": "trutande",
    "trutandets": "trutande",
    "trutar": "truta",
    "trutarna": "trut",
    "trutarnas": "trut",
    "trutars": "trut",
    "trutas": "truta",
    "trutat": "truta",
    "trutats": "truta",
    "trute": "tryta",
    "truten": "trut",
    "trutens": "trut",
    "trutes": "tryta",
    "trutit": "tryta",
    "trutits": "tryta",
    "truts": "trut",
    "tryck": "trycka",
    "tryckaccenten": "tryckaccent",
    "tryckaccentens": "tryckaccent",
    "tryckaccenter": "tryckaccent",
    "tryckaccenterna": "tryckaccent",
    "tryckaccenternas": "tryckaccent",
    "tryckaccenters": "tryckaccent",
    "tryckaccents": "tryckaccent",
    "tryckalsterna": "tryckalster",
    "tryckalsternas": "tryckalster",
    "tryckalsters": "tryckalster",
    "tryckalstren": "tryckalster",
    "tryckalstrens": "tryckalster",
    "tryckalstret": "tryckalster",
    "tryckalstrets": "tryckalster",
    "tryckande": "trycka",
    "tryckanden": "tryckande",
    "tryckandena": "tryckande",
    "tryckandenas": "tryckande",
    "tryckandens": "tryckande",
    "tryckandes": "tryckande",
    "tryckandet": "tryckande",
    "tryckandets": "tryckande",
    "tryckar": "tryckare",
    "tryckaren": "tryckare",
    "tryckarens": "tryckare",
    "tryckares": "tryckare",
    "tryckarna": "tryckare",
    "tryckarnas": "tryckare",
    "tryckas": "trycka",
    "tryckbara": "tryckbar",
    "tryckbarare": "tryckbar",
    "tryckbarares": "tryckbar",
    "tryckbaras": "tryckbar",
    "tryckbarast": "tryckbar",
    "tryckbaraste": "tryckbar",
    "tryckbarastes": "tryckbar",
    "tryckbarasts": "tryckbar",
    "tryckbare": "tryckbar",
    "tryckbares": "tryckbar",
    "tryckbarheten": "tryckbarhet",
    "tryckbarhetens": "tryckbarhet",
    "tryckbarhets": "tryckbarhet",
    "tryckbars": "tryckbar",
    "tryckbart": "tryckbar",
    "tryckbarts": "tryckbar",
    "tryckbehållar": "tryckbehållare",
    "tryckbehållaren": "tryckbehållare",
    "tryckbehållarens": "tryckbehållare",
    "tryckbehållares": "tryckbehållare",
    "tryckbehållarna": "tryckbehållare",
    "tryckbehållarnas": "tryckbehållare",
    "tryckbokstaven": "tryckbokstav",
    "tryckbokstavens": "tryckbokstav",
    "tryckbokstavs": "tryckbokstav",
    "tryckbokstäver": "tryckbokstav",
    "tryckbokstäverna": "tryckbokstav",
    "tryckbokstävernas": "tryckbokstav",
    "tryckbokstävers": "tryckbokstav",
    "tryckbrännar": "tryckbrännare",
    "tryckbrännaren": "tryckbrännare",
    "tryckbrännarens": "tryckbrännare",
    "tryckbrännares": "tryckbrännare",
    "tryckbrännarna": "tryckbrännare",
    "tryckbrännarnas": "tryckbrännare",
    "tryckdräkten": "tryckdräkt",
    "tryckdräktens": "tryckdräkt",
    "tryckdräkter": "tryckdräkt",
    "tryckdräkterna": "tryckdräkt",
    "tryckdräkternas": "tryckdräkt",
    "tryckdräkters": "tryckdräkt",
    "tryckdräkts": "tryckdräkt",
    "trycken": "trycke",
    "tryckena": "trycke",
    "tryckenas": "trycke",
    "tryckens": "trycke",
    "trycker": "trycka",
    "tryckerier": "tryckeri",
    "tryckerierna": "tryckeri",
    "tryckeriernas": "tryckeri",
    "tryckeriers": "tryckeri",
    "tryckeriet": "tryckeri",
    "tryckeriets": "tryckeri",
    "tryckeris": "tryckeri",
    "tryckerit": "tryckeri",
    "tryckerits": "tryckeri",
    "tryckes": "trycke",
    "trycket": "trycke",
    "tryckets": "trycke",
    "tryckfelen": "tryckfel",
    "tryckfelens": "tryckfel",
    "tryckfelet": "tryckfel",
    "tryckfelets": "tryckfel",
    "tryckfels": "tryckfel",
    "tryckfelsniss": "tryckfelsnisse",
    "tryckfelsnissar": "tryckfelsnisse",
    "tryckfelsnissarna": "tryckfelsnisse",
    "tryckfelsnissarnas": "tryckfelsnisse",
    "tryckfelsnissars": "tryckfelsnisse",
    "tryckfelsnissen": "tryckfelsnisse",
    "tryckfelsnissens": "tryckfelsnisse",
    "tryckfelsnisses": "tryckfelsnisse",
    "tryckformar": "tryckform",
    "tryckformarna": "tryckform",
    "tryckformarnas": "tryckform",
    "tryckformars": "tryckform",
    "tryckformen": "tryckform",
    "tryckformens": "tryckform",
    "tryckforms": "tryckform",
    "tryckfriheten": "tryckfrihet",
    "tryckfrihetens": "tryckfrihet",
    "tryckfriheter": "tryckfrihet",
    "tryckfriheterna": "tryckfrihet",
    "tryckfriheternas": "tryckfrihet",
    "tryckfriheters": "tryckfrihet",
    "tryckfrihets": "tryckfrihet",
    "tryckfärgen": "tryckfärg",
    "tryckfärgens": "tryckfärg",
    "tryckfärger": "tryckfärg",
    "tryckfärgerna": "tryckfärg",
    "tryckfärgernas": "tryckfärg",
    "tryckfärgers": "tryckfärg",
    "tryckfärgs": "tryckfärg",
    "tryckförbanden": "tryckförband",
    "tryckförbandens": "tryckförband",
    "tryckförbandet": "tryckförband",
    "tryckförbandets": "tryckförband",
    "tryckförbands": "tryckförband",
    "tryckimpregnerad": "tryckimpregnera",
    "tryckimpregnerade": "tryckimpregnera",
    "tryckimpregnerades": "tryckimpregnera",
    "tryckimpregnerads": "tryckimpregnera",
    "tryckimpregnerande": "tryckimpregnera",
    "tryckimpregneranden": "tryckimpregnerande",
    "tryckimpregnerandena": "tryckimpregnerande",
    "tryckimpregnerandenas": "tryckimpregnerande",
    "tryckimpregnerandens": "tryckimpregnerande",
    "tryckimpregnerandes": "tryckimpregnerande",
    "tryckimpregnerandet": "tryckimpregnerande",
    "tryckimpregnerandets": "tryckimpregnerande",
    "tryckimpregnerar": "tryckimpregnera",
    "tryckimpregneras": "tryckimpregnera",
    "tryckimpregnerat": "tryckimpregnera",
    "tryckimpregnerats": "tryckimpregnera",
    "tryckimpregnerbara": "tryckimpregnerbar",
    "tryckimpregnerbarare": "tryckimpregnerbar",
    "tryckimpregnerbarares": "tryckimpregnerbar",
    "tryckimpregnerbaras": "tryckimpregnerbar",
    "tryckimpregnerbarast": "tryckimpregnerbar",
    "tryckimpregnerbaraste": "tryckimpregnerbar",
    "tryckimpregnerbarastes": "tryckimpregnerbar",
    "tryckimpregnerbarasts": "tryckimpregnerbar",
    "tryckimpregnerbare": "tryckimpregnerbar",
    "tryckimpregnerbares": "tryckimpregnerbar",
    "tryckimpregnerbarheten": "tryckimpregnerbarhet",
    "tryckimpregnerbarhetens": "tryckimpregnerbarhet",
    "tryckimpregnerbarhets": "tryckimpregnerbarhet",
    "tryckimpregnerbars": "tryckimpregnerbar",
    "tryckimpregnerbart": "tryckimpregnerbar",
    "tryckimpregnerbarts": "tryckimpregnerbar",
    "tryckimpregneringar": "tryckimpregnering",
    "tryckimpregneringarna": "tryckimpregnering",
    "tryckimpregneringarnas": "tryckimpregnering",
    "tryckimpregneringars": "tryckimpregnering",
    "tryckimpregneringen": "tryckimpregnering",
    "tryckimpregneringens": "tryckimpregnering",
    "tryckimpregnerings": "tryckimpregnering",
    "tryckkabinen": "tryckkabin",
    "tryckkabinens": "tryckkabin",
    "tryckkabiner": "tryckkabin",
    "tryckkabinerna": "tryckkabin",
    "tryckkabinernas": "tryckkabin",
    "tryckkabiners": "tryckkabin",
    "tryckkabins": "tryckkabin",
    "tryckkammar": "tryckkammare",
    "tryckkammaren": "tryckkammare",
    "tryckkammarens": "tryckkammare",
    "tryckkammares": "tryckkammare",
    "tryckkamrar": "tryckkammare",
    "tryckkamrarna": "tryckkammare",
    "tryckkamrarnas": "tryckkammare",
    "tryckkamrars": "tryckkammare",
    "tryckknappar": "tryckknapp",
    "tryckknapparna": "tryckknapp",
    "tryckknapparnas": "tryckknapp",
    "tryckknappars": "tryckknapp",
    "tryckknappen": "tryckknapp",
    "tryckknappens": "tryckknapp",
    "tryckknapps": "tryckknapp",
    "tryckkokar": "tryckkokare",
    "tryckkokaren": "tryckkokare",
    "tryckkokarens": "tryckkokare",
    "tryckkokares": "tryckkokare",
    "tryckkokarna": "tryckkokare",
    "tryckkokarnas": "tryckkokare",
    "tryckkontakten": "tryckkontakt",
    "tryckkontaktens": "tryckkontakt",
    "tryckkontakter": "tryckkontakt",
    "tryckkontakterna": "tryckkontakt",
    "tryckkontakternas": "tryckkontakt",
    "tryckkontakters": "tryckkontakt",
    "tryckkontakts": "tryckkontakt",
    "tryckkänsliga": "tryckkänslig",
    "tryckkänsligare": "tryckkänslig",
    "tryckkänsligares": "tryckkänslig",
    "tryckkänsligas": "tryckkänslig",
    "tryckkänsligast": "tryckkänslig",
    "tryckkänsligaste": "tryckkänslig",
    "tryckkänsligastes": "tryckkänslig",
    "tryckkänsligasts": "tryckkänslig",
    "tryckkänslige": "tryckkänslig",
    "tryckkänsliges": "tryckkänslig",
    "tryckkänsligheten": "tryckkänslighet",
    "tryckkänslighetens": "tryckkänslighet",
    "tryckkänslighets": "tryckkänslighet",
    "tryckkänsligs": "tryckkänslig",
    "tryckkänsligt": "tryckkänslig",
    "tryckkänsligts": "tryckkänslig",
    "tryckkärlen": "tryckkärl",
    "tryckkärlens": "tryckkärl",
    "tryckkärlet": "tryckkärl",
    "tryckkärlets": "tryckkärl",
    "tryckkärls": "tryckkärl",
    "tryckluften": "tryckluft",
    "tryckluftens": "tryckluft",
    "trycklufts": "tryckluft",
    "tryckluftsapparaten": "tryckluftsapparat",
    "tryckluftsapparatens": "tryckluftsapparat",
    "tryckluftsapparater": "tryckluftsapparat",
    "tryckluftsapparaterna": "tryckluftsapparat",
    "tryckluftsapparaternas": "tryckluftsapparat",
    "tryckluftsapparaters": "tryckluftsapparat",
    "tryckluftsapparats": "tryckluftsapparat",
    "tryckluftsavläsningar": "tryckluftsavläsning",
    "tryckluftsavläsningarna": "tryckluftsavläsning",
    "tryckluftsavläsningarnas": "tryckluftsavläsning",
    "tryckluftsavläsningars": "tryckluftsavläsning",
    "tryckluftsavläsningen": "tryckluftsavläsning",
    "tryckluftsavläsningens": "tryckluftsavläsning",
    "tryckluftsavläsnings": "tryckluftsavläsning",
    "tryckluftsdrivens": "tryckluftsdriven",
    "tryckluftsdrivet": "tryckluftsdriven",
    "tryckluftsdrivets": "tryckluftsdriven",
    "tryckluftsdrivna": "tryckluftsdriven",
    "tryckluftsdrivnas": "tryckluftsdriven",
    "tryckluftsdrivne": "tryckluftsdriven",
    "tryckluftsdrivnes": "tryckluftsdriven",
    "tryckluftsslangar": "tryckluftsslang",
    "tryckluftsslangarna": "tryckluftsslang",
    "tryckluftsslangarnas": "tryckluftsslang",
    "tryckluftsslangars": "tryckluftsslang",
    "tryckluftsslangen": "tryckluftsslang",
    "tryckluftsslangens": "tryckluftsslang",
    "tryckluftsslangs": "tryckluftsslang",
    "tryckmetoden": "tryckmetod",
    "tryckmetodens": "tryckmetod",
    "tryckmetoder": "tryckmetod",
    "tryckmetoderna": "tryckmetod",
    "tryckmetodernas": "tryckmetod",
    "tryckmetoders": "tryckmetod",
    "tryckmetods": "tryckmetod",
    "tryckningar": "tryckning",
    "tryckningarna": "tryckning",
    "tryckningarnas": "tryckning",
    "tryckningars": "tryckning",
    "tryckningen": "tryckning",
    "tryckningens": "tryckning",
    "trycknings": "tryckning",
    "tryckorden": "tryckord",
    "tryckordens": "tryckord",
    "tryckordet": "tryckord",
    "tryckordets": "tryckord",
    "tryckords": "tryckord",
    "tryckorten": "tryckort",
    "tryckortens": "tryckort",
    "tryckorter": "tryckort",
    "tryckorterna": "tryckort",
    "tryckorternas": "tryckort",
    "tryckorters": "tryckort",
    "tryckorts": "tryckort",
    "tryckpressar": "tryckpress",
    "tryckpressarna": "tryckpress",
    "tryckpressarnas": "tryckpress",
    "tryckpressars": "tryckpress",
    "tryckpressen": "tryckpress",
    "tryckpressens": "tryckpress",
    "tryckpunkten": "tryckpunkt",
    "tryckpunktens": "tryckpunkt",
    "tryckpunkter": "tryckpunkt",
    "tryckpunkterna": "tryckpunkt",
    "tryckpunkternas": "tryckpunkt",
    "tryckpunkters": "tryckpunkt",
    "tryckpunkts": "tryckpunkt",
    "tryckreduceringar": "tryckreducering",
    "tryckreduceringarna": "tryckreducering",
    "tryckreduceringarnas": "tryckreducering",
    "tryckreduceringars": "tryckreducering",
    "tryckreduceringen": "tryckreducering",
    "tryckreduceringens": "tryckreducering",
    "tryckreducerings": "tryckreducering",
    "trycks": "trycke",
    "trycksaken": "trycksak",
    "trycksakens": "trycksak",
    "trycksaker": "trycksak",
    "trycksakerna": "trycksak",
    "trycksakernas": "trycksak",
    "trycksakers": "trycksak",
    "trycksaks": "trycksak",
    "trycksatsen": "trycksats",
    "trycksatsens": "trycksats",
    "trycksatser": "trycksats",
    "trycksatserna": "trycksats",
    "trycksatsernas": "trycksats",
    "trycksatsers": "trycksats",
    "tryckskydden": "tryckskydd",
    "tryckskyddens": "tryckskydd",
    "tryckskyddet": "tryckskydd",
    "tryckskyddets": "tryckskydd",
    "tryckskydds": "tryckskydd",
    "trycksmörjningar": "trycksmörjning",
    "trycksmörjningarna": "trycksmörjning",
    "trycksmörjningarnas": "trycksmörjning",
    "trycksmörjningars": "trycksmörjning",
    "trycksmörjningen": "trycksmörjning",
    "trycksmörjningens": "trycksmörjning",
    "trycksmörjnings": "trycksmörjning",
    "trycksprut": "tryckspruta",
    "trycksprutan": "tryckspruta",
    "trycksprutans": "tryckspruta",
    "trycksprutas": "tryckspruta",
    "trycksprute": "tryckspruta",
    "trycksprutor": "tryckspruta",
    "trycksprutorna": "tryckspruta",
    "trycksprutornas": "tryckspruta",
    "trycksprutors": "tryckspruta",
    "tryckspruts": "tryckspruta",
    "tryckstarka": "tryckstark",
    "tryckstarkare": "tryckstark",
    "tryckstarkares": "tryckstark",
    "tryckstarkas": "tryckstark",
    "tryckstarkast": "tryckstark",
    "tryckstarkaste": "tryckstark",
    "tryckstarkastes": "tryckstark",
    "tryckstarkasts": "tryckstark",
    "tryckstarke": "tryckstark",
    "tryckstarkes": "tryckstark",
    "tryckstarkheten": "tryckstarkhet",
    "tryckstarkhetens": "tryckstarkhet",
    "tryckstarkhets": "tryckstarkhet",
    "tryckstarks": "tryckstark",
    "tryckstarkt": "tryckstark",
    "tryckstarkts": "tryckstark",
    "tryckstilar": "tryckstil",
    "tryckstilarna": "tryckstil",
    "tryckstilarnas": "tryckstil",
    "tryckstilars": "tryckstil",
    "tryckstilen": "tryckstil",
    "tryckstilens": "tryckstil",
    "tryckstils": "tryckstil",
    "tryckstyrkan": "tryckstyrka",
    "tryckstyrkans": "tryckstyrka",
    "tryckstyrkas": "tryckstyrka",
    "tryckstyrke": "tryckstyrka",
    "tryckstyrkor": "tryckstyrka",
    "tryckstyrkorna": "tryckstyrka",
    "tryckstyrkornas": "tryckstyrka",
    "tryckstyrkors": "tryckstyrka",
    "trycksvaga": "trycksvag",
    "trycksvagare": "trycksvag",
    "trycksvagares": "trycksvag",
    "trycksvagas": "trycksvag",
    "trycksvagast": "trycksvag",
    "trycksvagaste": "trycksvag",
    "trycksvagastes": "trycksvag",
    "trycksvagasts": "trycksvag",
    "trycksvage": "trycksvag",
    "trycksvages": "trycksvag",
    "trycksvagheten": "trycksvaghet",
    "trycksvaghetens": "trycksvaghet",
    "trycksvaghets": "trycksvaghet",
    "trycksvags": "trycksvag",
    "trycksvagt": "trycksvag",
    "trycksvagts": "trycksvag",
    "trycksvärtan": "trycksvärta",
    "trycksvärtans": "trycksvärta",
    "trycksvärtas": "trycksvärta",
    "trycksvärte": "trycksvärta",
    "trycksvärts": "trycksvärta",
    "trycksäkerheten": "trycksäkerhet",
    "trycksäkerhetens": "trycksäkerhet",
    "trycksäkerhets": "trycksäkerhet",
    "trycksäkers": "trycksäker",
    "trycksäkert": "trycksäker",
    "trycksäkerts": "trycksäker",
    "trycksäkra": "trycksäker",
    "trycksäkrare": "trycksäker",
    "trycksäkrares": "trycksäker",
    "trycksäkras": "trycksäker",
    "trycksäkrast": "trycksäker",
    "trycksäkraste": "trycksäker",
    "trycksäkrastes": "trycksäker",
    "trycksäkrasts": "trycksäker",
    "trycksäkre": "trycksäker",
    "trycksäkres": "trycksäker",
    "tryckt": "trycka",
    "tryckta": "tryckt",
    "trycktare": "tryckt",
    "trycktares": "tryckt",
    "trycktas": "tryckt",
    "trycktast": "tryckt",
    "trycktaste": "tryckt",
    "trycktastes": "tryckt",
    "trycktasts": "tryckt",
    "tryckte": "tryckt",
    "trycktes": "tryckt",
    "trycktheten": "tryckthet",
    "tryckthetens": "tryckthet",
    "tryckthets": "tryckthet",
    "tryckts": "tryckt",
    "trycktypen": "trycktyp",
    "trycktypens": "trycktyp",
    "trycktyper": "trycktyp",
    "trycktyperna": "trycktyp",
    "trycktypernas": "trycktyp",
    "trycktypers": "trycktyp",
    "trycktyps": "trycktyp",
    "tryckvattenreaktorer": "tryckvattenreaktor",
    "tryckvattenreaktorerna": "tryckvattenreaktor",
    "tryckvattenreaktorernas": "tryckvattenreaktor",
    "tryckvattenreaktorers": "tryckvattenreaktor",
    "tryckvattenreaktorn": "tryckvattenreaktor",
    "tryckvattenreaktorns": "tryckvattenreaktor",
    "tryckvattenreaktors": "tryckvattenreaktor",
    "tryckvattensreaktorer": "tryckvattensreaktor",
    "tryckvattensreaktorerna": "tryckvattensreaktor",
    "tryckvattensreaktorernas": "tryckvattensreaktor",
    "tryckvattensreaktorers": "tryckvattensreaktor",
    "tryckvattensreaktorn": "tryckvattensreaktor",
    "tryckvattensreaktorns": "tryckvattensreaktor",
    "tryckvattensreaktors": "tryckvattensreaktor",
    "tryckvågen": "tryckvåg",
    "tryckvågens": "tryckvåg",
    "tryckvågor": "tryckvåg",
    "tryckvågorna": "tryckvåg",
    "tryckvågornas": "tryckvåg",
    "tryckvågors": "tryckvåg",
    "tryckvågs": "tryckvåg",
    "tryckytan": "tryckyta",
    "tryckytans": "tryckyta",
    "tryckytas": "tryckyta",
    "tryckyte": "tryckyta",
    "tryckytor": "tryckyta",
    "tryckytorna": "tryckyta",
    "tryckytornas": "tryckyta",
    "tryckytors": "tryckyta",
    "tryckåren": "tryckår",
    "tryckårens": "tryckår",
    "tryckåret": "tryckår",
    "tryckårets": "tryckår",
    "tryckårs": "tryckår",
    "tryckökningar": "tryckökning",
    "tryckökningarna": "tryckökning",
    "tryckökningarnas": "tryckökning",
    "tryckökningars": "tryckökning",
    "tryckökningen": "tryckökning",
    "tryckökningens": "tryckökning",
    "trycköknings": "tryckökning",
    "tryffelhundar": "tryffelhund",
    "tryffelhundarna": "tryffelhund",
    "tryffelhundarnas": "tryffelhund",
    "tryffelhundars": "tryffelhund",
    "tryffelhunden": "tryffelhund",
    "tryffelhundens": "tryffelhund",
    "tryffelhunds": "tryffelhund",
    "tryffeln": "tryffel",
    "tryffelns": "tryffel",
    "tryffels": "tryffel",
    "tryffelsvampar": "tryffelsvamp",
    "tryffelsvamparna": "tryffelsvamp",
    "tryffelsvamparnas": "tryffelsvamp",
    "tryffelsvampars": "tryffelsvamp",
    "tryffelsvampen": "tryffelsvamp",
    "tryffelsvampens": "tryffelsvamp",
    "tryffelsvamps": "tryffelsvamp",
    "tryfferad": "tryffera",
    "tryfferade": "tryffera",
    "tryfferades": "tryffera",
    "tryfferads": "tryffera",
    "tryfferande": "tryffera",
    "tryfferanden": "tryfferande",
    "tryfferandena": "tryfferande",
    "tryfferandenas": "tryfferande",
    "tryfferandens": "tryfferande",
    "tryfferandes": "tryfferande",
    "tryfferandet": "tryfferande",
    "tryfferandets": "tryfferande",
    "tryfferar": "tryffera",
    "tryfferas": "tryffera",
    "tryfferat": "tryffera",
    "tryfferats": "tryffera",
    "tryfferbara": "tryfferbar",
    "tryfferbarare": "tryfferbar",
    "tryfferbarares": "tryfferbar",
    "tryfferbaras": "tryfferbar",
    "tryfferbarast": "tryfferbar",
    "tryfferbaraste": "tryfferbar",
    "tryfferbarastes": "tryfferbar",
    "tryfferbarasts": "tryfferbar",
    "tryfferbare": "tryfferbar",
    "tryfferbares": "tryfferbar",
    "tryfferbarheten": "tryfferbarhet",
    "tryfferbarhetens": "tryfferbarhet",
    "tryfferbarhets": "tryfferbarhet",
    "tryfferbars": "tryfferbar",
    "tryfferbart": "tryfferbar",
    "tryfferbarts": "tryfferbar",
    "tryfferingar": "tryffering",
    "tryfferingarna": "tryffering",
    "tryfferingarnas": "tryffering",
    "tryfferingars": "tryffering",
    "tryfferingen": "tryffering",
    "tryfferingens": "tryffering",
    "tryfferings": "tryffering",
    "tryfflar": "tryffel",
    "tryfflarna": "tryffel",
    "tryfflarnas": "tryffel",
    "tryfflars": "tryffel",
    "tryg": "tryga",
    "trygan": "tryga",
    "trygans": "tryga",
    "trygas": "tryga",
    "tryge": "tryga",
    "trygg": "trygga",
    "trygga": "trygg",
    "tryggad": "trygga",
    "tryggade": "trygga",
    "tryggades": "trygga",
    "tryggads": "trygga",
    "tryggande": "trygga",
    "trygganden": "tryggande",
    "tryggandena": "tryggande",
    "tryggandenas": "tryggande",
    "tryggandens": "tryggande",
    "tryggandes": "tryggande",
    "tryggandet": "tryggande",
    "tryggandets": "tryggande",
    "tryggar": "trygga",
    "tryggare": "trygg",
    "tryggares": "trygg",
    "tryggas": "trygga",
    "tryggast": "trygg",
    "tryggaste": "trygg",
    "tryggastes": "trygg",
    "tryggasts": "trygg",
    "tryggat": "trygga",
    "tryggats": "trygga",
    "trygge": "trygg",
    "trygges": "trygg",
    "tryggheten": "trygghet",
    "trygghetens": "trygghet",
    "tryggheter": "trygghet",
    "tryggheterna": "trygghet",
    "tryggheternas": "trygghet",
    "tryggheters": "trygghet",
    "trygghets": "trygghet",
    "trygghetsboenden": "trygghetsboende",
    "trygghetsboendena": "trygghetsboende",
    "trygghetsboendenas": "trygghetsboende",
    "trygghetsboendens": "trygghetsboende",
    "trygghetsboendes": "trygghetsboende",
    "trygghetsboendet": "trygghetsboende",
    "trygghetsboendets": "trygghetsboende",
    "trygghetsförsäkringar": "trygghetsförsäkring",
    "trygghetsförsäkringarna": "trygghetsförsäkring",
    "trygghetsförsäkringarnas": "trygghetsförsäkring",
    "trygghetsförsäkringars": "trygghetsförsäkring",
    "trygghetsförsäkringen": "trygghetsförsäkring",
    "trygghetsförsäkringens": "trygghetsförsäkring",
    "trygghetsförsäkrings": "trygghetsförsäkring",
    "trygghetsnarkomanen": "trygghetsnarkoman",
    "trygghetsnarkomanens": "trygghetsnarkoman",
    "trygghetsnarkomaner": "trygghetsnarkoman",
    "trygghetsnarkomanerna": "trygghetsnarkoman",
    "trygghetsnarkomanernas": "trygghetsnarkoman",
    "trygghetsnarkomaners": "trygghetsnarkoman",
    "trygghetsnarkomanien": "trygghetsnarkomani",
    "trygghetsnarkomaniens": "trygghetsnarkomani",
    "trygghetsnarkomanin": "trygghetsnarkomani",
    "trygghetsnarkomanins": "trygghetsnarkomani",
    "trygghetsnarkomanis": "trygghetsnarkomani",
    "trygghetsnarkomans": "trygghetsnarkoman",
    "tryggs": "trygg",
    "tryggt": "trygg",
    "tryggts": "trygg",
    "trygor": "tryga",
    "trygorna": "tryga",
    "trygornas": "tryga",
    "trygors": "tryga",
    "trygs": "tryga",
    "trymåer": "trymå",
    "trymåerna": "trymå",
    "trymåernas": "trymå",
    "trymåers": "trymå",
    "trymån": "trymå",
    "trymåns": "trymå",
    "trymås": "trymå",
    "tryn": "tryna",
    "trynad": "tryna",
    "trynade": "tryna",
    "trynades": "tryna",
    "trynads": "tryna",
    "trynande": "tryna",
    "trynanden": "trynande",
    "trynandena": "trynande",
    "trynandenas": "trynande",
    "trynandens": "trynande",
    "trynandes": "trynande",
    "trynandet": "trynande",
    "trynandets": "trynande",
    "trynar": "tryna",
    "trynas": "tryna",
    "trynat": "tryna",
    "trynats": "tryna",
    "trynen": "tryne",
    "trynena": "tryne",
    "trynenas": "tryne",
    "trynens": "tryne",
    "trynes": "tryne",
    "trynet": "tryne",
    "trynets": "tryne",
    "tryns": "tryne",
    "trypsinen": "trypsin",
    "trypsinens": "trypsin",
    "trypsiner": "trypsin",
    "trypsinerna": "trypsin",
    "trypsinernas": "trypsin",
    "trypsiners": "trypsin",
    "trypsinet": "trypsin",
    "trypsinets": "trypsin",
    "trypsins": "trypsin",
    "tryt": "tryta",
    "trytande": "tryta",
    "trytanden": "trytande",
    "trytandena": "trytande",
    "trytandenas": "trytande",
    "trytandens": "trytande",
    "trytandes": "trytande",
    "trytandet": "trytande",
    "trytandets": "trytande",
    "trytas": "tryta",
    "tryte": "tryta",
    "tryter": "tryta",
    "trytes": "tryta",
    "tryts": "tryta",
    "träad": "träa",
    "träade": "träa",
    "träades": "träa",
    "träads": "träa",
    "träaktiga": "träaktig",
    "träaktigare": "träaktig",
    "träaktigares": "träaktig",
    "träaktigas": "träaktig",
    "träaktigast": "träaktig",
    "träaktigaste": "träaktig",
    "träaktigastes": "träaktig",
    "träaktigasts": "träaktig",
    "träaktige": "träaktig",
    "träaktiges": "träaktig",
    "träaktigheten": "träaktighet",
    "träaktighetens": "träaktighet",
    "träaktighets": "träaktighet",
    "träaktigs": "träaktig",
    "träaktigt": "träaktig",
    "träaktigts": "träaktig",
    "träande": "träa",
    "träanden": "träande",
    "träandena": "träande",
    "träandenas": "träande",
    "träandens": "träande",
    "träandes": "träande",
    "träandet": "träande",
    "träandets": "träande",
    "träar": "träa",
    "träas": "träa",
    "träat": "träa",
    "träats": "träa",
    "träavfallen": "träavfall",
    "träavfallens": "träavfall",
    "träavfallet": "träavfall",
    "träavfallets": "träavfall",
    "träavfalls": "träavfall",
    "träbeläggningar": "träbeläggning",
    "träbeläggningarna": "träbeläggning",
    "träbeläggningarnas": "träbeläggning",
    "träbeläggningars": "träbeläggning",
    "träbeläggningen": "träbeläggning",
    "träbeläggningens": "träbeläggning",
    "träbeläggnings": "träbeläggning",
    "träbenen": "träben",
    "träbenens": "träben",
    "träbenet": "träben",
    "träbenets": "träben",
    "träbens": "träben",
    "träbitar": "träbit",
    "träbitarna": "träbit",
    "träbitarnas": "träbit",
    "träbitars": "träbit",
    "träbiten": "träbit",
    "träbitens": "träbit",
    "träbits": "träbit",
    "träblåsar": "träblåsare",
    "träblåsaren": "träblåsare",
    "träblåsarens": "träblåsare",
    "träblåsares": "träblåsare",
    "träblåsarna": "träblåsare",
    "träblåsarnas": "träblåsare",
    "träblåsinstrumenten": "träblåsinstrument",
    "träblåsinstrumentens": "träblåsinstrument",
    "träblåsinstrumentet": "träblåsinstrument",
    "träblåsinstrumentets": "träblåsinstrument",
    "träblåsinstruments": "träblåsinstrument",
    "träbockar": "träbock",
    "träbockarna": "träbock",
    "träbockarnas": "träbock",
    "träbockars": "träbock",
    "träbocken": "träbock",
    "träbockens": "träbock",
    "träbocks": "träbock",
    "träcellen": "träcell",
    "träcellens": "träcell",
    "träceller": "träcell",
    "träcellerna": "träcell",
    "träcellernas": "träcell",
    "träcellers": "träcell",
    "träcells": "träcell",
    "träcellulosan": "träcellulosa",
    "träcellulosans": "träcellulosa",
    "träcellulosas": "träcellulosa",
    "träck": "träcka",
    "träckande": "träcka",
    "träckanden": "träckande",
    "träckandena": "träckande",
    "träckandenas": "träckande",
    "träckandens": "träckande",
    "träckandes": "träckande",
    "träckandet": "träckande",
    "träckandets": "träckande",
    "träckas": "träcka",
    "träcken": "träck",
    "träckens": "träck",
    "träcker": "träcka",
    "träckes": "träcka",
    "träcks": "träcka",
    "träckt": "träcka",
    "träckta": "träcka",
    "träcktas": "träcka",
    "träckte": "träcka",
    "träcktes": "träcka",
    "träckts": "träcka",
    "träd": "träda",
    "träda": "trä",
    "trädade": "träda",
    "trädades": "träda",
    "trädan": "träda",
    "trädande": "träda",
    "trädanden": "trädande",
    "trädandena": "trädande",
    "trädandenas": "trädande",
    "trädandens": "trädande",
    "trädandes": "trädande",
    "trädandet": "trädande",
    "trädandets": "trädande",
    "trädans": "träda",
    "trädas": "träda",
    "trädat": "träda",
    "trädats": "träda",
    "trädbanken": "trädbank",
    "trädbankens": "trädbank",
    "trädbanker": "trädbank",
    "trädbankerna": "trädbank",
    "trädbankernas": "trädbank",
    "trädbankers": "trädbank",
    "trädbanks": "trädbank",
    "trädd": "träda",
    "trädda": "träda",
    "träddas": "träda",
    "trädde": "träda",
    "träddes": "träda",
    "träddiagrammen": "träddiagram",
    "träddiagrammens": "träddiagram",
    "träddiagrammet": "träddiagram",
    "träddiagrammets": "träddiagram",
    "träddiagrams": "träddiagram",
    "trädds": "träda",
    "träde": "träda",
    "träden": "träde",
    "trädena": "träde",
    "trädenas": "träde",
    "trädens": "träde",
    "träder": "träda",
    "trädes": "träde",
    "trädestillationen": "trädestillation",
    "trädestillationens": "trädestillation",
    "trädestillationer": "trädestillation",
    "trädestillationerna": "trädestillation",
    "trädestillationernas": "trädestillation",
    "trädestillationers": "trädestillation",
    "trädestillations": "trädestillation",
    "trädet": "träde",
    "trädets": "träde",
    "trädflor": "trädflora",
    "trädfloran": "trädflora",
    "trädflorans": "trädflora",
    "trädfloras": "trädflora",
    "trädflore": "trädflora",
    "trädfloror": "trädflora",
    "trädflororna": "trädflora",
    "trädflorornas": "trädflora",
    "trädflorors": "trädflora",
    "trädflors": "trädflora",
    "trädgrenar": "trädgren",
    "trädgrenarna": "trädgren",
    "trädgrenarnas": "trädgren",
    "trädgrenars": "trädgren",
    "trädgrenen": "trädgren",
    "trädgrenens": "trädgren",
    "trädgrens": "trädgren",
    "trädgränsen": "trädgräns",
    "trädgränsens": "trädgräns",
    "trädgränser": "trädgräns",
    "trädgränserna": "trädgräns",
    "trädgränsernas": "trädgräns",
    "trädgränsers": "trädgräns",
    "trädgårdar": "trädgård",
    "trädgårdarna": "trädgård",
    "trädgårdarnas": "trädgård",
    "trädgårdars": "trädgård",
    "trädgården": "trädgård",
    "trädgårdens": "trädgård",
    "trädgårds": "trädgård",
    "trädgårdsanläggningar": "trädgårdsanläggning",
    "trädgårdsanläggningarna": "trädgårdsanläggning",
    "trädgårdsanläggningarnas": "trädgårdsanläggning",
    "trädgårdsanläggningars": "trädgårdsanläggning",
    "trädgårdsanläggningen": "trädgårdsanläggning",
    "trädgårdsanläggningens": "trädgårdsanläggning",
    "trädgårdsanläggnings": "trädgårdsanläggning",
    "trädgårdsarkitekten": "trädgårdsarkitekt",
    "trädgårdsarkitektens": "trädgårdsarkitekt",
    "trädgårdsarkitekter": "trädgårdsarkitekt",
    "trädgårdsarkitekterna": "trädgårdsarkitekt",
    "trädgårdsarkitekternas": "trädgårdsarkitekt",
    "trädgårdsarkitekters": "trädgårdsarkitekt",
    "trädgårdsarkitekts": "trädgårdsarkitekt",
    "trädgårdsbelysningar": "trädgårdsbelysning",
    "trädgårdsbelysningarna": "trädgårdsbelysning",
    "trädgårdsbelysningarnas": "trädgårdsbelysning",
    "trädgårdsbelysningars": "trädgårdsbelysning",
    "trädgårdsbelysningen": "trädgårdsbelysning",
    "trädgårdsbelysningens": "trädgårdsbelysning",
    "trädgårdsbelysnings": "trädgårdsbelysning",
    "trädgårdsblom": "trädgårdsblomma",
    "trädgårdsblomman": "trädgårdsblomma",
    "trädgårdsblommans": "trädgårdsblomma",
    "trädgårdsblommas": "trädgårdsblomma",
    "trädgårdsblomme": "trädgårdsblomma",
    "trädgårdsblommor": "trädgårdsblomma",
    "trädgårdsblommorna": "trädgårdsblomma",
    "trädgårdsblommornas": "trädgårdsblomma",
    "trädgårdsblommors": "trädgårdsblomma",
    "trädgårdsbloms": "trädgårdsblomma",
    "trädgårdsbusk": "trädgårdsbuske",
    "trädgårdsbuskar": "trädgårdsbuske",
    "trädgårdsbuskarna": "trädgårdsbuske",
    "trädgårdsbuskarnas": "trädgårdsbuske",
    "trädgårdsbuskars": "trädgårdsbuske",
    "trädgårdsbusken": "trädgårdsbuske",
    "trädgårdsbuskens": "trädgårdsbuske",
    "trädgårdsbuskes": "trädgårdsbuske",
    "trädgårdsbön": "trädgårdsböna",
    "trädgårdsbönan": "trädgårdsböna",
    "trädgårdsbönans": "trädgårdsböna",
    "trädgårdsbönas": "trädgårdsböna",
    "trädgårdsböne": "trädgårdsböna",
    "trädgårdsbönor": "trädgårdsböna",
    "trädgårdsbönorna": "trädgårdsböna",
    "trädgårdsbönornas": "trädgårdsböna",
    "trädgårdsbönors": "trädgårdsböna",
    "trädgårdsböns": "trädgårdsböna",
    "trädgårdsdammar": "trädgårdsdamm",
    "trädgårdsdammarna": "trädgårdsdamm",
    "trädgårdsdammarnas": "trädgårdsdamm",
    "trädgårdsdammars": "trädgårdsdamm",
    "trädgårdsdammen": "trädgårdsdamm",
    "trädgårdsdammens": "trädgårdsdamm",
    "trädgårdsdamms": "trädgårdsdamm",
    "trädgårdsexperten": "trädgårdsexpert",
    "trädgårdsexpertens": "trädgårdsexpert",
    "trädgårdsexperter": "trädgårdsexpert",
    "trädgårdsexperterna": "trädgårdsexpert",
    "trädgårdsexperternas": "trädgårdsexpert",
    "trädgårdsexperters": "trädgårdsexpert",
    "trädgårdsexperts": "trädgårdsexpert",
    "trädgårdsgångar": "trädgårdsgång",
    "trädgårdsgångarna": "trädgårdsgång",
    "trädgårdsgångarnas": "trädgårdsgång",
    "trädgårdsgångars": "trädgårdsgång",
    "trädgårdsgången": "trädgårdsgång",
    "trädgårdsgångens": "trädgårdsgång",
    "trädgårdsgångs": "trädgårdsgång",
    "trädgårdskonsten": "trädgårdskonst",
    "trädgårdskonstens": "trädgårdskonst",
    "trädgårdskonsts": "trädgårdskonst",
    "trädgårdskratt": "trädgårdskratta",
    "trädgårdskrattan": "trädgårdskratta",
    "trädgårdskrattans": "trädgårdskratta",
    "trädgårdskrattas": "trädgårdskratta",
    "trädgårdskratte": "trädgårdskratta",
    "trädgårdskrattor": "trädgårdskratta",
    "trädgårdskrattorna": "trädgårdskratta",
    "trädgårdskrattornas": "trädgårdskratta",
    "trädgårdskrattors": "trädgårdskratta",
    "trädgårdskratts": "trädgårdskratta",
    "trädgårdsmästar": "trädgårdsmästare",
    "trädgårdsmästaren": "trädgårdsmästare",
    "trädgårdsmästarens": "trädgårdsmästare",
    "trädgårdsmästares": "trädgårdsmästare",
    "trädgårdsmästarfruar": "trädgårdsmästarfru",
    "trädgårdsmästarfruarna": "trädgårdsmästarfru",
    "trädgårdsmästarfruarnas": "trädgårdsmästarfru",
    "trädgårdsmästarfruars": "trädgårdsmästarfru",
    "trädgårdsmästarfrun": "trädgårdsmästarfru",
    "trädgårdsmästarfruns": "trädgårdsmästarfru",
    "trädgårdsmästarfrus": "trädgårdsmästarfru",
    "trädgårdsmästarna": "trädgårdsmästare",
    "trädgårdsmästarnas": "trädgårdsmästare",
    "trädgårdsmöbeln": "trädgårdsmöbel",
    "trädgårdsmöbelns": "trädgårdsmöbel",
    "trädgårdsmöbels": "trädgårdsmöbel",
    "trädgårdsmöbler": "trädgårdsmöbel",
    "trädgårdsmöblerna": "trädgårdsmöbel",
    "trädgårdsmöblernas": "trädgårdsmöbel",
    "trädgårdsmöblers": "trädgårdsmöbel",
    "trädgårdsnejlik": "trädgårdsnejlika",
    "trädgårdsnejlikan": "trädgårdsnejlika",
    "trädgårdsnejlikans": "trädgårdsnejlika",
    "trädgårdsnejlikas": "trädgårdsnejlika",
    "trädgårdsnejlike": "trädgårdsnejlika",
    "trädgårdsnejlikor": "trädgårdsnejlika",
    "trädgårdsnejlikorna": "trädgårdsnejlika",
    "trädgårdsnejlikornas": "trädgårdsnejlika",
    "trädgårdsnejlikors": "trädgårdsnejlika",
    "trädgårdsnejliks": "trädgårdsnejlika",
    "trädgårdsodlingar": "trädgårdsodling",
    "trädgårdsodlingarna": "trädgårdsodling",
    "trädgårdsodlingarnas": "trädgårdsodling",
    "trädgårdsodlingars": "trädgårdsodling",
    "trädgårdsodlingen": "trädgårdsodling",
    "trädgårdsodlingens": "trädgårdsodling",
    "trädgårdsodlings": "trädgårdsodling",
    "trädgårdsprydnaden": "trädgårdsprydnad",
    "trädgårdsprydnadens": "trädgårdsprydnad",
    "trädgårdsprydnader": "trädgårdsprydnad",
    "trädgårdsprydnaderna": "trädgårdsprydnad",
    "trädgårdsprydnadernas": "trädgårdsprydnad",
    "trädgårdsprydnaders": "trädgårdsprydnad",
    "trädgårdsprydnads": "trädgårdsprydnad",
    "trädgårdsredskapen": "trädgårdsredskap",
    "trädgårdsredskapens": "trädgårdsredskap",
    "trädgårdsredskapet": "trädgårdsredskap",
    "trädgårdsredskapets": "trädgårdsredskap",
    "trädgårdsredskaps": "trädgårdsredskap",
    "trädgårdssaxar": "trädgårdssax",
    "trädgårdssaxarna": "trädgårdssax",
    "trädgårdssaxarnas": "trädgårdssax",
    "trädgårdssaxars": "trädgårdssax",
    "trädgårdssaxen": "trädgårdssax",
    "trädgårdssaxens": "trädgårdssax",
    "trädgårdsskötseln": "trädgårdsskötsel",
    "trädgårdsskötselns": "trädgårdsskötsel",
    "trädgårdsskötsels": "trädgårdsskötsel",
    "trädgårdsslangar": "trädgårdsslang",
    "trädgårdsslangarna": "trädgårdsslang",
    "trädgårdsslangarnas": "trädgårdsslang",
    "trädgårdsslangars": "trädgårdsslang",
    "trädgårdsslangen": "trädgårdsslang",
    "trädgårdsslangens": "trädgårdsslang",
    "trädgårdsslangs": "trädgårdsslang",
    "trädgårdssnäck": "trädgårdssnäcka",
    "trädgårdssnäckan": "trädgårdssnäcka",
    "trädgårdssnäckans": "trädgårdssnäcka",
    "trädgårdssnäckas": "trädgårdssnäcka",
    "trädgårdssnäcke": "trädgårdssnäcka",
    "trädgårdssnäckor": "trädgårdssnäcka",
    "trädgårdssnäckorna": "trädgårdssnäcka",
    "trädgårdssnäckornas": "trädgårdssnäcka",
    "trädgårdssnäckors": "trädgårdssnäcka",
    "trädgårdssnäcks": "trädgårdssnäcka",
    "trädgårdsspad": "trädgårdsspade",
    "trädgårdsspadar": "trädgårdsspade",
    "trädgårdsspadarna": "trädgårdsspade",
    "trädgårdsspadarnas": "trädgårdsspade",
    "trädgårdsspadars": "trädgårdsspade",
    "trädgårdsspaden": "trädgårdsspade",
    "trädgårdsspadens": "trädgårdsspade",
    "trädgårdsspades": "trädgårdsspade",
    "trädgårdsspads": "trädgårdsspade",
    "trädgårdsstädar": "trädgårdsstädare",
    "trädgårdsstädaren": "trädgårdsstädare",
    "trädgårdsstädarens": "trädgårdsstädare",
    "trädgårdsstädares": "trädgårdsstädare",
    "trädgårdsstädarna": "trädgårdsstädare",
    "trädgårdsstädarnas": "trädgårdsstädare",
    "trädgårdssångar": "trädgårdssångare",
    "trädgårdssångaren": "trädgårdssångare",
    "trädgårdssångarens": "trädgårdssångare",
    "trädgårdssångares": "trädgårdssångare",
    "trädgårdssångarna": "trädgårdssångare",
    "trädgårdssångarnas": "trädgårdssångare",
    "trädgårdstraktorer": "trädgårdstraktor",
    "trädgårdstraktorerna": "trädgårdstraktor",
    "trädgårdstraktorernas": "trädgårdstraktor",
    "trädgårdstraktorers": "trädgårdstraktor",
    "trädgårdstraktorn": "trädgårdstraktor",
    "trädgårdstraktorns": "trädgårdstraktor",
    "trädgårdstraktors": "trädgårdstraktor",
    "trädgårdstäpp": "trädgårdstäppa",
    "trädgårdstäppan": "trädgårdstäppa",
    "trädgårdstäppans": "trädgårdstäppa",
    "trädgårdstäppas": "trädgårdstäppa",
    "trädgårdstäppe": "trädgårdstäppa",
    "trädgårdstäppor": "trädgårdstäppa",
    "trädgårdstäpporna": "trädgårdstäppa",
    "trädgårdstäppornas": "trädgårdstäppa",
    "trädgårdstäppors": "trädgårdstäppa",
    "trädgårdstäpps": "trädgårdstäppa",
    "trädgårdsärten": "trädgårdsärt",
    "trädgårdsärtens": "trädgårdsärt",
    "trädgårdsärter": "trädgårdsärt",
    "trädgårdsärterna": "trädgårdsärt",
    "trädgårdsärternas": "trädgårdsärt",
    "trädgårdsärters": "trädgårdsärt",
    "trädgårdsärts": "trädgårdsärt",
    "trädkoj": "trädkoja",
    "trädkojan": "trädkoja",
    "trädkojans": "trädkoja",
    "trädkojas": "trädkoja",
    "trädkoje": "trädkoja",
    "trädkojor": "trädkoja",
    "trädkojorna": "trädkoja",
    "trädkojornas": "trädkoja",
    "trädkojors": "trädkoja",
    "trädkojs": "trädkoja",
    "trädkramar": "trädkramare",
    "trädkramaren": "trädkramare",
    "trädkramarens": "trädkramare",
    "trädkramares": "trädkramare",
    "trädkramarna": "trädkramare",
    "trädkramarnas": "trädkramare",
    "trädkron": "trädkrona",
    "trädkronan": "trädkrona",
    "trädkronans": "trädkrona",
    "trädkronas": "trädkrona",
    "trädkrone": "trädkrona",
    "trädkronor": "trädkrona",
    "trädkronorna": "trädkrona",
    "trädkronornas": "trädkrona",
    "trädkronors": "trädkrona",
    "trädkrons": "trädkrona",
    "trädkrypar": "trädkrypare",
    "trädkryparen": "trädkrypare",
    "trädkryparens": "trädkrypare",
    "trädkrypares": "trädkrypare",
    "trädkryparna": "trädkrypare",
    "trädkryparnas": "trädkrypare",
    "trädlärk": "trädlärka",
    "trädlärkan": "trädlärka",
    "trädlärkans": "trädlärka",
    "trädlärkas": "trädlärka",
    "trädlärke": "trädlärka",
    "trädlärkor": "trädlärka",
    "trädlärkorna": "trädlärka",
    "trädlärkornas": "trädlärka",
    "trädlärkors": "trädlärka",
    "trädlärks": "trädlärka",
    "trädmogens": "trädmogen",
    "trädmoget": "trädmogen",
    "trädmogets": "trädmogen",
    "trädmogna": "trädmogen",
    "trädmognare": "trädmogen",
    "trädmognares": "trädmogen",
    "trädmognas": "trädmogen",
    "trädmognast": "trädmogen",
    "trädmognaste": "trädmogen",
    "trädmognastes": "trädmogen",
    "trädmognasts": "trädmogen",
    "trädmogne": "trädmogen",
    "trädmognes": "trädmogen",
    "trädningar": "trädning",
    "trädningarna": "trädning",
    "trädningarnas": "trädning",
    "trädningars": "trädning",
    "trädningen": "trädning",
    "trädningens": "trädning",
    "trädnings": "trädning",
    "trädnålar": "trädnål",
    "trädnålarna": "trädnål",
    "trädnålarnas": "trädnål",
    "trädnålars": "trädnål",
    "trädnålen": "trädnål",
    "trädnålens": "trädnål",
    "trädnåls": "trädnål",
    "trädock": "trädocka",
    "trädockan": "trädocka",
    "trädockans": "trädocka",
    "trädockas": "trädocka",
    "trädocke": "trädocka",
    "trädockor": "trädocka",
    "trädockorna": "trädocka",
    "trädockornas": "trädocka",
    "trädockors": "trädocka",
    "trädocks": "trädocka",
    "trädor": "träda",
    "trädorna": "träda",
    "trädornas": "träda",
    "trädors": "träda",
    "trädpiplärk": "trädpiplärka",
    "trädpiplärkan": "trädpiplärka",
    "trädpiplärkans": "trädpiplärka",
    "trädpiplärkas": "trädpiplärka",
    "trädpiplärke": "trädpiplärka",
    "trädpiplärkor": "trädpiplärka",
    "trädpiplärkorna": "trädpiplärka",
    "trädpiplärkornas": "trädpiplärka",
    "trädpiplärkors": "trädpiplärka",
    "trädpiplärks": "trädpiplärka",
    "trädroten": "trädrot",
    "trädrotens": "trädrot",
    "trädrots": "trädrot",
    "trädrötter": "trädrot",
    "trädrötterna": "trädrot",
    "trädrötternas": "trädrot",
    "trädrötters": "trädrot",
    "träds": "träde",
    "trädslagen": "trädslag",
    "trädslagens": "trädslag",
    "trädslaget": "trädslag",
    "trädslagets": "trädslag",
    "trädslags": "trädslag",
    "trädstammar": "trädstam",
    "trädstammarna": "trädstam",
    "trädstammarnas": "trädstam",
    "trädstammars": "trädstam",
    "trädstammen": "trädstam",
    "trädstammens": "trädstam",
    "trädstams": "trädstam",
    "trädstrukturen": "trädstruktur",
    "trädstrukturens": "trädstruktur",
    "trädstrukturer": "trädstruktur",
    "trädstrukturerna": "trädstruktur",
    "trädstrukturernas": "trädstruktur",
    "trädstrukturers": "trädstruktur",
    "trädstrukturs": "trädstruktur",
    "trädstygnen": "trädstygn",
    "trädstygnens": "trädstygn",
    "trädstygnet": "trädstygn",
    "trädstygnets": "trädstygn",
    "trädstygns": "trädstygn",
    "trädsvampar": "trädsvamp",
    "trädsvamparna": "trädsvamp",
    "trädsvamparnas": "trädsvamp",
    "trädsvampars": "trädsvamp",
    "trädsvampen": "trädsvamp",
    "trädsvampens": "trädsvamp",
    "trädsvamps": "trädsvamp",
    "trädtoppar": "trädtopp",
    "trädtopparna": "trädtopp",
    "trädtopparnas": "trädtopp",
    "trädtoppars": "trädtopp",
    "trädtoppen": "trädtopp",
    "trädtoppens": "trädtopp",
    "trädtopps": "trädtopp",
    "träende": "trä",
    "träendes": "trä",
    "träer": "trä",
    "träerna": "trä",
    "träernas": "trä",
    "träers": "trä",
    "träet": "trä",
    "träets": "trä",
    "träfartygen": "träfartyg",
    "träfartygens": "träfartyg",
    "träfartyget": "träfartyg",
    "träfartygets": "träfartyg",
    "träfartygs": "träfartyg",
    "träff": "träffa",
    "träffad": "träffa",
    "träffade": "träffad",
    "träffades": "träffas",
    "träffads": "träffad",
    "träffande": "träffa",
    "träffanden": "träffande",
    "träffandena": "träffande",
    "träffandenas": "träffande",
    "träffandens": "träffande",
    "träffandes": "träffande",
    "träffandet": "träffande",
    "träffandets": "träffande",
    "träffar": "träffa",
    "träffarna": "träff",
    "träffarnas": "träff",
    "träffars": "träff",
    "träffas": "träffa",
    "träffat": "träffad",
    "träffats": "träffas",
    "träffbilden": "träffbild",
    "träffbildens": "träffbild",
    "träffbilder": "träffbild",
    "träffbilderna": "träffbild",
    "träffbildernas": "träffbild",
    "träffbilders": "träffbild",
    "träffbilds": "träffbild",
    "träffen": "träff",
    "träffens": "träff",
    "träffningar": "träffning",
    "träffningarna": "träffning",
    "träffningarnas": "träffning",
    "träffningars": "träffning",
    "träffningen": "träffning",
    "träffningens": "träffning",
    "träffnings": "träffning",
    "träffpunkten": "träffpunkt",
    "träffpunktens": "träffpunkt",
    "träffpunkter": "träffpunkt",
    "träffpunkterna": "träffpunkt",
    "träffpunkternas": "träffpunkt",
    "träffpunkters": "träffpunkt",
    "träffpunkts": "träffpunkt",
    "träffs": "träff",
    "träffsäkerheten": "träffsäkerhet",
    "träffsäkerhetens": "träffsäkerhet",
    "träffsäkerheter": "träffsäkerhet",
    "träffsäkerheterna": "träffsäkerhet",
    "träffsäkerheternas": "träffsäkerhet",
    "träffsäkerheters": "träffsäkerhet",
    "träffsäkerhets": "träffsäkerhet",
    "träffsäkers": "träffsäker",
    "träffsäkert": "träffsäker",
    "träffsäkerts": "träffsäker",
    "träffsäkra": "träffsäker",
    "träffsäkrare": "träffsäker",
    "träffsäkrares": "träffsäker",
    "träffsäkras": "träffsäker",
    "träffsäkrast": "träffsäker",
    "träffsäkraste": "träffsäker",
    "träffsäkrastes": "träffsäker",
    "träffsäkrasts": "träffsäker",
    "träffsäkre": "träffsäker",
    "träffsäkres": "träffsäker",
    "träffverkans": "träffverkan",
    "träfibermassan": "träfibermassa",
    "träfibermassans": "träfibermassa",
    "träfibermassas": "träfibermassa",
    "träfibermasse": "träfibermassa",
    "träfibern": "träfiber",
    "träfiberns": "träfiber",
    "träfiberplatt": "träfiberplatta",
    "träfiberplattan": "träfiberplatta",
    "träfiberplattans": "träfiberplatta",
    "träfiberplattas": "träfiberplatta",
    "träfiberplatte": "träfiberplatta",
    "träfiberplattor": "träfiberplatta",
    "träfiberplattorna": "träfiberplatta",
    "träfiberplattornas": "träfiberplatta",
    "träfiberplattors": "träfiberplatta",
    "träfiberplatts": "träfiberplatta",
    "träfibers": "träfiber",
    "träfiberskivan": "träfiberskiva",
    "träfiberskivans": "träfiberskiva",
    "träfiberskivas": "träfiberskiva",
    "träfiberskive": "träfiberskiva",
    "träfiberskivor": "träfiberskiva",
    "träfiberskivorna": "träfiberskiva",
    "träfiberskivornas": "träfiberskiva",
    "träfiberskivors": "träfiberskiva",
    "träfibrer": "träfiber",
    "träfibrerna": "träfiber",
    "träfibrernas": "träfiber",
    "träfibrers": "träfiber",
    "träfilar": "träfil",
    "träfilarna": "träfil",
    "träfilarnas": "träfil",
    "träfilars": "träfil",
    "träfilen": "träfil",
    "träfilens": "träfil",
    "träfils": "träfil",
    "träflis": "träflisa",
    "träflisan": "träflisa",
    "träflisans": "träflisa",
    "träflisas": "träflisa",
    "träflise": "träflisa",
    "träflisen": "träflis",
    "träflisens": "träflis",
    "träflisor": "träflisa",
    "träflisorna": "träflisa",
    "träflisornas": "träflisa",
    "träflisors": "träflisa",
    "träformar": "träform",
    "träformarna": "träform",
    "träformarnas": "träform",
    "träformars": "träform",
    "träformen": "träform",
    "träformens": "träform",
    "träforms": "träform",
    "träfrackar": "träfrack",
    "träfrackarna": "träfrack",
    "träfrackarnas": "träfrack",
    "träfrackars": "träfrack",
    "träfracken": "träfrack",
    "träfrackens": "träfrack",
    "träfracks": "träfrack",
    "träfria": "träfri",
    "träfriare": "träfri",
    "träfriares": "träfri",
    "träfrias": "träfri",
    "träfriast": "träfri",
    "träfriaste": "träfri",
    "träfriastes": "träfri",
    "träfriasts": "träfri",
    "träfrie": "träfri",
    "träfries": "träfri",
    "träfris": "träfri",
    "träfritt": "träfri",
    "träfritts": "träfri",
    "träfräsar": "träfräs",
    "träfräsarna": "träfräs",
    "träfräsarnas": "träfräs",
    "träfräsars": "träfräs",
    "träfräsen": "träfräs",
    "träfräsens": "träfräs",
    "träförsockringar": "träförsockring",
    "träförsockringarna": "träförsockring",
    "träförsockringarnas": "träförsockring",
    "träförsockringars": "träförsockring",
    "träförsockringen": "träförsockring",
    "träförsockringens": "träförsockring",
    "träförsockrings": "träförsockring",
    "träförädlingar": "träförädling",
    "träförädlingarna": "träförädling",
    "träförädlingarnas": "träförädling",
    "träförädlingars": "träförädling",
    "träförädlingen": "träförädling",
    "träförädlingens": "träförädling",
    "träförädlings": "träförädling",
    "trägens": "trägen",
    "träget": "trägen",
    "trägets": "trägen",
    "trägna": "trägen",
    "trägnare": "trägen",
    "trägnares": "trägen",
    "trägnas": "trägen",
    "trägnast": "trägen",
    "trägnaste": "trägen",
    "trägnastes": "trägen",
    "trägnasts": "trägen",
    "trägne": "trägen",
    "trägnes": "trägen",
    "trägolven": "trägolv",
    "trägolvens": "trägolv",
    "trägolvet": "trägolv",
    "trägolvets": "trägolv",
    "trägolvs": "trägolv",
    "trägravyren": "trägravyr",
    "trägravyrens": "trägravyr",
    "trägravyrer": "trägravyr",
    "trägravyrerna": "trägravyr",
    "trägravyrernas": "trägravyr",
    "trägravyrers": "trägravyr",
    "trägravyrs": "trägravyr",
    "trähästar": "trähäst",
    "trähästarna": "trähäst",
    "trähästarnas": "trähäst",
    "trähästars": "trähäst",
    "trähästen": "trähäst",
    "trähästens": "trähäst",
    "trähästs": "trähäst",
    "träiga": "träig",
    "träigare": "träig",
    "träigares": "träig",
    "träigas": "träig",
    "träigast": "träig",
    "träigaste": "träig",
    "träigastes": "träig",
    "träigasts": "träig",
    "träige": "träig",
    "träiges": "träig",
    "träigheten": "träighet",
    "träighetens": "träighet",
    "träighets": "träighet",
    "träigs": "träig",
    "träigt": "träig",
    "träigts": "träig",
    "träindustrien": "träindustri",
    "träindustriens": "träindustri",
    "träindustrier": "träindustri",
    "träindustrierna": "träindustri",
    "träindustriernas": "träindustri",
    "träindustriers": "träindustri",
    "träindustrin": "träindustri",
    "träindustrins": "träindustri",
    "träindustris": "träindustri",
    "träjonet": "träjon",
    "träjonets": "träjon",
    "träjons": "träjon",
    "träkarlar": "träkarl",
    "träkarlarna": "träkarl",
    "träkarlarnas": "träkarl",
    "träkarlars": "träkarl",
    "träkarlen": "träkarl",
    "träkarlens": "träkarl",
    "träkarls": "träkarl",
    "träkarlsbridgen": "träkarlsbridge",
    "träkarlsbridgens": "träkarlsbridge",
    "träkarlsbridges": "träkarlsbridge",
    "träklossar": "träkloss",
    "träklossarna": "träkloss",
    "träklossarnas": "träkloss",
    "träklossars": "träkloss",
    "träklossen": "träkloss",
    "träklossens": "träkloss",
    "träkolen": "träkol",
    "träkolens": "träkol",
    "träkolet": "träkol",
    "träkolets": "träkol",
    "träkols": "träkol",
    "träkonstruktionen": "träkonstruktion",
    "träkonstruktionens": "träkonstruktion",
    "träkonstruktioner": "träkonstruktion",
    "träkonstruktionerna": "träkonstruktion",
    "träkonstruktionernas": "träkonstruktion",
    "träkonstruktioners": "träkonstruktion",
    "träkonstruktions": "träkonstruktion",
    "träkorsen": "träkors",
    "träkorsens": "träkors",
    "träkorset": "träkors",
    "träkorsets": "träkors",
    "träl": "träla",
    "trälad": "träla",
    "trälade": "träla",
    "trälades": "träla",
    "trälads": "träla",
    "trälande": "träla",
    "trälanden": "trälande",
    "trälandena": "trälande",
    "trälandenas": "trälande",
    "trälandens": "trälande",
    "trälandes": "trälande",
    "trälandet": "trälande",
    "trälandets": "trälande",
    "trälar": "träla",
    "trälarbeten": "trälarbete",
    "trälarbetena": "trälarbete",
    "trälarbetenas": "trälarbete",
    "trälarbetens": "trälarbete",
    "trälarbetes": "trälarbete",
    "trälarbetet": "trälarbete",
    "trälarbetets": "trälarbete",
    "trälarbets": "trälarbete",
    "trälarna": "träl",
    "trälarnas": "träl",
    "trälars": "träl",
    "trälas": "träla",
    "trälat": "träla",
    "trälats": "träla",
    "trälband": "trälbinda",
    "trälbands": "trälbinda",
    "trälbind": "trälbinda",
    "trälbindande": "trälbinda",
    "trälbindanden": "trälbindande",
    "trälbindandena": "trälbindande",
    "trälbindandenas": "trälbindande",
    "trälbindandens": "trälbindande",
    "trälbindandes": "trälbindande",
    "trälbindandet": "trälbindande",
    "trälbindandets": "trälbindande",
    "trälbindas": "trälbinda",
    "trälbinde": "trälbinda",
    "trälbinder": "trälbinda",
    "trälbindes": "trälbinda",
    "trälbinds": "trälbinda",
    "trälbunde": "trälbinda",
    "trälbunden": "trälbinda",
    "trälbundens": "trälbinda",
    "trälbundes": "trälbinda",
    "trälbundet": "trälbinda",
    "trälbundets": "trälbinda",
    "trälbundit": "trälbinda",
    "trälbundits": "trälbinda",
    "trälbundna": "trälbinda",
    "trälbundnas": "trälbinda",
    "trälbundne": "trälbinda",
    "trälbundnes": "trälbinda",
    "träldomar": "träldom",
    "träldomarna": "träldom",
    "träldomarnas": "träldom",
    "träldomars": "träldom",
    "träldomen": "träldom",
    "träldomens": "träldom",
    "träldoms": "träldom",
    "trälen": "träl",
    "trälens": "träl",
    "träliga": "trälig",
    "träligare": "trälig",
    "träligares": "trälig",
    "träligas": "trälig",
    "träligast": "trälig",
    "träligaste": "trälig",
    "träligastes": "trälig",
    "träligasts": "trälig",
    "trälige": "trälig",
    "träliges": "trälig",
    "träligheten": "trälighet",
    "trälighetens": "trälighet",
    "trälighets": "trälighet",
    "träligs": "trälig",
    "träligt": "trälig",
    "träligts": "trälig",
    "träls": "träl",
    "trämaskar": "trämask",
    "trämaskarna": "trämask",
    "trämaskarnas": "trämask",
    "trämaskars": "trämask",
    "trämasken": "trämask",
    "trämaskens": "trämask",
    "trämasks": "trämask",
    "trämassan": "trämassa",
    "trämassans": "trämassa",
    "trämassas": "trämassa",
    "trämasse": "trämassa",
    "trämorteln": "trämortel",
    "trämortelns": "trämortel",
    "trämortels": "trämortel",
    "trämortlar": "trämortel",
    "trämortlarna": "trämortel",
    "trämortlarnas": "trämortel",
    "trämortlars": "trämortel",
    "trän": "träna",
    "träna": "träd",
    "tränad": "träna",
    "tränade": "träna",
    "tränades": "träna",
    "tränads": "träna",
    "tränande": "träna",
    "tränanden": "tränande",
    "tränandena": "tränande",
    "tränandenas": "tränande",
    "tränandens": "tränande",
    "tränandes": "tränande",
    "tränandet": "tränande",
    "tränandets": "tränande",
    "tränar": "tränare",
    "tränaren": "tränare",
    "tränarens": "tränare",
    "tränares": "tränare",
    "tränarna": "tränare",
    "tränarnas": "tränare",
    "tränas": "träna",
    "tränat": "träna",
    "tränats": "träna",
    "träng": "tränga",
    "trängande": "tränga",
    "tränganden": "trängande",
    "trängandena": "trängande",
    "trängandenas": "trängande",
    "trängandens": "trängande",
    "trängandes": "trängande",
    "trängandet": "trängande",
    "trängandets": "trängande",
    "trängas": "tränga",
    "trängd": "tränga",
    "trängda": "trängd",
    "trängdare": "trängd",
    "trängdares": "trängd",
    "trängdas": "trängd",
    "trängdast": "trängd",
    "trängdaste": "trängd",
    "trängdastes": "trängd",
    "trängdasts": "trängd",
    "trängde": "trängd",
    "trängdes": "trängd",
    "trängdheten": "trängdhet",
    "trängdhetens": "trängdhet",
    "trängdhets": "trängdhet",
    "trängds": "trängd",
    "tränger": "tränga",
    "tränges": "tränga",
    "trängningar": "trängning",
    "trängningarna": "trängning",
    "trängningarnas": "trängning",
    "trängningars": "trängning",
    "trängningen": "trängning",
    "trängningens": "trängning",
    "trängnings": "trängning",
    "trängre": "trång",
    "trängres": "trång",
    "trängs": "trängas",
    "trängselavgiften": "trängselavgift",
    "trängselavgiftens": "trängselavgift",
    "trängselavgifter": "trängselavgift",
    "trängselavgifterna": "trängselavgift",
    "trängselavgifternas": "trängselavgift",
    "trängselavgifters": "trängselavgift",
    "trängselavgifts": "trängselavgift",
    "trängseln": "trängsel",
    "trängselns": "trängsel",
    "trängsels": "trängsel",
    "trängselskatten": "trängselskatt",
    "trängselskattens": "trängselskatt",
    "trängselskatter": "trängselskatt",
    "trängselskatterna": "trängselskatt",
    "trängselskatternas": "trängselskatt",
    "trängselskatters": "trängselskatt",
    "trängselskatts": "trängselskatt",
    "trängst": "trång",
    "trängste": "trång",
    "trängstes": "trång",
    "trängsts": "trång",
    "trängt": "trängta",
    "trängtad": "trängta",
    "trängtade": "trängta",
    "trängtades": "trängta",
    "trängtads": "trängta",
    "trängtande": "trängta",
    "trängtanden": "trängtande",
    "trängtandena": "trängtande",
    "trängtandenas": "trängtande",
    "trängtandens": "trängtande",
    "trängtandes": "trängtande",
    "trängtandet": "trängtande",
    "trängtandets": "trängtande",
    "trängtans": "trängtan",
    "trängtar": "trängta",
    "trängtas": "trängta",
    "trängtat": "trängta",
    "trängtats": "trängta",
    "trängtruppen": "trängtrupp",
    "trängtruppens": "trängtrupp",
    "trängtrupper": "trängtrupp",
    "trängtrupperna": "trängtrupp",
    "trängtruppernas": "trängtrupp",
    "trängtruppers": "trängtrupp",
    "trängtrupps": "trängtrupp",
    "trängts": "trängd",
    "träningar": "träning",
    "träningarna": "träning",
    "träningarnas": "träning",
    "träningars": "träning",
    "träningen": "träning",
    "träningens": "träning",
    "tränings": "träning",
    "träningsdräkten": "träningsdräkt",
    "träningsdräktens": "träningsdräkt",
    "träningsdräkter": "träningsdräkt",
    "träningsdräkterna": "träningsdräkt",
    "träningsdräkternas": "träningsdräkt",
    "träningsdräkters": "träningsdräkt",
    "träningsdräkts": "träningsdräkt",
    "träningsglädjen": "träningsglädje",
    "träningsglädjens": "träningsglädje",
    "träningsglädjes": "träningsglädje",
    "träningskläderna": "träningskläder",
    "träningsklädernas": "träningskläder",
    "träningskläders": "träningskläder",
    "träningsklädes": "träningskläder",
    "träningskläds": "träningskläder",
    "träningslägerna": "träningsläger",
    "träningslägernas": "träningsläger",
    "träningslägers": "träningsläger",
    "träningslägren": "träningsläger",
    "träningslägrens": "träningsläger",
    "träningslägret": "träningsläger",
    "träningslägrets": "träningsläger",
    "träningsmässiga": "träningsmässig",
    "träningsmässigare": "träningsmässig",
    "träningsmässigares": "träningsmässig",
    "träningsmässigas": "träningsmässig",
    "träningsmässigast": "träningsmässig",
    "träningsmässigaste": "träningsmässig",
    "träningsmässigastes": "träningsmässig",
    "träningsmässigasts": "träningsmässig",
    "träningsmässige": "träningsmässig",
    "träningsmässiges": "träningsmässig",
    "träningsmässigs": "träningsmässig",
    "träningsmässigt": "träningsmässig",
    "träningsmässigts": "träningsmässig",
    "träningsoverallen": "träningsoverall",
    "träningsoverallens": "träningsoverall",
    "träningsoveraller": "träningsoverall",
    "träningsoverallerna": "träningsoverall",
    "träningsoverallernas": "träningsoverall",
    "träningsoverallers": "träningsoverall",
    "träningsoveralls": "träningsoverall",
    "träningsskolan": "träningsskola",
    "träningsskolans": "träningsskola",
    "träningsskolas": "träningsskola",
    "träningsskole": "träningsskola",
    "träningsskolor": "träningsskola",
    "träningsskolorna": "träningsskola",
    "träningsskolornas": "träningsskola",
    "träningsskolors": "träningsskola",
    "träningsuppläggen": "träningsupplägg",
    "träningsuppläggens": "träningsupplägg",
    "träningsupplägget": "träningsupplägg",
    "träningsuppläggets": "träningsupplägg",
    "träningsuppläggs": "träningsupplägg",
    "tränjonen": "tränjon",
    "tränjonens": "tränjon",
    "tränjonet": "tränjon",
    "tränjonets": "tränjon",
    "tränjons": "tränjon",
    "träns": "tränsa",
    "tränsad": "tränsa",
    "tränsade": "tränsa",
    "tränsades": "tränsa",
    "tränsads": "tränsa",
    "tränsande": "tränsa",
    "tränsanden": "tränsande",
    "tränsandena": "tränsande",
    "tränsandenas": "tränsande",
    "tränsandens": "tränsande",
    "tränsandes": "tränsande",
    "tränsandet": "tränsande",
    "tränsandets": "tränsande",
    "tränsar": "tränsa",
    "tränsarna": "träns",
    "tränsarnas": "träns",
    "tränsars": "träns",
    "tränsas": "tränsa",
    "tränsat": "tränsa",
    "tränsats": "tränsa",
    "tränsen": "träns",
    "tränsens": "träns",
    "träpinn": "träpinne",
    "träpinnar": "träpinne",
    "träpinnarna": "träpinne",
    "träpinnarnas": "träpinne",
    "träpinnars": "träpinne",
    "träpinnen": "träpinne",
    "träpinnens": "träpinne",
    "träpinnes": "träpinne",
    "träpinns": "träpinne",
    "träplatt": "träplatta",
    "träplattan": "träplatta",
    "träplattans": "träplatta",
    "träplattas": "träplatta",
    "träplatte": "träplatta",
    "träplattor": "träplatta",
    "träplattorna": "träplatta",
    "träplattornas": "träplatta",
    "träplattors": "träplatta",
    "träplatts": "träplatta",
    "träportar": "träport",
    "träportarna": "träport",
    "träportarnas": "träport",
    "träportars": "träport",
    "träporten": "träport",
    "träportens": "träport",
    "träports": "träport",
    "träprodukten": "träprodukt",
    "träproduktens": "träprodukt",
    "träprodukter": "träprodukt",
    "träprodukterna": "träprodukt",
    "träprodukternas": "träprodukt",
    "träprodukters": "träprodukt",
    "träprodukts": "träprodukt",
    "trär": "trä",
    "träramar": "träram",
    "träramarna": "träram",
    "träramarnas": "träram",
    "träramars": "träram",
    "träramen": "träram",
    "träramens": "träram",
    "trärams": "träram",
    "träribb": "träribba",
    "träribban": "träribba",
    "träribbans": "träribba",
    "träribbas": "träribba",
    "träribbe": "träribba",
    "träribbor": "träribba",
    "träribborna": "träribba",
    "träribbornas": "träribba",
    "träribbors": "träribba",
    "träribbs": "träribba",
    "träs": "trä",
    "träskall": "träskalle",
    "träskallar": "träskalle",
    "träskallarna": "träskalle",
    "träskallarnas": "träskalle",
    "träskallars": "träskalle",
    "träskallen": "träskalle",
    "träskallens": "träskalle",
    "träskalles": "träskalle",
    "träskalliga": "träskallig",
    "träskalligare": "träskallig",
    "träskalligares": "träskallig",
    "träskalligas": "träskallig",
    "träskalligast": "träskallig",
    "träskalligaste": "träskallig",
    "träskalligastes": "träskallig",
    "träskalligasts": "träskallig",
    "träskallige": "träskallig",
    "träskalliges": "träskallig",
    "träskalligheten": "träskallighet",
    "träskallighetens": "träskallighet",
    "träskallighets": "träskallighet",
    "träskalligs": "träskallig",
    "träskalligt": "träskallig",
    "träskalligts": "träskallig",
    "träskalls": "träskalle",
    "träskedar": "träsked",
    "träskedarna": "träsked",
    "träskedarnas": "träsked",
    "träskedars": "träsked",
    "träskeden": "träsked",
    "träskedens": "träsked",
    "träskeds": "träsked",
    "träsken": "träsk",
    "träskens": "träsk",
    "träsket": "träsk",
    "träskets": "träsk",
    "träskfebern": "träskfeber",
    "träskfeberns": "träskfeber",
    "träskfebers": "träskfeber",
    "träskfolken": "träskfolk",
    "träskfolkens": "träskfolk",
    "träskfolket": "träskfolk",
    "träskfolkets": "träskfolk",
    "träskfolks": "träskfolk",
    "träskivan": "träskiva",
    "träskivans": "träskiva",
    "träskivas": "träskiva",
    "träskive": "träskiva",
    "träskivor": "träskiva",
    "träskivorna": "träskiva",
    "träskivornas": "träskiva",
    "träskivors": "träskiva",
    "träsklanden": "träskland",
    "träsklandens": "träskland",
    "träsklandet": "träskland",
    "träsklandets": "träskland",
    "träsklands": "träskland",
    "träskodansen": "träskodans",
    "träskodansens": "träskodans",
    "träskodanser": "träskodans",
    "träskodanserna": "träskodans",
    "träskodansernas": "träskodans",
    "träskodansers": "träskodans",
    "träskon": "träsko",
    "träskons": "träsko",
    "träskor": "träsko",
    "träskorna": "träsko",
    "träskornas": "träsko",
    "träskors": "träsko",
    "träskos": "träsko",
    "träskostegen": "träskosteg",
    "träskostegens": "träskosteg",
    "träskosteget": "träskosteg",
    "träskostegets": "träskosteg",
    "träskostegs": "träskosteg",
    "träskostöveln": "träskostövel",
    "träskostövelns": "träskostövel",
    "träskostövels": "träskostövel",
    "träskostövlar": "träskostövel",
    "träskostövlarna": "träskostövel",
    "träskostövlarnas": "träskostövel",
    "träskostövlars": "träskostövel",
    "träskrindan": "träskrinda",
    "träskrindans": "träskrinda",
    "träskrindas": "träskrinda",
    "träskrinde": "träskrinda",
    "träskrindor": "träskrinda",
    "träskrindorna": "träskrinda",
    "träskrindornas": "träskrinda",
    "träskrindors": "träskrinda",
    "träskruvar": "träskruv",
    "träskruvarna": "träskruv",
    "träskruvarnas": "träskruv",
    "träskruvars": "träskruv",
    "träskruven": "träskruv",
    "träskruvens": "träskruv",
    "träskruvs": "träskruv",
    "träsks": "träsk",
    "träskydden": "träskydd",
    "träskyddens": "träskydd",
    "träskyddet": "träskydd",
    "träskyddets": "träskydd",
    "träskydds": "träskydd",
    "träskyddsmedels": "träskyddsmedel",
    "träskyddsmedlen": "träskyddsmedel",
    "träskyddsmedlens": "träskyddsmedel",
    "träskyddsmedlet": "träskyddsmedel",
    "träskyddsmedlets": "träskyddsmedel",
    "träskålar": "träskål",
    "träskålarna": "träskål",
    "träskålarnas": "träskål",
    "träskålars": "träskål",
    "träskålen": "träskål",
    "träskålens": "träskål",
    "träskåls": "träskål",
    "träslagen": "träslag",
    "träslagens": "träslag",
    "träslaget": "träslag",
    "träslagets": "träslag",
    "träslags": "träslag",
    "träslevar": "träslev",
    "träslevarna": "träslev",
    "träslevarnas": "träslev",
    "träslevars": "träslev",
    "träsleven": "träslev",
    "träslevens": "träslev",
    "träslevs": "träslev",
    "träslipar": "träslip",
    "träsliparna": "träslip",
    "träsliparnas": "träslip",
    "träslipars": "träslip",
    "träslipen": "träslip",
    "träslipens": "träslip",
    "träslips": "träslip",
    "träslotten": "träslott",
    "träslottens": "träslott",
    "träslottet": "träslott",
    "träslottets": "träslott",
    "träslotts": "träslott",
    "träslöjden": "träslöjd",
    "träslöjdens": "träslöjd",
    "träslöjds": "träslöjd",
    "träsmaken": "träsmak",
    "träsmakens": "träsmak",
    "träsmaks": "träsmak",
    "träsnidar": "träsnidare",
    "träsnidaren": "träsnidare",
    "träsnidarens": "träsnidare",
    "träsnidares": "träsnidare",
    "träsnidarna": "träsnidare",
    "träsnidarnas": "träsnidare",
    "träsniderier": "träsnideri",
    "träsniderierna": "träsnideri",
    "träsnideriernas": "träsnideri",
    "träsnideriers": "träsnideri",
    "träsnideriet": "träsnideri",
    "träsnideriets": "träsnideri",
    "träsnideris": "träsnideri",
    "träsniderit": "träsnideri",
    "träsniderits": "träsnideri",
    "träsnitten": "träsnitt",
    "träsnittens": "träsnitt",
    "träsnittet": "träsnitt",
    "träsnittets": "träsnitt",
    "träsnitts": "träsnitt",
    "träsnittsstockar": "träsnittsstock",
    "träsnittsstockarna": "träsnittsstock",
    "träsnittsstockarnas": "träsnittsstock",
    "träsnittsstockars": "träsnittsstock",
    "träsnittsstocken": "träsnittsstock",
    "träsnittsstockens": "träsnittsstock",
    "träsnittsstocks": "träsnittsstock",
    "träsockers": "träsocker",
    "träsockret": "träsocker",
    "träsockrets": "träsocker",
    "träspriten": "träsprit",
    "träspritens": "träsprit",
    "träsprits": "träsprit",
    "trästavar": "trästav",
    "trästavarna": "trästav",
    "trästavarnas": "trästav",
    "trästavars": "trästav",
    "trästaven": "trästav",
    "trästavens": "trästav",
    "trästavs": "trästav",
    "trästicken": "trästick",
    "trästickens": "trästick",
    "trästicket": "trästick",
    "trästickets": "trästick",
    "trästicks": "trästick",
    "trästiften": "trästift",
    "trästiftens": "trästift",
    "trästiftet": "trästift",
    "trästiftets": "trästift",
    "trästifts": "trästift",
    "trästycken": "trästycke",
    "trästyckena": "trästycke",
    "trästyckenas": "trästycke",
    "trästyckens": "trästycke",
    "trästyckes": "trästycke",
    "trästycket": "trästycke",
    "trästyckets": "trästycke",
    "trästycks": "trästycke",
    "träsvarvar": "träsvarv",
    "träsvarvarna": "träsvarv",
    "träsvarvarnas": "träsvarv",
    "träsvarvars": "träsvarv",
    "träsvarven": "träsvarv",
    "träsvarvens": "träsvarv",
    "träsvarvs": "träsvarv",
    "trät": "träta",
    "trätan": "träta",
    "trätande": "träta",
    "trätanden": "trätande",
    "trätandena": "trätande",
    "trätandenas": "trätande",
    "trätandens": "trätande",
    "trätandes": "trätande",
    "trätandet": "trätande",
    "trätandets": "trätande",
    "trätans": "träta",
    "trätas": "träta",
    "träte": "träta",
    "trätekniska": "träteknisk",
    "trätekniskare": "träteknisk",
    "trätekniskares": "träteknisk",
    "trätekniskas": "träteknisk",
    "trätekniskast": "träteknisk",
    "trätekniskaste": "träteknisk",
    "trätekniskastes": "träteknisk",
    "trätekniskasts": "träteknisk",
    "trätekniske": "träteknisk",
    "trätekniskes": "träteknisk",
    "träteknisks": "träteknisk",
    "trätekniskt": "träteknisk",
    "trätekniskts": "träteknisk",
    "träter": "träta",
    "trätes": "träta",
    "trätgiriga": "trätgirig",
    "trätgirigare": "trätgirig",
    "trätgirigares": "trätgirig",
    "trätgirigas": "trätgirig",
    "trätgirigast": "trätgirig",
    "trätgirigaste": "trätgirig",
    "trätgirigastes": "trätgirig",
    "trätgirigasts": "trätgirig",
    "trätgirige": "trätgirig",
    "trätgiriges": "trätgirig",
    "trätgirigheten": "trätgirighet",
    "trätgirighetens": "trätgirighet",
    "trätgirighets": "trätgirighet",
    "trätgirigs": "trätgirig",
    "trätgirigt": "trätgirig",
    "trätgirigts": "trätgirig",
    "trätjäran": "trätjära",
    "trätjärans": "trätjära",
    "trätjäras": "trätjära",
    "trätjäre": "trätjära",
    "trätlystens": "trätlysten",
    "trätlystet": "trätlysten",
    "trätlystets": "trätlysten",
    "trätlystna": "trätlysten",
    "trätlystnare": "trätlysten",
    "trätlystnares": "trätlysten",
    "trätlystnas": "trätlysten",
    "trätlystnast": "trätlysten",
    "trätlystnaste": "trätlysten",
    "trätlystnastes": "trätlysten",
    "trätlystnasts": "trätlysten",
    "trätlystne": "trätlysten",
    "trätlystnes": "trätlysten",
    "trätobrodern": "trätobroder",
    "trätobroderns": "trätobroder",
    "trätobroders": "trätobroder",
    "trätobröder": "trätobroder",
    "trätobröderna": "trätobroder",
    "trätobrödernas": "trätobroder",
    "trätobröders": "trätobroder",
    "trätoffeln": "trätoffel",
    "trätoffelns": "trätoffel",
    "trätoffels": "trätoffel",
    "trätoffla": "trätoffel",
    "trätofflan": "trätoffel",
    "trätofflans": "trätoffel",
    "trätofflas": "trätoffel",
    "trätoffle": "trätoffel",
    "trätofflor": "trätoffel",
    "trätofflorna": "trätoffel",
    "trätofflornas": "trätoffel",
    "trätofflors": "trätoffel",
    "trätor": "träta",
    "trätorna": "träta",
    "trätornas": "träta",
    "trätors": "träta",
    "träts": "träta",
    "trätt": "träta",
    "trätta": "träta",
    "trättas": "träta",
    "trätte": "träta",
    "trättes": "träta",
    "trätts": "träta",
    "trätugget": "trätugg",
    "trätuggets": "trätugg",
    "trätuggs": "trätugg",
    "träullen": "träull",
    "träullens": "träull",
    "träulls": "träull",
    "trävirkes": "trävirke",
    "trävirket": "trävirke",
    "trävirkets": "trävirke",
    "trävita": "trävit",
    "trävitare": "trävit",
    "trävitares": "trävit",
    "trävitas": "trävit",
    "trävitast": "trävit",
    "trävitaste": "trävit",
    "trävitastes": "trävit",
    "trävitasts": "trävit",
    "trävite": "trävit",
    "trävites": "trävit",
    "trävits": "trävit",
    "trävitt": "trävit",
    "trävitts": "trävit",
    "träytan": "träyta",
    "träytans": "träyta",
    "träytas": "träyta",
    "träyte": "träyta",
    "träytor": "träyta",
    "träytorna": "träyta",
    "träytornas": "träyta",
    "träytors": "träyta",
    "tråckel": "tråckla",
    "tråckelstygnen": "tråckelstygn",
    "tråckelstygnens": "tråckelstygn",
    "tråckelstygnet": "tråckelstygn",
    "tråckelstygnets": "tråckelstygn",
    "tråckelstygns": "tråckelstygn",
    "tråckeltrådar": "tråckeltråd",
    "tråckeltrådarna": "tråckeltråd",
    "tråckeltrådarnas": "tråckeltråd",
    "tråckeltrådars": "tråckeltråd",
    "tråckeltråden": "tråckeltråd",
    "tråckeltrådens": "tråckeltråd",
    "tråckeltråds": "tråckeltråd",
    "tråcklad": "tråckla",
    "tråcklade": "tråckla",
    "tråcklades": "tråckla",
    "tråcklads": "tråckla",
    "tråcklande": "tråckla",
    "tråcklanden": "tråcklande",
    "tråcklandena": "tråcklande",
    "tråcklandenas": "tråcklande",
    "tråcklandens": "tråcklande",
    "tråcklandes": "tråcklande",
    "tråcklandet": "tråcklande",
    "tråcklandets": "tråcklande",
    "tråcklar": "tråckla",
    "tråcklas": "tråckla",
    "tråcklat": "tråckla",
    "tråcklats": "tråckla",
    "tråcklingar": "tråckling",
    "tråcklingarna": "tråckling",
    "tråcklingarnas": "tråckling",
    "tråcklingars": "tråckling",
    "tråcklingen": "tråckling",
    "tråcklingens": "tråckling",
    "tråcklings": "tråckling",
    "trådar": "tråd",
    "trådarna": "tråd",
    "trådarnas": "tråd",
    "trådars": "tråd",
    "trådbindningar": "trådbindning",
    "trådbindningarna": "trådbindning",
    "trådbindningarnas": "trådbindning",
    "trådbindningars": "trådbindning",
    "trådbindningen": "trådbindning",
    "trådbindningens": "trådbindning",
    "trådbindnings": "trådbindning",
    "trådbussar": "trådbuss",
    "trådbussarna": "trådbuss",
    "trådbussarnas": "trådbuss",
    "trådbussars": "trådbuss",
    "trådbussen": "trådbuss",
    "trådbussens": "trådbuss",
    "trådd": "trå",
    "trådda": "trå",
    "tråddas": "trå",
    "trådde": "trå",
    "tråddes": "trå",
    "tråddiametern": "tråddiameter",
    "tråddiameterns": "tråddiameter",
    "tråddiameters": "tråddiameter",
    "tråddiametrar": "tråddiameter",
    "tråddiametrarna": "tråddiameter",
    "tråddiametrarnas": "tråddiameter",
    "tråddiametrars": "tråddiameter",
    "tråddragningar": "tråddragning",
    "tråddragningarna": "tråddragning",
    "tråddragningarnas": "tråddragning",
    "tråddragningars": "tråddragning",
    "tråddragningen": "tråddragning",
    "tråddragningens": "tråddragning",
    "tråddragnings": "tråddragning",
    "trådds": "trå",
    "tråddukar": "trådduk",
    "tråddukarna": "trådduk",
    "tråddukarnas": "trådduk",
    "tråddukars": "trådduk",
    "trådduken": "trådduk",
    "tråddukens": "trådduk",
    "trådduks": "trådduk",
    "tråden": "tråd",
    "trådens": "tråd",
    "trådglaset": "trådglas",
    "trådglasets": "trådglas",
    "trådiga": "trådig",
    "trådigare": "trådig",
    "trådigares": "trådig",
    "trådigas": "trådig",
    "trådigast": "trådig",
    "trådigaste": "trådig",
    "trådigastes": "trådig",
    "trådigasts": "trådig",
    "trådige": "trådig",
    "trådiges": "trådig",
    "trådigs": "trådig",
    "trådigt": "trådig",
    "trådigts": "trådig",
    "trådknappar": "trådknapp",
    "trådknapparna": "trådknapp",
    "trådknapparnas": "trådknapp",
    "trådknappars": "trådknapp",
    "trådknappen": "trådknapp",
    "trådknappens": "trådknapp",
    "trådknapps": "trådknapp",
    "trådkorsen": "trådkors",
    "trådkorsens": "trådkors",
    "trådkorset": "trådkors",
    "trådkorsets": "trådkors",
    "trådlösa": "trådlös",
    "trådlösare": "trådlös",
    "trådlösares": "trådlös",
    "trådlösas": "trådlös",
    "trådlösast": "trådlös",
    "trådlösaste": "trådlös",
    "trådlösastes": "trådlös",
    "trådlösasts": "trådlös",
    "trådlöse": "trådlös",
    "trådlöses": "trådlös",
    "trådlösheten": "trådlöshet",
    "trådlöshetens": "trådlöshet",
    "trådlöshets": "trådlöshet",
    "trådlöst": "trådlös",
    "trådlösts": "trådlös",
    "trådmaskar": "trådmask",
    "trådmaskarna": "trådmask",
    "trådmaskarnas": "trådmask",
    "trådmaskars": "trådmask",
    "trådmasken": "trådmask",
    "trådmaskens": "trådmask",
    "trådmasks": "trådmask",
    "trådmatningen": "trådmatning",
    "trådmatningens": "trådmatning",
    "trådmatnings": "trådmatning",
    "trådmin": "trådmina",
    "trådminan": "trådmina",
    "trådminans": "trådmina",
    "trådminas": "trådmina",
    "trådmine": "trådmina",
    "trådminor": "trådmina",
    "trådminorna": "trådmina",
    "trådminornas": "trådmina",
    "trådminors": "trådmina",
    "trådmins": "trådmina",
    "trådradion": "trådradio",
    "trådradions": "trådradio",
    "trådradios": "trådradio",
    "trådrull": "trådrulle",
    "trådrullar": "trådrulle",
    "trådrullarna": "trådrulle",
    "trådrullarnas": "trådrulle",
    "trådrullars": "trådrulle",
    "trådrullen": "trådrulle",
    "trådrullens": "trådrulle",
    "trådrulles": "trådrulle",
    "trådrulls": "trådrulle",
    "trådräta": "trådrät",
    "trådrätare": "trådrät",
    "trådrätares": "trådrät",
    "trådrätas": "trådrät",
    "trådrätast": "trådrät",
    "trådrätaste": "trådrät",
    "trådrätastes": "trådrät",
    "trådrätasts": "trådrät",
    "trådräte": "trådrät",
    "trådrätes": "trådrät",
    "trådräts": "trådrät",
    "trådrätt": "trådrät",
    "trådrätts": "trådrät",
    "tråds": "tråd",
    "trådsaxar": "trådsax",
    "trådsaxarna": "trådsax",
    "trådsaxarnas": "trådsax",
    "trådsaxars": "trådsax",
    "trådsaxen": "trådsax",
    "trådsaxens": "trådsax",
    "trådskivlingar": "trådskivling",
    "trådskivlingarna": "trådskivling",
    "trådskivlingarnas": "trådskivling",
    "trådskivlingars": "trådskivling",
    "trådskivlingen": "trådskivling",
    "trådskivlingens": "trådskivling",
    "trådskivlings": "trådskivling",
    "trådslitens": "trådsliten",
    "trådslitet": "trådsliten",
    "trådslitets": "trådsliten",
    "trådslitna": "trådsliten",
    "trådslitnare": "trådsliten",
    "trådslitnares": "trådsliten",
    "trådslitnas": "trådsliten",
    "trådslitnast": "trådsliten",
    "trådslitnaste": "trådsliten",
    "trådslitnastes": "trådsliten",
    "trådslitnasts": "trådsliten",
    "trådslitne": "trådsliten",
    "trådslitnes": "trådsliten",
    "trådsmala": "trådsmal",
    "trådsmalare": "trådsmal",
    "trådsmalares": "trådsmal",
    "trådsmalas": "trådsmal",
    "trådsmalast": "trådsmal",
    "trådsmalaste": "trådsmal",
    "trådsmalastes": "trådsmal",
    "trådsmalasts": "trådsmal",
    "trådsmale": "trådsmal",
    "trådsmales": "trådsmal",
    "trådsmals": "trådsmal",
    "trådsmalt": "trådsmal",
    "trådsmalts": "trådsmal",
    "trådspikar": "trådspik",
    "trådspikarna": "trådspik",
    "trådspikarnas": "trådspik",
    "trådspikars": "trådspik",
    "trådspiken": "trådspik",
    "trådspikens": "trådspik",
    "trådspiks": "trådspik",
    "trådämnen": "trådämne",
    "trådämnena": "trådämne",
    "trådämnenas": "trådämne",
    "trådämnens": "trådämne",
    "trådämnes": "trådämne",
    "trådämnet": "trådämne",
    "trådämnets": "trådämne",
    "trående": "trå",
    "tråenden": "trående",
    "tråendena": "trående",
    "tråendenas": "trående",
    "tråendens": "trående",
    "tråendes": "trående",
    "tråendet": "trående",
    "tråendets": "trående",
    "trågdalar": "trågdal",
    "trågdalarna": "trågdal",
    "trågdalarnas": "trågdal",
    "trågdalars": "trågdal",
    "trågdalen": "trågdal",
    "trågdalens": "trågdal",
    "trågdals": "trågdal",
    "trågen": "tråg",
    "trågens": "tråg",
    "tråget": "tråg",
    "trågets": "tråg",
    "trågs": "tråg",
    "tråk": "tråka",
    "tråkad": "tråka",
    "tråkade": "tråka",
    "tråkades": "tråka",
    "tråkads": "tråka",
    "tråkande": "tråka",
    "tråkanden": "tråkande",
    "tråkandena": "tråkande",
    "tråkandenas": "tråkande",
    "tråkandens": "tråkande",
    "tråkandes": "tråkande",
    "tråkandet": "tråkande",
    "tråkandets": "tråkande",
    "tråkar": "tråka",
    "tråkarna": "tråk",
    "tråkarnas": "tråk",
    "tråkars": "tråk",
    "tråkas": "tråka",
    "tråkat": "tråka",
    "tråkats": "tråka",
    "tråken": "tråk",
    "tråkens": "tråk",
    "tråket": "tråk",
    "tråkets": "tråk",
    "tråkfotbollen": "tråkfotboll",
    "tråkfotbollens": "tråkfotboll",
    "tråkfotbolls": "tråkfotboll",
    "tråkiga": "tråkig",
    "tråkigare": "tråkig",
    "tråkigares": "tråkig",
    "tråkigas": "tråkig",
    "tråkigast": "tråkig",
    "tråkigaste": "tråkig",
    "tråkigastes": "tråkig",
    "tråkigasts": "tråkig",
    "tråkige": "tråkig",
    "tråkiges": "tråkig",
    "tråkigheten": "tråkighet",
    "tråkighetens": "tråkighet",
    "tråkigheter": "tråkighet",
    "tråkigheterna": "tråkighet",
    "tråkigheternas": "tråkighet",
    "tråkigheters": "tråkighet",
    "tråkighets": "tråkighet",
    "tråkigs": "tråkig",
    "tråkigt": "tråkig",
    "tråkigts": "tråkig",
    "tråkmånsar": "tråkmåns",
    "tråkmånsarna": "tråkmåns",
    "tråkmånsarnas": "tråkmåns",
    "tråkmånsars": "tråkmåns",
    "tråkmånsen": "tråkmåns",
    "tråkmånsens": "tråkmåns",
    "tråkningar": "tråkning",
    "tråkningarna": "tråkning",
    "tråkningarnas": "tråkning",
    "tråkningars": "tråkning",
    "tråkningen": "tråkning",
    "tråkningens": "tråkning",
    "tråknings": "tråkning",
    "tråks": "tråk",
    "trål": "tråla",
    "trålad": "tråla",
    "trålade": "tråla",
    "trålades": "tråla",
    "trålads": "tråla",
    "trålande": "tråla",
    "trålanden": "trålande",
    "trålandena": "trålande",
    "trålandenas": "trålande",
    "trålandens": "trålande",
    "trålandes": "trålande",
    "trålandet": "trålande",
    "trålandets": "trålande",
    "trålar": "trålare",
    "trålaren": "trålare",
    "trålarens": "trålare",
    "trålares": "trålare",
    "trålarna": "trålare",
    "trålarnas": "trålare",
    "trålars": "trål",
    "trålas": "tråla",
    "trålat": "tråla",
    "trålats": "tråla",
    "trålen": "trål",
    "trålens": "trål",
    "trålfiskes": "trålfiske",
    "trålfisket": "trålfiske",
    "trålfiskets": "trålfiske",
    "tråls": "trål",
    "trån": "tråna",
    "trånad": "tråna",
    "trånade": "tråna",
    "trånaden": "trånad",
    "trånadens": "trånad",
    "trånader": "trånad",
    "trånaderna": "trånad",
    "trånadernas": "trånad",
    "trånaders": "trånad",
    "trånades": "tråna",
    "trånads": "trånad",
    "trånande": "tråna",
    "trånanden": "trånande",
    "trånandena": "trånande",
    "trånandenas": "trånande",
    "trånandens": "trånande",
    "trånandes": "trånande",
    "trånandet": "trånande",
    "trånandets": "trånande",
    "trånar": "tråna",
    "trånas": "tråna",
    "trånat": "tråna",
    "trånats": "tråna",
    "trånga": "trång",
    "trångare": "trång",
    "trångares": "trång",
    "trångas": "trång",
    "trångast": "trång",
    "trångaste": "trång",
    "trångastes": "trång",
    "trångasts": "trång",
    "trångbodda": "trångbodd",
    "trångboddare": "trångbodd",
    "trångboddares": "trångbodd",
    "trångboddas": "trångbodd",
    "trångboddast": "trångbodd",
    "trångboddaste": "trångbodd",
    "trångboddastes": "trångbodd",
    "trångboddasts": "trångbodd",
    "trångbodde": "trångbodd",
    "trångboddes": "trångbodd",
    "trångboddheten": "trångboddhet",
    "trångboddhetens": "trångboddhet",
    "trångboddhets": "trångboddhet",
    "trångbodds": "trångbodd",
    "trångbott": "trångbodd",
    "trångbotts": "trångbodd",
    "trångbröstade": "trångbröstad",
    "trångbröstades": "trångbröstad",
    "trångbröstads": "trångbröstad",
    "trångbröstat": "trångbröstad",
    "trångbröstats": "trångbröstad",
    "trånge": "trång",
    "trånges": "trång",
    "trångmålen": "trångmål",
    "trångmålens": "trångmål",
    "trångmålet": "trångmål",
    "trångmålets": "trångmål",
    "trångmåls": "trångmål",
    "trångs": "trång",
    "trångsinta": "trångsint",
    "trångsintare": "trångsint",
    "trångsintares": "trångsint",
    "trångsintas": "trångsint",
    "trångsintast": "trångsint",
    "trångsintaste": "trångsint",
    "trångsintastes": "trångsint",
    "trångsintasts": "trångsint",
    "trångsinte": "trångsint",
    "trångsintes": "trångsint",
    "trångsintheten": "trångsinthet",
    "trångsinthetens": "trångsinthet",
    "trångsinthets": "trångsinthet",
    "trångsints": "trångsint",
    "trångsynen": "trångsyn",
    "trångsynens": "trångsyn",
    "trångsyns": "trångsyn",
    "trångsynta": "trångsynt",
    "trångsyntare": "trångsynt",
    "trångsyntares": "trångsynt",
    "trångsyntas": "trångsynt",
    "trångsyntast": "trångsynt",
    "trångsyntaste": "trångsynt",
    "trångsyntastes": "trångsynt",
    "trångsyntasts": "trångsynt",
    "trångsynte": "trångsynt",
    "trångsyntes": "trångsynt",
    "trångsyntheten": "trångsynthet",
    "trångsynthetens": "trångsynthet",
    "trångsynthets": "trångsynthet",
    "trångsynts": "trångsynt",
    "trångt": "trång",
    "trångts": "trång",
    "trånsjuka": "trånsjuk",
    "trånsjukare": "trånsjuk",
    "trånsjukares": "trånsjuk",
    "trånsjukas": "trånsjuk",
    "trånsjukast": "trånsjuk",
    "trånsjukaste": "trånsjuk",
    "trånsjukastes": "trånsjuk",
    "trånsjukasts": "trånsjuk",
    "trånsjuke": "trånsjuk",
    "trånsjukes": "trånsjuk",
    "trånsjukheten": "trånsjukhet",
    "trånsjukhetens": "trånsjukhet",
    "trånsjukhets": "trånsjukhet",
    "trånsjuks": "trånsjuk",
    "trånsjukt": "trånsjuk",
    "trånsjukts": "trånsjuk",
    "trår": "trå",
    "trås": "trå",
    "trått": "trå",
    "tråtts": "trå",
    "tröga": "trög",
    "trögare": "trög",
    "trögares": "trög",
    "trögas": "trög",
    "trögast": "trög",
    "trögaste": "trög",
    "trögastes": "trög",
    "trögasts": "trög",
    "trögbedda": "trögbedd",
    "trögbeddare": "trögbedd",
    "trögbeddares": "trögbedd",
    "trögbeddas": "trögbedd",
    "trögbeddast": "trögbedd",
    "trögbeddaste": "trögbedd",
    "trögbeddastes": "trögbedd",
    "trögbeddasts": "trögbedd",
    "trögbedde": "trögbedd",
    "trögbeddes": "trögbedd",
    "trögbeddheten": "trögbeddhet",
    "trögbeddhetens": "trögbeddhet",
    "trögbeddhets": "trögbeddhet",
    "trögbedds": "trögbedd",
    "trögbett": "trögbedd",
    "trögbetts": "trögbedd",
    "trögdjuren": "trögdjur",
    "trögdjurens": "trögdjur",
    "trögdjuret": "trögdjur",
    "trögdjurets": "trögdjur",
    "trögdjurs": "trögdjur",
    "tröge": "trög",
    "tröges": "trög",
    "trögfattade": "trögfattad",
    "trögfattades": "trögfattad",
    "trögfattads": "trögfattad",
    "trögfattat": "trögfattad",
    "trögfattats": "trögfattad",
    "trögheten": "tröghet",
    "tröghetens": "tröghet",
    "trögheter": "tröghet",
    "trögheterna": "tröghet",
    "trögheternas": "tröghet",
    "trögheters": "tröghet",
    "tröghets": "tröghet",
    "tröghetskraften": "tröghetskraft",
    "tröghetskraftens": "tröghetskraft",
    "tröghetskrafts": "tröghetskraft",
    "tröghetslagen": "tröghetslag",
    "tröghetslagens": "tröghetslag",
    "tröghetslags": "tröghetslag",
    "tröghetsnavigerad": "tröghetsnavigera",
    "tröghetsnavigerade": "tröghetsnavigera",
    "tröghetsnavigerades": "tröghetsnavigera",
    "tröghetsnavigerads": "tröghetsnavigera",
    "tröghetsnavigerande": "tröghetsnavigera",
    "tröghetsnavigeranden": "tröghetsnavigerande",
    "tröghetsnavigerandena": "tröghetsnavigerande",
    "tröghetsnavigerandenas": "tröghetsnavigerande",
    "tröghetsnavigerandens": "tröghetsnavigerande",
    "tröghetsnavigerandes": "tröghetsnavigerande",
    "tröghetsnavigerandet": "tröghetsnavigerande",
    "tröghetsnavigerandets": "tröghetsnavigerande",
    "tröghetsnavigerar": "tröghetsnavigera",
    "tröghetsnavigeras": "tröghetsnavigera",
    "tröghetsnavigerat": "tröghetsnavigera",
    "tröghetsnavigerats": "tröghetsnavigera",
    "tröghetsnavigerbara": "tröghetsnavigerbar",
    "tröghetsnavigerbarare": "tröghetsnavigerbar",
    "tröghetsnavigerbarares": "tröghetsnavigerbar",
    "tröghetsnavigerbaras": "tröghetsnavigerbar",
    "tröghetsnavigerbarast": "tröghetsnavigerbar",
    "tröghetsnavigerbaraste": "tröghetsnavigerbar",
    "tröghetsnavigerbarastes": "tröghetsnavigerbar",
    "tröghetsnavigerbarasts": "tröghetsnavigerbar",
    "tröghetsnavigerbare": "tröghetsnavigerbar",
    "tröghetsnavigerbares": "tröghetsnavigerbar",
    "tröghetsnavigerbarheten": "tröghetsnavigerbarhet",
    "tröghetsnavigerbarhetens": "tröghetsnavigerbarhet",
    "tröghetsnavigerbarhets": "tröghetsnavigerbarhet",
    "tröghetsnavigerbars": "tröghetsnavigerbar",
    "tröghetsnavigerbart": "tröghetsnavigerbar",
    "tröghetsnavigerbarts": "tröghetsnavigerbar",
    "tröghetsnavigeringar": "tröghetsnavigering",
    "tröghetsnavigeringarna": "tröghetsnavigering",
    "tröghetsnavigeringarnas": "tröghetsnavigering",
    "tröghetsnavigeringars": "tröghetsnavigering",
    "tröghetsnavigeringen": "tröghetsnavigering",
    "tröghetsnavigeringens": "tröghetsnavigering",
    "tröghetsnavigerings": "tröghetsnavigering",
    "tröglästa": "trögläst",
    "tröglästare": "trögläst",
    "tröglästares": "trögläst",
    "tröglästas": "trögläst",
    "tröglästast": "trögläst",
    "tröglästaste": "trögläst",
    "tröglästastes": "trögläst",
    "tröglästasts": "trögläst",
    "trögläste": "trögläst",
    "tröglästes": "trögläst",
    "tröglästheten": "tröglästhet",
    "tröglästhetens": "tröglästhet",
    "tröglästhets": "tröglästhet",
    "tröglästs": "trögläst",
    "trögs": "trög",
    "trögt": "trög",
    "trögts": "trög",
    "trögtänkta": "trögtänkt",
    "trögtänktare": "trögtänkt",
    "trögtänktares": "trögtänkt",
    "trögtänktas": "trögtänkt",
    "trögtänktast": "trögtänkt",
    "trögtänktaste": "trögtänkt",
    "trögtänktastes": "trögtänkt",
    "trögtänktasts": "trögtänkt",
    "trögtänkte": "trögtänkt",
    "trögtänktes": "trögtänkt",
    "trögtänktheten": "trögtänkthet",
    "trögtänkthetens": "trögtänkthet",
    "trögtänkthets": "trögtänkthet",
    "trögtänkts": "trögtänkt",
    "tröj": "tröja",
    "tröjan": "tröja",
    "tröjans": "tröja",
    "tröjas": "tröja",
    "tröje": "tröja",
    "tröjfabriken": "tröjfabrik",
    "tröjfabrikens": "tröjfabrik",
    "tröjfabriker": "tröjfabrik",
    "tröjfabrikerna": "tröjfabrik",
    "tröjfabrikernas": "tröjfabrik",
    "tröjfabrikers": "tröjfabrik",
    "tröjfabriks": "tröjfabrik",
    "tröjfick": "tröjficka",
    "tröjfickan": "tröjficka",
    "tröjfickans": "tröjficka",
    "tröjfickas": "tröjficka",
    "tröjficke": "tröjficka",
    "tröjfickor": "tröjficka",
    "tröjfickorna": "tröjficka",
    "tröjfickornas": "tröjficka",
    "tröjfickors": "tröjficka",
    "tröjficks": "tröjficka",
    "tröjor": "tröja",
    "tröjorna": "tröja",
    "tröjornas": "tröja",
    "tröjors": "tröja",
    "tröjs": "tröja",
    "trösk": "tröska",
    "tröskad": "tröska",
    "tröskade": "tröska",
    "tröskades": "tröska",
    "tröskads": "tröska",
    "tröskan": "tröska",
    "tröskande": "tröska",
    "tröskanden": "tröskande",
    "tröskandena": "tröskande",
    "tröskandenas": "tröskande",
    "tröskandens": "tröskande",
    "tröskandes": "tröskande",
    "tröskandet": "tröskande",
    "tröskandets": "tröskande",
    "tröskans": "tröska",
    "tröskar": "tröska",
    "tröskas": "tröska",
    "tröskat": "tröska",
    "tröskats": "tröska",
    "tröske": "tröska",
    "tröskellåd": "tröskellåda",
    "tröskellådan": "tröskellåda",
    "tröskellådans": "tröskellåda",
    "tröskellådas": "tröskellåda",
    "tröskellåde": "tröskellåda",
    "tröskellådor": "tröskellåda",
    "tröskellådorna": "tröskellåda",
    "tröskellådornas": "tröskellåda",
    "tröskellådors": "tröskellåda",
    "tröskellåds": "tröskellåda",
    "tröskeln": "tröskel",
    "tröskelns": "tröskel",
    "tröskels": "tröskel",
    "tröskelvärden": "tröskelvärde",
    "tröskelvärdena": "tröskelvärde",
    "tröskelvärdenas": "tröskelvärde",
    "tröskelvärdens": "tröskelvärde",
    "tröskelvärdes": "tröskelvärde",
    "tröskelvärdet": "tröskelvärde",
    "tröskelvärdets": "tröskelvärde",
    "trösklad": "trösklada",
    "tröskladan": "trösklada",
    "tröskladans": "trösklada",
    "tröskladas": "trösklada",
    "trösklade": "trösklada",
    "trösklador": "trösklada",
    "tröskladorna": "trösklada",
    "tröskladornas": "trösklada",
    "tröskladors": "trösklada",
    "trösklads": "trösklada",
    "trösklar": "tröskel",
    "trösklarna": "tröskel",
    "trösklarnas": "tröskel",
    "trösklars": "tröskel",
    "tröskor": "tröska",
    "tröskorna": "tröska",
    "tröskornas": "tröska",
    "tröskors": "tröska",
    "tröskverken": "tröskverk",
    "tröskverkens": "tröskverk",
    "tröskverket": "tröskverk",
    "tröskverkets": "tröskverk",
    "tröskverks": "tröskverk",
    "tröst": "trösta",
    "tröstad": "trösta",
    "tröstade": "trösta",
    "tröstades": "trösta",
    "tröstads": "trösta",
    "tröstande": "trösta",
    "tröstanden": "tröstande",
    "tröstandena": "tröstande",
    "tröstandenas": "tröstande",
    "tröstandens": "tröstande",
    "tröstandes": "tröstande",
    "tröstandet": "tröstande",
    "tröstandets": "tröstande",
    "tröstar": "tröstare",
    "tröstaren": "tröstare",
    "tröstarens": "tröstare",
    "tröstares": "tröstare",
    "tröstarna": "tröstare",
    "tröstarnas": "tröstare",
    "tröstars": "tröst",
    "tröstas": "trösta",
    "tröstat": "trösta",
    "tröstats": "trösta",
    "tröstegrunden": "tröstegrund",
    "tröstegrundens": "tröstegrund",
    "tröstegrunder": "tröstegrund",
    "tröstegrunderna": "tröstegrund",
    "tröstegrundernas": "tröstegrund",
    "tröstegrunders": "tröstegrund",
    "tröstegrunds": "tröstegrund",
    "trösten": "tröst",
    "tröstens": "tröst",
    "trösterika": "trösterik",
    "trösterikare": "trösterik",
    "trösterikares": "trösterik",
    "trösterikas": "trösterik",
    "trösterikast": "trösterik",
    "trösterikaste": "trösterik",
    "trösterikastes": "trösterik",
    "trösterikasts": "trösterik",
    "trösterike": "trösterik",
    "trösterikes": "trösterik",
    "trösterikheten": "trösterikhet",
    "trösterikhetens": "trösterikhet",
    "trösterikhets": "trösterikhet",
    "trösteriks": "trösterik",
    "trösterikt": "trösterik",
    "trösterikts": "trösterik",
    "trösteskriften": "trösteskrift",
    "trösteskriftens": "trösteskrift",
    "trösteskrifter": "trösteskrift",
    "trösteskrifterna": "trösteskrift",
    "trösteskrifternas": "trösteskrift",
    "trösteskrifters": "trösteskrift",
    "trösteskrifts": "trösteskrift",
    "tröstlösa": "tröstlös",
    "tröstlösare": "tröstlös",
    "tröstlösares": "tröstlös",
    "tröstlösas": "tröstlös",
    "tröstlösast": "tröstlös",
    "tröstlösaste": "tröstlös",
    "tröstlösastes": "tröstlös",
    "tröstlösasts": "tröstlös",
    "tröstlöse": "tröstlös",
    "tröstlöses": "tröstlös",
    "tröstlösheten": "tröstlöshet",
    "tröstlöshetens": "tröstlöshet",
    "tröstlöshets": "tröstlöshet",
    "tröstlöst": "tröstlös",
    "tröstlösts": "tröstlös",
    "tröstmålen": "tröstmål",
    "tröstmålens": "tröstmål",
    "tröstmålet": "tröstmål",
    "tröstmålets": "tröstmål",
    "tröstmåls": "tröstmål",
    "tröstnappar": "tröstnapp",
    "tröstnapparna": "tröstnapp",
    "tröstnapparnas": "tröstnapp",
    "tröstnappars": "tröstnapp",
    "tröstnappen": "tröstnapp",
    "tröstnappens": "tröstnapp",
    "tröstnapps": "tröstnapp",
    "tröstprisen": "tröstpris",
    "tröstprisens": "tröstpris",
    "tröstpriser": "tröstpris",
    "tröstpriserna": "tröstpris",
    "tröstprisernas": "tröstpris",
    "tröstprisers": "tröstpris",
    "tröstpriset": "tröstpris",
    "tröstprisets": "tröstpris",
    "tröstrika": "tröstrik",
    "tröstrikare": "tröstrik",
    "tröstrikares": "tröstrik",
    "tröstrikas": "tröstrik",
    "tröstrikast": "tröstrik",
    "tröstrikaste": "tröstrik",
    "tröstrikastes": "tröstrik",
    "tröstrikasts": "tröstrik",
    "tröstrike": "tröstrik",
    "tröstrikes": "tröstrik",
    "tröstrikheten": "tröstrikhet",
    "tröstrikhetens": "tröstrikhet",
    "tröstrikhets": "tröstrikhet",
    "tröstriks": "tröstrik",
    "tröstrikt": "tröstrik",
    "tröstrikts": "tröstrik",
    "trösts": "tröst",
    "tröt": "tryta",
    "tröts": "tryta",
    "trött": "trötta",
    "trötta": "trött",
    "tröttad": "trötta",
    "tröttade": "trötta",
    "tröttades": "tröttas",
    "tröttads": "trötta",
    "tröttande": "trötta",
    "tröttanden": "tröttande",
    "tröttandena": "tröttande",
    "tröttandenas": "tröttande",
    "tröttandens": "tröttande",
    "tröttandes": "tröttande",
    "tröttandet": "tröttande",
    "tröttandets": "tröttande",
    "tröttar": "trötta",
    "tröttare": "trött",
    "tröttares": "trött",
    "tröttas": "trötta",
    "tröttast": "trött",
    "tröttaste": "trött",
    "tröttastes": "trött",
    "tröttasts": "trött",
    "tröttat": "trötta",
    "tröttats": "tröttas",
    "trötte": "trött",
    "tröttes": "trött",
    "tröttheten": "trötthet",
    "trötthetens": "trötthet",
    "trötthets": "trötthet",
    "tröttkörda": "tröttkörd",
    "tröttkördare": "tröttkörd",
    "tröttkördares": "tröttkörd",
    "tröttkördas": "tröttkörd",
    "tröttkördast": "tröttkörd",
    "tröttkördaste": "tröttkörd",
    "tröttkördastes": "tröttkörd",
    "tröttkördasts": "tröttkörd",
    "tröttkörde": "tröttkörd",
    "tröttkördes": "tröttkörd",
    "tröttkördheten": "tröttkördhet",
    "tröttkördhetens": "tröttkördhet",
    "tröttkördhets": "tröttkördhet",
    "tröttkörds": "tröttkörd",
    "tröttkört": "tröttkörd",
    "tröttkörts": "tröttkörd",
    "tröttnad": "tröttna",
    "tröttnade": "tröttna",
    "tröttnades": "tröttna",
    "tröttnads": "tröttna",
    "tröttnande": "tröttna",
    "tröttnanden": "tröttnande",
    "tröttnandena": "tröttnande",
    "tröttnandenas": "tröttnande",
    "tröttnandens": "tröttnande",
    "tröttnandes": "tröttnande",
    "tröttnandet": "tröttnande",
    "tröttnandets": "tröttnande",
    "tröttnar": "tröttna",
    "tröttnas": "tröttna",
    "tröttnat": "tröttna",
    "tröttnats": "tröttna",
    "trötts": "trött",
    "tröttsamheten": "tröttsamhet",
    "tröttsamhetens": "tröttsamhet",
    "tröttsamhets": "tröttsamhet",
    "tröttsamma": "tröttsam",
    "tröttsammare": "tröttsam",
    "tröttsammares": "tröttsam",
    "tröttsammas": "tröttsam",
    "tröttsammast": "tröttsam",
    "tröttsammaste": "tröttsam",
    "tröttsammastes": "tröttsam",
    "tröttsammasts": "tröttsam",
    "tröttsamme": "tröttsam",
    "tröttsammes": "tröttsam",
    "tröttsams": "tröttsam",
    "tröttsamt": "tröttsam",
    "tröttsamts": "tröttsam",
    "tsardottern": "tsardotter",
    "tsardotterns": "tsardotter",
    "tsardotters": "tsardotter",
    "tsardöttrar": "tsardotter",
    "tsardöttrarna": "tsardotter",
    "tsardöttrarnas": "tsardotter",
    "tsardöttrars": "tsardotter",
    "tsaren": "tsar",
    "tsarens": "tsar",
    "tsarer": "tsar",
    "tsarerna": "tsar",
    "tsarernas": "tsar",
    "tsarers": "tsar",
    "tsarfamiljen": "tsarfamilj",
    "tsarfamiljens": "tsarfamilj",
    "tsarfamiljer": "tsarfamilj",
    "tsarfamiljerna": "tsarfamilj",
    "tsarfamiljernas": "tsarfamilj",
    "tsarfamiljers": "tsarfamilj",
    "tsarfamiljs": "tsarfamilj",
    "tsarregimen": "tsarregim",
    "tsarregimens": "tsarregim",
    "tsarregimer": "tsarregim",
    "tsarregimerna": "tsarregim",
    "tsarregimernas": "tsarregim",
    "tsarregimers": "tsarregim",
    "tsarregims": "tsarregim",
    "tsars": "tsar",
    "tsetseflug": "tsetsefluga",
    "tsetseflugan": "tsetsefluga",
    "tsetseflugans": "tsetsefluga",
    "tsetseflugas": "tsetsefluga",
    "tsetsefluge": "tsetsefluga",
    "tsetseflugor": "tsetsefluga",
    "tsetseflugorna": "tsetsefluga",
    "tsetseflugornas": "tsetsefluga",
    "tsetseflugors": "tsetsefluga",
    "tsetseflugs": "tsetsefluga",
    "tsunamier": "tsunami",
    "tsunamierna": "tsunami",
    "tsunamiernas": "tsunami",
    "tsunamiers": "tsunami",
    "tsunamikatastrofen": "tsunamikatastrof",
    "tsunamikatastrofens": "tsunamikatastrof",
    "tsunamikatastrofer": "tsunamikatastrof",
    "tsunamikatastroferna": "tsunamikatastrof",
    "tsunamikatastrofernas": "tsunamikatastrof",
    "tsunamikatastrofers": "tsunamikatastrof",
    "tsunamikatastrofs": "tsunamikatastrof",
    "tsunamin": "tsunami",
    "tsunamins": "tsunami",
    "tsunamis": "tsunami",
    "tsunamisarna": "tsunami",
    "tsunamisarnas": "tsunami",
    "tsunamivarningar": "tsunamivarning",
    "tsunamivarningarna": "tsunamivarning",
    "tsunamivarningarnas": "tsunamivarning",
    "tsunamivarningars": "tsunamivarning",
    "tsunamivarningen": "tsunamivarning",
    "tsunamivarningens": "tsunamivarning",
    "tsunamivarnings": "tsunamivarning",
    "tub": "tuba",
    "tuban": "tuba",
    "tubans": "tuba",
    "tubas": "tuba",
    "tubb": "tubba",
    "tubbad": "tubba",
    "tubbade": "tubba",
    "tubbades": "tubba",
    "tubbads": "tubba",
    "tubbande": "tubba",
    "tubbanden": "tubbande",
    "tubbandena": "tubbande",
    "tubbandenas": "tubbande",
    "tubbandens": "tubbande",
    "tubbandes": "tubbande",
    "tubbandet": "tubbande",
    "tubbandets": "tubbande",
    "tubbar": "tubba",
    "tubbas": "tubba",
    "tubbat": "tubba",
    "tubbats": "tubba",
    "tube": "tuba",
    "tuben": "tub",
    "tubens": "tub",
    "tuber": "tub",
    "tuberkelbakterien": "tuberkelbakterie",
    "tuberkelbakteriens": "tuberkelbakterie",
    "tuberkelbakterier": "tuberkelbakterie",
    "tuberkelbakterierna": "tuberkelbakterie",
    "tuberkelbakteriernas": "tuberkelbakterie",
    "tuberkelbakteriers": "tuberkelbakterie",
    "tuberkelbakteries": "tuberkelbakterie",
    "tuberkeln": "tuberkel",
    "tuberkelns": "tuberkel",
    "tuberkels": "tuberkel",
    "tuberkler": "tuberkel",
    "tuberklerna": "tuberkel",
    "tuberklernas": "tuberkel",
    "tuberklers": "tuberkel",
    "tuberkulinen": "tuberkulin",
    "tuberkulinens": "tuberkulin",
    "tuberkuliner": "tuberkulin",
    "tuberkulinerna": "tuberkulin",
    "tuberkulinernas": "tuberkulin",
    "tuberkuliners": "tuberkulin",
    "tuberkulinet": "tuberkulin",
    "tuberkulinets": "tuberkulin",
    "tuberkulins": "tuberkulin",
    "tuberkulosen": "tuberkulos",
    "tuberkulosens": "tuberkulos",
    "tuberkulösa": "tuberkulös",
    "tuberkulösare": "tuberkulös",
    "tuberkulösares": "tuberkulös",
    "tuberkulösas": "tuberkulös",
    "tuberkulösast": "tuberkulös",
    "tuberkulösaste": "tuberkulös",
    "tuberkulösastes": "tuberkulös",
    "tuberkulösasts": "tuberkulös",
    "tuberkulöse": "tuberkulös",
    "tuberkulöses": "tuberkulös",
    "tuberkulöst": "tuberkulös",
    "tuberkulösts": "tuberkulös",
    "tuberna": "tub",
    "tubernas": "tub",
    "tubers": "tub",
    "tubkanonen": "tubkanon",
    "tubkanonens": "tubkanon",
    "tubkanoner": "tubkanon",
    "tubkanonerna": "tubkanon",
    "tubkanonernas": "tubkanon",
    "tubkanoners": "tubkanon",
    "tubkanons": "tubkanon",
    "tubkikar": "tubkikare",
    "tubkikaren": "tubkikare",
    "tubkikarens": "tubkikare",
    "tubkikares": "tubkikare",
    "tubkikarna": "tubkikare",
    "tubkikarnas": "tubkikare",
    "tubor": "tuba",
    "tuborna": "tuba",
    "tubornas": "tuba",
    "tubors": "tuba",
    "tubrören": "tubrör",
    "tubrörens": "tubrör",
    "tubröret": "tubrör",
    "tubrörets": "tubrör",
    "tubrörs": "tubrör",
    "tubs": "tuba",
    "tudel": "tudela",
    "tudelad": "tudela",
    "tudelade": "tudela",
    "tudelades": "tudela",
    "tudelads": "tudela",
    "tudelande": "tudela",
    "tudelanden": "tudelande",
    "tudelandena": "tudelande",
    "tudelandenas": "tudelande",
    "tudelandens": "tudelande",
    "tudelandes": "tudelande",
    "tudelandet": "tudelande",
    "tudelandets": "tudelande",
    "tudelar": "tudela",
    "tudelas": "tudela",
    "tudelat": "tudela",
    "tudelats": "tudela",
    "tudelningar": "tudelning",
    "tudelningarna": "tudelning",
    "tudelningarnas": "tudelning",
    "tudelningars": "tudelning",
    "tudelningen": "tudelning",
    "tudelningens": "tudelning",
    "tudelnings": "tudelning",
    "tuff": "tuffa",
    "tuffa": "tuff",
    "tuffad": "tuffa",
    "tuffade": "tuffa",
    "tuffades": "tuffa",
    "tuffads": "tuffa",
    "tuffande": "tuffa",
    "tuffanden": "tuffande",
    "tuffandena": "tuffande",
    "tuffandenas": "tuffande",
    "tuffandens": "tuffande",
    "tuffandes": "tuffande",
    "tuffandet": "tuffande",
    "tuffandets": "tuffande",
    "tuffar": "tuffa",
    "tuffare": "tuff",
    "tuffares": "tuff",
    "tuffas": "tuffa",
    "tuffast": "tuff",
    "tuffaste": "tuff",
    "tuffastes": "tuff",
    "tuffasts": "tuff",
    "tuffat": "tuffa",
    "tuffats": "tuffa",
    "tuffe": "tuff",
    "tuffen": "tuff",
    "tuffens": "tuff",
    "tuffer": "tuff",
    "tufferna": "tuff",
    "tuffernas": "tuff",
    "tuffers": "tuff",
    "tuffes": "tuff",
    "tuffheten": "tuffhet",
    "tuffhetens": "tuffhet",
    "tuffhets": "tuffhet",
    "tuffingar": "tuffing",
    "tuffingarna": "tuffing",
    "tuffingarnas": "tuffing",
    "tuffingars": "tuffing",
    "tuffingen": "tuffing",
    "tuffingens": "tuffing",
    "tuffings": "tuffing",
    "tuffs": "tuff",
    "tufft": "tuff",
    "tuffts": "tuff",
    "tufs": "tufsa",
    "tufsad": "tufsa",
    "tufsade": "tufsa",
    "tufsades": "tufsa",
    "tufsads": "tufsa",
    "tufsande": "tufsa",
    "tufsanden": "tufsande",
    "tufsandena": "tufsande",
    "tufsandenas": "tufsande",
    "tufsandens": "tufsande",
    "tufsandes": "tufsande",
    "tufsandet": "tufsande",
    "tufsandets": "tufsande",
    "tufsar": "tufsa",
    "tufsas": "tufsa",
    "tufsat": "tufsa",
    "tufsats": "tufsa",
    "tufsiga": "tufsig",
    "tufsigare": "tufsig",
    "tufsigares": "tufsig",
    "tufsigas": "tufsig",
    "tufsigast": "tufsig",
    "tufsigaste": "tufsig",
    "tufsigastes": "tufsig",
    "tufsigasts": "tufsig",
    "tufsige": "tufsig",
    "tufsiges": "tufsig",
    "tufsigheten": "tufsighet",
    "tufsighetens": "tufsighet",
    "tufsighets": "tufsighet",
    "tufsigs": "tufsig",
    "tufsigt": "tufsig",
    "tufsigts": "tufsig",
    "tuftade": "tuftad",
    "tuftades": "tuftad",
    "tuftads": "tuftad",
    "tuftat": "tuftad",
    "tuftats": "tuftad",
    "tuftmatt": "tuftmatta",
    "tuftmattan": "tuftmatta",
    "tuftmattans": "tuftmatta",
    "tuftmattas": "tuftmatta",
    "tuftmatte": "tuftmatta",
    "tuftmattor": "tuftmatta",
    "tuftmattorna": "tuftmatta",
    "tuftmattornas": "tuftmatta",
    "tuftmattors": "tuftmatta",
    "tuftmatts": "tuftmatta",
    "tugg": "tugga",
    "tuggad": "tugga",
    "tuggade": "tugga",
    "tuggades": "tugga",
    "tuggads": "tugga",
    "tuggan": "tugga",
    "tuggande": "tugga",
    "tugganden": "tuggande",
    "tuggandena": "tuggande",
    "tuggandenas": "tuggande",
    "tuggandens": "tuggande",
    "tuggandes": "tuggande",
    "tuggandet": "tuggande",
    "tuggandets": "tuggande",
    "tuggans": "tugga",
    "tuggar": "tugga",
    "tuggas": "tugga",
    "tuggat": "tugga",
    "tuggats": "tugga",
    "tuggbussar": "tuggbuss",
    "tuggbussarna": "tuggbuss",
    "tuggbussarnas": "tuggbuss",
    "tuggbussars": "tuggbuss",
    "tuggbussen": "tuggbuss",
    "tuggbussens": "tuggbuss",
    "tugge": "tugga",
    "tugget": "tugg",
    "tuggets": "tugg",
    "tuggmuskeln": "tuggmuskel",
    "tuggmuskelns": "tuggmuskel",
    "tuggmuskels": "tuggmuskel",
    "tuggmuskler": "tuggmuskel",
    "tuggmusklerna": "tuggmuskel",
    "tuggmusklernas": "tuggmuskel",
    "tuggmusklers": "tuggmuskel",
    "tuggor": "tugga",
    "tuggorna": "tugga",
    "tuggornas": "tugga",
    "tuggors": "tugga",
    "tuggs": "tugga",
    "tuggtobaken": "tuggtobak",
    "tuggtobakens": "tuggtobak",
    "tuggtobaks": "tuggtobak",
    "tuggummibitar": "tuggummibit",
    "tuggummibitarna": "tuggummibit",
    "tuggummibitarnas": "tuggummibit",
    "tuggummibitars": "tuggummibit",
    "tuggummibiten": "tuggummibit",
    "tuggummibitens": "tuggummibit",
    "tuggummibits": "tuggummibit",
    "tuggummin": "tuggummi",
    "tuggummina": "tuggummi",
    "tuggumminas": "tuggummi",
    "tuggummins": "tuggummi",
    "tuggummis": "tuggummi",
    "tuggummit": "tuggummi",
    "tuggummits": "tuggummi",
    "tuggytan": "tuggyta",
    "tuggytans": "tuggyta",
    "tuggytas": "tuggyta",
    "tuggyte": "tuggyta",
    "tuggytor": "tuggyta",
    "tuggytorna": "tuggyta",
    "tuggytornas": "tuggyta",
    "tuggytors": "tuggyta",
    "tuj": "tuja",
    "tujan": "tuja",
    "tujans": "tuja",
    "tujas": "tuja",
    "tuje": "tuja",
    "tujor": "tuja",
    "tujorna": "tuja",
    "tujornas": "tuja",
    "tujors": "tuja",
    "tujs": "tuja",
    "tukanen": "tukan",
    "tukanens": "tukan",
    "tukaner": "tukan",
    "tukanerna": "tukan",
    "tukanernas": "tukan",
    "tukaners": "tukan",
    "tukans": "tukan",
    "tukt": "tukta",
    "tuktad": "tukta",
    "tuktade": "tukta",
    "tuktades": "tukta",
    "tuktads": "tukta",
    "tuktande": "tukta",
    "tuktanden": "tuktande",
    "tuktandena": "tuktande",
    "tuktandenas": "tuktande",
    "tuktandens": "tuktande",
    "tuktandes": "tuktande",
    "tuktandet": "tuktande",
    "tuktandets": "tuktande",
    "tuktans": "tuktan",
    "tuktar": "tukta",
    "tuktas": "tukta",
    "tuktat": "tukta",
    "tuktats": "tukta",
    "tukten": "tukt",
    "tuktens": "tukt",
    "tukthusen": "tukthus",
    "tukthusens": "tukthus",
    "tukthuset": "tukthus",
    "tukthusets": "tukthus",
    "tuktiga": "tuktig",
    "tuktigare": "tuktig",
    "tuktigares": "tuktig",
    "tuktigas": "tuktig",
    "tuktigast": "tuktig",
    "tuktigaste": "tuktig",
    "tuktigastes": "tuktig",
    "tuktigasts": "tuktig",
    "tuktige": "tuktig",
    "tuktiges": "tuktig",
    "tuktigheten": "tuktighet",
    "tuktighetens": "tuktighet",
    "tuktighets": "tuktighet",
    "tuktigs": "tuktig",
    "tuktigt": "tuktig",
    "tuktigts": "tuktig",
    "tukts": "tukt",
    "tularemien": "tularemi",
    "tularemiens": "tularemi",
    "tularemin": "tularemi",
    "tularemins": "tularemi",
    "tularemis": "tularemi",
    "tuliet": "tulium",
    "tuliets": "tulium",
    "tulipanarosen": "tulipanaros",
    "tulipanarosens": "tulipanaros",
    "tuliumet": "tulium",
    "tuliumets": "tulium",
    "tuliums": "tulium",
    "tulkörten": "tulkört",
    "tulkörtens": "tulkört",
    "tulkörter": "tulkört",
    "tulkörterna": "tulkört",
    "tulkörternas": "tulkört",
    "tulkörters": "tulkört",
    "tulkörts": "tulkört",
    "tull": "tulla",
    "tullad": "tulla",
    "tullade": "tulla",
    "tullades": "tulla",
    "tullads": "tulla",
    "tullande": "tulla",
    "tullanden": "tullande",
    "tullandena": "tullande",
    "tullandenas": "tullande",
    "tullandens": "tullande",
    "tullandes": "tullande",
    "tullandet": "tullande",
    "tullandets": "tullande",
    "tullar": "tullare",
    "tullaren": "tullare",
    "tullarens": "tullare",
    "tullares": "tullare",
    "tullarna": "tullare",
    "tullarnas": "tullare",
    "tullars": "tull",
    "tullas": "tulla",
    "tullat": "tulla",
    "tullats": "tulla",
    "tullavgiften": "tullavgift",
    "tullavgiftens": "tullavgift",
    "tullavgifter": "tullavgift",
    "tullavgifterna": "tullavgift",
    "tullavgifternas": "tullavgift",
    "tullavgifters": "tullavgift",
    "tullavgifts": "tullavgift",
    "tullbesiktig": "tullbesiktiga",
    "tullbesiktigad": "tullbesiktiga",
    "tullbesiktigade": "tullbesiktiga",
    "tullbesiktigades": "tullbesiktiga",
    "tullbesiktigads": "tullbesiktiga",
    "tullbesiktigande": "tullbesiktiga",
    "tullbesiktiganden": "tullbesiktigande",
    "tullbesiktigandena": "tullbesiktigande",
    "tullbesiktigandenas": "tullbesiktigande",
    "tullbesiktigandens": "tullbesiktigande",
    "tullbesiktigandes": "tullbesiktigande",
    "tullbesiktigandet": "tullbesiktigande",
    "tullbesiktigandets": "tullbesiktigande",
    "tullbesiktigar": "tullbesiktiga",
    "tullbesiktigas": "tullbesiktiga",
    "tullbesiktigat": "tullbesiktiga",
    "tullbesiktigats": "tullbesiktiga",
    "tullbesiktningar": "tullbesiktning",
    "tullbesiktningarna": "tullbesiktning",
    "tullbesiktningarnas": "tullbesiktning",
    "tullbesiktningars": "tullbesiktning",
    "tullbesiktningen": "tullbesiktning",
    "tullbesiktningens": "tullbesiktning",
    "tullbesiktnings": "tullbesiktning",
    "tulldeklarationen": "tulldeklaration",
    "tulldeklarationens": "tulldeklaration",
    "tulldeklarationer": "tulldeklaration",
    "tulldeklarationerna": "tulldeklaration",
    "tulldeklarationernas": "tulldeklaration",
    "tulldeklarationers": "tulldeklaration",
    "tulldeklarations": "tulldeklaration",
    "tullen": "tull",
    "tullens": "tull",
    "tullfria": "tullfri",
    "tullfriare": "tullfri",
    "tullfriares": "tullfri",
    "tullfrias": "tullfri",
    "tullfriast": "tullfri",
    "tullfriaste": "tullfri",
    "tullfriastes": "tullfri",
    "tullfriasts": "tullfri",
    "tullfrie": "tullfri",
    "tullfries": "tullfri",
    "tullfris": "tullfri",
    "tullfritt": "tullfri",
    "tullfritts": "tullfri",
    "tullkontoren": "tullkontor",
    "tullkontorens": "tullkontor",
    "tullkontoret": "tullkontor",
    "tullkontorets": "tullkontor",
    "tullkontors": "tullkontor",
    "tullkontrollen": "tullkontroll",
    "tullkontrollens": "tullkontroll",
    "tullkontroller": "tullkontroll",
    "tullkontrollerna": "tullkontroll",
    "tullkontrollernas": "tullkontroll",
    "tullkontrollers": "tullkontroll",
    "tullkontrolls": "tullkontroll",
    "tullmurar": "tullmur",
    "tullmurarna": "tullmur",
    "tullmurarnas": "tullmur",
    "tullmurars": "tullmur",
    "tullmuren": "tullmur",
    "tullmurens": "tullmur",
    "tullmurs": "tullmur",
    "tullmässiga": "tullmässig",
    "tullmässigare": "tullmässig",
    "tullmässigares": "tullmässig",
    "tullmässigas": "tullmässig",
    "tullmässigast": "tullmässig",
    "tullmässigaste": "tullmässig",
    "tullmässigastes": "tullmässig",
    "tullmässigasts": "tullmässig",
    "tullmässige": "tullmässig",
    "tullmässiges": "tullmässig",
    "tullmässigs": "tullmässig",
    "tullmässigt": "tullmässig",
    "tullmässigts": "tullmässig",
    "tullnären": "tullnär",
    "tullnärens": "tullnär",
    "tullnärer": "tullnär",
    "tullnärerna": "tullnär",
    "tullnärernas": "tullnär",
    "tullnärers": "tullnär",
    "tullnärs": "tullnär",
    "tullpassen": "tullpass",
    "tullpassens": "tullpass",
    "tullpasset": "tullpass",
    "tullpassets": "tullpass",
    "tullpliktiga": "tullpliktig",
    "tullpliktigare": "tullpliktig",
    "tullpliktigares": "tullpliktig",
    "tullpliktigas": "tullpliktig",
    "tullpliktigast": "tullpliktig",
    "tullpliktigaste": "tullpliktig",
    "tullpliktigastes": "tullpliktig",
    "tullpliktigasts": "tullpliktig",
    "tullpliktige": "tullpliktig",
    "tullpliktiges": "tullpliktig",
    "tullpliktigheten": "tullpliktighet",
    "tullpliktighetens": "tullpliktighet",
    "tullpliktighets": "tullpliktighet",
    "tullpliktigs": "tullpliktig",
    "tullpliktigt": "tullpliktig",
    "tullpliktigts": "tullpliktig",
    "tulls": "tull",
    "tullskydden": "tullskydd",
    "tullskyddens": "tullskydd",
    "tullskyddet": "tullskydd",
    "tullskyddets": "tullskydd",
    "tullskydds": "tullskydd",
    "tullstationen": "tullstation",
    "tullstationens": "tullstation",
    "tullstationer": "tullstation",
    "tullstationerna": "tullstation",
    "tullstationernas": "tullstation",
    "tullstationers": "tullstation",
    "tullstations": "tullstation",
    "tulltjänstemannen": "tulltjänsteman",
    "tulltjänstemannens": "tulltjänsteman",
    "tulltjänstemans": "tulltjänsteman",
    "tulltjänstemän": "tulltjänsteman",
    "tulltjänstemännen": "tulltjänsteman",
    "tulltjänstemännens": "tulltjänsteman",
    "tulltjänstemäns": "tulltjänsteman",
    "tullunionen": "tullunion",
    "tullunionens": "tullunion",
    "tullunioner": "tullunion",
    "tullunionerna": "tullunion",
    "tullunionernas": "tullunion",
    "tullunioners": "tullunion",
    "tullunions": "tullunion",
    "tullverken": "tullverk",
    "tullverkens": "tullverk",
    "tullverket": "tullverk",
    "tullverkets": "tullverk",
    "tullverks": "tullverk",
    "tullvisitationen": "tullvisitation",
    "tullvisitationens": "tullvisitation",
    "tullvisitationer": "tullvisitation",
    "tullvisitationerna": "tullvisitation",
    "tullvisitationernas": "tullvisitation",
    "tullvisitationers": "tullvisitation",
    "tullvisitations": "tullvisitation",
    "tullväsendet": "tullväsen",
    "tullväsendets": "tullväsen",
    "tullväsenet": "tullväsen",
    "tullväsenets": "tullväsen",
    "tullväsens": "tullväsen",
    "tulpanen": "tulpan",
    "tulpanens": "tulpan",
    "tulpaner": "tulpan",
    "tulpanerna": "tulpan",
    "tulpanernas": "tulpan",
    "tulpaners": "tulpan",
    "tulpanlökar": "tulpanlök",
    "tulpanlökarna": "tulpanlök",
    "tulpanlökarnas": "tulpanlök",
    "tulpanlökars": "tulpanlök",
    "tulpanlöken": "tulpanlök",
    "tulpanlökens": "tulpanlök",
    "tulpanlöks": "tulpanlök",
    "tulpans": "tulpan",
    "tulpanträden": "tulpanträd",
    "tulpanträdens": "tulpanträd",
    "tulpanträdet": "tulpanträd",
    "tulpanträdets": "tulpanträd",
    "tulpanträds": "tulpanträd",
    "tulpanängar": "tulpanäng",
    "tulpanängarna": "tulpanäng",
    "tulpanängarnas": "tulpanäng",
    "tulpanängars": "tulpanäng",
    "tulpanängen": "tulpanäng",
    "tulpanängens": "tulpanäng",
    "tulpanängs": "tulpanäng",
    "tult": "tulta",
    "tultad": "tulta",
    "tultade": "tulta",
    "tultades": "tulta",
    "tultads": "tulta",
    "tultan": "tulta",
    "tultande": "tulta",
    "tultanden": "tultande",
    "tultandena": "tultande",
    "tultandenas": "tultande",
    "tultandens": "tultande",
    "tultandes": "tultande",
    "tultandet": "tultande",
    "tultandets": "tultande",
    "tultans": "tulta",
    "tultar": "tulta",
    "tultas": "tulta",
    "tultat": "tulta",
    "tultats": "tulta",
    "tulte": "tulta",
    "tultor": "tulta",
    "tultorna": "tulta",
    "tultornas": "tulta",
    "tultors": "tulta",
    "tults": "tulta",
    "tum": "tumme",
    "tumgreppen": "tumgrepp",
    "tumgreppens": "tumgrepp",
    "tumgreppet": "tumgrepp",
    "tumgreppets": "tumgrepp",
    "tumgrepps": "tumgrepp",
    "tumlad": "tumla",
    "tumlade": "tumla",
    "tumlades": "tumla",
    "tumlads": "tumla",
    "tumlande": "tumla",
    "tumlanden": "tumlande",
    "tumlandena": "tumlande",
    "tumlandenas": "tumlande",
    "tumlandens": "tumlande",
    "tumlandes": "tumlande",
    "tumlandet": "tumlande",
    "tumlandets": "tumlande",
    "tumlar": "tumlare",
    "tumlaren": "tumlare",
    "tumlarens": "tumlare",
    "tumlares": "tumlare",
    "tumlarna": "tumlare",
    "tumlarnas": "tumlare",
    "tumlas": "tumla",
    "tumlat": "tumla",
    "tumlats": "tumla",
    "tumlet": "tummel",
    "tumlets": "tummel",
    "tummad": "tumma",
    "tummade": "tumma",
    "tummades": "tumma",
    "tummads": "tumma",
    "tummande": "tumma",
    "tummanden": "tummande",
    "tummandena": "tummande",
    "tummandenas": "tummande",
    "tummandens": "tummande",
    "tummandes": "tummande",
    "tummandet": "tummande",
    "tummandets": "tummande",
    "tummar": "tumme",
    "tummarna": "tumme",
    "tummarnas": "tumme",
    "tummars": "tumme",
    "tummas": "tumma",
    "tummat": "tumma",
    "tummats": "tumma",
    "tummel": "tumla",
    "tummelitens": "tummeliten",
    "tummelplatsen": "tummelplats",
    "tummelplatsens": "tummelplats",
    "tummelplatser": "tummelplats",
    "tummelplatserna": "tummelplats",
    "tummelplatsernas": "tummelplats",
    "tummelplatsers": "tummelplats",
    "tummels": "tummel",
    "tummen": "tumme",
    "tummens": "tumme",
    "tummes": "tumme",
    "tummetottar": "tummetott",
    "tummetottarna": "tummetott",
    "tummetottarnas": "tummetott",
    "tummetottars": "tummetott",
    "tummetotten": "tummetott",
    "tummetottens": "tummetott",
    "tummetotts": "tummetott",
    "tumnageln": "tumnagel",
    "tumnagelns": "tumnagel",
    "tumnagels": "tumnagel",
    "tumnaglar": "tumnagel",
    "tumnaglarna": "tumnagel",
    "tumnaglarnas": "tumnagel",
    "tumnaglars": "tumnagel",
    "tumregeln": "tumregel",
    "tumregelns": "tumregel",
    "tumregels": "tumregel",
    "tumregler": "tumregel",
    "tumreglerna": "tumregel",
    "tumreglernas": "tumregel",
    "tumreglers": "tumregel",
    "tums": "tumme",
    "tumskalan": "tumskala",
    "tumskalans": "tumskala",
    "tumskalas": "tumskala",
    "tumskale": "tumskala",
    "tumskalor": "tumskala",
    "tumskalorna": "tumskala",
    "tumskalornas": "tumskala",
    "tumskalors": "tumskala",
    "tumskruvar": "tumskruv",
    "tumskruvarna": "tumskruv",
    "tumskruvarnas": "tumskruv",
    "tumskruvars": "tumskruv",
    "tumskruven": "tumskruv",
    "tumskruvens": "tumskruv",
    "tumskruvs": "tumskruv",
    "tumstjocka": "tumstjock",
    "tumstjockare": "tumstjock",
    "tumstjockares": "tumstjock",
    "tumstjockas": "tumstjock",
    "tumstjockast": "tumstjock",
    "tumstjockaste": "tumstjock",
    "tumstjockastes": "tumstjock",
    "tumstjockasts": "tumstjock",
    "tumstjocke": "tumstjock",
    "tumstjockes": "tumstjock",
    "tumstjocks": "tumstjock",
    "tumstjockt": "tumstjock",
    "tumstjockts": "tumstjock",
    "tumstockar": "tumstock",
    "tumstockarna": "tumstock",
    "tumstockarnas": "tumstock",
    "tumstockars": "tumstock",
    "tumstocken": "tumstock",
    "tumstockens": "tumstock",
    "tumstocks": "tumstock",
    "tumsugar": "tumsugare",
    "tumsugaren": "tumsugare",
    "tumsugarens": "tumsugare",
    "tumsugares": "tumsugare",
    "tumsugarna": "tumsugare",
    "tumsugarnas": "tumsugare",
    "tumultartade": "tumultartad",
    "tumultartades": "tumultartad",
    "tumultartads": "tumultartad",
    "tumultartat": "tumultartad",
    "tumultartats": "tumultartad",
    "tumulten": "tumult",
    "tumultens": "tumult",
    "tumultet": "tumult",
    "tumultets": "tumult",
    "tumults": "tumult",
    "tumultuariska": "tumultuarisk",
    "tumultuariskare": "tumultuarisk",
    "tumultuariskares": "tumultuarisk",
    "tumultuariskas": "tumultuarisk",
    "tumultuariskast": "tumultuarisk",
    "tumultuariskaste": "tumultuarisk",
    "tumultuariskastes": "tumultuarisk",
    "tumultuariskasts": "tumultuarisk",
    "tumultuariske": "tumultuarisk",
    "tumultuariskes": "tumultuarisk",
    "tumultuarisks": "tumultuarisk",
    "tumultuariskt": "tumultuarisk",
    "tumultuariskts": "tumultuarisk",
    "tumvant": "tumvante",
    "tumvantar": "tumvante",
    "tumvantarna": "tumvante",
    "tumvantarnas": "tumvante",
    "tumvantars": "tumvante",
    "tumvanten": "tumvante",
    "tumvantens": "tumvante",
    "tumvantes": "tumvante",
    "tumvants": "tumvante",
    "tumvecken": "tumveck",
    "tumveckens": "tumveck",
    "tumvecket": "tumveck",
    "tumveckets": "tumveck",
    "tumvecks": "tumveck",
    "tumören": "tumör",
    "tumörens": "tumör",
    "tumörer": "tumör",
    "tumörerna": "tumör",
    "tumörernas": "tumör",
    "tumörers": "tumör",
    "tumörs": "tumör",
    "tundran": "tundra",
    "tundrans": "tundra",
    "tundras": "tundra",
    "tundre": "tundra",
    "tundror": "tundra",
    "tundrorna": "tundra",
    "tundrornas": "tundra",
    "tundrors": "tundra",
    "tunen": "tun",
    "tunens": "tun",
    "tunern": "tuner",
    "tunerna": "tuner",
    "tunernas": "tuner",
    "tunerns": "tuner",
    "tuners": "tuner",
    "tunersarna": "tuner",
    "tunersarnas": "tuner",
    "tunersen": "tuner",
    "tunersens": "tuner",
    "tunet": "tun",
    "tunets": "tun",
    "tung": "tunga",
    "tunga": "tung",
    "tungan": "tunga",
    "tungans": "tunga",
    "tungarbetade": "tungarbetad",
    "tungarbetades": "tungarbetad",
    "tungarbetads": "tungarbetad",
    "tungarbetat": "tungarbetad",
    "tungarbetats": "tungarbetad",
    "tungas": "tunga",
    "tungbanden": "tungband",
    "tungbandens": "tungband",
    "tungbandet": "tungband",
    "tungbandets": "tungband",
    "tungbands": "tungband",
    "tungbenen": "tungben",
    "tungbenens": "tungben",
    "tungbenet": "tungben",
    "tungbenets": "tungben",
    "tungbens": "tungben",
    "tunge": "tunga",
    "tungels": "tungel",
    "tunges": "tung",
    "tungfotade": "tungfotad",
    "tungfotades": "tungfotad",
    "tungfotads": "tungfotad",
    "tungfotat": "tungfotad",
    "tungfotats": "tungfotad",
    "tunggumpade": "tunggumpad",
    "tunggumpades": "tunggumpad",
    "tunggumpads": "tunggumpad",
    "tunggumpat": "tunggumpad",
    "tunggumpats": "tunggumpad",
    "tunghäftan": "tunghäfta",
    "tunghäftans": "tunghäfta",
    "tunghäftas": "tunghäfta",
    "tungkörda": "tungkörd",
    "tungkördare": "tungkörd",
    "tungkördares": "tungkörd",
    "tungkördas": "tungkörd",
    "tungkördast": "tungkörd",
    "tungkördaste": "tungkörd",
    "tungkördastes": "tungkörd",
    "tungkördasts": "tungkörd",
    "tungkörde": "tungkörd",
    "tungkördes": "tungkörd",
    "tungkördheten": "tungkördhet",
    "tungkördhetens": "tungkördhet",
    "tungkördhets": "tungkördhet",
    "tungkörds": "tungkörd",
    "tungkört": "tungkörd",
    "tungkörts": "tungkörd",
    "tunglet": "tungel",
    "tunglets": "tungel",
    "tungljuden": "tungljud",
    "tungljudens": "tungljud",
    "tungljudet": "tungljud",
    "tungljudets": "tungljud",
    "tungljuds": "tungljud",
    "tunglästa": "tungläst",
    "tunglästare": "tungläst",
    "tunglästares": "tungläst",
    "tunglästas": "tungläst",
    "tunglästast": "tungläst",
    "tunglästaste": "tungläst",
    "tunglästastes": "tungläst",
    "tunglästasts": "tungläst",
    "tungläste": "tungläst",
    "tunglästes": "tungläst",
    "tunglästheten": "tunglästhet",
    "tunglästhetens": "tunglästhet",
    "tunglästhets": "tunglästhet",
    "tunglästs": "tungläst",
    "tungmetallen": "tungmetall",
    "tungmetallens": "tungmetall",
    "tungmetaller": "tungmetall",
    "tungmetallerna": "tungmetall",
    "tungmetallernas": "tungmetall",
    "tungmetallers": "tungmetall",
    "tungmetalls": "tungmetall",
    "tungo": "tunga",
    "tungomålen": "tungomål",
    "tungomålens": "tungomål",
    "tungomålet": "tungomål",
    "tungomålets": "tungomål",
    "tungomåls": "tungomål",
    "tungomålstalandes": "tungomålstalande",
    "tungomålstalandet": "tungomålstalande",
    "tungomålstalandets": "tungomålstalande",
    "tungomålstalar": "tungomålstalare",
    "tungomålstalaren": "tungomålstalare",
    "tungomålstalarens": "tungomålstalare",
    "tungomålstalares": "tungomålstalare",
    "tungomålstalarna": "tungomålstalare",
    "tungomålstalarnas": "tungomålstalare",
    "tungor": "tunga",
    "tungorna": "tunga",
    "tungornas": "tunga",
    "tungors": "tunga",
    "tungrodda": "tungrodd",
    "tungroddare": "tungrodd",
    "tungroddares": "tungrodd",
    "tungroddas": "tungrodd",
    "tungroddast": "tungrodd",
    "tungroddaste": "tungrodd",
    "tungroddastes": "tungrodd",
    "tungroddasts": "tungrodd",
    "tungrodde": "tungrodd",
    "tungroddes": "tungrodd",
    "tungroddheten": "tungroddhet",
    "tungroddhetens": "tungroddhet",
    "tungroddhets": "tungroddhet",
    "tungrodds": "tungrodd",
    "tungroten": "tungrot",
    "tungrotens": "tungrot",
    "tungrots": "tungrot",
    "tungrots-r-en": "tungrots-r",
    "tungrots-r-ens": "tungrots-r",
    "tungrots-r-et": "tungrots-r",
    "tungrots-r-ets": "tungrots-r",
    "tungrots-r-s": "tungrots-r",
    "tungrots-r:en": "tungrots-r",
    "tungrots-r:ens": "tungrots-r",
    "tungrots-r:et": "tungrots-r",
    "tungrots-r:ets": "tungrots-r",
    "tungrots-r:s": "tungrots-r",
    "tungrots-ren": "tungrots-r",
    "tungrots-rens": "tungrots-r",
    "tungrots-ret": "tungrots-r",
    "tungrots-rets": "tungrots-r",
    "tungrots-rs": "tungrots-r",
    "tungrott": "tungrodd",
    "tungrotts": "tungrodd",
    "tungryggar": "tungrygg",
    "tungryggarna": "tungrygg",
    "tungryggarnas": "tungrygg",
    "tungryggars": "tungrygg",
    "tungryggen": "tungrygg",
    "tungryggens": "tungrygg",
    "tungryggs": "tungrygg",
    "tungs": "tunga",
    "tungsamheten": "tungsamhet",
    "tungsamhetens": "tungsamhet",
    "tungsamhets": "tungsamhet",
    "tungsamma": "tungsam",
    "tungsammare": "tungsam",
    "tungsammares": "tungsam",
    "tungsammas": "tungsam",
    "tungsammast": "tungsam",
    "tungsammaste": "tungsam",
    "tungsammastes": "tungsam",
    "tungsammasts": "tungsam",
    "tungsamme": "tungsam",
    "tungsammes": "tungsam",
    "tungsams": "tungsam",
    "tungsamt": "tungsam",
    "tungsamts": "tungsam",
    "tungsidan": "tungsida",
    "tungsidans": "tungsida",
    "tungsidas": "tungsida",
    "tungside": "tungsida",
    "tungsides": "tungsida",
    "tungsidor": "tungsida",
    "tungsidorna": "tungsida",
    "tungsidornas": "tungsida",
    "tungsidors": "tungsida",
    "tungsinnes": "tungsinne",
    "tungsinnet": "tungsinne",
    "tungsinnets": "tungsinne",
    "tungsinta": "tungsint",
    "tungsintare": "tungsint",
    "tungsintares": "tungsint",
    "tungsintas": "tungsint",
    "tungsintast": "tungsint",
    "tungsintaste": "tungsint",
    "tungsintastes": "tungsint",
    "tungsintasts": "tungsint",
    "tungsinte": "tungsint",
    "tungsintes": "tungsint",
    "tungsintheten": "tungsinthet",
    "tungsinthetens": "tungsinthet",
    "tungsintheter": "tungsinthet",
    "tungsintheterna": "tungsinthet",
    "tungsintheternas": "tungsinthet",
    "tungsintheters": "tungsinthet",
    "tungsinthets": "tungsinthet",
    "tungsints": "tungsint",
    "tungspaten": "tungspat",
    "tungspatens": "tungspat",
    "tungspats": "tungspat",
    "tungspen": "tungspene",
    "tungspenar": "tungspene",
    "tungspenarna": "tungspene",
    "tungspenarnas": "tungspene",
    "tungspenars": "tungspene",
    "tungspenen": "tungspene",
    "tungspenens": "tungspene",
    "tungspenes": "tungspene",
    "tungspens": "tungspene",
    "tungspets-r-en": "tungspets-r",
    "tungspets-r-ens": "tungspets-r",
    "tungspets-r-et": "tungspets-r",
    "tungspets-r-ets": "tungspets-r",
    "tungspets-r-s": "tungspets-r",
    "tungspets-r:en": "tungspets-r",
    "tungspets-r:ens": "tungspets-r",
    "tungspets-r:et": "tungspets-r",
    "tungspets-r:ets": "tungspets-r",
    "tungspets-r:s": "tungspets-r",
    "tungspets-ren": "tungspets-r",
    "tungspets-rens": "tungspets-r",
    "tungspets-ret": "tungspets-r",
    "tungspets-rets": "tungspets-r",
    "tungspets-rs": "tungspets-r",
    "tungspetsar": "tungspets",
    "tungspetsarna": "tungspets",
    "tungspetsarnas": "tungspets",
    "tungspetsars": "tungspets",
    "tungspetsen": "tungspets",
    "tungspetsens": "tungspets",
    "tungstenen": "tungsten",
    "tungstenens": "tungsten",
    "tungstens": "tungsten",
    "tungsövda": "tungsövd",
    "tungsövdare": "tungsövd",
    "tungsövdares": "tungsövd",
    "tungsövdas": "tungsövd",
    "tungsövdast": "tungsövd",
    "tungsövdaste": "tungsövd",
    "tungsövdastes": "tungsövd",
    "tungsövdasts": "tungsövd",
    "tungsövde": "tungsövd",
    "tungsövdes": "tungsövd",
    "tungsövdheten": "tungsövdhet",
    "tungsövdhetens": "tungsövdhet",
    "tungsövdhets": "tungsövdhet",
    "tungsövds": "tungsövd",
    "tungsövt": "tungsövd",
    "tungsövts": "tungsövd",
    "tungt": "tung",
    "tungts": "tung",
    "tungusen": "tungus",
    "tungusens": "tungus",
    "tunguser": "tungus",
    "tunguserna": "tungus",
    "tungusernas": "tungus",
    "tungusers": "tungus",
    "tungvattenreaktorer": "tungvattenreaktor",
    "tungvattenreaktorerna": "tungvattenreaktor",
    "tungvattenreaktorernas": "tungvattenreaktor",
    "tungvattenreaktorers": "tungvattenreaktor",
    "tungvattenreaktorn": "tungvattenreaktor",
    "tungvattenreaktorns": "tungvattenreaktor",
    "tungvattenreaktors": "tungvattenreaktor",
    "tungviktar": "tungviktare",
    "tungviktaren": "tungviktare",
    "tungviktarens": "tungviktare",
    "tungviktares": "tungviktare",
    "tungviktarna": "tungviktare",
    "tungviktarnas": "tungviktare",
    "tungvikten": "tungvikt",
    "tungviktens": "tungvikt",
    "tungvikts": "tungvikt",
    "tungörten": "tungört",
    "tungörtens": "tungört",
    "tungörter": "tungört",
    "tungörterna": "tungört",
    "tungörternas": "tungört",
    "tungörters": "tungört",
    "tungörts": "tungört",
    "tunik": "tunika",
    "tunikan": "tunika",
    "tunikans": "tunika",
    "tunikas": "tunika",
    "tunike": "tunika",
    "tuniken": "tunik",
    "tunikens": "tunik",
    "tuniker": "tunik",
    "tunikerna": "tunik",
    "tunikernas": "tunik",
    "tunikers": "tunik",
    "tunikor": "tunika",
    "tunikorna": "tunika",
    "tunikornas": "tunika",
    "tunikors": "tunika",
    "tuniks": "tunika",
    "tunisiern": "tunisier",
    "tunisierna": "tunisier",
    "tunisiernas": "tunisier",
    "tunisierns": "tunisier",
    "tunisiers": "tunisier",
    "tunisiska": "tunisisk",
    "tunisiskan": "tunisiska",
    "tunisiskans": "tunisiska",
    "tunisiskare": "tunisisk",
    "tunisiskares": "tunisisk",
    "tunisiskas": "tunisiska",
    "tunisiskast": "tunisisk",
    "tunisiskaste": "tunisisk",
    "tunisiskastes": "tunisisk",
    "tunisiskasts": "tunisisk",
    "tunisiske": "tunisiska",
    "tunisiskes": "tunisisk",
    "tunisiskor": "tunisiska",
    "tunisiskorna": "tunisiska",
    "tunisiskornas": "tunisiska",
    "tunisiskors": "tunisiska",
    "tunisisks": "tunisisk",
    "tunisiskt": "tunisisk",
    "tunisiskts": "tunisisk",
    "tunlar": "tunnel",
    "tunlarna": "tunnel",
    "tunlarnas": "tunnel",
    "tunlars": "tunnel",
    "tunn": "tunna",
    "tunna": "tunn",
    "tunnad": "tunna",
    "tunnade": "tunna",
    "tunnades": "tunna",
    "tunnads": "tunna",
    "tunnan": "tunna",
    "tunnande": "tunna",
    "tunnanden": "tunnande",
    "tunnandena": "tunnande",
    "tunnandenas": "tunnande",
    "tunnandens": "tunnande",
    "tunnandes": "tunnande",
    "tunnandet": "tunnande",
    "tunnandets": "tunnande",
    "tunnans": "tunna",
    "tunnar": "tunna",
    "tunnare": "tunn",
    "tunnares": "tunn",
    "tunnas": "tunna",
    "tunnast": "tunn",
    "tunnaste": "tunn",
    "tunnastes": "tunn",
    "tunnasts": "tunn",
    "tunnat": "tunna",
    "tunnats": "tunna",
    "tunnbanden": "tunnband",
    "tunnbandens": "tunnband",
    "tunnbandet": "tunnband",
    "tunnbandets": "tunnband",
    "tunnbands": "tunnband",
    "tunnbindar": "tunnbindare",
    "tunnbindaren": "tunnbindare",
    "tunnbindarens": "tunnbindare",
    "tunnbindares": "tunnbindare",
    "tunnbindarna": "tunnbindare",
    "tunnbindarnas": "tunnbindare",
    "tunnbinderier": "tunnbinderi",
    "tunnbinderierna": "tunnbinderi",
    "tunnbinderiernas": "tunnbinderi",
    "tunnbinderiers": "tunnbinderi",
    "tunnbinderiet": "tunnbinderi",
    "tunnbinderiets": "tunnbinderi",
    "tunnbinderis": "tunnbinderi",
    "tunnbinderit": "tunnbinderi",
    "tunnbinderits": "tunnbinderi",
    "tunnbladiga": "tunnbladig",
    "tunnbladigare": "tunnbladig",
    "tunnbladigares": "tunnbladig",
    "tunnbladigas": "tunnbladig",
    "tunnbladigast": "tunnbladig",
    "tunnbladigaste": "tunnbladig",
    "tunnbladigastes": "tunnbladig",
    "tunnbladigasts": "tunnbladig",
    "tunnbladige": "tunnbladig",
    "tunnbladiges": "tunnbladig",
    "tunnbladigs": "tunnbladig",
    "tunnbladigt": "tunnbladig",
    "tunnbladigts": "tunnbladig",
    "tunnbröden": "tunnbröd",
    "tunnbrödens": "tunnbröd",
    "tunnbrödet": "tunnbröd",
    "tunnbrödets": "tunnbröd",
    "tunnbröds": "tunnbröd",
    "tunne": "tunna",
    "tunnelbanan": "tunnelbana",
    "tunnelbanans": "tunnelbana",
    "tunnelbanas": "tunnelbana",
    "tunnelbane": "tunnelbana",
    "tunnelbanebombningar": "tunnelbanebombning",
    "tunnelbanebombningarna": "tunnelbanebombning",
    "tunnelbanebombningarnas": "tunnelbanebombning",
    "tunnelbanebombningars": "tunnelbanebombning",
    "tunnelbanebombningen": "tunnelbanebombning",
    "tunnelbanebombningens": "tunnelbanebombning",
    "tunnelbanebombnings": "tunnelbanebombning",
    "tunnelbanebyggen": "tunnelbanebygge",
    "tunnelbanebyggena": "tunnelbanebygge",
    "tunnelbanebyggenas": "tunnelbanebygge",
    "tunnelbanebyggens": "tunnelbanebygge",
    "tunnelbanebygges": "tunnelbanebygge",
    "tunnelbanebygget": "tunnelbanebygge",
    "tunnelbanebyggets": "tunnelbanebygge",
    "tunnelbanefärden": "tunnelbanefärd",
    "tunnelbanefärdens": "tunnelbanefärd",
    "tunnelbanefärder": "tunnelbanefärd",
    "tunnelbanefärderna": "tunnelbanefärd",
    "tunnelbanefärdernas": "tunnelbanefärd",
    "tunnelbanefärders": "tunnelbanefärd",
    "tunnelbanefärds": "tunnelbanefärd",
    "tunnelbanekiosken": "tunnelbanekiosk",
    "tunnelbanekioskens": "tunnelbanekiosk",
    "tunnelbanekiosker": "tunnelbanekiosk",
    "tunnelbanekioskerna": "tunnelbanekiosk",
    "tunnelbanekioskernas": "tunnelbanekiosk",
    "tunnelbanekioskers": "tunnelbanekiosk",
    "tunnelbanekiosks": "tunnelbanekiosk",
    "tunnelbanestationen": "tunnelbanestation",
    "tunnelbanestationens": "tunnelbanestation",
    "tunnelbanestationer": "tunnelbanestation",
    "tunnelbanestationerna": "tunnelbanestation",
    "tunnelbanestationernas": "tunnelbanestation",
    "tunnelbanestationers": "tunnelbanestation",
    "tunnelbanestations": "tunnelbanestation",
    "tunnelbanor": "tunnelbana",
    "tunnelbanorna": "tunnelbana",
    "tunnelbanornas": "tunnelbana",
    "tunnelbanors": "tunnelbana",
    "tunneldioden": "tunneldiod",
    "tunneldiodens": "tunneldiod",
    "tunneldioder": "tunneldiod",
    "tunneldioderna": "tunneldiod",
    "tunneldiodernas": "tunneldiod",
    "tunneldioders": "tunneldiod",
    "tunneldiods": "tunneldiod",
    "tunneleffekten": "tunneleffekt",
    "tunneleffektens": "tunneleffekt",
    "tunneleffekter": "tunneleffekt",
    "tunneleffekterna": "tunneleffekt",
    "tunneleffekternas": "tunneleffekt",
    "tunneleffekters": "tunneleffekt",
    "tunneleffekts": "tunneleffekt",
    "tunneln": "tunnel",
    "tunnelns": "tunnel",
    "tunnels": "tunnel",
    "tunnelseenden": "tunnelseende",
    "tunnelseendena": "tunnelseende",
    "tunnelseendenas": "tunnelseende",
    "tunnelseendens": "tunnelseende",
    "tunnelseendes": "tunnelseende",
    "tunnelseendet": "tunnelseende",
    "tunnelseendets": "tunnelseende",
    "tunnelugnar": "tunnelugn",
    "tunnelugnarna": "tunnelugn",
    "tunnelugnarnas": "tunnelugn",
    "tunnelugnars": "tunnelugn",
    "tunnelugnen": "tunnelugn",
    "tunnelugnens": "tunnelugn",
    "tunnelugns": "tunnelugn",
    "tunnes": "tunn",
    "tunnheten": "tunnhet",
    "tunnhetens": "tunnhet",
    "tunnhets": "tunnhet",
    "tunnhudade": "tunnhudad",
    "tunnhudades": "tunnhudad",
    "tunnhudads": "tunnhudad",
    "tunnhudat": "tunnhudad",
    "tunnhudats": "tunnhudad",
    "tunnhåriga": "tunnhårig",
    "tunnhårigare": "tunnhårig",
    "tunnhårigares": "tunnhårig",
    "tunnhårigas": "tunnhårig",
    "tunnhårigast": "tunnhårig",
    "tunnhårigaste": "tunnhårig",
    "tunnhårigastes": "tunnhårig",
    "tunnhårigasts": "tunnhårig",
    "tunnhårige": "tunnhårig",
    "tunnhåriges": "tunnhårig",
    "tunnhårigheten": "tunnhårighet",
    "tunnhårighetens": "tunnhårighet",
    "tunnhårighets": "tunnhårighet",
    "tunnhårigs": "tunnhårig",
    "tunnhårigt": "tunnhårig",
    "tunnhårigts": "tunnhårig",
    "tunnklädda": "tunnklädd",
    "tunnkläddare": "tunnklädd",
    "tunnkläddares": "tunnklädd",
    "tunnkläddas": "tunnklädd",
    "tunnkläddast": "tunnklädd",
    "tunnkläddaste": "tunnklädd",
    "tunnkläddastes": "tunnklädd",
    "tunnkläddasts": "tunnklädd",
    "tunnklädde": "tunnklädd",
    "tunnkläddes": "tunnklädd",
    "tunnkläddheten": "tunnkläddhet",
    "tunnkläddhetens": "tunnkläddhet",
    "tunnkläddhets": "tunnkläddhet",
    "tunnklädds": "tunnklädd",
    "tunnklätt": "tunnklädd",
    "tunnklätts": "tunnklädd",
    "tunnlanden": "tunnland",
    "tunnlandens": "tunnland",
    "tunnlandet": "tunnland",
    "tunnlandets": "tunnland",
    "tunnlands": "tunnland",
    "tunnlar": "tunnel",
    "tunnlarna": "tunnel",
    "tunnlarnas": "tunnel",
    "tunnlars": "tunnel",
    "tunnor": "tunna",
    "tunnorna": "tunna",
    "tunnornas": "tunna",
    "tunnors": "tunna",
    "tunnpannkak": "tunnpannkaka",
    "tunnpannkakan": "tunnpannkaka",
    "tunnpannkakans": "tunnpannkaka",
    "tunnpannkakas": "tunnpannkaka",
    "tunnpannkake": "tunnpannkaka",
    "tunnpannkakor": "tunnpannkaka",
    "tunnpannkakorna": "tunnpannkaka",
    "tunnpannkakornas": "tunnpannkaka",
    "tunnpannkakors": "tunnpannkaka",
    "tunnpannkaks": "tunnpannkaka",
    "tunnplåten": "tunnplåt",
    "tunnplåtens": "tunnplåt",
    "tunnplåts": "tunnplåt",
    "tunns": "tunna",
    "tunnslitens": "tunnsliten",
    "tunnslitet": "tunnsliten",
    "tunnslitets": "tunnsliten",
    "tunnslitna": "tunnsliten",
    "tunnslitnare": "tunnsliten",
    "tunnslitnares": "tunnsliten",
    "tunnslitnas": "tunnsliten",
    "tunnslitnast": "tunnsliten",
    "tunnslitnaste": "tunnsliten",
    "tunnslitnastes": "tunnsliten",
    "tunnslitnasts": "tunnsliten",
    "tunnslitne": "tunnsliten",
    "tunnslitnes": "tunnsliten",
    "tunnstavar": "tunnstav",
    "tunnstavarna": "tunnstav",
    "tunnstavarnas": "tunnstav",
    "tunnstavars": "tunnstav",
    "tunnstaven": "tunnstav",
    "tunnstavens": "tunnstav",
    "tunnstavs": "tunnstav",
    "tunnsådda": "tunnsådd",
    "tunnsåddare": "tunnsådd",
    "tunnsåddares": "tunnsådd",
    "tunnsåddas": "tunnsådd",
    "tunnsåddast": "tunnsådd",
    "tunnsåddaste": "tunnsådd",
    "tunnsåddastes": "tunnsådd",
    "tunnsåddasts": "tunnsådd",
    "tunnsådde": "tunnsådd",
    "tunnsåddes": "tunnsådd",
    "tunnsåddheten": "tunnsåddhet",
    "tunnsåddhetens": "tunnsåddhet",
    "tunnsåddhets": "tunnsåddhet",
    "tunnsådds": "tunnsådd",
    "tunnsått": "tunnsådd",
    "tunnsåtts": "tunnsådd",
    "tunntarmar": "tunntarm",
    "tunntarmarna": "tunntarm",
    "tunntarmarnas": "tunntarm",
    "tunntarmars": "tunntarm",
    "tunntarmen": "tunntarm",
    "tunntarmens": "tunntarm",
    "tunntarms": "tunntarm",
    "tunnvalven": "tunnvalv",
    "tunnvalvens": "tunnvalv",
    "tunnvalvet": "tunnvalv",
    "tunnvalvets": "tunnvalv",
    "tunnvalvs": "tunnvalv",
    "tuns": "tun",
    "tunt": "tunn",
    "tunts": "tunn",
    "tuperad": "tupera",
    "tuperade": "tupera",
    "tuperades": "tupera",
    "tuperads": "tupera",
    "tuperande": "tupera",
    "tuperanden": "tuperande",
    "tuperandena": "tuperande",
    "tuperandenas": "tuperande",
    "tuperandens": "tuperande",
    "tuperandes": "tuperande",
    "tuperandet": "tuperande",
    "tuperandets": "tuperande",
    "tuperar": "tupera",
    "tuperas": "tupera",
    "tuperat": "tupera",
    "tuperats": "tupera",
    "tuperbara": "tuperbar",
    "tuperbarare": "tuperbar",
    "tuperbarares": "tuperbar",
    "tuperbaras": "tuperbar",
    "tuperbarast": "tuperbar",
    "tuperbaraste": "tuperbar",
    "tuperbarastes": "tuperbar",
    "tuperbarasts": "tuperbar",
    "tuperbare": "tuperbar",
    "tuperbares": "tuperbar",
    "tuperbarheten": "tuperbarhet",
    "tuperbarhetens": "tuperbarhet",
    "tuperbarhets": "tuperbarhet",
    "tuperbars": "tuperbar",
    "tuperbart": "tuperbar",
    "tuperbarts": "tuperbar",
    "tuperingar": "tupering",
    "tuperingarna": "tupering",
    "tuperingarnas": "tupering",
    "tuperingars": "tupering",
    "tuperingen": "tupering",
    "tuperingens": "tupering",
    "tuperings": "tupering",
    "tuppar": "tupp",
    "tupparna": "tupp",
    "tupparnas": "tupp",
    "tuppars": "tupp",
    "tuppen": "tupp",
    "tuppens": "tupp",
    "tuppfjäten": "tuppfjät",
    "tuppfjätens": "tuppfjät",
    "tuppfjätet": "tuppfjät",
    "tuppfjätets": "tuppfjät",
    "tuppfjäts": "tuppfjät",
    "tuppfäktningar": "tuppfäktning",
    "tuppfäktningarna": "tuppfäktning",
    "tuppfäktningarnas": "tuppfäktning",
    "tuppfäktningars": "tuppfäktning",
    "tuppfäktningen": "tuppfäktning",
    "tuppfäktningens": "tuppfäktning",
    "tuppfäktnings": "tuppfäktning",
    "tuppjucken": "tuppjuck",
    "tuppjuckens": "tuppjuck",
    "tuppjucket": "tuppjuck",
    "tuppjuckets": "tuppjuck",
    "tuppjucks": "tuppjuck",
    "tuppkammar": "tuppkam",
    "tuppkammarna": "tuppkam",
    "tuppkammarnas": "tuppkam",
    "tuppkammars": "tuppkam",
    "tuppkammen": "tuppkam",
    "tuppkammens": "tuppkam",
    "tuppkams": "tuppkam",
    "tuppkycklingar": "tuppkyckling",
    "tuppkycklingarna": "tuppkyckling",
    "tuppkycklingarnas": "tuppkyckling",
    "tuppkycklingars": "tuppkyckling",
    "tuppkycklingen": "tuppkyckling",
    "tuppkycklingens": "tuppkyckling",
    "tuppkycklings": "tuppkyckling",
    "tupplurar": "tupplur",
    "tupplurarna": "tupplur",
    "tupplurarnas": "tupplur",
    "tupplurars": "tupplur",
    "tuppluren": "tupplur",
    "tupplurens": "tupplur",
    "tupplurs": "tupplur",
    "tupps": "tupp",
    "tupéer": "tupé",
    "tupéerna": "tupé",
    "tupéernas": "tupé",
    "tupéers": "tupé",
    "tupén": "tupé",
    "tupéns": "tupé",
    "tupés": "tupé",
    "turbanen": "turban",
    "turbanens": "turban",
    "turbaner": "turban",
    "turbanerna": "turban",
    "turbanernas": "turban",
    "turbaners": "turban",
    "turbans": "turban",
    "turbinen": "turbin",
    "turbinens": "turbin",
    "turbiner": "turbin",
    "turbinerna": "turbin",
    "turbinernas": "turbin",
    "turbiners": "turbin",
    "turbinlagerna": "turbinlager",
    "turbinlagernas": "turbinlager",
    "turbinlagers": "turbinlager",
    "turbinlagren": "turbinlager",
    "turbinlagrens": "turbinlager",
    "turbinlagret": "turbinlager",
    "turbinlagrets": "turbinlager",
    "turbinmotorer": "turbinmotor",
    "turbinmotorerna": "turbinmotor",
    "turbinmotorernas": "turbinmotor",
    "turbinmotorers": "turbinmotor",
    "turbinmotorn": "turbinmotor",
    "turbinmotorns": "turbinmotor",
    "turbinmotors": "turbinmotor",
    "turbins": "turbin",
    "turbojetmotorer": "turbojetmotor",
    "turbojetmotorerna": "turbojetmotor",
    "turbojetmotorernas": "turbojetmotor",
    "turbojetmotorers": "turbojetmotor",
    "turbojetmotorn": "turbojetmotor",
    "turbojetmotorns": "turbojetmotor",
    "turbojetmotors": "turbojetmotor",
    "turbojetplanen": "turbojetplan",
    "turbojetplanens": "turbojetplan",
    "turbojetplanet": "turbojetplan",
    "turbojetplanets": "turbojetplan",
    "turbojetplans": "turbojetplan",
    "turbomotorer": "turbomotor",
    "turbomotorerna": "turbomotor",
    "turbomotorernas": "turbomotor",
    "turbomotorers": "turbomotor",
    "turbomotorn": "turbomotor",
    "turbomotorns": "turbomotor",
    "turbomotors": "turbomotor",
    "turbopropmotorer": "turbopropmotor",
    "turbopropmotorerna": "turbopropmotor",
    "turbopropmotorernas": "turbopropmotor",
    "turbopropmotorers": "turbopropmotor",
    "turbopropmotorn": "turbopropmotor",
    "turbopropmotorns": "turbopropmotor",
    "turbopropmotors": "turbopropmotor",
    "turbulensen": "turbulens",
    "turbulensens": "turbulens",
    "turbulenta": "turbulent",
    "turbulentare": "turbulent",
    "turbulentares": "turbulent",
    "turbulentas": "turbulent",
    "turbulentast": "turbulent",
    "turbulentaste": "turbulent",
    "turbulentastes": "turbulent",
    "turbulentasts": "turbulent",
    "turbulente": "turbulent",
    "turbulentes": "turbulent",
    "turbulents": "turbulent",
    "turen": "tur",
    "turens": "tur",
    "turer": "tur",
    "turerna": "tur",
    "turernas": "tur",
    "turers": "tur",
    "turfen": "turf",
    "turfens": "turf",
    "turfs": "turf",
    "turismen": "turism",
    "turismens": "turism",
    "turismer": "turism",
    "turismerna": "turism",
    "turismernas": "turism",
    "turismers": "turism",
    "turisms": "turism",
    "turist": "turista",
    "turistad": "turista",
    "turistade": "turista",
    "turistades": "turista",
    "turistads": "turista",
    "turistande": "turista",
    "turistanden": "turistande",
    "turistandena": "turistande",
    "turistandenas": "turistande",
    "turistandens": "turistande",
    "turistandes": "turistande",
    "turistandet": "turistande",
    "turistandets": "turistande",
    "turistar": "turista",
    "turistas": "turista",
    "turistat": "turista",
    "turistats": "turista",
    "turistbroschyren": "turistbroschyr",
    "turistbroschyrens": "turistbroschyr",
    "turistbroschyrer": "turistbroschyr",
    "turistbroschyrerna": "turistbroschyr",
    "turistbroschyrernas": "turistbroschyr",
    "turistbroschyrers": "turistbroschyr",
    "turistbroschyrs": "turistbroschyr",
    "turistbyråer": "turistbyrå",
    "turistbyråerna": "turistbyrå",
    "turistbyråernas": "turistbyrå",
    "turistbyråers": "turistbyrå",
    "turistbyrån": "turistbyrå",
    "turistbyråns": "turistbyrå",
    "turistbyrås": "turistbyrå",
    "turisten": "turist",
    "turistens": "turist",
    "turister": "turist",
    "turisterna": "turist",
    "turisternas": "turist",
    "turisters": "turist",
    "turistföreningar": "turistförening",
    "turistföreningarna": "turistförening",
    "turistföreningarnas": "turistförening",
    "turistföreningars": "turistförening",
    "turistföreningen": "turistförening",
    "turistföreningens": "turistförening",
    "turistförenings": "turistförening",
    "turisthandboken": "turisthandbok",
    "turisthandbokens": "turisthandbok",
    "turisthandboks": "turisthandbok",
    "turisthandböcker": "turisthandbok",
    "turisthandböckerna": "turisthandbok",
    "turisthandböckernas": "turisthandbok",
    "turisthandböckers": "turisthandbok",
    "turistinformationen": "turistinformation",
    "turistinformationens": "turistinformation",
    "turistinformationer": "turistinformation",
    "turistinformationerna": "turistinformation",
    "turistinformationernas": "turistinformation",
    "turistinformationers": "turistinformation",
    "turistinformations": "turistinformation",
    "turistiska": "turistisk",
    "turistiskare": "turistisk",
    "turistiskares": "turistisk",
    "turistiskas": "turistisk",
    "turistiskast": "turistisk",
    "turistiskaste": "turistisk",
    "turistiskastes": "turistisk",
    "turistiskasts": "turistisk",
    "turistiske": "turistisk",
    "turistiskes": "turistisk",
    "turistisks": "turistisk",
    "turistiskt": "turistisk",
    "turistiskts": "turistisk",
    "turistklassen": "turistklass",
    "turistklassens": "turistklass",
    "turistklasser": "turistklass",
    "turistklasserna": "turistklass",
    "turistklassernas": "turistklass",
    "turistklassers": "turistklass",
    "turistlandet": "turistland",
    "turistlandets": "turistland",
    "turistlands": "turistland",
    "turistländer": "turistland",
    "turistländerna": "turistland",
    "turistländernas": "turistland",
    "turistländers": "turistland",
    "turistmässiga": "turistmässig",
    "turistmässigare": "turistmässig",
    "turistmässigares": "turistmässig",
    "turistmässigas": "turistmässig",
    "turistmässigast": "turistmässig",
    "turistmässigaste": "turistmässig",
    "turistmässigastes": "turistmässig",
    "turistmässigasts": "turistmässig",
    "turistmässige": "turistmässig",
    "turistmässiges": "turistmässig",
    "turistmässigs": "turistmässig",
    "turistmässigt": "turistmässig",
    "turistmässigts": "turistmässig",
    "turistnäringar": "turistnäring",
    "turistnäringarna": "turistnäring",
    "turistnäringarnas": "turistnäring",
    "turistnäringars": "turistnäring",
    "turistnäringen": "turistnäring",
    "turistnäringens": "turistnäring",
    "turistnärings": "turistnäring",
    "turists": "turist",
    "turiststationen": "turiststation",
    "turiststationens": "turiststation",
    "turiststationer": "turiststation",
    "turiststationerna": "turiststation",
    "turiststationernas": "turiststation",
    "turiststationers": "turiststation",
    "turiststations": "turiststation",
    "turistströmmar": "turistström",
    "turistströmmarna": "turistström",
    "turistströmmarnas": "turistström",
    "turistströmmars": "turistström",
    "turistströmmen": "turistström",
    "turistströmmens": "turistström",
    "turistströms": "turistström",
    "turiststugan": "turiststuga",
    "turiststugans": "turiststuga",
    "turiststugas": "turiststuga",
    "turiststuge": "turiststuga",
    "turiststugor": "turiststuga",
    "turiststugorna": "turiststuga",
    "turiststugornas": "turiststuga",
    "turiststugors": "turiststuga",
    "turiststugu": "turiststuga",
    "turistsängar": "turistsäng",
    "turistsängarna": "turistsäng",
    "turistsängarnas": "turistsäng",
    "turistsängars": "turistsäng",
    "turistsängen": "turistsäng",
    "turistsängens": "turistsäng",
    "turistsängs": "turistsäng",
    "turisttäta": "turisttät",
    "turisttätare": "turisttät",
    "turisttätares": "turisttät",
    "turisttätas": "turisttät",
    "turisttätast": "turisttät",
    "turisttätaste": "turisttät",
    "turisttätastes": "turisttät",
    "turisttätasts": "turisttät",
    "turisttäte": "turisttät",
    "turisttätes": "turisttät",
    "turisttätheten": "turisttäthet",
    "turisttäthetens": "turisttäthet",
    "turisttäthets": "turisttäthet",
    "turisttäts": "turisttät",
    "turisttätt": "turisttät",
    "turisttätts": "turisttät",
    "turistvalutan": "turistvaluta",
    "turistvalutans": "turistvaluta",
    "turistvalutas": "turistvaluta",
    "turistvalute": "turistvaluta",
    "turistvalutor": "turistvaluta",
    "turistvalutorna": "turistvaluta",
    "turistvalutornas": "turistvaluta",
    "turistvalutors": "turistvaluta",
    "turistöar": "turistö",
    "turistöarna": "turistö",
    "turistöarnas": "turistö",
    "turistöars": "turistö",
    "turistön": "turistö",
    "turistöns": "turistö",
    "turistös": "turistö",
    "turkar": "turk",
    "turkarna": "turk",
    "turkarnas": "turk",
    "turkars": "turk",
    "turkcyprioten": "turkcypriot",
    "turkcypriotens": "turkcypriot",
    "turkcyprioter": "turkcypriot",
    "turkcyprioterna": "turkcypriot",
    "turkcyprioternas": "turkcypriot",
    "turkcyprioters": "turkcypriot",
    "turkcypriots": "turkcypriot",
    "turken": "turk",
    "turkens": "turk",
    "turkfolken": "turkfolk",
    "turkfolkens": "turkfolk",
    "turkfolket": "turkfolk",
    "turkfolkets": "turkfolk",
    "turkfolks": "turkfolk",
    "turkisk": "turkiska",
    "turkiska": "turkisk",
    "turkiskan": "turkiska",
    "turkiskans": "turkiska",
    "turkiskare": "turkisk",
    "turkiskares": "turkisk",
    "turkiskas": "turkiska",
    "turkiskast": "turkisk",
    "turkiskaste": "turkisk",
    "turkiskastes": "turkisk",
    "turkiskasts": "turkisk",
    "turkiske": "turkiska",
    "turkiskes": "turkisk",
    "turkiskor": "turkiska",
    "turkiskorna": "turkiska",
    "turkiskornas": "turkiska",
    "turkiskors": "turkiska",
    "turkisks": "turkisk",
    "turkiskt": "turkisk",
    "turkiskts": "turkisk",
    "turkmenen": "turkmen",
    "turkmenens": "turkmen",
    "turkmener": "turkmen",
    "turkmenerna": "turkmen",
    "turkmenernas": "turkmen",
    "turkmeners": "turkmen",
    "turkmens": "turkmen",
    "turkmensk": "turkmenska",
    "turkmenskan": "turkmenska",
    "turkmenskans": "turkmenska",
    "turkmenskas": "turkmenska",
    "turkmenske": "turkmenska",
    "turkmenskor": "turkmenska",
    "turkmenskorna": "turkmenska",
    "turkmenskornas": "turkmenska",
    "turkmenskors": "turkmenska",
    "turkosa": "turkos",
    "turkosare": "turkos",
    "turkosares": "turkos",
    "turkosas": "turkos",
    "turkosast": "turkos",
    "turkosaste": "turkos",
    "turkosastes": "turkos",
    "turkosasts": "turkos",
    "turkosblåa": "turkosblå",
    "turkosblåare": "turkosblå",
    "turkosblåares": "turkosblå",
    "turkosblåas": "turkosblå",
    "turkosblåast": "turkosblå",
    "turkosblåaste": "turkosblå",
    "turkosblåastes": "turkosblå",
    "turkosblåasts": "turkosblå",
    "turkosblåe": "turkosblå",
    "turkosblåes": "turkosblå",
    "turkosblås": "turkosblå",
    "turkosblått": "turkosblå",
    "turkosblåtts": "turkosblå",
    "turkose": "turkos",
    "turkosen": "turkos",
    "turkosens": "turkos",
    "turkoser": "turkos",
    "turkoserna": "turkos",
    "turkosernas": "turkos",
    "turkosers": "turkos",
    "turkoses": "turkos",
    "turkosfärgade": "turkosfärgad",
    "turkosfärgades": "turkosfärgad",
    "turkosfärgads": "turkosfärgad",
    "turkosfärgat": "turkosfärgad",
    "turkosfärgats": "turkosfärgad",
    "turkost": "turkos",
    "turkosts": "turkos",
    "turks": "turk",
    "turksadeln": "turksadel",
    "turksadelns": "turksadel",
    "turksadels": "turksadel",
    "turliga": "turlig",
    "turligare": "turlig",
    "turligares": "turlig",
    "turligas": "turlig",
    "turligast": "turlig",
    "turligaste": "turlig",
    "turligastes": "turlig",
    "turligasts": "turlig",
    "turlige": "turlig",
    "turliges": "turlig",
    "turligheten": "turlighet",
    "turlighetens": "turlighet",
    "turlighets": "turlighet",
    "turligs": "turlig",
    "turligt": "turlig",
    "turligts": "turlig",
    "turlistan": "turlista",
    "turlistans": "turlista",
    "turlistas": "turlista",
    "turliste": "turlista",
    "turlistor": "turlista",
    "turlistorna": "turlista",
    "turlistornas": "turlista",
    "turlistors": "turlista",
    "turmalinen": "turmalin",
    "turmalinens": "turmalin",
    "turmaliner": "turmalin",
    "turmalinerna": "turmalin",
    "turmalinernas": "turmalin",
    "turmaliners": "turmalin",
    "turmalins": "turmalin",
    "turnerad": "turnera",
    "turnerade": "turnera",
    "turnerades": "turnera",
    "turnerads": "turnera",
    "turnerande": "turnera",
    "turneranden": "turnerande",
    "turnerandena": "turnerande",
    "turnerandenas": "turnerande",
    "turnerandens": "turnerande",
    "turnerandes": "turnerande",
    "turnerandet": "turnerande",
    "turnerandets": "turnerande",
    "turnerar": "turnera",
    "turneras": "turnera",
    "turnerat": "turnera",
    "turnerats": "turnera",
    "turnerbara": "turnerbar",
    "turnerbarare": "turnerbar",
    "turnerbarares": "turnerbar",
    "turnerbaras": "turnerbar",
    "turnerbarast": "turnerbar",
    "turnerbaraste": "turnerbar",
    "turnerbarastes": "turnerbar",
    "turnerbarasts": "turnerbar",
    "turnerbare": "turnerbar",
    "turnerbares": "turnerbar",
    "turnerbarheten": "turnerbarhet",
    "turnerbarhetens": "turnerbarhet",
    "turnerbarhets": "turnerbarhet",
    "turnerbars": "turnerbar",
    "turnerbart": "turnerbar",
    "turnerbarts": "turnerbar",
    "turneringar": "turnering",
    "turneringarna": "turnering",
    "turneringarnas": "turnering",
    "turneringars": "turnering",
    "turneringen": "turnering",
    "turneringens": "turnering",
    "turnerings": "turnering",
    "turnyren": "turnyr",
    "turnyrens": "turnyr",
    "turnyrer": "turnyr",
    "turnyrerna": "turnyr",
    "turnyrernas": "turnyr",
    "turnyrers": "turnyr",
    "turnyrs": "turnyr",
    "turnébussar": "turnébuss",
    "turnébussarna": "turnébuss",
    "turnébussarnas": "turnébuss",
    "turnébussars": "turnébuss",
    "turnébussen": "turnébuss",
    "turnébussens": "turnébuss",
    "turnéer": "turné",
    "turnéerna": "turné",
    "turnéernas": "turné",
    "turnéers": "turné",
    "turnén": "turné",
    "turnéns": "turné",
    "turnés": "turné",
    "turochreturbiljetten": "turochreturbiljett",
    "turochreturbiljettens": "turochreturbiljett",
    "turochreturbiljetter": "turochreturbiljett",
    "turochreturbiljetterna": "turochreturbiljett",
    "turochreturbiljetternas": "turochreturbiljett",
    "turochreturbiljetters": "turochreturbiljett",
    "turochreturbiljetts": "turochreturbiljett",
    "turordningar": "turordning",
    "turordningarna": "turordning",
    "turordningarnas": "turordning",
    "turordningars": "turordning",
    "turordningen": "turordning",
    "turordningens": "turordning",
    "turordnings": "turordning",
    "turordningsregeln": "turordningsregel",
    "turordningsregelns": "turordningsregel",
    "turordningsregels": "turordningsregel",
    "turordningsregler": "turordningsregel",
    "turordningsreglerna": "turordningsregel",
    "turordningsreglernas": "turordningsregel",
    "turordningsreglers": "turordningsregel",
    "turs": "tur",
    "tursamheten": "tursamhet",
    "tursamhetens": "tursamhet",
    "tursamhets": "tursamhet",
    "tursamma": "tursam",
    "tursammare": "tursam",
    "tursammares": "tursam",
    "tursammas": "tursam",
    "tursammast": "tursam",
    "tursammaste": "tursam",
    "tursammastes": "tursam",
    "tursammasts": "tursam",
    "tursamme": "tursam",
    "tursammes": "tursam",
    "tursams": "tursam",
    "tursamt": "tursam",
    "tursamts": "tursam",
    "tursar": "turs",
    "tursarna": "turs",
    "tursarnas": "turs",
    "tursars": "turs",
    "tursen": "turs",
    "tursens": "turs",
    "turturduv": "turturduva",
    "turturduvan": "turturduva",
    "turturduvans": "turturduva",
    "turturduvas": "turturduva",
    "turturduve": "turturduva",
    "turturduvor": "turturduva",
    "turturduvorna": "turturduva",
    "turturduvornas": "turturduva",
    "turturduvors": "turturduva",
    "turturduvs": "turturduva",
    "tus": "tu",
    "tusans": "tusan",
    "tusch": "tuscha",
    "tuschad": "tuscha",
    "tuschade": "tuscha",
    "tuschades": "tuscha",
    "tuschads": "tuscha",
    "tuschande": "tuscha",
    "tuschanden": "tuschande",
    "tuschandena": "tuschande",
    "tuschandenas": "tuschande",
    "tuschandens": "tuschande",
    "tuschandes": "tuschande",
    "tuschandet": "tuschande",
    "tuschandets": "tuschande",
    "tuschar": "tuscha",
    "tuschas": "tuscha",
    "tuschat": "tuscha",
    "tuschats": "tuscha",
    "tuschen": "tusch",
    "tuschens": "tusch",
    "tuscherad": "tuschera",
    "tuscherade": "tuschera",
    "tuscherades": "tuschera",
    "tuscherads": "tuschera",
    "tuscherande": "tuschera",
    "tuscheranden": "tuscherande",
    "tuscherandena": "tuscherande",
    "tuscherandenas": "tuscherande",
    "tuscherandens": "tuscherande",
    "tuscherandes": "tuscherande",
    "tuscherandet": "tuscherande",
    "tuscherandets": "tuscherande",
    "tuscherar": "tuschera",
    "tuscheras": "tuschera",
    "tuscherat": "tuschera",
    "tuscherats": "tuschera",
    "tuscherbara": "tuscherbar",
    "tuscherbarare": "tuscherbar",
    "tuscherbarares": "tuscherbar",
    "tuscherbaras": "tuscherbar",
    "tuscherbarast": "tuscherbar",
    "tuscherbaraste": "tuscherbar",
    "tuscherbarastes": "tuscherbar",
    "tuscherbarasts": "tuscherbar",
    "tuscherbare": "tuscherbar",
    "tuscherbares": "tuscherbar",
    "tuscherbarheten": "tuscherbarhet",
    "tuscherbarhetens": "tuscherbarhet",
    "tuscherbarhets": "tuscherbarhet",
    "tuscherbars": "tuscherbar",
    "tuscherbart": "tuscherbar",
    "tuscherbarts": "tuscherbar",
    "tuscheringar": "tuschering",
    "tuscheringarna": "tuschering",
    "tuscheringarnas": "tuschering",
    "tuscheringars": "tuschering",
    "tuscheringen": "tuschering",
    "tuscheringens": "tuschering",
    "tuscherings": "tuschering",
    "tuschet": "tusch",
    "tuschets": "tusch",
    "tuschpenn": "tuschpenna",
    "tuschpennan": "tuschpenna",
    "tuschpennans": "tuschpenna",
    "tuschpennas": "tuschpenna",
    "tuschpenne": "tuschpenna",
    "tuschpennor": "tuschpenna",
    "tuschpennorna": "tuschpenna",
    "tuschpennornas": "tuschpenna",
    "tuschpennors": "tuschpenna",
    "tuschpenns": "tuschpenna",
    "tuschs": "tusch",
    "tuschteckningar": "tuschteckning",
    "tuschteckningarna": "tuschteckning",
    "tuschteckningarnas": "tuschteckning",
    "tuschteckningars": "tuschteckning",
    "tuschteckningen": "tuschteckning",
    "tuschteckningens": "tuschteckning",
    "tuschtecknings": "tuschteckning",
    "tusenbladstårt": "tusenbladstårta",
    "tusenbladstårtan": "tusenbladstårta",
    "tusenbladstårtans": "tusenbladstårta",
    "tusenbladstårtas": "tusenbladstårta",
    "tusenbladstårte": "tusenbladstårta",
    "tusenbladstårtor": "tusenbladstårta",
    "tusenbladstårtorna": "tusenbladstårta",
    "tusenbladstårtornas": "tusenbladstårta",
    "tusenbladstårtors": "tusenbladstårta",
    "tusenbladstårts": "tusenbladstårta",
    "tusende": "tusen",
    "tusendedelar": "tusendedel",
    "tusendedelarna": "tusendedel",
    "tusendedelarnas": "tusendedel",
    "tusendedelars": "tusendedel",
    "tusendedelen": "tusendedel",
    "tusendedelens": "tusendedel",
    "tusendedels": "tusendedel",
    "tusendelar": "tusendel",
    "tusendelarna": "tusendel",
    "tusendelarnas": "tusendel",
    "tusendelars": "tusendel",
    "tusendelen": "tusendel",
    "tusendelens": "tusendel",
    "tusendels": "tusendel",
    "tusenden": "tusende",
    "tusendena": "tusende",
    "tusendenas": "tusende",
    "tusendens": "tusende",
    "tusendes": "tusende",
    "tusendet": "tusende",
    "tusendets": "tusende",
    "tusenfotingar": "tusenfoting",
    "tusenfotingarna": "tusenfoting",
    "tusenfotingarnas": "tusenfoting",
    "tusenfotingars": "tusenfoting",
    "tusenfotingen": "tusenfoting",
    "tusenfotingens": "tusenfoting",
    "tusenfotings": "tusenfoting",
    "tusenhövdade": "tusenhövdad",
    "tusenhövdades": "tusenhövdad",
    "tusenhövdads": "tusenhövdad",
    "tusenhövdat": "tusenhövdad",
    "tusenhövdats": "tusenhövdad",
    "tusenkonstnären": "tusenkonstnär",
    "tusenkonstnärens": "tusenkonstnär",
    "tusenkonstnärer": "tusenkonstnär",
    "tusenkonstnärerna": "tusenkonstnär",
    "tusenkonstnärernas": "tusenkonstnär",
    "tusenkonstnärers": "tusenkonstnär",
    "tusenkonstnärs": "tusenkonstnär",
    "tusenkronorssedeln": "tusenkronorssedel",
    "tusenkronorssedelns": "tusenkronorssedel",
    "tusenkronorssedels": "tusenkronorssedel",
    "tusenkronorssedlar": "tusenkronorssedel",
    "tusenkronorssedlarna": "tusenkronorssedel",
    "tusenkronorssedlarnas": "tusenkronorssedel",
    "tusenkronorssedlars": "tusenkronorssedel",
    "tusenlappar": "tusenlapp",
    "tusenlapparna": "tusenlapp",
    "tusenlapparnas": "tusenlapp",
    "tusenlappars": "tusenlapp",
    "tusenlappen": "tusenlapp",
    "tusenlappens": "tusenlapp",
    "tusenlapps": "tusenlapp",
    "tusens": "tusen",
    "tusenskön": "tusensköna",
    "tusenskönan": "tusensköna",
    "tusenskönans": "tusensköna",
    "tusenskönas": "tusensköna",
    "tusensköne": "tusensköna",
    "tusenskönor": "tusensköna",
    "tusenskönorna": "tusensköna",
    "tusenskönornas": "tusensköna",
    "tusenskönors": "tusensköna",
    "tusensköns": "tusensköna",
    "tusentalen": "tusental",
    "tusentalens": "tusental",
    "tusentalet": "tusental",
    "tusentalets": "tusental",
    "tusentals": "tusental",
    "tusenåriga": "tusenårig",
    "tusenårigas": "tusenårig",
    "tusenårige": "tusenårig",
    "tusenåriges": "tusenårig",
    "tusenårigs": "tusenårig",
    "tusenårigt": "tusenårig",
    "tusenårigts": "tusenårig",
    "tusenårsriken": "tusenårsrike",
    "tusenårsrikena": "tusenårsrike",
    "tusenårsrikenas": "tusenårsrike",
    "tusenårsrikens": "tusenårsrike",
    "tusenårsrikes": "tusenårsrike",
    "tusenårsriket": "tusenårsrike",
    "tusenårsrikets": "tusenårsrike",
    "tuskafts": "tuskaft",
    "tuss": "tussa",
    "tussad": "tussa",
    "tussade": "tussa",
    "tussades": "tussa",
    "tussads": "tussa",
    "tussande": "tussa",
    "tussanden": "tussande",
    "tussandena": "tussande",
    "tussandenas": "tussande",
    "tussandens": "tussande",
    "tussandes": "tussande",
    "tussandet": "tussande",
    "tussandets": "tussande",
    "tussar": "tussa",
    "tussarna": "tuss",
    "tussarnas": "tuss",
    "tussars": "tuss",
    "tussas": "tussa",
    "tussat": "tussa",
    "tussats": "tussa",
    "tussen": "tuss",
    "tussens": "tuss",
    "tussilagon": "tussilago",
    "tussilagons": "tussilago",
    "tussilagor": "tussilago",
    "tussilagorna": "tussilago",
    "tussilagornas": "tussilago",
    "tussilagors": "tussilago",
    "tussilagos": "tussilago",
    "tut": "tuta",
    "tutade": "tuta",
    "tutades": "tuta",
    "tutan": "tuta",
    "tutande": "tuta",
    "tutanden": "tutande",
    "tutandena": "tutande",
    "tutandenas": "tutande",
    "tutandens": "tutande",
    "tutandes": "tutande",
    "tutandet": "tutande",
    "tutandets": "tutande",
    "tutans": "tuta",
    "tutar": "tuta",
    "tutarna": "tut",
    "tutarnas": "tut",
    "tutars": "tut",
    "tutas": "tuta",
    "tutat": "tuta",
    "tutats": "tuta",
    "tute": "tuta",
    "tuten": "tut",
    "tutens": "tut",
    "tutet": "tut",
    "tutets": "tut",
    "tutingar": "tuting",
    "tutingarna": "tuting",
    "tutingarnas": "tuting",
    "tutingars": "tuting",
    "tutingen": "tuting",
    "tutingens": "tuting",
    "tutings": "tuting",
    "tutor": "tuta",
    "tutorna": "tuta",
    "tutornas": "tuta",
    "tutors": "tuta",
    "tuts": "tuta",
    "tutt": "tutte",
    "tuttan": "tutta",
    "tuttans": "tutta",
    "tuttar": "tutte",
    "tuttarna": "tutte",
    "tuttarnas": "tutte",
    "tuttars": "tutte",
    "tuttas": "tutta",
    "tutte": "tutta",
    "tutten": "tutte",
    "tuttens": "tutte",
    "tuttes": "tutte",
    "tuttifruttin": "tuttifrutti",
    "tuttifruttins": "tuttifrutti",
    "tuttifruttis": "tuttifrutti",
    "tuttin": "tutti",
    "tuttina": "tutti",
    "tuttinas": "tutti",
    "tuttins": "tutti",
    "tuttis": "tutti",
    "tuttit": "tutti",
    "tuttits": "tutti",
    "tuttor": "tutta",
    "tuttorna": "tutta",
    "tuttornas": "tutta",
    "tuttors": "tutta",
    "tutts": "tutte",
    "tuv": "tuva",
    "tuvade": "tuvad",
    "tuvades": "tuvad",
    "tuvads": "tuvad",
    "tuvaluanen": "tuvaluan",
    "tuvaluanens": "tuvaluan",
    "tuvaluaner": "tuvaluan",
    "tuvaluanerna": "tuvaluan",
    "tuvaluanernas": "tuvaluan",
    "tuvaluaners": "tuvaluan",
    "tuvaluans": "tuvaluan",
    "tuvaluansk": "tuvaluanska",
    "tuvaluanska": "tuvaluansk",
    "tuvaluanskan": "tuvaluanska",
    "tuvaluanskans": "tuvaluanska",
    "tuvaluanskare": "tuvaluansk",
    "tuvaluanskares": "tuvaluansk",
    "tuvaluanskas": "tuvaluanska",
    "tuvaluanskast": "tuvaluansk",
    "tuvaluanskaste": "tuvaluansk",
    "tuvaluanskastes": "tuvaluansk",
    "tuvaluanskasts": "tuvaluansk",
    "tuvaluanske": "tuvaluanska",
    "tuvaluanskes": "tuvaluansk",
    "tuvaluanskor": "tuvaluanska",
    "tuvaluanskorna": "tuvaluanska",
    "tuvaluanskornas": "tuvaluanska",
    "tuvaluanskors": "tuvaluanska",
    "tuvaluansks": "tuvaluansk",
    "tuvaluanskt": "tuvaluansk",
    "tuvaluanskts": "tuvaluansk",
    "tuvan": "tuva",
    "tuvans": "tuva",
    "tuvas": "tuva",
    "tuvat": "tuvad",
    "tuvats": "tuvad",
    "tuve": "tuva",
    "tuviga": "tuvig",
    "tuvigare": "tuvig",
    "tuvigares": "tuvig",
    "tuvigas": "tuvig",
    "tuvigast": "tuvig",
    "tuvigaste": "tuvig",
    "tuvigastes": "tuvig",
    "tuvigasts": "tuvig",
    "tuvige": "tuvig",
    "tuviges": "tuvig",
    "tuvigs": "tuvig",
    "tuvigt": "tuvig",
    "tuvigts": "tuvig",
    "tuvor": "tuva",
    "tuvorna": "tuva",
    "tuvornas": "tuva",
    "tuvors": "tuva",
    "tuvs": "tuva",
    "tuvstarren": "tuvstarr",
    "tuvstarrens": "tuvstarr",
    "tuvstarrs": "tuvstarr",
    "tuvtåteln": "tuvtåtel",
    "tuvtåtelns": "tuvtåtel",
    "tuvtåtels": "tuvtåtel",
    "tuvtåtlar": "tuvtåtel",
    "tuvtåtlarna": "tuvtåtel",
    "tuvtåtlarnas": "tuvtåtel",
    "tuvtåtlars": "tuvtåtel",
    "tv-evangelistens": "tv-evangelist",
    "tv-evangelisternas": "tv-evangelist",
    "tv-evangelisters": "tv-evangelist",
    "tv-evangelists": "tv-evangelist",
    "tv-leverantören": "tv-leverantör",
    "tv-leverantörer": "tv-leverantör",
    "tv-leverantörernas": "tv-leverantör",
    "tv-leverantörers": "tv-leverantör",
    "tv-nas": "tv",
    "tv-nyheten": "tv-nyhet",
    "tv-nyheter": "tv-nyhet",
    "tv-nyheternas": "tv-nyhet",
    "tv-nyheters": "tv-nyhet",
    "tv-predikantens": "tv-predikant",
    "tv-predikanternas": "tv-predikant",
    "tv-predikanters": "tv-predikant",
    "tv:n": "tv",
    "tv:ns": "tv",
    "tvag": "tvaga",
    "tvagan": "tvaga",
    "tvagans": "tvaga",
    "tvagas": "tvaga",
    "tvage": "tvaga",
    "tvagit": "två",
    "tvagits": "två",
    "tvagningar": "tvagning",
    "tvagningarna": "tvagning",
    "tvagningarnas": "tvagning",
    "tvagningars": "tvagning",
    "tvagningen": "tvagning",
    "tvagningens": "tvagning",
    "tvagnings": "tvagning",
    "tvagor": "tvaga",
    "tvagorna": "tvaga",
    "tvagornas": "tvaga",
    "tvagors": "tvaga",
    "tvags": "tvaga",
    "tvang": "tvinga",
    "tvangs": "tvinga",
    "tvedräkten": "tvedräkt",
    "tvedräktens": "tvedräkt",
    "tvedräkts": "tvedräkt",
    "tveeggade": "tveeggad",
    "tveeggades": "tveeggad",
    "tveeggads": "tveeggad",
    "tveeggat": "tveeggad",
    "tveeggats": "tveeggad",
    "tvegiften": "tvegifte",
    "tvegiftena": "tvegifte",
    "tvegiftenas": "tvegifte",
    "tvegiftens": "tvegifte",
    "tvegiftes": "tvegifte",
    "tvegiftet": "tvegifte",
    "tvegiftets": "tvegifte",
    "tvegifts": "tvegifte",
    "tvehågsens": "tvehågsen",
    "tvehågset": "tvehågsen",
    "tvehågsets": "tvehågsen",
    "tvehågsna": "tvehågsen",
    "tvehågsnare": "tvehågsen",
    "tvehågsnares": "tvehågsen",
    "tvehågsnas": "tvehågsen",
    "tvehågsnast": "tvehågsen",
    "tvehågsnaste": "tvehågsen",
    "tvehågsnastes": "tvehågsen",
    "tvehågsnasts": "tvehågsen",
    "tvehågsne": "tvehågsen",
    "tvehågsnes": "tvehågsen",
    "tvehövdade": "tvehövdad",
    "tvehövdades": "tvehövdad",
    "tvehövdads": "tvehövdad",
    "tvehövdat": "tvehövdad",
    "tvehövdats": "tvehövdad",
    "tvek": "tveka",
    "tvekad": "tveka",
    "tvekade": "tveka",
    "tvekades": "tveka",
    "tvekads": "tveka",
    "tvekampen": "tvekamp",
    "tvekampens": "tvekamp",
    "tvekamper": "tvekamp",
    "tvekamperna": "tvekamp",
    "tvekampernas": "tvekamp",
    "tvekampers": "tvekamp",
    "tvekamps": "tvekamp",
    "tvekande": "tveka",
    "tvekanden": "tvekande",
    "tvekandena": "tvekande",
    "tvekandenas": "tvekande",
    "tvekandens": "tvekande",
    "tvekandes": "tvekande",
    "tvekandet": "tvekande",
    "tvekandets": "tvekande",
    "tvekans": "tvekan",
    "tvekar": "tveka",
    "tvekas": "tveka",
    "tvekat": "tveka",
    "tvekats": "tveka",
    "tveklösa": "tveklös",
    "tveklösare": "tveklös",
    "tveklösares": "tveklös",
    "tveklösas": "tveklös",
    "tveklösast": "tveklös",
    "tveklösaste": "tveklös",
    "tveklösastes": "tveklös",
    "tveklösasts": "tveklös",
    "tveklöse": "tveklös",
    "tveklöses": "tveklös",
    "tveklösheten": "tveklöshet",
    "tveklöshetens": "tveklöshet",
    "tveklöshets": "tveklöshet",
    "tveklöst": "tveklös",
    "tveklösts": "tveklös",
    "tveksamheten": "tveksamhet",
    "tveksamhetens": "tveksamhet",
    "tveksamheter": "tveksamhet",
    "tveksamheterna": "tveksamhet",
    "tveksamheternas": "tveksamhet",
    "tveksamheters": "tveksamhet",
    "tveksamhets": "tveksamhet",
    "tveksamma": "tveksam",
    "tveksammare": "tveksam",
    "tveksammares": "tveksam",
    "tveksammas": "tveksam",
    "tveksammast": "tveksam",
    "tveksammaste": "tveksam",
    "tveksammastes": "tveksam",
    "tveksammasts": "tveksam",
    "tveksamme": "tveksam",
    "tveksammes": "tveksam",
    "tveksams": "tveksam",
    "tveksamt": "tveksam",
    "tveksamts": "tveksam",
    "tvennes": "tvenne",
    "tvesalus": "tvesalu",
    "tvestjärtar": "tvestjärt",
    "tvestjärtarna": "tvestjärt",
    "tvestjärtarnas": "tvestjärt",
    "tvestjärtars": "tvestjärt",
    "tvestjärten": "tvestjärt",
    "tvestjärtens": "tvestjärt",
    "tvestjärts": "tvestjärt",
    "tvetalans": "tvetalan",
    "tvetydiga": "tvetydig",
    "tvetydigare": "tvetydig",
    "tvetydigares": "tvetydig",
    "tvetydigas": "tvetydig",
    "tvetydigast": "tvetydig",
    "tvetydigaste": "tvetydig",
    "tvetydigastes": "tvetydig",
    "tvetydigasts": "tvetydig",
    "tvetydige": "tvetydig",
    "tvetydiges": "tvetydig",
    "tvetydigheten": "tvetydighet",
    "tvetydighetens": "tvetydighet",
    "tvetydigheter": "tvetydighet",
    "tvetydigheterna": "tvetydighet",
    "tvetydigheternas": "tvetydighet",
    "tvetydigheters": "tvetydighet",
    "tvetydighets": "tvetydighet",
    "tvetydigs": "tvetydig",
    "tvetydigt": "tvetydig",
    "tvetydigts": "tvetydig",
    "tvillingar": "tvilling",
    "tvillingarna": "tvilling",
    "tvillingarnas": "tvilling",
    "tvillingars": "tvilling",
    "tvillingen": "tvilling",
    "tvillingens": "tvilling",
    "tvillingflick": "tvillingflicka",
    "tvillingflickan": "tvillingflicka",
    "tvillingflickans": "tvillingflicka",
    "tvillingflickas": "tvillingflicka",
    "tvillingflicke": "tvillingflicka",
    "tvillingflickor": "tvillingflicka",
    "tvillingflickorna": "tvillingflicka",
    "tvillingflickornas": "tvillingflicka",
    "tvillingflickors": "tvillingflicka",
    "tvillingflicks": "tvillingflicka",
    "tvillingkristallen": "tvillingkristall",
    "tvillingkristallens": "tvillingkristall",
    "tvillingkristaller": "tvillingkristall",
    "tvillingkristallerna": "tvillingkristall",
    "tvillingkristallernas": "tvillingkristall",
    "tvillingkristallers": "tvillingkristall",
    "tvillingkristalls": "tvillingkristall",
    "tvillingkärn": "tvillingkärna",
    "tvillingkärnan": "tvillingkärna",
    "tvillingkärnans": "tvillingkärna",
    "tvillingkärnas": "tvillingkärna",
    "tvillingkärne": "tvillingkärna",
    "tvillingkärnor": "tvillingkärna",
    "tvillingkärnorna": "tvillingkärna",
    "tvillingkärnornas": "tvillingkärna",
    "tvillingkärnors": "tvillingkärna",
    "tvillingkärns": "tvillingkärna",
    "tvillingmaskinen": "tvillingmaskin",
    "tvillingmaskinens": "tvillingmaskin",
    "tvillingmaskiner": "tvillingmaskin",
    "tvillingmaskinerna": "tvillingmaskin",
    "tvillingmaskinernas": "tvillingmaskin",
    "tvillingmaskiners": "tvillingmaskin",
    "tvillingmaskins": "tvillingmaskin",
    "tvillings": "tvilling",
    "tvillingstjärnan": "tvillingstjärna",
    "tvillingstjärnans": "tvillingstjärna",
    "tvillingstjärnas": "tvillingstjärna",
    "tvillingstjärne": "tvillingstjärna",
    "tvillingstjärnor": "tvillingstjärna",
    "tvillingstjärnorna": "tvillingstjärna",
    "tvillingstjärnornas": "tvillingstjärna",
    "tvillingstjärnors": "tvillingstjärna",
    "tvillingsystern": "tvillingsyster",
    "tvillingsysterns": "tvillingsyster",
    "tvillingsysters": "tvillingsyster",
    "tvillingsystrar": "tvillingsyster",
    "tvillingsystrarna": "tvillingsyster",
    "tvillingsystrarnas": "tvillingsyster",
    "tvillingsystrars": "tvillingsyster",
    "tvillingvagnar": "tvillingvagn",
    "tvillingvagnarna": "tvillingvagn",
    "tvillingvagnarnas": "tvillingvagn",
    "tvillingvagnars": "tvillingvagn",
    "tvillingvagnen": "tvillingvagn",
    "tvillingvagnens": "tvillingvagn",
    "tvillingvagns": "tvillingvagn",
    "tvillsen": "tvills",
    "tvillsens": "tvills",
    "tvin": "tvina",
    "tvinad": "tvina",
    "tvinade": "tvina",
    "tvinades": "tvina",
    "tvinads": "tvina",
    "tvinande": "tvina",
    "tvinanden": "tvinande",
    "tvinandena": "tvinande",
    "tvinandenas": "tvinande",
    "tvinandens": "tvinande",
    "tvinandes": "tvinande",
    "tvinandet": "tvinande",
    "tvinandets": "tvinande",
    "tvinar": "tvina",
    "tvinas": "tvina",
    "tvinat": "tvina",
    "tvinats": "tvina",
    "tving": "tvinga",
    "tvingad": "tvinga",
    "tvingade": "tvinga",
    "tvingades": "tvinga",
    "tvingads": "tvinga",
    "tvingande": "tvinga",
    "tvinganden": "tvingande",
    "tvingandena": "tvingande",
    "tvingandenas": "tvingande",
    "tvingandens": "tvingande",
    "tvingandes": "tvingande",
    "tvingandet": "tvingande",
    "tvingandets": "tvingande",
    "tvingar": "tvinga",
    "tvingarna": "tving",
    "tvingarnas": "tving",
    "tvingars": "tving",
    "tvingas": "tvinga",
    "tvingat": "tvinga",
    "tvingats": "tvinga",
    "tvinge": "tvinga",
    "tvingen": "tving",
    "tvingens": "tving",
    "tvinges": "tvinga",
    "tvings": "tving",
    "tvinn": "tvinna",
    "tvinnad": "tvinna",
    "tvinnade": "tvinna",
    "tvinnades": "tvinna",
    "tvinnads": "tvinna",
    "tvinnande": "tvinna",
    "tvinnanden": "tvinnande",
    "tvinnandena": "tvinnande",
    "tvinnandenas": "tvinnande",
    "tvinnandens": "tvinnande",
    "tvinnandes": "tvinnande",
    "tvinnandet": "tvinnande",
    "tvinnandets": "tvinnande",
    "tvinnar": "tvinna",
    "tvinnas": "tvinna",
    "tvinnat": "tvinna",
    "tvinnats": "tvinna",
    "tvinsjuka": "tvinsjuk",
    "tvinsjukare": "tvinsjuk",
    "tvinsjukares": "tvinsjuk",
    "tvinsjukas": "tvinsjuk",
    "tvinsjukast": "tvinsjuk",
    "tvinsjukaste": "tvinsjuk",
    "tvinsjukastes": "tvinsjuk",
    "tvinsjukasts": "tvinsjuk",
    "tvinsjuke": "tvinsjuk",
    "tvinsjukes": "tvinsjuk",
    "tvinsjuks": "tvinsjuk",
    "tvinsjukt": "tvinsjuk",
    "tvinsjukts": "tvinsjuk",
    "tvinsoten": "tvinsot",
    "tvinsotens": "tvinsot",
    "tvinsots": "tvinsot",
    "tvistad": "tvista",
    "tvistade": "tvista",
    "tvistades": "tvista",
    "tvistads": "tvista",
    "tvistande": "tvista",
    "tvistanden": "tvistande",
    "tvistandena": "tvistande",
    "tvistandenas": "tvistande",
    "tvistandens": "tvistande",
    "tvistandes": "tvistande",
    "tvistandet": "tvistande",
    "tvistandets": "tvistande",
    "tvistar": "tvista",
    "tvistas": "tvista",
    "tvistat": "tvista",
    "tvistats": "tvista",
    "tviste": "tvista",
    "tvistefrågan": "tvistefråga",
    "tvistefrågans": "tvistefråga",
    "tvistefrågas": "tvistefråga",
    "tvistefråge": "tvistefråga",
    "tvistefrågor": "tvistefråga",
    "tvistefrågorna": "tvistefråga",
    "tvistefrågornas": "tvistefråga",
    "tvistefrågors": "tvistefråga",
    "tvistefröen": "tvistefrö",
    "tvistefröens": "tvistefrö",
    "tvistefröet": "tvistefrö",
    "tvistefröets": "tvistefrö",
    "tvistefrön": "tvistefrö",
    "tvistefröna": "tvistefrö",
    "tvistefrönas": "tvistefrö",
    "tvistefröns": "tvistefrö",
    "tvistefrös": "tvistefrö",
    "tvistefröt": "tvistefrö",
    "tvistefröts": "tvistefrö",
    "tvistemålen": "tvistemål",
    "tvistemålens": "tvistemål",
    "tvistemålet": "tvistemål",
    "tvistemålets": "tvistemål",
    "tvistemåls": "tvistemål",
    "tvisten": "tvist",
    "tvistens": "tvist",
    "tvister": "tvist",
    "tvisterna": "tvist",
    "tvisternas": "tvist",
    "tvisters": "tvist",
    "tvisteämnen": "tvisteämne",
    "tvisteämnena": "tvisteämne",
    "tvisteämnenas": "tvisteämne",
    "tvisteämnens": "tvisteämne",
    "tvisteämnes": "tvisteämne",
    "tvisteämnet": "tvisteämne",
    "tvisteämnets": "tvisteämne",
    "tvistiga": "tvistig",
    "tvistigare": "tvistig",
    "tvistigares": "tvistig",
    "tvistigas": "tvistig",
    "tvistigast": "tvistig",
    "tvistigaste": "tvistig",
    "tvistigastes": "tvistig",
    "tvistigasts": "tvistig",
    "tvistige": "tvistig",
    "tvistiges": "tvistig",
    "tvistigheten": "tvistighet",
    "tvistighetens": "tvistighet",
    "tvistigheter": "tvistighet",
    "tvistigheterna": "tvistighet",
    "tvistigheternas": "tvistighet",
    "tvistigheters": "tvistighet",
    "tvistighets": "tvistighet",
    "tvistigs": "tvistig",
    "tvistigt": "tvistig",
    "tvistigts": "tvistig",
    "tvists": "tvist",
    "tvistsömmar": "tvistsöm",
    "tvistsömmarna": "tvistsöm",
    "tvistsömmarnas": "tvistsöm",
    "tvistsömmars": "tvistsöm",
    "tvistsömmen": "tvistsöm",
    "tvistsömmens": "tvistsöm",
    "tvistsöms": "tvistsöm",
    "tvivelaktiga": "tvivelaktig",
    "tvivelaktigare": "tvivelaktig",
    "tvivelaktigares": "tvivelaktig",
    "tvivelaktigas": "tvivelaktig",
    "tvivelaktigast": "tvivelaktig",
    "tvivelaktigaste": "tvivelaktig",
    "tvivelaktigastes": "tvivelaktig",
    "tvivelaktigasts": "tvivelaktig",
    "tvivelaktige": "tvivelaktig",
    "tvivelaktiges": "tvivelaktig",
    "tvivelaktigheten": "tvivelaktighet",
    "tvivelaktighetens": "tvivelaktighet",
    "tvivelaktighets": "tvivelaktighet",
    "tvivelaktigs": "tvivelaktig",
    "tvivelaktigt": "tvivelaktig",
    "tvivelaktigts": "tvivelaktig",
    "tvivels": "tvivel",
    "tvivelsamheten": "tvivelsamhet",
    "tvivelsamhetens": "tvivelsamhet",
    "tvivelsamhets": "tvivelsamhet",
    "tvivelsamma": "tvivelsam",
    "tvivelsammare": "tvivelsam",
    "tvivelsammares": "tvivelsam",
    "tvivelsammas": "tvivelsam",
    "tvivelsammast": "tvivelsam",
    "tvivelsammaste": "tvivelsam",
    "tvivelsammastes": "tvivelsam",
    "tvivelsammasts": "tvivelsam",
    "tvivelsamme": "tvivelsam",
    "tvivelsammes": "tvivelsam",
    "tvivelsams": "tvivelsam",
    "tvivelsamt": "tvivelsam",
    "tvivelsamts": "tvivelsam",
    "tvivelsjuka": "tvivelsjuk",
    "tvivelsjukare": "tvivelsjuk",
    "tvivelsjukares": "tvivelsjuk",
    "tvivelsjukas": "tvivelsjuk",
    "tvivelsjukast": "tvivelsjuk",
    "tvivelsjukaste": "tvivelsjuk",
    "tvivelsjukastes": "tvivelsjuk",
    "tvivelsjukasts": "tvivelsjuk",
    "tvivelsjuke": "tvivelsjuk",
    "tvivelsjukes": "tvivelsjuk",
    "tvivelsjukheten": "tvivelsjukhet",
    "tvivelsjukhetens": "tvivelsjukhet",
    "tvivelsjukhets": "tvivelsjukhet",
    "tvivelsjuks": "tvivelsjuk",
    "tvivelsjukt": "tvivelsjuk",
    "tvivelsjukts": "tvivelsjuk",
    "tvivelsmålet": "tvivelsmål",
    "tvivelsmålets": "tvivelsmål",
    "tvivelsmåls": "tvivelsmål",
    "tvivlad": "tvivla",
    "tvivlade": "tvivla",
    "tvivlades": "tvivla",
    "tvivlads": "tvivla",
    "tvivlande": "tvivla",
    "tvivlanden": "tvivlande",
    "tvivlandena": "tvivlande",
    "tvivlandenas": "tvivlande",
    "tvivlandens": "tvivlande",
    "tvivlandes": "tvivlande",
    "tvivlandet": "tvivlande",
    "tvivlandets": "tvivlande",
    "tvivlar": "tvivlare",
    "tvivlaren": "tvivlare",
    "tvivlarens": "tvivlare",
    "tvivlares": "tvivlare",
    "tvivlarna": "tvivlare",
    "tvivlarnas": "tvivlare",
    "tvivlas": "tvivla",
    "tvivlat": "tvivla",
    "tvivlats": "tvivla",
    "tvivlen": "tvivel",
    "tvivlens": "tvivel",
    "tvivlet": "tvivel",
    "tvivlets": "tvivel",
    "tvn": "tv",
    "tvna": "tv",
    "tvns": "tv",
    "tvs": "tv",
    "tvunge": "tvinga",
    "tvungen": "tvinga",
    "tvungens": "tvungen",
    "tvunges": "tvinga",
    "tvunget": "tvungen",
    "tvungets": "tvungen",
    "tvungit": "tvinga",
    "tvungits": "tvinga",
    "tvungna": "tvungen",
    "tvungnare": "tvungen",
    "tvungnares": "tvungen",
    "tvungnas": "tvungen",
    "tvungnast": "tvungen",
    "tvungnaste": "tvungen",
    "tvungnastes": "tvungen",
    "tvungnasts": "tvungen",
    "tvungne": "tvungen",
    "tvungnes": "tvungen",
    "tvär": "tvära",
    "tvära": "tvär",
    "tvärad": "tvära",
    "tvärade": "tvära",
    "tvärades": "tvära",
    "tvärads": "tvära",
    "tvärande": "tvära",
    "tväranden": "tvärande",
    "tvärandena": "tvärande",
    "tvärandenas": "tvärande",
    "tvärandens": "tvärande",
    "tvärandes": "tvärande",
    "tvärandet": "tvärande",
    "tvärandets": "tvärande",
    "tvärar": "tvära",
    "tvärare": "tvär",
    "tvärares": "tvär",
    "tvärarga": "tvärarg",
    "tvärargare": "tvärarg",
    "tvärargares": "tvärarg",
    "tvärargas": "tvärarg",
    "tvärargast": "tvärarg",
    "tvärargaste": "tvärarg",
    "tvärargastes": "tvärarg",
    "tvärargasts": "tvärarg",
    "tvärarge": "tvärarg",
    "tvärarges": "tvärarg",
    "tvärargheten": "tvärarghet",
    "tvärarghetens": "tvärarghet",
    "tvärarghets": "tvärarghet",
    "tvärargs": "tvärarg",
    "tvärargt": "tvärarg",
    "tvärargts": "tvärarg",
    "tväras": "tvära",
    "tvärast": "tvär",
    "tväraste": "tvär",
    "tvärastes": "tvär",
    "tvärasts": "tvär",
    "tvärat": "tvära",
    "tvärats": "tvära",
    "tväraxeln": "tväraxel",
    "tväraxelns": "tväraxel",
    "tväraxels": "tväraxel",
    "tväraxlar": "tväraxel",
    "tväraxlarna": "tväraxel",
    "tväraxlarnas": "tväraxel",
    "tväraxlars": "tväraxel",
    "tvärbalkar": "tvärbalk",
    "tvärbalkarna": "tvärbalk",
    "tvärbalkarnas": "tvärbalk",
    "tvärbalkars": "tvärbalk",
    "tvärbalken": "tvärbalk",
    "tvärbalkens": "tvärbalk",
    "tvärbalks": "tvärbalk",
    "tvärbjälk": "tvärbjälke",
    "tvärbjälkar": "tvärbjälke",
    "tvärbjälkarna": "tvärbjälke",
    "tvärbjälkarnas": "tvärbjälke",
    "tvärbjälkars": "tvärbjälke",
    "tvärbjälken": "tvärbjälke",
    "tvärbjälkens": "tvärbjälke",
    "tvärbjälkes": "tvärbjälke",
    "tvärbjälks": "tvärbjälke",
    "tvärbranta": "tvärbrant",
    "tvärbrantare": "tvärbrant",
    "tvärbrantares": "tvärbrant",
    "tvärbrantas": "tvärbrant",
    "tvärbrantast": "tvärbrant",
    "tvärbrantaste": "tvärbrant",
    "tvärbrantastes": "tvärbrant",
    "tvärbrantasts": "tvärbrant",
    "tvärbrante": "tvärbrant",
    "tvärbrantes": "tvärbrant",
    "tvärbrants": "tvärbrant",
    "tvärbroms": "tvärbromsa",
    "tvärbromsad": "tvärbromsa",
    "tvärbromsade": "tvärbromsa",
    "tvärbromsades": "tvärbromsa",
    "tvärbromsads": "tvärbromsa",
    "tvärbromsande": "tvärbromsa",
    "tvärbromsanden": "tvärbromsande",
    "tvärbromsandena": "tvärbromsande",
    "tvärbromsandenas": "tvärbromsande",
    "tvärbromsandens": "tvärbromsande",
    "tvärbromsandes": "tvärbromsande",
    "tvärbromsandet": "tvärbromsande",
    "tvärbromsandets": "tvärbromsande",
    "tvärbromsar": "tvärbromsa",
    "tvärbromsas": "tvärbromsa",
    "tvärbromsat": "tvärbromsa",
    "tvärbromsats": "tvärbromsa",
    "tvärdraget": "tvärdrag",
    "tvärdragets": "tvärdrag",
    "tvärdrags": "tvärdrag",
    "tväre": "tvär",
    "tväres": "tvär",
    "tvärfackliga": "tvärfacklig",
    "tvärfackligare": "tvärfacklig",
    "tvärfackligares": "tvärfacklig",
    "tvärfackligas": "tvärfacklig",
    "tvärfackligast": "tvärfacklig",
    "tvärfackligaste": "tvärfacklig",
    "tvärfackligastes": "tvärfacklig",
    "tvärfackligasts": "tvärfacklig",
    "tvärfacklige": "tvärfacklig",
    "tvärfackliges": "tvärfacklig",
    "tvärfackligheten": "tvärfacklighet",
    "tvärfacklighetens": "tvärfacklighet",
    "tvärfacklighets": "tvärfacklighet",
    "tvärfackligs": "tvärfacklig",
    "tvärfackligt": "tvärfacklig",
    "tvärfackligts": "tvärfacklig",
    "tvärfakultära": "tvärfakultär",
    "tvärfakultärare": "tvärfakultär",
    "tvärfakultärares": "tvärfakultär",
    "tvärfakultäras": "tvärfakultär",
    "tvärfakultärast": "tvärfakultär",
    "tvärfakultäraste": "tvärfakultär",
    "tvärfakultärastes": "tvärfakultär",
    "tvärfakultärasts": "tvärfakultär",
    "tvärfakultäre": "tvärfakultär",
    "tvärfakultäres": "tvärfakultär",
    "tvärfakultärs": "tvärfakultär",
    "tvärfakultärt": "tvärfakultär",
    "tvärfakultärts": "tvärfakultär",
    "tvärfick": "tvärficka",
    "tvärfickan": "tvärficka",
    "tvärfickans": "tvärficka",
    "tvärfickas": "tvärficka",
    "tvärficke": "tvärficka",
    "tvärfickor": "tvärficka",
    "tvärfickorna": "tvärficka",
    "tvärfickornas": "tvärficka",
    "tvärfickors": "tvärficka",
    "tvärficks": "tvärficka",
    "tvärflöjten": "tvärflöjt",
    "tvärflöjtens": "tvärflöjt",
    "tvärflöjter": "tvärflöjt",
    "tvärflöjterna": "tvärflöjt",
    "tvärflöjternas": "tvärflöjt",
    "tvärflöjters": "tvärflöjt",
    "tvärflöjts": "tvärflöjt",
    "tvärförbannade": "tvärförbannad",
    "tvärförbannades": "tvärförbannad",
    "tvärförbannads": "tvärförbannad",
    "tvärförbannat": "tvärförbannad",
    "tvärförbannats": "tvärförbannad",
    "tvärgat": "tvärgata",
    "tvärgatan": "tvärgata",
    "tvärgatans": "tvärgata",
    "tvärgatas": "tvärgata",
    "tvärgate": "tvärgata",
    "tvärgator": "tvärgata",
    "tvärgatorna": "tvärgata",
    "tvärgatornas": "tvärgata",
    "tvärgators": "tvärgata",
    "tvärgats": "tvärgata",
    "tvärhands": "tvärhand",
    "tvärheten": "tvärhet",
    "tvärhetens": "tvärhet",
    "tvärhets": "tvärhet",
    "tvärhuggens": "tvärhuggen",
    "tvärhugget": "tvärhuggen",
    "tvärhuggets": "tvärhuggen",
    "tvärhuggna": "tvärhuggen",
    "tvärhuggnare": "tvärhuggen",
    "tvärhuggnares": "tvärhuggen",
    "tvärhuggnas": "tvärhuggen",
    "tvärhuggnast": "tvärhuggen",
    "tvärhuggnaste": "tvärhuggen",
    "tvärhuggnastes": "tvärhuggen",
    "tvärhuggnasts": "tvärhuggen",
    "tvärhuggne": "tvärhuggen",
    "tvärhuggnes": "tvärhuggen",
    "tvärilskens": "tvärilsken",
    "tvärilsket": "tvärilsken",
    "tvärilskets": "tvärilsken",
    "tvärilskna": "tvärilsken",
    "tvärilsknare": "tvärilsken",
    "tvärilsknares": "tvärilsken",
    "tvärilsknas": "tvärilsken",
    "tvärilsknast": "tvärilsken",
    "tvärilsknaste": "tvärilsken",
    "tvärilsknastes": "tvärilsken",
    "tvärilsknasts": "tvärilsken",
    "tvärilskne": "tvärilsken",
    "tvärilsknes": "tvärilsken",
    "tvärkulturella": "tvärkulturell",
    "tvärkulturellare": "tvärkulturell",
    "tvärkulturellares": "tvärkulturell",
    "tvärkulturellas": "tvärkulturell",
    "tvärkulturellast": "tvärkulturell",
    "tvärkulturellaste": "tvärkulturell",
    "tvärkulturellastes": "tvärkulturell",
    "tvärkulturellasts": "tvärkulturell",
    "tvärkulturelle": "tvärkulturell",
    "tvärkulturelles": "tvärkulturell",
    "tvärkulturells": "tvärkulturell",
    "tvärkulturellt": "tvärkulturell",
    "tvärkulturellts": "tvärkulturell",
    "tvärmätta": "tvärmätt",
    "tvärmättare": "tvärmätt",
    "tvärmättares": "tvärmätt",
    "tvärmättas": "tvärmätt",
    "tvärmättast": "tvärmätt",
    "tvärmättaste": "tvärmätt",
    "tvärmättastes": "tvärmätt",
    "tvärmättasts": "tvärmätt",
    "tvärmätte": "tvärmätt",
    "tvärmättes": "tvärmätt",
    "tvärmättheten": "tvärmätthet",
    "tvärmätthetens": "tvärmätthet",
    "tvärmätthets": "tvärmätthet",
    "tvärmätts": "tvärmätt",
    "tvärnit": "tvärnita",
    "tvärnitad": "tvärnita",
    "tvärnitade": "tvärnita",
    "tvärnitades": "tvärnita",
    "tvärnitads": "tvärnita",
    "tvärnitande": "tvärnita",
    "tvärnitanden": "tvärnitande",
    "tvärnitandena": "tvärnitande",
    "tvärnitandenas": "tvärnitande",
    "tvärnitandens": "tvärnitande",
    "tvärnitandes": "tvärnitande",
    "tvärnitandet": "tvärnitande",
    "tvärnitandets": "tvärnitande",
    "tvärnitar": "tvärnita",
    "tvärnitarna": "tvärnit",
    "tvärnitarnas": "tvärnit",
    "tvärnitars": "tvärnit",
    "tvärnitas": "tvärnita",
    "tvärnitat": "tvärnita",
    "tvärnitats": "tvärnita",
    "tvärniten": "tvärnit",
    "tvärnitens": "tvärnit",
    "tvärnits": "tvärnit",
    "tvärpolitiska": "tvärpolitisk",
    "tvärpolitiskare": "tvärpolitisk",
    "tvärpolitiskares": "tvärpolitisk",
    "tvärpolitiskas": "tvärpolitisk",
    "tvärpolitiskast": "tvärpolitisk",
    "tvärpolitiskaste": "tvärpolitisk",
    "tvärpolitiskastes": "tvärpolitisk",
    "tvärpolitiskasts": "tvärpolitisk",
    "tvärpolitiske": "tvärpolitisk",
    "tvärpolitiskes": "tvärpolitisk",
    "tvärpolitisks": "tvärpolitisk",
    "tvärpolitiskt": "tvärpolitisk",
    "tvärpolitiskts": "tvärpolitisk",
    "tvärrandiga": "tvärrandig",
    "tvärrandigare": "tvärrandig",
    "tvärrandigares": "tvärrandig",
    "tvärrandigas": "tvärrandig",
    "tvärrandigast": "tvärrandig",
    "tvärrandigaste": "tvärrandig",
    "tvärrandigastes": "tvärrandig",
    "tvärrandigasts": "tvärrandig",
    "tvärrandige": "tvärrandig",
    "tvärrandiges": "tvärrandig",
    "tvärrandigheten": "tvärrandighet",
    "tvärrandighetens": "tvärrandighet",
    "tvärrandighets": "tvärrandighet",
    "tvärrandigs": "tvärrandig",
    "tvärrandigt": "tvärrandig",
    "tvärrandigts": "tvärrandig",
    "tvärs": "tvärsa",
    "tvärsad": "tvärsa",
    "tvärsade": "tvärsa",
    "tvärsades": "tvärsa",
    "tvärsads": "tvärsa",
    "tvärsande": "tvärsa",
    "tvärsanden": "tvärsande",
    "tvärsandena": "tvärsande",
    "tvärsandenas": "tvärsande",
    "tvärsandens": "tvärsande",
    "tvärsandes": "tvärsande",
    "tvärsandet": "tvärsande",
    "tvärsandets": "tvärsande",
    "tvärsar": "tvärsa",
    "tvärsas": "tvärsa",
    "tvärsat": "tvärsa",
    "tvärsats": "tvärsa",
    "tvärskeppen": "tvärskepp",
    "tvärskeppens": "tvärskepp",
    "tvärskeppet": "tvärskepp",
    "tvärskeppets": "tvärskepp",
    "tvärskepps": "tvärskepp",
    "tvärskurens": "tvärskuren",
    "tvärskuret": "tvärskuren",
    "tvärskurets": "tvärskuren",
    "tvärskurna": "tvärskuren",
    "tvärskurnare": "tvärskuren",
    "tvärskurnares": "tvärskuren",
    "tvärskurnas": "tvärskuren",
    "tvärskurnast": "tvärskuren",
    "tvärskurnaste": "tvärskuren",
    "tvärskurnastes": "tvärskuren",
    "tvärskurnasts": "tvärskuren",
    "tvärskurne": "tvärskuren",
    "tvärskurnes": "tvärskuren",
    "tvärslåar": "tvärslå",
    "tvärslåarna": "tvärslå",
    "tvärslåarnas": "tvärslå",
    "tvärslåars": "tvärslå",
    "tvärslån": "tvärslå",
    "tvärslåns": "tvärslå",
    "tvärslås": "tvärslå",
    "tvärsnitten": "tvärsnitt",
    "tvärsnittens": "tvärsnitt",
    "tvärsnittet": "tvärsnitt",
    "tvärsnittets": "tvärsnitt",
    "tvärsnitts": "tvärsnitt",
    "tvärstann": "tvärstanna",
    "tvärstannad": "tvärstanna",
    "tvärstannade": "tvärstanna",
    "tvärstannades": "tvärstanna",
    "tvärstannads": "tvärstanna",
    "tvärstannande": "tvärstanna",
    "tvärstannanden": "tvärstannande",
    "tvärstannandena": "tvärstannande",
    "tvärstannandenas": "tvärstannande",
    "tvärstannandens": "tvärstannande",
    "tvärstannandes": "tvärstannande",
    "tvärstannandet": "tvärstannande",
    "tvärstannandets": "tvärstannande",
    "tvärstannar": "tvärstanna",
    "tvärstannas": "tvärstanna",
    "tvärstannat": "tvärstanna",
    "tvärstannats": "tvärstanna",
    "tvärstoppen": "tvärstopp",
    "tvärstoppens": "tvärstopp",
    "tvärstoppet": "tvärstopp",
    "tvärstoppets": "tvärstopp",
    "tvärstopps": "tvärstopp",
    "tvärstrecken": "tvärstreck",
    "tvärstreckens": "tvärstreck",
    "tvärstrecket": "tvärstreck",
    "tvärstreckets": "tvärstreck",
    "tvärstrecks": "tvärstreck",
    "tvärstupen": "tvärstup",
    "tvärstupens": "tvärstup",
    "tvärstupet": "tvärstup",
    "tvärstupets": "tvärstup",
    "tvärstups": "tvärstup",
    "tvärsäkerheten": "tvärsäkerhet",
    "tvärsäkerhetens": "tvärsäkerhet",
    "tvärsäkerhets": "tvärsäkerhet",
    "tvärsäkers": "tvärsäker",
    "tvärsäkert": "tvärsäker",
    "tvärsäkerts": "tvärsäker",
    "tvärsäkra": "tvärsäker",
    "tvärsäkrare": "tvärsäker",
    "tvärsäkrares": "tvärsäker",
    "tvärsäkras": "tvärsäker",
    "tvärsäkrast": "tvärsäker",
    "tvärsäkraste": "tvärsäker",
    "tvärsäkrastes": "tvärsäker",
    "tvärsäkrasts": "tvärsäker",
    "tvärsäkre": "tvärsäker",
    "tvärsäkres": "tvärsäker",
    "tvärt": "tvär",
    "tvärts": "tvär",
    "tvärvetenskapen": "tvärvetenskap",
    "tvärvetenskapens": "tvärvetenskap",
    "tvärvetenskaper": "tvärvetenskap",
    "tvärvetenskaperna": "tvärvetenskap",
    "tvärvetenskapernas": "tvärvetenskap",
    "tvärvetenskapers": "tvärvetenskap",
    "tvärvetenskapliga": "tvärvetenskaplig",
    "tvärvetenskapligare": "tvärvetenskaplig",
    "tvärvetenskapligares": "tvärvetenskaplig",
    "tvärvetenskapligas": "tvärvetenskaplig",
    "tvärvetenskapligast": "tvärvetenskaplig",
    "tvärvetenskapligaste": "tvärvetenskaplig",
    "tvärvetenskapligastes": "tvärvetenskaplig",
    "tvärvetenskapligasts": "tvärvetenskaplig",
    "tvärvetenskaplige": "tvärvetenskaplig",
    "tvärvetenskapliges": "tvärvetenskaplig",
    "tvärvetenskapligheten": "tvärvetenskaplighet",
    "tvärvetenskaplighetens": "tvärvetenskaplighet",
    "tvärvetenskaplighets": "tvärvetenskaplighet",
    "tvärvetenskapligs": "tvärvetenskaplig",
    "tvärvetenskapligt": "tvärvetenskaplig",
    "tvärvetenskapligts": "tvärvetenskaplig",
    "tvärvetenskaps": "tvärvetenskap",
    "tvärviggar": "tvärvigg",
    "tvärviggarna": "tvärvigg",
    "tvärviggarnas": "tvärvigg",
    "tvärviggars": "tvärvigg",
    "tvärviggen": "tvärvigg",
    "tvärviggens": "tvärvigg",
    "tvärviggs": "tvärvigg",
    "tvärvänd": "tvärvända",
    "tvärvändande": "tvärvända",
    "tvärvändanden": "tvärvändande",
    "tvärvändandena": "tvärvändande",
    "tvärvändandenas": "tvärvändande",
    "tvärvändandens": "tvärvändande",
    "tvärvändandes": "tvärvändande",
    "tvärvändandet": "tvärvändande",
    "tvärvändandets": "tvärvändande",
    "tvärvändas": "tvärvända",
    "tvärvände": "tvärvända",
    "tvärvänder": "tvärvända",
    "tvärvändes": "tvärvända",
    "tvärvändningar": "tvärvändning",
    "tvärvändningarna": "tvärvändning",
    "tvärvändningarnas": "tvärvändning",
    "tvärvändningars": "tvärvändning",
    "tvärvändningen": "tvärvändning",
    "tvärvändningens": "tvärvändning",
    "tvärvändnings": "tvärvändning",
    "tvärvänds": "tvärvända",
    "tvärvänt": "tvärvända",
    "tvärvänts": "tvärvända",
    "tvätt": "tvätta",
    "tvättad": "tvätta",
    "tvättade": "tvätta",
    "tvättades": "tvätta",
    "tvättads": "tvätta",
    "tvättande": "tvätta",
    "tvättanden": "tvättande",
    "tvättandena": "tvättande",
    "tvättandenas": "tvättande",
    "tvättandens": "tvättande",
    "tvättandes": "tvättande",
    "tvättandet": "tvättande",
    "tvättandets": "tvättande",
    "tvättar": "tvätta",
    "tvättarna": "tvätt",
    "tvättarnas": "tvätt",
    "tvättars": "tvätt",
    "tvättas": "tvätta",
    "tvättat": "tvätta",
    "tvättats": "tvätta",
    "tvättautomaten": "tvättautomat",
    "tvättautomatens": "tvättautomat",
    "tvättautomater": "tvättautomat",
    "tvättautomaterna": "tvättautomat",
    "tvättautomaternas": "tvättautomat",
    "tvättautomaters": "tvättautomat",
    "tvättautomats": "tvättautomat",
    "tvättbara": "tvättbar",
    "tvättbarare": "tvättbar",
    "tvättbarares": "tvättbar",
    "tvättbaras": "tvättbar",
    "tvättbarast": "tvättbar",
    "tvättbaraste": "tvättbar",
    "tvättbarastes": "tvättbar",
    "tvättbarasts": "tvättbar",
    "tvättbare": "tvättbar",
    "tvättbaren": "tvättbar",
    "tvättbarens": "tvättbar",
    "tvättbarer": "tvättbar",
    "tvättbarerna": "tvättbar",
    "tvättbarernas": "tvättbar",
    "tvättbarers": "tvättbar",
    "tvättbares": "tvättbar",
    "tvättbarheten": "tvättbarhet",
    "tvättbarhetens": "tvättbarhet",
    "tvättbarhets": "tvättbarhet",
    "tvättbars": "tvättbar",
    "tvättbart": "tvättbar",
    "tvättbarts": "tvättbar",
    "tvättbjörnar": "tvättbjörn",
    "tvättbjörnarna": "tvättbjörn",
    "tvättbjörnarnas": "tvättbjörn",
    "tvättbjörnars": "tvättbjörn",
    "tvättbjörnen": "tvättbjörn",
    "tvättbjörnens": "tvättbjörn",
    "tvättbjörns": "tvättbjörn",
    "tvättbräd": "tvättbräda",
    "tvättbrädan": "tvättbräda",
    "tvättbrädans": "tvättbräda",
    "tvättbrädas": "tvättbräda",
    "tvättbräde": "tvättbräda",
    "tvättbräden": "tvättbräde",
    "tvättbrädena": "tvättbräde",
    "tvättbrädenas": "tvättbräde",
    "tvättbrädens": "tvättbräde",
    "tvättbrädes": "tvättbräde",
    "tvättbrädet": "tvättbräde",
    "tvättbrädets": "tvättbräde",
    "tvättbrädor": "tvättbräda",
    "tvättbrädorna": "tvättbräda",
    "tvättbrädornas": "tvättbräda",
    "tvättbrädors": "tvättbräda",
    "tvättbräds": "tvättbräda",
    "tvätten": "tvätt",
    "tvättens": "tvätt",
    "tvätterier": "tvätteri",
    "tvätterierna": "tvätteri",
    "tvätteriernas": "tvätteri",
    "tvätteriers": "tvätteri",
    "tvätteriet": "tvätteri",
    "tvätteriets": "tvätteri",
    "tvätteris": "tvätteri",
    "tvätterit": "tvätteri",
    "tvätterits": "tvätteri",
    "tvättfaten": "tvättfat",
    "tvättfatens": "tvättfat",
    "tvättfatet": "tvättfat",
    "tvättfatets": "tvättfat",
    "tvättfats": "tvättfat",
    "tvätthallar": "tvätthall",
    "tvätthallarna": "tvätthall",
    "tvätthallarnas": "tvätthall",
    "tvätthallars": "tvätthall",
    "tvätthallen": "tvätthall",
    "tvätthallens": "tvätthall",
    "tvätthalls": "tvätthall",
    "tvättinrättningar": "tvättinrättning",
    "tvättinrättningarna": "tvättinrättning",
    "tvättinrättningarnas": "tvättinrättning",
    "tvättinrättningars": "tvättinrättning",
    "tvättinrättningen": "tvättinrättning",
    "tvättinrättningens": "tvättinrättning",
    "tvättinrättnings": "tvättinrättning",
    "tvättkläderna": "tvättkläder",
    "tvättklädernas": "tvättkläder",
    "tvättkläders": "tvättkläder",
    "tvättklädes": "tvättkläder",
    "tvättkläds": "tvättkläder",
    "tvättklämman": "tvättklämma",
    "tvättklämmans": "tvättklämma",
    "tvättklämmas": "tvättklämma",
    "tvättklämme": "tvättklämma",
    "tvättklämmor": "tvättklämma",
    "tvättklämmorna": "tvättklämma",
    "tvättklämmornas": "tvättklämma",
    "tvättklämmors": "tvättklämma",
    "tvättkorgar": "tvättkorg",
    "tvättkorgarna": "tvättkorg",
    "tvättkorgarnas": "tvättkorg",
    "tvättkorgars": "tvättkorg",
    "tvättkorgen": "tvättkorg",
    "tvättkorgens": "tvättkorg",
    "tvättkorgs": "tvättkorg",
    "tvättlappar": "tvättlapp",
    "tvättlapparna": "tvättlapp",
    "tvättlapparnas": "tvättlapp",
    "tvättlappars": "tvättlapp",
    "tvättlappen": "tvättlapp",
    "tvättlappens": "tvättlapp",
    "tvättlapps": "tvättlapp",
    "tvättlin": "tvättlina",
    "tvättlinan": "tvättlina",
    "tvättlinans": "tvättlina",
    "tvättlinas": "tvättlina",
    "tvättline": "tvättlina",
    "tvättlinor": "tvättlina",
    "tvättlinorna": "tvättlina",
    "tvättlinornas": "tvättlina",
    "tvättlinors": "tvättlina",
    "tvättlins": "tvättlina",
    "tvättmaskinen": "tvättmaskin",
    "tvättmaskinens": "tvättmaskin",
    "tvättmaskiner": "tvättmaskin",
    "tvättmaskinerna": "tvättmaskin",
    "tvättmaskinernas": "tvättmaskin",
    "tvättmaskiners": "tvättmaskin",
    "tvättmaskins": "tvättmaskin",
    "tvättmedels": "tvättmedel",
    "tvättmedlen": "tvättmedel",
    "tvättmedlens": "tvättmedel",
    "tvättmedlet": "tvättmedel",
    "tvättmedlets": "tvättmedel",
    "tvättomaten": "tvättomat",
    "tvättomatens": "tvättomat",
    "tvättomater": "tvättomat",
    "tvättomaterna": "tvättomat",
    "tvättomaternas": "tvättomat",
    "tvättomaters": "tvättomat",
    "tvättomats": "tvättomat",
    "tvättpulverna": "tvättpulver",
    "tvättpulvernas": "tvättpulver",
    "tvättpulvers": "tvättpulver",
    "tvättpulvren": "tvättpulver",
    "tvättpulvrens": "tvättpulver",
    "tvättpulvret": "tvättpulver",
    "tvättpulvrets": "tvättpulver",
    "tvättresultaten": "tvättresultat",
    "tvättresultatens": "tvättresultat",
    "tvättresultatet": "tvättresultat",
    "tvättresultatets": "tvättresultat",
    "tvättresultats": "tvättresultat",
    "tvätts": "tvätt",
    "tvättstugan": "tvättstuga",
    "tvättstugans": "tvättstuga",
    "tvättstugas": "tvättstuga",
    "tvättstuge": "tvättstuga",
    "tvättstugebråken": "tvättstugebråk",
    "tvättstugebråkens": "tvättstugebråk",
    "tvättstugebråket": "tvättstugebråk",
    "tvättstugebråkets": "tvättstugebråk",
    "tvättstugebråks": "tvättstugebråk",
    "tvättstugor": "tvättstuga",
    "tvättstugorna": "tvättstuga",
    "tvättstugornas": "tvättstuga",
    "tvättstugors": "tvättstuga",
    "tvättstugu": "tvättstuga",
    "tvättställen": "tvättställ",
    "tvättställens": "tvättställ",
    "tvättstället": "tvättställ",
    "tvättställets": "tvättställ",
    "tvättställs": "tvättställ",
    "tvättsvampar": "tvättsvamp",
    "tvättsvamparna": "tvättsvamp",
    "tvättsvamparnas": "tvättsvamp",
    "tvättsvampars": "tvättsvamp",
    "tvättsvampen": "tvättsvamp",
    "tvättsvampens": "tvättsvamp",
    "tvättsvamps": "tvättsvamp",
    "tvättvattens": "tvättvatten",
    "tvättvattnen": "tvättvatten",
    "tvättvattnens": "tvättvatten",
    "tvättvattnet": "tvättvatten",
    "tvättvattnets": "tvättvatten",
    "tvåan": "tvåa",
    "tvåans": "tvåa",
    "tvåas": "tvåa",
    "tvåbarnspappan": "tvåbarnspappa",
    "tvåbarnspappans": "tvåbarnspappa",
    "tvåbarnspappas": "tvåbarnspappa",
    "tvåbarnspappor": "tvåbarnspappa",
    "tvåbarnspapporna": "tvåbarnspappa",
    "tvåbarnspappornas": "tvåbarnspappa",
    "tvåbarnspappors": "tvåbarnspappa",
    "tvåbenta": "tvåbent",
    "tvåbentare": "tvåbent",
    "tvåbentares": "tvåbent",
    "tvåbentas": "tvåbent",
    "tvåbentast": "tvåbent",
    "tvåbentaste": "tvåbent",
    "tvåbentastes": "tvåbent",
    "tvåbentasts": "tvåbent",
    "tvåbente": "tvåbent",
    "tvåbentes": "tvåbent",
    "tvåbents": "tvåbent",
    "tvåbladen": "tvåblad",
    "tvåbladens": "tvåblad",
    "tvåbladet": "tvåblad",
    "tvåbladets": "tvåblad",
    "tvåblads": "tvåblad",
    "tvåbyggar": "tvåbyggare",
    "tvåbyggaren": "tvåbyggare",
    "tvåbyggarens": "tvåbyggare",
    "tvåbyggares": "tvåbyggare",
    "tvåbyggarna": "tvåbyggare",
    "tvåbyggarnas": "tvåbyggare",
    "tvåcylindriga": "tvåcylindrig",
    "tvåcylindrigare": "tvåcylindrig",
    "tvåcylindrigares": "tvåcylindrig",
    "tvåcylindrigas": "tvåcylindrig",
    "tvåcylindrigast": "tvåcylindrig",
    "tvåcylindrigaste": "tvåcylindrig",
    "tvåcylindrigastes": "tvåcylindrig",
    "tvåcylindrigasts": "tvåcylindrig",
    "tvåcylindrige": "tvåcylindrig",
    "tvåcylindriges": "tvåcylindrig",
    "tvåcylindrigs": "tvåcylindrig",
    "tvåcylindrigt": "tvåcylindrig",
    "tvåcylindrigts": "tvåcylindrig",
    "tvådd": "två",
    "tvådda": "två",
    "tvåddas": "två",
    "tvådde": "två",
    "tvåddes": "två",
    "tvådds": "två",
    "tvådelade": "tvådelad",
    "tvådelades": "tvådelad",
    "tvådelads": "tvådelad",
    "tvådelat": "tvådelad",
    "tvådelats": "tvådelad",
    "tvådimensionella": "tvådimensionell",
    "tvådimensionellare": "tvådimensionell",
    "tvådimensionellares": "tvådimensionell",
    "tvådimensionellas": "tvådimensionell",
    "tvådimensionellast": "tvådimensionell",
    "tvådimensionellaste": "tvådimensionell",
    "tvådimensionellastes": "tvådimensionell",
    "tvådimensionellasts": "tvådimensionell",
    "tvådimensionelle": "tvådimensionell",
    "tvådimensionelles": "tvådimensionell",
    "tvådimensionells": "tvådimensionell",
    "tvådimensionellt": "tvådimensionell",
    "tvådimensionellts": "tvådimensionell",
    "tvående": "två",
    "tvåendelar": "tvåendel",
    "tvåendelarna": "tvåendel",
    "tvåendelarnas": "tvåendel",
    "tvåendelars": "tvåendel",
    "tvåendelen": "tvåendel",
    "tvåendelens": "tvåendel",
    "tvåendels": "tvåendel",
    "tvåenden": "tvående",
    "tvåendena": "tvående",
    "tvåendenas": "tvående",
    "tvåendens": "tvående",
    "tvåendes": "tvående",
    "tvåendet": "tvående",
    "tvåendets": "tvående",
    "tvåfaldiga": "tvåfaldig",
    "tvåfaldigas": "tvåfaldig",
    "tvåfaldige": "tvåfaldig",
    "tvåfaldiges": "tvåfaldig",
    "tvåfaldigs": "tvåfaldig",
    "tvåfaldigt": "tvåfaldig",
    "tvåfaldigts": "tvåfaldig",
    "tvåfamiljshusen": "tvåfamiljshus",
    "tvåfamiljshusens": "tvåfamiljshus",
    "tvåfamiljshuset": "tvåfamiljshus",
    "tvåfamiljshusets": "tvåfamiljshus",
    "tvåfjärdedelstakten": "tvåfjärdedelstakt",
    "tvåfjärdedelstaktens": "tvåfjärdedelstakt",
    "tvåfjärdedelstakts": "tvåfjärdedelstakt",
    "tvåformiga": "tvåformig",
    "tvåformigare": "tvåformig",
    "tvåformigares": "tvåformig",
    "tvåformigas": "tvåformig",
    "tvåformigast": "tvåformig",
    "tvåformigaste": "tvåformig",
    "tvåformigastes": "tvåformig",
    "tvåformigasts": "tvåformig",
    "tvåformige": "tvåformig",
    "tvåformiges": "tvåformig",
    "tvåformigheten": "tvåformighet",
    "tvåformighetens": "tvåformighet",
    "tvåformighets": "tvåformighet",
    "tvåformigs": "tvåformig",
    "tvåformigt": "tvåformig",
    "tvåformigts": "tvåformig",
    "tvåfrontskrigen": "tvåfrontskrig",
    "tvåfrontskrigens": "tvåfrontskrig",
    "tvåfrontskriget": "tvåfrontskrig",
    "tvåfrontskrigets": "tvåfrontskrig",
    "tvåfrontskrigs": "tvåfrontskrig",
    "tvåfärgade": "tvåfärgad",
    "tvåfärgades": "tvåfärgad",
    "tvåfärgads": "tvåfärgad",
    "tvåfärgat": "tvåfärgad",
    "tvåfärgats": "tvåfärgad",
    "tvåhjuliga": "tvåhjulig",
    "tvåhjuligas": "tvåhjulig",
    "tvåhjulige": "tvåhjulig",
    "tvåhjuliges": "tvåhjulig",
    "tvåhjuligheten": "tvåhjulighet",
    "tvåhjulighetens": "tvåhjulighet",
    "tvåhjulighets": "tvåhjulighet",
    "tvåhjuligs": "tvåhjulig",
    "tvåhjuligt": "tvåhjulig",
    "tvåhjuligts": "tvåhjulig",
    "tvåhjulingar": "tvåhjuling",
    "tvåhjulingarna": "tvåhjuling",
    "tvåhjulingarnas": "tvåhjuling",
    "tvåhjulingars": "tvåhjuling",
    "tvåhjulingen": "tvåhjuling",
    "tvåhjulingens": "tvåhjuling",
    "tvåhjulings": "tvåhjuling",
    "tvåhjärtbladiga": "tvåhjärtbladig",
    "tvåhjärtbladigare": "tvåhjärtbladig",
    "tvåhjärtbladigares": "tvåhjärtbladig",
    "tvåhjärtbladigas": "tvåhjärtbladig",
    "tvåhjärtbladigast": "tvåhjärtbladig",
    "tvåhjärtbladigaste": "tvåhjärtbladig",
    "tvåhjärtbladigastes": "tvåhjärtbladig",
    "tvåhjärtbladigasts": "tvåhjärtbladig",
    "tvåhjärtbladige": "tvåhjärtbladig",
    "tvåhjärtbladiges": "tvåhjärtbladig",
    "tvåhjärtbladigs": "tvåhjärtbladig",
    "tvåhjärtbladigt": "tvåhjärtbladig",
    "tvåhjärtbladigts": "tvåhjärtbladig",
    "tvåhundrade": "tvåhundra",
    "tvåhundrades": "tvåhundra",
    "tvåhundras": "tvåhundra",
    "tvåhundratalet": "tvåhundratal",
    "tvåhundratalets": "tvåhundratal",
    "tvåhundratals": "tvåhundratal",
    "tvåhändiga": "tvåhändig",
    "tvåhändigare": "tvåhändig",
    "tvåhändigares": "tvåhändig",
    "tvåhändigas": "tvåhändig",
    "tvåhändigast": "tvåhändig",
    "tvåhändigaste": "tvåhändig",
    "tvåhändigastes": "tvåhändig",
    "tvåhändigasts": "tvåhändig",
    "tvåhändige": "tvåhändig",
    "tvåhändiges": "tvåhändig",
    "tvåhändigs": "tvåhändig",
    "tvåhändigt": "tvåhändig",
    "tvåhändigts": "tvåhändig",
    "tvåhänta": "tvåhänt",
    "tvåhäntas": "tvåhänt",
    "tvåhänte": "tvåhänt",
    "tvåhäntes": "tvåhänt",
    "tvåhäntheten": "tvåhänthet",
    "tvåhänthetens": "tvåhänthet",
    "tvåhänthets": "tvåhänthet",
    "tvåhänts": "tvåhänt",
    "tvåkammarlykt": "tvåkammarlykta",
    "tvåkammarlyktan": "tvåkammarlykta",
    "tvåkammarlyktans": "tvåkammarlykta",
    "tvåkammarlyktas": "tvåkammarlykta",
    "tvåkammarlykte": "tvåkammarlykta",
    "tvåkammarlyktor": "tvåkammarlykta",
    "tvåkammarlyktorna": "tvåkammarlykta",
    "tvåkammarlyktornas": "tvåkammarlykta",
    "tvåkammarlyktors": "tvåkammarlykta",
    "tvåkammarlykts": "tvåkammarlykta",
    "tvåkomponentslimmet": "tvåkomponentslim",
    "tvåkomponentslimmets": "tvåkomponentslim",
    "tvåkomponentslims": "tvåkomponentslim",
    "tvåkron": "tvåkrona",
    "tvåkronan": "tvåkrona",
    "tvåkronans": "tvåkrona",
    "tvåkronas": "tvåkrona",
    "tvåkrone": "tvåkrona",
    "tvåkronor": "tvåkrona",
    "tvåkronorna": "tvåkrona",
    "tvåkronornas": "tvåkrona",
    "tvåkronors": "tvåkrona",
    "tvåkrons": "tvåkrona",
    "tvåkropparsproblemets": "tvåkropparsproblemet",
    "tvåkönade": "tvåkönad",
    "tvåkönades": "tvåkönad",
    "tvåkönads": "tvåkönad",
    "tvåkönat": "tvåkönad",
    "tvåkönats": "tvåkönad",
    "tvålar": "tvål",
    "tvålarna": "tvål",
    "tvålarnas": "tvål",
    "tvålars": "tvål",
    "tvålaskar": "tvålask",
    "tvålaskarna": "tvålask",
    "tvålaskarnas": "tvålask",
    "tvålaskars": "tvålask",
    "tvålasken": "tvålask",
    "tvålaskens": "tvålask",
    "tvålasks": "tvålask",
    "tvåledarsystemet": "tvåledarsystem",
    "tvåledarsystemets": "tvåledarsystem",
    "tvåledarsystems": "tvåledarsystem",
    "tvålen": "tvål",
    "tvålens": "tvål",
    "tvålfagerheten": "tvålfagerhet",
    "tvålfagerhetens": "tvålfagerhet",
    "tvålfagerhets": "tvålfagerhet",
    "tvålfagers": "tvålfager",
    "tvålfagert": "tvålfager",
    "tvålfagerts": "tvålfager",
    "tvålfagra": "tvålfager",
    "tvålfagrare": "tvålfager",
    "tvålfagrares": "tvålfager",
    "tvålfagras": "tvålfager",
    "tvålfagrast": "tvålfager",
    "tvålfagraste": "tvålfager",
    "tvålfagrastes": "tvålfager",
    "tvålfagrasts": "tvålfager",
    "tvålfagre": "tvålfager",
    "tvålfagres": "tvålfager",
    "tvålfling": "tvålflinga",
    "tvålflingan": "tvålflinga",
    "tvålflingans": "tvålflinga",
    "tvålflingas": "tvålflinga",
    "tvålflinge": "tvålflinga",
    "tvålflingor": "tvålflinga",
    "tvålflingorna": "tvålflinga",
    "tvålflingornas": "tvålflinga",
    "tvålflingors": "tvålflinga",
    "tvålflings": "tvålflinga",
    "tvåliga": "tvålig",
    "tvåligare": "tvålig",
    "tvåligares": "tvålig",
    "tvåligas": "tvålig",
    "tvåligast": "tvålig",
    "tvåligaste": "tvålig",
    "tvåligastes": "tvålig",
    "tvåligasts": "tvålig",
    "tvålige": "tvålig",
    "tvåliges": "tvålig",
    "tvåligheten": "tvålighet",
    "tvålighetens": "tvålighet",
    "tvålighets": "tvålighet",
    "tvåligs": "tvålig",
    "tvåligt": "tvålig",
    "tvåligts": "tvålig",
    "tvålkoppar": "tvålkopp",
    "tvålkopparna": "tvålkopp",
    "tvålkopparnas": "tvålkopp",
    "tvålkoppars": "tvålkopp",
    "tvålkoppen": "tvålkopp",
    "tvålkoppens": "tvålkopp",
    "tvålkopps": "tvålkopp",
    "tvållödders": "tvållödder",
    "tvållöddret": "tvållödder",
    "tvållöddrets": "tvållödder",
    "tvåloperamässiga": "tvåloperamässig",
    "tvåloperamässigare": "tvåloperamässig",
    "tvåloperamässigares": "tvåloperamässig",
    "tvåloperamässigas": "tvåloperamässig",
    "tvåloperamässigast": "tvåloperamässig",
    "tvåloperamässigaste": "tvåloperamässig",
    "tvåloperamässigastes": "tvåloperamässig",
    "tvåloperamässigasts": "tvåloperamässig",
    "tvåloperamässige": "tvåloperamässig",
    "tvåloperamässiges": "tvåloperamässig",
    "tvåloperamässigs": "tvåloperamässig",
    "tvåloperamässigt": "tvåloperamässig",
    "tvåloperamässigts": "tvåloperamässig",
    "tvåloperan": "tvålopera",
    "tvåloperans": "tvålopera",
    "tvåloperas": "tvålopera",
    "tvåloperor": "tvålopera",
    "tvåloperorna": "tvålopera",
    "tvåloperornas": "tvålopera",
    "tvåloperors": "tvålopera",
    "tvåls": "tvål",
    "tvåläppiga": "tvåläppig",
    "tvåläppigare": "tvåläppig",
    "tvåläppigares": "tvåläppig",
    "tvåläppigas": "tvåläppig",
    "tvåläppigast": "tvåläppig",
    "tvåläppigaste": "tvåläppig",
    "tvåläppigastes": "tvåläppig",
    "tvåläppigasts": "tvåläppig",
    "tvåläppige": "tvåläppig",
    "tvåläppiges": "tvåläppig",
    "tvåläppigs": "tvåläppig",
    "tvåläppigt": "tvåläppig",
    "tvåläppigts": "tvåläppig",
    "tvåmannatälten": "tvåmannatält",
    "tvåmannatältens": "tvåmannatält",
    "tvåmannatältet": "tvåmannatält",
    "tvåmannatältets": "tvåmannatält",
    "tvåmannatälts": "tvåmannatält",
    "tvåmanstälten": "tvåmanstält",
    "tvåmanstältens": "tvåmanstält",
    "tvåmanstältet": "tvåmanstält",
    "tvåmanstältets": "tvåmanstält",
    "tvåmanstälts": "tvåmanstält",
    "tvåmastade": "tvåmastad",
    "tvåmastades": "tvåmastad",
    "tvåmastads": "tvåmastad",
    "tvåmastar": "tvåmastare",
    "tvåmastaren": "tvåmastare",
    "tvåmastarens": "tvåmastare",
    "tvåmastares": "tvåmastare",
    "tvåmastarna": "tvåmastare",
    "tvåmastarnas": "tvåmastare",
    "tvåmastat": "tvåmastad",
    "tvåmastats": "tvåmastad",
    "tvåmänningar": "tvåmänning",
    "tvåmänningarna": "tvåmänning",
    "tvåmänningarnas": "tvåmänning",
    "tvåmänningars": "tvåmänning",
    "tvåmänningen": "tvåmänning",
    "tvåmänningens": "tvåmänning",
    "tvåmännings": "tvåmänning",
    "tvånget": "tvång",
    "tvångets": "tvång",
    "tvångs": "tvång",
    "tvångsarbeten": "tvångsarbete",
    "tvångsarbetena": "tvångsarbete",
    "tvångsarbetenas": "tvångsarbete",
    "tvångsarbetens": "tvångsarbete",
    "tvångsarbetes": "tvångsarbete",
    "tvångsarbetet": "tvångsarbete",
    "tvångsarbetets": "tvångsarbete",
    "tvångsarbets": "tvångsarbete",
    "tvångsbälten": "tvångsbälte",
    "tvångsbältena": "tvångsbälte",
    "tvångsbältenas": "tvångsbälte",
    "tvångsbältens": "tvångsbälte",
    "tvångsbältes": "tvångsbälte",
    "tvångsbältet": "tvångsbälte",
    "tvångsbältets": "tvångsbälte",
    "tvångsföreställningar": "tvångsföreställning",
    "tvångsföreställningarna": "tvångsföreställning",
    "tvångsföreställningarnas": "tvångsföreställning",
    "tvångsföreställningars": "tvångsföreställning",
    "tvångsföreställningen": "tvångsföreställning",
    "tvångsföreställningens": "tvångsföreställning",
    "tvångsföreställnings": "tvångsföreställning",
    "tvångsgifta": "tvångsgift",
    "tvångsgiftas": "tvångsgift",
    "tvångsgifte": "tvångsgift",
    "tvångsgiften": "tvångsgifte",
    "tvångsgiftena": "tvångsgifte",
    "tvångsgiftenas": "tvångsgifte",
    "tvångsgiftens": "tvångsgifte",
    "tvångsgiftes": "tvångsgifte",
    "tvångsgiftet": "tvångsgifte",
    "tvångsgiftets": "tvångsgifte",
    "tvångsgifts": "tvångsgift",
    "tvångsintagens": "tvångsintagen",
    "tvångsintaget": "tvångsintagen",
    "tvångsintagets": "tvångsintagen",
    "tvångsintagna": "tvångsintagen",
    "tvångsintagnas": "tvångsintagen",
    "tvångsintagne": "tvångsintagen",
    "tvångsintagnes": "tvångsintagen",
    "tvångsintagningar": "tvångsintagning",
    "tvångsintagningarna": "tvångsintagning",
    "tvångsintagningarnas": "tvångsintagning",
    "tvångsintagningars": "tvångsintagning",
    "tvångsintagningen": "tvångsintagning",
    "tvångsintagningens": "tvångsintagning",
    "tvångsintagnings": "tvångsintagning",
    "tvångskommenderad": "tvångskommendera",
    "tvångskommenderade": "tvångskommendera",
    "tvångskommenderades": "tvångskommendera",
    "tvångskommenderads": "tvångskommendera",
    "tvångskommenderande": "tvångskommendera",
    "tvångskommenderanden": "tvångskommenderande",
    "tvångskommenderandena": "tvångskommenderande",
    "tvångskommenderandenas": "tvångskommenderande",
    "tvångskommenderandens": "tvångskommenderande",
    "tvångskommenderandes": "tvångskommenderande",
    "tvångskommenderandet": "tvångskommenderande",
    "tvångskommenderandets": "tvångskommenderande",
    "tvångskommenderar": "tvångskommendera",
    "tvångskommenderas": "tvångskommendera",
    "tvångskommenderat": "tvångskommendera",
    "tvångskommenderats": "tvångskommendera",
    "tvångskommenderbara": "tvångskommenderbar",
    "tvångskommenderbarare": "tvångskommenderbar",
    "tvångskommenderbarares": "tvångskommenderbar",
    "tvångskommenderbaras": "tvångskommenderbar",
    "tvångskommenderbarast": "tvångskommenderbar",
    "tvångskommenderbaraste": "tvångskommenderbar",
    "tvångskommenderbarastes": "tvångskommenderbar",
    "tvångskommenderbarasts": "tvångskommenderbar",
    "tvångskommenderbare": "tvångskommenderbar",
    "tvångskommenderbares": "tvångskommenderbar",
    "tvångskommenderbarheten": "tvångskommenderbarhet",
    "tvångskommenderbarhetens": "tvångskommenderbarhet",
    "tvångskommenderbarhets": "tvångskommenderbarhet",
    "tvångskommenderbars": "tvångskommenderbar",
    "tvångskommenderbart": "tvångskommenderbar",
    "tvångskommenderbarts": "tvångskommenderbar",
    "tvångskommenderingar": "tvångskommendering",
    "tvångskommenderingarna": "tvångskommendering",
    "tvångskommenderingarnas": "tvångskommendering",
    "tvångskommenderingars": "tvångskommendering",
    "tvångskommenderingen": "tvångskommendering",
    "tvångskommenderingens": "tvångskommendering",
    "tvångskommenderings": "tvångskommendering",
    "tvångslagar": "tvångslag",
    "tvångslagarna": "tvångslag",
    "tvångslagarnas": "tvångslag",
    "tvångslagars": "tvångslag",
    "tvångslagen": "tvångslag",
    "tvångslagens": "tvångslag",
    "tvångslags": "tvångslag",
    "tvångslägen": "tvångsläge",
    "tvångslägena": "tvångsläge",
    "tvångslägenas": "tvångsläge",
    "tvångslägens": "tvångsläge",
    "tvångsläges": "tvångsläge",
    "tvångsläget": "tvångsläge",
    "tvångslägets": "tvångsläge",
    "tvångsmedels": "tvångsmedel",
    "tvångsmedlen": "tvångsmedel",
    "tvångsmedlens": "tvångsmedel",
    "tvångsmedlet": "tvångsmedel",
    "tvångsmedlets": "tvångsmedel",
    "tvångsmässiga": "tvångsmässig",
    "tvångsmässigare": "tvångsmässig",
    "tvångsmässigares": "tvångsmässig",
    "tvångsmässigas": "tvångsmässig",
    "tvångsmässigast": "tvångsmässig",
    "tvångsmässigaste": "tvångsmässig",
    "tvångsmässigastes": "tvångsmässig",
    "tvångsmässigasts": "tvångsmässig",
    "tvångsmässige": "tvångsmässig",
    "tvångsmässiges": "tvångsmässig",
    "tvångsmässigheten": "tvångsmässighet",
    "tvångsmässighetens": "tvångsmässighet",
    "tvångsmässigheter": "tvångsmässighet",
    "tvångsmässigheterna": "tvångsmässighet",
    "tvångsmässigheternas": "tvångsmässighet",
    "tvångsmässigheters": "tvångsmässighet",
    "tvångsmässighets": "tvångsmässighet",
    "tvångsmässigs": "tvångsmässig",
    "tvångsmässigt": "tvångsmässig",
    "tvångsmässigts": "tvångsmässig",
    "tvångsneurosen": "tvångsneuros",
    "tvångsneurosens": "tvångsneuros",
    "tvångsneuroser": "tvångsneuros",
    "tvångsneuroserna": "tvångsneuros",
    "tvångsneurosernas": "tvångsneuros",
    "tvångsneurosers": "tvångsneuros",
    "tvångsrekryterad": "tvångsrekrytera",
    "tvångsrekryterade": "tvångsrekrytera",
    "tvångsrekryterades": "tvångsrekrytera",
    "tvångsrekryterads": "tvångsrekrytera",
    "tvångsrekryterande": "tvångsrekrytera",
    "tvångsrekryteranden": "tvångsrekryterande",
    "tvångsrekryterandena": "tvångsrekryterande",
    "tvångsrekryterandenas": "tvångsrekryterande",
    "tvångsrekryterandens": "tvångsrekryterande",
    "tvångsrekryterandes": "tvångsrekryterande",
    "tvångsrekryterandet": "tvångsrekryterande",
    "tvångsrekryterandets": "tvångsrekryterande",
    "tvångsrekryterar": "tvångsrekrytera",
    "tvångsrekryteras": "tvångsrekrytera",
    "tvångsrekryterat": "tvångsrekrytera",
    "tvångsrekryterats": "tvångsrekrytera",
    "tvångsrekryterbara": "tvångsrekryterbar",
    "tvångsrekryterbarare": "tvångsrekryterbar",
    "tvångsrekryterbarares": "tvångsrekryterbar",
    "tvångsrekryterbaras": "tvångsrekryterbar",
    "tvångsrekryterbarast": "tvångsrekryterbar",
    "tvångsrekryterbaraste": "tvångsrekryterbar",
    "tvångsrekryterbarastes": "tvångsrekryterbar",
    "tvångsrekryterbarasts": "tvångsrekryterbar",
    "tvångsrekryterbare": "tvångsrekryterbar",
    "tvångsrekryterbares": "tvångsrekryterbar",
    "tvångsrekryterbarheten": "tvångsrekryterbarhet",
    "tvångsrekryterbarhetens": "tvångsrekryterbarhet",
    "tvångsrekryterbarhets": "tvångsrekryterbarhet",
    "tvångsrekryterbars": "tvångsrekryterbar",
    "tvångsrekryterbart": "tvångsrekryterbar",
    "tvångsrekryterbarts": "tvångsrekryterbar",
    "tvångsrekryteringar": "tvångsrekrytering",
    "tvångsrekryteringarna": "tvångsrekrytering",
    "tvångsrekryteringarnas": "tvångsrekrytering",
    "tvångsrekryteringars": "tvångsrekrytering",
    "tvångsrekryteringen": "tvångsrekrytering",
    "tvångsrekryteringens": "tvångsrekrytering",
    "tvångsrekryterings": "tvångsrekrytering",
    "tvångssituationen": "tvångssituation",
    "tvångssituationens": "tvångssituation",
    "tvångssituationer": "tvångssituation",
    "tvångssituationerna": "tvångssituation",
    "tvångssituationernas": "tvångssituation",
    "tvångssituationers": "tvångssituation",
    "tvångssituations": "tvångssituation",
    "tvångssparandes": "tvångssparande",
    "tvångssparandet": "tvångssparande",
    "tvångssparandets": "tvångssparande",
    "tvångstank": "tvångstanke",
    "tvångstankar": "tvångstanke",
    "tvångstankarna": "tvångstanke",
    "tvångstankarnas": "tvångstanke",
    "tvångstankars": "tvångstanke",
    "tvångstanken": "tvångstanke",
    "tvångstankens": "tvångstanke",
    "tvångstankes": "tvångstanke",
    "tvångstanks": "tvångstanke",
    "tvångstatuerad": "tvångstatuera",
    "tvångstatuerade": "tvångstatuera",
    "tvångstatuerades": "tvångstatuera",
    "tvångstatuerads": "tvångstatuera",
    "tvångstatuerande": "tvångstatuera",
    "tvångstatueranden": "tvångstatuerande",
    "tvångstatuerandena": "tvångstatuerande",
    "tvångstatuerandenas": "tvångstatuerande",
    "tvångstatuerandens": "tvångstatuerande",
    "tvångstatuerandes": "tvångstatuerande",
    "tvångstatuerandet": "tvångstatuerande",
    "tvångstatuerandets": "tvångstatuerande",
    "tvångstatuerar": "tvångstatuera",
    "tvångstatueras": "tvångstatuera",
    "tvångstatuerat": "tvångstatuera",
    "tvångstatuerats": "tvångstatuera",
    "tvångstatuerbara": "tvångstatuerbar",
    "tvångstatuerbarare": "tvångstatuerbar",
    "tvångstatuerbarares": "tvångstatuerbar",
    "tvångstatuerbaras": "tvångstatuerbar",
    "tvångstatuerbarast": "tvångstatuerbar",
    "tvångstatuerbaraste": "tvångstatuerbar",
    "tvångstatuerbarastes": "tvångstatuerbar",
    "tvångstatuerbarasts": "tvångstatuerbar",
    "tvångstatuerbare": "tvångstatuerbar",
    "tvångstatuerbares": "tvångstatuerbar",
    "tvångstatuerbarheten": "tvångstatuerbarhet",
    "tvångstatuerbarhetens": "tvångstatuerbarhet",
    "tvångstatuerbarhets": "tvångstatuerbarhet",
    "tvångstatuerbars": "tvångstatuerbar",
    "tvångstatuerbart": "tvångstatuerbar",
    "tvångstatuerbarts": "tvångstatuerbar",
    "tvångströjan": "tvångströja",
    "tvångströjans": "tvångströja",
    "tvångströjas": "tvångströja",
    "tvångströje": "tvångströja",
    "tvångströjor": "tvångströja",
    "tvångströjorna": "tvångströja",
    "tvångströjornas": "tvångströja",
    "tvångströjors": "tvångströja",
    "tvångsvärvade": "tvångsvärvad",
    "tvångsvärvades": "tvångsvärvad",
    "tvångsvärvads": "tvångsvärvad",
    "tvångsvärvat": "tvångsvärvad",
    "tvångsvärvats": "tvångsvärvad",
    "tvångsvården": "tvångsvård",
    "tvångsvårdens": "tvångsvård",
    "tvångsvårds": "tvångsvård",
    "tvångsåtgärden": "tvångsåtgärd",
    "tvångsåtgärdens": "tvångsåtgärd",
    "tvångsåtgärder": "tvångsåtgärd",
    "tvångsåtgärderna": "tvångsåtgärd",
    "tvångsåtgärdernas": "tvångsåtgärd",
    "tvångsåtgärders": "tvångsåtgärd",
    "tvångsåtgärds": "tvångsåtgärd",
    "tvåondelar": "tvåondel",
    "tvåondelarna": "tvåondel",
    "tvåondelarnas": "tvåondel",
    "tvåondelars": "tvåondel",
    "tvåondelen": "tvåondel",
    "tvåondelens": "tvåondel",
    "tvåondels": "tvåondel",
    "tvåor": "tvåa",
    "tvåorna": "tvåa",
    "tvåornas": "tvåa",
    "tvåors": "tvåa",
    "tvåpartsförhållanden": "tvåpartsförhållande",
    "tvåpartsförhållandena": "tvåpartsförhållande",
    "tvåpartsförhållandenas": "tvåpartsförhållande",
    "tvåpartsförhållandens": "tvåpartsförhållande",
    "tvåpartsförhållandes": "tvåpartsförhållande",
    "tvåpartsförhållandet": "tvåpartsförhållande",
    "tvåpartsförhållandets": "tvåpartsförhållande",
    "tvår": "två",
    "tvåradingar": "tvårading",
    "tvåradingarna": "tvårading",
    "tvåradingarnas": "tvårading",
    "tvåradingars": "tvårading",
    "tvåradingen": "tvårading",
    "tvåradingens": "tvårading",
    "tvåradings": "tvårading",
    "tvårummar": "tvårummare",
    "tvårummaren": "tvårummare",
    "tvårummarens": "tvårummare",
    "tvårummares": "tvårummare",
    "tvårummarna": "tvårummare",
    "tvårummarnas": "tvårummare",
    "tvårumslägenheten": "tvårumslägenhet",
    "tvårumslägenhetens": "tvårumslägenhet",
    "tvårumslägenheter": "tvårumslägenhet",
    "tvårumslägenheterna": "tvårumslägenhet",
    "tvårumslägenheternas": "tvårumslägenhet",
    "tvårumslägenheters": "tvårumslägenhet",
    "tvårumslägenhets": "tvårumslägenhet",
    "tvås": "två",
    "tvåsamheten": "tvåsamhet",
    "tvåsamhetens": "tvåsamhet",
    "tvåsamheter": "tvåsamhet",
    "tvåsamheterna": "tvåsamhet",
    "tvåsamheternas": "tvåsamhet",
    "tvåsamheters": "tvåsamhet",
    "tvåsamhets": "tvåsamhet",
    "tvåsiffriga": "tvåsiffrig",
    "tvåsiffrigare": "tvåsiffrig",
    "tvåsiffrigares": "tvåsiffrig",
    "tvåsiffrigas": "tvåsiffrig",
    "tvåsiffrigast": "tvåsiffrig",
    "tvåsiffrigaste": "tvåsiffrig",
    "tvåsiffrigastes": "tvåsiffrig",
    "tvåsiffrigasts": "tvåsiffrig",
    "tvåsiffrige": "tvåsiffrig",
    "tvåsiffriges": "tvåsiffrig",
    "tvåsiffrigs": "tvåsiffrig",
    "tvåsiffrigt": "tvåsiffrig",
    "tvåsiffrigts": "tvåsiffrig",
    "tvåsitssoff": "tvåsitssoffa",
    "tvåsitssoffan": "tvåsitssoffa",
    "tvåsitssoffans": "tvåsitssoffa",
    "tvåsitssoffas": "tvåsitssoffa",
    "tvåsitssoffe": "tvåsitssoffa",
    "tvåsitssoffor": "tvåsitssoffa",
    "tvåsitssofforna": "tvåsitssoffa",
    "tvåsitssoffornas": "tvåsitssoffa",
    "tvåsitssoffors": "tvåsitssoffa",
    "tvåsitssoffs": "tvåsitssoffa",
    "tvåskafts": "tvåskaft",
    "tvåskaftsbindningar": "tvåskaftsbindning",
    "tvåskaftsbindningarna": "tvåskaftsbindning",
    "tvåskaftsbindningarnas": "tvåskaftsbindning",
    "tvåskaftsbindningars": "tvåskaftsbindning",
    "tvåskaftsbindningen": "tvåskaftsbindning",
    "tvåskaftsbindningens": "tvåskaftsbindning",
    "tvåskaftsbindnings": "tvåskaftsbindning",
    "tvåskiftet": "tvåskift",
    "tvåskiftets": "tvåskift",
    "tvåskifts": "tvåskift",
    "tvåsnårets": "tvåsnåret",
    "tvåspannen": "tvåspann",
    "tvåspannens": "tvåspann",
    "tvåspannet": "tvåspann",
    "tvåspannets": "tvåspann",
    "tvåspanns": "tvåspann",
    "tvåspråkiga": "tvåspråkig",
    "tvåspråkigare": "tvåspråkig",
    "tvåspråkigares": "tvåspråkig",
    "tvåspråkigas": "tvåspråkig",
    "tvåspråkigast": "tvåspråkig",
    "tvåspråkigaste": "tvåspråkig",
    "tvåspråkigastes": "tvåspråkig",
    "tvåspråkigasts": "tvåspråkig",
    "tvåspråkige": "tvåspråkig",
    "tvåspråkiges": "tvåspråkig",
    "tvåspråkigheten": "tvåspråkighet",
    "tvåspråkighetens": "tvåspråkighet",
    "tvåspråkighets": "tvåspråkighet",
    "tvåspråkigs": "tvåspråkig",
    "tvåspråkigt": "tvåspråkig",
    "tvåspråkigts": "tvåspråkig",
    "tvåspända": "tvåspänd",
    "tvåspändare": "tvåspänd",
    "tvåspändares": "tvåspänd",
    "tvåspändas": "tvåspänd",
    "tvåspändast": "tvåspänd",
    "tvåspändaste": "tvåspänd",
    "tvåspändastes": "tvåspänd",
    "tvåspändasts": "tvåspänd",
    "tvåspände": "tvåspänd",
    "tvåspändes": "tvåspänd",
    "tvåspänds": "tvåspänd",
    "tvåspänt": "tvåspänd",
    "tvåspänts": "tvåspänd",
    "tvåstaviga": "tvåstavig",
    "tvåstavigare": "tvåstavig",
    "tvåstavigares": "tvåstavig",
    "tvåstavigas": "tvåstavig",
    "tvåstavigast": "tvåstavig",
    "tvåstavigaste": "tvåstavig",
    "tvåstavigastes": "tvåstavig",
    "tvåstavigasts": "tvåstavig",
    "tvåstavige": "tvåstavig",
    "tvåstaviges": "tvåstavig",
    "tvåstavigheten": "tvåstavighet",
    "tvåstavighetens": "tvåstavighet",
    "tvåstavighets": "tvåstavighet",
    "tvåstavighetsaccenten": "tvåstavighetsaccent",
    "tvåstavighetsaccentens": "tvåstavighetsaccent",
    "tvåstavighetsaccenter": "tvåstavighetsaccent",
    "tvåstavighetsaccenterna": "tvåstavighetsaccent",
    "tvåstavighetsaccenternas": "tvåstavighetsaccent",
    "tvåstavighetsaccenters": "tvåstavighetsaccent",
    "tvåstavighetsaccents": "tvåstavighetsaccent",
    "tvåstavigs": "tvåstavig",
    "tvåstavigt": "tvåstavig",
    "tvåstavigts": "tvåstavig",
    "tvåstegsavtryckar": "tvåstegsavtryckare",
    "tvåstegsavtryckaren": "tvåstegsavtryckare",
    "tvåstegsavtryckarens": "tvåstegsavtryckare",
    "tvåstegsavtryckares": "tvåstegsavtryckare",
    "tvåstegsavtryckarna": "tvåstegsavtryckare",
    "tvåstegsavtryckarnas": "tvåstegsavtryckare",
    "tvåstjärniga": "tvåstjärnig",
    "tvåstjärnigas": "tvåstjärnig",
    "tvåstjärnige": "tvåstjärnig",
    "tvåstjärniges": "tvåstjärnig",
    "tvåstjärnigs": "tvåstjärnig",
    "tvåstjärnigt": "tvåstjärnig",
    "tvåstjärnigts": "tvåstjärnig",
    "tvåstrukens": "tvåstruken",
    "tvåstruket": "tvåstruken",
    "tvåstrukets": "tvåstruken",
    "tvåstrukna": "tvåstruken",
    "tvåstruknare": "tvåstruken",
    "tvåstruknares": "tvåstruken",
    "tvåstruknas": "tvåstruken",
    "tvåstruknast": "tvåstruken",
    "tvåstruknaste": "tvåstruken",
    "tvåstruknastes": "tvåstruken",
    "tvåstruknasts": "tvåstruken",
    "tvåstrukne": "tvåstruken",
    "tvåstruknes": "tvåstruken",
    "tvåtaktar": "tvåtaktare",
    "tvåtaktaren": "tvåtaktare",
    "tvåtaktarens": "tvåtaktare",
    "tvåtaktares": "tvåtaktare",
    "tvåtaktarna": "tvåtaktare",
    "tvåtaktarnas": "tvåtaktare",
    "tvåtaktsmotorer": "tvåtaktsmotor",
    "tvåtaktsmotorerna": "tvåtaktsmotor",
    "tvåtaktsmotorernas": "tvåtaktsmotor",
    "tvåtaktsmotorers": "tvåtaktsmotor",
    "tvåtaktsmotorn": "tvåtaktsmotor",
    "tvåtaktsmotorns": "tvåtaktsmotor",
    "tvåtaktsmotors": "tvåtaktsmotor",
    "tvåtaktsoljan": "tvåtaktsolja",
    "tvåtaktsoljans": "tvåtaktsolja",
    "tvåtaktsoljas": "tvåtaktsolja",
    "tvåtaktsolje": "tvåtaktsolja",
    "tvåtaktsoljor": "tvåtaktsolja",
    "tvåtaktsoljorna": "tvåtaktsolja",
    "tvåtaktsoljornas": "tvåtaktsolja",
    "tvåtaktsoljors": "tvåtaktsolja",
    "tvåtimmarsskiften": "tvåtimmarsskift",
    "tvåtimmarsskiftens": "tvåtimmarsskift",
    "tvåtimmarsskiftet": "tvåtimmarsskift",
    "tvåtimmarsskiftets": "tvåtimmarsskift",
    "tvåtimmarsskifts": "tvåtimmarsskift",
    "tvått": "två",
    "tvåtts": "två",
    "tvåtumsspikar": "tvåtumsspik",
    "tvåtumsspikarna": "tvåtumsspik",
    "tvåtumsspikarnas": "tvåtumsspik",
    "tvåtumsspikars": "tvåtumsspik",
    "tvåtumsspiken": "tvåtumsspik",
    "tvåtumsspikens": "tvåtumsspik",
    "tvåtumsspiks": "tvåtumsspik",
    "tvåtungade": "tvåtungad",
    "tvåtungades": "tvåtungad",
    "tvåtungads": "tvåtungad",
    "tvåtungat": "tvåtungad",
    "tvåtungats": "tvåtungad",
    "tvåtusentalet": "tvåtusental",
    "tvåtusentalets": "tvåtusental",
    "tvåtusentals": "tvåtusental",
    "tvåving": "tvåvinge",
    "tvåvingar": "tvåvinge",
    "tvåvingarna": "tvåvinge",
    "tvåvingarnas": "tvåvinge",
    "tvåvingars": "tvåvinge",
    "tvåvingen": "tvåvinge",
    "tvåvingens": "tvåvinge",
    "tvåvinges": "tvåvinge",
    "tvåvings": "tvåvinge",
    "tvåvåningsbussar": "tvåvåningsbuss",
    "tvåvåningsbussarna": "tvåvåningsbuss",
    "tvåvåningsbussarnas": "tvåvåningsbuss",
    "tvåvåningsbussars": "tvåvåningsbuss",
    "tvåvåningsbussen": "tvåvåningsbuss",
    "tvåvåningsbussens": "tvåvåningsbuss",
    "tvåäggstvillingar": "tvåäggstvilling",
    "tvåäggstvillingarna": "tvåäggstvilling",
    "tvåäggstvillingarnas": "tvåäggstvilling",
    "tvåäggstvillingars": "tvåäggstvilling",
    "tvåäggstvillingen": "tvåäggstvilling",
    "tvåäggstvillingens": "tvåäggstvilling",
    "tvåäggstvillings": "tvåäggstvilling",
    "tvååriga": "tvåårig",
    "tvåårigas": "tvåårig",
    "tvåårige": "tvåårig",
    "tvååriges": "tvåårig",
    "tvåårigs": "tvåårig",
    "tvåårigt": "tvåårig",
    "tvåårigts": "tvåårig",
    "tvååringar": "tvååring",
    "tvååringarna": "tvååring",
    "tvååringarnas": "tvååring",
    "tvååringars": "tvååring",
    "tvååringen": "tvååring",
    "tvååringens": "tvååring",
    "tvåårings": "tvååring",
    "tvåöringar": "tvåöring",
    "tvåöringarna": "tvåöring",
    "tvåöringarnas": "tvåöring",
    "tvåöringars": "tvåöring",
    "tvåöringen": "tvåöring",
    "tvåöringens": "tvåöring",
    "tvåörings": "tvåöring",
    "tweeden": "tweed",
    "tweedens": "tweed",
    "tweedkavajen": "tweedkavaj",
    "tweedkavajens": "tweedkavaj",
    "tweedkavajer": "tweedkavaj",
    "tweedkavajerna": "tweedkavaj",
    "tweedkavajernas": "tweedkavaj",
    "tweedkavajers": "tweedkavaj",
    "tweedkavajs": "tweedkavaj",
    "tweeds": "tweed",
    "twillen": "twill",
    "twillens": "twill",
    "twills": "twill",
    "twist": "twista",
    "twistade": "twista",
    "twistades": "twista",
    "twistande": "twista",
    "twistanden": "twistande",
    "twistandena": "twistande",
    "twistandenas": "twistande",
    "twistandens": "twistande",
    "twistandes": "twistande",
    "twistandet": "twistande",
    "twistandets": "twistande",
    "twistar": "twista",
    "twistas": "twista",
    "twistat": "twista",
    "twistats": "twista",
    "twisten": "twist",
    "twistens": "twist",
    "twists": "twist",
    "twittrad": "twittra",
    "twittrade": "twittra",
    "twittrades": "twittra",
    "twittrads": "twittra",
    "twittrande": "twittra",
    "twittranden": "twittrande",
    "twittrandena": "twittrande",
    "twittrandenas": "twittrande",
    "twittrandens": "twittrande",
    "twittrandes": "twittrande",
    "twittrandet": "twittrande",
    "twittrandets": "twittrande",
    "twittrar": "twittra",
    "twittras": "twittra",
    "twittrat": "twittra",
    "twittrats": "twittra",
    "ty": "tya",
    "tyad": "tya",
    "tyade": "tya",
    "tyades": "tya",
    "tyads": "tya",
    "tyande": "tya",
    "tyanden": "tyande",
    "tyandena": "tyande",
    "tyandenas": "tyande",
    "tyandens": "tyande",
    "tyandes": "tyande",
    "tyandet": "tyande",
    "tyandets": "tyande",
    "tyar": "tya",
    "tyas": "tya",
    "tyat": "tya",
    "tyats": "tya",
    "tyck": "tycka",
    "tyckande": "tycka",
    "tyckanden": "tyckande",
    "tyckandena": "tyckande",
    "tyckandenas": "tyckande",
    "tyckandens": "tyckande",
    "tyckandes": "tyckande",
    "tyckandet": "tyckande",
    "tyckandets": "tyckande",
    "tyckar": "tyckare",
    "tyckaren": "tyckare",
    "tyckarens": "tyckare",
    "tyckares": "tyckare",
    "tyckarna": "tyckare",
    "tyckarnas": "tyckare",
    "tyckas": "tycka",
    "tycken": "tycke",
    "tyckena": "tycke",
    "tyckenas": "tycke",
    "tyckens": "tycke",
    "tycker": "tycka",
    "tyckes": "tycke",
    "tycket": "tycke",
    "tyckets": "tycke",
    "tyckmyckens": "tyckmycken",
    "tyckmycket": "tyckmycken",
    "tyckmyckets": "tyckmycken",
    "tyckmyckna": "tyckmycken",
    "tyckmycknare": "tyckmycken",
    "tyckmycknares": "tyckmycken",
    "tyckmycknas": "tyckmycken",
    "tyckmycknast": "tyckmycken",
    "tyckmycknaste": "tyckmycken",
    "tyckmycknastes": "tyckmycken",
    "tyckmycknasts": "tyckmycken",
    "tyckmyckne": "tyckmycken",
    "tyckmycknes": "tyckmycken",
    "tycks": "tycke",
    "tyckt": "tycka",
    "tyckta": "tycka",
    "tycktas": "tycka",
    "tyckte": "tycka",
    "tycktes": "tyckas",
    "tyckts": "tyckas",
    "tyd": "tyda",
    "tydan": "tyda",
    "tydande": "tyda",
    "tydanden": "tydande",
    "tydandena": "tydande",
    "tydandenas": "tydande",
    "tydandens": "tydande",
    "tydandes": "tydande",
    "tydandet": "tydande",
    "tydandets": "tydande",
    "tydans": "tyda",
    "tydas": "tyda",
    "tydbara": "tydbar",
    "tydbarare": "tydbar",
    "tydbarares": "tydbar",
    "tydbaras": "tydbar",
    "tydbarast": "tydbar",
    "tydbaraste": "tydbar",
    "tydbarastes": "tydbar",
    "tydbarasts": "tydbar",
    "tydbare": "tydbar",
    "tydbares": "tydbar",
    "tydbarheten": "tydbarhet",
    "tydbarhetens": "tydbarhet",
    "tydbarhets": "tydbarhet",
    "tydbars": "tydbar",
    "tydbart": "tydbar",
    "tydbarts": "tydbar",
    "tydd": "tyda",
    "tydda": "tyda",
    "tyddas": "tyda",
    "tydde": "tyda",
    "tyddes": "tyda",
    "tydds": "tyda",
    "tyde": "tyda",
    "tyder": "tyda",
    "tydes": "tyda",
    "tydliga": "tydlig",
    "tydligare": "tydlig",
    "tydligares": "tydlig",
    "tydligas": "tydlig",
    "tydligast": "tydlig",
    "tydligaste": "tydlig",
    "tydligastes": "tydlig",
    "tydligasts": "tydlig",
    "tydlige": "tydlig",
    "tydliges": "tydlig",
    "tydliggjord": "tydliggöra",
    "tydliggjorda": "tydliggöra",
    "tydliggjordas": "tydliggöra",
    "tydliggjorde": "tydliggöra",
    "tydliggjordes": "tydliggöra",
    "tydliggjords": "tydliggöra",
    "tydliggjort": "tydliggöra",
    "tydliggjorts": "tydliggöra",
    "tydliggör": "tydliggöra",
    "tydliggörande": "tydliggöra",
    "tydliggöranden": "tydliggörande",
    "tydliggörandena": "tydliggörande",
    "tydliggörandenas": "tydliggörande",
    "tydliggörandens": "tydliggörande",
    "tydliggörandes": "tydliggörande",
    "tydliggörandet": "tydliggörande",
    "tydliggörandets": "tydliggörande",
    "tydliggöras": "tydliggöra",
    "tydliggöres": "tydliggöra",
    "tydliggörs": "tydliggöra",
    "tydligheten": "tydlighet",
    "tydlighetens": "tydlighet",
    "tydligheter": "tydlighet",
    "tydligheterna": "tydlighet",
    "tydligheternas": "tydlighet",
    "tydligheters": "tydlighet",
    "tydlighets": "tydlighet",
    "tydlighetskommateringar": "tydlighetskommatering",
    "tydlighetskommateringarna": "tydlighetskommatering",
    "tydlighetskommateringarnas": "tydlighetskommatering",
    "tydlighetskommateringars": "tydlighetskommatering",
    "tydlighetskommateringen": "tydlighetskommatering",
    "tydlighetskommateringens": "tydlighetskommatering",
    "tydlighetskommaterings": "tydlighetskommatering",
    "tydligs": "tydlig",
    "tydligt": "tydlig",
    "tydligts": "tydlig",
    "tydor": "tyda",
    "tydorna": "tyda",
    "tydornas": "tyda",
    "tydors": "tyda",
    "tyds": "tyda",
    "tyfoidbakterien": "tyfoidbakterie",
    "tyfoidbakteriens": "tyfoidbakterie",
    "tyfoidbakterier": "tyfoidbakterie",
    "tyfoidbakterierna": "tyfoidbakterie",
    "tyfoidbakteriernas": "tyfoidbakterie",
    "tyfoidbakteriers": "tyfoidbakterie",
    "tyfoidbakteries": "tyfoidbakterie",
    "tyfoidepidemien": "tyfoidepidemi",
    "tyfoidepidemiens": "tyfoidepidemi",
    "tyfoidepidemier": "tyfoidepidemi",
    "tyfoidepidemierna": "tyfoidepidemi",
    "tyfoidepidemiernas": "tyfoidepidemi",
    "tyfoidepidemiers": "tyfoidepidemi",
    "tyfoidepidemin": "tyfoidepidemi",
    "tyfoidepidemins": "tyfoidepidemi",
    "tyfoidepidemis": "tyfoidepidemi",
    "tyfoidfebern": "tyfoidfeber",
    "tyfoidfeberns": "tyfoidfeber",
    "tyfoidfebers": "tyfoidfeber",
    "tyfonen": "tyfon",
    "tyfonens": "tyfon",
    "tyfoner": "tyfon",
    "tyfonerna": "tyfon",
    "tyfonernas": "tyfon",
    "tyfoners": "tyfon",
    "tyfons": "tyfon",
    "tyfusen": "tyfus",
    "tyfusens": "tyfus",
    "tygbanden": "tygband",
    "tygbandens": "tygband",
    "tygbandet": "tygband",
    "tygbandets": "tygband",
    "tygbands": "tygband",
    "tygbollar": "tygboll",
    "tygbollarna": "tygboll",
    "tygbollarnas": "tygboll",
    "tygbollars": "tygboll",
    "tygbollen": "tygboll",
    "tygbollens": "tygboll",
    "tygbolls": "tygboll",
    "tygbommar": "tygbom",
    "tygbommarna": "tygbom",
    "tygbommarnas": "tygbom",
    "tygbommars": "tygbom",
    "tygbommen": "tygbom",
    "tygbommens": "tygbom",
    "tygboms": "tygbom",
    "tygbredden": "tygbredd",
    "tygbreddens": "tygbredd",
    "tygbredder": "tygbredd",
    "tygbredderna": "tygbredd",
    "tygbreddernas": "tygbredd",
    "tygbredders": "tygbredd",
    "tygbredds": "tygbredd",
    "tygel": "tygla",
    "tygellösa": "tygellös",
    "tygellösare": "tygellös",
    "tygellösares": "tygellös",
    "tygellösas": "tygellös",
    "tygellösast": "tygellös",
    "tygellösaste": "tygellös",
    "tygellösastes": "tygellös",
    "tygellösasts": "tygellös",
    "tygellöse": "tygellös",
    "tygellöses": "tygellös",
    "tygellösheten": "tygellöshet",
    "tygellöshetens": "tygellöshet",
    "tygellöshets": "tygellöshet",
    "tygellöst": "tygellös",
    "tygellösts": "tygellös",
    "tygeln": "tygel",
    "tygelns": "tygel",
    "tygels": "tygel",
    "tygen": "tyg",
    "tygens": "tyg",
    "tyger": "tyg",
    "tygerna": "tyg",
    "tygernas": "tyg",
    "tygers": "tyg",
    "tyget": "tyg",
    "tygets": "tyg",
    "tygkanten": "tygkant",
    "tygkantens": "tygkant",
    "tygkanter": "tygkant",
    "tygkanterna": "tygkant",
    "tygkanternas": "tygkant",
    "tygkanters": "tygkant",
    "tygkants": "tygkant",
    "tyglad": "tygla",
    "tyglade": "tygla",
    "tyglades": "tygla",
    "tyglads": "tygla",
    "tyglande": "tygla",
    "tyglanden": "tyglande",
    "tyglandena": "tyglande",
    "tyglandenas": "tyglande",
    "tyglandens": "tyglande",
    "tyglandes": "tyglande",
    "tyglandet": "tyglande",
    "tyglandets": "tyglande",
    "tyglappar": "tyglapp",
    "tyglapparna": "tyglapp",
    "tyglapparnas": "tyglapp",
    "tyglappars": "tyglapp",
    "tyglappen": "tyglapp",
    "tyglappens": "tyglapp",
    "tyglapps": "tyglapp",
    "tyglar": "tygla",
    "tyglarna": "tygel",
    "tyglarnas": "tygel",
    "tyglars": "tygel",
    "tyglas": "tygla",
    "tyglat": "tygla",
    "tyglats": "tygla",
    "tygmaterielen": "tygmateriel",
    "tygmaterielens": "tygmateriel",
    "tygmateriels": "tygmateriel",
    "tygproven": "tygprov",
    "tygprovens": "tygprov",
    "tygprover": "tygprov",
    "tygproverna": "tygprov",
    "tygprovernas": "tygprov",
    "tygprovers": "tygprov",
    "tygprovet": "tygprov",
    "tygprovets": "tygprov",
    "tygprovs": "tygprov",
    "tygrems": "tygremsa",
    "tygremsan": "tygremsa",
    "tygremsans": "tygremsa",
    "tygremsas": "tygremsa",
    "tygremse": "tygremsa",
    "tygremsor": "tygremsa",
    "tygremsorna": "tygremsa",
    "tygremsornas": "tygremsa",
    "tygremsors": "tygremsa",
    "tygresten": "tygrest",
    "tygrestens": "tygrest",
    "tygrester": "tygrest",
    "tygresterna": "tygrest",
    "tygresternas": "tygrest",
    "tygresters": "tygrest",
    "tygrests": "tygrest",
    "tygrull": "tygrulle",
    "tygrullar": "tygrulle",
    "tygrullarna": "tygrulle",
    "tygrullarnas": "tygrulle",
    "tygrullars": "tygrulle",
    "tygrullen": "tygrulle",
    "tygrullens": "tygrulle",
    "tygrulles": "tygrulle",
    "tygrulls": "tygrulle",
    "tygs": "tyg",
    "tygsjoken": "tygsjok",
    "tygsjokens": "tygsjok",
    "tygsjoket": "tygsjok",
    "tygsjokets": "tygsjok",
    "tygsjoks": "tygsjok",
    "tygskon": "tygsko",
    "tygskons": "tygsko",
    "tygskor": "tygsko",
    "tygskorna": "tygsko",
    "tygskornas": "tygsko",
    "tygskors": "tygsko",
    "tygskos": "tygsko",
    "tygstycken": "tygstycke",
    "tygstyckena": "tygstycke",
    "tygstyckenas": "tygstycke",
    "tygstyckens": "tygstycke",
    "tygstyckes": "tygstycke",
    "tygstycket": "tygstycke",
    "tygstyckets": "tygstycke",
    "tygstycks": "tygstycke",
    "tygtjänsten": "tygtjänst",
    "tygtjänstens": "tygtjänst",
    "tygtjänsts": "tygtjänst",
    "tygtras": "tygtrasa",
    "tygtrasan": "tygtrasa",
    "tygtrasans": "tygtrasa",
    "tygtrasas": "tygtrasa",
    "tygtrase": "tygtrasa",
    "tygtrasor": "tygtrasa",
    "tygtrasorna": "tygtrasa",
    "tygtrasornas": "tygtrasa",
    "tygtrasors": "tygtrasa",
    "tygtrycken": "tygtryck",
    "tygtryckens": "tygtryck",
    "tygtrycket": "tygtryck",
    "tygtryckets": "tygtryck",
    "tygtrycks": "tygtryck",
    "tygöverdragen": "tygöverdrag",
    "tygöverdragens": "tygöverdrag",
    "tygöverdraget": "tygöverdrag",
    "tygöverdragets": "tygöverdrag",
    "tygöverdrags": "tygöverdrag",
    "tykenheten": "tykenhet",
    "tykenhetens": "tykenhet",
    "tykenheter": "tykenhet",
    "tykenheterna": "tykenhet",
    "tykenheternas": "tykenhet",
    "tykenheters": "tykenhet",
    "tykenhets": "tykenhet",
    "tykens": "tyken",
    "tyket": "tyken",
    "tykets": "tyken",
    "tykna": "tyken",
    "tyknare": "tyken",
    "tyknares": "tyken",
    "tyknas": "tyken",
    "tyknast": "tyken",
    "tyknaste": "tyken",
    "tyknastes": "tyken",
    "tyknasts": "tyken",
    "tykne": "tyken",
    "tyknes": "tyken",
    "tykobrahedagar": "tykobrahedag",
    "tykobrahedagarna": "tykobrahedag",
    "tykobrahedagarnas": "tykobrahedag",
    "tykobrahedagars": "tykobrahedag",
    "tykobrahedagen": "tykobrahedag",
    "tykobrahedagens": "tykobrahedag",
    "tykobrahedags": "tykobrahedag",
    "tykänndes": "tykännas",
    "tykänns": "tykännas",
    "tykännts": "tykännas",
    "tyllen": "tyll",
    "tyllens": "tyll",
    "tyllet": "tyll",
    "tyllets": "tyll",
    "tylls": "tyll",
    "tyllschalar": "tyllschal",
    "tyllschalarna": "tyllschal",
    "tyllschalarnas": "tyllschal",
    "tyllschalars": "tyllschal",
    "tyllschalen": "tyllschal",
    "tyllschalens": "tyllschal",
    "tyllschals": "tyllschal",
    "tyllsjalar": "tyllsjal",
    "tyllsjalarna": "tyllsjal",
    "tyllsjalarnas": "tyllsjal",
    "tyllsjalars": "tyllsjal",
    "tyllsjalen": "tyllsjal",
    "tyllsjalens": "tyllsjal",
    "tyllsjals": "tyllsjal",
    "tympanonen": "tympanon",
    "tympanonens": "tympanon",
    "tympanoner": "tympanon",
    "tympanonerna": "tympanon",
    "tympanonernas": "tympanon",
    "tympanoners": "tympanon",
    "tympanons": "tympanon",
    "tymusen": "tymus",
    "tymusens": "tymus",
    "tyn": "tyna",
    "tynad": "tyna",
    "tynade": "tyna",
    "tynades": "tyna",
    "tynads": "tyna",
    "tynande": "tyna",
    "tynanden": "tynande",
    "tynandena": "tynande",
    "tynandenas": "tynande",
    "tynandens": "tynande",
    "tynandes": "tynande",
    "tynandet": "tynande",
    "tynandets": "tynande",
    "tynar": "tyna",
    "tynas": "tyna",
    "tynat": "tyna",
    "tynats": "tyna",
    "tyng": "tynga",
    "tyngande": "tynga",
    "tynganden": "tyngande",
    "tyngandena": "tyngande",
    "tyngandenas": "tyngande",
    "tyngandens": "tyngande",
    "tyngandes": "tyngande",
    "tyngandet": "tyngande",
    "tyngandets": "tyngande",
    "tyngas": "tynga",
    "tyngd": "tynga",
    "tyngda": "tynga",
    "tyngdaccelerationen": "tyngdacceleration",
    "tyngdaccelerationens": "tyngdacceleration",
    "tyngdaccelerationer": "tyngdacceleration",
    "tyngdaccelerationerna": "tyngdacceleration",
    "tyngdaccelerationernas": "tyngdacceleration",
    "tyngdaccelerationers": "tyngdacceleration",
    "tyngdaccelerations": "tyngdacceleration",
    "tyngdas": "tynga",
    "tyngde": "tynga",
    "tyngden": "tyngd",
    "tyngdens": "tyngd",
    "tyngder": "tyngd",
    "tyngderna": "tyngd",
    "tyngdernas": "tyngd",
    "tyngders": "tyngd",
    "tyngdes": "tynga",
    "tyngdkraften": "tyngdkraft",
    "tyngdkraftens": "tyngdkraft",
    "tyngdkrafts": "tyngdkraft",
    "tyngdkraftsstörningar": "tyngdkraftsstörning",
    "tyngdkraftsstörningarna": "tyngdkraftsstörning",
    "tyngdkraftsstörningarnas": "tyngdkraftsstörning",
    "tyngdkraftsstörningars": "tyngdkraftsstörning",
    "tyngdkraftsstörningen": "tyngdkraftsstörning",
    "tyngdkraftsstörningens": "tyngdkraftsstörning",
    "tyngdkraftsstörnings": "tyngdkraftsstörning",
    "tyngdlagen": "tyngdlag",
    "tyngdlagens": "tyngdlag",
    "tyngdlags": "tyngdlag",
    "tyngdlyftar": "tyngdlyftare",
    "tyngdlyftaren": "tyngdlyftare",
    "tyngdlyftarens": "tyngdlyftare",
    "tyngdlyftares": "tyngdlyftare",
    "tyngdlyftarna": "tyngdlyftare",
    "tyngdlyftarnas": "tyngdlyftare",
    "tyngdlyftningar": "tyngdlyftning",
    "tyngdlyftningarna": "tyngdlyftning",
    "tyngdlyftningarnas": "tyngdlyftning",
    "tyngdlyftningars": "tyngdlyftning",
    "tyngdlyftningen": "tyngdlyftning",
    "tyngdlyftningens": "tyngdlyftning",
    "tyngdlyftnings": "tyngdlyftning",
    "tyngdlösa": "tyngdlös",
    "tyngdlösare": "tyngdlös",
    "tyngdlösares": "tyngdlös",
    "tyngdlösas": "tyngdlös",
    "tyngdlösast": "tyngdlös",
    "tyngdlösaste": "tyngdlös",
    "tyngdlösastes": "tyngdlös",
    "tyngdlösasts": "tyngdlös",
    "tyngdlöse": "tyngdlös",
    "tyngdlöses": "tyngdlös",
    "tyngdlösheten": "tyngdlöshet",
    "tyngdlöshetens": "tyngdlöshet",
    "tyngdlösheter": "tyngdlöshet",
    "tyngdlösheterna": "tyngdlöshet",
    "tyngdlösheternas": "tyngdlöshet",
    "tyngdlösheters": "tyngdlöshet",
    "tyngdlöshets": "tyngdlöshet",
    "tyngdlöst": "tyngdlös",
    "tyngdlösts": "tyngdlös",
    "tyngdpunkten": "tyngdpunkt",
    "tyngdpunktens": "tyngdpunkt",
    "tyngdpunkter": "tyngdpunkt",
    "tyngdpunkterna": "tyngdpunkt",
    "tyngdpunkternas": "tyngdpunkt",
    "tyngdpunkters": "tyngdpunkt",
    "tyngdpunkts": "tyngdpunkt",
    "tyngds": "tyngd",
    "tynger": "tynga",
    "tynges": "tynga",
    "tyngre": "tung",
    "tyngres": "tung",
    "tyngs": "tynga",
    "tyngst": "tung",
    "tyngsta": "tung",
    "tyngstas": "tung",
    "tyngste": "tung",
    "tyngstes": "tung",
    "tyngsts": "tung",
    "tyngt": "tynga",
    "tyngts": "tynga",
    "typbesiktningar": "typbesiktning",
    "typbesiktningarna": "typbesiktning",
    "typbesiktningarnas": "typbesiktning",
    "typbesiktningars": "typbesiktning",
    "typbesiktningen": "typbesiktning",
    "typbesiktningens": "typbesiktning",
    "typbesiktnings": "typbesiktning",
    "typen": "typ",
    "typens": "typ",
    "typer": "typ",
    "typerna": "typ",
    "typernas": "typ",
    "typers": "typ",
    "typexempels": "typexempel",
    "typexemplen": "typexempel",
    "typexemplens": "typexempel",
    "typexemplet": "typexempel",
    "typexemplets": "typexempel",
    "typfallen": "typfall",
    "typfallens": "typfall",
    "typfallet": "typfall",
    "typfallets": "typfall",
    "typfalls": "typfall",
    "typifierad": "typifiera",
    "typifierade": "typifiera",
    "typifierades": "typifiera",
    "typifierads": "typifiera",
    "typifierande": "typifiera",
    "typifieranden": "typifierande",
    "typifierandena": "typifierande",
    "typifierandenas": "typifierande",
    "typifierandens": "typifierande",
    "typifierandes": "typifierande",
    "typifierandet": "typifierande",
    "typifierandets": "typifierande",
    "typifierar": "typifiera",
    "typifieras": "typifiera",
    "typifierat": "typifiera",
    "typifierats": "typifiera",
    "typifierbara": "typifierbar",
    "typifierbarare": "typifierbar",
    "typifierbarares": "typifierbar",
    "typifierbaras": "typifierbar",
    "typifierbarast": "typifierbar",
    "typifierbaraste": "typifierbar",
    "typifierbarastes": "typifierbar",
    "typifierbarasts": "typifierbar",
    "typifierbare": "typifierbar",
    "typifierbares": "typifierbar",
    "typifierbarheten": "typifierbarhet",
    "typifierbarhetens": "typifierbarhet",
    "typifierbarhets": "typifierbarhet",
    "typifierbars": "typifierbar",
    "typifierbart": "typifierbar",
    "typifierbarts": "typifierbar",
    "typifieringar": "typifiering",
    "typifieringarna": "typifiering",
    "typifieringarnas": "typifiering",
    "typifieringars": "typifiering",
    "typifieringen": "typifiering",
    "typifieringens": "typifiering",
    "typifierings": "typifiering",
    "typiserad": "typisera",
    "typiserade": "typisera",
    "typiserades": "typisera",
    "typiserads": "typisera",
    "typiserande": "typisera",
    "typiseranden": "typiserande",
    "typiserandena": "typiserande",
    "typiserandenas": "typiserande",
    "typiserandens": "typiserande",
    "typiserandes": "typiserande",
    "typiserandet": "typiserande",
    "typiserandets": "typiserande",
    "typiserar": "typisera",
    "typiseras": "typisera",
    "typiserat": "typisera",
    "typiserats": "typisera",
    "typiserbara": "typiserbar",
    "typiserbarare": "typiserbar",
    "typiserbarares": "typiserbar",
    "typiserbaras": "typiserbar",
    "typiserbarast": "typiserbar",
    "typiserbaraste": "typiserbar",
    "typiserbarastes": "typiserbar",
    "typiserbarasts": "typiserbar",
    "typiserbare": "typiserbar",
    "typiserbares": "typiserbar",
    "typiserbarheten": "typiserbarhet",
    "typiserbarhetens": "typiserbarhet",
    "typiserbarhets": "typiserbarhet",
    "typiserbars": "typiserbar",
    "typiserbart": "typiserbar",
    "typiserbarts": "typiserbar",
    "typiseringar": "typisering",
    "typiseringarna": "typisering",
    "typiseringarnas": "typisering",
    "typiseringars": "typisering",
    "typiseringen": "typisering",
    "typiseringens": "typisering",
    "typiserings": "typisering",
    "typiska": "typisk",
    "typiskare": "typisk",
    "typiskares": "typisk",
    "typiskas": "typisk",
    "typiskast": "typisk",
    "typiskaste": "typisk",
    "typiskastes": "typisk",
    "typiskasts": "typisk",
    "typiske": "typisk",
    "typiskes": "typisk",
    "typisks": "typisk",
    "typiskt": "typisk",
    "typiskts": "typisk",
    "typnummerna": "typnummer",
    "typnummernas": "typnummer",
    "typnummers": "typnummer",
    "typnumren": "typnummer",
    "typnumrens": "typnummer",
    "typnumret": "typnummer",
    "typnumrets": "typnummer",
    "typografen": "typograf",
    "typografens": "typograf",
    "typografer": "typograf",
    "typograferna": "typograf",
    "typografernas": "typograf",
    "typografers": "typograf",
    "typografien": "typografi",
    "typografiens": "typografi",
    "typografier": "typografi",
    "typografierna": "typografi",
    "typografiernas": "typografi",
    "typografiers": "typografi",
    "typografin": "typografi",
    "typografins": "typografi",
    "typografis": "typografi",
    "typografiska": "typografisk",
    "typografiskare": "typografisk",
    "typografiskares": "typografisk",
    "typografiskas": "typografisk",
    "typografiskast": "typografisk",
    "typografiskaste": "typografisk",
    "typografiskastes": "typografisk",
    "typografiskasts": "typografisk",
    "typografiske": "typografisk",
    "typografiskes": "typografisk",
    "typografisks": "typografisk",
    "typografiskt": "typografisk",
    "typografiskts": "typografisk",
    "typografs": "typograf",
    "typologien": "typologi",
    "typologiens": "typologi",
    "typologier": "typologi",
    "typologierna": "typologi",
    "typologiernas": "typologi",
    "typologiers": "typologi",
    "typologin": "typologi",
    "typologins": "typologi",
    "typologis": "typologi",
    "typs": "typ",
    "typsnitten": "typsnitt",
    "typsnittens": "typsnitt",
    "typsnittet": "typsnitt",
    "typsnittets": "typsnitt",
    "typsnitts": "typsnitt",
    "typvärden": "typvärde",
    "typvärdena": "typvärde",
    "typvärdenas": "typvärde",
    "typvärdens": "typvärde",
    "typvärdes": "typvärde",
    "typvärdet": "typvärde",
    "typvärdets": "typvärde",
    "tyrannen": "tyrann",
    "tyrannens": "tyrann",
    "tyranner": "tyrann",
    "tyrannerna": "tyrann",
    "tyrannernas": "tyrann",
    "tyranners": "tyrann",
    "tyranniet": "tyranni",
    "tyranniets": "tyranni",
    "tyrannis": "tyranni",
    "tyranniserad": "tyrannisera",
    "tyranniserade": "tyrannisera",
    "tyranniserades": "tyrannisera",
    "tyranniserads": "tyrannisera",
    "tyranniserande": "tyrannisera",
    "tyranniseranden": "tyranniserande",
    "tyranniserandena": "tyranniserande",
    "tyranniserandenas": "tyranniserande",
    "tyranniserandens": "tyranniserande",
    "tyranniserandes": "tyranniserande",
    "tyranniserandet": "tyranniserande",
    "tyranniserandets": "tyranniserande",
    "tyranniserar": "tyrannisera",
    "tyranniseras": "tyrannisera",
    "tyranniserat": "tyrannisera",
    "tyranniserats": "tyrannisera",
    "tyranniserbara": "tyranniserbar",
    "tyranniserbarare": "tyranniserbar",
    "tyranniserbarares": "tyranniserbar",
    "tyranniserbaras": "tyranniserbar",
    "tyranniserbarast": "tyranniserbar",
    "tyranniserbaraste": "tyranniserbar",
    "tyranniserbarastes": "tyranniserbar",
    "tyranniserbarasts": "tyranniserbar",
    "tyranniserbare": "tyranniserbar",
    "tyranniserbares": "tyranniserbar",
    "tyranniserbarheten": "tyranniserbarhet",
    "tyranniserbarhetens": "tyranniserbarhet",
    "tyranniserbarhets": "tyranniserbarhet",
    "tyranniserbars": "tyranniserbar",
    "tyranniserbart": "tyranniserbar",
    "tyranniserbarts": "tyranniserbar",
    "tyranniseringar": "tyrannisering",
    "tyranniseringarna": "tyrannisering",
    "tyranniseringarnas": "tyrannisering",
    "tyranniseringars": "tyrannisering",
    "tyranniseringen": "tyrannisering",
    "tyranniseringens": "tyrannisering",
    "tyranniserings": "tyrannisering",
    "tyranniska": "tyrannisk",
    "tyranniskare": "tyrannisk",
    "tyranniskares": "tyrannisk",
    "tyranniskas": "tyrannisk",
    "tyranniskast": "tyrannisk",
    "tyranniskaste": "tyrannisk",
    "tyranniskastes": "tyrannisk",
    "tyranniskasts": "tyrannisk",
    "tyranniske": "tyrannisk",
    "tyranniskes": "tyrannisk",
    "tyrannisks": "tyrannisk",
    "tyranniskt": "tyrannisk",
    "tyranniskts": "tyrannisk",
    "tyrannit": "tyranni",
    "tyrannits": "tyranni",
    "tyranns": "tyrann",
    "tyres": "tyre",
    "tyret": "tyre",
    "tyrets": "tyre",
    "tyristorer": "tyristor",
    "tyristorerna": "tyristor",
    "tyristorernas": "tyristor",
    "tyristorers": "tyristor",
    "tyristorn": "tyristor",
    "tyristorns": "tyristor",
    "tyristors": "tyristor",
    "tyrolar": "tyrolare",
    "tyrolaren": "tyrolare",
    "tyrolarens": "tyrolare",
    "tyrolares": "tyrolare",
    "tyrolarna": "tyrolare",
    "tyrolarnas": "tyrolare",
    "tyrolerhattar": "tyrolerhatt",
    "tyrolerhattarna": "tyrolerhatt",
    "tyrolerhattarnas": "tyrolerhatt",
    "tyrolerhattars": "tyrolerhatt",
    "tyrolerhatten": "tyrolerhatt",
    "tyrolerhattens": "tyrolerhatt",
    "tyrolerhatts": "tyrolerhatt",
    "tyrolska": "tyrolsk",
    "tyrolskan": "tyrolska",
    "tyrolskans": "tyrolska",
    "tyrolskare": "tyrolsk",
    "tyrolskares": "tyrolsk",
    "tyrolskas": "tyrolska",
    "tyrolskast": "tyrolsk",
    "tyrolskaste": "tyrolsk",
    "tyrolskastes": "tyrolsk",
    "tyrolskasts": "tyrolsk",
    "tyrolske": "tyrolska",
    "tyrolskes": "tyrolsk",
    "tyrolskor": "tyrolska",
    "tyrolskorna": "tyrolska",
    "tyrolskornas": "tyrolska",
    "tyrolskors": "tyrolska",
    "tyrolsks": "tyrolsk",
    "tyrolskt": "tyrolsk",
    "tyrolskts": "tyrolsk",
    "tysk": "tyska",
    "tysk-romerska": "tysk-romersk",
    "tysk-romerskas": "tysk-romersk",
    "tysk-romerske": "tysk-romersk",
    "tysk-romerskes": "tysk-romersk",
    "tysk-romersks": "tysk-romersk",
    "tysk-romerskt": "tysk-romersk",
    "tysk-romerskts": "tysk-romersk",
    "tysk-schweiziska": "tysk-schweizisk",
    "tysk-schweiziskas": "tysk-schweizisk",
    "tysk-schweiziske": "tysk-schweizisk",
    "tysk-schweiziskes": "tysk-schweizisk",
    "tysk-schweizisks": "tysk-schweizisk",
    "tysk-schweiziskt": "tysk-schweizisk",
    "tysk-schweiziskts": "tysk-schweizisk",
    "tysk-svenska": "tysk-svensk",
    "tysk-svenskas": "tysk-svensk",
    "tysk-svenske": "tysk-svensk",
    "tysk-svenskes": "tysk-svensk",
    "tysk-svensks": "tysk-svensk",
    "tysk-svenskt": "tysk-svensk",
    "tysk-svenskts": "tysk-svensk",
    "tyska": "tysk",
    "tyskan": "tyska",
    "tyskans": "tyska",
    "tyskar": "tysk",
    "tyskare": "tysk",
    "tyskares": "tysk",
    "tyskarna": "tysk",
    "tyskarnas": "tysk",
    "tyskars": "tysk",
    "tyskas": "tyska",
    "tyskast": "tysk",
    "tyskaste": "tysk",
    "tyskastes": "tysk",
    "tyskasts": "tysk",
    "tyske": "tyska",
    "tysken": "tysk",
    "tyskens": "tysk",
    "tyskes": "tysk",
    "tyskhar": "tyskhare",
    "tyskharar": "tyskhare",
    "tyskhararna": "tyskhare",
    "tyskhararnas": "tyskhare",
    "tyskharars": "tyskhare",
    "tyskharen": "tyskhare",
    "tyskharens": "tyskhare",
    "tyskhares": "tyskhare",
    "tyskhars": "tyskhare",
    "tyskhaten": "tyskhat",
    "tyskhatens": "tyskhat",
    "tyskhatet": "tyskhat",
    "tyskhatets": "tyskhat",
    "tyskhats": "tyskhat",
    "tyskheten": "tyskhet",
    "tyskhetens": "tyskhet",
    "tyskhets": "tyskhet",
    "tyskkursen": "tyskkurs",
    "tyskkursens": "tyskkurs",
    "tyskkurser": "tyskkurs",
    "tyskkurserna": "tyskkurs",
    "tyskkursernas": "tyskkurs",
    "tyskkursers": "tyskkurs",
    "tysklektionen": "tysklektion",
    "tysklektionens": "tysklektion",
    "tysklektioner": "tysklektion",
    "tysklektionerna": "tysklektion",
    "tysklektionernas": "tysklektion",
    "tysklektioners": "tysklektion",
    "tysklektions": "tysklektion",
    "tysklärar": "tysklärare",
    "tyskläraren": "tysklärare",
    "tysklärarens": "tysklärare",
    "tysklärares": "tysklärare",
    "tysklärarna": "tysklärare",
    "tysklärarnas": "tysklärare",
    "tyskor": "tyska",
    "tyskorna": "tyska",
    "tyskornas": "tyska",
    "tyskors": "tyska",
    "tysks": "tysk",
    "tyskspråkiga": "tyskspråkig",
    "tyskspråkigas": "tyskspråkig",
    "tyskspråkige": "tyskspråkig",
    "tyskspråkiges": "tyskspråkig",
    "tyskspråkigheten": "tyskspråkighet",
    "tyskspråkighetens": "tyskspråkighet",
    "tyskspråkighets": "tyskspråkighet",
    "tyskspråkigs": "tyskspråkig",
    "tyskspråkigt": "tyskspråkig",
    "tyskspråkigts": "tyskspråkig",
    "tyskt": "tysk",
    "tyskts": "tysk",
    "tyskundervisningen": "tyskundervisning",
    "tyskundervisningens": "tyskundervisning",
    "tyskundervisnings": "tyskundervisning",
    "tyst": "tysta",
    "tysta": "tyst",
    "tystad": "tysta",
    "tystade": "tysta",
    "tystades": "tysta",
    "tystads": "tysta",
    "tystande": "tysta",
    "tystanden": "tystande",
    "tystandena": "tystande",
    "tystandenas": "tystande",
    "tystandens": "tystande",
    "tystandes": "tystande",
    "tystandet": "tystande",
    "tystandets": "tystande",
    "tystar": "tysta",
    "tystare": "tyst",
    "tystares": "tyst",
    "tystas": "tysta",
    "tystast": "tyst",
    "tystaste": "tyst",
    "tystastes": "tyst",
    "tystasts": "tyst",
    "tystat": "tysta",
    "tystats": "tysta",
    "tyste": "tyst",
    "tystes": "tyst",
    "tystheten": "tysthet",
    "tysthetens": "tysthet",
    "tystheter": "tysthet",
    "tystheterna": "tysthet",
    "tystheternas": "tysthet",
    "tystheters": "tysthet",
    "tysthets": "tysthet",
    "tysthetslöften": "tysthetslöfte",
    "tysthetslöftena": "tysthetslöfte",
    "tysthetslöftenas": "tysthetslöfte",
    "tysthetslöftens": "tysthetslöfte",
    "tysthetslöftes": "tysthetslöfte",
    "tysthetslöftet": "tysthetslöfte",
    "tysthetslöftets": "tysthetslöfte",
    "tystlåtens": "tystlåten",
    "tystlåtet": "tystlåten",
    "tystlåtets": "tystlåten",
    "tystlåtna": "tystlåten",
    "tystlåtnare": "tystlåten",
    "tystlåtnares": "tystlåten",
    "tystlåtnas": "tystlåten",
    "tystlåtnast": "tystlåten",
    "tystlåtnaste": "tystlåten",
    "tystlåtnastes": "tystlåten",
    "tystlåtnasts": "tystlåten",
    "tystlåtne": "tystlåten",
    "tystlåtnes": "tystlåten",
    "tystn": "tystna",
    "tystnad": "tystna",
    "tystnade": "tystna",
    "tystnaden": "tystnad",
    "tystnadens": "tystnad",
    "tystnader": "tystnad",
    "tystnaderna": "tystnad",
    "tystnadernas": "tystnad",
    "tystnaders": "tystnad",
    "tystnades": "tystna",
    "tystnads": "tystnad",
    "tystnadsplikten": "tystnadsplikt",
    "tystnadspliktens": "tystnadsplikt",
    "tystnadsplikts": "tystnadsplikt",
    "tystnande": "tystna",
    "tystnanden": "tystnande",
    "tystnandena": "tystnande",
    "tystnandenas": "tystnande",
    "tystnandens": "tystnande",
    "tystnandes": "tystnande",
    "tystnandet": "tystnande",
    "tystnandets": "tystnande",
    "tystnar": "tystna",
    "tystnas": "tystna",
    "tystnat": "tystna",
    "tystnats": "tystna",
    "tysts": "tyst",
    "tytt": "tyda",
    "tytts": "tyda",
    "täck": "täcka",
    "täcka": "täck",
    "täckadressen": "täckadress",
    "täckadressens": "täckadress",
    "täckadresser": "täckadress",
    "täckadresserna": "täckadress",
    "täckadressernas": "täckadress",
    "täckadressers": "täckadress",
    "täckande": "täcka",
    "täckanden": "täckande",
    "täckandena": "täckande",
    "täckandenas": "täckande",
    "täckandens": "täckande",
    "täckandes": "täckande",
    "täckandet": "täckande",
    "täckandets": "täckande",
    "täckare": "täck",
    "täckares": "täck",
    "täckas": "täcka",
    "täckast": "täck",
    "täckaste": "täck",
    "täckastes": "täck",
    "täckasts": "täck",
    "täckbladen": "täckblad",
    "täckbladens": "täckblad",
    "täckbladet": "täckblad",
    "täckbladets": "täckblad",
    "täckblads": "täckblad",
    "täckdikad": "täckdika",
    "täckdikade": "täckdika",
    "täckdikades": "täckdika",
    "täckdikads": "täckdika",
    "täckdikande": "täckdika",
    "täckdikanden": "täckdikande",
    "täckdikandena": "täckdikande",
    "täckdikandenas": "täckdikande",
    "täckdikandens": "täckdikande",
    "täckdikandes": "täckdikande",
    "täckdikandet": "täckdikande",
    "täckdikandets": "täckdikande",
    "täckdikar": "täckdika",
    "täckdikas": "täckdika",
    "täckdikat": "täckdika",
    "täckdikats": "täckdika",
    "täckdiken": "täckdike",
    "täckdikena": "täckdike",
    "täckdikenas": "täckdike",
    "täckdikens": "täckdike",
    "täckdikes": "täckdike",
    "täckdiket": "täckdike",
    "täckdikets": "täckdike",
    "täckdikningar": "täckdikning",
    "täckdikningarna": "täckdikning",
    "täckdikningarnas": "täckdikning",
    "täckdikningars": "täckdikning",
    "täckdikningen": "täckdikning",
    "täckdikningens": "täckdikning",
    "täckdiknings": "täckdikning",
    "täcke": "täck",
    "täckeliga": "täckelig",
    "täckeligare": "täckelig",
    "täckeligares": "täckelig",
    "täckeligas": "täckelig",
    "täckeligast": "täckelig",
    "täckeligaste": "täckelig",
    "täckeligastes": "täckelig",
    "täckeligasts": "täckelig",
    "täckelige": "täckelig",
    "täckeliges": "täckelig",
    "täckeligheten": "täckelighet",
    "täckelighetens": "täckelighet",
    "täckelighets": "täckelighet",
    "täckeligs": "täckelig",
    "täckeligt": "täckelig",
    "täckeligts": "täckelig",
    "täckelser": "täckelse",
    "täckelserna": "täckelse",
    "täckelsernas": "täckelse",
    "täckelsers": "täckelse",
    "täckelses": "täckelse",
    "täckelset": "täckelse",
    "täckelsets": "täckelse",
    "täcken": "täcke",
    "täckena": "täcke",
    "täckenas": "täcke",
    "täckens": "täcke",
    "täcker": "täcka",
    "täckes": "täcke",
    "täcket": "täcke",
    "täckets": "täcke",
    "täckfärgen": "täckfärg",
    "täckfärgens": "täckfärg",
    "täckfärger": "täckfärg",
    "täckfärgerna": "täckfärg",
    "täckfärgernas": "täckfärg",
    "täckfärgers": "täckfärg",
    "täckfärgs": "täckfärg",
    "täckförbanden": "täckförband",
    "täckförbandens": "täckförband",
    "täckförbandet": "täckförband",
    "täckförbandets": "täckförband",
    "täckförbands": "täckförband",
    "täckglasen": "täckglas",
    "täckglasens": "täckglas",
    "täckglaset": "täckglas",
    "täckglasets": "täckglas",
    "täckheten": "täckhet",
    "täckhetens": "täckhet",
    "täckhets": "täckhet",
    "täckhåren": "täckhår",
    "täckhårens": "täckhår",
    "täckhåret": "täckhår",
    "täckhårets": "täckhår",
    "täckhårs": "täckhår",
    "täckjack": "täckjacka",
    "täckjackan": "täckjacka",
    "täckjackans": "täckjacka",
    "täckjackas": "täckjacka",
    "täckjacke": "täckjacka",
    "täckjackor": "täckjacka",
    "täckjackorna": "täckjacka",
    "täckjackornas": "täckjacka",
    "täckjackors": "täckjacka",
    "täckjacks": "täckjacka",
    "täckmanteln": "täckmantel",
    "täckmantelns": "täckmantel",
    "täckmantels": "täckmantel",
    "täckmantlar": "täckmantel",
    "täckmantlarna": "täckmantel",
    "täckmantlarnas": "täckmantel",
    "täckmantlars": "täckmantel",
    "täckmatt": "täckmatta",
    "täckmattan": "täckmatta",
    "täckmattans": "täckmatta",
    "täckmattas": "täckmatta",
    "täckmatte": "täckmatta",
    "täckmattor": "täckmatta",
    "täckmattorna": "täckmatta",
    "täckmattornas": "täckmatta",
    "täckmattors": "täckmatta",
    "täckmatts": "täckmatta",
    "täcknamnen": "täcknamn",
    "täcknamnens": "täcknamn",
    "täcknamnet": "täcknamn",
    "täcknamnets": "täcknamn",
    "täcknamns": "täcknamn",
    "täckningar": "täckning",
    "täckningarna": "täckning",
    "täckningarnas": "täckning",
    "täckningars": "täckning",
    "täckningen": "täckning",
    "täckningens": "täckning",
    "täcknings": "täckning",
    "täckningsgraden": "täckningsgrad",
    "täckningsgradens": "täckningsgrad",
    "täckningsgrader": "täckningsgrad",
    "täckningsgraderna": "täckningsgrad",
    "täckningsgradernas": "täckningsgrad",
    "täckningsgraders": "täckningsgrad",
    "täckningsgrads": "täckningsgrad",
    "täckningsköpen": "täckningsköp",
    "täckningsköpens": "täckningsköp",
    "täckningsköpet": "täckningsköp",
    "täckningsköpets": "täckningsköp",
    "täckningsköps": "täckningsköp",
    "täckorden": "täckord",
    "täckordens": "täckord",
    "täckordet": "täckord",
    "täckordets": "täckord",
    "täckords": "täckord",
    "täckorganisationen": "täckorganisation",
    "täckorganisationens": "täckorganisation",
    "täckorganisationer": "täckorganisation",
    "täckorganisationerna": "täckorganisation",
    "täckorganisationernas": "täckorganisation",
    "täckorganisationers": "täckorganisation",
    "täckorganisations": "täckorganisation",
    "täcks": "täcke",
    "täckt": "täcka",
    "täckta": "täckt",
    "täcktare": "täckt",
    "täcktares": "täckt",
    "täcktas": "täckt",
    "täcktast": "täckt",
    "täcktaste": "täckt",
    "täcktastes": "täckt",
    "täcktasts": "täckt",
    "täckte": "täckt",
    "täcktes": "täckt",
    "täckts": "täckt",
    "täckving": "täckvinge",
    "täckvingar": "täckvinge",
    "täckvingarna": "täckvinge",
    "täckvingarnas": "täckvinge",
    "täckvingars": "täckvinge",
    "täckvingen": "täckvinge",
    "täckvingens": "täckvinge",
    "täckvinges": "täckvinge",
    "täckvings": "täckvinge",
    "täkten": "täkt",
    "täktens": "täkt",
    "täkter": "täkt",
    "täkterna": "täkt",
    "täkternas": "täkt",
    "täkters": "täkt",
    "täkts": "täkt",
    "tälj": "tälja",
    "täljande": "tälja",
    "täljanden": "täljande",
    "täljandena": "täljande",
    "täljandenas": "täljande",
    "täljandens": "täljande",
    "täljandes": "täljande",
    "täljandet": "täljande",
    "täljandets": "täljande",
    "täljar": "täljare",
    "täljaren": "täljare",
    "täljarens": "täljare",
    "täljares": "täljare",
    "täljarna": "täljare",
    "täljarnas": "täljare",
    "täljas": "tälja",
    "täljd": "tälja",
    "täljda": "tälja",
    "täljdas": "tälja",
    "täljde": "tälja",
    "täljdes": "tälja",
    "täljds": "tälja",
    "täljer": "tälja",
    "täljes": "tälja",
    "täljknivar": "täljkniv",
    "täljknivarna": "täljkniv",
    "täljknivarnas": "täljkniv",
    "täljknivars": "täljkniv",
    "täljkniven": "täljkniv",
    "täljknivens": "täljkniv",
    "täljknivs": "täljkniv",
    "täljs": "tälja",
    "täljstenen": "täljsten",
    "täljstenens": "täljsten",
    "täljstens": "täljsten",
    "täljstenskaminen": "täljstenskamin",
    "täljstenskaminens": "täljstenskamin",
    "täljstenskaminer": "täljstenskamin",
    "täljstenskaminerna": "täljstenskamin",
    "täljstenskaminernas": "täljstenskamin",
    "täljstenskaminers": "täljstenskamin",
    "täljstenskamins": "täljstenskamin",
    "täljt": "tälja",
    "täljts": "tälja",
    "tält": "tälta",
    "tältad": "tälta",
    "tältade": "tälta",
    "tältades": "tälta",
    "tältads": "tälta",
    "tältande": "tälta",
    "tältanden": "tältande",
    "tältandena": "tältande",
    "tältandenas": "tältande",
    "tältandens": "tältande",
    "tältandes": "tältande",
    "tältandet": "tältande",
    "tältandets": "tältande",
    "tältar": "tältare",
    "tältaren": "tältare",
    "tältarens": "tältare",
    "tältares": "tältare",
    "tältarna": "tältare",
    "tältarnas": "tältare",
    "tältas": "tälta",
    "tältat": "tälta",
    "tältats": "tälta",
    "tältduken": "tältduk",
    "tältdukens": "tältduk",
    "tältduks": "tältduk",
    "tälten": "tält",
    "tältens": "tält",
    "tältet": "tält",
    "tältets": "tält",
    "tältmöten": "tältmöte",
    "tältmötena": "tältmöte",
    "tältmötenas": "tältmöte",
    "tältmötens": "tältmöte",
    "tältmötes": "tältmöte",
    "tältmötet": "tältmöte",
    "tältmötets": "tältmöte",
    "tältpinn": "tältpinne",
    "tältpinnar": "tältpinne",
    "tältpinnarna": "tältpinne",
    "tältpinnarnas": "tältpinne",
    "tältpinnars": "tältpinne",
    "tältpinnen": "tältpinne",
    "tältpinnens": "tältpinne",
    "tältpinnes": "tältpinne",
    "tältpinns": "tältpinne",
    "tälts": "tält",
    "tältstolar": "tältstol",
    "tältstolarna": "tältstol",
    "tältstolarnas": "tältstol",
    "tältstolars": "tältstol",
    "tältstolen": "tältstol",
    "tältstolens": "tältstol",
    "tältstols": "tältstol",
    "tältsängar": "tältsäng",
    "tältsängarna": "tältsäng",
    "tältsängarnas": "tältsäng",
    "tältsängars": "tältsäng",
    "tältsängen": "tältsäng",
    "tältsängens": "tältsäng",
    "tältsängs": "tältsäng",
    "tälttaken": "tälttak",
    "tälttakens": "tälttak",
    "tälttaket": "tälttak",
    "tälttakets": "tälttak",
    "tälttaks": "tälttak",
    "tämj": "tämja",
    "tämjande": "tämja",
    "tämjanden": "tämjande",
    "tämjandena": "tämjande",
    "tämjandenas": "tämjande",
    "tämjandens": "tämjande",
    "tämjandes": "tämjande",
    "tämjandet": "tämjande",
    "tämjandets": "tämjande",
    "tämjas": "tämja",
    "tämjd": "tämja",
    "tämjda": "tämja",
    "tämjdas": "tämja",
    "tämjde": "tämja",
    "tämjdes": "tämja",
    "tämjds": "tämja",
    "tämjer": "tämja",
    "tämjes": "tämja",
    "tämjs": "tämja",
    "tämjt": "tämja",
    "tämjts": "tämja",
    "tämliga": "tämlig",
    "tämligare": "tämlig",
    "tämligares": "tämlig",
    "tämligas": "tämlig",
    "tämligast": "tämlig",
    "tämligaste": "tämlig",
    "tämligastes": "tämlig",
    "tämligasts": "tämlig",
    "tämlige": "tämlig",
    "tämliges": "tämlig",
    "tämligs": "tämlig",
    "tämligt": "tämlig",
    "tämligts": "tämlig",
    "tämt": "tämja",
    "tämts": "tämja",
    "tänd": "tända",
    "tändande": "tända",
    "tändanden": "tändande",
    "tändandena": "tändande",
    "tändandenas": "tändande",
    "tändandens": "tändande",
    "tändandes": "tändande",
    "tändandet": "tändande",
    "tändandets": "tändande",
    "tändar": "tändare",
    "tändaren": "tändare",
    "tändarens": "tändare",
    "tändares": "tändare",
    "tändarna": "tändare",
    "tändarnas": "tändare",
    "tändaruttagen": "tändaruttag",
    "tändaruttagens": "tändaruttag",
    "tändaruttaget": "tändaruttag",
    "tändaruttagets": "tändaruttag",
    "tändaruttags": "tändaruttag",
    "tändas": "tända",
    "tände": "tända",
    "tänder": "tända",
    "tänderna": "tand",
    "tändernas": "tand",
    "tänders": "tand",
    "tändes": "tända",
    "tändhattar": "tändhatt",
    "tändhattarna": "tändhatt",
    "tändhattarnas": "tändhatt",
    "tändhattars": "tändhatt",
    "tändhatten": "tändhatt",
    "tändhattens": "tändhatt",
    "tändhatts": "tändhatt",
    "tändkulemotorer": "tändkulemotor",
    "tändkulemotorerna": "tändkulemotor",
    "tändkulemotorernas": "tändkulemotor",
    "tändkulemotorers": "tändkulemotor",
    "tändkulemotorn": "tändkulemotor",
    "tändkulemotorns": "tändkulemotor",
    "tändkulemotors": "tändkulemotor",
    "tändmedels": "tändmedel",
    "tändmedlen": "tändmedel",
    "tändmedlens": "tändmedel",
    "tändmedlet": "tändmedel",
    "tändmedlets": "tändmedel",
    "tändningar": "tändning",
    "tändningarna": "tändning",
    "tändningarnas": "tändning",
    "tändningars": "tändning",
    "tändningen": "tändning",
    "tändningens": "tändning",
    "tändnings": "tändning",
    "tändningslåsen": "tändningslås",
    "tändningslåsens": "tändningslås",
    "tändningslåset": "tändningslås",
    "tändningslåsets": "tändningslås",
    "tändningsnyckeln": "tändningsnyckel",
    "tändningsnyckelns": "tändningsnyckel",
    "tändningsnyckels": "tändningsnyckel",
    "tändningsnycklar": "tändningsnyckel",
    "tändningsnycklarna": "tändningsnyckel",
    "tändningsnycklarnas": "tändningsnyckel",
    "tändningsnycklars": "tändningsnyckel",
    "tändpatronen": "tändpatron",
    "tändpatronens": "tändpatron",
    "tändpatroner": "tändpatron",
    "tändpatronerna": "tändpatron",
    "tändpatronernas": "tändpatron",
    "tändpatroners": "tändpatron",
    "tändpatrons": "tändpatron",
    "tändrören": "tändrör",
    "tändrörens": "tändrör",
    "tändröret": "tändrör",
    "tändrörets": "tändrör",
    "tändrörs": "tändrör",
    "tänds": "tända",
    "tändsatsen": "tändsats",
    "tändsatsens": "tändsats",
    "tändsatser": "tändsats",
    "tändsatserna": "tändsats",
    "tändsatsernas": "tändsats",
    "tändsatsers": "tändsats",
    "tändspol": "tändspole",
    "tändspolar": "tändspole",
    "tändspolarna": "tändspole",
    "tändspolarnas": "tändspole",
    "tändspolars": "tändspole",
    "tändspolen": "tändspole",
    "tändspolens": "tändspole",
    "tändspoles": "tändspole",
    "tändspols": "tändspole",
    "tändstick": "tändsticka",
    "tändstickan": "tändsticka",
    "tändstickans": "tändsticka",
    "tändstickas": "tändsticka",
    "tändsticke": "tändsticka",
    "tändstickor": "tändsticka",
    "tändstickorna": "tändsticka",
    "tändstickornas": "tändsticka",
    "tändstickors": "tändsticka",
    "tändsticks": "tändsticka",
    "tändsticksaskar": "tändsticksask",
    "tändsticksaskarna": "tändsticksask",
    "tändsticksaskarnas": "tändsticksask",
    "tändsticksaskars": "tändsticksask",
    "tändsticksasken": "tändsticksask",
    "tändsticksaskens": "tändsticksask",
    "tändsticksasks": "tändsticksask",
    "tändsticksfabriken": "tändsticksfabrik",
    "tändsticksfabrikens": "tändsticksfabrik",
    "tändsticksfabriker": "tändsticksfabrik",
    "tändsticksfabrikerna": "tändsticksfabrik",
    "tändsticksfabrikernas": "tändsticksfabrik",
    "tändsticksfabrikers": "tändsticksfabrik",
    "tändsticksfabriks": "tändsticksfabrik",
    "tändsticksmönsterna": "tändsticksmönster",
    "tändsticksmönsternas": "tändsticksmönster",
    "tändsticksmönsters": "tändsticksmönster",
    "tändsticksmönstren": "tändsticksmönster",
    "tändsticksmönstrens": "tändsticksmönster",
    "tändsticksmönstret": "tändsticksmönster",
    "tändsticksmönstrets": "tändsticksmönster",
    "tändsticksproblemen": "tändsticksproblem",
    "tändsticksproblemens": "tändsticksproblem",
    "tändsticksproblemet": "tändsticksproblem",
    "tändsticksproblemets": "tändsticksproblem",
    "tändsticksproblems": "tändsticksproblem",
    "tändstiften": "tändstift",
    "tändstiftens": "tändstift",
    "tändstiftet": "tändstift",
    "tändstiftets": "tändstift",
    "tändstifts": "tändstift",
    "tändstiftshyls": "tändstiftshylsa",
    "tändstiftshylsan": "tändstiftshylsa",
    "tändstiftshylsans": "tändstiftshylsa",
    "tändstiftshylsas": "tändstiftshylsa",
    "tändstiftshylse": "tändstiftshylsa",
    "tändstiftshylsor": "tändstiftshylsa",
    "tändstiftshylsorna": "tändstiftshylsa",
    "tändstiftshylsornas": "tändstiftshylsa",
    "tändstiftshylsors": "tändstiftshylsa",
    "tändvätskan": "tändvätska",
    "tändvätskans": "tändvätska",
    "tändvätskas": "tändvätska",
    "tändvätske": "tändvätska",
    "tändvätskor": "tändvätska",
    "tändvätskorna": "tändvätska",
    "tändvätskornas": "tändvätska",
    "tändvätskors": "tändvätska",
    "tändämnen": "tändämne",
    "tändämnena": "tändämne",
    "tändämnenas": "tändämne",
    "tändämnens": "tändämne",
    "tändämnes": "tändämne",
    "tändämnet": "tändämne",
    "tändämnets": "tändämne",
    "tänger": "tång",
    "tängerna": "tång",
    "tängernas": "tång",
    "tängers": "tång",
    "tänj": "tänja",
    "tänjande": "tänja",
    "tänjanden": "tänjande",
    "tänjandena": "tänjande",
    "tänjandenas": "tänjande",
    "tänjandens": "tänjande",
    "tänjandes": "tänjande",
    "tänjandet": "tänjande",
    "tänjandets": "tänjande",
    "tänjas": "tänja",
    "tänjbara": "tänjbar",
    "tänjbarare": "tänjbar",
    "tänjbarares": "tänjbar",
    "tänjbaras": "tänjbar",
    "tänjbarast": "tänjbar",
    "tänjbaraste": "tänjbar",
    "tänjbarastes": "tänjbar",
    "tänjbarasts": "tänjbar",
    "tänjbare": "tänjbar",
    "tänjbares": "tänjbar",
    "tänjbarheten": "tänjbarhet",
    "tänjbarhetens": "tänjbarhet",
    "tänjbarhets": "tänjbarhet",
    "tänjbars": "tänjbar",
    "tänjbart": "tänjbar",
    "tänjbarts": "tänjbar",
    "tänjd": "tänja",
    "tänjda": "tänja",
    "tänjdas": "tänja",
    "tänjde": "tänja",
    "tänjdes": "tänja",
    "tänjds": "tänja",
    "tänjer": "tänja",
    "tänjes": "tänja",
    "tänjningar": "tänjning",
    "tänjningarna": "tänjning",
    "tänjningarnas": "tänjning",
    "tänjningars": "tänjning",
    "tänjningen": "tänjning",
    "tänjningens": "tänjning",
    "tänjnings": "tänjning",
    "tänjs": "tänja",
    "tänjt": "tänja",
    "tänjts": "tänja",
    "tänk": "tänka",
    "tänkande": "tänka",
    "tänkanden": "tänkande",
    "tänkandena": "tänkande",
    "tänkandenas": "tänkande",
    "tänkandens": "tänkande",
    "tänkandes": "tänkande",
    "tänkandet": "tänkande",
    "tänkandets": "tänkande",
    "tänkar": "tänkare",
    "tänkaren": "tänkare",
    "tänkarens": "tänkare",
    "tänkares": "tänkare",
    "tänkarna": "tänkare",
    "tänkarnas": "tänkare",
    "tänkarpann": "tänkarpanna",
    "tänkarpannan": "tänkarpanna",
    "tänkarpannans": "tänkarpanna",
    "tänkarpannas": "tänkarpanna",
    "tänkarpanne": "tänkarpanna",
    "tänkarpannor": "tänkarpanna",
    "tänkarpannorna": "tänkarpanna",
    "tänkarpannornas": "tänkarpanna",
    "tänkarpannors": "tänkarpanna",
    "tänkarpanns": "tänkarpanna",
    "tänkas": "tänka",
    "tänkbara": "tänkbar",
    "tänkbarare": "tänkbar",
    "tänkbarares": "tänkbar",
    "tänkbaras": "tänkbar",
    "tänkbarast": "tänkbar",
    "tänkbaraste": "tänkbar",
    "tänkbarastes": "tänkbar",
    "tänkbarasts": "tänkbar",
    "tänkbare": "tänkbar",
    "tänkbares": "tänkbar",
    "tänkbarheten": "tänkbarhet",
    "tänkbarhetens": "tänkbarhet",
    "tänkbarheter": "tänkbarhet",
    "tänkbarheterna": "tänkbarhet",
    "tänkbarheternas": "tänkbarhet",
    "tänkbarheters": "tänkbarhet",
    "tänkbarhets": "tänkbarhet",
    "tänkbars": "tänkbar",
    "tänkbart": "tänkbar",
    "tänkbarts": "tänkbar",
    "tänkeboken": "tänkebok",
    "tänkebokens": "tänkebok",
    "tänkeboks": "tänkebok",
    "tänkeböcker": "tänkebok",
    "tänkeböckerna": "tänkebok",
    "tänkeböckernas": "tänkebok",
    "tänkeböckers": "tänkebok",
    "tänker": "tänka",
    "tänkes": "tänka",
    "tänkespråken": "tänkespråk",
    "tänkespråkens": "tänkespråk",
    "tänkespråket": "tänkespråk",
    "tänkespråkets": "tänkespråk",
    "tänkespråks": "tänkespråk",
    "tänkesätten": "tänkesätt",
    "tänkesättens": "tänkesätt",
    "tänkesättet": "tänkesätt",
    "tänkesättets": "tänkesätt",
    "tänkesätts": "tänkesätt",
    "tänket": "tänk",
    "tänkets": "tänk",
    "tänks": "tänka",
    "tänkt": "tänka",
    "tänkta": "tänka",
    "tänktas": "tänka",
    "tänkte": "tänka",
    "tänktes": "tänka",
    "tänkts": "tänka",
    "tänkvärda": "tänkvärd",
    "tänkvärdare": "tänkvärd",
    "tänkvärdares": "tänkvärd",
    "tänkvärdas": "tänkvärd",
    "tänkvärdast": "tänkvärd",
    "tänkvärdaste": "tänkvärd",
    "tänkvärdastes": "tänkvärd",
    "tänkvärdasts": "tänkvärd",
    "tänkvärde": "tänkvärd",
    "tänkvärdes": "tänkvärd",
    "tänkvärdheten": "tänkvärdhet",
    "tänkvärdhetens": "tänkvärdhet",
    "tänkvärdheter": "tänkvärdhet",
    "tänkvärdheterna": "tänkvärdhet",
    "tänkvärdheternas": "tänkvärdhet",
    "tänkvärdheters": "tänkvärdhet",
    "tänkvärdhets": "tänkvärdhet",
    "tänkvärds": "tänkvärd",
    "tänkvärt": "tänkvärd",
    "tänkvärts": "tänkvärd",
    "tännlik": "tännlika",
    "tännlikan": "tännlika",
    "tännlikans": "tännlika",
    "tännlikas": "tännlika",
    "tännlike": "tännlika",
    "tännlikor": "tännlika",
    "tännlikorna": "tännlika",
    "tännlikornas": "tännlika",
    "tännlikors": "tännlika",
    "tännliks": "tännlika",
    "tänt": "tända",
    "tänts": "tända",
    "täpp": "täppa",
    "täppan": "täppa",
    "täppans": "täppa",
    "täppas": "täppa",
    "täppe": "täppa",
    "täppor": "täppa",
    "täpporna": "täppa",
    "täppornas": "täppa",
    "täppors": "täppa",
    "täpps": "täppa",
    "täppta": "täppt",
    "täpptare": "täppt",
    "täpptares": "täppt",
    "täpptas": "täppt",
    "täpptast": "täppt",
    "täpptaste": "täppt",
    "täpptastes": "täppt",
    "täpptasts": "täppt",
    "täppte": "täppt",
    "täpptes": "täppt",
    "täppts": "täppt",
    "tär": "tära",
    "tärande": "tära",
    "täranden": "tärande",
    "tärandena": "tärande",
    "tärandenas": "tärande",
    "tärandens": "tärande",
    "tärandes": "tärande",
    "tärandet": "tärande",
    "tärandets": "tärande",
    "täras": "tära",
    "tärd": "tära",
    "tärda": "tärd",
    "tärdare": "tärd",
    "tärdares": "tärd",
    "tärdas": "tärd",
    "tärdast": "tärd",
    "tärdaste": "tärd",
    "tärdastes": "tärd",
    "tärdasts": "tärd",
    "tärde": "tärd",
    "tärdes": "tärd",
    "tärdheten": "tärdhet",
    "tärdhetens": "tärdhet",
    "tärdhets": "tärdhet",
    "tärds": "tärd",
    "täres": "tära",
    "tärn": "tärna",
    "tärnad": "tärna",
    "tärnade": "tärna",
    "tärnades": "tärna",
    "tärnads": "tärna",
    "tärnan": "tärna",
    "tärnande": "tärna",
    "tärnanden": "tärnande",
    "tärnandena": "tärnande",
    "tärnandenas": "tärnande",
    "tärnandens": "tärnande",
    "tärnandes": "tärnande",
    "tärnandet": "tärnande",
    "tärnandets": "tärnande",
    "tärnans": "tärna",
    "tärnar": "tärna",
    "tärnas": "tärna",
    "tärnat": "tärna",
    "tärnats": "tärna",
    "tärne": "tärna",
    "tärningar": "tärning",
    "tärningarna": "tärning",
    "tärningarnas": "tärning",
    "tärningars": "tärning",
    "tärningen": "tärning",
    "tärningens": "tärning",
    "tärnings": "tärning",
    "tärningsbägar": "tärningsbägare",
    "tärningsbägaren": "tärningsbägare",
    "tärningsbägarens": "tärningsbägare",
    "tärningsbägares": "tärningsbägare",
    "tärningsbägarna": "tärningsbägare",
    "tärningsbägarnas": "tärningsbägare",
    "tärningskasten": "tärningskast",
    "tärningskastens": "tärningskast",
    "tärningskastet": "tärningskast",
    "tärningskastets": "tärningskast",
    "tärningskasts": "tärningskast",
    "tärningsspelar": "tärningsspelare",
    "tärningsspelaren": "tärningsspelare",
    "tärningsspelarens": "tärningsspelare",
    "tärningsspelares": "tärningsspelare",
    "tärningsspelarna": "tärningsspelare",
    "tärningsspelarnas": "tärningsspelare",
    "tärningsspelen": "tärningsspel",
    "tärningsspelens": "tärningsspel",
    "tärningsspelet": "tärningsspel",
    "tärningsspelets": "tärningsspel",
    "tärningsspels": "tärningsspel",
    "tärnor": "tärna",
    "tärnorna": "tärna",
    "tärnornas": "tärna",
    "tärnors": "tärna",
    "tärns": "tärna",
    "tärs": "tära",
    "tärt": "tärd",
    "tärts": "tärd",
    "tät": "täta",
    "täta": "tät",
    "tätad": "täta",
    "tätade": "täta",
    "tätades": "täta",
    "tätads": "täta",
    "tätande": "täta",
    "tätanden": "tätande",
    "tätandena": "tätande",
    "tätandenas": "tätande",
    "tätandens": "tätande",
    "tätandes": "tätande",
    "tätandet": "tätande",
    "tätandets": "tätande",
    "tätar": "täta",
    "tätare": "tät",
    "tätares": "tät",
    "tätas": "täta",
    "tätast": "tät",
    "tätaste": "tät",
    "tätastes": "tät",
    "tätasts": "tät",
    "tätat": "täta",
    "tätats": "täta",
    "tätatäten": "tätatät",
    "tätatätens": "tätatät",
    "tätatäter": "tätatät",
    "tätatäterna": "tätatät",
    "tätatäternas": "tätatät",
    "tätatäters": "tätatät",
    "tätatäts": "tätatät",
    "täte": "tät",
    "täten": "täte",
    "tätens": "täte",
    "täter": "tät",
    "täterna": "tät",
    "täternas": "tät",
    "täters": "tät",
    "tätes": "täte",
    "tätheten": "täthet",
    "täthetens": "täthet",
    "täthets": "täthet",
    "täthetstoppar": "täthetstopp",
    "täthetstopparna": "täthetstopp",
    "täthetstopparnas": "täthetstopp",
    "täthetstoppars": "täthetstopp",
    "täthetstoppen": "täthetstopp",
    "täthetstoppens": "täthetstopp",
    "täthetstopps": "täthetstopp",
    "täthetsvariationen": "täthetsvariation",
    "täthetsvariationens": "täthetsvariation",
    "täthetsvariationer": "täthetsvariation",
    "täthetsvariationerna": "täthetsvariation",
    "täthetsvariationernas": "täthetsvariation",
    "täthetsvariationers": "täthetsvariation",
    "täthetsvariations": "täthetsvariation",
    "tätmjölken": "tätmjölk",
    "tätmjölkens": "tätmjölk",
    "tätmjölks": "tätmjölk",
    "tätn": "tätna",
    "tätnad": "tätna",
    "tätnade": "tätna",
    "tätnades": "tätna",
    "tätnads": "tätna",
    "tätnande": "tätna",
    "tätnanden": "tätnande",
    "tätnandena": "tätnande",
    "tätnandenas": "tätnande",
    "tätnandens": "tätnande",
    "tätnandes": "tätnande",
    "tätnandet": "tätnande",
    "tätnandets": "tätnande",
    "tätnar": "tätna",
    "tätnas": "tätna",
    "tätnat": "tätna",
    "tätnats": "tätna",
    "tätningar": "tätning",
    "tätningarna": "tätning",
    "tätningarnas": "tätning",
    "tätningars": "tätning",
    "tätningen": "tätning",
    "tätningens": "tätning",
    "tätnings": "tätning",
    "tätningslisten": "tätningslist",
    "tätningslistens": "tätningslist",
    "tätningslister": "tätningslist",
    "tätningslisterna": "tätningslist",
    "tätningslisternas": "tätningslist",
    "tätningslisters": "tätningslist",
    "tätningslists": "tätningslist",
    "tätningsmassan": "tätningsmassa",
    "tätningsmassans": "tätningsmassa",
    "tätningsmassas": "tätningsmassa",
    "tätningsmasse": "tätningsmassa",
    "tätningsmassor": "tätningsmassa",
    "tätningsmassorna": "tätningsmassa",
    "tätningsmassornas": "tätningsmassa",
    "tätningsmassors": "tätningsmassa",
    "tätorten": "tätort",
    "tätortens": "tätort",
    "tätorter": "tätort",
    "tätorterna": "tätort",
    "tätorternas": "tätort",
    "tätorters": "tätort",
    "tätorts": "tätort",
    "tätortsbon": "tätortsbo",
    "tätortsbons": "tätortsbo",
    "tätortsbor": "tätortsbo",
    "tätortsborna": "tätortsbo",
    "tätortsbornas": "tätortsbo",
    "tätortsbors": "tätortsbo",
    "tätortsbos": "tätortsbo",
    "tätortstrafiken": "tätortstrafik",
    "tätortstrafikens": "tätortstrafik",
    "tätortstrafiks": "tätortstrafik",
    "tätplacerade": "tätplacerad",
    "tätplacerades": "tätplacerad",
    "tätplacerads": "tätplacerad",
    "tätplacerat": "tätplacerad",
    "tätplacerats": "tätplacerad",
    "tätplaceringar": "tätplacering",
    "tätplaceringarna": "tätplacering",
    "tätplaceringarnas": "tätplacering",
    "tätplaceringars": "tätplacering",
    "tätplaceringen": "tätplacering",
    "tätplaceringens": "tätplacering",
    "tätplacerings": "tätplacering",
    "tätplatsen": "tätplats",
    "tätplatsens": "tätplats",
    "tätplatser": "tätplats",
    "tätplatserna": "tätplats",
    "tätplatsernas": "tätplats",
    "tätplatsers": "tätplats",
    "täts": "tät",
    "tätt": "tät",
    "tättbebyggda": "tättbebyggd",
    "tättbebyggdare": "tättbebyggd",
    "tättbebyggdares": "tättbebyggd",
    "tättbebyggdas": "tättbebyggd",
    "tättbebyggdast": "tättbebyggd",
    "tättbebyggdaste": "tättbebyggd",
    "tättbebyggdastes": "tättbebyggd",
    "tättbebyggdasts": "tättbebyggd",
    "tättbebyggde": "tättbebyggd",
    "tättbebyggdes": "tättbebyggd",
    "tättbebyggdheten": "tättbebyggdhet",
    "tättbebyggdhetens": "tättbebyggdhet",
    "tättbebyggdhets": "tättbebyggdhet",
    "tättbebyggds": "tättbebyggd",
    "tättbebyggt": "tättbebyggd",
    "tättbebyggts": "tättbebyggd",
    "tättbefolkade": "tättbefolkad",
    "tättbefolkades": "tättbefolkad",
    "tättbefolkads": "tättbefolkad",
    "tättbefolkat": "tättbefolkad",
    "tättbefolkats": "tättbefolkad",
    "tättingar": "tätting",
    "tättingarna": "tätting",
    "tättingarnas": "tätting",
    "tättingars": "tätting",
    "tättingen": "tätting",
    "tättingens": "tätting",
    "tättingfågeln": "tättingfågel",
    "tättingfågelns": "tättingfågel",
    "tättingfågels": "tättingfågel",
    "tättingfåglar": "tättingfågel",
    "tättingfåglarna": "tättingfågel",
    "tättingfåglarnas": "tättingfågel",
    "tättingfåglars": "tättingfågel",
    "tättings": "tätting",
    "tättklippta": "tättklippt",
    "tättklipptare": "tättklippt",
    "tättklipptares": "tättklippt",
    "tättklipptas": "tättklippt",
    "tättklipptast": "tättklippt",
    "tättklipptaste": "tättklippt",
    "tättklipptastes": "tättklippt",
    "tättklipptasts": "tättklippt",
    "tättklippte": "tättklippt",
    "tättklipptes": "tättklippt",
    "tättklipptheten": "tättklippthet",
    "tättklippthetens": "tättklippthet",
    "tättklippthets": "tättklippthet",
    "tättklippts": "tättklippt",
    "tätts": "tät",
    "tättskrivens": "tättskriven",
    "tättskrivet": "tättskriven",
    "tättskrivets": "tättskriven",
    "tättskrivna": "tättskriven",
    "tättskrivnare": "tättskriven",
    "tättskrivnares": "tättskriven",
    "tättskrivnas": "tättskriven",
    "tättskrivnast": "tättskriven",
    "tättskrivnaste": "tättskriven",
    "tättskrivnastes": "tättskriven",
    "tättskrivnasts": "tättskriven",
    "tättskrivne": "tättskriven",
    "tättskrivnes": "tättskriven",
    "tätörten": "tätört",
    "tätörtens": "tätört",
    "tätörts": "tätört",
    "tävlad": "tävla",
    "tävlade": "tävla",
    "tävlades": "tävla",
    "tävlads": "tävla",
    "tävlande": "tävla",
    "tävlanden": "tävlande",
    "tävlandena": "tävlande",
    "tävlandenas": "tävlande",
    "tävlandens": "tävlande",
    "tävlandes": "tävlande",
    "tävlandet": "tävlande",
    "tävlandets": "tävlande",
    "tävlans": "tävlan",
    "tävlar": "tävla",
    "tävlas": "tävla",
    "tävlat": "tävla",
    "tävlats": "tävla",
    "tävlingar": "tävling",
    "tävlingarna": "tävling",
    "tävlingarnas": "tävling",
    "tävlingars": "tävling",
    "tävlingen": "tävling",
    "tävlingens": "tävling",
    "tävlings": "tävling",
    "tävlingsbanan": "tävlingsbana",
    "tävlingsbanans": "tävlingsbana",
    "tävlingsbanas": "tävlingsbana",
    "tävlingsbane": "tävlingsbana",
    "tävlingsbanor": "tävlingsbana",
    "tävlingsbanorna": "tävlingsbana",
    "tävlingsbanornas": "tävlingsbana",
    "tävlingsbanors": "tävlingsbana",
    "tävlingsbilar": "tävlingsbil",
    "tävlingsbilarna": "tävlingsbil",
    "tävlingsbilarnas": "tävlingsbil",
    "tävlingsbilars": "tävlingsbil",
    "tävlingsbilen": "tävlingsbil",
    "tävlingsbilens": "tävlingsbil",
    "tävlingsbils": "tävlingsbil",
    "tävlingscyklisten": "tävlingscyklist",
    "tävlingscyklistens": "tävlingscyklist",
    "tävlingscyklister": "tävlingscyklist",
    "tävlingscyklisterna": "tävlingscyklist",
    "tävlingscyklisternas": "tävlingscyklist",
    "tävlingscyklisters": "tävlingscyklist",
    "tävlingscyklists": "tävlingscyklist",
    "tävlingshumören": "tävlingshumör",
    "tävlingshumörens": "tävlingshumör",
    "tävlingshumöret": "tävlingshumör",
    "tävlingshumörets": "tävlingshumör",
    "tävlingshumörs": "tävlingshumör",
    "tävlingsjuryer": "tävlingsjury",
    "tävlingsjuryerna": "tävlingsjury",
    "tävlingsjuryernas": "tävlingsjury",
    "tävlingsjuryers": "tävlingsjury",
    "tävlingsjuryn": "tävlingsjury",
    "tävlingsjuryns": "tävlingsjury",
    "tävlingsjurys": "tävlingsjury",
    "tävlingskampen": "tävlingskamp",
    "tävlingskampens": "tävlingskamp",
    "tävlingskamper": "tävlingskamp",
    "tävlingskamperna": "tävlingskamp",
    "tävlingskampernas": "tävlingskamp",
    "tävlingskampers": "tävlingskamp",
    "tävlingskamps": "tävlingskamp",
    "tävlingsklassen": "tävlingsklass",
    "tävlingsklassens": "tävlingsklass",
    "tävlingsklasser": "tävlingsklass",
    "tävlingsklasserna": "tävlingsklass",
    "tävlingsklassernas": "tävlingsklass",
    "tävlingsklassers": "tävlingsklass",
    "tävlingsledar": "tävlingsledare",
    "tävlingsledaren": "tävlingsledare",
    "tävlingsledarens": "tävlingsledare",
    "tävlingsledares": "tävlingsledare",
    "tävlingsledarna": "tävlingsledare",
    "tävlingsledarnas": "tävlingsledare",
    "tävlingsledningar": "tävlingsledning",
    "tävlingsledningarna": "tävlingsledning",
    "tävlingsledningarnas": "tävlingsledning",
    "tävlingsledningars": "tävlingsledning",
    "tävlingsledningen": "tävlingsledning",
    "tävlingsledningens": "tävlingsledning",
    "tävlingslednings": "tävlingsledning",
    "tävlingslekar": "tävlingslek",
    "tävlingslekarna": "tävlingslek",
    "tävlingslekarnas": "tävlingslek",
    "tävlingslekars": "tävlingslek",
    "tävlingsleken": "tävlingslek",
    "tävlingslekens": "tävlingslek",
    "tävlingsleks": "tävlingslek",
    "tävlingsmänniskan": "tävlingsmänniska",
    "tävlingsmänniskans": "tävlingsmänniska",
    "tävlingsmänniskas": "tävlingsmänniska",
    "tävlingsmännisko": "tävlingsmänniska",
    "tävlingsmänniskor": "tävlingsmänniska",
    "tävlingsmänniskorna": "tävlingsmänniska",
    "tävlingsmänniskornas": "tävlingsmänniska",
    "tävlingsmänniskors": "tävlingsmänniska",
    "tävlingsmässiga": "tävlingsmässig",
    "tävlingsmässigare": "tävlingsmässig",
    "tävlingsmässigares": "tävlingsmässig",
    "tävlingsmässigas": "tävlingsmässig",
    "tävlingsmässigast": "tävlingsmässig",
    "tävlingsmässigaste": "tävlingsmässig",
    "tävlingsmässigastes": "tävlingsmässig",
    "tävlingsmässigasts": "tävlingsmässig",
    "tävlingsmässige": "tävlingsmässig",
    "tävlingsmässiges": "tävlingsmässig",
    "tävlingsmässigs": "tävlingsmässig",
    "tävlingsmässigt": "tävlingsmässig",
    "tävlingsmässigts": "tävlingsmässig",
    "tävlingsprisen": "tävlingspris",
    "tävlingsprisens": "tävlingspris",
    "tävlingspriser": "tävlingspris",
    "tävlingspriserna": "tävlingspris",
    "tävlingsprisernas": "tävlingspris",
    "tävlingsprisers": "tävlingspris",
    "tävlingspriset": "tävlingspris",
    "tävlingsprisets": "tävlingspris",
    "tävlingsseglad": "tävlingssegla",
    "tävlingsseglade": "tävlingssegla",
    "tävlingsseglades": "tävlingssegla",
    "tävlingsseglads": "tävlingssegla",
    "tävlingsseglande": "tävlingssegla",
    "tävlingsseglanden": "tävlingsseglande",
    "tävlingsseglandena": "tävlingsseglande",
    "tävlingsseglandenas": "tävlingsseglande",
    "tävlingsseglandens": "tävlingsseglande",
    "tävlingsseglandes": "tävlingsseglande",
    "tävlingsseglandet": "tävlingsseglande",
    "tävlingsseglandets": "tävlingsseglande",
    "tävlingsseglar": "tävlingssegla",
    "tävlingsseglas": "tävlingssegla",
    "tävlingsseglat": "tävlingssegla",
    "tävlingsseglats": "tävlingssegla",
    "tävlingsseglingar": "tävlingssegling",
    "tävlingsseglingarna": "tävlingssegling",
    "tävlingsseglingarnas": "tävlingssegling",
    "tävlingsseglingars": "tävlingssegling",
    "tävlingsseglingen": "tävlingssegling",
    "tävlingsseglingens": "tävlingssegling",
    "tävlingsseglings": "tävlingssegling",
    "tå": "tåa",
    "tåad": "tåa",
    "tåade": "tåa",
    "tåades": "tåa",
    "tåads": "tåa",
    "tåande": "tåa",
    "tåanden": "tåande",
    "tåandena": "tåande",
    "tåandenas": "tåande",
    "tåandens": "tåande",
    "tåandes": "tåande",
    "tåandet": "tåande",
    "tåandets": "tåande",
    "tåar": "tåa",
    "tåas": "tåa",
    "tåat": "tåa",
    "tåats": "tåa",
    "tåg": "tåga",
    "tågad": "tåga",
    "tågade": "tåga",
    "tågades": "tåga",
    "tågads": "tåga",
    "tågan": "tåga",
    "tågande": "tåga",
    "tåganden": "tågande",
    "tågandena": "tågande",
    "tågandenas": "tågande",
    "tågandens": "tågande",
    "tågandes": "tågande",
    "tågandet": "tågande",
    "tågandets": "tågande",
    "tågankomsten": "tågankomst",
    "tågankomstens": "tågankomst",
    "tågankomster": "tågankomst",
    "tågankomsterna": "tågankomst",
    "tågankomsternas": "tågankomst",
    "tågankomsters": "tågankomst",
    "tågankomsts": "tågankomst",
    "tågans": "tåga",
    "tågar": "tåga",
    "tågas": "tåga",
    "tågat": "tåga",
    "tågats": "tåga",
    "tågavgångar": "tågavgång",
    "tågavgångarna": "tågavgång",
    "tågavgångarnas": "tågavgång",
    "tågavgångars": "tågavgång",
    "tågavgången": "tågavgång",
    "tågavgångens": "tågavgång",
    "tågavgångs": "tågavgång",
    "tågbiljetten": "tågbiljett",
    "tågbiljettens": "tågbiljett",
    "tågbiljetter": "tågbiljett",
    "tågbiljetterna": "tågbiljett",
    "tågbiljetternas": "tågbiljett",
    "tågbiljetters": "tågbiljett",
    "tågbiljetts": "tågbiljett",
    "tåge": "tåga",
    "tågen": "tåg",
    "tågens": "tåg",
    "tåget": "tåg",
    "tågets": "tåg",
    "tågklarerar": "tågklarerare",
    "tågklareraren": "tågklarerare",
    "tågklarerarens": "tågklarerare",
    "tågklarerares": "tågklarerare",
    "tågklarerarna": "tågklarerare",
    "tågklarerarnas": "tågklarerare",
    "tågkrockar": "tågkrock",
    "tågkrockarna": "tågkrock",
    "tågkrockarnas": "tågkrock",
    "tågkrockars": "tågkrock",
    "tågkrocken": "tågkrock",
    "tågkrockens": "tågkrock",
    "tågkrocks": "tågkrock",
    "tågkupéer": "tågkupé",
    "tågkupéerna": "tågkupé",
    "tågkupéernas": "tågkupé",
    "tågkupéers": "tågkupé",
    "tågkupén": "tågkupé",
    "tågkupéns": "tågkupé",
    "tågkupés": "tågkupé",
    "tågluff": "tågluffa",
    "tågluffad": "tågluffa",
    "tågluffade": "tågluffa",
    "tågluffades": "tågluffa",
    "tågluffads": "tågluffa",
    "tågluffande": "tågluffa",
    "tågluffanden": "tågluffande",
    "tågluffandena": "tågluffande",
    "tågluffandenas": "tågluffande",
    "tågluffandens": "tågluffande",
    "tågluffandes": "tågluffande",
    "tågluffandet": "tågluffande",
    "tågluffandets": "tågluffande",
    "tågluffar": "tågluffa",
    "tågluffas": "tågluffa",
    "tågluffat": "tågluffa",
    "tågluffats": "tågluffa",
    "tåglägenheten": "tåglägenhet",
    "tåglägenhetens": "tåglägenhet",
    "tåglägenheter": "tåglägenhet",
    "tåglägenheterna": "tåglägenhet",
    "tåglägenheternas": "tåglägenhet",
    "tåglägenheters": "tåglägenhet",
    "tåglägenhets": "tåglägenhet",
    "tågor": "tåga",
    "tågordningar": "tågordning",
    "tågordningarna": "tågordning",
    "tågordningarnas": "tågordning",
    "tågordningars": "tågordning",
    "tågordningen": "tågordning",
    "tågordningens": "tågordning",
    "tågordnings": "tågordning",
    "tågorna": "tåga",
    "tågornas": "tåga",
    "tågors": "tåga",
    "tågpassagerar": "tågpassagerare",
    "tågpassageraren": "tågpassagerare",
    "tågpassagerarens": "tågpassagerare",
    "tågpassagerares": "tågpassagerare",
    "tågpassagerarna": "tågpassagerare",
    "tågpassagerarnas": "tågpassagerare",
    "tågpendlad": "tågpendla",
    "tågpendlade": "tågpendla",
    "tågpendlades": "tågpendla",
    "tågpendlads": "tågpendla",
    "tågpendlande": "tågpendla",
    "tågpendlandes": "tågpendla",
    "tågpendlar": "tågpendla",
    "tågpendlas": "tågpendla",
    "tågpendlat": "tågpendla",
    "tågpendlats": "tågpendla",
    "tågresan": "tågresa",
    "tågresans": "tågresa",
    "tågresas": "tågresa",
    "tågrese": "tågresa",
    "tågresor": "tågresa",
    "tågresorna": "tågresa",
    "tågresornas": "tågresa",
    "tågresors": "tågresa",
    "tågrånen": "tågrån",
    "tågrånens": "tågrån",
    "tågrånet": "tågrån",
    "tågrånets": "tågrån",
    "tågråns": "tågrån",
    "tågs": "tåga",
    "tågsträck": "tågsträcka",
    "tågsträckan": "tågsträcka",
    "tågsträckans": "tågsträcka",
    "tågsträckas": "tågsträcka",
    "tågsträcke": "tågsträcka",
    "tågsträckor": "tågsträcka",
    "tågsträckorna": "tågsträcka",
    "tågsträckornas": "tågsträcka",
    "tågsträckors": "tågsträcka",
    "tågsträcks": "tågsträcka",
    "tågsätten": "tågsätt",
    "tågsättens": "tågsätt",
    "tågsättet": "tågsätt",
    "tågsättets": "tågsätt",
    "tågsätts": "tågsätt",
    "tågtiden": "tågtid",
    "tågtidens": "tågtid",
    "tågtider": "tågtid",
    "tågtiderna": "tågtid",
    "tågtidernas": "tågtid",
    "tågtiders": "tågtid",
    "tågtids": "tågtid",
    "tågtidtabellen": "tågtidtabell",
    "tågtidtabellens": "tågtidtabell",
    "tågtidtabeller": "tågtidtabell",
    "tågtidtabellerna": "tågtidtabell",
    "tågtidtabellernas": "tågtidtabell",
    "tågtidtabellers": "tågtidtabell",
    "tågtidtabells": "tågtidtabell",
    "tågtrafiken": "tågtrafik",
    "tågtrafikens": "tågtrafik",
    "tågtrafiks": "tågtrafik",
    "tågtransporten": "tågtransport",
    "tågtransportens": "tågtransport",
    "tågtransporter": "tågtransport",
    "tågtransporterna": "tågtransport",
    "tågtransporternas": "tågtransport",
    "tågtransporters": "tågtransport",
    "tågtransports": "tågtransport",
    "tågturen": "tågtur",
    "tågturens": "tågtur",
    "tågturer": "tågtur",
    "tågturerna": "tågtur",
    "tågturernas": "tågtur",
    "tågturers": "tågtur",
    "tågturs": "tågtur",
    "tågvirkes": "tågvirke",
    "tågvirket": "tågvirke",
    "tågvirkets": "tågvirke",
    "tågångar": "tågångare",
    "tågångaren": "tågångare",
    "tågångarens": "tågångare",
    "tågångares": "tågångare",
    "tågångarna": "tågångare",
    "tågångarnas": "tågångare",
    "tåhätt": "tåhätta",
    "tåhättan": "tåhätta",
    "tåhättans": "tåhätta",
    "tåhättas": "tåhätta",
    "tåhätte": "tåhätta",
    "tåhättor": "tåhätta",
    "tåhättorna": "tåhätta",
    "tåhättornas": "tåhätta",
    "tåhättors": "tåhätta",
    "tåhätts": "tåhätta",
    "tåhävningar": "tåhävning",
    "tåhävningarna": "tåhävning",
    "tåhävningarnas": "tåhävning",
    "tåhävningars": "tåhävning",
    "tåhävningen": "tåhävning",
    "tåhävningens": "tåhävning",
    "tåhävnings": "tåhävning",
    "tåjärnen": "tåjärn",
    "tåjärnens": "tåjärn",
    "tåjärnet": "tåjärn",
    "tåjärnets": "tåjärn",
    "tåjärns": "tåjärn",
    "tål": "tåla",
    "tålamodet": "tålamod",
    "tålamodets": "tålamod",
    "tålamods": "tålamod",
    "tålande": "tåla",
    "tålanden": "tålande",
    "tålandena": "tålande",
    "tålandenas": "tålande",
    "tålandens": "tålande",
    "tålandes": "tålande",
    "tålandet": "tålande",
    "tålandets": "tålande",
    "tålas": "tåla",
    "tåld": "tåla",
    "tålda": "tåla",
    "tåldas": "tåla",
    "tålde": "tåla",
    "tåldes": "tåla",
    "tålds": "tåla",
    "tåles": "tåla",
    "tåliga": "tålig",
    "tåligare": "tålig",
    "tåligares": "tålig",
    "tåligas": "tålig",
    "tåligast": "tålig",
    "tåligaste": "tålig",
    "tåligastes": "tålig",
    "tåligasts": "tålig",
    "tålige": "tålig",
    "tåliges": "tålig",
    "tåligheten": "tålighet",
    "tålighetens": "tålighet",
    "tålighets": "tålighet",
    "tåligs": "tålig",
    "tåligt": "tålig",
    "tåligts": "tålig",
    "tålmodiga": "tålmodig",
    "tålmodigare": "tålmodig",
    "tålmodigares": "tålmodig",
    "tålmodigas": "tålmodig",
    "tålmodigast": "tålmodig",
    "tålmodigaste": "tålmodig",
    "tålmodigastes": "tålmodig",
    "tålmodigasts": "tålmodig",
    "tålmodige": "tålmodig",
    "tålmodiges": "tålmodig",
    "tålmodigheten": "tålmodighet",
    "tålmodighetens": "tålmodighet",
    "tålmodighets": "tålmodighet",
    "tålmodigs": "tålmodig",
    "tålmodigt": "tålmodig",
    "tålmodigts": "tålmodig",
    "tåls": "tåla",
    "tålt": "tåla",
    "tålts": "tåla",
    "tån": "tå",
    "tånageln": "tånagel",
    "tånagelns": "tånagel",
    "tånagels": "tånagel",
    "tånaglar": "tånagel",
    "tånaglarna": "tånagel",
    "tånaglarnas": "tånagel",
    "tånaglars": "tånagel",
    "tång": "tånge",
    "tångar": "tånge",
    "tångarna": "tånge",
    "tångarnas": "tånge",
    "tångars": "tånge",
    "tångbaden": "tångbad",
    "tångbadens": "tångbad",
    "tångbadet": "tångbad",
    "tångbadets": "tångbad",
    "tångbads": "tångbad",
    "tången": "tånge",
    "tångens": "tånge",
    "tånges": "tånge",
    "tånglak": "tånglake",
    "tånglakar": "tånglake",
    "tånglakarna": "tånglake",
    "tånglakarnas": "tånglake",
    "tånglakars": "tånglake",
    "tånglaken": "tånglake",
    "tånglakens": "tånglake",
    "tånglakes": "tånglake",
    "tånglaks": "tånglake",
    "tångräk": "tångräka",
    "tångräkan": "tångräka",
    "tångräkans": "tångräka",
    "tångräkas": "tångräka",
    "tångräke": "tångräka",
    "tångräkor": "tångräka",
    "tångräkorna": "tångräka",
    "tångräkornas": "tångräka",
    "tångräkors": "tångräka",
    "tångräks": "tångräka",
    "tångs": "tånge",
    "tåns": "tå",
    "tår": "tå",
    "tårades": "tåras",
    "tårar": "tår",
    "tårarna": "tår",
    "tårarnas": "tår",
    "tårars": "tår",
    "tårats": "tåras",
    "tårbenen": "tårben",
    "tårbenens": "tårben",
    "tårbenet": "tårben",
    "tårbenets": "tårben",
    "tårbens": "tårben",
    "tårdränkta": "tårdränkt",
    "tårdränktare": "tårdränkt",
    "tårdränktares": "tårdränkt",
    "tårdränktas": "tårdränkt",
    "tårdränktast": "tårdränkt",
    "tårdränktaste": "tårdränkt",
    "tårdränktastes": "tårdränkt",
    "tårdränktasts": "tårdränkt",
    "tårdränkte": "tårdränkt",
    "tårdränktes": "tårdränkt",
    "tårdränktheten": "tårdränkthet",
    "tårdränkthetens": "tårdränkthet",
    "tårdränkthets": "tårdränkthet",
    "tårdränkts": "tårdränkt",
    "tåredalar": "tåredal",
    "tåredalarna": "tåredal",
    "tåredalarnas": "tåredal",
    "tåredalars": "tåredal",
    "tåredalen": "tåredal",
    "tåredalens": "tåredal",
    "tåredals": "tåredal",
    "tåreflöden": "tåreflöde",
    "tåreflödena": "tåreflöde",
    "tåreflödenas": "tåreflöde",
    "tåreflödens": "tåreflöde",
    "tåreflödes": "tåreflöde",
    "tåreflödet": "tåreflöde",
    "tåreflödets": "tåreflöde",
    "tåren": "tår",
    "tårens": "tår",
    "tårgasdim": "tårgasdimma",
    "tårgasdimman": "tårgasdimma",
    "tårgasdimmans": "tårgasdimma",
    "tårgasdimmas": "tårgasdimma",
    "tårgasdimme": "tårgasdimma",
    "tårgasdimmor": "tårgasdimma",
    "tårgasdimmorna": "tårgasdimma",
    "tårgasdimmornas": "tårgasdimma",
    "tårgasdimmors": "tårgasdimma",
    "tårgasdims": "tårgasdimma",
    "tårgasen": "tårgas",
    "tårgasens": "tårgas",
    "tårgaspatronen": "tårgaspatron",
    "tårgaspatronens": "tårgaspatron",
    "tårgaspatroner": "tårgaspatron",
    "tårgaspatronerna": "tårgaspatron",
    "tårgaspatronernas": "tårgaspatron",
    "tårgaspatroners": "tårgaspatron",
    "tårgaspatrons": "tårgaspatron",
    "tårkanalen": "tårkanal",
    "tårkanalens": "tårkanal",
    "tårkanaler": "tårkanal",
    "tårkanalerna": "tårkanal",
    "tårkanalernas": "tårkanal",
    "tårkanalers": "tårkanal",
    "tårkanals": "tårkanal",
    "tårkörteln": "tårkörtel",
    "tårkörtelns": "tårkörtel",
    "tårkörtels": "tårkörtel",
    "tårkörtlar": "tårkörtel",
    "tårkörtlarna": "tårkörtel",
    "tårkörtlarnas": "tårkörtel",
    "tårkörtlars": "tårkörtel",
    "tårna": "tå",
    "tårnas": "tå",
    "tårpilar": "tårpil",
    "tårpilarna": "tårpil",
    "tårpilarnas": "tårpil",
    "tårpilars": "tårpil",
    "tårpilen": "tårpil",
    "tårpilens": "tårpil",
    "tårpils": "tårpil",
    "tårs": "tår",
    "tårsäckar": "tårsäck",
    "tårsäckarna": "tårsäck",
    "tårsäckarnas": "tårsäck",
    "tårsäckars": "tårsäck",
    "tårsäcken": "tårsäck",
    "tårsäckens": "tårsäck",
    "tårsäcks": "tårsäck",
    "tårt": "tårta",
    "tårtad": "tårta",
    "tårtade": "tårta",
    "tårtades": "tårta",
    "tårtads": "tårta",
    "tårtan": "tårta",
    "tårtande": "tårta",
    "tårtanden": "tårtande",
    "tårtandena": "tårtande",
    "tårtandenas": "tårtande",
    "tårtandens": "tårtande",
    "tårtandes": "tårtande",
    "tårtandet": "tårtande",
    "tårtandets": "tårtande",
    "tårtans": "tårta",
    "tårtar": "tårta",
    "tårtas": "tårta",
    "tårtat": "tårta",
    "tårtats": "tårta",
    "tårtbottens": "tårtbotten",
    "tårtbottnar": "tårtbotten",
    "tårtbottnarna": "tårtbotten",
    "tårtbottnarnas": "tårtbotten",
    "tårtbottnars": "tårtbotten",
    "tårtbottnen": "tårtbotten",
    "tårtbottnens": "tårtbotten",
    "tårte": "tårta",
    "tårtkalasen": "tårtkalas",
    "tårtkalasens": "tårtkalas",
    "tårtkalaset": "tårtkalas",
    "tårtkalasets": "tårtkalas",
    "tårtor": "tårta",
    "tårtorna": "tårta",
    "tårtornas": "tårta",
    "tårtors": "tårta",
    "tårts": "tårta",
    "tårtspad": "tårtspade",
    "tårtspadar": "tårtspade",
    "tårtspadarna": "tårtspade",
    "tårtspadarnas": "tårtspade",
    "tårtspadars": "tårtspade",
    "tårtspaden": "tårtspade",
    "tårtspadens": "tårtspade",
    "tårtspadeprincipen": "tårtspadeprincip",
    "tårtspadeprincipens": "tårtspadeprincip",
    "tårtspadeprincips": "tårtspadeprincip",
    "tårtspades": "tårtspade",
    "tårtspads": "tårtspade",
    "tårögda": "tårögd",
    "tårögdare": "tårögd",
    "tårögdares": "tårögd",
    "tårögdas": "tårögd",
    "tårögdast": "tårögd",
    "tårögdaste": "tårögd",
    "tårögdastes": "tårögd",
    "tårögdasts": "tårögd",
    "tårögde": "tårögd",
    "tårögdes": "tårögd",
    "tårögdheten": "tårögdhet",
    "tårögdhetens": "tårögdhet",
    "tårögdhets": "tårögdhet",
    "tårögds": "tårögd",
    "tårögt": "tårögd",
    "tårögts": "tårögd",
    "tås": "tå",
    "tåspetsar": "tåspets",
    "tåspetsarna": "tåspets",
    "tåspetsarnas": "tåspets",
    "tåspetsars": "tåspets",
    "tåspetsdansen": "tåspetsdans",
    "tåspetsdansens": "tåspetsdans",
    "tåspetsen": "tåspets",
    "tåspetsens": "tåspets",
    "tåtar": "tåt",
    "tåtarna": "tåt",
    "tåtarnas": "tåt",
    "tåtars": "tåt",
    "tåten": "tåt",
    "tåtens": "tåt",
    "tåts": "tåt",
    "tête-à-têten": "tête-à-tête",
    "tête-à-têtens": "tête-à-tête",
    "tête-à-têter": "tête-à-tête",
    "tête-à-têterna": "tête-à-tête",
    "tête-à-têternas": "tête-à-tête",
    "tête-à-têters": "tête-à-tête",
    "tête-à-têtes": "tête-à-tête",
    "tö": "töa",
    "töad": "töa",
    "töade": "töa",
    "töades": "töa",
    "töads": "töa",
    "töande": "töa",
    "töanden": "töande",
    "töandena": "töande",
    "töandenas": "töande",
    "töandens": "töande",
    "töandes": "töande",
    "töandet": "töande",
    "töandets": "töande",
    "töar": "töa",
    "töas": "töa",
    "töat": "töa",
    "töats": "töa",
    "töckens": "töcken",
    "töcknen": "töcken",
    "töcknens": "töcken",
    "töcknet": "töcken",
    "töcknets": "töcken",
    "töckniga": "töcknig",
    "töcknigare": "töcknig",
    "töcknigares": "töcknig",
    "töcknigas": "töcknig",
    "töcknigast": "töcknig",
    "töcknigaste": "töcknig",
    "töcknigastes": "töcknig",
    "töcknigasts": "töcknig",
    "töcknige": "töcknig",
    "töckniges": "töcknig",
    "töcknigheten": "töcknighet",
    "töcknighetens": "töcknighet",
    "töcknighets": "töcknighet",
    "töcknigs": "töcknig",
    "töcknigt": "töcknig",
    "töcknigts": "töcknig",
    "töet": "tö",
    "töets": "tö",
    "töiga": "töig",
    "töigare": "töig",
    "töigares": "töig",
    "töigas": "töig",
    "töigast": "töig",
    "töigaste": "töig",
    "töigastes": "töig",
    "töigasts": "töig",
    "töige": "töig",
    "töiges": "töig",
    "töigs": "töig",
    "töigt": "töig",
    "töigts": "töig",
    "töj": "töja",
    "töjande": "töja",
    "töjanden": "töjande",
    "töjandena": "töjande",
    "töjandenas": "töjande",
    "töjandens": "töjande",
    "töjandes": "töjande",
    "töjandet": "töjande",
    "töjandets": "töjande",
    "töjas": "töja",
    "töjbara": "töjbar",
    "töjbarare": "töjbar",
    "töjbarares": "töjbar",
    "töjbaras": "töjbar",
    "töjbarast": "töjbar",
    "töjbaraste": "töjbar",
    "töjbarastes": "töjbar",
    "töjbarasts": "töjbar",
    "töjbare": "töjbar",
    "töjbares": "töjbar",
    "töjbarheten": "töjbarhet",
    "töjbarhetens": "töjbarhet",
    "töjbarheter": "töjbarhet",
    "töjbarheterna": "töjbarhet",
    "töjbarheternas": "töjbarhet",
    "töjbarheters": "töjbarhet",
    "töjbarhets": "töjbarhet",
    "töjbars": "töjbar",
    "töjbart": "töjbar",
    "töjbarts": "töjbar",
    "töjd": "töja",
    "töjda": "töja",
    "töjdas": "töja",
    "töjde": "töja",
    "töjdes": "töja",
    "töjds": "töja",
    "töjer": "töja",
    "töjes": "töja",
    "töjningar": "töjning",
    "töjningarna": "töjning",
    "töjningarnas": "töjning",
    "töjningars": "töjning",
    "töjningen": "töjning",
    "töjningens": "töjning",
    "töjnings": "töjning",
    "töjningsmätar": "töjningsmätare",
    "töjningsmätaren": "töjningsmätare",
    "töjningsmätarens": "töjningsmätare",
    "töjningsmätares": "töjningsmätare",
    "töjningsmätarna": "töjningsmätare",
    "töjningsmätarnas": "töjningsmätare",
    "töjs": "töja",
    "töjt": "töja",
    "töjts": "töja",
    "tölpaktiga": "tölpaktig",
    "tölpaktigare": "tölpaktig",
    "tölpaktigares": "tölpaktig",
    "tölpaktigas": "tölpaktig",
    "tölpaktigast": "tölpaktig",
    "tölpaktigaste": "tölpaktig",
    "tölpaktigastes": "tölpaktig",
    "tölpaktigasts": "tölpaktig",
    "tölpaktige": "tölpaktig",
    "tölpaktiges": "tölpaktig",
    "tölpaktigheten": "tölpaktighet",
    "tölpaktighetens": "tölpaktighet",
    "tölpaktighets": "tölpaktighet",
    "tölpaktigs": "tölpaktig",
    "tölpaktigt": "tölpaktig",
    "tölpaktigts": "tölpaktig",
    "tölpar": "tölp",
    "tölparna": "tölp",
    "tölparnas": "tölp",
    "tölpars": "tölp",
    "tölpen": "tölp",
    "tölpens": "tölp",
    "tölpiga": "tölpig",
    "tölpigare": "tölpig",
    "tölpigares": "tölpig",
    "tölpigas": "tölpig",
    "tölpigast": "tölpig",
    "tölpigaste": "tölpig",
    "tölpigastes": "tölpig",
    "tölpigasts": "tölpig",
    "tölpige": "tölpig",
    "tölpiges": "tölpig",
    "tölpigheten": "tölpighet",
    "tölpighetens": "tölpighet",
    "tölpighets": "tölpighet",
    "tölpigs": "tölpig",
    "tölpigt": "tölpig",
    "tölpigts": "tölpig",
    "tölps": "tölp",
    "tölt": "tölta",
    "töltade": "tölta",
    "töltades": "tölta",
    "töltande": "tölta",
    "töltanden": "töltande",
    "töltandena": "töltande",
    "töltandenas": "töltande",
    "töltandens": "töltande",
    "töltandes": "töltande",
    "töltandet": "töltande",
    "töltandets": "töltande",
    "töltar": "tölta",
    "töltas": "tölta",
    "töltat": "tölta",
    "töltats": "tölta",
    "tölten": "tölt",
    "töltens": "tölt",
    "tölts": "tölt",
    "töm": "tömma",
    "tömd": "tömma",
    "tömda": "tömma",
    "tömdas": "tömma",
    "tömde": "tömma",
    "tömdes": "tömma",
    "tömds": "tömma",
    "tömmande": "tömma",
    "tömmanden": "tömmande",
    "tömmandena": "tömmande",
    "tömmandenas": "tömmande",
    "tömmandens": "tömmande",
    "tömmandes": "tömmande",
    "tömmandet": "tömmande",
    "tömmandets": "tömmande",
    "tömmar": "töm",
    "tömmarna": "töm",
    "tömmarnas": "töm",
    "tömmars": "töm",
    "tömmas": "tömma",
    "tömmen": "töm",
    "tömmens": "töm",
    "tömmer": "tömma",
    "tömningar": "tömning",
    "tömningarna": "tömning",
    "tömningarnas": "tömning",
    "tömningars": "tömning",
    "tömningen": "tömning",
    "tömningens": "tömning",
    "tömnings": "tömning",
    "tömningshålen": "tömningshål",
    "tömningshålens": "tömningshål",
    "tömningshålet": "tömningshål",
    "tömningshålets": "tömningshål",
    "tömningshåls": "tömningshål",
    "tömringar": "tömring",
    "tömringarna": "tömring",
    "tömringarnas": "tömring",
    "tömringars": "tömring",
    "tömringen": "tömring",
    "tömringens": "tömring",
    "tömrings": "tömring",
    "töms": "tömma",
    "tömt": "tömma",
    "tömts": "tömma",
    "tön": "tö",
    "töns": "tö",
    "tönt": "tönta",
    "töntad": "tönta",
    "töntade": "tönta",
    "töntades": "tönta",
    "töntads": "tönta",
    "töntande": "tönta",
    "töntanden": "töntande",
    "töntandena": "töntande",
    "töntandenas": "töntande",
    "töntandens": "töntande",
    "töntandes": "töntande",
    "töntandet": "töntande",
    "töntandets": "töntande",
    "töntar": "tönta",
    "töntarna": "tönt",
    "töntarnas": "tönt",
    "töntars": "tönt",
    "töntas": "tönta",
    "töntat": "tönta",
    "töntats": "tönta",
    "tönten": "tönt",
    "töntens": "tönt",
    "töntiga": "töntig",
    "töntigare": "töntig",
    "töntigares": "töntig",
    "töntigas": "töntig",
    "töntigast": "töntig",
    "töntigaste": "töntig",
    "töntigastes": "töntig",
    "töntigasts": "töntig",
    "töntige": "töntig",
    "töntiges": "töntig",
    "töntigheten": "töntighet",
    "töntighetens": "töntighet",
    "töntigheter": "töntighet",
    "töntigheterna": "töntighet",
    "töntigheternas": "töntighet",
    "töntigheters": "töntighet",
    "töntighets": "töntighet",
    "töntigs": "töntig",
    "töntigt": "töntig",
    "töntigts": "töntig",
    "tönts": "tönt",
    "tör": "torde",
    "töreln": "törel",
    "törelns": "törel",
    "törels": "törel",
    "töres": "töre",
    "töret": "töre",
    "törets": "töre",
    "törn": "törna",
    "törnad": "törna",
    "törnade": "törna",
    "törnades": "törna",
    "törnads": "törna",
    "törnande": "törna",
    "törnanden": "törnande",
    "törnandena": "törnande",
    "törnandenas": "törnande",
    "törnandens": "törnande",
    "törnandes": "törnande",
    "törnandet": "törnande",
    "törnandets": "törnande",
    "törnar": "törna",
    "törnarna": "törn",
    "törnarnas": "törn",
    "törnars": "törn",
    "törnas": "törna",
    "törnat": "törna",
    "törnats": "törna",
    "törnbeströdda": "törnbeströdd",
    "törnbeströddare": "törnbeströdd",
    "törnbeströddares": "törnbeströdd",
    "törnbeströddas": "törnbeströdd",
    "törnbeströddast": "törnbeströdd",
    "törnbeströddaste": "törnbeströdd",
    "törnbeströddastes": "törnbeströdd",
    "törnbeströddasts": "törnbeströdd",
    "törnbeströdde": "törnbeströdd",
    "törnbeströddes": "törnbeströdd",
    "törnbeströdds": "törnbeströdd",
    "törnbestrött": "törnbeströdd",
    "törnbeströtts": "törnbeströdd",
    "törnbusk": "törnbuske",
    "törnbuskar": "törnbuske",
    "törnbuskarna": "törnbuske",
    "törnbuskarnas": "törnbuske",
    "törnbuskars": "törnbuske",
    "törnbusken": "törnbuske",
    "törnbuskens": "törnbuske",
    "törnbuskes": "törnbuske",
    "törnekron": "törnekrona",
    "törnekronan": "törnekrona",
    "törnekronans": "törnekrona",
    "törnekronas": "törnekrona",
    "törnekrone": "törnekrona",
    "törnekronor": "törnekrona",
    "törnekronorna": "törnekrona",
    "törnekronornas": "törnekrona",
    "törnekronors": "törnekrona",
    "törnekrons": "törnekrona",
    "törnekrönta": "törnekrönt",
    "törnekröntare": "törnekrönt",
    "törnekröntares": "törnekrönt",
    "törnekröntas": "törnekrönt",
    "törnekröntast": "törnekrönt",
    "törnekröntaste": "törnekrönt",
    "törnekröntastes": "törnekrönt",
    "törnekröntasts": "törnekrönt",
    "törnekrönte": "törnekrönt",
    "törnekröntes": "törnekrönt",
    "törnekrönts": "törnekrönt",
    "törnen": "törne",
    "törnena": "törne",
    "törnenas": "törne",
    "törnens": "törne",
    "törnes": "törne",
    "törnet": "törne",
    "törnets": "törne",
    "törniga": "törnig",
    "törnigare": "törnig",
    "törnigares": "törnig",
    "törnigas": "törnig",
    "törnigast": "törnig",
    "törnigaste": "törnig",
    "törnigastes": "törnig",
    "törnigasts": "törnig",
    "törnige": "törnig",
    "törniges": "törnig",
    "törnigheten": "törnighet",
    "törnighetens": "törnighet",
    "törnighets": "törnighet",
    "törnigs": "törnig",
    "törnigt": "törnig",
    "törnigts": "törnig",
    "törnrosasömnen": "törnrosasömn",
    "törnrosasömnens": "törnrosasömn",
    "törnrosasömns": "törnrosasömn",
    "törnrosen": "törnros",
    "törnrosens": "törnros",
    "törnrosor": "törnros",
    "törnrosorna": "törnros",
    "törnrosornas": "törnros",
    "törnrosors": "törnros",
    "törns": "törne",
    "törnskat": "törnskata",
    "törnskatan": "törnskata",
    "törnskatans": "törnskata",
    "törnskatas": "törnskata",
    "törnskate": "törnskata",
    "törnskator": "törnskata",
    "törnskatorna": "törnskata",
    "törnskatornas": "törnskata",
    "törnskators": "törnskata",
    "törnskats": "törnskata",
    "törnsångar": "törnsångare",
    "törnsångaren": "törnsångare",
    "törnsångarens": "törnsångare",
    "törnsångares": "törnsångare",
    "törnsångarna": "törnsångare",
    "törnsångarnas": "törnsångare",
    "törntaggar": "törntagg",
    "törntaggarna": "törntagg",
    "törntaggarnas": "törntagg",
    "törntaggars": "törntagg",
    "törntaggen": "törntagg",
    "törntaggens": "törntagg",
    "törntaggs": "törntagg",
    "törs": "töras",
    "törst": "törsta",
    "törstad": "törsta",
    "törstade": "törsta",
    "törstades": "törsta",
    "törstads": "törsta",
    "törstande": "törsta",
    "törstanden": "törstande",
    "törstandena": "törstande",
    "törstandenas": "törstande",
    "törstandens": "törstande",
    "törstandes": "törstande",
    "törstandet": "törstande",
    "törstandets": "törstande",
    "törstar": "törsta",
    "törstas": "törsta",
    "törstat": "törsta",
    "törstats": "törsta",
    "törsten": "törst",
    "törstens": "törst",
    "törstiga": "törstig",
    "törstigare": "törstig",
    "törstigares": "törstig",
    "törstigas": "törstig",
    "törstigast": "törstig",
    "törstigaste": "törstig",
    "törstigastes": "törstig",
    "törstigasts": "törstig",
    "törstige": "törstig",
    "törstiges": "törstig",
    "törstigheten": "törstighet",
    "törstighetens": "törstighet",
    "törstighets": "törstighet",
    "törstigs": "törstig",
    "törstigt": "törstig",
    "törstigts": "törstig",
    "törsts": "törst",
    "tös": "tö",
    "tösen": "tös",
    "tösens": "tös",
    "töser": "tös",
    "töserna": "tös",
    "tösernas": "tös",
    "tösers": "tös",
    "töt": "tö",
    "töts": "tö",
    "töv": "töva",
    "tövad": "töva",
    "tövade": "töva",
    "tövades": "töva",
    "tövads": "töva",
    "tövande": "töva",
    "tövanden": "tövande",
    "tövandena": "tövande",
    "tövandenas": "tövande",
    "tövandens": "tövande",
    "tövandes": "tövande",
    "tövandet": "tövande",
    "tövandets": "tövande",
    "tövans": "tövan",
    "tövar": "töva",
    "tövas": "töva",
    "tövat": "töva",
    "tövats": "töva",
    "töväderna": "töväder",
    "tövädernas": "töväder",
    "töväders": "töväder",
    "tövädren": "töväder",
    "tövädrens": "töväder",
    "tövädret": "töväder",
    "tövädrets": "töväder",
    "u-båtar": "u-båt",
    "u-båtarna": "u-båt",
    "u-båtarnas": "u-båt",
    "u-båtars": "u-båt",
    "u-båten": "u-båt",
    "u-båtens": "u-båt",
    "u-båts": "u-båt",
    "u-et": "u",
    "u-ets": "u",
    "u-formade": "u-formad",
    "u-formades": "u-formad",
    "u-formads": "u-formad",
    "u-format": "u-formad",
    "u-formats": "u-formad",
    "u-formiga": "u-formig",
    "u-formigare": "u-formig",
    "u-formigares": "u-formig",
    "u-formigas": "u-formig",
    "u-formigast": "u-formig",
    "u-formigaste": "u-formig",
    "u-formigastes": "u-formig",
    "u-formigasts": "u-formig",
    "u-formige": "u-formig",
    "u-formiges": "u-formig",
    "u-formigs": "u-formig",
    "u-formigt": "u-formig",
    "u-formigts": "u-formig",
    "u-hjälpen": "u-hjälp",
    "u-hjälpens": "u-hjälp",
    "u-hjälps": "u-hjälp",
    "u-landet": "u-land",
    "u-länder": "u-land",
    "u-ländernas": "u-land",
    "u-n": "u",
    "u-na": "u",
    "u-nas": "u",
    "u-ns": "u",
    "u-t": "u",
    "u-ts": "u",
    "u:et": "u",
    "u:ets": "u",
    "u:n": "u",
    "u:na": "u",
    "u:nas": "u",
    "u:ns": "u",
    "u:s": "u",
    "u:t": "u",
    "u:ts": "u",
    "ubikvisten": "ubikvist",
    "ubikvistens": "ubikvist",
    "ubikvister": "ubikvist",
    "ubikvisterna": "ubikvist",
    "ubikvisternas": "ubikvist",
    "ubikvisters": "ubikvist",
    "ubikvists": "ubikvist",
    "ubikviteten": "ubikvitet",
    "ubikvitetens": "ubikvitet",
    "ubikviteter": "ubikvitet",
    "ubikviteterna": "ubikvitet",
    "ubikviteternas": "ubikvitet",
    "ubikviteters": "ubikvitet",
    "ubikvitets": "ubikvitet",
    "ubåtar": "ubåt",
    "ubåtarna": "ubåt",
    "ubåtarnas": "ubåt",
    "ubåtars": "ubåt",
    "ubåten": "ubåt",
    "ubåtens": "ubåt",
    "ubåts": "ubåt",
    "ubåtsfäll": "ubåtsfälla",
    "ubåtsfällan": "ubåtsfälla",
    "ubåtsfällans": "ubåtsfälla",
    "ubåtsfällas": "ubåtsfälla",
    "ubåtsfälle": "ubåtsfälla",
    "ubåtsfällor": "ubåtsfälla",
    "ubåtsfällorna": "ubåtsfälla",
    "ubåtsfällornas": "ubåtsfälla",
    "ubåtsfällors": "ubåtsfälla",
    "ubåtsfälls": "ubåtsfälla",
    "ubåtsförstörar": "ubåtsförstörare",
    "ubåtsförstöraren": "ubåtsförstörare",
    "ubåtsförstörarens": "ubåtsförstörare",
    "ubåtsförstörares": "ubåtsförstörare",
    "ubåtsförstörarna": "ubåtsförstörare",
    "ubåtsförstörarnas": "ubåtsförstörare",
    "ubåtsjagar": "ubåtsjagare",
    "ubåtsjagaren": "ubåtsjagare",
    "ubåtsjagarens": "ubåtsjagare",
    "ubåtsjagares": "ubåtsjagare",
    "ubåtsjagarna": "ubåtsjagare",
    "ubåtsjagarnas": "ubåtsjagare",
    "ubåtsjakten": "ubåtsjakt",
    "ubåtsjaktens": "ubåtsjakt",
    "ubåtsjakter": "ubåtsjakt",
    "ubåtsjakterna": "ubåtsjakt",
    "ubåtsjakternas": "ubåtsjakt",
    "ubåtsjakters": "ubåtsjakt",
    "ubåtsjaktfartygen": "ubåtsjaktfartyg",
    "ubåtsjaktfartygens": "ubåtsjaktfartyg",
    "ubåtsjaktfartyget": "ubåtsjaktfartyg",
    "ubåtsjaktfartygets": "ubåtsjaktfartyg",
    "ubåtsjaktfartygs": "ubåtsjaktfartyg",
    "ubåtsjakts": "ubåtsjakt",
    "ubåtsklock": "ubåtsklocka",
    "ubåtsklockan": "ubåtsklocka",
    "ubåtsklockans": "ubåtsklocka",
    "ubåtsklockas": "ubåtsklocka",
    "ubåtsklocke": "ubåtsklocka",
    "ubåtsklockor": "ubåtsklocka",
    "ubåtsklockorna": "ubåtsklocka",
    "ubåtsklockornas": "ubåtsklocka",
    "ubåtsklockors": "ubåtsklocka",
    "ubåtsklocks": "ubåtsklocka",
    "ubåtsnäten": "ubåtsnät",
    "ubåtsnätens": "ubåtsnät",
    "ubåtsnätet": "ubåtsnät",
    "ubåtsnätets": "ubåtsnät",
    "ubåtsnäts": "ubåtsnät",
    "udd": "udde",
    "uddabyx": "uddabyxa",
    "uddabyxan": "uddabyxa",
    "uddabyxans": "uddabyxa",
    "uddabyxas": "uddabyxa",
    "uddabyxe": "uddabyxa",
    "uddabyxor": "uddabyxa",
    "uddabyxorna": "uddabyxa",
    "uddabyxornas": "uddabyxa",
    "uddabyxors": "uddabyxa",
    "uddamålen": "uddamål",
    "uddamålens": "uddamål",
    "uddamålet": "uddamål",
    "uddamålets": "uddamål",
    "uddamåls": "uddamål",
    "uddanummerna": "uddanummer",
    "uddanummernas": "uddanummer",
    "uddanummers": "uddanummer",
    "uddanumren": "uddanummer",
    "uddanumrens": "uddanummer",
    "uddanumret": "uddanummer",
    "uddanumrets": "uddanummer",
    "uddaplaggen": "uddaplagg",
    "uddaplaggens": "uddaplagg",
    "uddaplagget": "uddaplagg",
    "uddaplaggets": "uddaplagg",
    "uddaplaggs": "uddaplagg",
    "uddar": "udde",
    "uddarna": "udde",
    "uddarnas": "udde",
    "uddars": "udde",
    "uddatalsmetoden": "uddatalsmetod",
    "uddatalsmetodens": "uddatalsmetod",
    "uddatalsmetoder": "uddatalsmetod",
    "uddatalsmetoderna": "uddatalsmetod",
    "uddatalsmetodernas": "uddatalsmetod",
    "uddatalsmetoders": "uddatalsmetod",
    "uddatalsmetods": "uddatalsmetod",
    "uddatåiga": "uddatåig",
    "uddatåigare": "uddatåig",
    "uddatåigares": "uddatåig",
    "uddatåigas": "uddatåig",
    "uddatåigast": "uddatåig",
    "uddatåigaste": "uddatåig",
    "uddatåigastes": "uddatåig",
    "uddatåigasts": "uddatåig",
    "uddatåige": "uddatåig",
    "uddatåiges": "uddatåig",
    "uddatåigs": "uddatåig",
    "uddatåigt": "uddatåig",
    "uddatåigts": "uddatåig",
    "uddbladen": "uddblad",
    "uddbladens": "uddblad",
    "uddbladet": "uddblad",
    "uddbladets": "uddblad",
    "uddblads": "uddblad",
    "udden": "udde",
    "uddens": "udde",
    "uddes": "udde",
    "uddiga": "uddig",
    "uddigare": "uddig",
    "uddigares": "uddig",
    "uddigas": "uddig",
    "uddigast": "uddig",
    "uddigaste": "uddig",
    "uddigastes": "uddig",
    "uddigasts": "uddig",
    "uddige": "uddig",
    "uddiges": "uddig",
    "uddigheten": "uddighet",
    "uddighetens": "uddighet",
    "uddighets": "uddighet",
    "uddigs": "uddig",
    "uddigt": "uddig",
    "uddigts": "uddig",
    "uddjärnen": "uddjärn",
    "uddjärnens": "uddjärn",
    "uddjärnet": "uddjärn",
    "uddjärnets": "uddjärn",
    "uddjärns": "uddjärn",
    "uddljuden": "uddljud",
    "uddljudens": "uddljud",
    "uddljudet": "uddljud",
    "uddljudets": "uddljud",
    "uddljuds": "uddljud",
    "uddlösa": "uddlös",
    "uddlösare": "uddlös",
    "uddlösares": "uddlös",
    "uddlösas": "uddlös",
    "uddlösast": "uddlös",
    "uddlösaste": "uddlös",
    "uddlösastes": "uddlös",
    "uddlösasts": "uddlös",
    "uddlöse": "uddlös",
    "uddlöses": "uddlös",
    "uddlösheten": "uddlöshet",
    "uddlöshetens": "uddlöshet",
    "uddlöshets": "uddlöshet",
    "uddlöst": "uddlös",
    "uddlösts": "uddlös",
    "uddrimmen": "uddrim",
    "uddrimmens": "uddrim",
    "uddrimmet": "uddrim",
    "uddrimmets": "uddrim",
    "uddrims": "uddrim",
    "udds": "udde",
    "ufohackar": "ufohackare",
    "ufohackaren": "ufohackare",
    "ufohackarens": "ufohackare",
    "ufohackares": "ufohackare",
    "ufohackarna": "ufohackare",
    "ufohackarnas": "ufohackare",
    "ufon": "ufo",
    "ufona": "ufo",
    "ufonas": "ufo",
    "ufons": "ufo",
    "ufos": "ufo",
    "ufot": "ufo",
    "ufots": "ufo",
    "ugandiern": "ugandier",
    "ugandierna": "ugandier",
    "ugandiernas": "ugandier",
    "ugandierns": "ugandier",
    "ugandiers": "ugandier",
    "ugandiska": "ugandisk",
    "ugandiskan": "ugandiska",
    "ugandiskans": "ugandiska",
    "ugandiskare": "ugandisk",
    "ugandiskares": "ugandisk",
    "ugandiskas": "ugandiska",
    "ugandiskast": "ugandisk",
    "ugandiskaste": "ugandisk",
    "ugandiskastes": "ugandisk",
    "ugandiskasts": "ugandisk",
    "ugandiske": "ugandiska",
    "ugandiskes": "ugandisk",
    "ugandiskor": "ugandiska",
    "ugandiskorna": "ugandiska",
    "ugandiskornas": "ugandiska",
    "ugandiskors": "ugandiska",
    "ugandisks": "ugandisk",
    "ugandiskt": "ugandisk",
    "ugandiskts": "ugandisk",
    "uggel": "uggla",
    "ugglade": "uggla",
    "ugglades": "uggla",
    "ugglan": "uggla",
    "ugglande": "uggla",
    "ugglanden": "ugglande",
    "ugglandena": "ugglande",
    "ugglandenas": "ugglande",
    "ugglandens": "ugglande",
    "ugglandes": "ugglande",
    "ugglandet": "ugglande",
    "ugglandets": "ugglande",
    "ugglans": "uggla",
    "ugglar": "uggla",
    "ugglas": "uggla",
    "ugglat": "uggla",
    "ugglats": "uggla",
    "uggle": "uggla",
    "ugglebollar": "uggleboll",
    "ugglebollarna": "uggleboll",
    "ugglebollarnas": "uggleboll",
    "ugglebollars": "uggleboll",
    "ugglebollen": "uggleboll",
    "ugglebollens": "uggleboll",
    "ugglebolls": "uggleboll",
    "uggleglasögonen": "uggleglasögon",
    "uggleglasögonens": "uggleglasögon",
    "uggleglasögons": "uggleglasögon",
    "uggleveden": "uggleved",
    "ugglevedens": "uggleved",
    "uggleveds": "uggleved",
    "ugglor": "uggla",
    "ugglorna": "uggla",
    "ugglornas": "uggla",
    "ugglors": "uggla",
    "ugnar": "ugn",
    "ugnarna": "ugn",
    "ugnarnas": "ugn",
    "ugnars": "ugn",
    "ugnen": "ugn",
    "ugnens": "ugn",
    "ugns": "ugn",
    "ugnsbak": "ugnsbaka",
    "ugnsbakad": "ugnsbaka",
    "ugnsbakade": "ugnsbaka",
    "ugnsbakades": "ugnsbaka",
    "ugnsbakads": "ugnsbaka",
    "ugnsbakande": "ugnsbaka",
    "ugnsbakanden": "ugnsbakande",
    "ugnsbakandena": "ugnsbakande",
    "ugnsbakandenas": "ugnsbakande",
    "ugnsbakandens": "ugnsbakande",
    "ugnsbakandes": "ugnsbakande",
    "ugnsbakandet": "ugnsbakande",
    "ugnsbakandets": "ugnsbakande",
    "ugnsbakar": "ugnsbaka",
    "ugnsbakas": "ugnsbaka",
    "ugnsbakat": "ugnsbaka",
    "ugnsbakats": "ugnsbaka",
    "ugnsbakt": "ugnsbaka",
    "ugnsbakta": "ugnsbaka",
    "ugnsbaktas": "ugnsbaka",
    "ugnsbakte": "ugnsbaka",
    "ugnsbaktes": "ugnsbaka",
    "ugnsbakts": "ugnsbaka",
    "ugnseldfasta": "ugnseldfast",
    "ugnseldfastare": "ugnseldfast",
    "ugnseldfastares": "ugnseldfast",
    "ugnseldfastas": "ugnseldfast",
    "ugnseldfastast": "ugnseldfast",
    "ugnseldfastaste": "ugnseldfast",
    "ugnseldfastastes": "ugnseldfast",
    "ugnseldfastasts": "ugnseldfast",
    "ugnseldfaste": "ugnseldfast",
    "ugnseldfastes": "ugnseldfast",
    "ugnseldfastheten": "ugnseldfasthet",
    "ugnseldfasthetens": "ugnseldfasthet",
    "ugnseldfasthets": "ugnseldfasthet",
    "ugnseldfasts": "ugnseldfast",
    "ugnsfasta": "ugnsfast",
    "ugnsfastare": "ugnsfast",
    "ugnsfastares": "ugnsfast",
    "ugnsfastas": "ugnsfast",
    "ugnsfastast": "ugnsfast",
    "ugnsfastaste": "ugnsfast",
    "ugnsfastastes": "ugnsfast",
    "ugnsfastasts": "ugnsfast",
    "ugnsfaste": "ugnsfast",
    "ugnsfastes": "ugnsfast",
    "ugnsfasts": "ugnsfast",
    "ugnsfiskar": "ugnsfisk",
    "ugnsfiskarna": "ugnsfisk",
    "ugnsfiskarnas": "ugnsfisk",
    "ugnsfiskars": "ugnsfisk",
    "ugnsfisken": "ugnsfisk",
    "ugnsfiskens": "ugnsfisk",
    "ugnsfisks": "ugnsfisk",
    "ugnsgrädd": "ugnsgrädda",
    "ugnsgräddad": "ugnsgrädda",
    "ugnsgräddade": "ugnsgrädda",
    "ugnsgräddades": "ugnsgrädda",
    "ugnsgräddads": "ugnsgrädda",
    "ugnsgräddande": "ugnsgrädda",
    "ugnsgräddanden": "ugnsgräddande",
    "ugnsgräddandena": "ugnsgräddande",
    "ugnsgräddandenas": "ugnsgräddande",
    "ugnsgräddandens": "ugnsgräddande",
    "ugnsgräddandes": "ugnsgräddande",
    "ugnsgräddandet": "ugnsgräddande",
    "ugnsgräddandets": "ugnsgräddande",
    "ugnsgräddar": "ugnsgrädda",
    "ugnsgräddas": "ugnsgrädda",
    "ugnsgräddat": "ugnsgrädda",
    "ugnsgräddats": "ugnsgrädda",
    "ugnshällar": "ugnshäll",
    "ugnshällarna": "ugnshäll",
    "ugnshällarnas": "ugnshäll",
    "ugnshällars": "ugnshäll",
    "ugnshällen": "ugnshäll",
    "ugnshällens": "ugnshäll",
    "ugnshälls": "ugnshäll",
    "ugnsinfodringar": "ugnsinfodring",
    "ugnsinfodringarna": "ugnsinfodring",
    "ugnsinfodringarnas": "ugnsinfodring",
    "ugnsinfodringars": "ugnsinfodring",
    "ugnsinfodringen": "ugnsinfodring",
    "ugnsinfodringens": "ugnsinfodring",
    "ugnsinfodrings": "ugnsinfodring",
    "ugnskapp": "ugnskappa",
    "ugnskappan": "ugnskappa",
    "ugnskappans": "ugnskappa",
    "ugnskappas": "ugnskappa",
    "ugnskappe": "ugnskappa",
    "ugnskappor": "ugnskappa",
    "ugnskapporna": "ugnskappa",
    "ugnskappornas": "ugnskappa",
    "ugnskappors": "ugnskappa",
    "ugnskapps": "ugnskappa",
    "ugnskok": "ugnskoka",
    "ugnskokad": "ugnskoka",
    "ugnskokade": "ugnskoka",
    "ugnskokades": "ugnskoka",
    "ugnskokads": "ugnskoka",
    "ugnskokande": "ugnskoka",
    "ugnskokanden": "ugnskokande",
    "ugnskokandena": "ugnskokande",
    "ugnskokandenas": "ugnskokande",
    "ugnskokandens": "ugnskokande",
    "ugnskokandes": "ugnskokande",
    "ugnskokandet": "ugnskokande",
    "ugnskokandets": "ugnskokande",
    "ugnskokar": "ugnskoka",
    "ugnskokas": "ugnskoka",
    "ugnskokat": "ugnskoka",
    "ugnskokats": "ugnskoka",
    "ugnskoker": "ugnskoka",
    "ugnskokes": "ugnskoka",
    "ugnskoks": "ugnskoka",
    "ugnskokt": "ugnskoka",
    "ugnskokta": "ugnskoka",
    "ugnskoktas": "ugnskoka",
    "ugnskokte": "ugnskoka",
    "ugnskoktes": "ugnskoka",
    "ugnskokts": "ugnskoka",
    "ugnskolen": "ugnskol",
    "ugnskolens": "ugnskol",
    "ugnskolet": "ugnskol",
    "ugnskolets": "ugnskol",
    "ugnskolningar": "ugnskolning",
    "ugnskolningarna": "ugnskolning",
    "ugnskolningarnas": "ugnskolning",
    "ugnskolningars": "ugnskolning",
    "ugnskolningen": "ugnskolning",
    "ugnskolningens": "ugnskolning",
    "ugnskolnings": "ugnskolning",
    "ugnskols": "ugnskol",
    "ugnskåp": "ugnskåpa",
    "ugnskåpan": "ugnskåpa",
    "ugnskåpans": "ugnskåpa",
    "ugnskåpas": "ugnskåpa",
    "ugnskåpe": "ugnskåpa",
    "ugnskåpor": "ugnskåpa",
    "ugnskåporna": "ugnskåpa",
    "ugnskåpornas": "ugnskåpa",
    "ugnskåpors": "ugnskåpa",
    "ugnskåps": "ugnskåpa",
    "ugnslagade": "ugnslagad",
    "ugnslagades": "ugnslagad",
    "ugnslagads": "ugnslagad",
    "ugnslagat": "ugnslagad",
    "ugnslagats": "ugnslagad",
    "ugnsluck": "ugnslucka",
    "ugnsluckan": "ugnslucka",
    "ugnsluckans": "ugnslucka",
    "ugnsluckas": "ugnslucka",
    "ugnslucke": "ugnslucka",
    "ugnsluckor": "ugnslucka",
    "ugnsluckorna": "ugnslucka",
    "ugnsluckornas": "ugnslucka",
    "ugnsluckors": "ugnslucka",
    "ugnslucks": "ugnslucka",
    "ugnsomeletten": "ugnsomelett",
    "ugnsomelettens": "ugnsomelett",
    "ugnsomeletter": "ugnsomelett",
    "ugnsomeletterna": "ugnsomelett",
    "ugnsomeletternas": "ugnsomelett",
    "ugnsomeletters": "ugnsomelett",
    "ugnsomeletts": "ugnsomelett",
    "ugnspannkak": "ugnspannkaka",
    "ugnspannkakan": "ugnspannkaka",
    "ugnspannkakans": "ugnspannkaka",
    "ugnspannkakas": "ugnspannkaka",
    "ugnspannkake": "ugnspannkaka",
    "ugnspannkakor": "ugnspannkaka",
    "ugnspannkakorna": "ugnspannkaka",
    "ugnspannkakornas": "ugnspannkaka",
    "ugnspannkakors": "ugnspannkaka",
    "ugnspannkaks": "ugnspannkaka",
    "ugnsplåtar": "ugnsplåt",
    "ugnsplåtarna": "ugnsplåt",
    "ugnsplåtarnas": "ugnsplåt",
    "ugnsplåtars": "ugnsplåt",
    "ugnsplåten": "ugnsplåt",
    "ugnsplåtens": "ugnsplåt",
    "ugnsplåts": "ugnsplåt",
    "ugnsspad": "ugnsspade",
    "ugnsspadar": "ugnsspade",
    "ugnsspadarna": "ugnsspade",
    "ugnsspadarnas": "ugnsspade",
    "ugnsspadars": "ugnsspade",
    "ugnsspaden": "ugnsspade",
    "ugnsspadens": "ugnsspade",
    "ugnsspades": "ugnsspade",
    "ugnsspads": "ugnsspade",
    "ugnsstek": "ugnssteka",
    "ugnsstekande": "ugnssteka",
    "ugnsstekanden": "ugnsstekande",
    "ugnsstekandena": "ugnsstekande",
    "ugnsstekandenas": "ugnsstekande",
    "ugnsstekandens": "ugnsstekande",
    "ugnsstekandes": "ugnsstekande",
    "ugnsstekandet": "ugnsstekande",
    "ugnsstekandets": "ugnsstekande",
    "ugnsstekas": "ugnssteka",
    "ugnssteker": "ugnssteka",
    "ugnsstekes": "ugnssteka",
    "ugnssteks": "ugnssteka",
    "ugnsstekt": "ugnssteka",
    "ugnsstekta": "ugnssteka",
    "ugnsstektas": "ugnssteka",
    "ugnsstekte": "ugnssteka",
    "ugnsstektes": "ugnssteka",
    "ugnsstekts": "ugnssteka",
    "ugnssvärt": "ugnssvärta",
    "ugnssvärtan": "ugnssvärta",
    "ugnssvärtans": "ugnssvärta",
    "ugnssvärtas": "ugnssvärta",
    "ugnssvärte": "ugnssvärta",
    "ugnssvärtor": "ugnssvärta",
    "ugnssvärtorna": "ugnssvärta",
    "ugnssvärtornas": "ugnssvärta",
    "ugnssvärtors": "ugnssvärta",
    "ugnssvärts": "ugnssvärta",
    "ugnstegels": "ugnstegel",
    "ugnsteglen": "ugnstegel",
    "ugnsteglens": "ugnstegel",
    "ugnsteglet": "ugnstegel",
    "ugnsteglets": "ugnstegel",
    "ugnstillagade": "ugnstillagad",
    "ugnstillagades": "ugnstillagad",
    "ugnstillagads": "ugnstillagad",
    "ugnstillagat": "ugnstillagad",
    "ugnstillagats": "ugnstillagad",
    "ugnstjär": "ugnstjära",
    "ugnstjäran": "ugnstjära",
    "ugnstjärans": "ugnstjära",
    "ugnstjäras": "ugnstjära",
    "ugnstjäre": "ugnstjära",
    "ugnstjäror": "ugnstjära",
    "ugnstjärorna": "ugnstjära",
    "ugnstjärornas": "ugnstjära",
    "ugnstjärors": "ugnstjära",
    "ugnstjärs": "ugnstjära",
    "ugnstork": "ugnstorka",
    "ugnstorkad": "ugnstorka",
    "ugnstorkade": "ugnstorka",
    "ugnstorkades": "ugnstorka",
    "ugnstorkads": "ugnstorka",
    "ugnstorkande": "ugnstorka",
    "ugnstorkanden": "ugnstorkande",
    "ugnstorkandena": "ugnstorkande",
    "ugnstorkandenas": "ugnstorkande",
    "ugnstorkandens": "ugnstorkande",
    "ugnstorkandes": "ugnstorkande",
    "ugnstorkandet": "ugnstorkande",
    "ugnstorkandets": "ugnstorkande",
    "ugnstorkar": "ugnstorka",
    "ugnstorkas": "ugnstorka",
    "ugnstorkat": "ugnstorka",
    "ugnstorkats": "ugnstorka",
    "ugnsvarma": "ugnsvarm",
    "ugnsvarmare": "ugnsvarm",
    "ugnsvarmares": "ugnsvarm",
    "ugnsvarmas": "ugnsvarm",
    "ugnsvarmast": "ugnsvarm",
    "ugnsvarmaste": "ugnsvarm",
    "ugnsvarmastes": "ugnsvarm",
    "ugnsvarmasts": "ugnsvarm",
    "ugnsvarme": "ugnsvarm",
    "ugnsvarmes": "ugnsvarm",
    "ugnsvarms": "ugnsvarm",
    "ugnsvarmt": "ugnsvarm",
    "ugnsvarmts": "ugnsvarm",
    "ugnsvärmen": "ugnsvärme",
    "ugnsvärmens": "ugnsvärme",
    "ugnsvärmes": "ugnsvärme",
    "ukasen": "ukas",
    "ukasens": "ukas",
    "ukaser": "ukas",
    "ukaserna": "ukas",
    "ukasernas": "ukas",
    "ukasers": "ukas",
    "ukrainar": "ukrainare",
    "ukrainaren": "ukrainare",
    "ukrainarens": "ukrainare",
    "ukrainares": "ukrainare",
    "ukrainarna": "ukrainare",
    "ukrainarnas": "ukrainare",
    "ukrainsk": "ukrainska",
    "ukrainska": "ukrainsk",
    "ukrainskan": "ukrainska",
    "ukrainskans": "ukrainska",
    "ukrainskare": "ukrainsk",
    "ukrainskares": "ukrainsk",
    "ukrainskas": "ukrainska",
    "ukrainskast": "ukrainsk",
    "ukrainskaste": "ukrainsk",
    "ukrainskastes": "ukrainsk",
    "ukrainskasts": "ukrainsk",
    "ukrainske": "ukrainska",
    "ukrainskes": "ukrainsk",
    "ukrainskor": "ukrainska",
    "ukrainskorna": "ukrainska",
    "ukrainskornas": "ukrainska",
    "ukrainskors": "ukrainska",
    "ukrainsks": "ukrainsk",
    "ukrainskt": "ukrainsk",
    "ukrainskts": "ukrainsk",
    "ukulelen": "ukulele",
    "ukulelens": "ukulele",
    "ukuleler": "ukulele",
    "ukulelerna": "ukulele",
    "ukulelernas": "ukulele",
    "ukulelers": "ukulele",
    "ukuleles": "ukulele",
    "ulanen": "ulan",
    "ulanens": "ulan",
    "ulaner": "ulan",
    "ulanerna": "ulan",
    "ulanernas": "ulan",
    "ulaners": "ulan",
    "ulans": "ulan",
    "ulcerösa": "ulcerös",
    "ulcerösare": "ulcerös",
    "ulcerösares": "ulcerös",
    "ulcerösas": "ulcerös",
    "ulcerösast": "ulcerös",
    "ulcerösaste": "ulcerös",
    "ulcerösastes": "ulcerös",
    "ulcerösasts": "ulcerös",
    "ulceröse": "ulcerös",
    "ulceröses": "ulcerös",
    "ulceröst": "ulcerös",
    "ulcerösts": "ulcerös",
    "ulk": "ulka",
    "ulkad": "ulka",
    "ulkade": "ulka",
    "ulkades": "ulka",
    "ulkads": "ulka",
    "ulkande": "ulka",
    "ulkanden": "ulkande",
    "ulkandena": "ulkande",
    "ulkandenas": "ulkande",
    "ulkandens": "ulkande",
    "ulkandes": "ulkande",
    "ulkandet": "ulkande",
    "ulkandets": "ulkande",
    "ulkar": "ulka",
    "ulkarna": "ulk",
    "ulkarnas": "ulk",
    "ulkars": "ulk",
    "ulkas": "ulka",
    "ulkat": "ulka",
    "ulkats": "ulka",
    "ulken": "ulk",
    "ulkens": "ulk",
    "ulks": "ulk",
    "ullades": "ullas",
    "ullap": "ullapa",
    "ullapan": "ullapa",
    "ullapans": "ullapa",
    "ullapas": "ullapa",
    "ullape": "ullapa",
    "ullapor": "ullapa",
    "ullaporna": "ullapa",
    "ullapornas": "ullapa",
    "ullapors": "ullapa",
    "ullaps": "ullapa",
    "ullats": "ullas",
    "ullen": "ull",
    "ullens": "ull",
    "ullfettet": "ullfett",
    "ullfettets": "ullfett",
    "ullfetts": "ullfett",
    "ullgarnet": "ullgarn",
    "ullgarnets": "ullgarn",
    "ullgarns": "ullgarn",
    "ullhandskrabb": "ullhandskrabba",
    "ullhandskrabban": "ullhandskrabba",
    "ullhandskrabbans": "ullhandskrabba",
    "ullhandskrabbas": "ullhandskrabba",
    "ullhandskrabbe": "ullhandskrabba",
    "ullhandskrabbor": "ullhandskrabba",
    "ullhandskrabborna": "ullhandskrabba",
    "ullhandskrabbornas": "ullhandskrabba",
    "ullhandskrabbors": "ullhandskrabba",
    "ullhandskrabbs": "ullhandskrabba",
    "ullhåret": "ullhår",
    "ullhårets": "ullhår",
    "ullhåriga": "ullhårig",
    "ullhårigare": "ullhårig",
    "ullhårigares": "ullhårig",
    "ullhårigas": "ullhårig",
    "ullhårigast": "ullhårig",
    "ullhårigaste": "ullhårig",
    "ullhårigastes": "ullhårig",
    "ullhårigasts": "ullhårig",
    "ullhårige": "ullhårig",
    "ullhåriges": "ullhårig",
    "ullhårigheten": "ullhårighet",
    "ullhårighetens": "ullhårighet",
    "ullhårighets": "ullhårighet",
    "ullhårigs": "ullhårig",
    "ullhårigt": "ullhårig",
    "ullhårigts": "ullhårig",
    "ullhårs": "ullhår",
    "ulliga": "ullig",
    "ulligare": "ullig",
    "ulligares": "ullig",
    "ulligas": "ullig",
    "ulligast": "ullig",
    "ulligaste": "ullig",
    "ulligastes": "ullig",
    "ulligasts": "ullig",
    "ullige": "ullig",
    "ulliges": "ullig",
    "ulligheten": "ullighet",
    "ullighetens": "ullighet",
    "ullighets": "ullighet",
    "ulligs": "ullig",
    "ulligt": "ullig",
    "ulligts": "ullig",
    "ulloljan": "ullolja",
    "ulloljans": "ullolja",
    "ulloljas": "ullolja",
    "ullolje": "ullolja",
    "ulloljor": "ullolja",
    "ulloljorna": "ullolja",
    "ulloljornas": "ullolja",
    "ulloljors": "ullolja",
    "ulls": "ull",
    "ullsaxar": "ullsax",
    "ullsaxarna": "ullsax",
    "ullsaxarnas": "ullsax",
    "ullsaxars": "ullsax",
    "ullsaxen": "ullsax",
    "ullsaxens": "ullsax",
    "ullsidan": "ullsida",
    "ullsidans": "ullsida",
    "ullsidas": "ullsida",
    "ullside": "ullsida",
    "ullsides": "ullsida",
    "ullsidor": "ullsida",
    "ullsidorna": "ullsida",
    "ullsidornas": "ullsida",
    "ullsidors": "ullsida",
    "ullstrump": "ullstrumpa",
    "ullstrumpan": "ullstrumpa",
    "ullstrumpans": "ullstrumpa",
    "ullstrumpas": "ullstrumpa",
    "ullstrumpe": "ullstrumpa",
    "ullstrumpor": "ullstrumpa",
    "ullstrumporna": "ullstrumpa",
    "ullstrumpornas": "ullstrumpa",
    "ullstrumpors": "ullstrumpa",
    "ullstrumps": "ullstrumpa",
    "ullsvetten": "ullsvett",
    "ullsvettens": "ullsvett",
    "ullsvetts": "ullsvett",
    "ulltorkar": "ulltork",
    "ulltorkarna": "ulltork",
    "ulltorkarnas": "ulltork",
    "ulltorkars": "ulltork",
    "ulltorken": "ulltork",
    "ulltorkens": "ulltork",
    "ulltorks": "ulltork",
    "ulltottar": "ulltott",
    "ulltottarna": "ulltott",
    "ulltottarnas": "ulltott",
    "ulltottars": "ulltott",
    "ulltotten": "ulltott",
    "ulltottens": "ulltott",
    "ulltotts": "ulltott",
    "ulltäcken": "ulltäcke",
    "ulltäckena": "ulltäcke",
    "ulltäckenas": "ulltäcke",
    "ulltäckens": "ulltäcke",
    "ulltäckes": "ulltäcke",
    "ulltäcket": "ulltäcke",
    "ulltäckets": "ulltäcke",
    "ulltäcks": "ulltäcke",
    "ullusen": "ullus",
    "ullusens": "ullus",
    "ullörten": "ullört",
    "ullörtens": "ullört",
    "ullörter": "ullört",
    "ullörterna": "ullört",
    "ullörternas": "ullört",
    "ullörters": "ullört",
    "ullörts": "ullört",
    "ullöss": "ullus",
    "ullössen": "ullus",
    "ullössens": "ullus",
    "ulm": "ulma",
    "ulmad": "ulma",
    "ulmade": "ulma",
    "ulmades": "ulma",
    "ulmads": "ulma",
    "ulmande": "ulma",
    "ulmanden": "ulmande",
    "ulmandena": "ulmande",
    "ulmandenas": "ulmande",
    "ulmandens": "ulmande",
    "ulmandes": "ulmande",
    "ulmandet": "ulmande",
    "ulmandets": "ulmande",
    "ulmar": "ulma",
    "ulmas": "ulma",
    "ulmat": "ulma",
    "ulmats": "ulma",
    "ulstern": "ulster",
    "ulsterns": "ulster",
    "ulsters": "ulster",
    "ulstrar": "ulster",
    "ulstrarna": "ulster",
    "ulstrarnas": "ulster",
    "ulstrars": "ulster",
    "ultiman": "ultima",
    "ultimans": "ultima",
    "ultimas": "ultima",
    "ultimata": "ultimatum",
    "ultimatana": "ultimatum",
    "ultimatanas": "ultimatum",
    "ultimatare": "ultimat",
    "ultimatares": "ultimat",
    "ultimatas": "ultimatum",
    "ultimatast": "ultimat",
    "ultimataste": "ultimat",
    "ultimatastes": "ultimat",
    "ultimatasts": "ultimat",
    "ultimate": "ultimat",
    "ultimates": "ultimat",
    "ultimativa": "ultimativ",
    "ultimativare": "ultimativ",
    "ultimativares": "ultimativ",
    "ultimativas": "ultimativ",
    "ultimativast": "ultimativ",
    "ultimativaste": "ultimativ",
    "ultimativastes": "ultimativ",
    "ultimativasts": "ultimativ",
    "ultimative": "ultimativ",
    "ultimatives": "ultimativ",
    "ultimativs": "ultimativ",
    "ultimativt": "ultimativ",
    "ultimativts": "ultimativ",
    "ultimats": "ultimat",
    "ultimatumen": "ultimatum",
    "ultimatumens": "ultimatum",
    "ultimatumet": "ultimatum",
    "ultimatumets": "ultimatum",
    "ultimatums": "ultimatum",
    "ultimoaffären": "ultimoaffär",
    "ultimoaffärens": "ultimoaffär",
    "ultimoaffärer": "ultimoaffär",
    "ultimoaffärerna": "ultimoaffär",
    "ultimoaffärernas": "ultimoaffär",
    "ultimoaffärers": "ultimoaffär",
    "ultimoaffärs": "ultimoaffär",
    "ultimor": "ultima",
    "ultimorna": "ultima",
    "ultimornas": "ultima",
    "ultimors": "ultima",
    "ultracentrifugen": "ultracentrifug",
    "ultracentrifugens": "ultracentrifug",
    "ultracentrifuger": "ultracentrifug",
    "ultracentrifugerna": "ultracentrifug",
    "ultracentrifugernas": "ultracentrifug",
    "ultracentrifugers": "ultracentrifug",
    "ultracentrifugs": "ultracentrifug",
    "ultrakonservativa": "ultrakonservativ",
    "ultrakonservativare": "ultrakonservativ",
    "ultrakonservativares": "ultrakonservativ",
    "ultrakonservativas": "ultrakonservativ",
    "ultrakonservativast": "ultrakonservativ",
    "ultrakonservativaste": "ultrakonservativ",
    "ultrakonservativastes": "ultrakonservativ",
    "ultrakonservativasts": "ultrakonservativ",
    "ultrakonservative": "ultrakonservativ",
    "ultrakonservatives": "ultrakonservativ",
    "ultrakonservativs": "ultrakonservativ",
    "ultrakonservativt": "ultrakonservativ",
    "ultrakonservativts": "ultrakonservativ",
    "ultrakortvågen": "ultrakortvåg",
    "ultrakortvågens": "ultrakortvåg",
    "ultrakortvågor": "ultrakortvåg",
    "ultrakortvågorna": "ultrakortvåg",
    "ultrakortvågornas": "ultrakortvåg",
    "ultrakortvågors": "ultrakortvåg",
    "ultrakortvågs": "ultrakortvåg",
    "ultraljuden": "ultraljud",
    "ultraljudens": "ultraljud",
    "ultraljudet": "ultraljud",
    "ultraljudets": "ultraljud",
    "ultraljuds": "ultraljud",
    "ultraljudsbilden": "ultraljudsbild",
    "ultraljudsbildens": "ultraljudsbild",
    "ultraljudsbilder": "ultraljudsbild",
    "ultraljudsbilderna": "ultraljudsbild",
    "ultraljudsbildernas": "ultraljudsbild",
    "ultraljudsbilders": "ultraljudsbild",
    "ultraljudsbilds": "ultraljudsbild",
    "ultramarina": "ultramarin",
    "ultramarinare": "ultramarin",
    "ultramarinares": "ultramarin",
    "ultramarinas": "ultramarin",
    "ultramarinast": "ultramarin",
    "ultramarinaste": "ultramarin",
    "ultramarinastes": "ultramarin",
    "ultramarinasts": "ultramarin",
    "ultramarine": "ultramarin",
    "ultramarines": "ultramarin",
    "ultramarins": "ultramarin",
    "ultramarint": "ultramarin",
    "ultramarints": "ultramarin",
    "ultramontana": "ultramontan",
    "ultramontanare": "ultramontan",
    "ultramontanares": "ultramontan",
    "ultramontanas": "ultramontan",
    "ultramontanast": "ultramontan",
    "ultramontanaste": "ultramontan",
    "ultramontanastes": "ultramontan",
    "ultramontanasts": "ultramontan",
    "ultramontane": "ultramontan",
    "ultramontanes": "ultramontan",
    "ultramontanismen": "ultramontanism",
    "ultramontanismens": "ultramontanism",
    "ultramontanismer": "ultramontanism",
    "ultramontanismerna": "ultramontanism",
    "ultramontanismernas": "ultramontanism",
    "ultramontanismers": "ultramontanism",
    "ultramontanisms": "ultramontanism",
    "ultramontans": "ultramontan",
    "ultramontant": "ultramontan",
    "ultramontants": "ultramontan",
    "ultran": "ultra",
    "ultranationalisten": "ultranationalist",
    "ultranationalistens": "ultranationalist",
    "ultranationalister": "ultranationalist",
    "ultranationalisterna": "ultranationalist",
    "ultranationalisternas": "ultranationalist",
    "ultranationalisters": "ultranationalist",
    "ultranationalists": "ultranationalist",
    "ultrans": "ultra",
    "ultrarapida": "ultrarapid",
    "ultrarapidare": "ultrarapid",
    "ultrarapidares": "ultrarapid",
    "ultrarapidas": "ultrarapid",
    "ultrarapidast": "ultrarapid",
    "ultrarapidaste": "ultrarapid",
    "ultrarapidastes": "ultrarapid",
    "ultrarapidasts": "ultrarapid",
    "ultrarapide": "ultrarapid",
    "ultrarapides": "ultrarapid",
    "ultrarapidfilmen": "ultrarapidfilm",
    "ultrarapidfilmens": "ultrarapidfilm",
    "ultrarapidfilmer": "ultrarapidfilm",
    "ultrarapidfilmerna": "ultrarapidfilm",
    "ultrarapidfilmernas": "ultrarapidfilm",
    "ultrarapidfilmers": "ultrarapidfilm",
    "ultrarapidfilms": "ultrarapidfilm",
    "ultrarapidfotograferad": "ultrarapidfotografera",
    "ultrarapidfotograferade": "ultrarapidfotografera",
    "ultrarapidfotograferades": "ultrarapidfotografera",
    "ultrarapidfotograferads": "ultrarapidfotografera",
    "ultrarapidfotograferande": "ultrarapidfotografera",
    "ultrarapidfotograferanden": "ultrarapidfotograferande",
    "ultrarapidfotograferandena": "ultrarapidfotograferande",
    "ultrarapidfotograferandenas": "ultrarapidfotograferande",
    "ultrarapidfotograferandens": "ultrarapidfotograferande",
    "ultrarapidfotograferandes": "ultrarapidfotograferande",
    "ultrarapidfotograferandet": "ultrarapidfotograferande",
    "ultrarapidfotograferandets": "ultrarapidfotograferande",
    "ultrarapidfotograferar": "ultrarapidfotografera",
    "ultrarapidfotograferas": "ultrarapidfotografera",
    "ultrarapidfotograferat": "ultrarapidfotografera",
    "ultrarapidfotograferats": "ultrarapidfotografera",
    "ultrarapidfotograferbara": "ultrarapidfotograferbar",
    "ultrarapidfotograferbarare": "ultrarapidfotograferbar",
    "ultrarapidfotograferbarares": "ultrarapidfotograferbar",
    "ultrarapidfotograferbaras": "ultrarapidfotograferbar",
    "ultrarapidfotograferbarast": "ultrarapidfotograferbar",
    "ultrarapidfotograferbaraste": "ultrarapidfotograferbar",
    "ultrarapidfotograferbarastes": "ultrarapidfotograferbar",
    "ultrarapidfotograferbarasts": "ultrarapidfotograferbar",
    "ultrarapidfotograferbare": "ultrarapidfotograferbar",
    "ultrarapidfotograferbares": "ultrarapidfotograferbar",
    "ultrarapidfotograferbarheten": "ultrarapidfotograferbarhet",
    "ultrarapidfotograferbarhetens": "ultrarapidfotograferbarhet",
    "ultrarapidfotograferbarhets": "ultrarapidfotograferbarhet",
    "ultrarapidfotograferbars": "ultrarapidfotograferbar",
    "ultrarapidfotograferbart": "ultrarapidfotograferbar",
    "ultrarapidfotograferbarts": "ultrarapidfotograferbar",
    "ultrarapidfotograferingar": "ultrarapidfotografering",
    "ultrarapidfotograferingarna": "ultrarapidfotografering",
    "ultrarapidfotograferingarnas": "ultrarapidfotografering",
    "ultrarapidfotograferingars": "ultrarapidfotografering",
    "ultrarapidfotograferingen": "ultrarapidfotografering",
    "ultrarapidfotograferingens": "ultrarapidfotografering",
    "ultrarapidfotograferings": "ultrarapidfotografering",
    "ultrarapids": "ultrarapid",
    "ultraröda": "ultraröd",
    "ultrarödare": "ultraröd",
    "ultrarödares": "ultraröd",
    "ultrarödas": "ultraröd",
    "ultrarödast": "ultraröd",
    "ultrarödaste": "ultraröd",
    "ultrarödastes": "ultraröd",
    "ultrarödasts": "ultraröd",
    "ultraröde": "ultraröd",
    "ultrarödes": "ultraröd",
    "ultraröds": "ultraröd",
    "ultrarött": "ultraröd",
    "ultrarötts": "ultraröd",
    "ultras": "ultra",
    "ultrasarna": "ultra",
    "ultrasarnas": "ultra",
    "ultrasen": "ultra",
    "ultrasens": "ultra",
    "ultrasnabba": "ultrasnabb",
    "ultrasnabbare": "ultrasnabb",
    "ultrasnabbares": "ultrasnabb",
    "ultrasnabbas": "ultrasnabb",
    "ultrasnabbast": "ultrasnabb",
    "ultrasnabbaste": "ultrasnabb",
    "ultrasnabbastes": "ultrasnabb",
    "ultrasnabbasts": "ultrasnabb",
    "ultrasnabbe": "ultrasnabb",
    "ultrasnabbes": "ultrasnabb",
    "ultrasnabbheten": "ultrasnabbhet",
    "ultrasnabbhetens": "ultrasnabbhet",
    "ultrasnabbhets": "ultrasnabbhet",
    "ultrasnabbs": "ultrasnabb",
    "ultrasnabbt": "ultrasnabb",
    "ultrasnabbts": "ultrasnabb",
    "ultravioletta": "ultraviolett",
    "ultraviolettare": "ultraviolett",
    "ultraviolettares": "ultraviolett",
    "ultraviolettas": "ultraviolett",
    "ultraviolettast": "ultraviolett",
    "ultraviolettaste": "ultraviolett",
    "ultraviolettastes": "ultraviolett",
    "ultraviolettasts": "ultraviolett",
    "ultraviolette": "ultraviolett",
    "ultraviolettes": "ultraviolett",
    "ultravioletts": "ultraviolett",
    "ulvar": "ulv",
    "ulvarna": "ulv",
    "ulvarnas": "ulv",
    "ulvars": "ulv",
    "ulven": "ulv",
    "ulvens": "ulv",
    "ulvs": "ulv",
    "umbar": "umbära",
    "umbars": "umbära",
    "umbellaten": "umbellat",
    "umbellatens": "umbellat",
    "umbellater": "umbellat",
    "umbellaterna": "umbellat",
    "umbellaternas": "umbellat",
    "umbellaters": "umbellat",
    "umbellats": "umbellat",
    "umbran": "umbra",
    "umbrans": "umbra",
    "umbras": "umbra",
    "umbror": "umbra",
    "umbrorna": "umbra",
    "umbrornas": "umbra",
    "umbrors": "umbra",
    "umbure": "umbära",
    "umbures": "umbära",
    "umburit": "umbära",
    "umburits": "umbära",
    "umbär": "umbära",
    "umbärande": "umbära",
    "umbäranden": "umbärande",
    "umbärandena": "umbärande",
    "umbärandenas": "umbärande",
    "umbärandens": "umbärande",
    "umbärandes": "umbärande",
    "umbärandet": "umbärande",
    "umbärandets": "umbärande",
    "umbäras": "umbära",
    "umbäre": "umbära",
    "umbäres": "umbära",
    "umbärliga": "umbärlig",
    "umbärligare": "umbärlig",
    "umbärligares": "umbärlig",
    "umbärligas": "umbärlig",
    "umbärligast": "umbärlig",
    "umbärligaste": "umbärlig",
    "umbärligastes": "umbärlig",
    "umbärligasts": "umbärlig",
    "umbärlige": "umbärlig",
    "umbärliges": "umbärlig",
    "umbärligheten": "umbärlighet",
    "umbärlighetens": "umbärlighet",
    "umbärligheter": "umbärlighet",
    "umbärligheterna": "umbärlighet",
    "umbärligheternas": "umbärlighet",
    "umbärligheters": "umbärlighet",
    "umbärlighets": "umbärlighet",
    "umbärligs": "umbärlig",
    "umbärligt": "umbärlig",
    "umbärligts": "umbärlig",
    "umbärs": "umbära",
    "umgicks": "umgås",
    "umgälderna": "umgälder",
    "umgäldernas": "umgälder",
    "umgälders": "umgälder",
    "umgälds": "umgälder",
    "umgäll": "umgälla",
    "umgällande": "umgälla",
    "umgällanden": "umgällande",
    "umgällandena": "umgällande",
    "umgällandenas": "umgällande",
    "umgällandens": "umgällande",
    "umgällandes": "umgällande",
    "umgällandet": "umgällande",
    "umgällandets": "umgällande",
    "umgällas": "umgälla",
    "umgälld": "umgälla",
    "umgällda": "umgälla",
    "umgälldas": "umgälla",
    "umgällde": "umgälla",
    "umgälldes": "umgälla",
    "umgällds": "umgälla",
    "umgäller": "umgälla",
    "umgälles": "umgälla",
    "umgälls": "umgälla",
    "umgällt": "umgälla",
    "umgällts": "umgälla",
    "umgängelsen": "umgängelse",
    "umgängelsens": "umgängelse",
    "umgängelser": "umgängelse",
    "umgängelserna": "umgängelse",
    "umgängelsernas": "umgängelse",
    "umgängelsers": "umgängelse",
    "umgängelses": "umgängelse",
    "umgängen": "umgänge",
    "umgängena": "umgänge",
    "umgängenas": "umgänge",
    "umgängens": "umgänge",
    "umgänges": "umgänge",
    "umgängesformen": "umgängesform",
    "umgängesformens": "umgängesform",
    "umgängesformer": "umgängesform",
    "umgängesformerna": "umgängesform",
    "umgängesformernas": "umgängesform",
    "umgängesformers": "umgängesform",
    "umgängesforms": "umgängesform",
    "umgängeskonsten": "umgängeskonst",
    "umgängeskonstens": "umgängeskonst",
    "umgängeskonsts": "umgängeskonst",
    "umgängeskretsar": "umgängeskrets",
    "umgängeskretsarna": "umgängeskrets",
    "umgängeskretsarnas": "umgängeskrets",
    "umgängeskretsars": "umgängeskrets",
    "umgängeskretsen": "umgängeskrets",
    "umgängeskretsens": "umgängeskrets",
    "umgängeslivet": "umgängesliv",
    "umgängeslivets": "umgängesliv",
    "umgängeslivs": "umgängesliv",
    "umgängesnormen": "umgängesnorm",
    "umgängesnormens": "umgängesnorm",
    "umgängesnormer": "umgängesnorm",
    "umgängesnormerna": "umgängesnorm",
    "umgängesnormernas": "umgängesnorm",
    "umgängesnormers": "umgängesnorm",
    "umgängesnorms": "umgängesnorm",
    "umgängesrätten": "umgängesrätt",
    "umgängesrättens": "umgängesrätt",
    "umgängesrätts": "umgängesrätt",
    "umgängestonen": "umgängeston",
    "umgängestonens": "umgängeston",
    "umgängestons": "umgängeston",
    "umgängesvettet": "umgängesvett",
    "umgängesvettets": "umgängesvett",
    "umgängesvetts": "umgängesvett",
    "umgänget": "umgänge",
    "umgängets": "umgänge",
    "umgåtts": "umgås",
    "uncialen": "uncial",
    "uncialens": "uncial",
    "uncialer": "uncial",
    "uncialerna": "uncial",
    "uncialernas": "uncial",
    "uncialers": "uncial",
    "uncials": "uncial",
    "undandräkten": "undandräkt",
    "undandräktens": "undandräkt",
    "undandräkts": "undandräkt",
    "undanflykten": "undanflykt",
    "undanflyktens": "undanflykt",
    "undanflykter": "undanflykt",
    "undanflykterna": "undanflykt",
    "undanflykternas": "undanflykt",
    "undanflykters": "undanflykt",
    "undanflykts": "undanflykt",
    "undangjorda": "undangjord",
    "undangjordare": "undangjord",
    "undangjordares": "undangjord",
    "undangjordas": "undangjord",
    "undangjordast": "undangjord",
    "undangjordaste": "undangjord",
    "undangjordastes": "undangjord",
    "undangjordasts": "undangjord",
    "undangjorde": "undangjord",
    "undangjordes": "undangjord",
    "undangjords": "undangjord",
    "undangjort": "undangjord",
    "undangjorts": "undangjord",
    "undangöm": "undangömma",
    "undangömd": "undangömma",
    "undangömda": "undangömma",
    "undangömdare": "undangömd",
    "undangömdares": "undangömd",
    "undangömdas": "undangömma",
    "undangömdast": "undangömd",
    "undangömdaste": "undangömd",
    "undangömdastes": "undangömd",
    "undangömdasts": "undangömd",
    "undangömde": "undangömma",
    "undangömdes": "undangömma",
    "undangömds": "undangömma",
    "undangömmande": "undangömma",
    "undangömmanden": "undangömmande",
    "undangömmandena": "undangömmande",
    "undangömmandenas": "undangömmande",
    "undangömmandens": "undangömmande",
    "undangömmandes": "undangömmande",
    "undangömmandet": "undangömmande",
    "undangömmandets": "undangömmande",
    "undangömmas": "undangömma",
    "undangömmer": "undangömma",
    "undangöms": "undangömma",
    "undangömt": "undangömma",
    "undangömts": "undangömma",
    "undanhåll": "undanhålla",
    "undanhållande": "undanhålla",
    "undanhållanden": "undanhållande",
    "undanhållandena": "undanhållande",
    "undanhållandenas": "undanhållande",
    "undanhållandens": "undanhållande",
    "undanhållandes": "undanhållande",
    "undanhållandet": "undanhållande",
    "undanhållandets": "undanhållande",
    "undanhållas": "undanhålla",
    "undanhålle": "undanhålla",
    "undanhållen": "undanhålla",
    "undanhållens": "undanhålla",
    "undanhåller": "undanhålla",
    "undanhålles": "undanhålla",
    "undanhållet": "undanhålla",
    "undanhållets": "undanhålla",
    "undanhållit": "undanhålla",
    "undanhållits": "undanhålla",
    "undanhållna": "undanhålla",
    "undanhållnas": "undanhålla",
    "undanhållne": "undanhålla",
    "undanhållnes": "undanhålla",
    "undanhålls": "undanhålla",
    "undanhöll": "undanhålla",
    "undanhölle": "undanhålla",
    "undanhölles": "undanhålla",
    "undanhölls": "undanhålla",
    "undanlagda": "undanlagd",
    "undanlagdare": "undanlagd",
    "undanlagdares": "undanlagd",
    "undanlagdas": "undanlagd",
    "undanlagdast": "undanlagd",
    "undanlagdaste": "undanlagd",
    "undanlagdastes": "undanlagd",
    "undanlagdasts": "undanlagd",
    "undanlagde": "undanlagd",
    "undanlagdes": "undanlagd",
    "undanlagds": "undanlagd",
    "undanlagt": "undanlagd",
    "undanlagts": "undanlagd",
    "undanläggningar": "undanläggning",
    "undanläggningarna": "undanläggning",
    "undanläggningarnas": "undanläggning",
    "undanläggningars": "undanläggning",
    "undanläggningen": "undanläggning",
    "undanläggningens": "undanläggning",
    "undanläggnings": "undanläggning",
    "undanmanövern": "undanmanöver",
    "undanmanöverns": "undanmanöver",
    "undanmanövers": "undanmanöver",
    "undanmanövrar": "undanmanöver",
    "undanmanövrarna": "undanmanöver",
    "undanmanövrarnas": "undanmanöver",
    "undanmanövrars": "undanmanöver",
    "undanmanövrer": "undanmanöver",
    "undanmanövrerna": "undanmanöver",
    "undanmanövrernas": "undanmanöver",
    "undanmanövrers": "undanmanöver",
    "undanröj": "undanröja",
    "undanröjande": "undanröja",
    "undanröjanden": "undanröjande",
    "undanröjandena": "undanröjande",
    "undanröjandenas": "undanröjande",
    "undanröjandens": "undanröjande",
    "undanröjandes": "undanröjande",
    "undanröjandet": "undanröjande",
    "undanröjandets": "undanröjande",
    "undanröjas": "undanröja",
    "undanröjd": "undanröja",
    "undanröjda": "undanröja",
    "undanröjdas": "undanröja",
    "undanröjde": "undanröja",
    "undanröjdes": "undanröja",
    "undanröjds": "undanröja",
    "undanröjer": "undanröja",
    "undanröjes": "undanröja",
    "undanröjs": "undanröja",
    "undanröjt": "undanröja",
    "undanröjts": "undanröja",
    "undanskaff": "undanskaffa",
    "undanskaffad": "undanskaffa",
    "undanskaffade": "undanskaffa",
    "undanskaffades": "undanskaffa",
    "undanskaffads": "undanskaffa",
    "undanskaffande": "undanskaffa",
    "undanskaffanden": "undanskaffande",
    "undanskaffandena": "undanskaffande",
    "undanskaffandenas": "undanskaffande",
    "undanskaffandens": "undanskaffande",
    "undanskaffandes": "undanskaffande",
    "undanskaffandet": "undanskaffande",
    "undanskaffandets": "undanskaffande",
    "undanskaffar": "undanskaffa",
    "undanskaffas": "undanskaffa",
    "undanskaffat": "undanskaffa",
    "undanskaffats": "undanskaffa",
    "undanskift": "undanskifta",
    "undanskiftad": "undanskifta",
    "undanskiftade": "undanskifta",
    "undanskiftades": "undanskifta",
    "undanskiftads": "undanskifta",
    "undanskiftande": "undanskifta",
    "undanskiftanden": "undanskiftande",
    "undanskiftandena": "undanskiftande",
    "undanskiftandenas": "undanskiftande",
    "undanskiftandens": "undanskiftande",
    "undanskiftandes": "undanskiftande",
    "undanskiftandet": "undanskiftande",
    "undanskiftandets": "undanskiftande",
    "undanskiftar": "undanskifta",
    "undanskiftas": "undanskifta",
    "undanskiftat": "undanskifta",
    "undanskiftats": "undanskifta",
    "undanskym": "undanskymma",
    "undanskymd": "undanskymma",
    "undanskymda": "undanskymma",
    "undanskymdare": "undanskymd",
    "undanskymdares": "undanskymd",
    "undanskymdas": "undanskymma",
    "undanskymdast": "undanskymd",
    "undanskymdaste": "undanskymd",
    "undanskymdastes": "undanskymd",
    "undanskymdasts": "undanskymd",
    "undanskymde": "undanskymma",
    "undanskymdes": "undanskymma",
    "undanskymdheten": "undanskymdhet",
    "undanskymdhetens": "undanskymdhet",
    "undanskymdhets": "undanskymdhet",
    "undanskymds": "undanskymma",
    "undanskymmande": "undanskymma",
    "undanskymmanden": "undanskymmande",
    "undanskymmandena": "undanskymmande",
    "undanskymmandenas": "undanskymmande",
    "undanskymmandens": "undanskymmande",
    "undanskymmandes": "undanskymmande",
    "undanskymmandet": "undanskymmande",
    "undanskymmandets": "undanskymmande",
    "undanskymmas": "undanskymma",
    "undanskymmer": "undanskymma",
    "undanskyms": "undanskymma",
    "undanskymt": "undanskymma",
    "undanskymts": "undanskymma",
    "undansnill": "undansnilla",
    "undansnillad": "undansnilla",
    "undansnillade": "undansnilla",
    "undansnillades": "undansnilla",
    "undansnillads": "undansnilla",
    "undansnillande": "undansnilla",
    "undansnillanden": "undansnillande",
    "undansnillandena": "undansnillande",
    "undansnillandenas": "undansnillande",
    "undansnillandens": "undansnillande",
    "undansnillandes": "undansnillande",
    "undansnillandet": "undansnillande",
    "undansnillandets": "undansnillande",
    "undansnillar": "undansnilla",
    "undansnillas": "undansnilla",
    "undansnillat": "undansnilla",
    "undansnillats": "undansnilla",
    "undanstack": "undansticka",
    "undanstacks": "undansticka",
    "undanstick": "undansticka",
    "undanstickande": "undansticka",
    "undanstickanden": "undanstickande",
    "undanstickandena": "undanstickande",
    "undanstickandenas": "undanstickande",
    "undanstickandens": "undanstickande",
    "undanstickandes": "undanstickande",
    "undanstickandet": "undanstickande",
    "undanstickandets": "undanstickande",
    "undanstickas": "undansticka",
    "undansticke": "undansticka",
    "undansticker": "undansticka",
    "undanstickes": "undansticka",
    "undansticks": "undansticka",
    "undanstoppade": "undanstoppad",
    "undanstoppades": "undanstoppad",
    "undanstoppads": "undanstoppad",
    "undanstoppat": "undanstoppad",
    "undanstoppats": "undanstoppad",
    "undanstucke": "undansticka",
    "undanstucken": "undansticka",
    "undanstuckens": "undansticka",
    "undanstuckes": "undansticka",
    "undanstucket": "undansticka",
    "undanstuckets": "undansticka",
    "undanstuckit": "undansticka",
    "undanstuckits": "undansticka",
    "undanstuckna": "undansticka",
    "undanstucknas": "undansticka",
    "undanstuckne": "undansticka",
    "undanstucknes": "undansticka",
    "undanstökade": "undanstökad",
    "undanstökades": "undanstökad",
    "undanstökads": "undanstökad",
    "undanstökat": "undanstökad",
    "undanstökats": "undanstökad",
    "undantag": "undanta",
    "undantaga": "undanta",
    "undantagande": "undanta",
    "undantaganden": "undantagande",
    "undantagandena": "undantagande",
    "undantagandenas": "undantagande",
    "undantagandens": "undantagande",
    "undantagandes": "undantagande",
    "undantagandet": "undantagande",
    "undantagandets": "undantagande",
    "undantagas": "undanta",
    "undantage": "undanta",
    "undantagen": "undantag",
    "undantagens": "undantag",
    "undantager": "undanta",
    "undantages": "undanta",
    "undantaget": "undantag",
    "undantagets": "undantag",
    "undantagit": "undanta",
    "undantagits": "undanta",
    "undantagna": "undanta",
    "undantagnas": "undanta",
    "undantagne": "undanta",
    "undantagnes": "undanta",
    "undantags": "undantag",
    "undantagsbestämmelsen": "undantagsbestämmelse",
    "undantagsbestämmelsens": "undantagsbestämmelse",
    "undantagsbestämmelser": "undantagsbestämmelse",
    "undantagsbestämmelserna": "undantagsbestämmelse",
    "undantagsbestämmelsernas": "undantagsbestämmelse",
    "undantagsbestämmelsers": "undantagsbestämmelse",
    "undantagsbestämmelses": "undantagsbestämmelse",
    "undantagsfallen": "undantagsfall",
    "undantagsfallens": "undantagsfall",
    "undantagsfallet": "undantagsfall",
    "undantagsfallets": "undantagsfall",
    "undantagsfalls": "undantagsfall",
    "undantagsfria": "undantagsfri",
    "undantagsfriare": "undantagsfri",
    "undantagsfriares": "undantagsfri",
    "undantagsfrias": "undantagsfri",
    "undantagsfriast": "undantagsfri",
    "undantagsfriaste": "undantagsfri",
    "undantagsfriastes": "undantagsfri",
    "undantagsfriasts": "undantagsfri",
    "undantagsfrie": "undantagsfri",
    "undantagsfries": "undantagsfri",
    "undantagsfris": "undantagsfri",
    "undantagsfritt": "undantagsfri",
    "undantagsfritts": "undantagsfri",
    "undantagslagar": "undantagslag",
    "undantagslagarna": "undantagslag",
    "undantagslagarnas": "undantagslag",
    "undantagslagars": "undantagslag",
    "undantagslagen": "undantagslag",
    "undantagslagens": "undantagslag",
    "undantagslags": "undantagslag",
    "undantagslösa": "undantagslös",
    "undantagslösare": "undantagslös",
    "undantagslösares": "undantagslös",
    "undantagslösas": "undantagslös",
    "undantagslösast": "undantagslös",
    "undantagslösaste": "undantagslös",
    "undantagslösastes": "undantagslös",
    "undantagslösasts": "undantagslös",
    "undantagslöse": "undantagslös",
    "undantagslöses": "undantagslös",
    "undantagslösheten": "undantagslöshet",
    "undantagslöshetens": "undantagslöshet",
    "undantagslöshets": "undantagslöshet",
    "undantagslöst": "undantagslös",
    "undantagslösts": "undantagslös",
    "undantagsmänniskan": "undantagsmänniska",
    "undantagsmänniskans": "undantagsmänniska",
    "undantagsmänniskas": "undantagsmänniska",
    "undantagsmännisko": "undantagsmänniska",
    "undantagsmänniskor": "undantagsmänniska",
    "undantagsmänniskorna": "undantagsmänniska",
    "undantagsmänniskornas": "undantagsmänniska",
    "undantagsmänniskors": "undantagsmänniska",
    "undantagsrätten": "undantagsrätt",
    "undantagsrättens": "undantagsrätt",
    "undantagsrätter": "undantagsrätt",
    "undantagsrätterna": "undantagsrätt",
    "undantagsrätternas": "undantagsrätt",
    "undantagsrätters": "undantagsrätt",
    "undantagsrätts": "undantagsrätt",
    "undantagstillstånden": "undantagstillstånd",
    "undantagstillståndens": "undantagstillstånd",
    "undantagstillståndet": "undantagstillstånd",
    "undantagstillståndets": "undantagstillstånd",
    "undantagstillstånds": "undantagstillstånd",
    "undantagstillvaron": "undantagstillvaro",
    "undantagstillvarons": "undantagstillvaro",
    "undantagstillvaros": "undantagstillvaro",
    "undantar": "undanta",
    "undantas": "undanta",
    "undantog": "undanta",
    "undantoge": "undanta",
    "undantoges": "undanta",
    "undantogs": "undanta",
    "undanträng": "undantränga",
    "undanträngande": "undantränga",
    "undantränganden": "undanträngande",
    "undanträngandena": "undanträngande",
    "undanträngandenas": "undanträngande",
    "undanträngandens": "undanträngande",
    "undanträngandes": "undanträngande",
    "undanträngandet": "undanträngande",
    "undanträngandets": "undanträngande",
    "undanträngas": "undantränga",
    "undanträngd": "undantränga",
    "undanträngda": "undantränga",
    "undanträngdas": "undantränga",
    "undanträngde": "undantränga",
    "undanträngdes": "undantränga",
    "undanträngds": "undantränga",
    "undantränger": "undantränga",
    "undantränges": "undantränga",
    "undanträngs": "undantränga",
    "undanträngt": "undantränga",
    "undanträngts": "undantränga",
    "undanvindsvändningar": "undanvindsvändning",
    "undanvindsvändningarna": "undanvindsvändning",
    "undanvindsvändningarnas": "undanvindsvändning",
    "undanvindsvändningars": "undanvindsvändning",
    "undanvindsvändningen": "undanvindsvändning",
    "undanvindsvändningens": "undanvindsvändning",
    "undanvindsvändnings": "undanvindsvändning",
    "underanvänd": "underanvända",
    "underanvändande": "underanvända",
    "underanvändanden": "underanvändande",
    "underanvändandena": "underanvändande",
    "underanvändandenas": "underanvändande",
    "underanvändandens": "underanvändande",
    "underanvändandes": "underanvändande",
    "underanvändandet": "underanvändande",
    "underanvändandets": "underanvändande",
    "underanvändas": "underanvända",
    "underanvände": "underanvända",
    "underanvänder": "underanvända",
    "underanvändes": "underanvända",
    "underanvändningar": "underanvändning",
    "underanvändningarna": "underanvändning",
    "underanvändningarnas": "underanvändning",
    "underanvändningars": "underanvändning",
    "underanvändningen": "underanvändning",
    "underanvändningens": "underanvändning",
    "underanvändnings": "underanvändning",
    "underanvänds": "underanvända",
    "underanvänt": "underanvända",
    "underanvänts": "underanvända",
    "underarbeten": "underarbete",
    "underarbetena": "underarbete",
    "underarbetenas": "underarbete",
    "underarbetens": "underarbete",
    "underarbetes": "underarbete",
    "underarbetet": "underarbete",
    "underarbetets": "underarbete",
    "underarbets": "underarbete",
    "underarmar": "underarm",
    "underarmarna": "underarm",
    "underarmarnas": "underarm",
    "underarmars": "underarm",
    "underarmen": "underarm",
    "underarmens": "underarm",
    "underarms": "underarm",
    "underarmsmuskulaturen": "underarmsmuskulatur",
    "underarmsmuskulaturens": "underarmsmuskulatur",
    "underarmsmuskulaturs": "underarmsmuskulatur",
    "underarten": "underart",
    "underartens": "underart",
    "underarter": "underart",
    "underarterna": "underart",
    "underarternas": "underart",
    "underarters": "underart",
    "underarts": "underart",
    "underavdelningar": "underavdelning",
    "underavdelningarna": "underavdelning",
    "underavdelningarnas": "underavdelning",
    "underavdelningars": "underavdelning",
    "underavdelningen": "underavdelning",
    "underavdelningens": "underavdelning",
    "underavdelnings": "underavdelning",
    "underbalansen": "underbalans",
    "underbalansens": "underbalans",
    "underbalanserad": "underbalansera",
    "underbalanserade": "underbalansera",
    "underbalanserades": "underbalansera",
    "underbalanserads": "underbalansera",
    "underbalanserande": "underbalansera",
    "underbalanseranden": "underbalanserande",
    "underbalanserandena": "underbalanserande",
    "underbalanserandenas": "underbalanserande",
    "underbalanserandens": "underbalanserande",
    "underbalanserandes": "underbalanserande",
    "underbalanserandet": "underbalanserande",
    "underbalanserandets": "underbalanserande",
    "underbalanserar": "underbalansera",
    "underbalanseras": "underbalansera",
    "underbalanserat": "underbalansera",
    "underbalanserats": "underbalansera",
    "underbalanserbara": "underbalanserbar",
    "underbalanserbarare": "underbalanserbar",
    "underbalanserbarares": "underbalanserbar",
    "underbalanserbaras": "underbalanserbar",
    "underbalanserbarast": "underbalanserbar",
    "underbalanserbaraste": "underbalanserbar",
    "underbalanserbarastes": "underbalanserbar",
    "underbalanserbarasts": "underbalanserbar",
    "underbalanserbare": "underbalanserbar",
    "underbalanserbares": "underbalanserbar",
    "underbalanserbarheten": "underbalanserbarhet",
    "underbalanserbarhetens": "underbalanserbarhet",
    "underbalanserbarhets": "underbalanserbarhet",
    "underbalanserbars": "underbalanserbar",
    "underbalanserbart": "underbalanserbar",
    "underbalanserbarts": "underbalanserbar",
    "underbalanseringar": "underbalansering",
    "underbalanseringarna": "underbalansering",
    "underbalanseringarnas": "underbalansering",
    "underbalanseringars": "underbalansering",
    "underbalanseringen": "underbalansering",
    "underbalanseringens": "underbalansering",
    "underbalanserings": "underbalansering",
    "underband": "underbinda",
    "underbands": "underbinda",
    "underbara": "underbar",
    "underbarare": "underbar",
    "underbarares": "underbar",
    "underbaras": "underbar",
    "underbarast": "underbar",
    "underbaraste": "underbar",
    "underbarastes": "underbar",
    "underbarasts": "underbar",
    "underbare": "underbar",
    "underbares": "underbar",
    "underbarheten": "underbarhet",
    "underbarhetens": "underbarhet",
    "underbarhets": "underbarhet",
    "underbarnen": "underbarn",
    "underbarnens": "underbarn",
    "underbarnet": "underbarn",
    "underbarnets": "underbarn",
    "underbarns": "underbarn",
    "underbars": "underbar",
    "underbart": "underbar",
    "underbarts": "underbar",
    "underbefolkade": "underbefolkad",
    "underbefolkades": "underbefolkad",
    "underbefolkads": "underbefolkad",
    "underbefolkat": "underbefolkad",
    "underbefolkats": "underbefolkad",
    "underbefolkningar": "underbefolkning",
    "underbefolkningarna": "underbefolkning",
    "underbefolkningarnas": "underbefolkning",
    "underbefolkningars": "underbefolkning",
    "underbefolkningen": "underbefolkning",
    "underbefolkningens": "underbefolkning",
    "underbefolknings": "underbefolkning",
    "underbefälen": "underbefäl",
    "underbefälens": "underbefäl",
    "underbefälet": "underbefäl",
    "underbefälets": "underbefäl",
    "underbefäls": "underbefäl",
    "underbefälsutbildningar": "underbefälsutbildning",
    "underbefälsutbildningarna": "underbefälsutbildning",
    "underbefälsutbildningarnas": "underbefälsutbildning",
    "underbefälsutbildningars": "underbefälsutbildning",
    "underbefälsutbildningen": "underbefälsutbildning",
    "underbefälsutbildningens": "underbefälsutbildning",
    "underbefälsutbildnings": "underbefälsutbildning",
    "underbegreppen": "underbegrepp",
    "underbegreppens": "underbegrepp",
    "underbegreppet": "underbegrepp",
    "underbegreppets": "underbegrepp",
    "underbegrepps": "underbegrepp",
    "underbeläggningar": "underbeläggning",
    "underbeläggningarna": "underbeläggning",
    "underbeläggningarnas": "underbeläggning",
    "underbeläggningars": "underbeläggning",
    "underbeläggningen": "underbeläggning",
    "underbeläggningens": "underbeläggning",
    "underbeläggnings": "underbeläggning",
    "underbemannade": "underbemannad",
    "underbemannades": "underbemannad",
    "underbemannads": "underbemannad",
    "underbemannat": "underbemannad",
    "underbemannats": "underbemannad",
    "underbemanningar": "underbemanning",
    "underbemanningarna": "underbemanning",
    "underbemanningarnas": "underbemanning",
    "underbemanningars": "underbemanning",
    "underbemanningen": "underbemanning",
    "underbemanningens": "underbemanning",
    "underbemannings": "underbemanning",
    "underbenen": "underben",
    "underbenens": "underben",
    "underbenet": "underben",
    "underbenets": "underben",
    "underbens": "underben",
    "underbestånden": "underbestånd",
    "underbeståndens": "underbestånd",
    "underbeståndet": "underbestånd",
    "underbeståndets": "underbestånd",
    "underbestånds": "underbestånd",
    "underbetal": "underbetala",
    "underbetalad": "underbetala",
    "underbetalade": "underbetala",
    "underbetalades": "underbetala",
    "underbetalads": "underbetala",
    "underbetalande": "underbetala",
    "underbetalanden": "underbetalande",
    "underbetalandena": "underbetalande",
    "underbetalandenas": "underbetalande",
    "underbetalandens": "underbetalande",
    "underbetalandes": "underbetalande",
    "underbetalandet": "underbetalande",
    "underbetalandets": "underbetalande",
    "underbetalar": "underbetala",
    "underbetalas": "underbetala",
    "underbetalat": "underbetala",
    "underbetalats": "underbetala",
    "underbetald": "underbetala",
    "underbetalda": "underbetala",
    "underbetaldas": "underbetala",
    "underbetalde": "underbetala",
    "underbetaldes": "underbetala",
    "underbetalds": "underbetala",
    "underbetalt": "underbetala",
    "underbetalte": "underbetala",
    "underbetaltes": "underbetala",
    "underbetalts": "underbetala",
    "underbetten": "underbett",
    "underbettens": "underbett",
    "underbettet": "underbett",
    "underbettets": "underbett",
    "underbetts": "underbett",
    "underbetygen": "underbetyg",
    "underbetygens": "underbetyg",
    "underbetyget": "underbetyg",
    "underbetygets": "underbetyg",
    "underbetygs": "underbetyg",
    "underbind": "underbinda",
    "underbindande": "underbinda",
    "underbindanden": "underbindande",
    "underbindandena": "underbindande",
    "underbindandenas": "underbindande",
    "underbindandens": "underbindande",
    "underbindandes": "underbindande",
    "underbindandet": "underbindande",
    "underbindandets": "underbindande",
    "underbindas": "underbinda",
    "underbinde": "underbinda",
    "underbinder": "underbinda",
    "underbindes": "underbinda",
    "underbinds": "underbinda",
    "underbjud": "underbjuda",
    "underbjudande": "underbjuda",
    "underbjudanden": "underbjudande",
    "underbjudandena": "underbjudande",
    "underbjudandenas": "underbjudande",
    "underbjudandens": "underbjudande",
    "underbjudandes": "underbjudande",
    "underbjudandet": "underbjudande",
    "underbjudandets": "underbjudande",
    "underbjudas": "underbjuda",
    "underbjude": "underbjuda",
    "underbjuden": "underbjuda",
    "underbjudens": "underbjuda",
    "underbjuder": "underbjuda",
    "underbjudes": "underbjuda",
    "underbjudet": "underbjuda",
    "underbjudets": "underbjuda",
    "underbjudit": "underbjuda",
    "underbjudits": "underbjuda",
    "underbjudna": "underbjuda",
    "underbjudnas": "underbjuda",
    "underbjudne": "underbjuda",
    "underbjudnes": "underbjuda",
    "underbjuds": "underbjuda",
    "underbjöd": "underbjuda",
    "underbjöde": "underbjuda",
    "underbjödes": "underbjuda",
    "underbjöds": "underbjuda",
    "underblom": "underblomma",
    "underblomman": "underblomma",
    "underblommans": "underblomma",
    "underblommas": "underblomma",
    "underblomme": "underblomma",
    "underblommor": "underblomma",
    "underblommorna": "underblomma",
    "underblommornas": "underblomma",
    "underblommors": "underblomma",
    "underbloms": "underblomma",
    "underblås": "underblåsa",
    "underblåsande": "underblåsa",
    "underblåsanden": "underblåsande",
    "underblåsandena": "underblåsande",
    "underblåsandenas": "underblåsande",
    "underblåsandens": "underblåsande",
    "underblåsandes": "underblåsande",
    "underblåsandet": "underblåsande",
    "underblåsandets": "underblåsande",
    "underblåsas": "underblåsa",
    "underblåser": "underblåsa",
    "underblåses": "underblåsa",
    "underblåst": "underblåsa",
    "underblåsta": "underblåsa",
    "underblåstas": "underblåsa",
    "underblåste": "underblåsa",
    "underblåstes": "underblåsa",
    "underblåsts": "underblåsa",
    "underborgens": "underborgen",
    "underbuden": "underbud",
    "underbudens": "underbud",
    "underbudet": "underbud",
    "underbudets": "underbud",
    "underbuds": "underbud",
    "underbunde": "underbinda",
    "underbunden": "underbinda",
    "underbundens": "underbinda",
    "underbundes": "underbinda",
    "underbundet": "underbinda",
    "underbundets": "underbinda",
    "underbundit": "underbinda",
    "underbundits": "underbinda",
    "underbundna": "underbinda",
    "underbundnas": "underbinda",
    "underbundne": "underbinda",
    "underbundnes": "underbinda",
    "underbygg": "underbygga",
    "underbyggande": "underbygga",
    "underbygganden": "underbyggande",
    "underbyggandena": "underbyggande",
    "underbyggandenas": "underbyggande",
    "underbyggandens": "underbyggande",
    "underbyggandes": "underbyggande",
    "underbyggandet": "underbyggande",
    "underbyggandets": "underbyggande",
    "underbyggas": "underbygga",
    "underbyggd": "underbygga",
    "underbyggda": "underbygga",
    "underbyggdas": "underbygga",
    "underbyggde": "underbygga",
    "underbyggdes": "underbygga",
    "underbyggds": "underbygga",
    "underbygger": "underbygga",
    "underbygges": "underbygga",
    "underbyggnaden": "underbyggnad",
    "underbyggnadens": "underbyggnad",
    "underbyggnader": "underbyggnad",
    "underbyggnaderna": "underbyggnad",
    "underbyggnadernas": "underbyggnad",
    "underbyggnaders": "underbyggnad",
    "underbyggnads": "underbyggnad",
    "underbyggs": "underbygga",
    "underbyggt": "underbygga",
    "underbyggts": "underbygga",
    "underbyx": "underbyxa",
    "underbyxan": "underbyxa",
    "underbyxans": "underbyxa",
    "underbyxas": "underbyxa",
    "underbyxe": "underbyxa",
    "underbyxor": "underbyxa",
    "underbyxorna": "underbyxa",
    "underbyxornas": "underbyxa",
    "underbyxors": "underbyxa",
    "underbäddar": "underbädd",
    "underbäddarna": "underbädd",
    "underbäddarnas": "underbädd",
    "underbäddars": "underbädd",
    "underbädden": "underbädd",
    "underbäddens": "underbädd",
    "underbädds": "underbädd",
    "underdelar": "underdel",
    "underdelarna": "underdel",
    "underdelarnas": "underdel",
    "underdelars": "underdel",
    "underdelen": "underdel",
    "underdelens": "underdel",
    "underdels": "underdel",
    "underdimensionerad": "underdimensionera",
    "underdimensionerade": "underdimensionera",
    "underdimensionerades": "underdimensionera",
    "underdimensionerads": "underdimensionera",
    "underdimensionerande": "underdimensionera",
    "underdimensioneranden": "underdimensionerande",
    "underdimensionerandena": "underdimensionerande",
    "underdimensionerandenas": "underdimensionerande",
    "underdimensionerandens": "underdimensionerande",
    "underdimensionerandes": "underdimensionerande",
    "underdimensionerandet": "underdimensionerande",
    "underdimensionerandets": "underdimensionerande",
    "underdimensionerar": "underdimensionera",
    "underdimensioneras": "underdimensionera",
    "underdimensionerat": "underdimensionera",
    "underdimensionerats": "underdimensionera",
    "underdimensionerbara": "underdimensionerbar",
    "underdimensionerbarare": "underdimensionerbar",
    "underdimensionerbarares": "underdimensionerbar",
    "underdimensionerbaras": "underdimensionerbar",
    "underdimensionerbarast": "underdimensionerbar",
    "underdimensionerbaraste": "underdimensionerbar",
    "underdimensionerbarastes": "underdimensionerbar",
    "underdimensionerbarasts": "underdimensionerbar",
    "underdimensionerbare": "underdimensionerbar",
    "underdimensionerbares": "underdimensionerbar",
    "underdimensionerbarheten": "underdimensionerbarhet",
    "underdimensionerbarhetens": "underdimensionerbarhet",
    "underdimensionerbarhets": "underdimensionerbarhet",
    "underdimensionerbars": "underdimensionerbar",
    "underdimensionerbart": "underdimensionerbar",
    "underdimensionerbarts": "underdimensionerbar",
    "underdimensioneringar": "underdimensionering",
    "underdimensioneringarna": "underdimensionering",
    "underdimensioneringarnas": "underdimensionering",
    "underdimensioneringars": "underdimensionering",
    "underdimensioneringen": "underdimensionering",
    "underdimensioneringens": "underdimensionering",
    "underdimensionerings": "underdimensionering",
    "underdomstolar": "underdomstol",
    "underdomstolarna": "underdomstol",
    "underdomstolarnas": "underdomstol",
    "underdomstolars": "underdomstol",
    "underdomstolen": "underdomstol",
    "underdomstolens": "underdomstol",
    "underdomstols": "underdomstol",
    "underdrev": "underdriva",
    "underdrevs": "underdriva",
    "underdriften": "underdrift",
    "underdriftens": "underdrift",
    "underdrifter": "underdrift",
    "underdrifterna": "underdrift",
    "underdrifternas": "underdrift",
    "underdrifters": "underdrift",
    "underdrifts": "underdrift",
    "underdriv": "underdriva",
    "underdrivande": "underdriva",
    "underdrivanden": "underdrivande",
    "underdrivandena": "underdrivande",
    "underdrivandenas": "underdrivande",
    "underdrivandens": "underdrivande",
    "underdrivandes": "underdrivande",
    "underdrivandet": "underdrivande",
    "underdrivandets": "underdrivande",
    "underdrivas": "underdriva",
    "underdrive": "underdriva",
    "underdriven": "underdriva",
    "underdrivens": "underdriva",
    "underdriver": "underdriva",
    "underdrives": "underdriva",
    "underdrivet": "underdriva",
    "underdrivets": "underdriva",
    "underdrivit": "underdriva",
    "underdrivits": "underdriva",
    "underdrivna": "underdriva",
    "underdrivnas": "underdriva",
    "underdrivne": "underdriva",
    "underdrivnes": "underdriva",
    "underdrivs": "underdriva",
    "underdäcken": "underdäck",
    "underdäckens": "underdäck",
    "underdäcket": "underdäck",
    "underdäckets": "underdäck",
    "underdäcks": "underdäck",
    "underdåniga": "underdånig",
    "underdånigare": "underdånig",
    "underdånigares": "underdånig",
    "underdånigas": "underdånig",
    "underdånigast": "underdånig",
    "underdånigaste": "underdånig",
    "underdånigastes": "underdånig",
    "underdånigasts": "underdånig",
    "underdånige": "underdånig",
    "underdåniges": "underdånig",
    "underdånigheten": "underdånighet",
    "underdånighetens": "underdånighet",
    "underdånigheter": "underdånighet",
    "underdånigheterna": "underdånighet",
    "underdånigheternas": "underdånighet",
    "underdånigheters": "underdånighet",
    "underdånighets": "underdånighet",
    "underdånigs": "underdånig",
    "underdånigt": "underdånig",
    "underdånigts": "underdånig",
    "underemissionen": "underemission",
    "underemissionens": "underemission",
    "underemissioner": "underemission",
    "underemissionerna": "underemission",
    "underemissionernas": "underemission",
    "underemissioners": "underemission",
    "underemissions": "underemission",
    "underexponerad": "underexponera",
    "underexponerade": "underexponera",
    "underexponerades": "underexponera",
    "underexponerads": "underexponera",
    "underexponerande": "underexponera",
    "underexponeranden": "underexponerande",
    "underexponerandena": "underexponerande",
    "underexponerandenas": "underexponerande",
    "underexponerandens": "underexponerande",
    "underexponerandes": "underexponerande",
    "underexponerandet": "underexponerande",
    "underexponerandets": "underexponerande",
    "underexponerar": "underexponera",
    "underexponeras": "underexponera",
    "underexponerat": "underexponera",
    "underexponerats": "underexponera",
    "underexponerbara": "underexponerbar",
    "underexponerbarare": "underexponerbar",
    "underexponerbarares": "underexponerbar",
    "underexponerbaras": "underexponerbar",
    "underexponerbarast": "underexponerbar",
    "underexponerbaraste": "underexponerbar",
    "underexponerbarastes": "underexponerbar",
    "underexponerbarasts": "underexponerbar",
    "underexponerbare": "underexponerbar",
    "underexponerbares": "underexponerbar",
    "underexponerbarheten": "underexponerbarhet",
    "underexponerbarhetens": "underexponerbarhet",
    "underexponerbarhets": "underexponerbarhet",
    "underexponerbars": "underexponerbar",
    "underexponerbart": "underexponerbar",
    "underexponerbarts": "underexponerbar",
    "underexponeringar": "underexponering",
    "underexponeringarna": "underexponering",
    "underexponeringarnas": "underexponering",
    "underexponeringars": "underexponering",
    "underexponeringen": "underexponering",
    "underexponeringens": "underexponering",
    "underexponerings": "underexponering",
    "underfallen": "underfall",
    "underfallens": "underfall",
    "underfallet": "underfall",
    "underfallets": "underfall",
    "underfalls": "underfall",
    "underfamiljen": "underfamilj",
    "underfamiljens": "underfamilj",
    "underfamiljer": "underfamilj",
    "underfamiljerna": "underfamilj",
    "underfamiljernas": "underfamilj",
    "underfamiljers": "underfamilj",
    "underfamiljs": "underfamilj",
    "underfarten": "underfart",
    "underfartens": "underfart",
    "underfarter": "underfart",
    "underfarterna": "underfart",
    "underfarternas": "underfart",
    "underfarters": "underfart",
    "underfarts": "underfart",
    "underfinansierade": "underfinansierad",
    "underfinansierades": "underfinansierad",
    "underfinansierads": "underfinansierad",
    "underfinansierat": "underfinansierad",
    "underfinansierats": "underfinansierad",
    "underfulla": "underfull",
    "underfullare": "underfull",
    "underfullares": "underfull",
    "underfullas": "underfull",
    "underfullast": "underfull",
    "underfullaste": "underfull",
    "underfullastes": "underfull",
    "underfullasts": "underfull",
    "underfulle": "underfull",
    "underfulles": "underfull",
    "underfullheten": "underfullhet",
    "underfullhetens": "underfullhet",
    "underfullhets": "underfullhet",
    "underfulls": "underfull",
    "underfullt": "underfull",
    "underfullts": "underfull",
    "underfundiga": "underfundig",
    "underfundigare": "underfundig",
    "underfundigares": "underfundig",
    "underfundigas": "underfundig",
    "underfundigast": "underfundig",
    "underfundigaste": "underfundig",
    "underfundigastes": "underfundig",
    "underfundigasts": "underfundig",
    "underfundige": "underfundig",
    "underfundiges": "underfundig",
    "underfundigheten": "underfundighet",
    "underfundighetens": "underfundighet",
    "underfundigheter": "underfundighet",
    "underfundigheterna": "underfundighet",
    "underfundigheternas": "underfundighet",
    "underfundigheters": "underfundighet",
    "underfundighets": "underfundighet",
    "underfundigs": "underfundig",
    "underfundigt": "underfundig",
    "underfundigts": "underfundig",
    "underförstod": "underförstå",
    "underförstode": "underförstå",
    "underförstodes": "underförstå",
    "underförstods": "underförstå",
    "underförstådd": "underförstå",
    "underförstådda": "underförstådd",
    "underförståddare": "underförstådd",
    "underförståddares": "underförstådd",
    "underförståddas": "underförstådd",
    "underförståddast": "underförstådd",
    "underförståddaste": "underförstådd",
    "underförståddastes": "underförstådd",
    "underförståddasts": "underförstådd",
    "underförstådde": "underförstådd",
    "underförståddes": "underförstådd",
    "underförståddheten": "underförståddhet",
    "underförståddhetens": "underförståddhet",
    "underförståddhets": "underförståddhet",
    "underförstådds": "underförstådd",
    "underförstående": "underförstå",
    "underförståenden": "underförstående",
    "underförståendena": "underförstående",
    "underförståendenas": "underförstående",
    "underförståendens": "underförstående",
    "underförståendes": "underförstående",
    "underförståendet": "underförstående",
    "underförståendets": "underförstående",
    "underförstår": "underförstå",
    "underförstås": "underförstå",
    "underförstått": "underförstådd",
    "underförståtts": "underförstådd",
    "underförsäkrad": "underförsäkra",
    "underförsäkrade": "underförsäkra",
    "underförsäkrades": "underförsäkra",
    "underförsäkrads": "underförsäkra",
    "underförsäkrande": "underförsäkra",
    "underförsäkranden": "underförsäkrande",
    "underförsäkrandena": "underförsäkrande",
    "underförsäkrandenas": "underförsäkrande",
    "underförsäkrandens": "underförsäkrande",
    "underförsäkrandes": "underförsäkrande",
    "underförsäkrandet": "underförsäkrande",
    "underförsäkrandets": "underförsäkrande",
    "underförsäkrar": "underförsäkra",
    "underförsäkras": "underförsäkra",
    "underförsäkrat": "underförsäkra",
    "underförsäkrats": "underförsäkra",
    "underförsörjda": "underförsörjd",
    "underförsörjdare": "underförsörjd",
    "underförsörjdares": "underförsörjd",
    "underförsörjdas": "underförsörjd",
    "underförsörjdast": "underförsörjd",
    "underförsörjdaste": "underförsörjd",
    "underförsörjdastes": "underförsörjd",
    "underförsörjdasts": "underförsörjd",
    "underförsörjde": "underförsörjd",
    "underförsörjdes": "underförsörjd",
    "underförsörjds": "underförsörjd",
    "underförsörjt": "underförsörjd",
    "underförsörjts": "underförsörjd",
    "undergardinen": "undergardin",
    "undergardinens": "undergardin",
    "undergardiner": "undergardin",
    "undergardinerna": "undergardin",
    "undergardinernas": "undergardin",
    "undergardiners": "undergardin",
    "undergardins": "undergardin",
    "undergick": "undergå",
    "undergicks": "undergå",
    "underginge": "undergå",
    "underginges": "undergå",
    "undergivens": "undergiven",
    "undergivet": "undergiven",
    "undergivets": "undergiven",
    "undergivna": "undergiven",
    "undergivnare": "undergiven",
    "undergivnares": "undergiven",
    "undergivnas": "undergiven",
    "undergivnast": "undergiven",
    "undergivnaste": "undergiven",
    "undergivnastes": "undergiven",
    "undergivnasts": "undergiven",
    "undergivne": "undergiven",
    "undergivnes": "undergiven",
    "undergroundmusiken": "undergroundmusik",
    "undergroundmusikens": "undergroundmusik",
    "undergroundmusiks": "undergroundmusik",
    "undergrunden": "undergrund",
    "undergrundens": "undergrund",
    "undergrunder": "undergrund",
    "undergrunderna": "undergrund",
    "undergrundernas": "undergrund",
    "undergrunders": "undergrund",
    "undergrunds": "undergrund",
    "undergräv": "undergräva",
    "undergrävande": "undergräva",
    "undergrävanden": "undergrävande",
    "undergrävandena": "undergrävande",
    "undergrävandenas": "undergrävande",
    "undergrävandens": "undergrävande",
    "undergrävandes": "undergrävande",
    "undergrävandet": "undergrävande",
    "undergrävandets": "undergrävande",
    "undergrävas": "undergräva",
    "undergrävd": "undergräva",
    "undergrävda": "undergräva",
    "undergrävdas": "undergräva",
    "undergrävde": "undergräva",
    "undergrävdes": "undergräva",
    "undergrävds": "undergräva",
    "undergräver": "undergräva",
    "undergräves": "undergräva",
    "undergrävs": "undergräva",
    "undergrävt": "undergräva",
    "undergrävts": "undergräva",
    "undergående": "undergå",
    "undergåenden": "undergående",
    "undergåendena": "undergående",
    "undergåendenas": "undergående",
    "undergåendens": "undergående",
    "undergåendes": "undergående",
    "undergåendet": "undergående",
    "undergåendets": "undergående",
    "undergångar": "undergång",
    "undergångarna": "undergång",
    "undergångarnas": "undergång",
    "undergångars": "undergång",
    "undergånge": "undergå",
    "undergången": "undergång",
    "undergångens": "undergång",
    "undergånges": "undergå",
    "undergånget": "undergå",
    "undergångets": "undergå",
    "undergångna": "undergå",
    "undergångnas": "undergå",
    "undergångne": "undergå",
    "undergångnes": "undergå",
    "undergångs": "undergång",
    "undergångshoten": "undergångshot",
    "undergångshotens": "undergångshot",
    "undergångshotet": "undergångshot",
    "undergångshotets": "undergångshot",
    "undergångshots": "undergångshot",
    "undergångsprofetian": "undergångsprofetia",
    "undergångsprofetians": "undergångsprofetia",
    "undergångsprofetias": "undergångsprofetia",
    "undergångsprofetior": "undergångsprofetia",
    "undergångsprofetiorna": "undergångsprofetia",
    "undergångsprofetiornas": "undergångsprofetia",
    "undergångsprofetiors": "undergångsprofetia",
    "undergångsromantiken": "undergångsromantik",
    "undergångsromantikens": "undergångsromantik",
    "undergångsromantiks": "undergångsromantik",
    "undergångsspekulanten": "undergångsspekulant",
    "undergångsspekulantens": "undergångsspekulant",
    "undergångsspekulanter": "undergångsspekulant",
    "undergångsspekulanterna": "undergångsspekulant",
    "undergångsspekulanternas": "undergångsspekulant",
    "undergångsspekulanters": "undergångsspekulant",
    "undergångsspekulants": "undergångsspekulant",
    "undergångsteckens": "undergångstecken",
    "undergångstecknen": "undergångstecken",
    "undergångstecknens": "undergångstecken",
    "undergångstecknet": "undergångstecken",
    "undergångstecknets": "undergångstecken",
    "undergår": "undergå",
    "undergås": "undergå",
    "undergått": "undergå",
    "undergåtts": "undergå",
    "undergörar": "undergörare",
    "undergöraren": "undergörare",
    "undergörarens": "undergörare",
    "undergörares": "undergörare",
    "undergörarna": "undergörare",
    "undergörarnas": "undergörare",
    "underhaltiga": "underhaltig",
    "underhaltigare": "underhaltig",
    "underhaltigares": "underhaltig",
    "underhaltigas": "underhaltig",
    "underhaltigast": "underhaltig",
    "underhaltigaste": "underhaltig",
    "underhaltigastes": "underhaltig",
    "underhaltigasts": "underhaltig",
    "underhaltige": "underhaltig",
    "underhaltiges": "underhaltig",
    "underhaltigs": "underhaltig",
    "underhaltigt": "underhaltig",
    "underhaltigts": "underhaltig",
    "underhandlad": "underhandla",
    "underhandlade": "underhandla",
    "underhandlades": "underhandla",
    "underhandlads": "underhandla",
    "underhandlande": "underhandla",
    "underhandlanden": "underhandlande",
    "underhandlandena": "underhandlande",
    "underhandlandenas": "underhandlande",
    "underhandlandens": "underhandlande",
    "underhandlandes": "underhandlande",
    "underhandlandet": "underhandlande",
    "underhandlandets": "underhandlande",
    "underhandlar": "underhandla",
    "underhandlas": "underhandla",
    "underhandlat": "underhandla",
    "underhandlats": "underhandla",
    "underhandlingar": "underhandling",
    "underhandlingarna": "underhandling",
    "underhandlingarnas": "underhandling",
    "underhandlingars": "underhandling",
    "underhandlingen": "underhandling",
    "underhandlingens": "underhandling",
    "underhandlings": "underhandling",
    "underhandsackorden": "underhandsackord",
    "underhandsackordens": "underhandsackord",
    "underhandsackordet": "underhandsackord",
    "underhandsackordets": "underhandsackord",
    "underhandsackords": "underhandsackord",
    "underhandsbeskeden": "underhandsbesked",
    "underhandsbeskedens": "underhandsbesked",
    "underhandsbeskedet": "underhandsbesked",
    "underhandsbeskedets": "underhandsbesked",
    "underhandsbeskeds": "underhandsbesked",
    "underhandskontakten": "underhandskontakt",
    "underhandskontaktens": "underhandskontakt",
    "underhandskontakter": "underhandskontakt",
    "underhandskontakterna": "underhandskontakt",
    "underhandskontakternas": "underhandskontakt",
    "underhandskontakters": "underhandskontakt",
    "underhandskontakts": "underhandskontakt",
    "underhavanden": "underhavande",
    "underhavandena": "underhavande",
    "underhavandenas": "underhavande",
    "underhavandens": "underhavande",
    "underhavandes": "underhavande",
    "underhuden": "underhud",
    "underhudens": "underhud",
    "underhuds": "underhud",
    "underhuggar": "underhuggare",
    "underhuggaren": "underhuggare",
    "underhuggarens": "underhuggare",
    "underhuggares": "underhuggare",
    "underhuggarna": "underhuggare",
    "underhuggarnas": "underhuggare",
    "underhusen": "underhus",
    "underhusens": "underhus",
    "underhuset": "underhus",
    "underhusets": "underhus",
    "underhypoteken": "underhypotek",
    "underhypotekens": "underhypotek",
    "underhypoteket": "underhypotek",
    "underhypotekets": "underhypotek",
    "underhypoteks": "underhypotek",
    "underhärdiga": "underhärdig",
    "underhärdigare": "underhärdig",
    "underhärdigares": "underhärdig",
    "underhärdigas": "underhärdig",
    "underhärdigast": "underhärdig",
    "underhärdigaste": "underhärdig",
    "underhärdigastes": "underhärdig",
    "underhärdigasts": "underhärdig",
    "underhärdige": "underhärdig",
    "underhärdiges": "underhärdig",
    "underhärdigs": "underhärdig",
    "underhärdigt": "underhärdig",
    "underhärdigts": "underhärdig",
    "underhåll": "underhålla",
    "underhållande": "underhålla",
    "underhållanden": "underhållande",
    "underhållandena": "underhållande",
    "underhållandenas": "underhållande",
    "underhållandens": "underhållande",
    "underhållandes": "underhållande",
    "underhållandet": "underhållande",
    "underhållandets": "underhållande",
    "underhållar": "underhållare",
    "underhållaren": "underhållare",
    "underhållarens": "underhållare",
    "underhållares": "underhållare",
    "underhållarna": "underhållare",
    "underhållarnas": "underhållare",
    "underhållas": "underhålla",
    "underhålle": "underhålla",
    "underhållen": "underhålla",
    "underhållens": "underhålla",
    "underhåller": "underhålla",
    "underhålles": "underhålla",
    "underhållet": "underhålla",
    "underhållets": "underhålla",
    "underhållit": "underhålla",
    "underhållits": "underhålla",
    "underhållna": "underhålla",
    "underhållnas": "underhålla",
    "underhållne": "underhålla",
    "underhållnes": "underhålla",
    "underhållningar": "underhållning",
    "underhållningarna": "underhållning",
    "underhållningarnas": "underhållning",
    "underhållningars": "underhållning",
    "underhållningen": "underhållning",
    "underhållningens": "underhållning",
    "underhållnings": "underhållning",
    "underhållningsbranschen": "underhållningsbransch",
    "underhållningsbranschens": "underhållningsbransch",
    "underhållningsbranschs": "underhållningsbransch",
    "underhållningsmässiga": "underhållningsmässig",
    "underhållningsmässigare": "underhållningsmässig",
    "underhållningsmässigares": "underhållningsmässig",
    "underhållningsmässigas": "underhållningsmässig",
    "underhållningsmässigast": "underhållningsmässig",
    "underhållningsmässigaste": "underhållningsmässig",
    "underhållningsmässigastes": "underhållningsmässig",
    "underhållningsmässigasts": "underhållningsmässig",
    "underhållningsmässige": "underhållningsmässig",
    "underhållningsmässiges": "underhållningsmässig",
    "underhållningsmässigs": "underhållningsmässig",
    "underhållningsmässigt": "underhållningsmässig",
    "underhållningsmässigts": "underhållningsmässig",
    "underhållningsorkestern": "underhållningsorkester",
    "underhållningsorkesterns": "underhållningsorkester",
    "underhållningsorkesters": "underhållningsorkester",
    "underhållningsorkestrar": "underhållningsorkester",
    "underhållningsorkestrarna": "underhållningsorkester",
    "underhållningsorkestrarnas": "underhållningsorkester",
    "underhållningsorkestrars": "underhållningsorkester",
    "underhållningsvåldet": "underhållningsvåld",
    "underhållningsvåldets": "underhållningsvåld",
    "underhållningsvålds": "underhållningsvåld",
    "underhålls": "underhålla",
    "underhållsarbeten": "underhållsarbete",
    "underhållsarbetena": "underhållsarbete",
    "underhållsarbetenas": "underhållsarbete",
    "underhållsarbetens": "underhållsarbete",
    "underhållsarbetes": "underhållsarbete",
    "underhållsarbetet": "underhållsarbete",
    "underhållsarbetets": "underhållsarbete",
    "underhållsarbets": "underhållsarbete",
    "underhållsbidragen": "underhållsbidrag",
    "underhållsbidragens": "underhållsbidrag",
    "underhållsbidraget": "underhållsbidrag",
    "underhållsbidragets": "underhållsbidrag",
    "underhållsbidrags": "underhållsbidrag",
    "underhållsfria": "underhållsfri",
    "underhållsfriare": "underhållsfri",
    "underhållsfriares": "underhållsfri",
    "underhållsfrias": "underhållsfri",
    "underhållsfriast": "underhållsfri",
    "underhållsfriaste": "underhållsfri",
    "underhållsfriastes": "underhållsfri",
    "underhållsfriasts": "underhållsfri",
    "underhållsfrie": "underhållsfri",
    "underhållsfries": "underhållsfri",
    "underhållsfris": "underhållsfri",
    "underhållsfritt": "underhållsfri",
    "underhållsfritts": "underhållsfri",
    "underhållsförbanden": "underhållsförband",
    "underhållsförbandens": "underhållsförband",
    "underhållsförbandet": "underhållsförband",
    "underhållsförbandets": "underhållsförband",
    "underhållsförbands": "underhållsförband",
    "underhållskolonnen": "underhållskolonn",
    "underhållskolonnens": "underhållskolonn",
    "underhållskolonner": "underhållskolonn",
    "underhållskolonnerna": "underhållskolonn",
    "underhållskolonnernas": "underhållskolonn",
    "underhållskolonners": "underhållskolonn",
    "underhållskolonns": "underhållskolonn",
    "underhållskostnaden": "underhållskostnad",
    "underhållskostnadens": "underhållskostnad",
    "underhållskostnader": "underhållskostnad",
    "underhållskostnaderna": "underhållskostnad",
    "underhållskostnadernas": "underhållskostnad",
    "underhållskostnaders": "underhållskostnad",
    "underhållskostnads": "underhållskostnad",
    "underhållsproblemen": "underhållsproblem",
    "underhållsproblemens": "underhållsproblem",
    "underhållsproblemet": "underhållsproblem",
    "underhållsproblemets": "underhållsproblem",
    "underhållsproblems": "underhållsproblem",
    "underhållsprogrammen": "underhållsprogram",
    "underhållsprogrammens": "underhållsprogram",
    "underhållsprogrammet": "underhållsprogram",
    "underhållsprogrammets": "underhållsprogram",
    "underhållsprograms": "underhållsprogram",
    "underhållstjänsten": "underhållstjänst",
    "underhållstjänstens": "underhållstjänst",
    "underhållstjänster": "underhållstjänst",
    "underhållstjänsterna": "underhållstjänst",
    "underhållstjänsternas": "underhållstjänst",
    "underhållstjänsters": "underhållstjänst",
    "underhållstjänsts": "underhållstjänst",
    "underhållstruppen": "underhållstrupp",
    "underhållstruppens": "underhållstrupp",
    "underhållstrupper": "underhållstrupp",
    "underhållstrupperna": "underhållstrupp",
    "underhållstruppernas": "underhållstrupp",
    "underhållstruppers": "underhållstrupp",
    "underhållstrupps": "underhållstrupp",
    "underhöll": "underhålla",
    "underhölle": "underhålla",
    "underhölles": "underhålla",
    "underhölls": "underhålla",
    "underinformerade": "underinformerad",
    "underinformerades": "underinformerad",
    "underinformerads": "underinformerad",
    "underinformerat": "underinformerad",
    "underinformerats": "underinformerad",
    "underingenjören": "underingenjör",
    "underingenjörens": "underingenjör",
    "underingenjörer": "underingenjör",
    "underingenjörerna": "underingenjör",
    "underingenjörernas": "underingenjör",
    "underingenjörers": "underingenjör",
    "underingenjörn": "underingenjör",
    "underingenjörns": "underingenjör",
    "underingenjörs": "underingenjör",
    "underinstansen": "underinstans",
    "underinstansens": "underinstans",
    "underinstanser": "underinstans",
    "underinstanserna": "underinstans",
    "underinstansernas": "underinstans",
    "underinstansers": "underinstans",
    "underjordens": "underjorden",
    "underjordiska": "underjordisk",
    "underjordiskare": "underjordisk",
    "underjordiskares": "underjordisk",
    "underjordiskas": "underjordisk",
    "underjordiskast": "underjordisk",
    "underjordiskaste": "underjordisk",
    "underjordiskastes": "underjordisk",
    "underjordiskasts": "underjordisk",
    "underjordiske": "underjordisk",
    "underjordiskes": "underjordisk",
    "underjordisks": "underjordisk",
    "underjordiskt": "underjordisk",
    "underjordiskts": "underjordisk",
    "underjordsarbeten": "underjordsarbete",
    "underjordsarbetena": "underjordsarbete",
    "underjordsarbetenas": "underjordsarbete",
    "underjordsarbetens": "underjordsarbete",
    "underjordsarbetes": "underjordsarbete",
    "underjordsarbetet": "underjordsarbete",
    "underjordsarbetets": "underjordsarbete",
    "underjordsarbets": "underjordsarbete",
    "underjordsproven": "underjordsprov",
    "underjordsprovens": "underjordsprov",
    "underjordsprovet": "underjordsprov",
    "underjordsprovets": "underjordsprov",
    "underjordsprovs": "underjordsprov",
    "underjäsningar": "underjäsning",
    "underjäsningarna": "underjäsning",
    "underjäsningarnas": "underjäsning",
    "underjäsningars": "underjäsning",
    "underjäsningen": "underjäsning",
    "underjäsningens": "underjäsning",
    "underjäsnings": "underjäsning",
    "underjästen": "underjäst",
    "underjästens": "underjäst",
    "underjästs": "underjäst",
    "underkanten": "underkant",
    "underkantens": "underkant",
    "underkanter": "underkant",
    "underkanterna": "underkant",
    "underkanternas": "underkant",
    "underkanters": "underkant",
    "underkants": "underkant",
    "underkast": "underkasta",
    "underkastad": "underkasta",
    "underkastade": "underkasta",
    "underkastades": "underkasta",
    "underkastads": "underkasta",
    "underkastande": "underkasta",
    "underkastanden": "underkastande",
    "underkastandena": "underkastande",
    "underkastandenas": "underkastande",
    "underkastandens": "underkastande",
    "underkastandes": "underkastande",
    "underkastandet": "underkastande",
    "underkastandets": "underkastande",
    "underkastar": "underkasta",
    "underkastas": "underkasta",
    "underkastat": "underkasta",
    "underkastats": "underkasta",
    "underkastelsen": "underkastelse",
    "underkastelsens": "underkastelse",
    "underkastelses": "underkastelse",
    "underkjolar": "underkjol",
    "underkjolarna": "underkjol",
    "underkjolarnas": "underkjol",
    "underkjolars": "underkjol",
    "underkjolen": "underkjol",
    "underkjolens": "underkjol",
    "underkjols": "underkjol",
    "underklassar": "underklassare",
    "underklassaren": "underklassare",
    "underklassarens": "underklassare",
    "underklassares": "underklassare",
    "underklassarna": "underklassare",
    "underklassarnas": "underklassare",
    "underklassen": "underklass",
    "underklassens": "underklass",
    "underklassiga": "underklassig",
    "underklassigare": "underklassig",
    "underklassigares": "underklassig",
    "underklassigas": "underklassig",
    "underklassigast": "underklassig",
    "underklassigaste": "underklassig",
    "underklassigastes": "underklassig",
    "underklassigasts": "underklassig",
    "underklassige": "underklassig",
    "underklassiges": "underklassig",
    "underklassigheten": "underklassighet",
    "underklassighetens": "underklassighet",
    "underklassighets": "underklassighet",
    "underklassigs": "underklassig",
    "underklassigt": "underklassig",
    "underklassigts": "underklassig",
    "underkläderna": "underkläder",
    "underklädernas": "underkläder",
    "underkläders": "underkläder",
    "underklädes": "underkläder",
    "underkläds": "underkläder",
    "underklänningar": "underklänning",
    "underklänningarna": "underklänning",
    "underklänningarnas": "underklänning",
    "underklänningars": "underklänning",
    "underklänningen": "underklänning",
    "underklänningens": "underklänning",
    "underklännings": "underklänning",
    "underkroppar": "underkropp",
    "underkropparna": "underkropp",
    "underkropparnas": "underkropp",
    "underkroppars": "underkropp",
    "underkroppen": "underkropp",
    "underkroppens": "underkropp",
    "underkropps": "underkropp",
    "underkunniga": "underkunnig",
    "underkunnigare": "underkunnig",
    "underkunnigares": "underkunnig",
    "underkunnigas": "underkunnig",
    "underkunnigast": "underkunnig",
    "underkunnigaste": "underkunnig",
    "underkunnigastes": "underkunnig",
    "underkunnigasts": "underkunnig",
    "underkunnige": "underkunnig",
    "underkunniges": "underkunnig",
    "underkunnigs": "underkunnig",
    "underkunnigt": "underkunnig",
    "underkunnigts": "underkunnig",
    "underkursen": "underkurs",
    "underkursens": "underkurs",
    "underkurser": "underkurs",
    "underkurserna": "underkurs",
    "underkursernas": "underkurs",
    "underkursers": "underkurs",
    "underkuv": "underkuva",
    "underkuvad": "underkuva",
    "underkuvade": "underkuva",
    "underkuvades": "underkuva",
    "underkuvads": "underkuva",
    "underkuvande": "underkuva",
    "underkuvanden": "underkuvande",
    "underkuvandena": "underkuvande",
    "underkuvandenas": "underkuvande",
    "underkuvandens": "underkuvande",
    "underkuvandes": "underkuvande",
    "underkuvandet": "underkuvande",
    "underkuvandets": "underkuvande",
    "underkuvar": "underkuva",
    "underkuvas": "underkuva",
    "underkuvat": "underkuva",
    "underkuvats": "underkuva",
    "underkvist": "underkvista",
    "underkvistad": "underkvista",
    "underkvistade": "underkvista",
    "underkvistades": "underkvista",
    "underkvistads": "underkvista",
    "underkvistande": "underkvista",
    "underkvistanden": "underkvistande",
    "underkvistandena": "underkvistande",
    "underkvistandenas": "underkvistande",
    "underkvistandens": "underkvistande",
    "underkvistandes": "underkvistande",
    "underkvistandet": "underkvistande",
    "underkvistandets": "underkvistande",
    "underkvistar": "underkvista",
    "underkvistas": "underkvista",
    "underkvistat": "underkvista",
    "underkvistats": "underkvista",
    "underkyl": "underkyla",
    "underkylande": "underkyla",
    "underkylanden": "underkylande",
    "underkylandena": "underkylande",
    "underkylandenas": "underkylande",
    "underkylandens": "underkylande",
    "underkylandes": "underkylande",
    "underkylandet": "underkylande",
    "underkylandets": "underkylande",
    "underkylas": "underkyla",
    "underkyld": "underkyla",
    "underkylda": "underkyld",
    "underkyldare": "underkyld",
    "underkyldares": "underkyld",
    "underkyldas": "underkyld",
    "underkyldast": "underkyld",
    "underkyldaste": "underkyld",
    "underkyldastes": "underkyld",
    "underkyldasts": "underkyld",
    "underkylde": "underkyld",
    "underkyldes": "underkyld",
    "underkylds": "underkyld",
    "underkyler": "underkyla",
    "underkyles": "underkyla",
    "underkyls": "underkyla",
    "underkylt": "underkyld",
    "underkylts": "underkyld",
    "underkäk": "underkäke",
    "underkäkar": "underkäke",
    "underkäkarna": "underkäke",
    "underkäkarnas": "underkäke",
    "underkäkars": "underkäke",
    "underkäken": "underkäke",
    "underkäkens": "underkäke",
    "underkäkes": "underkäke",
    "underkäks": "underkäke",
    "underkänd": "underkänna",
    "underkända": "underkänna",
    "underkändare": "underkänd",
    "underkändares": "underkänd",
    "underkändas": "underkänna",
    "underkändast": "underkänd",
    "underkändaste": "underkänd",
    "underkändastes": "underkänd",
    "underkändasts": "underkänd",
    "underkände": "underkänna",
    "underkändes": "underkänna",
    "underkänds": "underkänna",
    "underkänn": "underkänna",
    "underkännande": "underkänna",
    "underkännanden": "underkännande",
    "underkännandena": "underkännande",
    "underkännandenas": "underkännande",
    "underkännandens": "underkännande",
    "underkännandes": "underkännande",
    "underkännandet": "underkännande",
    "underkännandets": "underkännande",
    "underkännas": "underkänna",
    "underkänner": "underkänna",
    "underkännes": "underkänna",
    "underkänns": "underkänna",
    "underkänt": "underkänna",
    "underkänts": "underkänna",
    "underlagen": "underlag",
    "underlagens": "underlag",
    "underlaget": "underlag",
    "underlagets": "underlag",
    "underlags": "underlag",
    "underlagskart": "underlagskarta",
    "underlagskartan": "underlagskarta",
    "underlagskartans": "underlagskarta",
    "underlagskartas": "underlagskarta",
    "underlagskarte": "underlagskarta",
    "underlagskartor": "underlagskarta",
    "underlagskartorna": "underlagskarta",
    "underlagskartornas": "underlagskarta",
    "underlagskartors": "underlagskarta",
    "underlagskarts": "underlagskarta",
    "underlakanen": "underlakan",
    "underlakanens": "underlakan",
    "underlakanet": "underlakan",
    "underlakanets": "underlakan",
    "underlakans": "underlakan",
    "underlandet": "underland",
    "underlandets": "underland",
    "underlands": "underland",
    "underlapp": "underlappa",
    "underlappad": "underlappa",
    "underlappade": "underlappa",
    "underlappades": "underlappa",
    "underlappads": "underlappa",
    "underlappande": "underlappa",
    "underlappanden": "underlappande",
    "underlappandena": "underlappande",
    "underlappandenas": "underlappande",
    "underlappandens": "underlappande",
    "underlappandes": "underlappande",
    "underlappandet": "underlappande",
    "underlappandets": "underlappande",
    "underlappar": "underlappa",
    "underlappas": "underlappa",
    "underlappat": "underlappa",
    "underlappats": "underlappa",
    "underledar": "underledare",
    "underledaren": "underledare",
    "underledarens": "underledare",
    "underledares": "underledare",
    "underledarna": "underledare",
    "underledarnas": "underledare",
    "underleverantören": "underleverantör",
    "underleverantörens": "underleverantör",
    "underleverantörer": "underleverantör",
    "underleverantörerna": "underleverantör",
    "underleverantörernas": "underleverantör",
    "underleverantörers": "underleverantör",
    "underleverantörs": "underleverantör",
    "underliga": "underlig",
    "underligare": "underlig",
    "underligares": "underlig",
    "underligas": "underlig",
    "underligast": "underlig",
    "underligaste": "underlig",
    "underligastes": "underlig",
    "underligasts": "underlig",
    "underlige": "underlig",
    "underliges": "underlig",
    "underligheten": "underlighet",
    "underlighetens": "underlighet",
    "underligheter": "underlighet",
    "underligheterna": "underlighet",
    "underligheternas": "underlighet",
    "underligheters": "underlighet",
    "underlighets": "underlighet",
    "underligs": "underlig",
    "underligt": "underlig",
    "underligts": "underlig",
    "underliven": "underliv",
    "underlivens": "underliv",
    "underlivet": "underliv",
    "underlivets": "underliv",
    "underlivs": "underliv",
    "underljudsfarten": "underljudsfart",
    "underljudsfartens": "underljudsfart",
    "underljudsfarter": "underljudsfart",
    "underljudsfarterna": "underljudsfart",
    "underljudsfarternas": "underljudsfart",
    "underljudsfarters": "underljudsfart",
    "underljudsfarts": "underljudsfart",
    "underljudshastigheten": "underljudshastighet",
    "underljudshastighetens": "underljudshastighet",
    "underljudshastigheter": "underljudshastighet",
    "underljudshastigheterna": "underljudshastighet",
    "underljudshastigheternas": "underljudshastighet",
    "underljudshastigheters": "underljudshastighet",
    "underljudshastighets": "underljudshastighet",
    "underläders": "underläder",
    "underlädret": "underläder",
    "underlädrets": "underläder",
    "underläges": "underläge",
    "underläget": "underläge",
    "underlägets": "underläge",
    "underläggen": "underlägg",
    "underläggens": "underlägg",
    "underlägget": "underlägg",
    "underläggets": "underlägg",
    "underläggs": "underlägg",
    "underlägsenheten": "underlägsenhet",
    "underlägsenhetens": "underlägsenhet",
    "underlägsenheter": "underlägsenhet",
    "underlägsenheterna": "underlägsenhet",
    "underlägsenheternas": "underlägsenhet",
    "underlägsenheters": "underlägsenhet",
    "underlägsenhets": "underlägsenhet",
    "underlägsens": "underlägsen",
    "underlägset": "underlägsen",
    "underlägsets": "underlägsen",
    "underlägsna": "underlägsen",
    "underlägsnare": "underlägsen",
    "underlägsnares": "underlägsen",
    "underlägsnas": "underlägsen",
    "underlägsnast": "underlägsen",
    "underlägsnaste": "underlägsen",
    "underlägsnastes": "underlägsen",
    "underlägsnasts": "underlägsen",
    "underlägsne": "underlägsen",
    "underlägsnes": "underlägsen",
    "underläkar": "underläkare",
    "underläkaren": "underläkare",
    "underläkarens": "underläkare",
    "underläkares": "underläkare",
    "underläkarna": "underläkare",
    "underläkarnas": "underläkare",
    "underläppen": "underläpp",
    "underläppens": "underläpp",
    "underläpps": "underläpp",
    "underlät": "underlåta",
    "underläts": "underlåta",
    "underlätt": "underlätta",
    "underlättad": "underlätta",
    "underlättade": "underlätta",
    "underlättades": "underlätta",
    "underlättads": "underlätta",
    "underlättande": "underlätta",
    "underlättanden": "underlättande",
    "underlättandena": "underlättande",
    "underlättandenas": "underlättande",
    "underlättandens": "underlättande",
    "underlättandes": "underlättande",
    "underlättandet": "underlättande",
    "underlättandets": "underlättande",
    "underlättar": "underlätta",
    "underlättas": "underlätta",
    "underlättat": "underlätta",
    "underlättats": "underlätta",
    "underlåt": "underlåta",
    "underlåtande": "underlåta",
    "underlåtanden": "underlåtande",
    "underlåtandena": "underlåtande",
    "underlåtandenas": "underlåtande",
    "underlåtandens": "underlåtande",
    "underlåtandes": "underlåtande",
    "underlåtandet": "underlåtande",
    "underlåtandets": "underlåtande",
    "underlåtas": "underlåta",
    "underlåte": "underlåta",
    "underlåtelsen": "underlåtelse",
    "underlåtelsens": "underlåtelse",
    "underlåtelser": "underlåtelse",
    "underlåtelserna": "underlåtelse",
    "underlåtelsernas": "underlåtelse",
    "underlåtelsers": "underlåtelse",
    "underlåtelses": "underlåtelse",
    "underlåten": "underlåta",
    "underlåtenheten": "underlåtenhet",
    "underlåtenhetens": "underlåtenhet",
    "underlåtenheter": "underlåtenhet",
    "underlåtenheterna": "underlåtenhet",
    "underlåtenheternas": "underlåtenhet",
    "underlåtenheters": "underlåtenhet",
    "underlåtenhets": "underlåtenhet",
    "underlåtenhetssynden": "underlåtenhetssynd",
    "underlåtenhetssyndens": "underlåtenhetssynd",
    "underlåtenhetssynder": "underlåtenhetssynd",
    "underlåtenhetssynderna": "underlåtenhetssynd",
    "underlåtenhetssyndernas": "underlåtenhetssynd",
    "underlåtenhetssynders": "underlåtenhetssynd",
    "underlåtenhetssynds": "underlåtenhetssynd",
    "underlåtens": "underlåta",
    "underlåter": "underlåta",
    "underlåtes": "underlåta",
    "underlåtet": "underlåta",
    "underlåtets": "underlåta",
    "underlåtit": "underlåta",
    "underlåtits": "underlåta",
    "underlåtna": "underlåta",
    "underlåtnas": "underlåta",
    "underlåtne": "underlåta",
    "underlåtnes": "underlåta",
    "underlåts": "underlåta",
    "undermasten": "undermast",
    "undermastens": "undermast",
    "undermaster": "undermast",
    "undermasterna": "undermast",
    "undermasternas": "undermast",
    "undermasters": "undermast",
    "undermasts": "undermast",
    "undermedicineringar": "undermedicinering",
    "undermedicineringarna": "undermedicinering",
    "undermedicineringarnas": "undermedicinering",
    "undermedicineringars": "undermedicinering",
    "undermedicineringen": "undermedicinering",
    "undermedicineringens": "undermedicinering",
    "undermedicinerings": "undermedicinering",
    "undermedvetandes": "undermedvetande",
    "undermedvetandet": "undermedvetande",
    "undermedvetandets": "undermedvetande",
    "undermedvetens": "undermedveten",
    "undermedvetet": "undermedveten",
    "undermedvetets": "undermedveten",
    "undermedvetna": "undermedveten",
    "undermedvetnare": "undermedveten",
    "undermedvetnares": "undermedveten",
    "undermedvetnas": "undermedveten",
    "undermedvetnast": "undermedveten",
    "undermedvetnaste": "undermedveten",
    "undermedvetnastes": "undermedveten",
    "undermedvetnasts": "undermedveten",
    "undermedvetne": "undermedveten",
    "undermedvetnes": "undermedveten",
    "undermeningar": "undermening",
    "undermeningarna": "undermening",
    "undermeningarnas": "undermening",
    "undermeningars": "undermening",
    "undermeningen": "undermening",
    "undermeningens": "undermening",
    "undermenings": "undermening",
    "underminerad": "underminera",
    "underminerade": "underminera",
    "underminerades": "underminera",
    "underminerads": "underminera",
    "underminerande": "underminera",
    "undermineranden": "underminerande",
    "underminerandena": "underminerande",
    "underminerandenas": "underminerande",
    "underminerandens": "underminerande",
    "underminerandes": "underminerande",
    "underminerandet": "underminerande",
    "underminerandets": "underminerande",
    "underminerar": "underminera",
    "undermineras": "underminera",
    "underminerat": "underminera",
    "underminerats": "underminera",
    "underminerbara": "underminerbar",
    "underminerbarare": "underminerbar",
    "underminerbarares": "underminerbar",
    "underminerbaras": "underminerbar",
    "underminerbarast": "underminerbar",
    "underminerbaraste": "underminerbar",
    "underminerbarastes": "underminerbar",
    "underminerbarasts": "underminerbar",
    "underminerbare": "underminerbar",
    "underminerbares": "underminerbar",
    "underminerbarheten": "underminerbarhet",
    "underminerbarhetens": "underminerbarhet",
    "underminerbarhets": "underminerbarhet",
    "underminerbars": "underminerbar",
    "underminerbart": "underminerbar",
    "underminerbarts": "underminerbar",
    "undermineringar": "underminering",
    "undermineringarna": "underminering",
    "undermineringarnas": "underminering",
    "undermineringars": "underminering",
    "undermineringen": "underminering",
    "undermineringens": "underminering",
    "underminerings": "underminering",
    "undermänskliga": "undermänsklig",
    "undermänskligare": "undermänsklig",
    "undermänskligares": "undermänsklig",
    "undermänskligas": "undermänsklig",
    "undermänskligast": "undermänsklig",
    "undermänskligaste": "undermänsklig",
    "undermänskligastes": "undermänsklig",
    "undermänskligasts": "undermänsklig",
    "undermänsklige": "undermänsklig",
    "undermänskliges": "undermänsklig",
    "undermänskligheten": "undermänsklighet",
    "undermänsklighetens": "undermänsklighet",
    "undermänsklighets": "undermänsklighet",
    "undermänskligs": "undermänsklig",
    "undermänskligt": "undermänsklig",
    "undermänskligts": "undermänsklig",
    "undermålet": "undermål",
    "undermålets": "undermål",
    "undermåliga": "undermålig",
    "undermåligare": "undermålig",
    "undermåligares": "undermålig",
    "undermåligas": "undermålig",
    "undermåligast": "undermålig",
    "undermåligaste": "undermålig",
    "undermåligastes": "undermålig",
    "undermåligasts": "undermålig",
    "undermålige": "undermålig",
    "undermåliges": "undermålig",
    "undermåligheten": "undermålighet",
    "undermålighetens": "undermålighet",
    "undermåligheter": "undermålighet",
    "undermåligheterna": "undermålighet",
    "undermåligheternas": "undermålighet",
    "undermåligheters": "undermålighet",
    "undermålighets": "undermålighet",
    "undermåligs": "undermålig",
    "undermåligt": "undermålig",
    "undermåligts": "undermålig",
    "undermålningar": "undermålning",
    "undermålningarna": "undermålning",
    "undermålningarnas": "undermålning",
    "undermålningars": "undermålning",
    "undermålningen": "undermålning",
    "undermålningens": "undermålning",
    "undermålnings": "undermålning",
    "undermåls": "undermål",
    "undernärda": "undernärd",
    "undernärdare": "undernärd",
    "undernärdares": "undernärd",
    "undernärdas": "undernärd",
    "undernärdast": "undernärd",
    "undernärdaste": "undernärd",
    "undernärdastes": "undernärd",
    "undernärdasts": "undernärd",
    "undernärde": "undernärd",
    "undernärdes": "undernärd",
    "undernärdheten": "undernärdhet",
    "undernärdhetens": "undernärdhet",
    "undernärdhets": "undernärdhet",
    "undernärds": "undernärd",
    "undernäringar": "undernäring",
    "undernäringarna": "undernäring",
    "undernäringarnas": "undernäring",
    "undernäringars": "undernäring",
    "undernäringen": "undernäring",
    "undernäringens": "undernäring",
    "undernärings": "undernäring",
    "undernärt": "undernärd",
    "undernärts": "undernärd",
    "underofficerare": "underofficer",
    "underofficerares": "underofficer",
    "underofficerarna": "underofficer",
    "underofficerarnas": "underofficer",
    "underofficeren": "underofficer",
    "underofficerens": "underofficer",
    "underofficern": "underofficer",
    "underofficerns": "underofficer",
    "underofficers": "underofficer",
    "underordn": "underordna",
    "underordnad": "underordna",
    "underordnade": "underordnad",
    "underordnades": "underordnad",
    "underordnads": "underordnad",
    "underordnande": "underordna",
    "underordnanden": "underordnande",
    "underordnandena": "underordnande",
    "underordnandenas": "underordnande",
    "underordnandens": "underordnande",
    "underordnandes": "underordnande",
    "underordnandet": "underordnande",
    "underordnandets": "underordnande",
    "underordnar": "underordna",
    "underordnas": "underordna",
    "underordnat": "underordnad",
    "underordnats": "underordnad",
    "underordningar": "underordning",
    "underordningarna": "underordning",
    "underordningarnas": "underordning",
    "underordningars": "underordning",
    "underordningen": "underordning",
    "underordningens": "underordning",
    "underordnings": "underordning",
    "underpanten": "underpant",
    "underpantens": "underpant",
    "underpanter": "underpant",
    "underpanterna": "underpant",
    "underpanternas": "underpant",
    "underpanters": "underpant",
    "underpants": "underpant",
    "underplaggen": "underplagg",
    "underplaggens": "underplagg",
    "underplagget": "underplagg",
    "underplaggets": "underplagg",
    "underplaggs": "underplagg",
    "underprisen": "underpris",
    "underprisens": "underpris",
    "underpriser": "underpris",
    "underpriserna": "underpris",
    "underprisernas": "underpris",
    "underprisers": "underpris",
    "underpriset": "underpris",
    "underprisets": "underpris",
    "underrapporteringen": "underrapportering",
    "underrapporteringens": "underrapportering",
    "underrapporterings": "underrapportering",
    "underreden": "underrede",
    "underredena": "underrede",
    "underredenas": "underrede",
    "underredens": "underrede",
    "underredes": "underrede",
    "underredet": "underrede",
    "underredets": "underrede",
    "underreds": "underrede",
    "underredsbehandlad": "underredsbehandla",
    "underredsbehandlade": "underredsbehandla",
    "underredsbehandlades": "underredsbehandla",
    "underredsbehandlads": "underredsbehandla",
    "underredsbehandlande": "underredsbehandla",
    "underredsbehandlanden": "underredsbehandlande",
    "underredsbehandlandena": "underredsbehandlande",
    "underredsbehandlandenas": "underredsbehandlande",
    "underredsbehandlandens": "underredsbehandlande",
    "underredsbehandlandes": "underredsbehandlande",
    "underredsbehandlandet": "underredsbehandlande",
    "underredsbehandlandets": "underredsbehandlande",
    "underredsbehandlar": "underredsbehandla",
    "underredsbehandlas": "underredsbehandla",
    "underredsbehandlat": "underredsbehandla",
    "underredsbehandlats": "underredsbehandla",
    "underredsbehandlingar": "underredsbehandling",
    "underredsbehandlingarna": "underredsbehandling",
    "underredsbehandlingarnas": "underredsbehandling",
    "underredsbehandlingars": "underredsbehandling",
    "underredsbehandlingen": "underredsbehandling",
    "underredsbehandlingens": "underredsbehandling",
    "underredsbehandlings": "underredsbehandling",
    "underrepresenterade": "underrepresenterad",
    "underrepresenterades": "underrepresenterad",
    "underrepresenterads": "underrepresenterad",
    "underrepresenterat": "underrepresenterad",
    "underrepresenterats": "underrepresenterad",
    "underrubriken": "underrubrik",
    "underrubrikens": "underrubrik",
    "underrubriker": "underrubrik",
    "underrubrikerna": "underrubrik",
    "underrubrikernas": "underrubrik",
    "underrubrikers": "underrubrik",
    "underrubriks": "underrubrik",
    "underrätt": "underrätta",
    "underrättad": "underrätta",
    "underrättade": "underrätta",
    "underrättades": "underrätta",
    "underrättads": "underrätta",
    "underrättande": "underrätta",
    "underrättanden": "underrättande",
    "underrättandena": "underrättande",
    "underrättandenas": "underrättande",
    "underrättandens": "underrättande",
    "underrättandes": "underrättande",
    "underrättandet": "underrättande",
    "underrättandets": "underrättande",
    "underrättar": "underrätta",
    "underrättas": "underrätta",
    "underrättat": "underrätta",
    "underrättats": "underrätta",
    "underrättelseläckagen": "underrättelseläckage",
    "underrättelseläckagens": "underrättelseläckage",
    "underrättelseläckages": "underrättelseläckage",
    "underrättelseläckaget": "underrättelseläckage",
    "underrättelseläckagets": "underrättelseläckage",
    "underrättelsen": "underrättelse",
    "underrättelsens": "underrättelse",
    "underrättelseofficerare": "underrättelseofficer",
    "underrättelseofficerares": "underrättelseofficer",
    "underrättelseofficerarna": "underrättelseofficer",
    "underrättelseofficerarnas": "underrättelseofficer",
    "underrättelseofficeren": "underrättelseofficer",
    "underrättelseofficerens": "underrättelseofficer",
    "underrättelseofficern": "underrättelseofficer",
    "underrättelseofficerns": "underrättelseofficer",
    "underrättelseofficers": "underrättelseofficer",
    "underrättelser": "underrättelse",
    "underrättelserna": "underrättelse",
    "underrättelsernas": "underrättelse",
    "underrättelsers": "underrättelse",
    "underrättelses": "underrättelse",
    "underrättelsetjänsten": "underrättelsetjänst",
    "underrättelsetjänstens": "underrättelsetjänst",
    "underrättelsetjänsts": "underrättelsetjänst",
    "underrättelseverksamheten": "underrättelseverksamhet",
    "underrättelseverksamhetens": "underrättelseverksamhet",
    "underrättelseverksamheter": "underrättelseverksamhet",
    "underrättelseverksamheterna": "underrättelseverksamhet",
    "underrättelseverksamheternas": "underrättelseverksamhet",
    "underrättelseverksamheters": "underrättelseverksamhet",
    "underrättelseverksamhets": "underrättelseverksamhet",
    "underrätten": "underrätt",
    "underrättens": "underrätt",
    "underrätter": "underrätt",
    "underrätterna": "underrätt",
    "underrätternas": "underrätt",
    "underrätters": "underrätt",
    "underrätts": "underrätt",
    "underrån": "underrå",
    "underråns": "underrå",
    "underrår": "underrå",
    "underrårna": "underrå",
    "underrårnas": "underrå",
    "underrårs": "underrå",
    "underrås": "underrå",
    "unders": "under",
    "undersamheten": "undersamhet",
    "undersamhetens": "undersamhet",
    "undersamhets": "undersamhet",
    "undersamma": "undersam",
    "undersammare": "undersam",
    "undersammares": "undersam",
    "undersammas": "undersam",
    "undersammast": "undersam",
    "undersammaste": "undersam",
    "undersammastes": "undersam",
    "undersammasts": "undersam",
    "undersamme": "undersam",
    "undersammes": "undersam",
    "undersams": "undersam",
    "undersamt": "undersam",
    "undersamts": "undersam",
    "undersatsen": "undersats",
    "undersatsens": "undersats",
    "undersatser": "undersats",
    "undersatserna": "undersats",
    "undersatsernas": "undersats",
    "undersatsers": "undersats",
    "undersegels": "undersegel",
    "underseglen": "undersegel",
    "underseglens": "undersegel",
    "underseglet": "undersegel",
    "underseglets": "undersegel",
    "undersidan": "undersida",
    "undersidans": "undersida",
    "undersidas": "undersida",
    "underside": "undersida",
    "undersides": "undersida",
    "undersidor": "undersida",
    "undersidorna": "undersida",
    "undersidornas": "undersida",
    "undersidors": "undersida",
    "underskatt": "underskatta",
    "underskattad": "underskatta",
    "underskattade": "underskatta",
    "underskattades": "underskatta",
    "underskattads": "underskatta",
    "underskattande": "underskatta",
    "underskattanden": "underskattande",
    "underskattandena": "underskattande",
    "underskattandenas": "underskattande",
    "underskattandens": "underskattande",
    "underskattandes": "underskattande",
    "underskattandet": "underskattande",
    "underskattandets": "underskattande",
    "underskattar": "underskatta",
    "underskattas": "underskatta",
    "underskattat": "underskatta",
    "underskattats": "underskatta",
    "underskattningar": "underskattning",
    "underskattningarna": "underskattning",
    "underskattningarnas": "underskattning",
    "underskattningars": "underskattning",
    "underskattningen": "underskattning",
    "underskattningens": "underskattning",
    "underskattnings": "underskattning",
    "underskogen": "underskog",
    "underskogens": "underskog",
    "underskogs": "underskog",
    "underskotten": "underskott",
    "underskottens": "underskott",
    "underskottet": "underskott",
    "underskottets": "underskott",
    "underskotts": "underskott",
    "underskottsavdragen": "underskottsavdrag",
    "underskottsavdragens": "underskottsavdrag",
    "underskottsavdraget": "underskottsavdrag",
    "underskottsavdragets": "underskottsavdrag",
    "underskottsavdrags": "underskottsavdrag",
    "underskred": "underskrida",
    "underskreds": "underskrida",
    "underskrid": "underskrida",
    "underskridande": "underskrida",
    "underskridanden": "underskridande",
    "underskridandena": "underskridande",
    "underskridandenas": "underskridande",
    "underskridandens": "underskridande",
    "underskridandes": "underskridande",
    "underskridandet": "underskridande",
    "underskridandets": "underskridande",
    "underskridas": "underskrida",
    "underskride": "underskrida",
    "underskriden": "underskrida",
    "underskridens": "underskrida",
    "underskrider": "underskrida",
    "underskrides": "underskrida",
    "underskridet": "underskrida",
    "underskridets": "underskrida",
    "underskridit": "underskrida",
    "underskridits": "underskrida",
    "underskridna": "underskrida",
    "underskridnas": "underskrida",
    "underskridne": "underskrida",
    "underskridnes": "underskrida",
    "underskrids": "underskrida",
    "underskriften": "underskrift",
    "underskriftens": "underskrift",
    "underskrifter": "underskrift",
    "underskrifterna": "underskrift",
    "underskrifternas": "underskrift",
    "underskrifters": "underskrift",
    "underskrifts": "underskrift",
    "underskåpen": "underskåp",
    "underskåpens": "underskåp",
    "underskåpet": "underskåp",
    "underskåpets": "underskåp",
    "underskåps": "underskåp",
    "undersköna": "underskön",
    "underskönare": "underskön",
    "underskönares": "underskön",
    "underskönas": "underskön",
    "underskönast": "underskön",
    "underskönaste": "underskön",
    "underskönastes": "underskön",
    "underskönasts": "underskön",
    "undersköne": "underskön",
    "underskönes": "underskön",
    "underskönheten": "underskönhet",
    "underskönhetens": "underskönhet",
    "underskönhets": "underskönhet",
    "undersköns": "underskön",
    "underskönt": "underskön",
    "underskönts": "underskön",
    "undersköterskan": "undersköterska",
    "undersköterskans": "undersköterska",
    "undersköterskas": "undersköterska",
    "undersköterske": "undersköterska",
    "undersköterskor": "undersköterska",
    "undersköterskorna": "undersköterska",
    "undersköterskornas": "undersköterska",
    "undersköterskors": "undersköterska",
    "underslagen": "underslag",
    "underslagens": "underslag",
    "underslaget": "underslag",
    "underslagets": "underslag",
    "underslagit": "underslå",
    "underslagits": "underslå",
    "underslagna": "underslå",
    "underslagnas": "underslå",
    "underslagne": "underslå",
    "underslagnes": "underslå",
    "underslags": "underslag",
    "undersleven": "underslev",
    "underslevens": "underslev",
    "underslevet": "underslev",
    "underslevets": "underslev",
    "underslevs": "underslev",
    "underslog": "underslå",
    "undersloge": "underslå",
    "undersloges": "underslå",
    "underslogs": "underslå",
    "undersläkten": "undersläkte",
    "undersläktena": "undersläkte",
    "undersläktenas": "undersläkte",
    "undersläktens": "undersläkte",
    "undersläktes": "undersläkte",
    "undersläktet": "undersläkte",
    "undersläktets": "undersläkte",
    "undersläkts": "undersläkte",
    "underslående": "underslå",
    "underslåenden": "underslående",
    "underslåendena": "underslående",
    "underslåendenas": "underslående",
    "underslåendens": "underslående",
    "underslåendes": "underslående",
    "underslåendet": "underslående",
    "underslåendets": "underslående",
    "underslår": "underslå",
    "underslås": "underslå",
    "underspännar": "underspännare",
    "underspännaren": "underspännare",
    "underspännarens": "underspännare",
    "underspännares": "underspännare",
    "underspännarna": "underspännare",
    "underspännarnas": "underspännare",
    "understa": "undre",
    "understack": "understicka",
    "understacks": "understicka",
    "understagen": "understag",
    "understagens": "understag",
    "understaget": "understag",
    "understagets": "understag",
    "understags": "understag",
    "understas": "undre",
    "understatementen": "understatement",
    "understatementens": "understatement",
    "understatementet": "understatement",
    "understatementets": "understatement",
    "understatements": "understatement",
    "underste": "undre",
    "understeg": "understiga",
    "understegs": "understiga",
    "understes": "undre",
    "understick": "understicka",
    "understickande": "understicka",
    "understickanden": "understickande",
    "understickandena": "understickande",
    "understickandenas": "understickande",
    "understickandens": "understickande",
    "understickandes": "understickande",
    "understickandet": "understickande",
    "understickandets": "understickande",
    "understickas": "understicka",
    "understicke": "understicka",
    "understicker": "understicka",
    "understickes": "understicka",
    "understicks": "understicka",
    "understig": "understiga",
    "understigande": "understiga",
    "understiganden": "understigande",
    "understigandena": "understigande",
    "understigandenas": "understigande",
    "understigandens": "understigande",
    "understigandes": "understigande",
    "understigandet": "understigande",
    "understigandets": "understigande",
    "understigas": "understiga",
    "understige": "understiga",
    "understigen": "understiga",
    "understigens": "understiga",
    "understiger": "understiga",
    "understiges": "understiga",
    "understiget": "understiga",
    "understigets": "understiga",
    "understigit": "understiga",
    "understigits": "understiga",
    "understigna": "understiga",
    "understignas": "understiga",
    "understigne": "understiga",
    "understignes": "understiga",
    "understigs": "understiga",
    "understimulerade": "understimulerad",
    "understimulerades": "understimulerad",
    "understimulerads": "understimulerad",
    "understimulerat": "understimulerad",
    "understimulerats": "understimulerad",
    "understreck": "understrecka",
    "understreckad": "understrecka",
    "understreckade": "understrecka",
    "understreckades": "understrecka",
    "understreckads": "understrecka",
    "understreckande": "understrecka",
    "understreckanden": "understreckande",
    "understreckandena": "understreckande",
    "understreckandenas": "understreckande",
    "understreckandens": "understreckande",
    "understreckandes": "understreckande",
    "understreckandet": "understreckande",
    "understreckandets": "understreckande",
    "understreckar": "understreckare",
    "understreckaren": "understreckare",
    "understreckarens": "understreckare",
    "understreckares": "understreckare",
    "understreckarna": "understreckare",
    "understreckarnas": "understreckare",
    "understreckas": "understrecka",
    "understreckat": "understrecka",
    "understreckats": "understrecka",
    "understruken": "understryka",
    "understrukens": "understryka",
    "understruket": "understryka",
    "understrukets": "understryka",
    "understrukit": "understryka",
    "understrukits": "understryka",
    "understrukna": "understryka",
    "understruknas": "understryka",
    "understrukne": "understryka",
    "understruknes": "understryka",
    "understryk": "understryka",
    "understrykande": "understryka",
    "understrykanden": "understrykande",
    "understrykandena": "understrykande",
    "understrykandenas": "understrykande",
    "understrykandens": "understrykande",
    "understrykandes": "understrykande",
    "understrykandet": "understrykande",
    "understrykandets": "understrykande",
    "understrykas": "understryka",
    "understryke": "understryka",
    "understryker": "understryka",
    "understrykes": "understryka",
    "understrykningar": "understrykning",
    "understrykningarna": "understrykning",
    "understrykningarnas": "understrykning",
    "understrykningars": "understrykning",
    "understrykningen": "understrykning",
    "understrykningens": "understrykning",
    "understryknings": "understrykning",
    "understryks": "understryka",
    "underströk": "understryka",
    "underströke": "understryka",
    "underströkes": "understryka",
    "underströks": "understryka",
    "underströmmar": "underström",
    "underströmmarna": "underström",
    "underströmmarnas": "underström",
    "underströmmars": "underström",
    "underströmmen": "underström",
    "underströmmens": "underström",
    "underströms": "underström",
    "understucke": "understicka",
    "understucken": "understicka",
    "understuckens": "understucken",
    "understuckes": "understicka",
    "understucket": "understucken",
    "understuckets": "understucken",
    "understuckit": "understicka",
    "understuckits": "understicka",
    "understuckna": "understucken",
    "understucknare": "understucken",
    "understucknares": "understucken",
    "understucknas": "understucken",
    "understucknast": "understucken",
    "understucknaste": "understucken",
    "understucknastes": "understucken",
    "understucknasts": "understucken",
    "understuckne": "understucken",
    "understucknes": "understucken",
    "understyrda": "understyrd",
    "understyrdare": "understyrd",
    "understyrdares": "understyrd",
    "understyrdas": "understyrd",
    "understyrdast": "understyrd",
    "understyrdaste": "understyrd",
    "understyrdastes": "understyrd",
    "understyrdasts": "understyrd",
    "understyrde": "understyrd",
    "understyrdes": "understyrd",
    "understyrdheten": "understyrdhet",
    "understyrdhetens": "understyrdhet",
    "understyrdhets": "understyrdhet",
    "understyrds": "understyrd",
    "understyrt": "understyrd",
    "understyrts": "understyrd",
    "underställ": "underställa",
    "underställande": "underställa",
    "underställanden": "underställande",
    "underställandena": "underställande",
    "underställandenas": "underställande",
    "underställandens": "underställande",
    "underställandes": "underställande",
    "underställandet": "underställande",
    "underställandets": "underställande",
    "underställas": "underställa",
    "underställd": "underställa",
    "underställda": "underställa",
    "underställdas": "underställa",
    "underställde": "underställa",
    "underställdes": "underställa",
    "underställds": "underställa",
    "underställer": "underställa",
    "underställes": "underställa",
    "underställningar": "underställning",
    "underställningarna": "underställning",
    "underställningarnas": "underställning",
    "underställningars": "underställning",
    "underställningen": "underställning",
    "underställningens": "underställning",
    "underställnings": "underställning",
    "underställs": "underställa",
    "underställt": "underställa",
    "underställts": "underställa",
    "understämman": "understämma",
    "understämmans": "understämma",
    "understämmas": "understämma",
    "understämme": "understämma",
    "understämmo": "understämma",
    "understämmor": "understämma",
    "understämmorna": "understämma",
    "understämmornas": "understämma",
    "understämmors": "understämma",
    "understöd": "understödja",
    "understöda": "understödja",
    "understödande": "understödja",
    "understödandes": "understödja",
    "understödas": "understödja",
    "understödd": "understödja",
    "understödda": "understödja",
    "understöddas": "understödja",
    "understödde": "understödja",
    "understöddes": "understödja",
    "understödds": "understödja",
    "understöder": "understödja",
    "understödes": "understödja",
    "understödet": "understöd",
    "understödets": "understöd",
    "understödjande": "understödja",
    "understödjanden": "understödjande",
    "understödjandena": "understödjande",
    "understödjandenas": "understödjande",
    "understödjandens": "understödjande",
    "understödjandes": "understödjande",
    "understödjandet": "understödjande",
    "understödjandets": "understödjande",
    "understödjas": "understödja",
    "understödje": "understödja",
    "understödjer": "understödja",
    "understöds": "understödja",
    "understödsföreningar": "understödsförening",
    "understödsföreningarna": "understödsförening",
    "understödsföreningarnas": "understödsförening",
    "understödsföreningars": "understödsförening",
    "understödsföreningen": "understödsförening",
    "understödsföreningens": "understödsförening",
    "understödsförenings": "understödsförening",
    "understödskassan": "understödskassa",
    "understödskassans": "understödskassa",
    "understödskassas": "understödskassa",
    "understödskasse": "understödskassa",
    "understödskassor": "understödskassa",
    "understödskassorna": "understödskassa",
    "understödskassornas": "understödskassa",
    "understödskassors": "understödskassa",
    "understödsnämnden": "understödsnämnd",
    "understödsnämndens": "understödsnämnd",
    "understödsnämnder": "understödsnämnd",
    "understödsnämnderna": "understödsnämnd",
    "understödsnämndernas": "understödsnämnd",
    "understödsnämnders": "understödsnämnd",
    "understödsnämnds": "understödsnämnd",
    "understödstagarandan": "understödstagaranda",
    "understödstagarandans": "understödstagaranda",
    "understödstagarandas": "understödstagaranda",
    "understötar": "understöt",
    "understötarna": "understöt",
    "understötarnas": "understöt",
    "understötars": "understöt",
    "understöten": "understöt",
    "understötens": "understöt",
    "understöts": "understöt",
    "understött": "understödja",
    "understötts": "understödja",
    "undersysselsatta": "undersysselsatt",
    "undersysselsattare": "undersysselsatt",
    "undersysselsattares": "undersysselsatt",
    "undersysselsattas": "undersysselsatt",
    "undersysselsattast": "undersysselsatt",
    "undersysselsattaste": "undersysselsatt",
    "undersysselsattastes": "undersysselsatt",
    "undersysselsattasts": "undersysselsatt",
    "undersysselsatte": "undersysselsatt",
    "undersysselsattes": "undersysselsatt",
    "undersysselsatts": "undersysselsatt",
    "undersysselsättningar": "undersysselsättning",
    "undersysselsättningarna": "undersysselsättning",
    "undersysselsättningarnas": "undersysselsättning",
    "undersysselsättningars": "undersysselsättning",
    "undersysselsättningen": "undersysselsättning",
    "undersysselsättningens": "undersysselsättning",
    "undersysselsättnings": "undersysselsättning",
    "undersälj": "undersälja",
    "undersäljande": "undersälja",
    "undersäljanden": "undersäljande",
    "undersäljandena": "undersäljande",
    "undersäljandenas": "undersäljande",
    "undersäljandens": "undersäljande",
    "undersäljandes": "undersäljande",
    "undersäljandet": "undersäljande",
    "undersäljandets": "undersäljande",
    "undersäljas": "undersälja",
    "undersäljer": "undersälja",
    "undersäljes": "undersälja",
    "undersäljs": "undersälja",
    "undersätsiga": "undersätsig",
    "undersätsigare": "undersätsig",
    "undersätsigares": "undersätsig",
    "undersätsigas": "undersätsig",
    "undersätsigast": "undersätsig",
    "undersätsigaste": "undersätsig",
    "undersätsigastes": "undersätsig",
    "undersätsigasts": "undersätsig",
    "undersätsige": "undersätsig",
    "undersätsiges": "undersätsig",
    "undersätsigheten": "undersätsighet",
    "undersätsighetens": "undersätsighet",
    "undersätsighets": "undersätsighet",
    "undersätsigs": "undersätsig",
    "undersätsigt": "undersätsig",
    "undersätsigts": "undersätsig",
    "undersåld": "undersälja",
    "undersålda": "undersälja",
    "undersåldas": "undersälja",
    "undersålde": "undersälja",
    "undersåldes": "undersälja",
    "undersålds": "undersälja",
    "undersålt": "undersälja",
    "undersålts": "undersälja",
    "undersåt": "undersåte",
    "undersåtar": "undersåte",
    "undersåtarna": "undersåte",
    "undersåtarnas": "undersåte",
    "undersåtars": "undersåte",
    "undersåten": "undersåte",
    "undersåtens": "undersåte",
    "undersåtes": "undersåte",
    "undersåtliga": "undersåtlig",
    "undersåtligare": "undersåtlig",
    "undersåtligares": "undersåtlig",
    "undersåtligas": "undersåtlig",
    "undersåtligast": "undersåtlig",
    "undersåtligaste": "undersåtlig",
    "undersåtligastes": "undersåtlig",
    "undersåtligasts": "undersåtlig",
    "undersåtlige": "undersåtlig",
    "undersåtliges": "undersåtlig",
    "undersåtligheten": "undersåtlighet",
    "undersåtlighetens": "undersåtlighet",
    "undersåtlighets": "undersåtlighet",
    "undersåtligs": "undersåtlig",
    "undersåtligt": "undersåtlig",
    "undersåtligts": "undersåtlig",
    "undersåts": "undersåte",
    "undersök": "undersöka",
    "undersökande": "undersöka",
    "undersökanden": "undersökande",
    "undersökandena": "undersökande",
    "undersökandenas": "undersökande",
    "undersökandens": "undersökande",
    "undersökandes": "undersökande",
    "undersökandet": "undersökande",
    "undersökandets": "undersökande",
    "undersökar": "undersökare",
    "undersökaren": "undersökare",
    "undersökarens": "undersökare",
    "undersökares": "undersökare",
    "undersökarna": "undersökare",
    "undersökarnas": "undersökare",
    "undersökas": "undersöka",
    "undersöker": "undersöka",
    "undersökes": "undersöka",
    "undersökningar": "undersökning",
    "undersökningarna": "undersökning",
    "undersökningarnas": "undersökning",
    "undersökningars": "undersökning",
    "undersökningen": "undersökning",
    "undersökningens": "undersökning",
    "undersöknings": "undersökning",
    "undersökningsdomar": "undersökningsdomare",
    "undersökningsdomaren": "undersökningsdomare",
    "undersökningsdomarens": "undersökningsdomare",
    "undersökningsdomares": "undersökningsdomare",
    "undersökningsdomarna": "undersökningsdomare",
    "undersökningsdomarnas": "undersökningsdomare",
    "undersökningsfångar": "undersökningsfånge",
    "undersökningsfångarna": "undersökningsfånge",
    "undersökningsfångarnas": "undersökningsfånge",
    "undersökningsfångars": "undersökningsfånge",
    "undersökningsfången": "undersökningsfånge",
    "undersökningsfångens": "undersökningsfånge",
    "undersökningsfånges": "undersökningsfånge",
    "undersökningsmetoden": "undersökningsmetod",
    "undersökningsmetodens": "undersökningsmetod",
    "undersökningsmetoder": "undersökningsmetod",
    "undersökningsmetoderna": "undersökningsmetod",
    "undersökningsmetodernas": "undersökningsmetod",
    "undersökningsmetoders": "undersökningsmetod",
    "undersökningsmetods": "undersökningsmetod",
    "undersökningsrummen": "undersökningsrum",
    "undersökningsrummens": "undersökningsrum",
    "undersökningsrummet": "undersökningsrum",
    "undersökningsrummets": "undersökningsrum",
    "undersökningsrums": "undersökningsrum",
    "undersöks": "undersöka",
    "undersökt": "undersöka",
    "undersökta": "undersöka",
    "undersöktas": "undersöka",
    "undersökte": "undersöka",
    "undersöktes": "undersöka",
    "undersökts": "undersöka",
    "undertaken": "undertak",
    "undertakens": "undertak",
    "undertaket": "undertak",
    "undertakets": "undertak",
    "undertaks": "undertak",
    "undertaliga": "undertalig",
    "undertaligare": "undertalig",
    "undertaligares": "undertalig",
    "undertaligas": "undertalig",
    "undertaligast": "undertalig",
    "undertaligaste": "undertalig",
    "undertaligastes": "undertalig",
    "undertaligasts": "undertalig",
    "undertalige": "undertalig",
    "undertaliges": "undertalig",
    "undertaligheten": "undertalighet",
    "undertalighetens": "undertalighet",
    "undertalighets": "undertalighet",
    "undertaligs": "undertalig",
    "undertaligt": "undertalig",
    "undertaligts": "undertalig",
    "undertaxerad": "undertaxera",
    "undertaxerade": "undertaxera",
    "undertaxerades": "undertaxera",
    "undertaxerads": "undertaxera",
    "undertaxerande": "undertaxera",
    "undertaxeranden": "undertaxerande",
    "undertaxerandena": "undertaxerande",
    "undertaxerandenas": "undertaxerande",
    "undertaxerandens": "undertaxerande",
    "undertaxerandes": "undertaxerande",
    "undertaxerandet": "undertaxerande",
    "undertaxerandets": "undertaxerande",
    "undertaxerar": "undertaxera",
    "undertaxeras": "undertaxera",
    "undertaxerat": "undertaxera",
    "undertaxerats": "undertaxera",
    "undertaxerbara": "undertaxerbar",
    "undertaxerbarare": "undertaxerbar",
    "undertaxerbarares": "undertaxerbar",
    "undertaxerbaras": "undertaxerbar",
    "undertaxerbarast": "undertaxerbar",
    "undertaxerbaraste": "undertaxerbar",
    "undertaxerbarastes": "undertaxerbar",
    "undertaxerbarasts": "undertaxerbar",
    "undertaxerbare": "undertaxerbar",
    "undertaxerbares": "undertaxerbar",
    "undertaxerbarheten": "undertaxerbarhet",
    "undertaxerbarhetens": "undertaxerbarhet",
    "undertaxerbarhets": "undertaxerbarhet",
    "undertaxerbars": "undertaxerbar",
    "undertaxerbart": "undertaxerbar",
    "undertaxerbarts": "undertaxerbar",
    "undertaxeringar": "undertaxering",
    "undertaxeringarna": "undertaxering",
    "undertaxeringarnas": "undertaxering",
    "undertaxeringars": "undertaxering",
    "undertaxeringen": "undertaxering",
    "undertaxeringens": "undertaxering",
    "undertaxerings": "undertaxering",
    "undertecknad": "underteckna",
    "undertecknade": "undertecknad",
    "undertecknades": "undertecknad",
    "undertecknads": "undertecknad",
    "undertecknande": "underteckna",
    "undertecknanden": "undertecknande",
    "undertecknandena": "undertecknande",
    "undertecknandenas": "undertecknande",
    "undertecknandens": "undertecknande",
    "undertecknandes": "undertecknande",
    "undertecknandet": "undertecknande",
    "undertecknandets": "undertecknande",
    "undertecknar": "undertecknare",
    "undertecknaren": "undertecknare",
    "undertecknarens": "undertecknare",
    "undertecknares": "undertecknare",
    "undertecknarna": "undertecknare",
    "undertecknarnas": "undertecknare",
    "undertecknas": "underteckna",
    "undertecknat": "undertecknad",
    "undertecknats": "undertecknad",
    "undertermen": "underterm",
    "undertermens": "underterm",
    "undertermer": "underterm",
    "undertermerna": "underterm",
    "undertermernas": "underterm",
    "undertermers": "underterm",
    "underterms": "underterm",
    "undertiteln": "undertitel",
    "undertitelns": "undertitel",
    "undertitels": "undertitel",
    "undertitlar": "undertitel",
    "undertitlarna": "undertitel",
    "undertitlarnas": "undertitel",
    "undertitlars": "undertitel",
    "undertonen": "underton",
    "undertonens": "underton",
    "undertoner": "underton",
    "undertonerna": "underton",
    "undertonernas": "underton",
    "undertoners": "underton",
    "undertons": "underton",
    "undertryck": "undertrycka",
    "undertryckande": "undertrycka",
    "undertryckanden": "undertryckande",
    "undertryckandena": "undertryckande",
    "undertryckandenas": "undertryckande",
    "undertryckandens": "undertryckande",
    "undertryckandes": "undertryckande",
    "undertryckandet": "undertryckande",
    "undertryckandets": "undertryckande",
    "undertryckas": "undertrycka",
    "undertrycker": "undertrycka",
    "undertryckes": "undertrycka",
    "undertrycket": "undertryck",
    "undertryckets": "undertryck",
    "undertrycks": "undertrycka",
    "undertryckt": "undertrycka",
    "undertryckta": "undertrycka",
    "undertrycktas": "undertrycka",
    "undertryckte": "undertrycka",
    "undertrycktes": "undertrycka",
    "undertryckts": "undertrycka",
    "undertrådar": "undertråd",
    "undertrådarna": "undertråd",
    "undertrådarnas": "undertråd",
    "undertrådars": "undertråd",
    "undertråden": "undertråd",
    "undertrådens": "undertråd",
    "undertråds": "undertråd",
    "undertröjan": "undertröja",
    "undertröjans": "undertröja",
    "undertröjas": "undertröja",
    "undertröje": "undertröja",
    "undertröjor": "undertröja",
    "undertröjorna": "undertröja",
    "undertröjornas": "undertröja",
    "undertröjors": "undertröja",
    "underutvecklade": "underutvecklad",
    "underutvecklades": "underutvecklad",
    "underutvecklads": "underutvecklad",
    "underutvecklat": "underutvecklad",
    "underutvecklats": "underutvecklad",
    "underutvecklingar": "underutveckling",
    "underutvecklingarna": "underutveckling",
    "underutvecklingarnas": "underutveckling",
    "underutvecklingars": "underutveckling",
    "underutvecklingen": "underutveckling",
    "underutvecklingens": "underutveckling",
    "underutvecklings": "underutveckling",
    "undervattensbåtar": "undervattensbåt",
    "undervattensbåtarna": "undervattensbåt",
    "undervattensbåtarnas": "undervattensbåt",
    "undervattensbåtars": "undervattensbåt",
    "undervattensbåten": "undervattensbåt",
    "undervattensbåtens": "undervattensbåt",
    "undervattensbåts": "undervattensbåt",
    "undervattensböljan": "undervattensbölja",
    "undervattensböljans": "undervattensbölja",
    "undervattensböljas": "undervattensbölja",
    "undervattensbölje": "undervattensbölja",
    "undervattensböljor": "undervattensbölja",
    "undervattensböljorna": "undervattensbölja",
    "undervattensböljornas": "undervattensbölja",
    "undervattensböljors": "undervattensbölja",
    "undervattensförbindelsen": "undervattensförbindelse",
    "undervattensförbindelsens": "undervattensförbindelse",
    "undervattensförbindelser": "undervattensförbindelse",
    "undervattensförbindelserna": "undervattensförbindelse",
    "undervattensförbindelsernas": "undervattensförbindelse",
    "undervattensförbindelsers": "undervattensförbindelse",
    "undervattensförbindelses": "undervattensförbindelse",
    "undervattensgången": "undervattensgång",
    "undervattensgångens": "undervattensgång",
    "undervattensgångs": "undervattensgång",
    "undervattenskameran": "undervattenskamera",
    "undervattenskamerans": "undervattenskamera",
    "undervattenskameras": "undervattenskamera",
    "undervattenskameror": "undervattenskamera",
    "undervattenskamerorna": "undervattenskamera",
    "undervattenskamerornas": "undervattenskamera",
    "undervattenskamerors": "undervattenskamera",
    "undervattenskroppar": "undervattenskropp",
    "undervattenskropparna": "undervattenskropp",
    "undervattenskropparnas": "undervattenskropp",
    "undervattenskroppars": "undervattenskropp",
    "undervattenskroppen": "undervattenskropp",
    "undervattenskroppens": "undervattenskropp",
    "undervattenskropps": "undervattenskropp",
    "undervattensläges": "undervattensläge",
    "undervattensläget": "undervattensläge",
    "undervattenslägets": "undervattensläge",
    "undervattenströskeln": "undervattenströskel",
    "undervattenströskelns": "undervattenströskel",
    "undervattenströskels": "undervattenströskel",
    "undervattenströsklar": "undervattenströskel",
    "undervattenströsklarna": "undervattenströskel",
    "undervattenströsklarnas": "undervattenströskel",
    "undervattenströsklars": "undervattenströskel",
    "undervegetationen": "undervegetation",
    "undervegetationens": "undervegetation",
    "undervegetationer": "undervegetation",
    "undervegetationerna": "undervegetation",
    "undervegetationernas": "undervegetation",
    "undervegetationers": "undervegetation",
    "undervegetations": "undervegetation",
    "underverken": "underverk",
    "underverkens": "underverk",
    "underverket": "underverk",
    "underverkets": "underverk",
    "underverks": "underverk",
    "undervikten": "undervikt",
    "underviktens": "undervikt",
    "underviktiga": "underviktig",
    "underviktigare": "underviktig",
    "underviktigares": "underviktig",
    "underviktigas": "underviktig",
    "underviktigast": "underviktig",
    "underviktigaste": "underviktig",
    "underviktigastes": "underviktig",
    "underviktigasts": "underviktig",
    "underviktige": "underviktig",
    "underviktiges": "underviktig",
    "underviktigheten": "underviktighet",
    "underviktighetens": "underviktighet",
    "underviktighets": "underviktighet",
    "underviktigs": "underviktig",
    "underviktigt": "underviktig",
    "underviktigts": "underviktig",
    "undervikts": "undervikt",
    "undervis": "undervisa",
    "undervisad": "undervisa",
    "undervisade": "undervisa",
    "undervisades": "undervisa",
    "undervisads": "undervisa",
    "undervisande": "undervisa",
    "undervisanden": "undervisande",
    "undervisandena": "undervisande",
    "undervisandenas": "undervisande",
    "undervisandens": "undervisande",
    "undervisandes": "undervisande",
    "undervisandet": "undervisande",
    "undervisandets": "undervisande",
    "undervisar": "undervisare",
    "undervisaren": "undervisare",
    "undervisarens": "undervisare",
    "undervisares": "undervisare",
    "undervisarna": "undervisare",
    "undervisarnas": "undervisare",
    "undervisas": "undervisa",
    "undervisat": "undervisa",
    "undervisats": "undervisa",
    "undervisningar": "undervisning",
    "undervisningarna": "undervisning",
    "undervisningarnas": "undervisning",
    "undervisningars": "undervisning",
    "undervisningen": "undervisning",
    "undervisningens": "undervisning",
    "undervisnings": "undervisning",
    "undervisningsbruket": "undervisningsbruk",
    "undervisningsbrukets": "undervisningsbruk",
    "undervisningsbruks": "undervisningsbruk",
    "undervisningsmaterialen": "undervisningsmaterial",
    "undervisningsmaterialens": "undervisningsmaterial",
    "undervisningsmaterialet": "undervisningsmaterial",
    "undervisningsmaterialets": "undervisningsmaterial",
    "undervisningsmaterials": "undervisningsmaterial",
    "undervisningsmetodiken": "undervisningsmetodik",
    "undervisningsmetodikens": "undervisningsmetodik",
    "undervisningsmetodiks": "undervisningsmetodik",
    "undervisningspaketen": "undervisningspaket",
    "undervisningspaketens": "undervisningspaket",
    "undervisningspaketet": "undervisningspaket",
    "undervisningspaketets": "undervisningspaket",
    "undervisningspakets": "undervisningspaket",
    "undervisningsråden": "undervisningsråd",
    "undervisningsrådens": "undervisningsråd",
    "undervisningsrådet": "undervisningsråd",
    "undervisningsrådets": "undervisningsråd",
    "undervisningsråds": "undervisningsråd",
    "undervisningssjukhusen": "undervisningssjukhus",
    "undervisningssjukhusens": "undervisningssjukhus",
    "undervisningssjukhuset": "undervisningssjukhus",
    "undervisningssjukhusets": "undervisningssjukhus",
    "undervisningsskickligheten": "undervisningsskicklighet",
    "undervisningsskicklighetens": "undervisningsskicklighet",
    "undervisningsskickligheter": "undervisningsskicklighet",
    "undervisningsskickligheterna": "undervisningsskicklighet",
    "undervisningsskickligheternas": "undervisningsskicklighet",
    "undervisningsskickligheters": "undervisningsskicklighet",
    "undervisningsskicklighets": "undervisningsskicklighet",
    "undervisningsskyldigheten": "undervisningsskyldighet",
    "undervisningsskyldighetens": "undervisningsskyldighet",
    "undervisningsskyldigheter": "undervisningsskyldighet",
    "undervisningsskyldigheterna": "undervisningsskyldighet",
    "undervisningsskyldigheternas": "undervisningsskyldighet",
    "undervisningsskyldigheters": "undervisningsskyldighet",
    "undervisningsskyldighets": "undervisningsskyldighet",
    "undervisningsspråken": "undervisningsspråk",
    "undervisningsspråkens": "undervisningsspråk",
    "undervisningsspråket": "undervisningsspråk",
    "undervisningsspråkets": "undervisningsspråk",
    "undervisningsspråks": "undervisningsspråk",
    "undervisningsteknologien": "undervisningsteknologi",
    "undervisningsteknologiens": "undervisningsteknologi",
    "undervisningsteknologier": "undervisningsteknologi",
    "undervisningsteknologierna": "undervisningsteknologi",
    "undervisningsteknologiernas": "undervisningsteknologi",
    "undervisningsteknologiers": "undervisningsteknologi",
    "undervisningsteknologin": "undervisningsteknologi",
    "undervisningsteknologins": "undervisningsteknologi",
    "undervisningsteknologis": "undervisningsteknologi",
    "undervisningstim": "undervisningstimme",
    "undervisningstimman": "undervisningstimma",
    "undervisningstimmans": "undervisningstimma",
    "undervisningstimmar": "undervisningstimme",
    "undervisningstimmarna": "undervisningstimme",
    "undervisningstimmarnas": "undervisningstimme",
    "undervisningstimmars": "undervisningstimme",
    "undervisningstimmas": "undervisningstimma",
    "undervisningstimmen": "undervisningstimme",
    "undervisningstimmens": "undervisningstimme",
    "undervisningstimmes": "undervisningstimme",
    "undervisningstims": "undervisningstimme",
    "undervisningsämnen": "undervisningsämne",
    "undervisningsämnena": "undervisningsämne",
    "undervisningsämnenas": "undervisningsämne",
    "undervisningsämnens": "undervisningsämne",
    "undervisningsämnes": "undervisningsämne",
    "undervisningsämnet": "undervisningsämne",
    "undervisningsämnets": "undervisningsämne",
    "undervärderad": "undervärdera",
    "undervärderade": "undervärdera",
    "undervärderades": "undervärdera",
    "undervärderads": "undervärdera",
    "undervärderande": "undervärdera",
    "undervärderanden": "undervärderande",
    "undervärderandena": "undervärderande",
    "undervärderandenas": "undervärderande",
    "undervärderandens": "undervärderande",
    "undervärderandes": "undervärderande",
    "undervärderandet": "undervärderande",
    "undervärderandets": "undervärderande",
    "undervärderar": "undervärdera",
    "undervärderas": "undervärdera",
    "undervärderat": "undervärdera",
    "undervärderats": "undervärdera",
    "undervärderbara": "undervärderbar",
    "undervärderbarare": "undervärderbar",
    "undervärderbarares": "undervärderbar",
    "undervärderbaras": "undervärderbar",
    "undervärderbarast": "undervärderbar",
    "undervärderbaraste": "undervärderbar",
    "undervärderbarastes": "undervärderbar",
    "undervärderbarasts": "undervärderbar",
    "undervärderbare": "undervärderbar",
    "undervärderbares": "undervärderbar",
    "undervärderbarheten": "undervärderbarhet",
    "undervärderbarhetens": "undervärderbarhet",
    "undervärderbarhets": "undervärderbarhet",
    "undervärderbars": "undervärderbar",
    "undervärderbart": "undervärderbar",
    "undervärderbarts": "undervärderbar",
    "undervärderingar": "undervärdering",
    "undervärderingarna": "undervärdering",
    "undervärderingarnas": "undervärdering",
    "undervärderingars": "undervärdering",
    "undervärderingen": "undervärdering",
    "undervärderingens": "undervärdering",
    "undervärderings": "undervärdering",
    "undervärmen": "undervärme",
    "undervärmens": "undervärme",
    "undervärmes": "undervärme",
    "undervåningar": "undervåning",
    "undervåningarna": "undervåning",
    "undervåningarnas": "undervåning",
    "undervåningars": "undervåning",
    "undervåningen": "undervåning",
    "undervåningens": "undervåning",
    "undervånings": "undervåning",
    "underåriga": "underårig",
    "underårigas": "underårig",
    "underårige": "underårig",
    "underåriges": "underårig",
    "underårigheten": "underårighet",
    "underårighetens": "underårighet",
    "underårighets": "underårighet",
    "underårigs": "underårig",
    "underårigt": "underårig",
    "underårigts": "underårig",
    "undfall": "undfalla",
    "undfallande": "undfalla",
    "undfallanden": "undfallande",
    "undfallandena": "undfallande",
    "undfallandenas": "undfallande",
    "undfallandens": "undfallande",
    "undfallandes": "undfallande",
    "undfallandet": "undfallande",
    "undfallandets": "undfallande",
    "undfallas": "undfalla",
    "undfalle": "undfalla",
    "undfallenheten": "undfallenhet",
    "undfallenhetens": "undfallenhet",
    "undfallenheter": "undfallenhet",
    "undfallenheterna": "undfallenhet",
    "undfallenheternas": "undfallenhet",
    "undfallenheters": "undfallenhet",
    "undfallenhets": "undfallenhet",
    "undfallens": "undfallen",
    "undfaller": "undfalla",
    "undfalles": "undfalla",
    "undfallet": "undfallen",
    "undfallets": "undfallen",
    "undfallit": "undfalla",
    "undfallits": "undfalla",
    "undfallna": "undfallen",
    "undfallnare": "undfallen",
    "undfallnares": "undfallen",
    "undfallnas": "undfallen",
    "undfallnast": "undfallen",
    "undfallnaste": "undfallen",
    "undfallnastes": "undfallen",
    "undfallnasts": "undfallen",
    "undfallne": "undfallen",
    "undfallnes": "undfallen",
    "undfalls": "undfalla",
    "undfick": "undfå",
    "undficks": "undfå",
    "undfinge": "undfå",
    "undfinges": "undfå",
    "undflydd": "undfly",
    "undflydda": "undfly",
    "undflyddas": "undfly",
    "undflydde": "undfly",
    "undflyddes": "undfly",
    "undflydds": "undfly",
    "undflyende": "undfly",
    "undflyendes": "undflyende",
    "undflyendet": "undflyende",
    "undflyendets": "undflyende",
    "undflyr": "undfly",
    "undflys": "undfly",
    "undflytt": "undfly",
    "undflytts": "undfly",
    "undfägn": "undfägna",
    "undfägnad": "undfägna",
    "undfägnade": "undfägna",
    "undfägnaden": "undfägnad",
    "undfägnadens": "undfägnad",
    "undfägnader": "undfägnad",
    "undfägnaderna": "undfägnad",
    "undfägnadernas": "undfägnad",
    "undfägnaders": "undfägnad",
    "undfägnades": "undfägna",
    "undfägnads": "undfägnad",
    "undfägnande": "undfägna",
    "undfägnanden": "undfägnande",
    "undfägnandena": "undfägnande",
    "undfägnandenas": "undfägnande",
    "undfägnandens": "undfägnande",
    "undfägnandes": "undfägnande",
    "undfägnandet": "undfägnande",
    "undfägnandets": "undfägnande",
    "undfägnar": "undfägna",
    "undfägnas": "undfägna",
    "undfägnat": "undfägna",
    "undfägnats": "undfägna",
    "undfående": "undfå",
    "undfåenden": "undfående",
    "undfåendena": "undfående",
    "undfåendenas": "undfående",
    "undfåendens": "undfående",
    "undfåendes": "undfående",
    "undfåendet": "undfående",
    "undfåendets": "undfående",
    "undfår": "undfå",
    "undfås": "undfå",
    "undfått": "undfå",
    "undfåtts": "undfå",
    "undföll": "undfalla",
    "undfölle": "undfalla",
    "undfölles": "undfalla",
    "undfölls": "undfalla",
    "undgick": "undgå",
    "undgicks": "undgå",
    "undginge": "undgå",
    "undginges": "undgå",
    "undgående": "undgå",
    "undgåenden": "undgående",
    "undgåendena": "undgående",
    "undgåendenas": "undgående",
    "undgåendens": "undgående",
    "undgåendes": "undgående",
    "undgåendet": "undgående",
    "undgåendets": "undgående",
    "undgår": "undgå",
    "undgås": "undgå",
    "undgått": "undgå",
    "undgåtts": "undgå",
    "undinen": "undin",
    "undinens": "undin",
    "undiner": "undin",
    "undinerna": "undin",
    "undinernas": "undin",
    "undiners": "undin",
    "undins": "undin",
    "undkom": "undkomma",
    "undkommande": "undkomma",
    "undkommanden": "undkommande",
    "undkommandena": "undkommande",
    "undkommandenas": "undkommande",
    "undkommandens": "undkommande",
    "undkommandes": "undkommande",
    "undkommandet": "undkommande",
    "undkommandets": "undkommande",
    "undkommas": "undkomma",
    "undkomme": "undkomma",
    "undkommer": "undkomma",
    "undkommes": "undkomma",
    "undkommit": "undkomma",
    "undkommits": "undkomma",
    "undkoms": "undkomma",
    "undrad": "undra",
    "undrade": "undra",
    "undrades": "undra",
    "undrads": "undra",
    "undrande": "undra",
    "undranden": "undrande",
    "undrandena": "undrande",
    "undrandenas": "undrande",
    "undrandens": "undrande",
    "undrandes": "undrande",
    "undrandet": "undrande",
    "undrandets": "undrande",
    "undrans": "undran",
    "undransvärda": "undransvärd",
    "undransvärdare": "undransvärd",
    "undransvärdares": "undransvärd",
    "undransvärdas": "undransvärd",
    "undransvärdast": "undransvärd",
    "undransvärdaste": "undransvärd",
    "undransvärdastes": "undransvärd",
    "undransvärdasts": "undransvärd",
    "undransvärde": "undransvärd",
    "undransvärdes": "undransvärd",
    "undransvärdheten": "undransvärdhet",
    "undransvärdhetens": "undransvärdhet",
    "undransvärdhets": "undransvärdhet",
    "undransvärds": "undransvärd",
    "undransvärt": "undransvärd",
    "undransvärts": "undransvärd",
    "undrar": "undra",
    "undras": "undra",
    "undrat": "undra",
    "undrats": "undra",
    "undren": "under",
    "undrens": "under",
    "undres": "undre",
    "undret": "under",
    "undrets": "under",
    "undringar": "undring",
    "undringarna": "undring",
    "undringarnas": "undring",
    "undringars": "undring",
    "undringen": "undring",
    "undringens": "undring",
    "undrings": "undring",
    "undsatt": "undsätta",
    "undsatta": "undsätta",
    "undsattas": "undsätta",
    "undsatte": "undsätta",
    "undsattes": "undsätta",
    "undsatts": "undsätta",
    "undseendes": "undseende",
    "undskyll": "undskylla",
    "undskyllande": "undskylla",
    "undskyllanden": "undskyllande",
    "undskyllandena": "undskyllande",
    "undskyllandenas": "undskyllande",
    "undskyllandens": "undskyllande",
    "undskyllandes": "undskyllande",
    "undskyllandet": "undskyllande",
    "undskyllandets": "undskyllande",
    "undskyllans": "undskyllan",
    "undskyllas": "undskylla",
    "undskylld": "undskylla",
    "undskyllda": "undskylla",
    "undskylldas": "undskylla",
    "undskyllde": "undskylla",
    "undskylldes": "undskylla",
    "undskyllds": "undskylla",
    "undskyller": "undskylla",
    "undskylles": "undskylla",
    "undskyllningar": "undskyllning",
    "undskyllningarna": "undskyllning",
    "undskyllningarnas": "undskyllning",
    "undskyllningars": "undskyllning",
    "undskyllningen": "undskyllning",
    "undskyllningens": "undskyllning",
    "undskyllnings": "undskyllning",
    "undskylls": "undskylla",
    "undskyllt": "undskylla",
    "undskyllts": "undskylla",
    "undslapp": "undslippa",
    "undslapps": "undslippa",
    "undslipp": "undslippa",
    "undslippande": "undslippa",
    "undslippanden": "undslippande",
    "undslippandena": "undslippande",
    "undslippandenas": "undslippande",
    "undslippandens": "undslippande",
    "undslippandes": "undslippande",
    "undslippandet": "undslippande",
    "undslippandets": "undslippande",
    "undslippas": "undslippa",
    "undslippe": "undslippa",
    "undslipper": "undslippa",
    "undslippes": "undslippa",
    "undslipps": "undslippa",
    "undsluppe": "undslippa",
    "undsluppes": "undslippa",
    "undsluppit": "undslippa",
    "undsluppits": "undslippa",
    "undsätt": "undsätta",
    "undsättande": "undsätta",
    "undsättanden": "undsättande",
    "undsättandena": "undsättande",
    "undsättandenas": "undsättande",
    "undsättandens": "undsättande",
    "undsättandes": "undsättande",
    "undsättandet": "undsättande",
    "undsättandets": "undsättande",
    "undsättas": "undsätta",
    "undsätter": "undsätta",
    "undsättes": "undsätta",
    "undsättningar": "undsättning",
    "undsättningarna": "undsättning",
    "undsättningarnas": "undsättning",
    "undsättningars": "undsättning",
    "undsättningen": "undsättning",
    "undsättningens": "undsättning",
    "undsättnings": "undsättning",
    "undsättningsfonden": "undsättningsfond",
    "undsättningsfondens": "undsättningsfond",
    "undsättningsfonder": "undsättningsfond",
    "undsättningsfonderna": "undsättningsfond",
    "undsättningsfondernas": "undsättningsfond",
    "undsättningsfonders": "undsättningsfond",
    "undsättningsfonds": "undsättningsfond",
    "undsättningsförsöken": "undsättningsförsök",
    "undsättningsförsökens": "undsättningsförsök",
    "undsättningsförsöket": "undsättningsförsök",
    "undsättningsförsökets": "undsättningsförsök",
    "undsättningsförsöks": "undsättningsförsök",
    "undsättningsstyrkan": "undsättningsstyrka",
    "undsättningsstyrkans": "undsättningsstyrka",
    "undsättningsstyrkas": "undsättningsstyrka",
    "undsättningsstyrke": "undsättningsstyrka",
    "undsättningsstyrkor": "undsättningsstyrka",
    "undsättningsstyrkorna": "undsättningsstyrka",
    "undsättningsstyrkornas": "undsättningsstyrka",
    "undsättningsstyrkors": "undsättningsstyrka",
    "undsätts": "undsätta",
    "undulantfebern": "undulantfeber",
    "undulantfeberns": "undulantfeber",
    "undulantfebers": "undulantfeber",
    "undulaten": "undulat",
    "undulatens": "undulat",
    "undulater": "undulat",
    "undulaterna": "undulat",
    "undulaternas": "undulat",
    "undulaters": "undulat",
    "undulationen": "undulation",
    "undulationens": "undulation",
    "undulationer": "undulation",
    "undulationerna": "undulation",
    "undulationernas": "undulation",
    "undulationers": "undulation",
    "undulations": "undulation",
    "undulatoriska": "undulatorisk",
    "undulatoriskare": "undulatorisk",
    "undulatoriskares": "undulatorisk",
    "undulatoriskas": "undulatorisk",
    "undulatoriskast": "undulatorisk",
    "undulatoriskaste": "undulatorisk",
    "undulatoriskastes": "undulatorisk",
    "undulatoriskasts": "undulatorisk",
    "undulatoriske": "undulatorisk",
    "undulatoriskes": "undulatorisk",
    "undulatorisks": "undulatorisk",
    "undulatoriskt": "undulatorisk",
    "undulatoriskts": "undulatorisk",
    "undulats": "undulat",
    "undulerade": "undulera",
    "undulerades": "undulera",
    "undulerande": "undulera",
    "unduleranden": "undulerande",
    "undulerandena": "undulerande",
    "undulerandenas": "undulerande",
    "undulerandens": "undulerande",
    "undulerandes": "undulerande",
    "undulerandet": "undulerande",
    "undulerandets": "undulerande",
    "undulerar": "undulera",
    "unduleras": "undulera",
    "undulerat": "undulera",
    "undulerats": "undulera",
    "unduleringar": "undulering",
    "unduleringarna": "undulering",
    "unduleringarnas": "undulering",
    "unduleringars": "undulering",
    "unduleringen": "undulering",
    "unduleringens": "undulering",
    "undulerings": "undulering",
    "undvar": "undvara",
    "undvarade": "undvara",
    "undvarades": "undvara",
    "undvarande": "undvara",
    "undvaranden": "undvarande",
    "undvarandena": "undvarande",
    "undvarandenas": "undvarande",
    "undvarandens": "undvarande",
    "undvarandes": "undvarande",
    "undvarandet": "undvarande",
    "undvarandets": "undvarande",
    "undvarar": "undvara",
    "undvaras": "undvara",
    "undvarat": "undvara",
    "undvarats": "undvara",
    "undvarit": "undvara",
    "undvarits": "undvara",
    "undvek": "undvika",
    "undveks": "undvika",
    "undvik": "undvika",
    "undvikande": "undvika",
    "undvikanden": "undvikande",
    "undvikandena": "undvikande",
    "undvikandenas": "undvikande",
    "undvikandens": "undvikande",
    "undvikandes": "undvikande",
    "undvikandet": "undvikande",
    "undvikandets": "undvikande",
    "undvikas": "undvika",
    "undvike": "undvika",
    "undviken": "undvika",
    "undvikens": "undvika",
    "undviker": "undvika",
    "undvikes": "undvika",
    "undviket": "undvika",
    "undvikets": "undvika",
    "undvikit": "undvika",
    "undvikits": "undvika",
    "undvikna": "undvika",
    "undviknas": "undvika",
    "undvikne": "undvika",
    "undviknes": "undvika",
    "undviks": "undvika",
    "ung": "unge",
    "unga": "ung",
    "ungar": "unge",
    "ungarna": "unge",
    "ungarnas": "unge",
    "ungars": "unge",
    "ungas": "ung",
    "ungdjuren": "ungdjur",
    "ungdjurens": "ungdjur",
    "ungdjuret": "ungdjur",
    "ungdjurets": "ungdjur",
    "ungdjurs": "ungdjur",
    "ungdomar": "ungdom",
    "ungdomarna": "ungdom",
    "ungdomarnas": "ungdom",
    "ungdomars": "ungdom",
    "ungdomen": "ungdom",
    "ungdomens": "ungdom",
    "ungdomliga": "ungdomlig",
    "ungdomligare": "ungdomlig",
    "ungdomligares": "ungdomlig",
    "ungdomligas": "ungdomlig",
    "ungdomligast": "ungdomlig",
    "ungdomligaste": "ungdomlig",
    "ungdomligastes": "ungdomlig",
    "ungdomligasts": "ungdomlig",
    "ungdomlige": "ungdomlig",
    "ungdomliges": "ungdomlig",
    "ungdomligheten": "ungdomlighet",
    "ungdomlighetens": "ungdomlighet",
    "ungdomlighets": "ungdomlighet",
    "ungdomligs": "ungdomlig",
    "ungdomligt": "ungdomlig",
    "ungdomligts": "ungdomlig",
    "ungdoms": "ungdom",
    "ungdomsanstalten": "ungdomsanstalt",
    "ungdomsanstaltens": "ungdomsanstalt",
    "ungdomsanstalter": "ungdomsanstalt",
    "ungdomsanstalterna": "ungdomsanstalt",
    "ungdomsanstalternas": "ungdomsanstalt",
    "ungdomsanstalters": "ungdomsanstalt",
    "ungdomsanstalts": "ungdomsanstalt",
    "ungdomsarbeten": "ungdomsarbete",
    "ungdomsarbetena": "ungdomsarbete",
    "ungdomsarbetenas": "ungdomsarbete",
    "ungdomsarbetens": "ungdomsarbete",
    "ungdomsarbetes": "ungdomsarbete",
    "ungdomsarbetet": "ungdomsarbete",
    "ungdomsarbetets": "ungdomsarbete",
    "ungdomsarbets": "ungdomsarbete",
    "ungdomsarbetslösheten": "ungdomsarbetslöshet",
    "ungdomsarbetslöshetens": "ungdomsarbetslöshet",
    "ungdomsarbetslösheter": "ungdomsarbetslöshet",
    "ungdomsarbetslösheterna": "ungdomsarbetslöshet",
    "ungdomsarbetslösheternas": "ungdomsarbetslöshet",
    "ungdomsarbetslösheters": "ungdomsarbetslöshet",
    "ungdomsarbetslöshets": "ungdomsarbetslöshet",
    "ungdomsboken": "ungdomsbok",
    "ungdomsbokens": "ungdomsbok",
    "ungdomsboks": "ungdomsbok",
    "ungdomsbrottsligheten": "ungdomsbrottslighet",
    "ungdomsbrottslighetens": "ungdomsbrottslighet",
    "ungdomsbrottsligheter": "ungdomsbrottslighet",
    "ungdomsbrottsligheterna": "ungdomsbrottslighet",
    "ungdomsbrottsligheternas": "ungdomsbrottslighet",
    "ungdomsbrottsligheters": "ungdomsbrottslighet",
    "ungdomsbrottslighets": "ungdomsbrottslighet",
    "ungdomsbrottslingar": "ungdomsbrottsling",
    "ungdomsbrottslingarna": "ungdomsbrottsling",
    "ungdomsbrottslingarnas": "ungdomsbrottsling",
    "ungdomsbrottslingars": "ungdomsbrottsling",
    "ungdomsbrottslingen": "ungdomsbrottsling",
    "ungdomsbrottslingens": "ungdomsbrottsling",
    "ungdomsbrottslings": "ungdomsbrottsling",
    "ungdomsböcker": "ungdomsbok",
    "ungdomsböckerna": "ungdomsbok",
    "ungdomsböckernas": "ungdomsbok",
    "ungdomsböckers": "ungdomsbok",
    "ungdomsfilmen": "ungdomsfilm",
    "ungdomsfilmens": "ungdomsfilm",
    "ungdomsfilmer": "ungdomsfilm",
    "ungdomsfilmerna": "ungdomsfilm",
    "ungdomsfilmernas": "ungdomsfilm",
    "ungdomsfilmers": "ungdomsfilm",
    "ungdomsfilms": "ungdomsfilm",
    "ungdomsflam": "ungdomsflamma",
    "ungdomsflamman": "ungdomsflamma",
    "ungdomsflammans": "ungdomsflamma",
    "ungdomsflammas": "ungdomsflamma",
    "ungdomsflamme": "ungdomsflamma",
    "ungdomsflammor": "ungdomsflamma",
    "ungdomsflammorna": "ungdomsflamma",
    "ungdomsflammornas": "ungdomsflamma",
    "ungdomsflammors": "ungdomsflamma",
    "ungdomsflams": "ungdomsflamma",
    "ungdomsfrågan": "ungdomsfråga",
    "ungdomsfrågans": "ungdomsfråga",
    "ungdomsfrågas": "ungdomsfråga",
    "ungdomsfråge": "ungdomsfråga",
    "ungdomsfrågor": "ungdomsfråga",
    "ungdomsfrågorna": "ungdomsfråga",
    "ungdomsfrågornas": "ungdomsfråga",
    "ungdomsfrågors": "ungdomsfråga",
    "ungdomsfyllerier": "ungdomsfylleri",
    "ungdomsfyllerierna": "ungdomsfylleri",
    "ungdomsfylleriernas": "ungdomsfylleri",
    "ungdomsfylleriers": "ungdomsfylleri",
    "ungdomsfylleriet": "ungdomsfylleri",
    "ungdomsfylleriets": "ungdomsfylleri",
    "ungdomsfylleris": "ungdomsfylleri",
    "ungdomsfyllerit": "ungdomsfylleri",
    "ungdomsfyllerits": "ungdomsfylleri",
    "ungdomsfängelser": "ungdomsfängelse",
    "ungdomsfängelserna": "ungdomsfängelse",
    "ungdomsfängelsernas": "ungdomsfängelse",
    "ungdomsfängelsers": "ungdomsfängelse",
    "ungdomsfängelses": "ungdomsfängelse",
    "ungdomsfängelset": "ungdomsfängelse",
    "ungdomsfängelsets": "ungdomsfängelse",
    "ungdomsförbunden": "ungdomsförbund",
    "ungdomsförbundens": "ungdomsförbund",
    "ungdomsförbundet": "ungdomsförbund",
    "ungdomsförbundets": "ungdomsförbund",
    "ungdomsförbunds": "ungdomsförbund",
    "ungdomsförmedlingar": "ungdomsförmedling",
    "ungdomsförmedlingarna": "ungdomsförmedling",
    "ungdomsförmedlingarnas": "ungdomsförmedling",
    "ungdomsförmedlingars": "ungdomsförmedling",
    "ungdomsförmedlingen": "ungdomsförmedling",
    "ungdomsförmedlingens": "ungdomsförmedling",
    "ungdomsförmedlings": "ungdomsförmedling",
    "ungdomsgruppen": "ungdomsgrupp",
    "ungdomsgruppens": "ungdomsgrupp",
    "ungdomsgrupper": "ungdomsgrupp",
    "ungdomsgrupperna": "ungdomsgrupp",
    "ungdomsgruppernas": "ungdomsgrupp",
    "ungdomsgruppers": "ungdomsgrupp",
    "ungdomsgrupps": "ungdomsgrupp",
    "ungdomsgårdar": "ungdomsgård",
    "ungdomsgårdarna": "ungdomsgård",
    "ungdomsgårdarnas": "ungdomsgård",
    "ungdomsgårdars": "ungdomsgård",
    "ungdomsgården": "ungdomsgård",
    "ungdomsgårdens": "ungdomsgård",
    "ungdomsgårds": "ungdomsgård",
    "ungdomshemmen": "ungdomshem",
    "ungdomshemmens": "ungdomshem",
    "ungdomshemmet": "ungdomshem",
    "ungdomshemmets": "ungdomshem",
    "ungdomshems": "ungdomshem",
    "ungdomskonsulenten": "ungdomskonsulent",
    "ungdomskonsulentens": "ungdomskonsulent",
    "ungdomskonsulenter": "ungdomskonsulent",
    "ungdomskonsulenterna": "ungdomskonsulent",
    "ungdomskonsulenternas": "ungdomskonsulent",
    "ungdomskonsulenters": "ungdomskonsulent",
    "ungdomskonsulents": "ungdomskonsulent",
    "ungdomskulturen": "ungdomskultur",
    "ungdomskulturens": "ungdomskultur",
    "ungdomskulturer": "ungdomskultur",
    "ungdomskulturerna": "ungdomskultur",
    "ungdomskulturernas": "ungdomskultur",
    "ungdomskulturers": "ungdomskultur",
    "ungdomskulturs": "ungdomskultur",
    "ungdomskäll": "ungdomskälla",
    "ungdomskällan": "ungdomskälla",
    "ungdomskällans": "ungdomskälla",
    "ungdomskällas": "ungdomskälla",
    "ungdomskälle": "ungdomskälla",
    "ungdomskällor": "ungdomskälla",
    "ungdomskällorna": "ungdomskälla",
    "ungdomskällornas": "ungdomskälla",
    "ungdomskällors": "ungdomskälla",
    "ungdomskälls": "ungdomskälla",
    "ungdomskärlekar": "ungdomskärlek",
    "ungdomskärlekarna": "ungdomskärlek",
    "ungdomskärlekarnas": "ungdomskärlek",
    "ungdomskärlekars": "ungdomskärlek",
    "ungdomskärleken": "ungdomskärlek",
    "ungdomskärlekens": "ungdomskärlek",
    "ungdomskärleks": "ungdomskärlek",
    "ungdomsledar": "ungdomsledare",
    "ungdomsledaren": "ungdomsledare",
    "ungdomsledarens": "ungdomsledare",
    "ungdomsledares": "ungdomsledare",
    "ungdomsledarna": "ungdomsledare",
    "ungdomsledarnas": "ungdomsledare",
    "ungdomsorganisationen": "ungdomsorganisation",
    "ungdomsorganisationens": "ungdomsorganisation",
    "ungdomsorganisationer": "ungdomsorganisation",
    "ungdomsorganisationerna": "ungdomsorganisation",
    "ungdomsorganisationernas": "ungdomsorganisation",
    "ungdomsorganisationers": "ungdomsorganisation",
    "ungdomsorganisations": "ungdomsorganisation",
    "ungdomspolisen": "ungdomspolis",
    "ungdomspolisens": "ungdomspolis",
    "ungdomspolitiken": "ungdomspolitik",
    "ungdomspolitikens": "ungdomspolitik",
    "ungdomspolitiks": "ungdomspolitik",
    "ungdomspolitiska": "ungdomspolitisk",
    "ungdomspolitiskas": "ungdomspolitisk",
    "ungdomspolitiske": "ungdomspolitisk",
    "ungdomspolitiskes": "ungdomspolitisk",
    "ungdomspolitisks": "ungdomspolitisk",
    "ungdomspolitiskt": "ungdomspolitisk",
    "ungdomspolitiskts": "ungdomspolitisk",
    "ungdomsråden": "ungdomsråd",
    "ungdomsrådens": "ungdomsråd",
    "ungdomsrådet": "ungdomsråd",
    "ungdomsrådets": "ungdomsråd",
    "ungdomsråds": "ungdomsråd",
    "ungdomsrörelsen": "ungdomsrörelse",
    "ungdomsrörelsens": "ungdomsrörelse",
    "ungdomsrörelser": "ungdomsrörelse",
    "ungdomsrörelserna": "ungdomsrörelse",
    "ungdomsrörelsernas": "ungdomsrörelse",
    "ungdomsrörelsers": "ungdomsrörelse",
    "ungdomsrörelses": "ungdomsrörelse",
    "ungdomsskolan": "ungdomsskola",
    "ungdomsskolans": "ungdomsskola",
    "ungdomsskolas": "ungdomsskola",
    "ungdomsskole": "ungdomsskola",
    "ungdomsskolor": "ungdomsskola",
    "ungdomsskolorna": "ungdomsskola",
    "ungdomsskolornas": "ungdomsskola",
    "ungdomsskolors": "ungdomsskola",
    "ungdomssvärmerier": "ungdomssvärmeri",
    "ungdomssvärmerierna": "ungdomssvärmeri",
    "ungdomssvärmeriernas": "ungdomssvärmeri",
    "ungdomssvärmeriers": "ungdomssvärmeri",
    "ungdomssvärmeriet": "ungdomssvärmeri",
    "ungdomssvärmeriets": "ungdomssvärmeri",
    "ungdomssvärmeris": "ungdomssvärmeri",
    "ungdomssvärmerit": "ungdomssvärmeri",
    "ungdomssvärmerits": "ungdomssvärmeri",
    "ungdomssynden": "ungdomssynd",
    "ungdomssyndens": "ungdomssynd",
    "ungdomssynder": "ungdomssynd",
    "ungdomssynderna": "ungdomssynd",
    "ungdomssyndernas": "ungdomssynd",
    "ungdomssynders": "ungdomssynd",
    "ungdomssynds": "ungdomssynd",
    "ungdomstiden": "ungdomstid",
    "ungdomstidens": "ungdomstid",
    "ungdomstider": "ungdomstid",
    "ungdomstiderna": "ungdomstid",
    "ungdomstidernas": "ungdomstid",
    "ungdomstiders": "ungdomstid",
    "ungdomstids": "ungdomstid",
    "ungdomsverken": "ungdomsverk",
    "ungdomsverkens": "ungdomsverk",
    "ungdomsverket": "ungdomsverk",
    "ungdomsverkets": "ungdomsverk",
    "ungdomsverks": "ungdomsverk",
    "ungdomsverksamheten": "ungdomsverksamhet",
    "ungdomsverksamhetens": "ungdomsverksamhet",
    "ungdomsverksamheter": "ungdomsverksamhet",
    "ungdomsverksamheterna": "ungdomsverksamhet",
    "ungdomsverksamheternas": "ungdomsverksamhet",
    "ungdomsverksamheters": "ungdomsverksamhet",
    "ungdomsverksamhets": "ungdomsverksamhet",
    "ungdomsväljar": "ungdomsväljare",
    "ungdomsväljaren": "ungdomsväljare",
    "ungdomsväljarens": "ungdomsväljare",
    "ungdomsväljares": "ungdomsväljare",
    "ungdomsväljarna": "ungdomsväljare",
    "ungdomsväljarnas": "ungdomsväljare",
    "ungdomsvännen": "ungdomsvän",
    "ungdomsvännens": "ungdomsvän",
    "ungdomsvänner": "ungdomsvän",
    "ungdomsvännerna": "ungdomsvän",
    "ungdomsvännernas": "ungdomsvän",
    "ungdomsvänners": "ungdomsvän",
    "ungdomsväns": "ungdomsvän",
    "ungdomsvården": "ungdomsvård",
    "ungdomsvårdens": "ungdomsvård",
    "ungdomsvårds": "ungdomsvård",
    "ungdomsvårdsskolan": "ungdomsvårdsskola",
    "ungdomsvårdsskolans": "ungdomsvårdsskola",
    "ungdomsvårdsskolas": "ungdomsvårdsskola",
    "ungdomsvårdsskole": "ungdomsvårdsskola",
    "ungdomsvårdsskolor": "ungdomsvårdsskola",
    "ungdomsvårdsskolorna": "ungdomsvårdsskola",
    "ungdomsvårdsskolornas": "ungdomsvårdsskola",
    "ungdomsvårdsskolors": "ungdomsvårdsskola",
    "ungdomsåren": "ungdomsår",
    "ungdomsårens": "ungdomsår",
    "ungdomsåret": "ungdomsår",
    "ungdomsårets": "ungdomsår",
    "ungdomsårs": "ungdomsår",
    "unge": "ung",
    "ungefärliga": "ungefärlig",
    "ungefärligare": "ungefärlig",
    "ungefärligares": "ungefärlig",
    "ungefärligas": "ungefärlig",
    "ungefärligast": "ungefärlig",
    "ungefärligaste": "ungefärlig",
    "ungefärligastes": "ungefärlig",
    "ungefärligasts": "ungefärlig",
    "ungefärlige": "ungefärlig",
    "ungefärliges": "ungefärlig",
    "ungefärligheten": "ungefärlighet",
    "ungefärlighetens": "ungefärlighet",
    "ungefärlighets": "ungefärlighet",
    "ungefärligs": "ungefärlig",
    "ungefärligt": "ungefärlig",
    "ungefärligts": "ungefärlig",
    "ungen": "unge",
    "ungens": "unge",
    "ungersk": "ungerska",
    "ungerska": "ungersk",
    "ungerskan": "ungerska",
    "ungerskans": "ungerska",
    "ungerskare": "ungersk",
    "ungerskares": "ungersk",
    "ungerskas": "ungerska",
    "ungerskast": "ungersk",
    "ungerskaste": "ungersk",
    "ungerskastes": "ungersk",
    "ungerskasts": "ungersk",
    "ungerske": "ungerska",
    "ungerskes": "ungersk",
    "ungerskor": "ungerska",
    "ungerskorna": "ungerska",
    "ungerskornas": "ungerska",
    "ungerskors": "ungerska",
    "ungersks": "ungersk",
    "ungerskt": "ungersk",
    "ungerskts": "ungersk",
    "ungersvennen": "ungersven",
    "ungersvennens": "ungersven",
    "ungersvenner": "ungersven",
    "ungersvennerna": "ungersven",
    "ungersvennernas": "ungersven",
    "ungersvenners": "ungersven",
    "ungersvens": "ungersven",
    "unges": "unge",
    "ungflicksaktiga": "ungflicksaktig",
    "ungflicksaktigare": "ungflicksaktig",
    "ungflicksaktigares": "ungflicksaktig",
    "ungflicksaktigas": "ungflicksaktig",
    "ungflicksaktigast": "ungflicksaktig",
    "ungflicksaktigaste": "ungflicksaktig",
    "ungflicksaktigastes": "ungflicksaktig",
    "ungflicksaktigasts": "ungflicksaktig",
    "ungflicksaktige": "ungflicksaktig",
    "ungflicksaktiges": "ungflicksaktig",
    "ungflicksaktigheten": "ungflicksaktighet",
    "ungflicksaktighetens": "ungflicksaktighet",
    "ungflicksaktighets": "ungflicksaktighet",
    "ungflicksaktigs": "ungflicksaktig",
    "ungflicksaktigt": "ungflicksaktig",
    "ungflicksaktigts": "ungflicksaktig",
    "ungherr": "ungherre",
    "ungherrar": "ungherre",
    "ungherrarna": "ungherre",
    "ungherrarnas": "ungherre",
    "ungherrars": "ungherre",
    "ungherren": "ungherre",
    "ungherrens": "ungherre",
    "ungherres": "ungherre",
    "ungherrs": "ungherre",
    "unghästar": "unghäst",
    "unghästarna": "unghäst",
    "unghästarnas": "unghäst",
    "unghästars": "unghäst",
    "unghästen": "unghäst",
    "unghästens": "unghäst",
    "unghästs": "unghäst",
    "ungkarlar": "ungkarl",
    "ungkarlarna": "ungkarl",
    "ungkarlarnas": "ungkarl",
    "ungkarlars": "ungkarl",
    "ungkarlen": "ungkarl",
    "ungkarlens": "ungkarl",
    "ungkarls": "ungkarl",
    "ungkarlsflick": "ungkarlsflicka",
    "ungkarlsflickan": "ungkarlsflicka",
    "ungkarlsflickans": "ungkarlsflicka",
    "ungkarlsflickas": "ungkarlsflicka",
    "ungkarlsflicke": "ungkarlsflicka",
    "ungkarlsflickor": "ungkarlsflicka",
    "ungkarlsflickorna": "ungkarlsflicka",
    "ungkarlsflickornas": "ungkarlsflicka",
    "ungkarlsflickors": "ungkarlsflicka",
    "ungkarlsflicks": "ungkarlsflicka",
    "ungkarlshotellen": "ungkarlshotell",
    "ungkarlshotellens": "ungkarlshotell",
    "ungkarlshotellet": "ungkarlshotell",
    "ungkarlshotellets": "ungkarlshotell",
    "ungkarlshotells": "ungkarlshotell",
    "ungkarlslivet": "ungkarlsliv",
    "ungkarlslivets": "ungkarlsliv",
    "ungkarlslivs": "ungkarlsliv",
    "ungkarlsvanan": "ungkarlsvana",
    "ungkarlsvanans": "ungkarlsvana",
    "ungkarlsvanas": "ungkarlsvana",
    "ungkarlsvane": "ungkarlsvana",
    "ungkarlsvanor": "ungkarlsvana",
    "ungkarlsvanorna": "ungkarlsvana",
    "ungkarlsvanornas": "ungkarlsvana",
    "ungkarlsvanors": "ungkarlsvana",
    "ungkommunisten": "ungkommunist",
    "ungkommunistens": "ungkommunist",
    "ungkommunister": "ungkommunist",
    "ungkommunisterna": "ungkommunist",
    "ungkommunisternas": "ungkommunist",
    "ungkommunisters": "ungkommunist",
    "ungkommunists": "ungkommunist",
    "ungkyrkliga": "ungkyrklig",
    "ungkyrkligare": "ungkyrklig",
    "ungkyrkligares": "ungkyrklig",
    "ungkyrkligas": "ungkyrklig",
    "ungkyrkligast": "ungkyrklig",
    "ungkyrkligaste": "ungkyrklig",
    "ungkyrkligastes": "ungkyrklig",
    "ungkyrkligasts": "ungkyrklig",
    "ungkyrklige": "ungkyrklig",
    "ungkyrkliges": "ungkyrklig",
    "ungkyrkligheten": "ungkyrklighet",
    "ungkyrklighetens": "ungkyrklighet",
    "ungkyrklighets": "ungkyrklighet",
    "ungkyrkligs": "ungkyrklig",
    "ungkyrkligt": "ungkyrklig",
    "ungkyrkligts": "ungkyrklig",
    "ungkyrkorörelsen": "ungkyrkorörelse",
    "ungkyrkorörelsens": "ungkyrkorörelse",
    "ungkyrkorörelses": "ungkyrkorörelse",
    "unglott": "unglotta",
    "unglottan": "unglotta",
    "unglottans": "unglotta",
    "unglottas": "unglotta",
    "unglotte": "unglotta",
    "unglottor": "unglotta",
    "unglottorna": "unglotta",
    "unglottornas": "unglotta",
    "unglottors": "unglotta",
    "unglotts": "unglotta",
    "ungmoder": "ungmor",
    "ungmodern": "ungmor",
    "ungmoderns": "ungmor",
    "ungmoders": "ungmor",
    "ungmors": "ungmor",
    "ungmödrar": "ungmor",
    "ungmödrarna": "ungmor",
    "ungmödrarnas": "ungmor",
    "ungmödrars": "ungmor",
    "ungmön": "ungmö",
    "ungmöns": "ungmö",
    "ungmör": "ungmö",
    "ungmörna": "ungmö",
    "ungmörnas": "ungmö",
    "ungmörs": "ungmö",
    "ungmös": "ungmö",
    "ungnöten": "ungnöt",
    "ungnötens": "ungnöt",
    "ungnötet": "ungnöt",
    "ungnötets": "ungnöt",
    "ungnöts": "ungnöt",
    "ungrar": "ungrare",
    "ungraren": "ungrare",
    "ungrarens": "ungrare",
    "ungrares": "ungrare",
    "ungrarna": "ungrare",
    "ungrarnas": "ungrare",
    "ungrenässansen": "ungrenässans",
    "ungrenässansens": "ungrenässans",
    "ungs": "unge",
    "ungskogar": "ungskog",
    "ungskogarna": "ungskog",
    "ungskogarnas": "ungskog",
    "ungskogars": "ungskog",
    "ungskogen": "ungskog",
    "ungskogens": "ungskog",
    "ungskogs": "ungskog",
    "ungsocialismen": "ungsocialism",
    "ungsocialismens": "ungsocialism",
    "ungsocialismer": "ungsocialism",
    "ungsocialismerna": "ungsocialism",
    "ungsocialismernas": "ungsocialism",
    "ungsocialismers": "ungsocialism",
    "ungsocialisms": "ungsocialism",
    "ungsocialistiska": "ungsocialistisk",
    "ungsocialistiskas": "ungsocialistisk",
    "ungsocialistiske": "ungsocialistisk",
    "ungsocialistiskes": "ungsocialistisk",
    "ungsocialistisks": "ungsocialistisk",
    "ungsocialistiskt": "ungsocialistisk",
    "ungsocialistiskts": "ungsocialistisk",
    "ungstadie": "ungstadium",
    "ungstadier": "ungstadium",
    "ungstadierna": "ungstadium",
    "ungstadiernas": "ungstadium",
    "ungstadiers": "ungstadium",
    "ungstadiet": "ungstadium",
    "ungstadiets": "ungstadium",
    "ungstadiums": "ungstadium",
    "ungsugg": "ungsugga",
    "ungsuggan": "ungsugga",
    "ungsuggans": "ungsugga",
    "ungsuggas": "ungsugga",
    "ungsugge": "ungsugga",
    "ungsuggor": "ungsugga",
    "ungsuggorna": "ungsugga",
    "ungsuggornas": "ungsugga",
    "ungsuggors": "ungsugga",
    "ungsuggs": "ungsugga",
    "ungsvenska": "ungsvensk",
    "ungsvenskar": "ungsvensk",
    "ungsvenskare": "ungsvensk",
    "ungsvenskares": "ungsvensk",
    "ungsvenskarna": "ungsvensk",
    "ungsvenskarnas": "ungsvensk",
    "ungsvenskars": "ungsvensk",
    "ungsvenskas": "ungsvensk",
    "ungsvenskast": "ungsvensk",
    "ungsvenskaste": "ungsvensk",
    "ungsvenskastes": "ungsvensk",
    "ungsvenskasts": "ungsvensk",
    "ungsvenske": "ungsvensk",
    "ungsvensken": "ungsvensk",
    "ungsvenskens": "ungsvensk",
    "ungsvenskes": "ungsvensk",
    "ungsvensks": "ungsvensk",
    "ungsvenskt": "ungsvensk",
    "ungsvenskts": "ungsvensk",
    "ungt": "ung",
    "ungtallar": "ungtall",
    "ungtallarna": "ungtall",
    "ungtallarnas": "ungtall",
    "ungtallars": "ungtall",
    "ungtallen": "ungtall",
    "ungtallens": "ungtall",
    "ungtalls": "ungtall",
    "ungts": "ung",
    "ungtuppar": "ungtupp",
    "ungtupparna": "ungtupp",
    "ungtupparnas": "ungtupp",
    "ungtuppars": "ungtupp",
    "ungtuppen": "ungtupp",
    "ungtuppens": "ungtupp",
    "ungtupps": "ungtupp",
    "ungturkar": "ungturk",
    "ungturkarna": "ungturk",
    "ungturkarnas": "ungturk",
    "ungturkars": "ungturk",
    "ungturken": "ungturk",
    "ungturkens": "ungturk",
    "ungturks": "ungturk",
    "unifierad": "unifiera",
    "unifierade": "unifiera",
    "unifierades": "unifiera",
    "unifierads": "unifiera",
    "unifierande": "unifiera",
    "unifieranden": "unifierande",
    "unifierandena": "unifierande",
    "unifierandenas": "unifierande",
    "unifierandens": "unifierande",
    "unifierandes": "unifierande",
    "unifierandet": "unifierande",
    "unifierandets": "unifierande",
    "unifierar": "unifiera",
    "unifieras": "unifiera",
    "unifierat": "unifiera",
    "unifierats": "unifiera",
    "unifierbara": "unifierbar",
    "unifierbarare": "unifierbar",
    "unifierbarares": "unifierbar",
    "unifierbaras": "unifierbar",
    "unifierbarast": "unifierbar",
    "unifierbaraste": "unifierbar",
    "unifierbarastes": "unifierbar",
    "unifierbarasts": "unifierbar",
    "unifierbare": "unifierbar",
    "unifierbares": "unifierbar",
    "unifierbarheten": "unifierbarhet",
    "unifierbarhetens": "unifierbarhet",
    "unifierbarhets": "unifierbarhet",
    "unifierbars": "unifierbar",
    "unifierbart": "unifierbar",
    "unifierbarts": "unifierbar",
    "unifieringar": "unifiering",
    "unifieringarna": "unifiering",
    "unifieringarnas": "unifiering",
    "unifieringars": "unifiering",
    "unifieringen": "unifiering",
    "unifieringens": "unifiering",
    "unifierings": "unifiering",
    "uniforma": "uniform",
    "uniformare": "uniform",
    "uniformares": "uniform",
    "uniformas": "uniform",
    "uniformast": "uniform",
    "uniformaste": "uniform",
    "uniformastes": "uniform",
    "uniformasts": "uniform",
    "uniforme": "uniform",
    "uniformen": "uniform",
    "uniformens": "uniform",
    "uniformer": "uniform",
    "uniformerad": "uniformera",
    "uniformerade": "uniformerad",
    "uniformerades": "uniformerad",
    "uniformerads": "uniformerad",
    "uniformerande": "uniformera",
    "uniformeranden": "uniformerande",
    "uniformerandena": "uniformerande",
    "uniformerandenas": "uniformerande",
    "uniformerandens": "uniformerande",
    "uniformerandes": "uniformerande",
    "uniformerandet": "uniformerande",
    "uniformerandets": "uniformerande",
    "uniformerar": "uniformera",
    "uniformeras": "uniformera",
    "uniformerat": "uniformerad",
    "uniformerats": "uniformerad",
    "uniformerbara": "uniformerbar",
    "uniformerbarare": "uniformerbar",
    "uniformerbarares": "uniformerbar",
    "uniformerbaras": "uniformerbar",
    "uniformerbarast": "uniformerbar",
    "uniformerbaraste": "uniformerbar",
    "uniformerbarastes": "uniformerbar",
    "uniformerbarasts": "uniformerbar",
    "uniformerbare": "uniformerbar",
    "uniformerbares": "uniformerbar",
    "uniformerbarheten": "uniformerbarhet",
    "uniformerbarhetens": "uniformerbarhet",
    "uniformerbarhets": "uniformerbarhet",
    "uniformerbars": "uniformerbar",
    "uniformerbart": "uniformerbar",
    "uniformerbarts": "uniformerbar",
    "uniformeringar": "uniformering",
    "uniformeringarna": "uniformering",
    "uniformeringarnas": "uniformering",
    "uniformeringars": "uniformering",
    "uniformeringen": "uniformering",
    "uniformeringens": "uniformering",
    "uniformerings": "uniformering",
    "uniformerna": "uniform",
    "uniformernas": "uniform",
    "uniformers": "uniform",
    "uniformes": "uniform",
    "uniformheten": "uniformhet",
    "uniformhetens": "uniformhet",
    "uniformhets": "uniformhet",
    "uniformiteten": "uniformitet",
    "uniformitetens": "uniformitet",
    "uniformiteter": "uniformitet",
    "uniformiteterna": "uniformitet",
    "uniformiteternas": "uniformitet",
    "uniformiteters": "uniformitet",
    "uniformitets": "uniformitet",
    "uniforms": "uniform",
    "uniformsbeteckningar": "uniformsbeteckning",
    "uniformsbeteckningarna": "uniformsbeteckning",
    "uniformsbeteckningarnas": "uniformsbeteckning",
    "uniformsbeteckningars": "uniformsbeteckning",
    "uniformsbeteckningen": "uniformsbeteckning",
    "uniformsbeteckningens": "uniformsbeteckning",
    "uniformsbetecknings": "uniformsbeteckning",
    "uniformsbyx": "uniformsbyxa",
    "uniformsbyxan": "uniformsbyxa",
    "uniformsbyxans": "uniformsbyxa",
    "uniformsbyxas": "uniformsbyxa",
    "uniformsbyxe": "uniformsbyxa",
    "uniformsbyxor": "uniformsbyxa",
    "uniformsbyxorna": "uniformsbyxa",
    "uniformsbyxornas": "uniformsbyxa",
    "uniformsbyxors": "uniformsbyxa",
    "uniformseffekterna": "uniformseffekter",
    "uniformseffekternas": "uniformseffekter",
    "uniformseffekters": "uniformseffekter",
    "uniformseffekts": "uniformseffekter",
    "uniformshattar": "uniformshatt",
    "uniformshattarna": "uniformshatt",
    "uniformshattarnas": "uniformshatt",
    "uniformshattars": "uniformshatt",
    "uniformshatten": "uniformshatt",
    "uniformshattens": "uniformshatt",
    "uniformshatts": "uniformshatt",
    "uniformsjack": "uniformsjacka",
    "uniformsjackan": "uniformsjacka",
    "uniformsjackans": "uniformsjacka",
    "uniformsjackas": "uniformsjacka",
    "uniformsjacke": "uniformsjacka",
    "uniformsjackor": "uniformsjacka",
    "uniformsjackorna": "uniformsjacka",
    "uniformsjackornas": "uniformsjacka",
    "uniformsjackors": "uniformsjacka",
    "uniformsjacks": "uniformsjacka",
    "uniformsknappar": "uniformsknapp",
    "uniformsknapparna": "uniformsknapp",
    "uniformsknapparnas": "uniformsknapp",
    "uniformsknappars": "uniformsknapp",
    "uniformsknappen": "uniformsknapp",
    "uniformsknappens": "uniformsknapp",
    "uniformsknapps": "uniformsknapp",
    "uniformsmöss": "uniformsmössa",
    "uniformsmössan": "uniformsmössa",
    "uniformsmössans": "uniformsmössa",
    "uniformsmössas": "uniformsmössa",
    "uniformsmösse": "uniformsmössa",
    "uniformsmössor": "uniformsmössa",
    "uniformsmössorna": "uniformsmössa",
    "uniformsmössornas": "uniformsmössa",
    "uniformsmössors": "uniformsmössa",
    "uniformsplikten": "uniformsplikt",
    "uniformspliktens": "uniformsplikt",
    "uniformsplikts": "uniformsplikt",
    "uniformsrockar": "uniformsrock",
    "uniformsrockarna": "uniformsrock",
    "uniformsrockarnas": "uniformsrock",
    "uniformsrockars": "uniformsrock",
    "uniformsrocken": "uniformsrock",
    "uniformsrockens": "uniformsrock",
    "uniformsrocks": "uniformsrock",
    "uniformssnör": "uniformssnöre",
    "uniformssnören": "uniformssnöre",
    "uniformssnörena": "uniformssnöre",
    "uniformssnörenas": "uniformssnöre",
    "uniformssnörens": "uniformssnöre",
    "uniformssnöres": "uniformssnöre",
    "uniformssnöret": "uniformssnöre",
    "uniformssnörets": "uniformssnöre",
    "uniformssnörs": "uniformssnöre",
    "uniformsteckens": "uniformstecken",
    "uniformstecknen": "uniformstecken",
    "uniformstecknens": "uniformstecken",
    "uniformstecknet": "uniformstecken",
    "uniformstecknets": "uniformstecken",
    "uniformt": "uniform",
    "uniformts": "uniform",
    "unigrammen": "unigram",
    "unigrammens": "unigram",
    "unigrammet": "unigram",
    "unigrammets": "unigram",
    "unigrams": "unigram",
    "unik": "unika",
    "unika": "unikum",
    "unikaboxar": "unikabox",
    "unikaboxarna": "unikabox",
    "unikaboxarnas": "unikabox",
    "unikaboxars": "unikabox",
    "unikaboxen": "unikabox",
    "unikaboxens": "unikabox",
    "unikan": "unika",
    "unikans": "unika",
    "unikare": "unik",
    "unikares": "unik",
    "unikas": "unikum",
    "unikast": "unik",
    "unikaste": "unik",
    "unikastes": "unik",
    "unikasts": "unik",
    "unikaten": "unikat",
    "unikatens": "unikat",
    "unikatet": "unikat",
    "unikatets": "unikat",
    "unikats": "unikat",
    "unike": "unika",
    "unikes": "unik",
    "unikor": "unika",
    "unikorna": "unika",
    "unikornas": "unika",
    "unikors": "unika",
    "uniks": "unika",
    "unikt": "unik",
    "unikts": "unik",
    "unikumen": "unikum",
    "unikumens": "unikum",
    "unikumet": "unikum",
    "unikumets": "unikum",
    "unikums": "unikum",
    "unilaterala": "unilateral",
    "unilateralare": "unilateral",
    "unilateralares": "unilateral",
    "unilateralas": "unilateral",
    "unilateralast": "unilateral",
    "unilateralaste": "unilateral",
    "unilateralastes": "unilateral",
    "unilateralasts": "unilateral",
    "unilaterale": "unilateral",
    "unilaterales": "unilateral",
    "unilaterals": "unilateral",
    "unilateralt": "unilateral",
    "unilateralts": "unilateral",
    "unionella": "unionell",
    "unionellare": "unionell",
    "unionellares": "unionell",
    "unionellas": "unionell",
    "unionellast": "unionell",
    "unionellaste": "unionell",
    "unionellastes": "unionell",
    "unionellasts": "unionell",
    "unionelle": "unionell",
    "unionelles": "unionell",
    "unionells": "unionell",
    "unionellt": "unionell",
    "unionellts": "unionell",
    "unionen": "union",
    "unionens": "union",
    "unioner": "union",
    "unionerna": "union",
    "unionernas": "union",
    "unioners": "union",
    "unions": "union",
    "unionsbrotten": "unionsbrott",
    "unionsbrottens": "unionsbrott",
    "unionsbrottet": "unionsbrott",
    "unionsbrottets": "unionsbrott",
    "unionsbrotts": "unionsbrott",
    "unisexoverallen": "unisexoverall",
    "unisexoverallens": "unisexoverall",
    "unisexoveraller": "unisexoverall",
    "unisexoverallerna": "unisexoverall",
    "unisexoverallernas": "unisexoverall",
    "unisexoverallers": "unisexoverall",
    "unisexoveralls": "unisexoverall",
    "unisona": "unison",
    "unisonare": "unison",
    "unisonares": "unison",
    "unisonas": "unison",
    "unisonast": "unison",
    "unisonaste": "unison",
    "unisonastes": "unison",
    "unisonasts": "unison",
    "unisone": "unison",
    "unisones": "unison",
    "unisons": "unison",
    "unisont": "unison",
    "unisonts": "unison",
    "unitarien": "unitarie",
    "unitariens": "unitarie",
    "unitarier": "unitarie",
    "unitarierna": "unitarie",
    "unitariernas": "unitarie",
    "unitariers": "unitarie",
    "unitaries": "unitarie",
    "unitariska": "unitarisk",
    "unitariskare": "unitarisk",
    "unitariskares": "unitarisk",
    "unitariskas": "unitarisk",
    "unitariskast": "unitarisk",
    "unitariskaste": "unitarisk",
    "unitariskastes": "unitarisk",
    "unitariskasts": "unitarisk",
    "unitariske": "unitarisk",
    "unitariskes": "unitarisk",
    "unitarisks": "unitarisk",
    "unitariskt": "unitarisk",
    "unitariskts": "unitarisk",
    "unitarismen": "unitarism",
    "unitarismens": "unitarism",
    "unitarismer": "unitarism",
    "unitarismerna": "unitarism",
    "unitarismernas": "unitarism",
    "unitarismers": "unitarism",
    "unitarisms": "unitarism",
    "unitaristen": "unitarist",
    "unitaristens": "unitarist",
    "unitarister": "unitarist",
    "unitaristerna": "unitarist",
    "unitaristernas": "unitarist",
    "unitaristers": "unitarist",
    "unitaristiska": "unitaristisk",
    "unitaristiskas": "unitaristisk",
    "unitaristiske": "unitaristisk",
    "unitaristiskes": "unitaristisk",
    "unitaristisks": "unitaristisk",
    "unitaristiskt": "unitaristisk",
    "unitaristiskts": "unitaristisk",
    "unitarists": "unitarist",
    "universalarvingar": "universalarvinge",
    "universalarvingarna": "universalarvinge",
    "universalarvingarnas": "universalarvinge",
    "universalarvingars": "universalarvinge",
    "universalarvingen": "universalarvinge",
    "universalarvingens": "universalarvinge",
    "universalarvinges": "universalarvinge",
    "universalbegreppen": "universalbegrepp",
    "universalbegreppens": "universalbegrepp",
    "universalbegreppet": "universalbegrepp",
    "universalbegreppets": "universalbegrepp",
    "universalbegrepps": "universalbegrepp",
    "universalbegåvningar": "universalbegåvning",
    "universalbegåvningarna": "universalbegåvning",
    "universalbegåvningarnas": "universalbegåvning",
    "universalbegåvningars": "universalbegåvning",
    "universalbegåvningen": "universalbegåvning",
    "universalbegåvningens": "universalbegåvning",
    "universalbegåvnings": "universalbegåvning",
    "universalborrar": "universalborr",
    "universalborrarna": "universalborr",
    "universalborrarnas": "universalborr",
    "universalborrars": "universalborr",
    "universalborren": "universalborr",
    "universalborrens": "universalborr",
    "universalborret": "universalborr",
    "universalborrets": "universalborr",
    "universalborrs": "universalborr",
    "universalismen": "universalism",
    "universalismens": "universalism",
    "universalismer": "universalism",
    "universalismerna": "universalism",
    "universalismernas": "universalism",
    "universalismers": "universalism",
    "universalisms": "universalism",
    "universalisten": "universalist",
    "universalistens": "universalist",
    "universalister": "universalist",
    "universalisterna": "universalist",
    "universalisternas": "universalist",
    "universalisters": "universalist",
    "universalistiska": "universalistisk",
    "universalistiskare": "universalistisk",
    "universalistiskares": "universalistisk",
    "universalistiskas": "universalistisk",
    "universalistiskast": "universalistisk",
    "universalistiskaste": "universalistisk",
    "universalistiskastes": "universalistisk",
    "universalistiskasts": "universalistisk",
    "universalistiske": "universalistisk",
    "universalistiskes": "universalistisk",
    "universalistisks": "universalistisk",
    "universalistiskt": "universalistisk",
    "universalistiskts": "universalistisk",
    "universalists": "universalist",
    "universaliteten": "universalitet",
    "universalitetens": "universalitet",
    "universaliteter": "universalitet",
    "universaliteterna": "universalitet",
    "universaliteternas": "universalitet",
    "universaliteters": "universalitet",
    "universalitets": "universalitet",
    "universalkart": "universalkarta",
    "universalkartan": "universalkarta",
    "universalkartans": "universalkarta",
    "universalkartas": "universalkarta",
    "universalkarte": "universalkarta",
    "universalkartor": "universalkarta",
    "universalkartorna": "universalkarta",
    "universalkartornas": "universalkarta",
    "universalkartors": "universalkarta",
    "universalkarts": "universalkarta",
    "universalknivar": "universalkniv",
    "universalknivarna": "universalkniv",
    "universalknivarnas": "universalkniv",
    "universalknivars": "universalkniv",
    "universalkniven": "universalkniv",
    "universalknivens": "universalkniv",
    "universalknivs": "universalkniv",
    "universalknutar": "universalknut",
    "universalknutarna": "universalknut",
    "universalknutarnas": "universalknut",
    "universalknutars": "universalknut",
    "universalknuten": "universalknut",
    "universalknutens": "universalknut",
    "universalknuts": "universalknut",
    "universalmedels": "universalmedel",
    "universalmedlen": "universalmedel",
    "universalmedlens": "universalmedel",
    "universalmedlet": "universalmedel",
    "universalmedlets": "universalmedel",
    "universalsilikonen": "universalsilikon",
    "universalsilikonens": "universalsilikon",
    "universalsilikoner": "universalsilikon",
    "universalsilikonerna": "universalsilikon",
    "universalsilikonernas": "universalsilikon",
    "universalsilikoners": "universalsilikon",
    "universalsilikons": "universalsilikon",
    "universalsnillen": "universalsnille",
    "universalsnillena": "universalsnille",
    "universalsnillenas": "universalsnille",
    "universalsnillens": "universalsnille",
    "universalsnilles": "universalsnille",
    "universalsnillet": "universalsnille",
    "universalsnillets": "universalsnille",
    "universalsnills": "universalsnille",
    "universaltiden": "universaltid",
    "universaltidens": "universaltid",
    "universaltids": "universaltid",
    "universella": "universell",
    "universellare": "universell",
    "universellares": "universell",
    "universellas": "universell",
    "universellast": "universell",
    "universellaste": "universell",
    "universellastes": "universell",
    "universellasts": "universell",
    "universelle": "universell",
    "universelles": "universell",
    "universells": "universell",
    "universellt": "universell",
    "universellts": "universell",
    "universiteten": "universitet",
    "universitetens": "universitet",
    "universitetet": "universitet",
    "universitetets": "universitet",
    "universitets": "universitet",
    "universitetsadjunkten": "universitetsadjunkt",
    "universitetsadjunktens": "universitetsadjunkt",
    "universitetsadjunkter": "universitetsadjunkt",
    "universitetsadjunkterna": "universitetsadjunkt",
    "universitetsadjunkternas": "universitetsadjunkt",
    "universitetsadjunkters": "universitetsadjunkt",
    "universitetsadjunkts": "universitetsadjunkt",
    "universitetsbiblioteken": "universitetsbibliotek",
    "universitetsbibliotekens": "universitetsbibliotek",
    "universitetsbiblioteket": "universitetsbibliotek",
    "universitetsbibliotekets": "universitetsbibliotek",
    "universitetsbiblioteks": "universitetsbibliotek",
    "universitetsbokhandeln": "universitetsbokhandel",
    "universitetsbokhandelns": "universitetsbokhandel",
    "universitetsbokhandels": "universitetsbokhandel",
    "universitetsbokhandlar": "universitetsbokhandel",
    "universitetsbokhandlarna": "universitetsbokhandel",
    "universitetsbokhandlarnas": "universitetsbokhandel",
    "universitetsbokhandlars": "universitetsbokhandel",
    "universitetsfilialen": "universitetsfilial",
    "universitetsfilialens": "universitetsfilial",
    "universitetsfilialer": "universitetsfilial",
    "universitetsfilialerna": "universitetsfilial",
    "universitetsfilialernas": "universitetsfilial",
    "universitetsfilialers": "universitetsfilial",
    "universitetsfilials": "universitetsfilial",
    "universitetsinstitutionen": "universitetsinstitution",
    "universitetsinstitutionens": "universitetsinstitution",
    "universitetsinstitutioner": "universitetsinstitution",
    "universitetsinstitutionerna": "universitetsinstitution",
    "universitetsinstitutionernas": "universitetsinstitution",
    "universitetsinstitutioners": "universitetsinstitution",
    "universitetsinstitutions": "universitetsinstitution",
    "universitetskanslerer": "universitetskansler",
    "universitetskanslererna": "universitetskansler",
    "universitetskanslerernas": "universitetskansler",
    "universitetskanslerers": "universitetskansler",
    "universitetskanslern": "universitetskansler",
    "universitetskanslerns": "universitetskansler",
    "universitetskanslers": "universitetskansler",
    "universitetslektorer": "universitetslektor",
    "universitetslektorerna": "universitetslektor",
    "universitetslektorernas": "universitetslektor",
    "universitetslektorers": "universitetslektor",
    "universitetslektorn": "universitetslektor",
    "universitetslektorns": "universitetslektor",
    "universitetslektors": "universitetslektor",
    "universitetsmatrikeln": "universitetsmatrikel",
    "universitetsmatrikelns": "universitetsmatrikel",
    "universitetsmatrikels": "universitetsmatrikel",
    "universitetsmatriklar": "universitetsmatrikel",
    "universitetsmatriklarna": "universitetsmatrikel",
    "universitetsmatriklarnas": "universitetsmatrikel",
    "universitetsmatriklars": "universitetsmatrikel",
    "universitetsrektoren": "universitetsrektor",
    "universitetsrektorens": "universitetsrektor",
    "universitetsrektorer": "universitetsrektor",
    "universitetsrektorerna": "universitetsrektor",
    "universitetsrektorernas": "universitetsrektor",
    "universitetsrektorers": "universitetsrektor",
    "universitetsrektorn": "universitetsrektor",
    "universitetsrektorns": "universitetsrektor",
    "universitetsrektors": "universitetsrektor",
    "universitetssjukhusen": "universitetssjukhus",
    "universitetssjukhusens": "universitetssjukhus",
    "universitetssjukhuset": "universitetssjukhus",
    "universitetssjukhusets": "universitetssjukhus",
    "universitetsstaden": "universitetsstad",
    "universitetsstadens": "universitetsstad",
    "universitetsstads": "universitetsstad",
    "universitetsstan": "universitetsstad",
    "universitetsstans": "universitetsstad",
    "universitetsstuderanden": "universitetsstuderande",
    "universitetsstuderandena": "universitetsstuderande",
    "universitetsstuderandenas": "universitetsstuderande",
    "universitetsstuderandens": "universitetsstuderande",
    "universitetsstuderandes": "universitetsstuderande",
    "universitetsstäder": "universitetsstad",
    "universitetsstäderna": "universitetsstad",
    "universitetsstädernas": "universitetsstad",
    "universitetsstäders": "universitetsstad",
    "universitetsutbildningar": "universitetsutbildning",
    "universitetsutbildningarna": "universitetsutbildning",
    "universitetsutbildningarnas": "universitetsutbildning",
    "universitetsutbildningars": "universitetsutbildning",
    "universitetsutbildningen": "universitetsutbildning",
    "universitetsutbildningens": "universitetsutbildning",
    "universitetsutbildnings": "universitetsutbildning",
    "universitetsämnen": "universitetsämne",
    "universitetsämnena": "universitetsämne",
    "universitetsämnenas": "universitetsämne",
    "universitetsämnens": "universitetsämne",
    "universitetsämnes": "universitetsämne",
    "universitetsämnet": "universitetsämne",
    "universitetsämnets": "universitetsämne",
    "universumen": "universum",
    "universumens": "universum",
    "universumet": "universum",
    "universumets": "universum",
    "universums": "universum",
    "unkens": "unken",
    "unket": "unken",
    "unkets": "unken",
    "unkn": "unkna",
    "unkna": "unken",
    "unknad": "unkna",
    "unknade": "unkna",
    "unknades": "unkna",
    "unknads": "unkna",
    "unknande": "unkna",
    "unknanden": "unknande",
    "unknandena": "unknande",
    "unknandenas": "unknande",
    "unknandens": "unknande",
    "unknandes": "unknande",
    "unknandet": "unknande",
    "unknandets": "unknande",
    "unknar": "unkna",
    "unknare": "unken",
    "unknares": "unken",
    "unknas": "unkna",
    "unknast": "unken",
    "unknaste": "unken",
    "unknastes": "unken",
    "unknasts": "unken",
    "unknat": "unkna",
    "unknats": "unkna",
    "unkne": "unken",
    "unknes": "unken",
    "unn": "unna",
    "unnad": "unna",
    "unnade": "unna",
    "unnades": "unna",
    "unnads": "unna",
    "unnande": "unna",
    "unnanden": "unnande",
    "unnandena": "unnande",
    "unnandenas": "unnande",
    "unnandens": "unnande",
    "unnandes": "unnande",
    "unnandet": "unnande",
    "unnandets": "unnande",
    "unnar": "unna",
    "unnas": "unna",
    "unnat": "unna",
    "unnats": "unna",
    "unsen": "uns",
    "unsens": "uns",
    "unset": "uns",
    "unsets": "uns",
    "unt": "unna",
    "unta": "unna",
    "untas": "unna",
    "unte": "unna",
    "untes": "unna",
    "unts": "unna",
    "uppammad": "uppamma",
    "uppammade": "uppamma",
    "uppammades": "uppamma",
    "uppammads": "uppamma",
    "uppammande": "uppamma",
    "uppammanden": "uppammande",
    "uppammandena": "uppammande",
    "uppammandenas": "uppammande",
    "uppammandens": "uppammande",
    "uppammandes": "uppammande",
    "uppammandet": "uppammande",
    "uppammandets": "uppammande",
    "uppammar": "uppamma",
    "uppammas": "uppamma",
    "uppammat": "uppamma",
    "uppammats": "uppamma",
    "upparbet": "upparbeta",
    "upparbetad": "upparbeta",
    "upparbetade": "upparbeta",
    "upparbetades": "upparbeta",
    "upparbetads": "upparbeta",
    "upparbetande": "upparbeta",
    "upparbetanden": "upparbetande",
    "upparbetandena": "upparbetande",
    "upparbetandenas": "upparbetande",
    "upparbetandens": "upparbetande",
    "upparbetandes": "upparbetande",
    "upparbetandet": "upparbetande",
    "upparbetandets": "upparbetande",
    "upparbetar": "upparbeta",
    "upparbetas": "upparbeta",
    "upparbetat": "upparbeta",
    "upparbetats": "upparbeta",
    "upparbetningar": "upparbetning",
    "upparbetningarna": "upparbetning",
    "upparbetningarnas": "upparbetning",
    "upparbetningars": "upparbetning",
    "upparbetningen": "upparbetning",
    "upparbetningens": "upparbetning",
    "upparbetnings": "upparbetning",
    "uppass": "uppassa",
    "uppassad": "uppassa",
    "uppassade": "uppassa",
    "uppassades": "uppassa",
    "uppassads": "uppassa",
    "uppassande": "uppassa",
    "uppassanden": "uppassande",
    "uppassandena": "uppassande",
    "uppassandenas": "uppassande",
    "uppassandens": "uppassande",
    "uppassandes": "uppassande",
    "uppassandet": "uppassande",
    "uppassandets": "uppassande",
    "uppassar": "uppassare",
    "uppassaren": "uppassare",
    "uppassarens": "uppassare",
    "uppassares": "uppassare",
    "uppassarna": "uppassare",
    "uppassarnas": "uppassare",
    "uppassas": "uppassa",
    "uppassat": "uppassa",
    "uppassats": "uppassa",
    "uppassningar": "uppassning",
    "uppassningarna": "uppassning",
    "uppassningarnas": "uppassning",
    "uppassningars": "uppassning",
    "uppassningen": "uppassning",
    "uppassningens": "uppassning",
    "uppassnings": "uppassning",
    "uppassningsställen": "uppassningsställe",
    "uppassningsställena": "uppassningsställe",
    "uppassningsställenas": "uppassningsställe",
    "uppassningsställens": "uppassningsställe",
    "uppassningsställes": "uppassningsställe",
    "uppassningsstället": "uppassningsställe",
    "uppassningsställets": "uppassningsställe",
    "uppbackar": "uppbackare",
    "uppbackaren": "uppbackare",
    "uppbackarens": "uppbackare",
    "uppbackares": "uppbackare",
    "uppbackarna": "uppbackare",
    "uppbackarnas": "uppbackare",
    "uppbackningar": "uppbackning",
    "uppbackningarna": "uppbackning",
    "uppbackningarnas": "uppbackning",
    "uppbackningars": "uppbackning",
    "uppbackningen": "uppbackning",
    "uppbackningens": "uppbackning",
    "uppbacknings": "uppbackning",
    "uppbar": "uppbära",
    "uppbars": "uppbära",
    "uppbindningar": "uppbindning",
    "uppbindningarna": "uppbindning",
    "uppbindningarnas": "uppbindning",
    "uppbindningars": "uppbindning",
    "uppbindningen": "uppbindning",
    "uppbindningens": "uppbindning",
    "uppbindnings": "uppbindning",
    "uppbjud": "uppbjuda",
    "uppbjudande": "uppbjuda",
    "uppbjudanden": "uppbjudande",
    "uppbjudandena": "uppbjudande",
    "uppbjudandenas": "uppbjudande",
    "uppbjudandens": "uppbjudande",
    "uppbjudandes": "uppbjudande",
    "uppbjudandet": "uppbjudande",
    "uppbjudandets": "uppbjudande",
    "uppbjudas": "uppbjuda",
    "uppbjude": "uppbjuda",
    "uppbjuden": "uppbjuda",
    "uppbjudens": "uppbjuda",
    "uppbjuder": "uppbjuda",
    "uppbjudes": "uppbjuda",
    "uppbjudet": "uppbjuda",
    "uppbjudets": "uppbjuda",
    "uppbjudit": "uppbjuda",
    "uppbjudits": "uppbjuda",
    "uppbjudna": "uppbjuda",
    "uppbjudnas": "uppbjuda",
    "uppbjudne": "uppbjuda",
    "uppbjudnes": "uppbjuda",
    "uppbjuds": "uppbjuda",
    "uppbjöd": "uppbjuda",
    "uppbjöde": "uppbjuda",
    "uppbjödes": "uppbjuda",
    "uppbjöds": "uppbjuda",
    "uppbland": "uppblanda",
    "uppblandad": "uppblanda",
    "uppblandade": "uppblandad",
    "uppblandades": "uppblandad",
    "uppblandads": "uppblandad",
    "uppblandande": "uppblanda",
    "uppblandanden": "uppblandande",
    "uppblandandena": "uppblandande",
    "uppblandandenas": "uppblandande",
    "uppblandandens": "uppblandande",
    "uppblandandes": "uppblandande",
    "uppblandandet": "uppblandande",
    "uppblandandets": "uppblandande",
    "uppblandar": "uppblanda",
    "uppblandas": "uppblanda",
    "uppblandat": "uppblandad",
    "uppblandats": "uppblandad",
    "uppblomstringar": "uppblomstring",
    "uppblomstringarna": "uppblomstring",
    "uppblomstringarnas": "uppblomstring",
    "uppblomstringars": "uppblomstring",
    "uppblomstringen": "uppblomstring",
    "uppblomstringens": "uppblomstring",
    "uppblomstrings": "uppblomstring",
    "uppblåsningar": "uppblåsning",
    "uppblåsningarna": "uppblåsning",
    "uppblåsningarnas": "uppblåsning",
    "uppblåsningars": "uppblåsning",
    "uppblåsningen": "uppblåsning",
    "uppblåsningens": "uppblåsning",
    "uppblåsnings": "uppblåsning",
    "uppblåsningsfasen": "uppblåsningsfas",
    "uppblåsningsfasens": "uppblåsningsfas",
    "uppblåsningsfaser": "uppblåsningsfas",
    "uppblåsningsfaserna": "uppblåsningsfas",
    "uppblåsningsfasernas": "uppblåsningsfas",
    "uppblåsningsfasers": "uppblåsningsfas",
    "uppblåsta": "uppblåst",
    "uppblåstare": "uppblåst",
    "uppblåstares": "uppblåst",
    "uppblåstas": "uppblåst",
    "uppblåstast": "uppblåst",
    "uppblåstaste": "uppblåst",
    "uppblåstastes": "uppblåst",
    "uppblåstasts": "uppblåst",
    "uppblåste": "uppblåst",
    "uppblåstes": "uppblåst",
    "uppblåstheten": "uppblåsthet",
    "uppblåsthetens": "uppblåsthet",
    "uppblåsthets": "uppblåsthet",
    "uppblåsts": "uppblåst",
    "uppblötta": "uppblött",
    "uppblöttare": "uppblött",
    "uppblöttares": "uppblött",
    "uppblöttas": "uppblött",
    "uppblöttast": "uppblött",
    "uppblöttaste": "uppblött",
    "uppblöttastes": "uppblött",
    "uppblöttasts": "uppblött",
    "uppblötte": "uppblött",
    "uppblöttes": "uppblött",
    "uppblötts": "uppblött",
    "uppbragta": "uppbragt",
    "uppbragtare": "uppbragt",
    "uppbragtares": "uppbragt",
    "uppbragtas": "uppbragt",
    "uppbragtast": "uppbragt",
    "uppbragtaste": "uppbragt",
    "uppbragtastes": "uppbragt",
    "uppbragtasts": "uppbragt",
    "uppbragte": "uppbragt",
    "uppbragtes": "uppbragt",
    "uppbragtheten": "uppbragthet",
    "uppbragthetens": "uppbragthet",
    "uppbragthets": "uppbragthet",
    "uppbragts": "uppbragt",
    "uppbring": "uppbringa",
    "uppbringad": "uppbringa",
    "uppbringade": "uppbringa",
    "uppbringades": "uppbringa",
    "uppbringads": "uppbringa",
    "uppbringande": "uppbringa",
    "uppbringanden": "uppbringande",
    "uppbringandena": "uppbringande",
    "uppbringandenas": "uppbringande",
    "uppbringandens": "uppbringande",
    "uppbringandes": "uppbringande",
    "uppbringandet": "uppbringande",
    "uppbringandets": "uppbringande",
    "uppbringar": "uppbringa",
    "uppbringas": "uppbringa",
    "uppbringat": "uppbringa",
    "uppbringats": "uppbringa",
    "uppbrotten": "uppbrott",
    "uppbrottens": "uppbrott",
    "uppbrottet": "uppbrott",
    "uppbrottets": "uppbrott",
    "uppbrotts": "uppbrott",
    "uppbrottsordern": "uppbrottsorder",
    "uppbrottsorderna": "uppbrottsorder",
    "uppbrottsordernas": "uppbrottsorder",
    "uppbrottsorderns": "uppbrottsorder",
    "uppbrottsorders": "uppbrottsorder",
    "uppbrottsordrar": "uppbrottsorder",
    "uppbrottsordrarna": "uppbrottsorder",
    "uppbrottsordrarnas": "uppbrottsorder",
    "uppbrottsordrars": "uppbrottsorder",
    "uppbrottssignalen": "uppbrottssignal",
    "uppbrottssignalens": "uppbrottssignal",
    "uppbrottssignaler": "uppbrottssignal",
    "uppbrottssignalerna": "uppbrottssignal",
    "uppbrottssignalernas": "uppbrottssignal",
    "uppbrottssignalers": "uppbrottssignal",
    "uppbrottssignals": "uppbrottssignal",
    "uppbrottsstämningar": "uppbrottsstämning",
    "uppbrottsstämningarna": "uppbrottsstämning",
    "uppbrottsstämningarnas": "uppbrottsstämning",
    "uppbrottsstämningars": "uppbrottsstämning",
    "uppbrottsstämningen": "uppbrottsstämning",
    "uppbrottsstämningens": "uppbrottsstämning",
    "uppbrottsstämnings": "uppbrottsstämning",
    "uppbuden": "uppbud",
    "uppbudens": "uppbud",
    "uppbudet": "uppbud",
    "uppbudets": "uppbud",
    "uppbuds": "uppbud",
    "uppbundens": "uppbunden",
    "uppbundet": "uppbunden",
    "uppbundets": "uppbunden",
    "uppbundna": "uppbunden",
    "uppbundnare": "uppbunden",
    "uppbundnares": "uppbunden",
    "uppbundnas": "uppbunden",
    "uppbundnast": "uppbunden",
    "uppbundnaste": "uppbunden",
    "uppbundnastes": "uppbunden",
    "uppbundnasts": "uppbunden",
    "uppbundne": "uppbunden",
    "uppbundnes": "uppbunden",
    "uppbure": "uppbära",
    "uppburen": "uppbära",
    "uppburens": "uppburen",
    "uppbures": "uppbära",
    "uppburet": "uppburen",
    "uppburets": "uppburen",
    "uppburit": "uppbära",
    "uppburits": "uppbära",
    "uppburna": "uppburen",
    "uppburnare": "uppburen",
    "uppburnares": "uppburen",
    "uppburnas": "uppburen",
    "uppburnast": "uppburen",
    "uppburnaste": "uppburen",
    "uppburnastes": "uppburen",
    "uppburnasts": "uppburen",
    "uppburne": "uppburen",
    "uppburnes": "uppburen",
    "uppbygg": "uppbygga",
    "uppbyggande": "uppbygga",
    "uppbygganden": "uppbyggande",
    "uppbyggandena": "uppbyggande",
    "uppbyggandenas": "uppbyggande",
    "uppbyggandens": "uppbyggande",
    "uppbyggandes": "uppbyggande",
    "uppbyggandet": "uppbyggande",
    "uppbyggandets": "uppbyggande",
    "uppbyggas": "uppbygga",
    "uppbyggd": "uppbygga",
    "uppbyggda": "uppbygga",
    "uppbyggdas": "uppbygga",
    "uppbyggde": "uppbygga",
    "uppbyggdes": "uppbygga",
    "uppbyggds": "uppbygga",
    "uppbyggelselitteraturen": "uppbyggelselitteratur",
    "uppbyggelselitteraturens": "uppbyggelselitteratur",
    "uppbyggelselitteraturs": "uppbyggelselitteratur",
    "uppbyggelsemöten": "uppbyggelsemöte",
    "uppbyggelsemötena": "uppbyggelsemöte",
    "uppbyggelsemötenas": "uppbyggelsemöte",
    "uppbyggelsemötens": "uppbyggelsemöte",
    "uppbyggelsemötes": "uppbyggelsemöte",
    "uppbyggelsemötet": "uppbyggelsemöte",
    "uppbyggelsemötets": "uppbyggelsemöte",
    "uppbyggelsen": "uppbyggelse",
    "uppbyggelsens": "uppbyggelse",
    "uppbyggelses": "uppbyggelse",
    "uppbygger": "uppbygga",
    "uppbygges": "uppbygga",
    "uppbyggliga": "uppbygglig",
    "uppbyggligare": "uppbygglig",
    "uppbyggligares": "uppbygglig",
    "uppbyggligas": "uppbygglig",
    "uppbyggligast": "uppbygglig",
    "uppbyggligaste": "uppbygglig",
    "uppbyggligastes": "uppbygglig",
    "uppbyggligasts": "uppbygglig",
    "uppbygglige": "uppbygglig",
    "uppbyggliges": "uppbygglig",
    "uppbyggligheten": "uppbygglighet",
    "uppbygglighetens": "uppbygglighet",
    "uppbygglighets": "uppbygglighet",
    "uppbygglighetsanspråken": "uppbygglighetsanspråk",
    "uppbygglighetsanspråkens": "uppbygglighetsanspråk",
    "uppbygglighetsanspråket": "uppbygglighetsanspråk",
    "uppbygglighetsanspråkets": "uppbygglighetsanspråk",
    "uppbygglighetsanspråks": "uppbygglighetsanspråk",
    "uppbyggligs": "uppbygglig",
    "uppbyggligt": "uppbygglig",
    "uppbyggligts": "uppbygglig",
    "uppbyggnaden": "uppbyggnad",
    "uppbyggnadens": "uppbyggnad",
    "uppbyggnader": "uppbyggnad",
    "uppbyggnaderna": "uppbyggnad",
    "uppbyggnadernas": "uppbyggnad",
    "uppbyggnaders": "uppbyggnad",
    "uppbyggnads": "uppbyggnad",
    "uppbyggs": "uppbygga",
    "uppbyggt": "uppbygga",
    "uppbyggts": "uppbygga",
    "uppbär": "uppbära",
    "uppbärande": "uppbära",
    "uppbäranden": "uppbärande",
    "uppbärandena": "uppbärande",
    "uppbärandenas": "uppbärande",
    "uppbärandens": "uppbärande",
    "uppbärandes": "uppbärande",
    "uppbärandet": "uppbärande",
    "uppbärandets": "uppbärande",
    "uppbäras": "uppbära",
    "uppbäre": "uppbära",
    "uppbäres": "uppbära",
    "uppbärs": "uppbära",
    "uppbåd": "uppbåda",
    "uppbådad": "uppbåda",
    "uppbådade": "uppbåda",
    "uppbådades": "uppbåda",
    "uppbådads": "uppbåda",
    "uppbådande": "uppbåda",
    "uppbådanden": "uppbådande",
    "uppbådandena": "uppbådande",
    "uppbådandenas": "uppbådande",
    "uppbådandens": "uppbådande",
    "uppbådandes": "uppbådande",
    "uppbådandet": "uppbådande",
    "uppbådandets": "uppbådande",
    "uppbådar": "uppbåda",
    "uppbådas": "uppbåda",
    "uppbådat": "uppbåda",
    "uppbådats": "uppbåda",
    "uppbåden": "uppbåd",
    "uppbådens": "uppbåd",
    "uppbådet": "uppbåd",
    "uppbådets": "uppbåd",
    "uppbåds": "uppbåd",
    "uppbörden": "uppbörd",
    "uppbördens": "uppbörd",
    "uppbörder": "uppbörd",
    "uppbörderna": "uppbörd",
    "uppbördernas": "uppbörd",
    "uppbörders": "uppbörd",
    "uppbörds": "uppbörd",
    "uppbördsboken": "uppbördsbok",
    "uppbördsbokens": "uppbördsbok",
    "uppbördsboks": "uppbördsbok",
    "uppbördsböcker": "uppbördsbok",
    "uppbördsböckerna": "uppbördsbok",
    "uppbördsböckernas": "uppbördsbok",
    "uppbördsböckers": "uppbördsbok",
    "uppbördsdagar": "uppbördsdag",
    "uppbördsdagarna": "uppbördsdag",
    "uppbördsdagarnas": "uppbördsdag",
    "uppbördsdagars": "uppbördsdag",
    "uppbördsdagen": "uppbördsdag",
    "uppbördsdagens": "uppbördsdag",
    "uppbördsdags": "uppbördsdag",
    "uppbördslängden": "uppbördslängd",
    "uppbördslängdens": "uppbördslängd",
    "uppbördslängder": "uppbördslängd",
    "uppbördslängderna": "uppbördslängd",
    "uppbördslängdernas": "uppbördslängd",
    "uppbördslängders": "uppbördslängd",
    "uppbördslängds": "uppbördslängd",
    "uppbördsmannen": "uppbördsman",
    "uppbördsmannens": "uppbördsman",
    "uppbördsmans": "uppbördsman",
    "uppbördsmän": "uppbördsman",
    "uppbördsmännen": "uppbördsman",
    "uppbördsmännens": "uppbördsman",
    "uppbördsmäns": "uppbördsman",
    "uppbördsterminen": "uppbördstermin",
    "uppbördsterminens": "uppbördstermin",
    "uppbördsterminer": "uppbördstermin",
    "uppbördsterminerna": "uppbördstermin",
    "uppbördsterminernas": "uppbördstermin",
    "uppbördsterminers": "uppbördstermin",
    "uppbördstermins": "uppbördstermin",
    "uppbördsverket": "uppbördsverk",
    "uppbördsverkets": "uppbördsverk",
    "uppbördsverks": "uppbördsverk",
    "uppbördsåren": "uppbördsår",
    "uppbördsårens": "uppbördsår",
    "uppbördsåret": "uppbördsår",
    "uppbördsårets": "uppbördsår",
    "uppbördsårs": "uppbördsår",
    "uppdag": "uppdaga",
    "uppdagad": "uppdaga",
    "uppdagade": "uppdaga",
    "uppdagades": "uppdaga",
    "uppdagads": "uppdaga",
    "uppdagande": "uppdaga",
    "uppdaganden": "uppdagande",
    "uppdagandena": "uppdagande",
    "uppdagandenas": "uppdagande",
    "uppdagandens": "uppdagande",
    "uppdagandes": "uppdagande",
    "uppdagandet": "uppdagande",
    "uppdagandets": "uppdagande",
    "uppdagar": "uppdaga",
    "uppdagas": "uppdaga",
    "uppdagat": "uppdaga",
    "uppdagats": "uppdaga",
    "uppdaterad": "uppdatera",
    "uppdaterade": "uppdatera",
    "uppdaterades": "uppdatera",
    "uppdaterads": "uppdatera",
    "uppdaterande": "uppdatera",
    "uppdateranden": "uppdaterande",
    "uppdaterandena": "uppdaterande",
    "uppdaterandenas": "uppdaterande",
    "uppdaterandens": "uppdaterande",
    "uppdaterandes": "uppdaterande",
    "uppdaterandet": "uppdaterande",
    "uppdaterandets": "uppdaterande",
    "uppdaterar": "uppdatera",
    "uppdateras": "uppdatera",
    "uppdaterat": "uppdatera",
    "uppdaterats": "uppdatera",
    "uppdaterbara": "uppdaterbar",
    "uppdaterbarare": "uppdaterbar",
    "uppdaterbarares": "uppdaterbar",
    "uppdaterbaras": "uppdaterbar",
    "uppdaterbarast": "uppdaterbar",
    "uppdaterbaraste": "uppdaterbar",
    "uppdaterbarastes": "uppdaterbar",
    "uppdaterbarasts": "uppdaterbar",
    "uppdaterbare": "uppdaterbar",
    "uppdaterbares": "uppdaterbar",
    "uppdaterbarheten": "uppdaterbarhet",
    "uppdaterbarhetens": "uppdaterbarhet",
    "uppdaterbarhets": "uppdaterbarhet",
    "uppdaterbars": "uppdaterbar",
    "uppdaterbart": "uppdaterbar",
    "uppdaterbarts": "uppdaterbar",
    "uppdateringar": "uppdatering",
    "uppdateringarna": "uppdatering",
    "uppdateringarnas": "uppdatering",
    "uppdateringars": "uppdatering",
    "uppdateringen": "uppdatering",
    "uppdateringens": "uppdatering",
    "uppdaterings": "uppdatering",
    "uppdel": "uppdela",
    "uppdelad": "uppdela",
    "uppdelade": "uppdela",
    "uppdelades": "uppdela",
    "uppdelads": "uppdela",
    "uppdelande": "uppdela",
    "uppdelanden": "uppdelande",
    "uppdelandena": "uppdelande",
    "uppdelandenas": "uppdelande",
    "uppdelandens": "uppdelande",
    "uppdelandes": "uppdelande",
    "uppdelandet": "uppdelande",
    "uppdelandets": "uppdelande",
    "uppdelar": "uppdela",
    "uppdelas": "uppdela",
    "uppdelat": "uppdela",
    "uppdelats": "uppdela",
    "uppdelningar": "uppdelning",
    "uppdelningarna": "uppdelning",
    "uppdelningarnas": "uppdelning",
    "uppdelningars": "uppdelning",
    "uppdelningen": "uppdelning",
    "uppdelningens": "uppdelning",
    "uppdelnings": "uppdelning",
    "uppdiktade": "uppdiktad",
    "uppdiktades": "uppdiktad",
    "uppdiktads": "uppdiktad",
    "uppdiktat": "uppdiktad",
    "uppdiktats": "uppdiktad",
    "uppdrag": "uppdra",
    "uppdraga": "uppdra",
    "uppdragande": "uppdra",
    "uppdraganden": "uppdragande",
    "uppdragandena": "uppdragande",
    "uppdragandenas": "uppdragande",
    "uppdragandens": "uppdragande",
    "uppdragandes": "uppdragande",
    "uppdragandet": "uppdragande",
    "uppdragandets": "uppdragande",
    "uppdragas": "uppdra",
    "uppdrage": "uppdra",
    "uppdragen": "uppdrag",
    "uppdragens": "uppdrag",
    "uppdrager": "uppdra",
    "uppdrages": "uppdra",
    "uppdraget": "uppdrag",
    "uppdragets": "uppdrag",
    "uppdragit": "uppdra",
    "uppdragits": "uppdra",
    "uppdragna": "uppdra",
    "uppdragnas": "uppdra",
    "uppdragne": "uppdra",
    "uppdragnes": "uppdra",
    "uppdrags": "uppdrag",
    "uppdragsarkeologien": "uppdragsarkeologi",
    "uppdragsarkeologiens": "uppdragsarkeologi",
    "uppdragsarkeologin": "uppdragsarkeologi",
    "uppdragsarkeologins": "uppdragsarkeologi",
    "uppdragsarkeologis": "uppdragsarkeologi",
    "uppdragsarkeologiska": "uppdragsarkeologisk",
    "uppdragsarkeologiskas": "uppdragsarkeologisk",
    "uppdragsarkeologiske": "uppdragsarkeologisk",
    "uppdragsarkeologiskes": "uppdragsarkeologisk",
    "uppdragsarkeologisks": "uppdragsarkeologisk",
    "uppdragsarkeologiskt": "uppdragsarkeologisk",
    "uppdragsarkeologiskts": "uppdragsarkeologisk",
    "uppdragsforskningar": "uppdragsforskning",
    "uppdragsforskningarna": "uppdragsforskning",
    "uppdragsforskningarnas": "uppdragsforskning",
    "uppdragsforskningars": "uppdragsforskning",
    "uppdragsforskningen": "uppdragsforskning",
    "uppdragsforskningens": "uppdragsforskning",
    "uppdragsforsknings": "uppdragsforskning",
    "uppdragsgivar": "uppdragsgivare",
    "uppdragsgivaren": "uppdragsgivare",
    "uppdragsgivarens": "uppdragsgivare",
    "uppdragsgivares": "uppdragsgivare",
    "uppdragsgivarna": "uppdragsgivare",
    "uppdragsgivarnas": "uppdragsgivare",
    "uppdragstagar": "uppdragstagare",
    "uppdragstagaren": "uppdragstagare",
    "uppdragstagarens": "uppdragstagare",
    "uppdragstagares": "uppdragstagare",
    "uppdragstagarna": "uppdragstagare",
    "uppdragstagarnas": "uppdragstagare",
    "uppdrar": "uppdra",
    "uppdras": "uppdra",
    "uppdrev": "uppdriva",
    "uppdrevs": "uppdriva",
    "uppdriv": "uppdriva",
    "uppdrivande": "uppdriva",
    "uppdrivanden": "uppdrivande",
    "uppdrivandena": "uppdrivande",
    "uppdrivandenas": "uppdrivande",
    "uppdrivandens": "uppdrivande",
    "uppdrivandes": "uppdrivande",
    "uppdrivandet": "uppdrivande",
    "uppdrivandets": "uppdrivande",
    "uppdrivas": "uppdriva",
    "uppdrive": "uppdriva",
    "uppdriven": "uppdriva",
    "uppdrivens": "uppdriven",
    "uppdriver": "uppdriva",
    "uppdrives": "uppdriva",
    "uppdrivet": "uppdriven",
    "uppdrivets": "uppdriven",
    "uppdrivit": "uppdriva",
    "uppdrivits": "uppdriva",
    "uppdrivna": "uppdriven",
    "uppdrivnare": "uppdriven",
    "uppdrivnares": "uppdriven",
    "uppdrivnas": "uppdriven",
    "uppdrivnast": "uppdriven",
    "uppdrivnaste": "uppdriven",
    "uppdrivnastes": "uppdriven",
    "uppdrivnasts": "uppdriven",
    "uppdrivne": "uppdriven",
    "uppdrivnes": "uppdriven",
    "uppdrivs": "uppdriva",
    "uppdrog": "uppdra",
    "uppdroge": "uppdra",
    "uppdroges": "uppdra",
    "uppdrogs": "uppdra",
    "uppdukningar": "uppdukning",
    "uppdukningarna": "uppdukning",
    "uppdukningarnas": "uppdukning",
    "uppdukningars": "uppdukning",
    "uppdukningen": "uppdukning",
    "uppdukningens": "uppdukning",
    "uppduknings": "uppdukning",
    "uppdämda": "uppdämd",
    "uppdämdare": "uppdämd",
    "uppdämdares": "uppdämd",
    "uppdämdas": "uppdämd",
    "uppdämdast": "uppdämd",
    "uppdämdaste": "uppdämd",
    "uppdämdastes": "uppdämd",
    "uppdämdasts": "uppdämd",
    "uppdämde": "uppdämd",
    "uppdämdes": "uppdämd",
    "uppdämds": "uppdämd",
    "uppdämt": "uppdämd",
    "uppdämts": "uppdämd",
    "uppegg": "uppegga",
    "uppeggad": "uppegga",
    "uppeggade": "uppegga",
    "uppeggades": "uppegga",
    "uppeggads": "uppegga",
    "uppeggande": "uppegga",
    "uppegganden": "uppeggande",
    "uppeggandena": "uppeggande",
    "uppeggandenas": "uppeggande",
    "uppeggandens": "uppeggande",
    "uppeggandes": "uppeggande",
    "uppeggandet": "uppeggande",
    "uppeggandets": "uppeggande",
    "uppeggar": "uppegga",
    "uppeggas": "uppegga",
    "uppeggat": "uppegga",
    "uppeggats": "uppegga",
    "uppehälles": "uppehälle",
    "uppehället": "uppehälle",
    "uppehällets": "uppehälle",
    "uppehåll": "uppehålla",
    "uppehållande": "uppehålla",
    "uppehållanden": "uppehållande",
    "uppehållandena": "uppehållande",
    "uppehållandenas": "uppehållande",
    "uppehållandens": "uppehållande",
    "uppehållandes": "uppehållande",
    "uppehållandet": "uppehållande",
    "uppehållandets": "uppehållande",
    "uppehållas": "uppehålla",
    "uppehålle": "uppehålla",
    "uppehållen": "uppehålla",
    "uppehållens": "uppehålla",
    "uppehåller": "uppehålla",
    "uppehålles": "uppehålla",
    "uppehållet": "uppehålla",
    "uppehållets": "uppehålla",
    "uppehållit": "uppehålla",
    "uppehållits": "uppehålla",
    "uppehållna": "uppehålla",
    "uppehållnas": "uppehålla",
    "uppehållne": "uppehålla",
    "uppehållnes": "uppehålla",
    "uppehålls": "uppehålla",
    "uppehållsorten": "uppehållsort",
    "uppehållsortens": "uppehållsort",
    "uppehållsorter": "uppehållsort",
    "uppehållsorterna": "uppehållsort",
    "uppehållsorternas": "uppehållsort",
    "uppehållsorters": "uppehållsort",
    "uppehållsorts": "uppehållsort",
    "uppehållstillstånden": "uppehållstillstånd",
    "uppehållstillståndens": "uppehållstillstånd",
    "uppehållstillståndet": "uppehållstillstånd",
    "uppehållstillståndets": "uppehållstillstånd",
    "uppehållstillstånds": "uppehållstillstånd",
    "uppehållsväderna": "uppehållsväder",
    "uppehållsvädernas": "uppehållsväder",
    "uppehållsväders": "uppehållsväder",
    "uppehållsvädren": "uppehållsväder",
    "uppehållsvädrens": "uppehållsväder",
    "uppehållsvädret": "uppehållsväder",
    "uppehållsvädrets": "uppehållsväder",
    "uppehöll": "uppehålla",
    "uppehölle": "uppehålla",
    "uppehölles": "uppehålla",
    "uppehölls": "uppehålla",
    "uppeldade": "uppeldad",
    "uppeldades": "uppeldad",
    "uppeldads": "uppeldad",
    "uppeldat": "uppeldad",
    "uppeldats": "uppeldad",
    "uppenbar": "uppenbara",
    "uppenbara": "uppenbar",
    "uppenbarad": "uppenbara",
    "uppenbarade": "uppenbara",
    "uppenbarades": "uppenbara",
    "uppenbarads": "uppenbara",
    "uppenbarande": "uppenbara",
    "uppenbaranden": "uppenbarande",
    "uppenbarandena": "uppenbarande",
    "uppenbarandenas": "uppenbarande",
    "uppenbarandens": "uppenbarande",
    "uppenbarandes": "uppenbarande",
    "uppenbarandet": "uppenbarande",
    "uppenbarandets": "uppenbarande",
    "uppenbarar": "uppenbara",
    "uppenbarare": "uppenbar",
    "uppenbarares": "uppenbar",
    "uppenbaras": "uppenbara",
    "uppenbarast": "uppenbar",
    "uppenbaraste": "uppenbar",
    "uppenbarastes": "uppenbar",
    "uppenbarasts": "uppenbar",
    "uppenbarat": "uppenbara",
    "uppenbarats": "uppenbara",
    "uppenbare": "uppenbar",
    "uppenbarelsen": "uppenbarelse",
    "uppenbarelsens": "uppenbarelse",
    "uppenbarelser": "uppenbarelse",
    "uppenbarelsereligionen": "uppenbarelsereligion",
    "uppenbarelsereligionens": "uppenbarelsereligion",
    "uppenbarelsereligioner": "uppenbarelsereligion",
    "uppenbarelsereligionerna": "uppenbarelsereligion",
    "uppenbarelsereligionernas": "uppenbarelsereligion",
    "uppenbarelsereligioners": "uppenbarelsereligion",
    "uppenbarelsereligions": "uppenbarelsereligion",
    "uppenbarelserna": "uppenbarelse",
    "uppenbarelsernas": "uppenbarelse",
    "uppenbarelsers": "uppenbarelse",
    "uppenbarelses": "uppenbarelse",
    "uppenbarelsetron": "uppenbarelsetro",
    "uppenbarelsetrons": "uppenbarelsetro",
    "uppenbarelsetros": "uppenbarelsetro",
    "uppenbares": "uppenbar",
    "uppenbarheten": "uppenbarhet",
    "uppenbarhetens": "uppenbarhet",
    "uppenbarhets": "uppenbarhet",
    "uppenbars": "uppenbar",
    "uppenbart": "uppenbar",
    "uppenbarts": "uppenbar",
    "uppercuten": "uppercut",
    "uppercutens": "uppercut",
    "uppercuts": "uppercut",
    "uppercutsarna": "uppercut",
    "uppercutsarnas": "uppercut",
    "uppercutsen": "uppercut",
    "uppercutsens": "uppercut",
    "uppesittar": "uppesittare",
    "uppesittaren": "uppesittare",
    "uppesittarens": "uppesittare",
    "uppesittares": "uppesittare",
    "uppesittarkvällar": "uppesittarkväll",
    "uppesittarkvällarna": "uppesittarkväll",
    "uppesittarkvällarnas": "uppesittarkväll",
    "uppesittarkvällars": "uppesittarkväll",
    "uppesittarkvällen": "uppesittarkväll",
    "uppesittarkvällens": "uppesittarkväll",
    "uppesittarkvälls": "uppesittarkväll",
    "uppesittarna": "uppesittare",
    "uppesittarnas": "uppesittare",
    "uppfann": "uppfinna",
    "uppfanns": "uppfinna",
    "uppfarten": "uppfart",
    "uppfartens": "uppfart",
    "uppfarter": "uppfart",
    "uppfarterna": "uppfart",
    "uppfarternas": "uppfart",
    "uppfarters": "uppfart",
    "uppfarts": "uppfart",
    "uppfartsrampen": "uppfartsramp",
    "uppfartsrampens": "uppfartsramp",
    "uppfartsramper": "uppfartsramp",
    "uppfartsramperna": "uppfartsramp",
    "uppfartsrampernas": "uppfartsramp",
    "uppfartsrampers": "uppfartsramp",
    "uppfartsramps": "uppfartsramp",
    "uppfatt": "uppfatta",
    "uppfattad": "uppfatta",
    "uppfattade": "uppfatta",
    "uppfattades": "uppfatta",
    "uppfattads": "uppfatta",
    "uppfattande": "uppfatta",
    "uppfattanden": "uppfattande",
    "uppfattandena": "uppfattande",
    "uppfattandenas": "uppfattande",
    "uppfattandens": "uppfattande",
    "uppfattandes": "uppfattande",
    "uppfattandet": "uppfattande",
    "uppfattandets": "uppfattande",
    "uppfattar": "uppfatta",
    "uppfattas": "uppfatta",
    "uppfattat": "uppfatta",
    "uppfattats": "uppfatta",
    "uppfattningar": "uppfattning",
    "uppfattningarna": "uppfattning",
    "uppfattningarnas": "uppfattning",
    "uppfattningars": "uppfattning",
    "uppfattningen": "uppfattning",
    "uppfattningens": "uppfattning",
    "uppfattnings": "uppfattning",
    "uppfattningsförmågan": "uppfattningsförmåga",
    "uppfattningsförmågans": "uppfattningsförmåga",
    "uppfattningsförmågas": "uppfattningsförmåga",
    "uppfattningsförmåge": "uppfattningsförmåga",
    "uppfinn": "uppfinna",
    "uppfinnande": "uppfinna",
    "uppfinnanden": "uppfinnande",
    "uppfinnandena": "uppfinnande",
    "uppfinnandenas": "uppfinnande",
    "uppfinnandens": "uppfinnande",
    "uppfinnandes": "uppfinnande",
    "uppfinnandet": "uppfinnande",
    "uppfinnandets": "uppfinnande",
    "uppfinnar": "uppfinnare",
    "uppfinnaren": "uppfinnare",
    "uppfinnarens": "uppfinnare",
    "uppfinnares": "uppfinnare",
    "uppfinnarna": "uppfinnare",
    "uppfinnarnas": "uppfinnare",
    "uppfinnas": "uppfinna",
    "uppfinne": "uppfinna",
    "uppfinner": "uppfinna",
    "uppfinnes": "uppfinna",
    "uppfinningar": "uppfinning",
    "uppfinningarna": "uppfinning",
    "uppfinningarnas": "uppfinning",
    "uppfinningars": "uppfinning",
    "uppfinningen": "uppfinning",
    "uppfinningens": "uppfinning",
    "uppfinnings": "uppfinning",
    "uppfinningsförmågan": "uppfinningsförmåga",
    "uppfinningsförmågans": "uppfinningsförmåga",
    "uppfinningsförmågas": "uppfinningsförmåga",
    "uppfinningsförmåge": "uppfinningsförmåga",
    "uppfinningsrika": "uppfinningsrik",
    "uppfinningsrikare": "uppfinningsrik",
    "uppfinningsrikares": "uppfinningsrik",
    "uppfinningsrikas": "uppfinningsrik",
    "uppfinningsrikast": "uppfinningsrik",
    "uppfinningsrikaste": "uppfinningsrik",
    "uppfinningsrikastes": "uppfinningsrik",
    "uppfinningsrikasts": "uppfinningsrik",
    "uppfinningsrike": "uppfinningsrik",
    "uppfinningsrikes": "uppfinningsrik",
    "uppfinningsrikheten": "uppfinningsrikhet",
    "uppfinningsrikhetens": "uppfinningsrikhet",
    "uppfinningsrikhets": "uppfinningsrikhet",
    "uppfinningsriks": "uppfinningsrik",
    "uppfinningsrikt": "uppfinningsrik",
    "uppfinningsrikts": "uppfinningsrik",
    "uppfinns": "uppfinna",
    "uppflogen": "uppflog",
    "uppflogens": "uppflog",
    "uppfloget": "uppflog",
    "uppflogets": "uppflog",
    "uppflogs": "uppflog",
    "uppflugens": "uppflugen",
    "uppfluget": "uppflugen",
    "uppflugets": "uppflugen",
    "uppflugna": "uppflugen",
    "uppflugnare": "uppflugen",
    "uppflugnares": "uppflugen",
    "uppflugnas": "uppflugen",
    "uppflugnast": "uppflugen",
    "uppflugnaste": "uppflugen",
    "uppflugnastes": "uppflugen",
    "uppflugnasts": "uppflugen",
    "uppflugne": "uppflugen",
    "uppflugnes": "uppflugen",
    "uppflågen": "uppflåg",
    "uppflågens": "uppflåg",
    "uppflåget": "uppflåg",
    "uppflågets": "uppflåg",
    "uppflågs": "uppflåg",
    "uppfordrad": "uppfordra",
    "uppfordrade": "uppfordra",
    "uppfordrades": "uppfordra",
    "uppfordrads": "uppfordra",
    "uppfordrande": "uppfordra",
    "uppfordranden": "uppfordrande",
    "uppfordrandena": "uppfordrande",
    "uppfordrandenas": "uppfordrande",
    "uppfordrandens": "uppfordrande",
    "uppfordrandes": "uppfordrande",
    "uppfordrandet": "uppfordrande",
    "uppfordrandets": "uppfordrande",
    "uppfordrans": "uppfordran",
    "uppfordrar": "uppfordra",
    "uppfordras": "uppfordra",
    "uppfordrat": "uppfordra",
    "uppfordrats": "uppfordra",
    "uppfordringar": "uppfordring",
    "uppfordringarna": "uppfordring",
    "uppfordringarnas": "uppfordring",
    "uppfordringars": "uppfordring",
    "uppfordringen": "uppfordring",
    "uppfordringens": "uppfordring",
    "uppfordrings": "uppfordring",
    "uppfostrad": "uppfostra",
    "uppfostrade": "uppfostra",
    "uppfostrades": "uppfostra",
    "uppfostrads": "uppfostra",
    "uppfostrande": "uppfostra",
    "uppfostranden": "uppfostrande",
    "uppfostrandena": "uppfostrande",
    "uppfostrandenas": "uppfostrande",
    "uppfostrandens": "uppfostrande",
    "uppfostrandes": "uppfostrande",
    "uppfostrandet": "uppfostrande",
    "uppfostrandets": "uppfostrande",
    "uppfostrans": "uppfostran",
    "uppfostrar": "uppfostrare",
    "uppfostraren": "uppfostrare",
    "uppfostrarens": "uppfostrare",
    "uppfostrares": "uppfostrare",
    "uppfostrarna": "uppfostrare",
    "uppfostrarnas": "uppfostrare",
    "uppfostras": "uppfostra",
    "uppfostrat": "uppfostra",
    "uppfostrats": "uppfostra",
    "uppfostringar": "uppfostring",
    "uppfostringarna": "uppfostring",
    "uppfostringarnas": "uppfostring",
    "uppfostringars": "uppfostring",
    "uppfostringen": "uppfostring",
    "uppfostringens": "uppfostring",
    "uppfostrings": "uppfostring",
    "uppfostringsanstalten": "uppfostringsanstalt",
    "uppfostringsanstaltens": "uppfostringsanstalt",
    "uppfostringsanstalter": "uppfostringsanstalt",
    "uppfostringsanstalterna": "uppfostringsanstalt",
    "uppfostringsanstalternas": "uppfostringsanstalt",
    "uppfostringsanstalters": "uppfostringsanstalt",
    "uppfostringsanstalts": "uppfostringsanstalt",
    "uppfostringshemmen": "uppfostringshem",
    "uppfostringshemmens": "uppfostringshem",
    "uppfostringshemmet": "uppfostringshem",
    "uppfostringshemmets": "uppfostringshem",
    "uppfostringshems": "uppfostringshem",
    "uppfrisk": "uppfriska",
    "uppfriskad": "uppfriska",
    "uppfriskade": "uppfriska",
    "uppfriskades": "uppfriska",
    "uppfriskads": "uppfriska",
    "uppfriskande": "uppfriska",
    "uppfriskanden": "uppfriskande",
    "uppfriskandena": "uppfriskande",
    "uppfriskandenas": "uppfriskande",
    "uppfriskandens": "uppfriskande",
    "uppfriskandes": "uppfriskande",
    "uppfriskandet": "uppfriskande",
    "uppfriskandets": "uppfriskande",
    "uppfriskar": "uppfriska",
    "uppfriskas": "uppfriska",
    "uppfriskat": "uppfriska",
    "uppfriskats": "uppfriska",
    "uppfunna": "uppfinna",
    "uppfunnas": "uppfinna",
    "uppfunne": "uppfinna",
    "uppfunnen": "uppfinna",
    "uppfunnens": "uppfinna",
    "uppfunnes": "uppfinna",
    "uppfunnet": "uppfinna",
    "uppfunnets": "uppfinna",
    "uppfunnit": "uppfinna",
    "uppfunnits": "uppfinna",
    "uppfyll": "uppfylla",
    "uppfyllande": "uppfylla",
    "uppfyllanden": "uppfyllande",
    "uppfyllandena": "uppfyllande",
    "uppfyllandenas": "uppfyllande",
    "uppfyllandens": "uppfyllande",
    "uppfyllandes": "uppfyllande",
    "uppfyllandet": "uppfyllande",
    "uppfyllandets": "uppfyllande",
    "uppfyllas": "uppfylla",
    "uppfylld": "uppfylla",
    "uppfyllda": "uppfylla",
    "uppfylldas": "uppfylla",
    "uppfyllde": "uppfylla",
    "uppfylldes": "uppfylla",
    "uppfyllds": "uppfylla",
    "uppfyllelsen": "uppfyllelse",
    "uppfyllelsens": "uppfyllelse",
    "uppfyllelses": "uppfyllelse",
    "uppfyller": "uppfylla",
    "uppfylles": "uppfylla",
    "uppfylls": "uppfylla",
    "uppfyllt": "uppfylla",
    "uppfyllts": "uppfylla",
    "uppfällbara": "uppfällbar",
    "uppfällbarare": "uppfällbar",
    "uppfällbarares": "uppfällbar",
    "uppfällbaras": "uppfällbar",
    "uppfällbarast": "uppfällbar",
    "uppfällbaraste": "uppfällbar",
    "uppfällbarastes": "uppfällbar",
    "uppfällbarasts": "uppfällbar",
    "uppfällbare": "uppfällbar",
    "uppfällbares": "uppfällbar",
    "uppfällbarheten": "uppfällbarhet",
    "uppfällbarhetens": "uppfällbarhet",
    "uppfällbarhets": "uppfällbarhet",
    "uppfällbars": "uppfällbar",
    "uppfällbart": "uppfällbar",
    "uppfällbarts": "uppfällbar",
    "uppfällde": "uppfälld",
    "uppfälldes": "uppfälld",
    "uppfällds": "uppfälld",
    "uppfällt": "uppfälld",
    "uppfällts": "uppfälld",
    "uppfång": "uppfånga",
    "uppfångad": "uppfånga",
    "uppfångade": "uppfånga",
    "uppfångades": "uppfånga",
    "uppfångads": "uppfånga",
    "uppfångande": "uppfånga",
    "uppfånganden": "uppfångande",
    "uppfångandena": "uppfångande",
    "uppfångandenas": "uppfångande",
    "uppfångandens": "uppfångande",
    "uppfångandes": "uppfångande",
    "uppfångandet": "uppfångande",
    "uppfångandets": "uppfångande",
    "uppfångar": "uppfånga",
    "uppfångas": "uppfånga",
    "uppfångat": "uppfånga",
    "uppfångats": "uppfånga",
    "uppföd": "uppföda",
    "uppfödande": "uppföda",
    "uppfödanden": "uppfödande",
    "uppfödandena": "uppfödande",
    "uppfödandenas": "uppfödande",
    "uppfödandens": "uppfödande",
    "uppfödandes": "uppfödande",
    "uppfödandet": "uppfödande",
    "uppfödandets": "uppfödande",
    "uppfödar": "uppfödare",
    "uppfödaren": "uppfödare",
    "uppfödarens": "uppfödare",
    "uppfödares": "uppfödare",
    "uppfödarna": "uppfödare",
    "uppfödarnas": "uppfödare",
    "uppfödas": "uppföda",
    "uppfödd": "uppföda",
    "uppfödda": "uppföda",
    "uppföddas": "uppföda",
    "uppfödde": "uppföda",
    "uppföddes": "uppföda",
    "uppfödds": "uppföda",
    "uppföder": "uppföda",
    "uppfödes": "uppföda",
    "uppfödningar": "uppfödning",
    "uppfödningarna": "uppfödning",
    "uppfödningarnas": "uppfödning",
    "uppfödningars": "uppfödning",
    "uppfödningen": "uppfödning",
    "uppfödningens": "uppfödning",
    "uppfödnings": "uppfödning",
    "uppföds": "uppföda",
    "uppföljar": "uppföljare",
    "uppföljaren": "uppföljare",
    "uppföljarens": "uppföljare",
    "uppföljares": "uppföljare",
    "uppföljarna": "uppföljare",
    "uppföljarnas": "uppföljare",
    "uppföljningar": "uppföljning",
    "uppföljningarna": "uppföljning",
    "uppföljningarnas": "uppföljning",
    "uppföljningars": "uppföljning",
    "uppföljningen": "uppföljning",
    "uppföljningens": "uppföljning",
    "uppföljnings": "uppföljning",
    "uppför": "uppföra",
    "uppförande": "uppföra",
    "uppföranden": "uppförande",
    "uppförandena": "uppförande",
    "uppförandenas": "uppförande",
    "uppförandens": "uppförande",
    "uppförandes": "uppförande",
    "uppförandet": "uppförande",
    "uppförandets": "uppförande",
    "uppföras": "uppföra",
    "uppförd": "uppföra",
    "uppförda": "uppföra",
    "uppfördas": "uppföra",
    "uppförde": "uppföra",
    "uppfördes": "uppföra",
    "uppförds": "uppföra",
    "uppföres": "uppföra",
    "uppförs": "uppföra",
    "uppförsback": "uppförsbacke",
    "uppförsbackar": "uppförsbacke",
    "uppförsbackarna": "uppförsbacke",
    "uppförsbackarnas": "uppförsbacke",
    "uppförsbackars": "uppförsbacke",
    "uppförsbacken": "uppförsbacke",
    "uppförsbackens": "uppförsbacke",
    "uppförsbackes": "uppförsbacke",
    "uppförsbacks": "uppförsbacke",
    "uppförstor": "uppförstora",
    "uppförstorad": "uppförstora",
    "uppförstorade": "uppförstora",
    "uppförstorades": "uppförstora",
    "uppförstorads": "uppförstora",
    "uppförstorande": "uppförstora",
    "uppförstoranden": "uppförstorande",
    "uppförstorandena": "uppförstorande",
    "uppförstorandenas": "uppförstorande",
    "uppförstorandens": "uppförstorande",
    "uppförstorandes": "uppförstorande",
    "uppförstorandet": "uppförstorande",
    "uppförstorandets": "uppförstorande",
    "uppförstorar": "uppförstora",
    "uppförstoras": "uppförstora",
    "uppförstorat": "uppförstora",
    "uppförstorats": "uppförstora",
    "uppfört": "uppföra",
    "uppförts": "uppföra",
    "uppfött": "uppföda",
    "uppfötts": "uppföda",
    "uppgav": "uppge",
    "uppgavs": "uppge",
    "uppgeende": "uppge",
    "uppgeendes": "uppge",
    "uppger": "uppge",
    "uppges": "uppge",
    "uppgett": "uppge",
    "uppgetts": "uppge",
    "uppgick": "uppgå",
    "uppgicks": "uppgå",
    "uppgiften": "uppgift",
    "uppgiftens": "uppgift",
    "uppgifter": "uppgift",
    "uppgifterna": "uppgift",
    "uppgifternas": "uppgift",
    "uppgifters": "uppgift",
    "uppgifts": "uppgift",
    "uppginge": "uppgå",
    "uppginges": "uppgå",
    "uppgiv": "uppge",
    "uppgiva": "uppge",
    "uppgivande": "uppge",
    "uppgivanden": "uppgivande",
    "uppgivandena": "uppgivande",
    "uppgivandenas": "uppgivande",
    "uppgivandens": "uppgivande",
    "uppgivandes": "uppgivande",
    "uppgivandet": "uppgivande",
    "uppgivandets": "uppgivande",
    "uppgivas": "uppge",
    "uppgive": "uppge",
    "uppgivelsen": "uppgivelse",
    "uppgivelsens": "uppgivelse",
    "uppgivelses": "uppgivelse",
    "uppgiven": "uppge",
    "uppgivenheten": "uppgivenhet",
    "uppgivenhetens": "uppgivenhet",
    "uppgivenheter": "uppgivenhet",
    "uppgivenheterna": "uppgivenhet",
    "uppgivenheternas": "uppgivenhet",
    "uppgivenheters": "uppgivenhet",
    "uppgivenhets": "uppgivenhet",
    "uppgivens": "uppgiven",
    "uppgiver": "uppge",
    "uppgives": "uppge",
    "uppgivet": "uppgiven",
    "uppgivets": "uppgiven",
    "uppgivit": "uppge",
    "uppgivits": "uppge",
    "uppgivna": "uppgiven",
    "uppgivnare": "uppgiven",
    "uppgivnares": "uppgiven",
    "uppgivnas": "uppgiven",
    "uppgivnast": "uppgiven",
    "uppgivnaste": "uppgiven",
    "uppgivnastes": "uppgiven",
    "uppgivnasts": "uppgiven",
    "uppgivne": "uppgiven",
    "uppgivnes": "uppgiven",
    "uppgivs": "uppge",
    "uppgjorda": "uppgjord",
    "uppgjordare": "uppgjord",
    "uppgjordares": "uppgjord",
    "uppgjordas": "uppgjord",
    "uppgjordast": "uppgjord",
    "uppgjordaste": "uppgjord",
    "uppgjordastes": "uppgjord",
    "uppgjordasts": "uppgjord",
    "uppgjorde": "uppgjord",
    "uppgjordes": "uppgjord",
    "uppgjords": "uppgjord",
    "uppgjort": "uppgjord",
    "uppgjorts": "uppgjord",
    "uppgraderad": "uppgradera",
    "uppgraderade": "uppgradera",
    "uppgraderades": "uppgradera",
    "uppgraderads": "uppgradera",
    "uppgraderande": "uppgradera",
    "uppgraderanden": "uppgraderande",
    "uppgraderandena": "uppgraderande",
    "uppgraderandenas": "uppgraderande",
    "uppgraderandens": "uppgraderande",
    "uppgraderandes": "uppgraderande",
    "uppgraderandet": "uppgraderande",
    "uppgraderandets": "uppgraderande",
    "uppgraderar": "uppgradera",
    "uppgraderas": "uppgradera",
    "uppgraderat": "uppgradera",
    "uppgraderats": "uppgradera",
    "uppgraderbara": "uppgraderbar",
    "uppgraderbarare": "uppgraderbar",
    "uppgraderbarares": "uppgraderbar",
    "uppgraderbaras": "uppgraderbar",
    "uppgraderbarast": "uppgraderbar",
    "uppgraderbaraste": "uppgraderbar",
    "uppgraderbarastes": "uppgraderbar",
    "uppgraderbarasts": "uppgraderbar",
    "uppgraderbare": "uppgraderbar",
    "uppgraderbares": "uppgraderbar",
    "uppgraderbarheten": "uppgraderbarhet",
    "uppgraderbarhetens": "uppgraderbarhet",
    "uppgraderbarhets": "uppgraderbarhet",
    "uppgraderbars": "uppgraderbar",
    "uppgraderbart": "uppgraderbar",
    "uppgraderbarts": "uppgraderbar",
    "uppgrundningar": "uppgrundning",
    "uppgrundningarna": "uppgrundning",
    "uppgrundningarnas": "uppgrundning",
    "uppgrundningars": "uppgrundning",
    "uppgrundningen": "uppgrundning",
    "uppgrundningens": "uppgrundning",
    "uppgrundnings": "uppgrundning",
    "uppgummade": "uppgummad",
    "uppgummades": "uppgummad",
    "uppgummads": "uppgummad",
    "uppgummat": "uppgummad",
    "uppgummats": "uppgummad",
    "uppgälden": "uppgäld",
    "uppgäldens": "uppgäld",
    "uppgälder": "uppgäld",
    "uppgälderna": "uppgäld",
    "uppgäldernas": "uppgäld",
    "uppgälders": "uppgäld",
    "uppgälds": "uppgäld",
    "uppgående": "uppgå",
    "uppgåenden": "uppgående",
    "uppgåendena": "uppgående",
    "uppgåendenas": "uppgående",
    "uppgåendens": "uppgående",
    "uppgåendes": "uppgående",
    "uppgåendet": "uppgående",
    "uppgåendets": "uppgående",
    "uppgångar": "uppgång",
    "uppgångarna": "uppgång",
    "uppgångarnas": "uppgång",
    "uppgångars": "uppgång",
    "uppgånge": "uppgå",
    "uppgången": "uppgång",
    "uppgångens": "uppgång",
    "uppgånges": "uppgå",
    "uppgånget": "uppgå",
    "uppgångets": "uppgå",
    "uppgångna": "uppgå",
    "uppgångnas": "uppgå",
    "uppgångne": "uppgå",
    "uppgångnes": "uppgå",
    "uppgångs": "uppgång",
    "uppgår": "uppgå",
    "uppgås": "uppgå",
    "uppgått": "uppgå",
    "uppgåtts": "uppgå",
    "uppgåve": "uppge",
    "uppgåves": "uppge",
    "uppgörelsen": "uppgörelse",
    "uppgörelsens": "uppgörelse",
    "uppgörelser": "uppgörelse",
    "uppgörelserna": "uppgörelse",
    "uppgörelsernas": "uppgörelse",
    "uppgörelsers": "uppgörelse",
    "uppgörelses": "uppgörelse",
    "upphalar": "upphalare",
    "upphalaren": "upphalare",
    "upphalarens": "upphalare",
    "upphalares": "upphalare",
    "upphalarna": "upphalare",
    "upphalarnas": "upphalare",
    "upphalningsbäddar": "upphalningsbädd",
    "upphalningsbäddarna": "upphalningsbädd",
    "upphalningsbäddarnas": "upphalningsbädd",
    "upphalningsbäddars": "upphalningsbädd",
    "upphalningsbädden": "upphalningsbädd",
    "upphalningsbäddens": "upphalningsbädd",
    "upphalningsbädds": "upphalningsbädd",
    "upphandlad": "upphandla",
    "upphandlade": "upphandla",
    "upphandlades": "upphandla",
    "upphandlads": "upphandla",
    "upphandlande": "upphandla",
    "upphandlanden": "upphandlande",
    "upphandlandena": "upphandlande",
    "upphandlandenas": "upphandlande",
    "upphandlandens": "upphandlande",
    "upphandlandes": "upphandlande",
    "upphandlandet": "upphandlande",
    "upphandlandets": "upphandlande",
    "upphandlar": "upphandlare",
    "upphandlaren": "upphandlare",
    "upphandlarens": "upphandlare",
    "upphandlares": "upphandlare",
    "upphandlarna": "upphandlare",
    "upphandlarnas": "upphandlare",
    "upphandlas": "upphandla",
    "upphandlat": "upphandla",
    "upphandlats": "upphandla",
    "upphandlingar": "upphandling",
    "upphandlingarna": "upphandling",
    "upphandlingarnas": "upphandling",
    "upphandlingars": "upphandling",
    "upphandlingen": "upphandling",
    "upphandlingens": "upphandling",
    "upphandlings": "upphandling",
    "upphauss": "upphaussa",
    "upphaussad": "upphaussa",
    "upphaussade": "upphaussa",
    "upphaussades": "upphaussa",
    "upphaussads": "upphaussa",
    "upphaussande": "upphaussa",
    "upphaussanden": "upphaussande",
    "upphaussandena": "upphaussande",
    "upphaussandenas": "upphaussande",
    "upphaussandens": "upphaussande",
    "upphaussandes": "upphaussande",
    "upphaussandet": "upphaussande",
    "upphaussandets": "upphaussande",
    "upphaussar": "upphaussa",
    "upphaussas": "upphaussa",
    "upphaussat": "upphaussa",
    "upphaussats": "upphaussa",
    "upphets": "upphetsa",
    "upphetsad": "upphetsa",
    "upphetsade": "upphetsad",
    "upphetsades": "upphetsad",
    "upphetsads": "upphetsad",
    "upphetsande": "upphetsa",
    "upphetsanden": "upphetsande",
    "upphetsandena": "upphetsande",
    "upphetsandenas": "upphetsande",
    "upphetsandens": "upphetsande",
    "upphetsandes": "upphetsande",
    "upphetsandet": "upphetsande",
    "upphetsandets": "upphetsande",
    "upphetsar": "upphetsa",
    "upphetsas": "upphetsa",
    "upphetsat": "upphetsad",
    "upphetsats": "upphetsad",
    "upphetsningar": "upphetsning",
    "upphetsningarna": "upphetsning",
    "upphetsningarnas": "upphetsning",
    "upphetsningars": "upphetsning",
    "upphetsningen": "upphetsning",
    "upphetsningens": "upphetsning",
    "upphetsnings": "upphetsning",
    "upphett": "upphetta",
    "upphettad": "upphetta",
    "upphettade": "upphetta",
    "upphettades": "upphetta",
    "upphettads": "upphetta",
    "upphettande": "upphetta",
    "upphettanden": "upphettande",
    "upphettandena": "upphettande",
    "upphettandenas": "upphettande",
    "upphettandens": "upphettande",
    "upphettandes": "upphettande",
    "upphettandet": "upphettande",
    "upphettandets": "upphettande",
    "upphettar": "upphetta",
    "upphettas": "upphetta",
    "upphettat": "upphetta",
    "upphettats": "upphetta",
    "upphettningar": "upphettning",
    "upphettningarna": "upphettning",
    "upphettningarnas": "upphettning",
    "upphettningars": "upphettning",
    "upphettningen": "upphettning",
    "upphettningens": "upphettning",
    "upphettnings": "upphettning",
    "upphinneliga": "upphinnelig",
    "upphinneligare": "upphinnelig",
    "upphinneligares": "upphinnelig",
    "upphinneligas": "upphinnelig",
    "upphinneligast": "upphinnelig",
    "upphinneligaste": "upphinnelig",
    "upphinneligastes": "upphinnelig",
    "upphinneligasts": "upphinnelig",
    "upphinnelige": "upphinnelig",
    "upphinneliges": "upphinnelig",
    "upphinneligheten": "upphinnelighet",
    "upphinnelighetens": "upphinnelighet",
    "upphinnelighets": "upphinnelighet",
    "upphinneligs": "upphinnelig",
    "upphinneligt": "upphinnelig",
    "upphinneligts": "upphinnelig",
    "upphitt": "upphitta",
    "upphittad": "upphitta",
    "upphittade": "upphitta",
    "upphittades": "upphitta",
    "upphittads": "upphitta",
    "upphittande": "upphitta",
    "upphittanden": "upphittande",
    "upphittandena": "upphittande",
    "upphittandenas": "upphittande",
    "upphittandens": "upphittande",
    "upphittandes": "upphittande",
    "upphittandet": "upphittande",
    "upphittandets": "upphittande",
    "upphittar": "upphitta",
    "upphittas": "upphitta",
    "upphittat": "upphitta",
    "upphittats": "upphitta",
    "upphoppen": "upphopp",
    "upphoppens": "upphopp",
    "upphoppet": "upphopp",
    "upphoppets": "upphopp",
    "upphopps": "upphopp",
    "upphostningar": "upphostning",
    "upphostningarna": "upphostning",
    "upphostningarnas": "upphostning",
    "upphostningars": "upphostning",
    "upphostningen": "upphostning",
    "upphostningens": "upphostning",
    "upphostnings": "upphostning",
    "upphottanden": "upphottande",
    "upphottandena": "upphottande",
    "upphottandenas": "upphottande",
    "upphottandens": "upphottande",
    "upphottandes": "upphottande",
    "upphottandet": "upphottande",
    "upphottandets": "upphottande",
    "upphottningar": "upphottning",
    "upphottningarna": "upphottning",
    "upphottningarnas": "upphottning",
    "upphottningars": "upphottning",
    "upphottningen": "upphottning",
    "upphottningens": "upphottning",
    "upphottnings": "upphottning",
    "upphov": "upphäva",
    "upphove": "upphäva",
    "upphoves": "upphäva",
    "upphovet": "upphov",
    "upphovets": "upphov",
    "upphovs": "upphov",
    "upphovsmannarätten": "upphovsmannarätt",
    "upphovsmannarättens": "upphovsmannarätt",
    "upphovsmannarätts": "upphovsmannarätt",
    "upphovsmannen": "upphovsman",
    "upphovsmannens": "upphovsman",
    "upphovsmans": "upphovsman",
    "upphovsmän": "upphovsman",
    "upphovsmännen": "upphovsman",
    "upphovsmännens": "upphovsman",
    "upphovsmäns": "upphovsman",
    "upphovsrätten": "upphovsrätt",
    "upphovsrättens": "upphovsrätt",
    "upphovsrätts": "upphovsrätt",
    "upphovsrättsbrotten": "upphovsrättsbrott",
    "upphovsrättsbrottens": "upphovsrättsbrott",
    "upphovsrättsbrottet": "upphovsrättsbrott",
    "upphovsrättsbrottets": "upphovsrättsbrott",
    "upphovsrättsbrotts": "upphovsrättsbrott",
    "upphovsrättsinnehavar": "upphovsrättsinnehavare",
    "upphovsrättsinnehavaren": "upphovsrättsinnehavare",
    "upphovsrättsinnehavarens": "upphovsrättsinnehavare",
    "upphovsrättsinnehavares": "upphovsrättsinnehavare",
    "upphovsrättsinnehavarna": "upphovsrättsinnehavare",
    "upphovsrättsinnehavarnas": "upphovsrättsinnehavare",
    "upphämt": "upphämta",
    "upphämtad": "upphämta",
    "upphämtade": "upphämta",
    "upphämtades": "upphämta",
    "upphämtads": "upphämta",
    "upphämtan": "upphämta",
    "upphämtande": "upphämta",
    "upphämtanden": "upphämtande",
    "upphämtandena": "upphämtande",
    "upphämtandenas": "upphämtande",
    "upphämtandens": "upphämtande",
    "upphämtandes": "upphämtande",
    "upphämtandet": "upphämtande",
    "upphämtandets": "upphämtande",
    "upphämtans": "upphämta",
    "upphämtar": "upphämta",
    "upphämtas": "upphämta",
    "upphämtat": "upphämta",
    "upphämtats": "upphämta",
    "upphämtningar": "upphämtning",
    "upphämtningarna": "upphämtning",
    "upphämtningarnas": "upphämtning",
    "upphämtningars": "upphämtning",
    "upphämtningen": "upphämtning",
    "upphämtningens": "upphämtning",
    "upphämtnings": "upphämtning",
    "upphängningar": "upphängning",
    "upphängningarna": "upphängning",
    "upphängningarnas": "upphängning",
    "upphängningars": "upphängning",
    "upphängningen": "upphängning",
    "upphängningens": "upphängning",
    "upphängnings": "upphängning",
    "upphängningskrokar": "upphängningskrok",
    "upphängningskrokarna": "upphängningskrok",
    "upphängningskrokarnas": "upphängningskrok",
    "upphängningskrokars": "upphängningskrok",
    "upphängningskroken": "upphängningskrok",
    "upphängningskrokens": "upphängningskrok",
    "upphängningskroks": "upphängningskrok",
    "upphängningsöglan": "upphängningsögla",
    "upphängningsöglans": "upphängningsögla",
    "upphängningsöglas": "upphängningsögla",
    "upphängningsögle": "upphängningsögla",
    "upphängningsöglor": "upphängningsögla",
    "upphängningsöglorna": "upphängningsögla",
    "upphängningsöglornas": "upphängningsögla",
    "upphängningsöglors": "upphängningsögla",
    "upphäv": "upphäva",
    "upphävande": "upphäva",
    "upphävanden": "upphävande",
    "upphävandena": "upphävande",
    "upphävandenas": "upphävande",
    "upphävandens": "upphävande",
    "upphävandes": "upphävande",
    "upphävandet": "upphävande",
    "upphävandets": "upphävande",
    "upphävas": "upphäva",
    "upphävd": "upphäva",
    "upphävda": "upphäva",
    "upphävdas": "upphäva",
    "upphävde": "upphäva",
    "upphävdes": "upphäva",
    "upphävds": "upphäva",
    "upphäve": "upphäva",
    "upphäver": "upphäva",
    "upphäves": "upphäva",
    "upphävs": "upphäva",
    "upphävt": "upphäva",
    "upphävts": "upphäva",
    "upphöj": "upphöja",
    "upphöjande": "upphöja",
    "upphöjanden": "upphöjande",
    "upphöjandena": "upphöjande",
    "upphöjandenas": "upphöjande",
    "upphöjandens": "upphöjande",
    "upphöjandes": "upphöjande",
    "upphöjandet": "upphöjande",
    "upphöjandets": "upphöjande",
    "upphöjas": "upphöja",
    "upphöjd": "upphöja",
    "upphöjda": "upphöjd",
    "upphöjdare": "upphöjd",
    "upphöjdares": "upphöjd",
    "upphöjdas": "upphöjd",
    "upphöjdast": "upphöjd",
    "upphöjdaste": "upphöjd",
    "upphöjdastes": "upphöjd",
    "upphöjdasts": "upphöjd",
    "upphöjde": "upphöjd",
    "upphöjdes": "upphöjd",
    "upphöjdheten": "upphöjdhet",
    "upphöjdhetens": "upphöjdhet",
    "upphöjdheter": "upphöjdhet",
    "upphöjdheterna": "upphöjdhet",
    "upphöjdheternas": "upphöjdhet",
    "upphöjdheters": "upphöjdhet",
    "upphöjdhets": "upphöjdhet",
    "upphöjds": "upphöjd",
    "upphöjelsen": "upphöjelse",
    "upphöjelsens": "upphöjelse",
    "upphöjelser": "upphöjelse",
    "upphöjelserna": "upphöjelse",
    "upphöjelsernas": "upphöjelse",
    "upphöjelsers": "upphöjelse",
    "upphöjelses": "upphöjelse",
    "upphöjer": "upphöja",
    "upphöjes": "upphöja",
    "upphöjningar": "upphöjning",
    "upphöjningarna": "upphöjning",
    "upphöjningarnas": "upphöjning",
    "upphöjningars": "upphöjning",
    "upphöjningen": "upphöjning",
    "upphöjningens": "upphöjning",
    "upphöjnings": "upphöjning",
    "upphöjs": "upphöja",
    "upphöjt": "upphöjd",
    "upphöjts": "upphöjd",
    "upphör": "upphöra",
    "upphörande": "upphöra",
    "upphöranden": "upphörande",
    "upphörandena": "upphörande",
    "upphörandenas": "upphörande",
    "upphörandens": "upphörande",
    "upphörandes": "upphörande",
    "upphörandet": "upphörande",
    "upphörandets": "upphörande",
    "upphöras": "upphöra",
    "upphörd": "upphöra",
    "upphörda": "upphöra",
    "upphördas": "upphöra",
    "upphörde": "upphöra",
    "upphördes": "upphöra",
    "upphörds": "upphöra",
    "upphöres": "upphöra",
    "upphörs": "upphöra",
    "upphört": "upphöra",
    "upphörts": "upphöra",
    "uppigganden": "uppiggande",
    "uppiggandena": "uppiggande",
    "uppiggandenas": "uppiggande",
    "uppiggandens": "uppiggande",
    "uppiggandes": "uppiggande",
    "uppiggandet": "uppiggande",
    "uppiggandets": "uppiggande",
    "uppiskade": "uppiskad",
    "uppiskades": "uppiskad",
    "uppiskads": "uppiskad",
    "uppiskat": "uppiskad",
    "uppiskats": "uppiskad",
    "uppjagade": "uppjagad",
    "uppjagades": "uppjagad",
    "uppjagads": "uppjagad",
    "uppjagat": "uppjagad",
    "uppjagats": "uppjagad",
    "uppjazz": "uppjazza",
    "uppjazzad": "uppjazza",
    "uppjazzade": "uppjazza",
    "uppjazzades": "uppjazza",
    "uppjazzads": "uppjazza",
    "uppjazzande": "uppjazza",
    "uppjazzanden": "uppjazzande",
    "uppjazzandena": "uppjazzande",
    "uppjazzandenas": "uppjazzande",
    "uppjazzandens": "uppjazzande",
    "uppjazzandes": "uppjazzande",
    "uppjazzandet": "uppjazzande",
    "uppjazzandets": "uppjazzande",
    "uppjazzar": "uppjazza",
    "uppjazzas": "uppjazza",
    "uppjazzat": "uppjazza",
    "uppjazzats": "uppjazza",
    "uppjusterad": "uppjustera",
    "uppjusterade": "uppjustera",
    "uppjusterades": "uppjustera",
    "uppjusterads": "uppjustera",
    "uppjusterande": "uppjustera",
    "uppjusteranden": "uppjusterande",
    "uppjusterandena": "uppjusterande",
    "uppjusterandenas": "uppjusterande",
    "uppjusterandens": "uppjusterande",
    "uppjusterandes": "uppjusterande",
    "uppjusterandet": "uppjusterande",
    "uppjusterandets": "uppjusterande",
    "uppjusterar": "uppjustera",
    "uppjusteras": "uppjustera",
    "uppjusterat": "uppjustera",
    "uppjusterats": "uppjustera",
    "uppjusterbara": "uppjusterbar",
    "uppjusterbarare": "uppjusterbar",
    "uppjusterbarares": "uppjusterbar",
    "uppjusterbaras": "uppjusterbar",
    "uppjusterbarast": "uppjusterbar",
    "uppjusterbaraste": "uppjusterbar",
    "uppjusterbarastes": "uppjusterbar",
    "uppjusterbarasts": "uppjusterbar",
    "uppjusterbare": "uppjusterbar",
    "uppjusterbares": "uppjusterbar",
    "uppjusterbarheten": "uppjusterbarhet",
    "uppjusterbarhetens": "uppjusterbarhet",
    "uppjusterbarhets": "uppjusterbarhet",
    "uppjusterbars": "uppjusterbar",
    "uppjusterbart": "uppjusterbar",
    "uppjusterbarts": "uppjusterbar",
    "uppjusteringar": "uppjustering",
    "uppjusteringarna": "uppjustering",
    "uppjusteringarnas": "uppjustering",
    "uppjusteringars": "uppjustering",
    "uppjusteringen": "uppjustering",
    "uppjusteringens": "uppjustering",
    "uppjusterings": "uppjustering",
    "uppkall": "uppkalla",
    "uppkallad": "uppkalla",
    "uppkallade": "uppkalla",
    "uppkallades": "uppkalla",
    "uppkallads": "uppkalla",
    "uppkallande": "uppkalla",
    "uppkallanden": "uppkallande",
    "uppkallandena": "uppkallande",
    "uppkallandenas": "uppkallande",
    "uppkallandens": "uppkallande",
    "uppkallandes": "uppkallande",
    "uppkallandet": "uppkallande",
    "uppkallandets": "uppkallande",
    "uppkallar": "uppkalla",
    "uppkallas": "uppkalla",
    "uppkallat": "uppkalla",
    "uppkallats": "uppkalla",
    "uppkammade": "uppkammad",
    "uppkammades": "uppkammad",
    "uppkammads": "uppkammad",
    "uppkammat": "uppkammad",
    "uppkammats": "uppkammad",
    "uppkasten": "uppkast",
    "uppkastens": "uppkast",
    "uppkastet": "uppkast",
    "uppkastets": "uppkast",
    "uppkastningar": "uppkastning",
    "uppkastningarna": "uppkastning",
    "uppkastningarnas": "uppkastning",
    "uppkastningars": "uppkastning",
    "uppkastningen": "uppkastning",
    "uppkastningens": "uppkastning",
    "uppkastnings": "uppkastning",
    "uppkasts": "uppkast",
    "uppkavlade": "uppkavlad",
    "uppkavlades": "uppkavlad",
    "uppkavlads": "uppkavlad",
    "uppkavlat": "uppkavlad",
    "uppkavlats": "uppkavlad",
    "uppklar": "uppklara",
    "uppklarad": "uppklara",
    "uppklarade": "uppklara",
    "uppklarades": "uppklara",
    "uppklarads": "uppklara",
    "uppklarande": "uppklara",
    "uppklaranden": "uppklarande",
    "uppklarandena": "uppklarande",
    "uppklarandenas": "uppklarande",
    "uppklarandens": "uppklarande",
    "uppklarandes": "uppklarande",
    "uppklarandet": "uppklarande",
    "uppklarandets": "uppklarande",
    "uppklarar": "uppklara",
    "uppklaras": "uppklara",
    "uppklarat": "uppklara",
    "uppklarats": "uppklara",
    "uppklippta": "uppklippt",
    "uppklipptare": "uppklippt",
    "uppklipptares": "uppklippt",
    "uppklipptas": "uppklippt",
    "uppklipptast": "uppklippt",
    "uppklipptaste": "uppklippt",
    "uppklipptastes": "uppklippt",
    "uppklipptasts": "uppklippt",
    "uppklippte": "uppklippt",
    "uppklipptes": "uppklippt",
    "uppklippts": "uppklippt",
    "uppklädda": "uppklädd",
    "uppkläddare": "uppklädd",
    "uppkläddares": "uppklädd",
    "uppkläddas": "uppklädd",
    "uppkläddast": "uppklädd",
    "uppkläddaste": "uppklädd",
    "uppkläddastes": "uppklädd",
    "uppkläddasts": "uppklädd",
    "uppklädde": "uppklädd",
    "uppkläddes": "uppklädd",
    "uppkläddheten": "uppkläddhet",
    "uppkläddhetens": "uppkläddhet",
    "uppkläddhets": "uppkläddhet",
    "uppklädds": "uppklädd",
    "uppklätt": "uppklädd",
    "uppklätts": "uppklädd",
    "uppknutens": "uppknuten",
    "uppknutet": "uppknuten",
    "uppknutets": "uppknuten",
    "uppknutna": "uppknuten",
    "uppknutnare": "uppknuten",
    "uppknutnares": "uppknuten",
    "uppknutnas": "uppknuten",
    "uppknutnast": "uppknuten",
    "uppknutnaste": "uppknuten",
    "uppknutnastes": "uppknuten",
    "uppknutnasts": "uppknuten",
    "uppknutne": "uppknuten",
    "uppknutnes": "uppknuten",
    "uppknäppta": "uppknäppt",
    "uppknäpptare": "uppknäppt",
    "uppknäpptares": "uppknäppt",
    "uppknäpptas": "uppknäppt",
    "uppknäpptast": "uppknäppt",
    "uppknäpptaste": "uppknäppt",
    "uppknäpptastes": "uppknäppt",
    "uppknäpptasts": "uppknäppt",
    "uppknäppte": "uppknäppt",
    "uppknäpptes": "uppknäppt",
    "uppknäpptheten": "uppknäppthet",
    "uppknäppthetens": "uppknäppthet",
    "uppknäppthets": "uppknäppthet",
    "uppknäppts": "uppknäppt",
    "uppkoken": "uppkok",
    "uppkokens": "uppkok",
    "uppkoket": "uppkok",
    "uppkokets": "uppkok",
    "uppkoks": "uppkok",
    "uppkolningar": "uppkolning",
    "uppkolningarna": "uppkolning",
    "uppkolningarnas": "uppkolning",
    "uppkolningars": "uppkolning",
    "uppkolningen": "uppkolning",
    "uppkolningens": "uppkolning",
    "uppkolnings": "uppkolning",
    "uppkom": "uppkomma",
    "uppkomet": "uppkomma",
    "uppkomets": "uppkomma",
    "uppkomlingar": "uppkomling",
    "uppkomlingarna": "uppkomling",
    "uppkomlingarnas": "uppkomling",
    "uppkomlingars": "uppkomling",
    "uppkomlingen": "uppkomling",
    "uppkomlingens": "uppkomling",
    "uppkomlings": "uppkomling",
    "uppkommande": "uppkomma",
    "uppkommanden": "uppkommande",
    "uppkommandena": "uppkommande",
    "uppkommandenas": "uppkommande",
    "uppkommandens": "uppkommande",
    "uppkommandes": "uppkommande",
    "uppkommandet": "uppkommande",
    "uppkommandets": "uppkommande",
    "uppkommas": "uppkomma",
    "uppkomme": "uppkomma",
    "uppkommen": "uppkomma",
    "uppkommens": "uppkomma",
    "uppkommer": "uppkomma",
    "uppkommes": "uppkomma",
    "uppkommit": "uppkomma",
    "uppkommits": "uppkomma",
    "uppkomna": "uppkomma",
    "uppkomnas": "uppkomma",
    "uppkomne": "uppkomma",
    "uppkomnes": "uppkomma",
    "uppkoms": "uppkomma",
    "uppkomsten": "uppkomst",
    "uppkomstens": "uppkomst",
    "uppkomsts": "uppkomst",
    "uppkvist": "uppkvista",
    "uppkvistad": "uppkvista",
    "uppkvistade": "uppkvista",
    "uppkvistades": "uppkvista",
    "uppkvistads": "uppkvista",
    "uppkvistande": "uppkvista",
    "uppkvistanden": "uppkvistande",
    "uppkvistandena": "uppkvistande",
    "uppkvistandenas": "uppkvistande",
    "uppkvistandens": "uppkvistande",
    "uppkvistandes": "uppkvistande",
    "uppkvistandet": "uppkvistande",
    "uppkvistandets": "uppkvistande",
    "uppkvistar": "uppkvista",
    "uppkvistas": "uppkvista",
    "uppkvistat": "uppkvista",
    "uppkvistats": "uppkvista",
    "uppkäftiga": "uppkäftig",
    "uppkäftigare": "uppkäftig",
    "uppkäftigares": "uppkäftig",
    "uppkäftigas": "uppkäftig",
    "uppkäftigast": "uppkäftig",
    "uppkäftigaste": "uppkäftig",
    "uppkäftigastes": "uppkäftig",
    "uppkäftigasts": "uppkäftig",
    "uppkäftige": "uppkäftig",
    "uppkäftiges": "uppkäftig",
    "uppkäftigheten": "uppkäftighet",
    "uppkäftighetens": "uppkäftighet",
    "uppkäftigheter": "uppkäftighet",
    "uppkäftigheterna": "uppkäftighet",
    "uppkäftigheternas": "uppkäftighet",
    "uppkäftigheters": "uppkäftighet",
    "uppkäftighets": "uppkäftighet",
    "uppkäftigs": "uppkäftig",
    "uppkäftigt": "uppkäftig",
    "uppkäftigts": "uppkäftig",
    "uppköpar": "uppköpare",
    "uppköparen": "uppköpare",
    "uppköparens": "uppköpare",
    "uppköpares": "uppköpare",
    "uppköparna": "uppköpare",
    "uppköparnas": "uppköpare",
    "uppköpen": "uppköp",
    "uppköpens": "uppköp",
    "uppköpet": "uppköp",
    "uppköpets": "uppköp",
    "uppköps": "uppköp",
    "uppkörda": "uppkörd",
    "uppkördare": "uppkörd",
    "uppkördares": "uppkörd",
    "uppkördas": "uppkörd",
    "uppkördast": "uppkörd",
    "uppkördaste": "uppkörd",
    "uppkördastes": "uppkörd",
    "uppkördasts": "uppkörd",
    "uppkörde": "uppkörd",
    "uppkördes": "uppkörd",
    "uppkördheten": "uppkördhet",
    "uppkördhetens": "uppkördhet",
    "uppkördhets": "uppkördhet",
    "uppkörds": "uppkörd",
    "uppkörningar": "uppkörning",
    "uppkörningarna": "uppkörning",
    "uppkörningarnas": "uppkörning",
    "uppkörningars": "uppkörning",
    "uppkörningen": "uppkörning",
    "uppkörningens": "uppkörning",
    "uppkörnings": "uppkörning",
    "uppkörningsrampen": "uppkörningsramp",
    "uppkörningsrampens": "uppkörningsramp",
    "uppkörningsramper": "uppkörningsramp",
    "uppkörningsramperna": "uppkörningsramp",
    "uppkörningsrampernas": "uppkörningsramp",
    "uppkörningsrampers": "uppkörningsramp",
    "uppkörningsramps": "uppkörningsramp",
    "uppkörsvägar": "uppkörsväg",
    "uppkörsvägarna": "uppkörsväg",
    "uppkörsvägarnas": "uppkörsväg",
    "uppkörsvägars": "uppkörsväg",
    "uppkörsvägen": "uppkörsväg",
    "uppkörsvägens": "uppkörsväg",
    "uppkörsvägs": "uppkörsväg",
    "uppkört": "uppkörd",
    "uppkörts": "uppkörd",
    "uppla": "upplägga",
    "uppladdade": "uppladdad",
    "uppladdades": "uppladdad",
    "uppladdads": "uppladdad",
    "uppladdat": "uppladdad",
    "uppladdats": "uppladdad",
    "uppladdningar": "uppladdning",
    "uppladdningarna": "uppladdning",
    "uppladdningarnas": "uppladdning",
    "uppladdningars": "uppladdning",
    "uppladdningen": "uppladdning",
    "uppladdningens": "uppladdning",
    "uppladdnings": "uppladdning",
    "upplade": "upplägga",
    "upplades": "upplägga",
    "upplagan": "upplaga",
    "upplagans": "upplaga",
    "upplagas": "upplaga",
    "upplagd": "upplägga",
    "upplagda": "upplägga",
    "upplagdare": "upplagd",
    "upplagdares": "upplagd",
    "upplagdas": "upplägga",
    "upplagdast": "upplagd",
    "upplagdaste": "upplagd",
    "upplagdastes": "upplagd",
    "upplagdasts": "upplagd",
    "upplagde": "upplägga",
    "upplagdes": "upplägga",
    "upplagds": "upplägga",
    "upplage": "upplaga",
    "upplagemässiga": "upplagemässig",
    "upplagemässigare": "upplagemässig",
    "upplagemässigares": "upplagemässig",
    "upplagemässigas": "upplagemässig",
    "upplagemässigast": "upplagemässig",
    "upplagemässigaste": "upplagemässig",
    "upplagemässigastes": "upplagemässig",
    "upplagemässigasts": "upplagemässig",
    "upplagemässige": "upplagemässig",
    "upplagemässiges": "upplagemässig",
    "upplagemässigs": "upplagemässig",
    "upplagemässigt": "upplagemässig",
    "upplagemässigts": "upplagemässig",
    "upplagen": "upplag",
    "upplagens": "upplag",
    "upplagesiffer": "upplagesiffra",
    "upplagesiffran": "upplagesiffra",
    "upplagesiffrans": "upplagesiffra",
    "upplagesiffras": "upplagesiffra",
    "upplagesiffre": "upplagesiffra",
    "upplagesiffror": "upplagesiffra",
    "upplagesiffrorna": "upplagesiffra",
    "upplagesiffrornas": "upplagesiffra",
    "upplagesiffrors": "upplagesiffra",
    "upplagespiralen": "upplagespiral",
    "upplagespiralens": "upplagespiral",
    "upplagespirals": "upplagespiral",
    "upplaget": "upplag",
    "upplagets": "upplag",
    "upplagor": "upplaga",
    "upplagorna": "upplaga",
    "upplagornas": "upplaga",
    "upplagors": "upplaga",
    "upplagrad": "upplagra",
    "upplagrade": "upplagra",
    "upplagrades": "upplagra",
    "upplagrads": "upplagra",
    "upplagrande": "upplagra",
    "upplagranden": "upplagrande",
    "upplagrandena": "upplagrande",
    "upplagrandenas": "upplagrande",
    "upplagrandens": "upplagrande",
    "upplagrandes": "upplagrande",
    "upplagrandet": "upplagrande",
    "upplagrandets": "upplagrande",
    "upplagrar": "upplagra",
    "upplagras": "upplagra",
    "upplagrat": "upplagra",
    "upplagrats": "upplagra",
    "upplagringsplatsen": "upplagringsplats",
    "upplagringsplatsens": "upplagringsplats",
    "upplagringsplatser": "upplagringsplats",
    "upplagringsplatserna": "upplagringsplats",
    "upplagringsplatsernas": "upplagringsplats",
    "upplagringsplatsers": "upplagringsplats",
    "upplags": "upplag",
    "upplagscellen": "upplagscell",
    "upplagscellens": "upplagscell",
    "upplagsceller": "upplagscell",
    "upplagscellerna": "upplagscell",
    "upplagscellernas": "upplagscell",
    "upplagscellers": "upplagscell",
    "upplagscells": "upplagscell",
    "upplagsnäringen": "upplagsnäring",
    "upplagsnäringens": "upplagsnäring",
    "upplagsnärings": "upplagsnäring",
    "upplagsplatsen": "upplagsplats",
    "upplagsplatsens": "upplagsplats",
    "upplagsplatser": "upplagsplats",
    "upplagsplatserna": "upplagsplats",
    "upplagsplatsernas": "upplagsplats",
    "upplagsplatsers": "upplagsplats",
    "upplagt": "upplägga",
    "upplagts": "upplägga",
    "upplandade": "upplandad",
    "upplandades": "upplandad",
    "upplandads": "upplandad",
    "upplandat": "upplandad",
    "upplandats": "upplandad",
    "upplanden": "uppland",
    "upplandens": "uppland",
    "upplandet": "uppland",
    "upplandets": "uppland",
    "upplands": "uppland",
    "upplandskyrk": "upplandskyrka",
    "upplandskyrkan": "upplandskyrka",
    "upplandskyrkans": "upplandskyrka",
    "upplandskyrkas": "upplandskyrka",
    "upplandskyrke": "upplandskyrka",
    "upplandskyrko": "upplandskyrka",
    "upplandskyrkor": "upplandskyrka",
    "upplandskyrkorna": "upplandskyrka",
    "upplandskyrkornas": "upplandskyrka",
    "upplandskyrkors": "upplandskyrka",
    "upplandskyrks": "upplandskyrka",
    "upplapp": "upplappa",
    "upplappad": "upplappa",
    "upplappade": "upplappa",
    "upplappades": "upplappa",
    "upplappads": "upplappa",
    "upplappande": "upplappa",
    "upplappanden": "upplappande",
    "upplappandena": "upplappande",
    "upplappandenas": "upplappande",
    "upplappandens": "upplappande",
    "upplappandes": "upplappande",
    "upplappandet": "upplappande",
    "upplappandets": "upplappande",
    "upplappar": "upplappa",
    "upplappas": "upplappa",
    "upplappat": "upplappa",
    "upplappats": "upplappa",
    "upplas": "upplägga",
    "uppleg": "upplega",
    "upplegan": "upplega",
    "upplegans": "upplega",
    "upplegas": "upplega",
    "upplege": "upplega",
    "upplegor": "upplega",
    "upplegorna": "upplega",
    "upplegornas": "upplega",
    "upplegors": "upplega",
    "upplegs": "upplega",
    "upplev": "uppleva",
    "upplevande": "uppleva",
    "upplevanden": "upplevande",
    "upplevandena": "upplevande",
    "upplevandenas": "upplevande",
    "upplevandens": "upplevande",
    "upplevandes": "upplevande",
    "upplevandet": "upplevande",
    "upplevandets": "upplevande",
    "upplevas": "uppleva",
    "upplevat": "uppleva",
    "upplevats": "uppleva",
    "upplevd": "uppleva",
    "upplevda": "uppleva",
    "upplevdas": "uppleva",
    "upplevde": "uppleva",
    "upplevdes": "uppleva",
    "upplevds": "uppleva",
    "upplevelseläsningar": "upplevelseläsning",
    "upplevelseläsningarna": "upplevelseläsning",
    "upplevelseläsningarnas": "upplevelseläsning",
    "upplevelseläsningars": "upplevelseläsning",
    "upplevelseläsningen": "upplevelseläsning",
    "upplevelseläsningens": "upplevelseläsning",
    "upplevelseläsnings": "upplevelseläsning",
    "upplevelsemässiga": "upplevelsemässig",
    "upplevelsemässigare": "upplevelsemässig",
    "upplevelsemässigares": "upplevelsemässig",
    "upplevelsemässigas": "upplevelsemässig",
    "upplevelsemässigast": "upplevelsemässig",
    "upplevelsemässigaste": "upplevelsemässig",
    "upplevelsemässigastes": "upplevelsemässig",
    "upplevelsemässigasts": "upplevelsemässig",
    "upplevelsemässige": "upplevelsemässig",
    "upplevelsemässiges": "upplevelsemässig",
    "upplevelsemässigs": "upplevelsemässig",
    "upplevelsemässigt": "upplevelsemässig",
    "upplevelsemässigts": "upplevelsemässig",
    "upplevelsen": "upplevelse",
    "upplevelsens": "upplevelse",
    "upplevelser": "upplevelse",
    "upplevelserna": "upplevelse",
    "upplevelsernas": "upplevelse",
    "upplevelsers": "upplevelse",
    "upplevelses": "upplevelse",
    "upplevelsevandringar": "upplevelsevandring",
    "upplevelsevandringarna": "upplevelsevandring",
    "upplevelsevandringarnas": "upplevelsevandring",
    "upplevelsevandringars": "upplevelsevandring",
    "upplevelsevandringen": "upplevelsevandring",
    "upplevelsevandringens": "upplevelsevandring",
    "upplevelsevandrings": "upplevelsevandring",
    "upplever": "uppleva",
    "uppleves": "uppleva",
    "upplevs": "uppleva",
    "upplevt": "uppleva",
    "upplevts": "uppleva",
    "uppliv": "uppliva",
    "upplivad": "uppliva",
    "upplivade": "uppliva",
    "upplivades": "uppliva",
    "upplivads": "uppliva",
    "upplivande": "uppliva",
    "upplivanden": "upplivande",
    "upplivandena": "upplivande",
    "upplivandenas": "upplivande",
    "upplivandens": "upplivande",
    "upplivandes": "upplivande",
    "upplivandet": "upplivande",
    "upplivandets": "upplivande",
    "upplivar": "uppliva",
    "upplivas": "uppliva",
    "upplivat": "uppliva",
    "upplivats": "uppliva",
    "upplivningar": "upplivning",
    "upplivningarna": "upplivning",
    "upplivningarnas": "upplivning",
    "upplivningars": "upplivning",
    "upplivningen": "upplivning",
    "upplivningens": "upplivning",
    "upplivnings": "upplivning",
    "upplivningsförsöken": "upplivningsförsök",
    "upplivningsförsökens": "upplivningsförsök",
    "upplivningsförsöket": "upplivningsförsök",
    "upplivningsförsökets": "upplivningsförsök",
    "upplivningsförsöks": "upplivningsförsök",
    "upploppen": "upplopp",
    "upploppens": "upplopp",
    "upploppet": "upplopp",
    "upploppets": "upplopp",
    "upplopps": "upplopp",
    "uppluckrade": "uppluckrad",
    "uppluckrades": "uppluckrad",
    "uppluckrads": "uppluckrad",
    "uppluckrat": "uppluckrad",
    "uppluckrats": "uppluckrad",
    "uppluckringar": "uppluckring",
    "uppluckringarna": "uppluckring",
    "uppluckringarnas": "uppluckring",
    "uppluckringars": "uppluckring",
    "uppluckringen": "uppluckring",
    "uppluckringens": "uppluckring",
    "uppluckrings": "uppluckring",
    "upplupens": "upplupen",
    "upplupet": "upplupen",
    "upplupets": "upplupen",
    "upplupna": "upplupen",
    "upplupnare": "upplupen",
    "upplupnares": "upplupen",
    "upplupnas": "upplupen",
    "upplupnast": "upplupen",
    "upplupnaste": "upplupen",
    "upplupnastes": "upplupen",
    "upplupnasts": "upplupen",
    "upplupne": "upplupen",
    "upplupnes": "upplupen",
    "upplys": "upplysa",
    "upplysande": "upplysa",
    "upplysanden": "upplysande",
    "upplysandena": "upplysande",
    "upplysandenas": "upplysande",
    "upplysandens": "upplysande",
    "upplysandes": "upplysande",
    "upplysandet": "upplysande",
    "upplysandets": "upplysande",
    "upplysas": "upplysa",
    "upplyser": "upplysa",
    "upplyses": "upplysa",
    "upplysningar": "upplysning",
    "upplysningarna": "upplysning",
    "upplysningarnas": "upplysning",
    "upplysningars": "upplysning",
    "upplysningen": "upplysning",
    "upplysningens": "upplysning",
    "upplysnings": "upplysning",
    "upplysningsfilosofien": "upplysningsfilosofi",
    "upplysningsfilosofiens": "upplysningsfilosofi",
    "upplysningsfilosofier": "upplysningsfilosofi",
    "upplysningsfilosofierna": "upplysningsfilosofi",
    "upplysningsfilosofiernas": "upplysningsfilosofi",
    "upplysningsfilosofiers": "upplysningsfilosofi",
    "upplysningsfilosofin": "upplysningsfilosofi",
    "upplysningsfilosofins": "upplysningsfilosofi",
    "upplysningsfilosofis": "upplysningsfilosofi",
    "upplysningsidéen": "upplysningsidé",
    "upplysningsidéens": "upplysningsidé",
    "upplysningsidéer": "upplysningsidé",
    "upplysningsidéerna": "upplysningsidé",
    "upplysningsidéernas": "upplysningsidé",
    "upplysningsidéers": "upplysningsidé",
    "upplysningsidén": "upplysningsidé",
    "upplysningsidéns": "upplysningsidé",
    "upplysningsidés": "upplysningsidé",
    "upplysningstiden": "upplysningstid",
    "upplysningstidens": "upplysningstid",
    "upplysningstids": "upplysningstid",
    "upplyst": "upplysa",
    "upplysta": "upplyst",
    "upplystare": "upplyst",
    "upplystares": "upplyst",
    "upplystas": "upplyst",
    "upplystast": "upplyst",
    "upplystaste": "upplyst",
    "upplystastes": "upplyst",
    "upplystasts": "upplyst",
    "upplyste": "upplyst",
    "upplystes": "upplyst",
    "upplystheten": "upplysthet",
    "upplysthetens": "upplysthet",
    "upplysthets": "upplysthet",
    "upplysts": "upplyst",
    "upplägg": "upplägga",
    "uppläggande": "upplägga",
    "upplägganden": "uppläggande",
    "uppläggandena": "uppläggande",
    "uppläggandenas": "uppläggande",
    "uppläggandens": "uppläggande",
    "uppläggandes": "uppläggande",
    "uppläggandet": "uppläggande",
    "uppläggandets": "uppläggande",
    "uppläggas": "upplägga",
    "uppläggen": "upplägg",
    "uppläggens": "upplägg",
    "upplägger": "upplägga",
    "upplägges": "upplägga",
    "upplägget": "upplägg",
    "uppläggets": "upplägg",
    "uppläggningar": "uppläggning",
    "uppläggningarna": "uppläggning",
    "uppläggningarnas": "uppläggning",
    "uppläggningars": "uppläggning",
    "uppläggningen": "uppläggning",
    "uppläggningens": "uppläggning",
    "uppläggnings": "uppläggning",
    "uppläggs": "upplägga",
    "uppländsk": "uppländska",
    "uppländska": "uppländsk",
    "uppländskan": "uppländska",
    "uppländskans": "uppländska",
    "uppländskare": "uppländsk",
    "uppländskares": "uppländsk",
    "uppländskas": "uppländska",
    "uppländskast": "uppländsk",
    "uppländskaste": "uppländsk",
    "uppländskastes": "uppländsk",
    "uppländskasts": "uppländsk",
    "uppländske": "uppländska",
    "uppländskes": "uppländsk",
    "uppländskor": "uppländska",
    "uppländskorna": "uppländska",
    "uppländskornas": "uppländska",
    "uppländskors": "uppländska",
    "uppländsks": "uppländsk",
    "uppländskt": "uppländsk",
    "uppländskts": "uppländsk",
    "upplänningar": "upplänning",
    "upplänningarna": "upplänning",
    "upplänningarnas": "upplänning",
    "upplänningars": "upplänning",
    "upplänningen": "upplänning",
    "upplänningens": "upplänning",
    "upplännings": "upplänning",
    "uppläs": "uppläsa",
    "uppläsande": "uppläsa",
    "uppläsanden": "uppläsande",
    "uppläsandena": "uppläsande",
    "uppläsandenas": "uppläsande",
    "uppläsandens": "uppläsande",
    "uppläsandes": "uppläsande",
    "uppläsandet": "uppläsande",
    "uppläsandets": "uppläsande",
    "uppläsar": "uppläsare",
    "uppläsaren": "uppläsare",
    "uppläsarens": "uppläsare",
    "uppläsares": "uppläsare",
    "uppläsarna": "uppläsare",
    "uppläsarnas": "uppläsare",
    "uppläsas": "uppläsa",
    "uppläser": "uppläsa",
    "uppläses": "uppläsa",
    "uppläsningar": "uppläsning",
    "uppläsningarna": "uppläsning",
    "uppläsningarnas": "uppläsning",
    "uppläsningars": "uppläsning",
    "uppläsningen": "uppläsning",
    "uppläsningens": "uppläsning",
    "uppläsnings": "uppläsning",
    "uppläst": "uppläsa",
    "upplästa": "uppläsa",
    "upplästas": "uppläsa",
    "uppläste": "uppläsa",
    "upplästes": "uppläsa",
    "upplästs": "uppläsa",
    "upplät": "upplåta",
    "uppläts": "upplåta",
    "upplåningar": "upplåning",
    "upplåningarna": "upplåning",
    "upplåningarnas": "upplåning",
    "upplåningars": "upplåning",
    "upplåningen": "upplåning",
    "upplåningens": "upplåning",
    "upplånings": "upplåning",
    "upplåt": "upplåta",
    "upplåtande": "upplåta",
    "upplåtanden": "upplåtande",
    "upplåtandena": "upplåtande",
    "upplåtandenas": "upplåtande",
    "upplåtandens": "upplåtande",
    "upplåtandes": "upplåtande",
    "upplåtandet": "upplåtande",
    "upplåtandets": "upplåtande",
    "upplåtas": "upplåta",
    "upplåte": "upplåta",
    "upplåtelsen": "upplåtelse",
    "upplåtelsens": "upplåtelse",
    "upplåtelser": "upplåtelse",
    "upplåtelserna": "upplåtelse",
    "upplåtelsernas": "upplåtelse",
    "upplåtelsers": "upplåtelse",
    "upplåtelses": "upplåtelse",
    "upplåten": "upplåta",
    "upplåtens": "upplåta",
    "upplåter": "upplåta",
    "upplåtes": "upplåta",
    "upplåtet": "upplåta",
    "upplåtets": "upplåta",
    "upplåtit": "upplåta",
    "upplåtits": "upplåta",
    "upplåtna": "upplåta",
    "upplåtnas": "upplåta",
    "upplåtne": "upplåta",
    "upplåtnes": "upplåta",
    "upplåts": "upplåta",
    "upplöjde": "upplöjd",
    "upplöjdes": "upplöjd",
    "upplöjds": "upplöjd",
    "upplöjt": "upplöjd",
    "upplöjts": "upplöjd",
    "upplös": "upplösa",
    "upplösande": "upplösa",
    "upplösanden": "upplösande",
    "upplösandena": "upplösande",
    "upplösandenas": "upplösande",
    "upplösandens": "upplösande",
    "upplösandes": "upplösande",
    "upplösandet": "upplösande",
    "upplösandets": "upplösande",
    "upplösas": "upplösa",
    "upplöser": "upplösa",
    "upplöses": "upplösa",
    "upplösningar": "upplösning",
    "upplösningarna": "upplösning",
    "upplösningarnas": "upplösning",
    "upplösningars": "upplösning",
    "upplösningen": "upplösning",
    "upplösningens": "upplösning",
    "upplösnings": "upplösning",
    "upplösningsförmågan": "upplösningsförmåga",
    "upplösningsförmågans": "upplösningsförmåga",
    "upplösningsförmågas": "upplösningsförmåga",
    "upplösningsförmåge": "upplösningsförmåga",
    "upplösningsmedels": "upplösningsmedel",
    "upplösningsmedlen": "upplösningsmedel",
    "upplösningsmedlens": "upplösningsmedel",
    "upplösningsmedlet": "upplösningsmedel",
    "upplösningsmedlets": "upplösningsmedel",
    "upplöst": "upplösa",
    "upplösta": "upplösa",
    "upplöstas": "upplösa",
    "upplöste": "upplösa",
    "upplöstes": "upplösa",
    "upplösts": "upplösa",
    "uppman": "uppmana",
    "uppmanad": "uppmana",
    "uppmanade": "uppmana",
    "uppmanades": "uppmana",
    "uppmanads": "uppmana",
    "uppmanande": "uppmana",
    "uppmananden": "uppmanande",
    "uppmanandena": "uppmanande",
    "uppmanandenas": "uppmanande",
    "uppmanandens": "uppmanande",
    "uppmanandes": "uppmanande",
    "uppmanandet": "uppmanande",
    "uppmanandets": "uppmanande",
    "uppmanar": "uppmana",
    "uppmanas": "uppmana",
    "uppmanat": "uppmana",
    "uppmanats": "uppmana",
    "uppmaningar": "uppmaning",
    "uppmaningarna": "uppmaning",
    "uppmaningarnas": "uppmaning",
    "uppmaningars": "uppmaning",
    "uppmaningen": "uppmaning",
    "uppmaningens": "uppmaning",
    "uppmanings": "uppmaning",
    "uppmaningssatsen": "uppmaningssats",
    "uppmaningssatsens": "uppmaningssats",
    "uppmaningssatser": "uppmaningssats",
    "uppmaningssatserna": "uppmaningssats",
    "uppmaningssatsernas": "uppmaningssats",
    "uppmaningssatsers": "uppmaningssats",
    "uppmarschen": "uppmarsch",
    "uppmarschens": "uppmarsch",
    "uppmarscher": "uppmarsch",
    "uppmarscherna": "uppmarsch",
    "uppmarschernas": "uppmarsch",
    "uppmarschers": "uppmarsch",
    "uppmarschområden": "uppmarschområde",
    "uppmarschområdena": "uppmarschområde",
    "uppmarschområdenas": "uppmarschområde",
    "uppmarschområdens": "uppmarschområde",
    "uppmarschområdes": "uppmarschområde",
    "uppmarschområdet": "uppmarschområde",
    "uppmarschområdets": "uppmarschområde",
    "uppmarschs": "uppmarsch",
    "uppmjuk": "uppmjuka",
    "uppmjukad": "uppmjuka",
    "uppmjukade": "uppmjuka",
    "uppmjukades": "uppmjuka",
    "uppmjukads": "uppmjuka",
    "uppmjukande": "uppmjuka",
    "uppmjukanden": "uppmjukande",
    "uppmjukandena": "uppmjukande",
    "uppmjukandenas": "uppmjukande",
    "uppmjukandens": "uppmjukande",
    "uppmjukandes": "uppmjukande",
    "uppmjukandet": "uppmjukande",
    "uppmjukandets": "uppmjukande",
    "uppmjukar": "uppmjuka",
    "uppmjukas": "uppmjuka",
    "uppmjukat": "uppmjuka",
    "uppmjukats": "uppmjuka",
    "uppmjukningar": "uppmjukning",
    "uppmjukningarna": "uppmjukning",
    "uppmjukningarnas": "uppmjukning",
    "uppmjukningars": "uppmjukning",
    "uppmjukningen": "uppmjukning",
    "uppmjukningens": "uppmjukning",
    "uppmjuknings": "uppmjukning",
    "uppmjukningspolitiken": "uppmjukningspolitik",
    "uppmjukningspolitikens": "uppmjukningspolitik",
    "uppmjukningspolitiks": "uppmjukningspolitik",
    "uppmuddrad": "uppmuddra",
    "uppmuddrade": "uppmuddra",
    "uppmuddrades": "uppmuddra",
    "uppmuddrads": "uppmuddra",
    "uppmuddrande": "uppmuddra",
    "uppmuddranden": "uppmuddrande",
    "uppmuddrandena": "uppmuddrande",
    "uppmuddrandenas": "uppmuddrande",
    "uppmuddrandens": "uppmuddrande",
    "uppmuddrandes": "uppmuddrande",
    "uppmuddrandet": "uppmuddrande",
    "uppmuddrandets": "uppmuddrande",
    "uppmuddrar": "uppmuddra",
    "uppmuddras": "uppmuddra",
    "uppmuddrat": "uppmuddra",
    "uppmuddrats": "uppmuddra",
    "uppmuntrad": "uppmuntra",
    "uppmuntrade": "uppmuntra",
    "uppmuntrades": "uppmuntra",
    "uppmuntrads": "uppmuntra",
    "uppmuntrande": "uppmuntra",
    "uppmuntranden": "uppmuntrande",
    "uppmuntrandena": "uppmuntrande",
    "uppmuntrandenas": "uppmuntrande",
    "uppmuntrandens": "uppmuntrande",
    "uppmuntrandes": "uppmuntrande",
    "uppmuntrandet": "uppmuntrande",
    "uppmuntrandets": "uppmuntrande",
    "uppmuntrans": "uppmuntran",
    "uppmuntrar": "uppmuntra",
    "uppmuntras": "uppmuntra",
    "uppmuntrat": "uppmuntra",
    "uppmuntrats": "uppmuntra",
    "uppmuntringar": "uppmuntring",
    "uppmuntringarna": "uppmuntring",
    "uppmuntringarnas": "uppmuntring",
    "uppmuntringars": "uppmuntring",
    "uppmuntringen": "uppmuntring",
    "uppmuntringens": "uppmuntring",
    "uppmuntrings": "uppmuntring",
    "uppmärksamheten": "uppmärksamhet",
    "uppmärksamhetens": "uppmärksamhet",
    "uppmärksamheter": "uppmärksamhet",
    "uppmärksamheterna": "uppmärksamhet",
    "uppmärksamheternas": "uppmärksamhet",
    "uppmärksamheters": "uppmärksamhet",
    "uppmärksamhets": "uppmärksamhet",
    "uppmärksamhetsfälten": "uppmärksamhetsfält",
    "uppmärksamhetsfältens": "uppmärksamhetsfält",
    "uppmärksamhetsfältet": "uppmärksamhetsfält",
    "uppmärksamhetsfältets": "uppmärksamhetsfält",
    "uppmärksamhetsfälts": "uppmärksamhetsfält",
    "uppmärksamhetspåkallar": "uppmärksamhetspåkallare",
    "uppmärksamhetspåkallaren": "uppmärksamhetspåkallare",
    "uppmärksamhetspåkallarens": "uppmärksamhetspåkallare",
    "uppmärksamhetspåkallares": "uppmärksamhetspåkallare",
    "uppmärksamhetspåkallarna": "uppmärksamhetspåkallare",
    "uppmärksamhetspåkallarnas": "uppmärksamhetspåkallare",
    "uppmärksamma": "uppmärksam",
    "uppmärksammad": "uppmärksamma",
    "uppmärksammade": "uppmärksammad",
    "uppmärksammades": "uppmärksammad",
    "uppmärksammads": "uppmärksammad",
    "uppmärksammande": "uppmärksamma",
    "uppmärksammanden": "uppmärksammande",
    "uppmärksammandena": "uppmärksammande",
    "uppmärksammandenas": "uppmärksammande",
    "uppmärksammandens": "uppmärksammande",
    "uppmärksammandes": "uppmärksammande",
    "uppmärksammandet": "uppmärksammande",
    "uppmärksammandets": "uppmärksammande",
    "uppmärksammar": "uppmärksamma",
    "uppmärksammare": "uppmärksam",
    "uppmärksammares": "uppmärksam",
    "uppmärksammas": "uppmärksamma",
    "uppmärksammast": "uppmärksam",
    "uppmärksammaste": "uppmärksam",
    "uppmärksammastes": "uppmärksam",
    "uppmärksammasts": "uppmärksam",
    "uppmärksammat": "uppmärksammad",
    "uppmärksammats": "uppmärksammad",
    "uppmärksamme": "uppmärksam",
    "uppmärksammes": "uppmärksam",
    "uppmärksams": "uppmärksam",
    "uppmärksamt": "uppmärksam",
    "uppmärksamts": "uppmärksam",
    "uppmät": "uppmäta",
    "uppmätande": "uppmäta",
    "uppmätanden": "uppmätande",
    "uppmätandena": "uppmätande",
    "uppmätandenas": "uppmätande",
    "uppmätandens": "uppmätande",
    "uppmätandes": "uppmätande",
    "uppmätandet": "uppmätande",
    "uppmätandets": "uppmätande",
    "uppmätas": "uppmäta",
    "uppmäter": "uppmäta",
    "uppmätes": "uppmäta",
    "uppmäts": "uppmäta",
    "uppmätt": "uppmäta",
    "uppmätta": "uppmäta",
    "uppmättas": "uppmäta",
    "uppmätte": "uppmäta",
    "uppmättes": "uppmäta",
    "uppmätts": "uppmäta",
    "uppmålade": "uppmålad",
    "uppmålades": "uppmålad",
    "uppmålads": "uppmålad",
    "uppmålat": "uppmålad",
    "uppmålats": "uppmålad",
    "uppnosiga": "uppnosig",
    "uppnosigare": "uppnosig",
    "uppnosigares": "uppnosig",
    "uppnosigas": "uppnosig",
    "uppnosigast": "uppnosig",
    "uppnosigaste": "uppnosig",
    "uppnosigastes": "uppnosig",
    "uppnosigasts": "uppnosig",
    "uppnosige": "uppnosig",
    "uppnosiges": "uppnosig",
    "uppnosigheten": "uppnosighet",
    "uppnosighetens": "uppnosighet",
    "uppnosighets": "uppnosighet",
    "uppnosigs": "uppnosig",
    "uppnosigt": "uppnosig",
    "uppnosigts": "uppnosig",
    "uppnäs": "uppnäsa",
    "uppnäsan": "uppnäsa",
    "uppnäsans": "uppnäsa",
    "uppnäsas": "uppnäsa",
    "uppnäse": "uppnäsa",
    "uppnäsor": "uppnäsa",
    "uppnäsorna": "uppnäsa",
    "uppnäsornas": "uppnäsa",
    "uppnäsors": "uppnäsa",
    "uppnästa": "uppnäst",
    "uppnästare": "uppnäst",
    "uppnästares": "uppnäst",
    "uppnästas": "uppnäst",
    "uppnästast": "uppnäst",
    "uppnästaste": "uppnäst",
    "uppnästastes": "uppnäst",
    "uppnästasts": "uppnäst",
    "uppnäste": "uppnäst",
    "uppnästes": "uppnäst",
    "uppnästheten": "uppnästhet",
    "uppnästhetens": "uppnästhet",
    "uppnästhets": "uppnästhet",
    "uppnästs": "uppnäst",
    "uppnådd": "uppnå",
    "uppnådda": "uppnå",
    "uppnåddas": "uppnå",
    "uppnådde": "uppnå",
    "uppnåddes": "uppnå",
    "uppnådds": "uppnå",
    "uppnåeliga": "uppnåelig",
    "uppnåeligare": "uppnåelig",
    "uppnåeligares": "uppnåelig",
    "uppnåeligas": "uppnåelig",
    "uppnåeligast": "uppnåelig",
    "uppnåeligaste": "uppnåelig",
    "uppnåeligastes": "uppnåelig",
    "uppnåeligasts": "uppnåelig",
    "uppnåelige": "uppnåelig",
    "uppnåeliges": "uppnåelig",
    "uppnåeligheten": "uppnåelighet",
    "uppnåelighetens": "uppnåelighet",
    "uppnåelighets": "uppnåelighet",
    "uppnåeligs": "uppnåelig",
    "uppnåeligt": "uppnåelig",
    "uppnåeligts": "uppnåelig",
    "uppnående": "uppnå",
    "uppnåenden": "uppnående",
    "uppnåendena": "uppnående",
    "uppnåendenas": "uppnående",
    "uppnåendens": "uppnående",
    "uppnåendes": "uppnående",
    "uppnåendet": "uppnående",
    "uppnåendets": "uppnående",
    "uppnål": "uppnåla",
    "uppnålad": "uppnåla",
    "uppnålade": "uppnåla",
    "uppnålades": "uppnåla",
    "uppnålads": "uppnåla",
    "uppnålande": "uppnåla",
    "uppnålanden": "uppnålande",
    "uppnålandena": "uppnålande",
    "uppnålandenas": "uppnålande",
    "uppnålandens": "uppnålande",
    "uppnålandes": "uppnålande",
    "uppnålandet": "uppnålande",
    "uppnålandets": "uppnålande",
    "uppnålar": "uppnåla",
    "uppnålas": "uppnåla",
    "uppnålat": "uppnåla",
    "uppnålats": "uppnåla",
    "uppnår": "uppnå",
    "uppnås": "uppnå",
    "uppnått": "uppnå",
    "uppnåtts": "uppnå",
    "uppochnedvända": "uppochnedvänd",
    "uppochnedvändare": "uppochnedvänd",
    "uppochnedvändares": "uppochnedvänd",
    "uppochnedvändas": "uppochnedvänd",
    "uppochnedvändast": "uppochnedvänd",
    "uppochnedvändaste": "uppochnedvänd",
    "uppochnedvändastes": "uppochnedvänd",
    "uppochnedvändasts": "uppochnedvänd",
    "uppochnedvände": "uppochnedvänd",
    "uppochnedvändes": "uppochnedvänd",
    "uppochnedvändheten": "uppochnedvändhet",
    "uppochnedvändhetens": "uppochnedvändhet",
    "uppochnedvändhets": "uppochnedvändhet",
    "uppochnedvänds": "uppochnedvänd",
    "uppochnedvänt": "uppochnedvänd",
    "uppochnedvänts": "uppochnedvänd",
    "uppochnervända": "uppochnervänd",
    "uppochnervändare": "uppochnervänd",
    "uppochnervändares": "uppochnervänd",
    "uppochnervändas": "uppochnervänd",
    "uppochnervändast": "uppochnervänd",
    "uppochnervändaste": "uppochnervänd",
    "uppochnervändastes": "uppochnervänd",
    "uppochnervändasts": "uppochnervänd",
    "uppochnervände": "uppochnervänd",
    "uppochnervändes": "uppochnervänd",
    "uppochnervändheten": "uppochnervändhet",
    "uppochnervändhetens": "uppochnervändhet",
    "uppochnervändhets": "uppochnervändhet",
    "uppochnervänds": "uppochnervänd",
    "uppochnervänt": "uppochnervänd",
    "uppochnervänts": "uppochnervänd",
    "uppodlad": "uppodla",
    "uppodlade": "uppodla",
    "uppodlades": "uppodla",
    "uppodlads": "uppodla",
    "uppodlande": "uppodla",
    "uppodlanden": "uppodlande",
    "uppodlandena": "uppodlande",
    "uppodlandenas": "uppodlande",
    "uppodlandens": "uppodlande",
    "uppodlandes": "uppodlande",
    "uppodlandet": "uppodlande",
    "uppodlandets": "uppodlande",
    "uppodlar": "uppodla",
    "uppodlas": "uppodla",
    "uppodlat": "uppodla",
    "uppodlats": "uppodla",
    "uppoffrad": "uppoffra",
    "uppoffrade": "uppoffra",
    "uppoffrades": "uppoffra",
    "uppoffrads": "uppoffra",
    "uppoffrande": "uppoffra",
    "uppoffranden": "uppoffrande",
    "uppoffrandena": "uppoffrande",
    "uppoffrandenas": "uppoffrande",
    "uppoffrandens": "uppoffrande",
    "uppoffrandes": "uppoffrande",
    "uppoffrandet": "uppoffrande",
    "uppoffrandets": "uppoffrande",
    "uppoffrar": "uppoffra",
    "uppoffras": "uppoffra",
    "uppoffrat": "uppoffra",
    "uppoffrats": "uppoffra",
    "uppoffringar": "uppoffring",
    "uppoffringarna": "uppoffring",
    "uppoffringarnas": "uppoffring",
    "uppoffringars": "uppoffring",
    "uppoffringen": "uppoffring",
    "uppoffringens": "uppoffring",
    "uppoffrings": "uppoffring",
    "upprad": "upprada",
    "uppradad": "upprada",
    "uppradade": "upprada",
    "uppradades": "upprada",
    "uppradads": "upprada",
    "uppradande": "upprada",
    "uppradanden": "uppradande",
    "uppradandena": "uppradande",
    "uppradandenas": "uppradande",
    "uppradandens": "uppradande",
    "uppradandes": "uppradande",
    "uppradandet": "uppradande",
    "uppradandets": "uppradande",
    "uppradar": "upprada",
    "uppradas": "upprada",
    "uppradat": "upprada",
    "uppradats": "upprada",
    "uppreklamerad": "uppreklamera",
    "uppreklamerade": "uppreklamera",
    "uppreklamerades": "uppreklamera",
    "uppreklamerads": "uppreklamera",
    "uppreklamerande": "uppreklamera",
    "uppreklameranden": "uppreklamerande",
    "uppreklamerandena": "uppreklamerande",
    "uppreklamerandenas": "uppreklamerande",
    "uppreklamerandens": "uppreklamerande",
    "uppreklamerandes": "uppreklamerande",
    "uppreklamerandet": "uppreklamerande",
    "uppreklamerandets": "uppreklamerande",
    "uppreklamerar": "uppreklamera",
    "uppreklameras": "uppreklamera",
    "uppreklamerat": "uppreklamera",
    "uppreklamerats": "uppreklamera",
    "uppreklamerbara": "uppreklamerbar",
    "uppreklamerbarare": "uppreklamerbar",
    "uppreklamerbarares": "uppreklamerbar",
    "uppreklamerbaras": "uppreklamerbar",
    "uppreklamerbarast": "uppreklamerbar",
    "uppreklamerbaraste": "uppreklamerbar",
    "uppreklamerbarastes": "uppreklamerbar",
    "uppreklamerbarasts": "uppreklamerbar",
    "uppreklamerbare": "uppreklamerbar",
    "uppreklamerbares": "uppreklamerbar",
    "uppreklamerbarheten": "uppreklamerbarhet",
    "uppreklamerbarhetens": "uppreklamerbarhet",
    "uppreklamerbarhets": "uppreklamerbarhet",
    "uppreklamerbars": "uppreklamerbar",
    "uppreklamerbart": "uppreklamerbar",
    "uppreklamerbarts": "uppreklamerbar",
    "uppreklameringar": "uppreklamering",
    "uppreklameringarna": "uppreklamering",
    "uppreklameringarnas": "uppreklamering",
    "uppreklameringars": "uppreklamering",
    "uppreklameringen": "uppreklamering",
    "uppreklameringens": "uppreklamering",
    "uppreklamerings": "uppreklamering",
    "upprens": "upprensa",
    "upprensad": "upprensa",
    "upprensade": "upprensa",
    "upprensades": "upprensa",
    "upprensads": "upprensa",
    "upprensande": "upprensa",
    "upprensanden": "upprensande",
    "upprensandena": "upprensande",
    "upprensandenas": "upprensande",
    "upprensandens": "upprensande",
    "upprensandes": "upprensande",
    "upprensandet": "upprensande",
    "upprensandets": "upprensande",
    "upprensar": "upprensa",
    "upprensas": "upprensa",
    "upprensat": "upprensa",
    "upprensats": "upprensa",
    "upprensningar": "upprensning",
    "upprensningarna": "upprensning",
    "upprensningarnas": "upprensning",
    "upprensningars": "upprensning",
    "upprensningen": "upprensning",
    "upprensningens": "upprensning",
    "upprensnings": "upprensning",
    "upprep": "upprepa",
    "upprepad": "upprepa",
    "upprepade": "upprepad",
    "upprepades": "upprepad",
    "upprepads": "upprepad",
    "upprepande": "upprepa",
    "upprepanden": "upprepande",
    "upprepandena": "upprepande",
    "upprepandenas": "upprepande",
    "upprepandens": "upprepande",
    "upprepandes": "upprepande",
    "upprepandet": "upprepande",
    "upprepandets": "upprepande",
    "upprepar": "upprepa",
    "upprepas": "upprepa",
    "upprepat": "upprepad",
    "upprepats": "upprepad",
    "upprepningar": "upprepning",
    "upprepningarna": "upprepning",
    "upprepningarnas": "upprepning",
    "upprepningars": "upprepning",
    "upprepningen": "upprepning",
    "upprepningens": "upprepning",
    "upprepnings": "upprepning",
    "upprepningsmönsterna": "upprepningsmönster",
    "upprepningsmönsternas": "upprepningsmönster",
    "upprepningsmönsters": "upprepningsmönster",
    "upprepningsmönstren": "upprepningsmönster",
    "upprepningsmönstrens": "upprepningsmönster",
    "upprepningsmönstret": "upprepningsmönster",
    "upprepningsmönstrets": "upprepningsmönster",
    "uppres": "uppresa",
    "uppresande": "uppresa",
    "uppresanden": "uppresande",
    "uppresandena": "uppresande",
    "uppresandenas": "uppresande",
    "uppresandens": "uppresande",
    "uppresandes": "uppresande",
    "uppresandet": "uppresande",
    "uppresandets": "uppresande",
    "uppresas": "uppresa",
    "uppreser": "uppresa",
    "uppreses": "uppresa",
    "upprest": "uppresa",
    "uppresta": "uppresa",
    "upprestas": "uppresa",
    "uppreste": "uppresa",
    "upprestes": "uppresa",
    "upprests": "uppresa",
    "uppretade": "uppretad",
    "uppretades": "uppretad",
    "uppretads": "uppretad",
    "uppretat": "uppretad",
    "uppretats": "uppretad",
    "upprev": "uppriva",
    "upprevs": "uppriva",
    "uppriktiga": "uppriktig",
    "uppriktigare": "uppriktig",
    "uppriktigares": "uppriktig",
    "uppriktigas": "uppriktig",
    "uppriktigast": "uppriktig",
    "uppriktigaste": "uppriktig",
    "uppriktigastes": "uppriktig",
    "uppriktigasts": "uppriktig",
    "uppriktige": "uppriktig",
    "uppriktiges": "uppriktig",
    "uppriktigheten": "uppriktighet",
    "uppriktighetens": "uppriktighet",
    "uppriktigheter": "uppriktighet",
    "uppriktigheterna": "uppriktighet",
    "uppriktigheternas": "uppriktighet",
    "uppriktigheters": "uppriktighet",
    "uppriktighets": "uppriktighet",
    "uppriktigs": "uppriktig",
    "uppriktigt": "uppriktig",
    "uppriktigts": "uppriktig",
    "uppringningar": "uppringning",
    "uppringningarna": "uppringning",
    "uppringningarnas": "uppringning",
    "uppringningars": "uppringning",
    "uppringningen": "uppringning",
    "uppringningens": "uppringning",
    "uppringnings": "uppringning",
    "upprinnelsen": "upprinnelse",
    "upprinnelsens": "upprinnelse",
    "upprinnelser": "upprinnelse",
    "upprinnelserna": "upprinnelse",
    "upprinnelsernas": "upprinnelse",
    "upprinnelsers": "upprinnelse",
    "upprinnelses": "upprinnelse",
    "upprinningar": "upprinning",
    "upprinningarna": "upprinning",
    "upprinningarnas": "upprinning",
    "upprinningars": "upprinning",
    "upprinningen": "upprinning",
    "upprinningens": "upprinning",
    "upprinnings": "upprinning",
    "uppriv": "uppriva",
    "upprivande": "uppriva",
    "upprivanden": "upprivande",
    "upprivandena": "upprivande",
    "upprivandenas": "upprivande",
    "upprivandens": "upprivande",
    "upprivandes": "upprivande",
    "upprivandet": "upprivande",
    "upprivandets": "upprivande",
    "upprivas": "uppriva",
    "upprive": "uppriva",
    "uppriven": "uppriva",
    "upprivens": "uppriven",
    "uppriver": "uppriva",
    "upprives": "uppriva",
    "upprivet": "uppriven",
    "upprivets": "uppriven",
    "upprivit": "uppriva",
    "upprivits": "uppriva",
    "upprivna": "uppriven",
    "upprivnare": "uppriven",
    "upprivnares": "uppriven",
    "upprivnas": "uppriven",
    "upprivnast": "uppriven",
    "upprivnaste": "uppriven",
    "upprivnastes": "uppriven",
    "upprivnasts": "uppriven",
    "upprivne": "uppriven",
    "upprivnes": "uppriven",
    "upprivs": "uppriva",
    "uppropen": "upprop",
    "uppropens": "upprop",
    "uppropet": "upprop",
    "uppropets": "upprop",
    "upprops": "upprop",
    "uppropslistan": "uppropslista",
    "uppropslistans": "uppropslista",
    "uppropslistas": "uppropslista",
    "uppropsliste": "uppropslista",
    "uppropslistor": "uppropslista",
    "uppropslistorna": "uppropslista",
    "uppropslistornas": "uppropslista",
    "uppropslistors": "uppropslista",
    "upproren": "uppror",
    "upprorens": "uppror",
    "upproret": "uppror",
    "upprorets": "uppror",
    "upproriska": "upprorisk",
    "upproriskare": "upprorisk",
    "upproriskares": "upprorisk",
    "upproriskas": "upprorisk",
    "upproriskast": "upprorisk",
    "upproriskaste": "upprorisk",
    "upproriskastes": "upprorisk",
    "upproriskasts": "upprorisk",
    "upproriske": "upprorisk",
    "upproriskes": "upprorisk",
    "upprorisks": "upprorisk",
    "upproriskt": "upprorisk",
    "upproriskts": "upprorisk",
    "upprors": "uppror",
    "upprorsandan": "upprorsanda",
    "upprorsandans": "upprorsanda",
    "upprorsandas": "upprorsanda",
    "upprorsförsöken": "upprorsförsök",
    "upprorsförsökens": "upprorsförsök",
    "upprorsförsöket": "upprorsförsök",
    "upprorsförsökets": "upprorsförsök",
    "upprorsförsöks": "upprorsförsök",
    "upprorshärdar": "upprorshärd",
    "upprorshärdarna": "upprorshärd",
    "upprorshärdarnas": "upprorshärd",
    "upprorshärdars": "upprorshärd",
    "upprorshärden": "upprorshärd",
    "upprorshärdens": "upprorshärd",
    "upprorshärds": "upprorshärd",
    "upprorsmakar": "upprorsmakare",
    "upprorsmakaren": "upprorsmakare",
    "upprorsmakarens": "upprorsmakare",
    "upprorsmakares": "upprorsmakare",
    "upprorsmakarna": "upprorsmakare",
    "upprorsmakarnas": "upprorsmakare",
    "upprorsmannen": "upprorsman",
    "upprorsmannens": "upprorsman",
    "upprorsmans": "upprorsman",
    "upprorsmän": "upprorsman",
    "upprorsmännen": "upprorsman",
    "upprorsmännens": "upprorsman",
    "upprorsmäns": "upprorsman",
    "upprust": "upprusta",
    "upprustad": "upprusta",
    "upprustade": "upprusta",
    "upprustades": "upprusta",
    "upprustads": "upprusta",
    "upprustande": "upprusta",
    "upprustanden": "upprustande",
    "upprustandena": "upprustande",
    "upprustandenas": "upprustande",
    "upprustandens": "upprustande",
    "upprustandes": "upprustande",
    "upprustandet": "upprustande",
    "upprustandets": "upprustande",
    "upprustar": "upprusta",
    "upprustas": "upprusta",
    "upprustat": "upprusta",
    "upprustats": "upprusta",
    "upprustningar": "upprustning",
    "upprustningarna": "upprustning",
    "upprustningarnas": "upprustning",
    "upprustningars": "upprustning",
    "upprustningen": "upprustning",
    "upprustningens": "upprustning",
    "upprustnings": "upprustning",
    "uppruttens": "upprutten",
    "uppruttet": "upprutten",
    "uppruttets": "upprutten",
    "uppruttna": "upprutten",
    "uppruttnare": "upprutten",
    "uppruttnares": "upprutten",
    "uppruttnas": "upprutten",
    "uppruttnast": "upprutten",
    "uppruttnaste": "upprutten",
    "uppruttnastes": "upprutten",
    "uppruttnasts": "upprutten",
    "uppruttne": "upprutten",
    "uppruttnes": "upprutten",
    "uppryckningar": "uppryckning",
    "uppryckningarna": "uppryckning",
    "uppryckningarnas": "uppryckning",
    "uppryckningars": "uppryckning",
    "uppryckningen": "uppryckning",
    "uppryckningens": "uppryckning",
    "upprycknings": "uppryckning",
    "upprym": "upprymma",
    "upprymd": "upprymma",
    "upprymda": "upprymma",
    "upprymdare": "upprymd",
    "upprymdares": "upprymd",
    "upprymdas": "upprymma",
    "upprymdast": "upprymd",
    "upprymdaste": "upprymd",
    "upprymdastes": "upprymd",
    "upprymdasts": "upprymd",
    "upprymde": "upprymma",
    "upprymdes": "upprymma",
    "upprymdheten": "upprymdhet",
    "upprymdhetens": "upprymdhet",
    "upprymdhets": "upprymdhet",
    "upprymds": "upprymma",
    "upprymmande": "upprymma",
    "upprymmanden": "upprymmande",
    "upprymmandena": "upprymmande",
    "upprymmandenas": "upprymmande",
    "upprymmandens": "upprymmande",
    "upprymmandes": "upprymmande",
    "upprymmandet": "upprymmande",
    "upprymmandets": "upprymmande",
    "upprymmar": "upprymmare",
    "upprymmaren": "upprymmare",
    "upprymmarens": "upprymmare",
    "upprymmares": "upprymmare",
    "upprymmarna": "upprymmare",
    "upprymmarnas": "upprymmare",
    "upprymmas": "upprymma",
    "upprymmer": "upprymma",
    "upprymningsstålen": "upprymningsstål",
    "upprymningsstålens": "upprymningsstål",
    "upprymningsstålet": "upprymningsstål",
    "upprymningsstålets": "upprymningsstål",
    "upprymningsståls": "upprymningsstål",
    "uppryms": "upprymma",
    "upprymt": "upprymma",
    "upprymts": "upprymma",
    "uppräknad": "uppräkna",
    "uppräknade": "uppräkna",
    "uppräknades": "uppräkna",
    "uppräknads": "uppräkna",
    "uppräknande": "uppräkna",
    "uppräknanden": "uppräknande",
    "uppräknandena": "uppräknande",
    "uppräknandenas": "uppräknande",
    "uppräknandens": "uppräknande",
    "uppräknandes": "uppräknande",
    "uppräknandet": "uppräknande",
    "uppräknandets": "uppräknande",
    "uppräknar": "uppräkna",
    "uppräknas": "uppräkna",
    "uppräknat": "uppräkna",
    "uppräknats": "uppräkna",
    "uppräkningar": "uppräkning",
    "uppräkningarna": "uppräkning",
    "uppräkningarnas": "uppräkning",
    "uppräkningars": "uppräkning",
    "uppräkningen": "uppräkning",
    "uppräkningens": "uppräkning",
    "uppräknings": "uppräkning",
    "uppränd": "uppränna",
    "upprända": "uppränna",
    "upprändas": "uppränna",
    "upprände": "uppränna",
    "upprändes": "uppränna",
    "uppränds": "uppränna",
    "uppränn": "uppränna",
    "upprännande": "uppränna",
    "upprännanden": "upprännande",
    "upprännandena": "upprännande",
    "upprännandenas": "upprännande",
    "upprännandens": "upprännande",
    "upprännandes": "upprännande",
    "upprännandet": "upprännande",
    "upprännandets": "upprännande",
    "upprännas": "uppränna",
    "uppränner": "uppränna",
    "upprännes": "uppränna",
    "uppränningar": "uppränning",
    "uppränningarna": "uppränning",
    "uppränningarnas": "uppränning",
    "uppränningars": "uppränning",
    "uppränningen": "uppränning",
    "uppränningens": "uppränning",
    "upprännings": "uppränning",
    "uppränns": "uppränna",
    "uppränt": "uppränna",
    "uppränts": "uppränna",
    "upprätt": "upprätta",
    "upprätta": "upprätt",
    "upprättad": "upprätta",
    "upprättade": "upprätta",
    "upprättades": "upprätta",
    "upprättads": "upprätta",
    "upprättande": "upprätta",
    "upprättanden": "upprättande",
    "upprättandena": "upprättande",
    "upprättandenas": "upprättande",
    "upprättandens": "upprättande",
    "upprättandes": "upprättande",
    "upprättandet": "upprättande",
    "upprättandets": "upprättande",
    "upprättar": "upprätta",
    "upprättare": "upprätt",
    "upprättares": "upprätt",
    "upprättas": "upprätta",
    "upprättast": "upprätt",
    "upprättaste": "upprätt",
    "upprättastes": "upprätt",
    "upprättasts": "upprätt",
    "upprättat": "upprätta",
    "upprättats": "upprätta",
    "upprätte": "upprätt",
    "upprättelsen": "upprättelse",
    "upprättelsens": "upprättelse",
    "upprättelser": "upprättelse",
    "upprättelserna": "upprättelse",
    "upprättelsernas": "upprättelse",
    "upprättelsers": "upprättelse",
    "upprättelses": "upprättelse",
    "upprättes": "upprätt",
    "upprätthåll": "upprätthålla",
    "upprätthållande": "upprätthålla",
    "upprätthållanden": "upprätthållande",
    "upprätthållandena": "upprätthållande",
    "upprätthållandenas": "upprätthållande",
    "upprätthållandens": "upprätthållande",
    "upprätthållandes": "upprätthållande",
    "upprätthållandet": "upprätthållande",
    "upprätthållandets": "upprätthållande",
    "upprätthållas": "upprätthålla",
    "upprätthålle": "upprätthålla",
    "upprätthållen": "upprätthålla",
    "upprätthållens": "upprätthålla",
    "upprätthåller": "upprätthålla",
    "upprätthålles": "upprätthålla",
    "upprätthållet": "upprätthålla",
    "upprätthållets": "upprätthålla",
    "upprätthållit": "upprätthålla",
    "upprätthållits": "upprätthålla",
    "upprätthållna": "upprätthålla",
    "upprätthållnas": "upprätthålla",
    "upprätthållne": "upprätthålla",
    "upprätthållnes": "upprätthålla",
    "upprätthålls": "upprätthålla",
    "upprätthöll": "upprätthålla",
    "upprätthölle": "upprätthålla",
    "upprätthölles": "upprätthålla",
    "upprätthölls": "upprätthålla",
    "upprätts": "upprätt",
    "uppröjningar": "uppröjning",
    "uppröjningarna": "uppröjning",
    "uppröjningarnas": "uppröjning",
    "uppröjningars": "uppröjning",
    "uppröjningen": "uppröjning",
    "uppröjningens": "uppröjning",
    "uppröjnings": "uppröjning",
    "upprör": "uppröra",
    "upprörande": "uppröra",
    "uppröranden": "upprörande",
    "upprörandena": "upprörande",
    "upprörandenas": "upprörande",
    "upprörandens": "upprörande",
    "upprörandes": "upprörande",
    "upprörandet": "upprörande",
    "upprörandets": "upprörande",
    "uppröras": "uppröra",
    "upprörd": "uppröra",
    "upprörda": "upprörd",
    "upprördare": "upprörd",
    "upprördares": "upprörd",
    "upprördas": "upprörd",
    "upprördast": "upprörd",
    "upprördaste": "upprörd",
    "upprördastes": "upprörd",
    "upprördasts": "upprörd",
    "upprörde": "upprörd",
    "upprördes": "upprörd",
    "upprördheten": "upprördhet",
    "upprördhetens": "upprördhet",
    "upprördhets": "upprördhet",
    "upprörds": "upprörd",
    "uppröres": "uppröra",
    "upprörs": "uppröra",
    "upprört": "upprörd",
    "upprörts": "upprörd",
    "uppsagda": "uppsagd",
    "uppsagdare": "uppsagd",
    "uppsagdares": "uppsagd",
    "uppsagdas": "uppsagd",
    "uppsagdast": "uppsagd",
    "uppsagdaste": "uppsagd",
    "uppsagdastes": "uppsagd",
    "uppsagdasts": "uppsagd",
    "uppsagde": "uppsagd",
    "uppsagdes": "uppsagd",
    "uppsagds": "uppsagd",
    "uppsagt": "uppsagd",
    "uppsagts": "uppsagd",
    "uppsamlad": "uppsamla",
    "uppsamlade": "uppsamla",
    "uppsamlades": "uppsamla",
    "uppsamlads": "uppsamla",
    "uppsamlande": "uppsamla",
    "uppsamlanden": "uppsamlande",
    "uppsamlandena": "uppsamlande",
    "uppsamlandenas": "uppsamlande",
    "uppsamlandens": "uppsamlande",
    "uppsamlandes": "uppsamlande",
    "uppsamlandet": "uppsamlande",
    "uppsamlandets": "uppsamlande",
    "uppsamlar": "uppsamlare",
    "uppsamlaren": "uppsamlare",
    "uppsamlarens": "uppsamlare",
    "uppsamlares": "uppsamlare",
    "uppsamlarna": "uppsamlare",
    "uppsamlarnas": "uppsamlare",
    "uppsamlas": "uppsamla",
    "uppsamlat": "uppsamla",
    "uppsamlats": "uppsamla",
    "uppsamlingar": "uppsamling",
    "uppsamlingarna": "uppsamling",
    "uppsamlingarnas": "uppsamling",
    "uppsamlingars": "uppsamling",
    "uppsamlingen": "uppsamling",
    "uppsamlingens": "uppsamling",
    "uppsamlings": "uppsamling",
    "uppsamlingsborst": "uppsamlingsborste",
    "uppsamlingsborstar": "uppsamlingsborste",
    "uppsamlingsborstarna": "uppsamlingsborste",
    "uppsamlingsborstarnas": "uppsamlingsborste",
    "uppsamlingsborstars": "uppsamlingsborste",
    "uppsamlingsborsten": "uppsamlingsborste",
    "uppsamlingsborstens": "uppsamlingsborste",
    "uppsamlingsborstes": "uppsamlingsborste",
    "uppsamlingskass": "uppsamlingskasse",
    "uppsamlingskassar": "uppsamlingskasse",
    "uppsamlingskassarna": "uppsamlingskasse",
    "uppsamlingskassarnas": "uppsamlingskasse",
    "uppsamlingskassars": "uppsamlingskasse",
    "uppsamlingskassen": "uppsamlingskasse",
    "uppsamlingskassens": "uppsamlingskasse",
    "uppsamlingskasses": "uppsamlingskasse",
    "uppsamlingslägerna": "uppsamlingsläger",
    "uppsamlingslägernas": "uppsamlingsläger",
    "uppsamlingslägers": "uppsamlingsläger",
    "uppsamlingslägren": "uppsamlingsläger",
    "uppsamlingslägrens": "uppsamlingsläger",
    "uppsamlingslägret": "uppsamlingsläger",
    "uppsamlingslägrets": "uppsamlingsläger",
    "uppsamlingssäckar": "uppsamlingssäck",
    "uppsamlingssäckarna": "uppsamlingssäck",
    "uppsamlingssäckarnas": "uppsamlingssäck",
    "uppsamlingssäckars": "uppsamlingssäck",
    "uppsamlingssäcken": "uppsamlingssäck",
    "uppsamlingssäckens": "uppsamlingssäck",
    "uppsamlingssäcks": "uppsamlingssäck",
    "uppsatsen": "uppsats",
    "uppsatsens": "uppsats",
    "uppsatser": "uppsats",
    "uppsatserna": "uppsats",
    "uppsatsernas": "uppsats",
    "uppsatsers": "uppsats",
    "uppsatslagen": "uppsatslag",
    "uppsatslagens": "uppsatslag",
    "uppsatslaget": "uppsatslag",
    "uppsatslagets": "uppsatslag",
    "uppsatslags": "uppsatslag",
    "uppsatt": "uppsätta",
    "uppsatta": "uppsätta",
    "uppsattare": "uppsatt",
    "uppsattares": "uppsatt",
    "uppsattas": "uppsätta",
    "uppsattast": "uppsatt",
    "uppsattaste": "uppsatt",
    "uppsattastes": "uppsatt",
    "uppsattasts": "uppsatt",
    "uppsatte": "uppsätta",
    "uppsattes": "uppsätta",
    "uppsatts": "uppsätta",
    "uppseendes": "uppseende",
    "uppseendet": "uppseende",
    "uppseendets": "uppseende",
    "uppsikten": "uppsikt",
    "uppsiktens": "uppsikt",
    "uppsikts": "uppsikt",
    "uppsittarkvällar": "uppsittarkväll",
    "uppsittarkvällarna": "uppsittarkväll",
    "uppsittarkvällarnas": "uppsittarkväll",
    "uppsittarkvällars": "uppsittarkväll",
    "uppsittarkvällen": "uppsittarkväll",
    "uppsittarkvällens": "uppsittarkväll",
    "uppsittarkvälls": "uppsittarkväll",
    "uppsittningar": "uppsittning",
    "uppsittningarna": "uppsittning",
    "uppsittningarnas": "uppsittning",
    "uppsittningars": "uppsittning",
    "uppsittningen": "uppsittning",
    "uppsittningens": "uppsittning",
    "uppsittnings": "uppsittning",
    "uppsjungningar": "uppsjungning",
    "uppsjungningarna": "uppsjungning",
    "uppsjungningarnas": "uppsjungning",
    "uppsjungningars": "uppsjungning",
    "uppsjungningen": "uppsjungning",
    "uppsjungningens": "uppsjungning",
    "uppsjungnings": "uppsjungning",
    "uppsjös": "uppsjö",
    "uppskakade": "uppskakad",
    "uppskakades": "uppskakad",
    "uppskakads": "uppskakad",
    "uppskakat": "uppskakad",
    "uppskakats": "uppskakad",
    "uppskalningar": "uppskalning",
    "uppskalningarna": "uppskalning",
    "uppskalningarnas": "uppskalning",
    "uppskalningars": "uppskalning",
    "uppskalningen": "uppskalning",
    "uppskalningens": "uppskalning",
    "uppskalnings": "uppskalning",
    "uppskatt": "uppskatta",
    "uppskattad": "uppskatta",
    "uppskattade": "uppskatta",
    "uppskattades": "uppskatta",
    "uppskattads": "uppskatta",
    "uppskattande": "uppskatta",
    "uppskattanden": "uppskattande",
    "uppskattandena": "uppskattande",
    "uppskattandenas": "uppskattande",
    "uppskattandens": "uppskattande",
    "uppskattandes": "uppskattande",
    "uppskattandet": "uppskattande",
    "uppskattandets": "uppskattande",
    "uppskattar": "uppskatta",
    "uppskattas": "uppskatta",
    "uppskattat": "uppskatta",
    "uppskattats": "uppskatta",
    "uppskattningar": "uppskattning",
    "uppskattningarna": "uppskattning",
    "uppskattningarnas": "uppskattning",
    "uppskattningars": "uppskattning",
    "uppskattningen": "uppskattning",
    "uppskattningens": "uppskattning",
    "uppskattnings": "uppskattning",
    "uppskjut": "uppskjuta",
    "uppskjutande": "uppskjuta",
    "uppskjutanden": "uppskjutande",
    "uppskjutandena": "uppskjutande",
    "uppskjutandenas": "uppskjutande",
    "uppskjutandens": "uppskjutande",
    "uppskjutandes": "uppskjutande",
    "uppskjutandet": "uppskjutande",
    "uppskjutandets": "uppskjutande",
    "uppskjutas": "uppskjuta",
    "uppskjute": "uppskjuta",
    "uppskjuten": "uppskjuta",
    "uppskjutens": "uppskjuta",
    "uppskjuter": "uppskjuta",
    "uppskjutes": "uppskjuta",
    "uppskjutet": "uppskjuta",
    "uppskjutets": "uppskjuta",
    "uppskjutit": "uppskjuta",
    "uppskjutits": "uppskjuta",
    "uppskjutna": "uppskjuta",
    "uppskjutnas": "uppskjuta",
    "uppskjutne": "uppskjuta",
    "uppskjutnes": "uppskjuta",
    "uppskjutningar": "uppskjutning",
    "uppskjutningarna": "uppskjutning",
    "uppskjutningarnas": "uppskjutning",
    "uppskjutningars": "uppskjutning",
    "uppskjutningen": "uppskjutning",
    "uppskjutningens": "uppskjutning",
    "uppskjutnings": "uppskjutning",
    "uppskjuts": "uppskjuta",
    "uppskojade": "uppskojad",
    "uppskojades": "uppskojad",
    "uppskojads": "uppskojad",
    "uppskojat": "uppskojad",
    "uppskojats": "uppskojad",
    "uppskoven": "uppskov",
    "uppskovens": "uppskov",
    "uppskovet": "uppskov",
    "uppskovets": "uppskov",
    "uppskovs": "uppskov",
    "uppskovsräntan": "uppskovsränta",
    "uppskovsräntans": "uppskovsränta",
    "uppskovsräntas": "uppskovsränta",
    "uppskovsränte": "uppskovsränta",
    "uppskovsräntor": "uppskovsränta",
    "uppskovsräntorna": "uppskovsränta",
    "uppskovsräntornas": "uppskovsränta",
    "uppskovsräntors": "uppskovsränta",
    "uppskrivningar": "uppskrivning",
    "uppskrivningarna": "uppskrivning",
    "uppskrivningarnas": "uppskrivning",
    "uppskrivningars": "uppskrivning",
    "uppskrivningen": "uppskrivning",
    "uppskrivningens": "uppskrivning",
    "uppskrivnings": "uppskrivning",
    "uppskruvade": "uppskruvad",
    "uppskruvades": "uppskruvad",
    "uppskruvads": "uppskruvad",
    "uppskruvat": "uppskruvad",
    "uppskruvats": "uppskruvad",
    "uppskrämde": "uppskrämd",
    "uppskrämdes": "uppskrämd",
    "uppskrämdheten": "uppskrämdhet",
    "uppskrämdhetens": "uppskrämdhet",
    "uppskrämdhets": "uppskrämdhet",
    "uppskrämds": "uppskrämd",
    "uppskrämt": "uppskrämd",
    "uppskrämts": "uppskrämd",
    "uppskärar": "uppskärare",
    "uppskäraren": "uppskärare",
    "uppskärarens": "uppskärare",
    "uppskärares": "uppskärare",
    "uppskärarna": "uppskärare",
    "uppskärarnas": "uppskärare",
    "uppskärrade": "uppskärrad",
    "uppskärrades": "uppskärrad",
    "uppskärrads": "uppskärrad",
    "uppskärrat": "uppskärrad",
    "uppskärrats": "uppskärrad",
    "uppskörtade": "uppskörtad",
    "uppskörtades": "uppskörtad",
    "uppskörtads": "uppskörtad",
    "uppskörtat": "uppskörtad",
    "uppskörtats": "uppskörtad",
    "uppsköt": "uppskjuta",
    "uppsköte": "uppskjuta",
    "uppskötes": "uppskjuta",
    "uppsköts": "uppskjuta",
    "uppslagen": "uppslag",
    "uppslagens": "uppslagen",
    "uppslaget": "uppslagen",
    "uppslagets": "uppslagen",
    "uppslagna": "uppslagen",
    "uppslagnas": "uppslagen",
    "uppslagne": "uppslagen",
    "uppslagnes": "uppslagen",
    "uppslags": "uppslag",
    "uppslagsboken": "uppslagsbok",
    "uppslagsbokens": "uppslagsbok",
    "uppslagsboks": "uppslagsbok",
    "uppslagsböcker": "uppslagsbok",
    "uppslagsböckerna": "uppslagsbok",
    "uppslagsböckernas": "uppslagsbok",
    "uppslagsböckers": "uppslagsbok",
    "uppslagsformen": "uppslagsform",
    "uppslagsformens": "uppslagsform",
    "uppslagsformer": "uppslagsform",
    "uppslagsformerna": "uppslagsform",
    "uppslagsformernas": "uppslagsform",
    "uppslagsformers": "uppslagsform",
    "uppslagsforms": "uppslagsform",
    "uppslagsorden": "uppslagsord",
    "uppslagsordens": "uppslagsord",
    "uppslagsordet": "uppslagsord",
    "uppslagsordets": "uppslagsord",
    "uppslagsords": "uppslagsord",
    "uppslagsrika": "uppslagsrik",
    "uppslagsrikare": "uppslagsrik",
    "uppslagsrikares": "uppslagsrik",
    "uppslagsrikas": "uppslagsrik",
    "uppslagsrikast": "uppslagsrik",
    "uppslagsrikaste": "uppslagsrik",
    "uppslagsrikastes": "uppslagsrik",
    "uppslagsrikasts": "uppslagsrik",
    "uppslagsrike": "uppslagsrik",
    "uppslagsrikes": "uppslagsrik",
    "uppslagsrikheten": "uppslagsrikhet",
    "uppslagsrikhetens": "uppslagsrikhet",
    "uppslagsrikhets": "uppslagsrikhet",
    "uppslagsriks": "uppslagsrik",
    "uppslagsrikt": "uppslagsrik",
    "uppslagsrikts": "uppslagsrik",
    "uppslagssikten": "uppslagssikte",
    "uppslagssiktena": "uppslagssikte",
    "uppslagssiktenas": "uppslagssikte",
    "uppslagssiktens": "uppslagssikte",
    "uppslagssiktes": "uppslagssikte",
    "uppslagssiktet": "uppslagssikte",
    "uppslagssiktets": "uppslagssikte",
    "uppslagsverken": "uppslagsverk",
    "uppslagsverkens": "uppslagsverk",
    "uppslagsverket": "uppslagsverk",
    "uppslagsverkets": "uppslagsverk",
    "uppslagsverks": "uppslagsverk",
    "uppslagsänd": "uppslagsända",
    "uppslagsändan": "uppslagsända",
    "uppslagsändans": "uppslagsända",
    "uppslagsändar": "uppslagsände",
    "uppslagsändarna": "uppslagsände",
    "uppslagsändarnas": "uppslagsände",
    "uppslagsändars": "uppslagsände",
    "uppslagsändas": "uppslagsända",
    "uppslagsände": "uppslagsända",
    "uppslagsänden": "uppslagsände",
    "uppslagsändens": "uppslagsände",
    "uppslagsändes": "uppslagsände",
    "uppslagsändor": "uppslagsända",
    "uppslagsändorna": "uppslagsända",
    "uppslagsändornas": "uppslagsända",
    "uppslagsändors": "uppslagsända",
    "uppslagsänds": "uppslagsända",
    "uppslaktade": "uppslaktad",
    "uppslaktades": "uppslaktad",
    "uppslaktads": "uppslaktad",
    "uppslaktat": "uppslaktad",
    "uppslaktats": "uppslaktad",
    "uppslammad": "uppslamma",
    "uppslammade": "uppslammad",
    "uppslammades": "uppslammad",
    "uppslammads": "uppslammad",
    "uppslammande": "uppslamma",
    "uppslammanden": "uppslammande",
    "uppslammandena": "uppslammande",
    "uppslammandenas": "uppslammande",
    "uppslammandens": "uppslammande",
    "uppslammandes": "uppslammande",
    "uppslammandet": "uppslammande",
    "uppslammandets": "uppslammande",
    "uppslammar": "uppslamma",
    "uppslammas": "uppslamma",
    "uppslammat": "uppslammad",
    "uppslammats": "uppslammad",
    "uppslitsade": "uppslitsad",
    "uppslitsades": "uppslitsad",
    "uppslitsads": "uppslitsad",
    "uppslitsat": "uppslitsad",
    "uppslitsats": "uppslitsad",
    "uppsluk": "uppsluka",
    "uppslukad": "uppsluka",
    "uppslukade": "uppsluka",
    "uppslukades": "uppsluka",
    "uppslukads": "uppsluka",
    "uppslukande": "uppsluka",
    "uppslukanden": "uppslukande",
    "uppslukandena": "uppslukande",
    "uppslukandenas": "uppslukande",
    "uppslukandens": "uppslukande",
    "uppslukandes": "uppslukande",
    "uppslukandet": "uppslukande",
    "uppslukandets": "uppslukande",
    "uppslukar": "uppsluka",
    "uppslukas": "uppsluka",
    "uppslukat": "uppsluka",
    "uppslukats": "uppsluka",
    "uppsluppens": "uppsluppen",
    "uppsluppet": "uppsluppen",
    "uppsluppets": "uppsluppen",
    "uppsluppna": "uppsluppen",
    "uppsluppnare": "uppsluppen",
    "uppsluppnares": "uppsluppen",
    "uppsluppnas": "uppsluppen",
    "uppsluppnast": "uppsluppen",
    "uppsluppnaste": "uppsluppen",
    "uppsluppnastes": "uppsluppen",
    "uppsluppnasts": "uppsluppen",
    "uppsluppne": "uppsluppen",
    "uppsluppnes": "uppsluppen",
    "uppslutningar": "uppslutning",
    "uppslutningarna": "uppslutning",
    "uppslutningarnas": "uppslutning",
    "uppslutningars": "uppslutning",
    "uppslutningen": "uppslutning",
    "uppslutningens": "uppslutning",
    "uppslutnings": "uppslutning",
    "uppsnabb": "uppsnabba",
    "uppsnabbad": "uppsnabba",
    "uppsnabbade": "uppsnabba",
    "uppsnabbades": "uppsnabba",
    "uppsnabbads": "uppsnabba",
    "uppsnabbande": "uppsnabba",
    "uppsnabbanden": "uppsnabbande",
    "uppsnabbandena": "uppsnabbande",
    "uppsnabbandenas": "uppsnabbande",
    "uppsnabbandens": "uppsnabbande",
    "uppsnabbandes": "uppsnabbande",
    "uppsnabbandet": "uppsnabbande",
    "uppsnabbandets": "uppsnabbande",
    "uppsnabbar": "uppsnabba",
    "uppsnabbas": "uppsnabba",
    "uppsnabbat": "uppsnabba",
    "uppsnabbats": "uppsnabba",
    "uppsnapp": "uppsnappa",
    "uppsnappad": "uppsnappa",
    "uppsnappade": "uppsnappa",
    "uppsnappades": "uppsnappa",
    "uppsnappads": "uppsnappa",
    "uppsnappande": "uppsnappa",
    "uppsnappanden": "uppsnappande",
    "uppsnappandena": "uppsnappande",
    "uppsnappandenas": "uppsnappande",
    "uppsnappandens": "uppsnappande",
    "uppsnappandes": "uppsnappande",
    "uppsnappandet": "uppsnappande",
    "uppsnappandets": "uppsnappande",
    "uppsnappar": "uppsnappa",
    "uppsnappas": "uppsnappa",
    "uppsnappat": "uppsnappa",
    "uppsnappats": "uppsnappa",
    "uppspaltningar": "uppspaltning",
    "uppspaltningarna": "uppspaltning",
    "uppspaltningarnas": "uppspaltning",
    "uppspaltningars": "uppspaltning",
    "uppspaltningen": "uppspaltning",
    "uppspaltningens": "uppspaltning",
    "uppspaltnings": "uppspaltning",
    "uppspelen": "uppspel",
    "uppspelens": "uppspel",
    "uppspelet": "uppspel",
    "uppspelets": "uppspel",
    "uppspelningar": "uppspelning",
    "uppspelningarna": "uppspelning",
    "uppspelningarnas": "uppspelning",
    "uppspelningars": "uppspelning",
    "uppspelningen": "uppspelning",
    "uppspelningens": "uppspelning",
    "uppspelnings": "uppspelning",
    "uppspels": "uppspel",
    "uppspelta": "uppspelt",
    "uppspeltare": "uppspelt",
    "uppspeltares": "uppspelt",
    "uppspeltas": "uppspelt",
    "uppspeltast": "uppspelt",
    "uppspeltaste": "uppspelt",
    "uppspeltastes": "uppspelt",
    "uppspeltasts": "uppspelt",
    "uppspelte": "uppspelt",
    "uppspeltes": "uppspelt",
    "uppspeltheten": "uppspelthet",
    "uppspelthetens": "uppspelthet",
    "uppspelthets": "uppspelthet",
    "uppspelts": "uppspelt",
    "uppspetade": "uppspetad",
    "uppspetades": "uppspetad",
    "uppspetads": "uppspetad",
    "uppspetat": "uppspetad",
    "uppspetats": "uppspetad",
    "uppspjälk": "uppspjälka",
    "uppspjälkad": "uppspjälka",
    "uppspjälkade": "uppspjälka",
    "uppspjälkades": "uppspjälka",
    "uppspjälkads": "uppspjälka",
    "uppspjälkande": "uppspjälka",
    "uppspjälkanden": "uppspjälkande",
    "uppspjälkandena": "uppspjälkande",
    "uppspjälkandenas": "uppspjälkande",
    "uppspjälkandens": "uppspjälkande",
    "uppspjälkandes": "uppspjälkande",
    "uppspjälkandet": "uppspjälkande",
    "uppspjälkandets": "uppspjälkande",
    "uppspjälkar": "uppspjälka",
    "uppspjälkas": "uppspjälka",
    "uppspjälkat": "uppspjälka",
    "uppspjälkats": "uppspjälka",
    "uppsplittringar": "uppsplittring",
    "uppsplittringarna": "uppsplittring",
    "uppsplittringarnas": "uppsplittring",
    "uppsplittringars": "uppsplittring",
    "uppsplittringen": "uppsplittring",
    "uppsplittringens": "uppsplittring",
    "uppsplittrings": "uppsplittring",
    "uppsprack": "uppspricka",
    "uppspracks": "uppspricka",
    "uppsprick": "uppspricka",
    "uppsprickande": "uppspricka",
    "uppsprickanden": "uppsprickande",
    "uppsprickandena": "uppsprickande",
    "uppsprickandenas": "uppsprickande",
    "uppsprickandens": "uppsprickande",
    "uppsprickandes": "uppsprickande",
    "uppsprickandet": "uppsprickande",
    "uppsprickandets": "uppsprickande",
    "uppsprickas": "uppspricka",
    "uppspricke": "uppspricka",
    "uppspricker": "uppspricka",
    "uppsprickes": "uppspricka",
    "uppspricks": "uppspricka",
    "uppsprucke": "uppspricka",
    "uppsprucken": "uppspricka",
    "uppspruckens": "uppspricka",
    "uppspruckes": "uppspricka",
    "uppsprucket": "uppspricka",
    "uppspruckets": "uppspricka",
    "uppspruckit": "uppspricka",
    "uppspruckits": "uppspricka",
    "uppspruckna": "uppspricka",
    "uppsprucknas": "uppspricka",
    "uppspruckne": "uppspricka",
    "uppsprucknes": "uppspricka",
    "uppsprången": "uppsprång",
    "uppsprångens": "uppsprång",
    "uppsprånget": "uppsprång",
    "uppsprångets": "uppsprång",
    "uppsprångs": "uppsprång",
    "uppspärrade": "uppspärrad",
    "uppspärrades": "uppspärrad",
    "uppspärrads": "uppspärrad",
    "uppspärrat": "uppspärrad",
    "uppspärrats": "uppspärrad",
    "uppspårade": "uppspåra",
    "uppspårades": "uppspåra",
    "uppspårande": "uppspåra",
    "uppspåranden": "uppspårande",
    "uppspårandena": "uppspårande",
    "uppspårandenas": "uppspårande",
    "uppspårandens": "uppspårande",
    "uppspårandes": "uppspårande",
    "uppspårandet": "uppspårande",
    "uppspårandets": "uppspårande",
    "uppspårar": "uppspåra",
    "uppspåras": "uppspåra",
    "uppspårat": "uppspåra",
    "uppspårats": "uppspåra",
    "uppstaden": "uppstad",
    "uppstadens": "uppstad",
    "uppstads": "uppstad",
    "uppstan": "uppstad",
    "uppstans": "uppstad",
    "uppsteg": "uppstiga",
    "uppstegs": "uppstiga",
    "uppstickar": "uppstickare",
    "uppstickarbanken": "uppstickarbank",
    "uppstickarbankens": "uppstickarbank",
    "uppstickarbanker": "uppstickarbank",
    "uppstickarbankerna": "uppstickarbank",
    "uppstickarbankernas": "uppstickarbank",
    "uppstickarbankers": "uppstickarbank",
    "uppstickarbanks": "uppstickarbank",
    "uppstickarbolagen": "uppstickarbolag",
    "uppstickarbolagens": "uppstickarbolag",
    "uppstickarbolaget": "uppstickarbolag",
    "uppstickarbolagets": "uppstickarbolag",
    "uppstickarbolags": "uppstickarbolag",
    "uppstickaren": "uppstickare",
    "uppstickarens": "uppstickare",
    "uppstickares": "uppstickare",
    "uppstickarna": "uppstickare",
    "uppstickarnas": "uppstickare",
    "uppstig": "uppstiga",
    "uppstigande": "uppstiga",
    "uppstiganden": "uppstigande",
    "uppstigandena": "uppstigande",
    "uppstigandenas": "uppstigande",
    "uppstigandens": "uppstigande",
    "uppstigandes": "uppstigande",
    "uppstigandet": "uppstigande",
    "uppstigandets": "uppstigande",
    "uppstigas": "uppstiga",
    "uppstige": "uppstiga",
    "uppstigen": "uppstiga",
    "uppstigens": "uppstiga",
    "uppstiger": "uppstiga",
    "uppstiges": "uppstiga",
    "uppstiget": "uppstiga",
    "uppstigets": "uppstiga",
    "uppstigit": "uppstiga",
    "uppstigits": "uppstiga",
    "uppstigna": "uppstiga",
    "uppstignas": "uppstiga",
    "uppstigne": "uppstiga",
    "uppstignes": "uppstiga",
    "uppstigningar": "uppstigning",
    "uppstigningarna": "uppstigning",
    "uppstigningarnas": "uppstigning",
    "uppstigningars": "uppstigning",
    "uppstigningen": "uppstigning",
    "uppstigningens": "uppstigning",
    "uppstignings": "uppstigning",
    "uppstigs": "uppstiga",
    "uppstod": "uppstå",
    "uppstode": "uppstå",
    "uppstodes": "uppstå",
    "uppstods": "uppstå",
    "uppstoppade": "uppstoppad",
    "uppstoppades": "uppstoppad",
    "uppstoppads": "uppstoppad",
    "uppstoppat": "uppstoppad",
    "uppstoppats": "uppstoppad",
    "uppstram": "uppstrama",
    "uppstramad": "uppstrama",
    "uppstramade": "uppstrama",
    "uppstramades": "uppstrama",
    "uppstramads": "uppstrama",
    "uppstramande": "uppstrama",
    "uppstramanden": "uppstramande",
    "uppstramandena": "uppstramande",
    "uppstramandenas": "uppstramande",
    "uppstramandens": "uppstramande",
    "uppstramandes": "uppstramande",
    "uppstramandet": "uppstramande",
    "uppstramandets": "uppstramande",
    "uppstramar": "uppstrama",
    "uppstramas": "uppstrama",
    "uppstramat": "uppstrama",
    "uppstramats": "uppstrama",
    "uppstramningar": "uppstramning",
    "uppstramningarna": "uppstramning",
    "uppstramningarnas": "uppstramning",
    "uppstramningars": "uppstramning",
    "uppstramningen": "uppstramning",
    "uppstramningens": "uppstramning",
    "uppstramnings": "uppstramning",
    "uppsträckningar": "uppsträckning",
    "uppsträckningarna": "uppsträckning",
    "uppsträckningarnas": "uppsträckning",
    "uppsträckningars": "uppsträckning",
    "uppsträckningen": "uppsträckning",
    "uppsträckningens": "uppsträckning",
    "uppsträcknings": "uppsträckning",
    "uppsträckta": "uppsträckt",
    "uppsträcktare": "uppsträckt",
    "uppsträcktares": "uppsträckt",
    "uppsträcktas": "uppsträckt",
    "uppsträcktast": "uppsträckt",
    "uppsträcktaste": "uppsträckt",
    "uppsträcktastes": "uppsträckt",
    "uppsträcktasts": "uppsträckt",
    "uppsträckte": "uppsträckt",
    "uppsträcktes": "uppsträckt",
    "uppsträcktheten": "uppsträckthet",
    "uppsträckthetens": "uppsträckthet",
    "uppsträckthets": "uppsträckthet",
    "uppsträckts": "uppsträckt",
    "uppstråken": "uppstråk",
    "uppstråkens": "uppstråk",
    "uppstråket": "uppstråk",
    "uppstråkets": "uppstråk",
    "uppstråks": "uppstråk",
    "uppströmmar": "uppström",
    "uppströmmarna": "uppström",
    "uppströmmarnas": "uppström",
    "uppströmmars": "uppström",
    "uppströmmen": "uppström",
    "uppströmmens": "uppström",
    "uppströms": "uppström",
    "uppstudsiga": "uppstudsig",
    "uppstudsigare": "uppstudsig",
    "uppstudsigares": "uppstudsig",
    "uppstudsigas": "uppstudsig",
    "uppstudsigast": "uppstudsig",
    "uppstudsigaste": "uppstudsig",
    "uppstudsigastes": "uppstudsig",
    "uppstudsigasts": "uppstudsig",
    "uppstudsige": "uppstudsig",
    "uppstudsiges": "uppstudsig",
    "uppstudsigheten": "uppstudsighet",
    "uppstudsighetens": "uppstudsighet",
    "uppstudsighets": "uppstudsighet",
    "uppstudsigs": "uppstudsig",
    "uppstudsigt": "uppstudsig",
    "uppstudsigts": "uppstudsig",
    "uppstyltade": "uppstyltad",
    "uppstyltades": "uppstyltad",
    "uppstyltads": "uppstyltad",
    "uppstyltat": "uppstyltad",
    "uppstyltats": "uppstyltad",
    "uppstäder": "uppstad",
    "uppstäderna": "uppstad",
    "uppstädernas": "uppstad",
    "uppstäders": "uppstad",
    "uppställ": "uppställa",
    "uppställande": "uppställa",
    "uppställanden": "uppställande",
    "uppställandena": "uppställande",
    "uppställandenas": "uppställande",
    "uppställandens": "uppställande",
    "uppställandes": "uppställande",
    "uppställandet": "uppställande",
    "uppställandets": "uppställande",
    "uppställas": "uppställa",
    "uppställd": "uppställa",
    "uppställda": "uppställa",
    "uppställdas": "uppställa",
    "uppställde": "uppställa",
    "uppställdes": "uppställa",
    "uppställds": "uppställa",
    "uppställer": "uppställa",
    "uppställes": "uppställa",
    "uppställningar": "uppställning",
    "uppställningarna": "uppställning",
    "uppställningarnas": "uppställning",
    "uppställningars": "uppställning",
    "uppställningen": "uppställning",
    "uppställningens": "uppställning",
    "uppställnings": "uppställning",
    "uppställningsplatsen": "uppställningsplats",
    "uppställningsplatsens": "uppställningsplats",
    "uppställningsplatser": "uppställningsplats",
    "uppställningsplatserna": "uppställningsplats",
    "uppställningsplatsernas": "uppställningsplats",
    "uppställningsplatsers": "uppställningsplats",
    "uppställningssignalen": "uppställningssignal",
    "uppställningssignalens": "uppställningssignal",
    "uppställningssignaler": "uppställningssignal",
    "uppställningssignalerna": "uppställningssignal",
    "uppställningssignalernas": "uppställningssignal",
    "uppställningssignalers": "uppställningssignal",
    "uppställningssignals": "uppställningssignal",
    "uppställningsspåren": "uppställningsspår",
    "uppställningsspårens": "uppställningsspår",
    "uppställningsspåret": "uppställningsspår",
    "uppställningsspårets": "uppställningsspår",
    "uppställningsspårs": "uppställningsspår",
    "uppställs": "uppställa",
    "uppställt": "uppställa",
    "uppställts": "uppställa",
    "uppstäm": "uppstämma",
    "uppstämd": "uppstämma",
    "uppstämda": "uppstämma",
    "uppstämdas": "uppstämma",
    "uppstämde": "uppstämma",
    "uppstämdes": "uppstämma",
    "uppstämds": "uppstämma",
    "uppstämmande": "uppstämma",
    "uppstämmanden": "uppstämmande",
    "uppstämmandena": "uppstämmande",
    "uppstämmandenas": "uppstämmande",
    "uppstämmandens": "uppstämmande",
    "uppstämmandes": "uppstämmande",
    "uppstämmandet": "uppstämmande",
    "uppstämmandets": "uppstämmande",
    "uppstämmas": "uppstämma",
    "uppstämmer": "uppstämma",
    "uppstäms": "uppstämma",
    "uppstämt": "uppstämma",
    "uppstämts": "uppstämma",
    "uppstående": "uppstå",
    "uppståenden": "uppstående",
    "uppståendena": "uppstående",
    "uppståendenas": "uppstående",
    "uppståendens": "uppstående",
    "uppståendes": "uppstående",
    "uppståendet": "uppstående",
    "uppståendets": "uppstående",
    "uppståndelsen": "uppståndelse",
    "uppståndelsens": "uppståndelse",
    "uppståndelses": "uppståndelse",
    "uppstånden": "uppstå",
    "uppståndens": "uppstånden",
    "uppståndet": "uppstånden",
    "uppståndets": "uppstånden",
    "uppståndna": "uppstånden",
    "uppståndnare": "uppstånden",
    "uppståndnares": "uppstånden",
    "uppståndnas": "uppstånden",
    "uppståndnast": "uppstånden",
    "uppståndnaste": "uppstånden",
    "uppståndnastes": "uppstånden",
    "uppståndnasts": "uppstånden",
    "uppståndne": "uppstånden",
    "uppståndnes": "uppstånden",
    "uppstår": "uppstå",
    "uppstås": "uppstå",
    "uppstått": "uppstå",
    "uppståtts": "uppstå",
    "uppstötningar": "uppstötning",
    "uppstötningarna": "uppstötning",
    "uppstötningarnas": "uppstötning",
    "uppstötningars": "uppstötning",
    "uppstötningen": "uppstötning",
    "uppstötningens": "uppstötning",
    "uppstötnings": "uppstötning",
    "uppsug": "uppsuga",
    "uppsugande": "uppsuga",
    "uppsuganden": "uppsugande",
    "uppsugandena": "uppsugande",
    "uppsugandenas": "uppsugande",
    "uppsugandens": "uppsugande",
    "uppsugandes": "uppsugande",
    "uppsugandet": "uppsugande",
    "uppsugandets": "uppsugande",
    "uppsugas": "uppsuga",
    "uppsuge": "uppsuga",
    "uppsugen": "uppsuga",
    "uppsugens": "uppsuga",
    "uppsuger": "uppsuga",
    "uppsuges": "uppsuga",
    "uppsuget": "uppsuga",
    "uppsugets": "uppsuga",
    "uppsugit": "uppsuga",
    "uppsugits": "uppsuga",
    "uppsugna": "uppsuga",
    "uppsugnas": "uppsuga",
    "uppsugne": "uppsuga",
    "uppsugnes": "uppsuga",
    "uppsugningar": "uppsugning",
    "uppsugningarna": "uppsugning",
    "uppsugningarnas": "uppsugning",
    "uppsugningars": "uppsugning",
    "uppsugningen": "uppsugning",
    "uppsugningens": "uppsugning",
    "uppsugnings": "uppsugning",
    "uppsugningsförmågan": "uppsugningsförmåga",
    "uppsugningsförmågans": "uppsugningsförmåga",
    "uppsugningsförmågas": "uppsugningsförmåga",
    "uppsugningsförmåge": "uppsugningsförmåga",
    "uppsugs": "uppsuga",
    "uppsummerad": "uppsummera",
    "uppsummerade": "uppsummera",
    "uppsummerades": "uppsummera",
    "uppsummerads": "uppsummera",
    "uppsummerande": "uppsummera",
    "uppsummeranden": "uppsummerande",
    "uppsummerandena": "uppsummerande",
    "uppsummerandenas": "uppsummerande",
    "uppsummerandens": "uppsummerande",
    "uppsummerandes": "uppsummerande",
    "uppsummerandet": "uppsummerande",
    "uppsummerandets": "uppsummerande",
    "uppsummerar": "uppsummera",
    "uppsummeras": "uppsummera",
    "uppsummerat": "uppsummera",
    "uppsummerats": "uppsummera",
    "uppsummerbara": "uppsummerbar",
    "uppsummerbarare": "uppsummerbar",
    "uppsummerbarares": "uppsummerbar",
    "uppsummerbaras": "uppsummerbar",
    "uppsummerbarast": "uppsummerbar",
    "uppsummerbaraste": "uppsummerbar",
    "uppsummerbarastes": "uppsummerbar",
    "uppsummerbarasts": "uppsummerbar",
    "uppsummerbare": "uppsummerbar",
    "uppsummerbares": "uppsummerbar",
    "uppsummerbarheten": "uppsummerbarhet",
    "uppsummerbarhetens": "uppsummerbarhet",
    "uppsummerbarhets": "uppsummerbarhet",
    "uppsummerbars": "uppsummerbar",
    "uppsummerbart": "uppsummerbar",
    "uppsummerbarts": "uppsummerbar",
    "uppsummeringar": "uppsummering",
    "uppsummeringarna": "uppsummering",
    "uppsummeringarnas": "uppsummering",
    "uppsummeringars": "uppsummering",
    "uppsummeringen": "uppsummering",
    "uppsummeringens": "uppsummering",
    "uppsummerings": "uppsummering",
    "uppsuttens": "uppsutten",
    "uppsuttet": "uppsutten",
    "uppsuttets": "uppsutten",
    "uppsuttna": "uppsutten",
    "uppsuttnas": "uppsutten",
    "uppsuttne": "uppsutten",
    "uppsuttnes": "uppsutten",
    "uppsvensk": "uppsvenska",
    "uppsvenska": "uppsvensk",
    "uppsvenskan": "uppsvenska",
    "uppsvenskans": "uppsvenska",
    "uppsvenskare": "uppsvensk",
    "uppsvenskares": "uppsvensk",
    "uppsvenskas": "uppsvenska",
    "uppsvenskast": "uppsvensk",
    "uppsvenskaste": "uppsvensk",
    "uppsvenskastes": "uppsvensk",
    "uppsvenskasts": "uppsvensk",
    "uppsvenske": "uppsvensk",
    "uppsvenskes": "uppsvensk",
    "uppsvensks": "uppsvensk",
    "uppsvenskt": "uppsvensk",
    "uppsvenskts": "uppsvensk",
    "uppsvingen": "uppsving",
    "uppsvingens": "uppsving",
    "uppsvinget": "uppsving",
    "uppsvingets": "uppsving",
    "uppsvings": "uppsving",
    "uppsvullens": "uppsvullen",
    "uppsvullet": "uppsvullen",
    "uppsvullets": "uppsvullen",
    "uppsvullna": "uppsvullen",
    "uppsvullnare": "uppsvullen",
    "uppsvullnares": "uppsvullen",
    "uppsvullnas": "uppsvullen",
    "uppsvullnast": "uppsvullen",
    "uppsvullnaste": "uppsvullen",
    "uppsvullnastes": "uppsvullen",
    "uppsvullnasts": "uppsvullen",
    "uppsvullne": "uppsvullen",
    "uppsvullnes": "uppsvullen",
    "uppsvällda": "uppsvälld",
    "uppsvälldare": "uppsvälld",
    "uppsvälldares": "uppsvälld",
    "uppsvälldas": "uppsvälld",
    "uppsvälldast": "uppsvälld",
    "uppsvälldaste": "uppsvälld",
    "uppsvälldastes": "uppsvälld",
    "uppsvälldasts": "uppsvälld",
    "uppsvällde": "uppsvälld",
    "uppsvälldes": "uppsvälld",
    "uppsvälldheten": "uppsvälldhet",
    "uppsvälldhetens": "uppsvälldhet",
    "uppsvälldhets": "uppsvälldhet",
    "uppsvällds": "uppsvälld",
    "uppsvällt": "uppsvälld",
    "uppsvällts": "uppsvälld",
    "uppsynen": "uppsyn",
    "uppsynens": "uppsyn",
    "uppsyner": "uppsyn",
    "uppsynerna": "uppsyn",
    "uppsynernas": "uppsyn",
    "uppsyners": "uppsyn",
    "uppsyningsmannen": "uppsyningsman",
    "uppsyningsmannens": "uppsyningsman",
    "uppsyningsmans": "uppsyningsman",
    "uppsyningsmän": "uppsyningsman",
    "uppsyningsmännen": "uppsyningsman",
    "uppsyningsmännens": "uppsyningsman",
    "uppsyningsmäns": "uppsyningsman",
    "uppsyns": "uppsyn",
    "uppsägelsen": "uppsägelse",
    "uppsägelsens": "uppsägelse",
    "uppsägelser": "uppsägelse",
    "uppsägelserna": "uppsägelse",
    "uppsägelsernas": "uppsägelse",
    "uppsägelsers": "uppsägelse",
    "uppsägelses": "uppsägelse",
    "uppsägningar": "uppsägning",
    "uppsägningarna": "uppsägning",
    "uppsägningarnas": "uppsägning",
    "uppsägningars": "uppsägning",
    "uppsägningen": "uppsägning",
    "uppsägningens": "uppsägning",
    "uppsägnings": "uppsägning",
    "uppsägningslånen": "uppsägningslån",
    "uppsägningslånens": "uppsägningslån",
    "uppsägningslånet": "uppsägningslån",
    "uppsägningslånets": "uppsägningslån",
    "uppsägningslåns": "uppsägningslån",
    "uppsägningsräkningar": "uppsägningsräkning",
    "uppsägningsräkningarna": "uppsägningsräkning",
    "uppsägningsräkningarnas": "uppsägningsräkning",
    "uppsägningsräkningars": "uppsägningsräkning",
    "uppsägningsräkningen": "uppsägningsräkning",
    "uppsägningsräkningens": "uppsägningsräkning",
    "uppsägningsräknings": "uppsägningsräkning",
    "uppsägningsterminen": "uppsägningstermin",
    "uppsägningsterminens": "uppsägningstermin",
    "uppsägningsterminer": "uppsägningstermin",
    "uppsägningsterminerna": "uppsägningstermin",
    "uppsägningsterminernas": "uppsägningstermin",
    "uppsägningsterminers": "uppsägningstermin",
    "uppsägningstermins": "uppsägningstermin",
    "uppsägningstiden": "uppsägningstid",
    "uppsägningstidens": "uppsägningstid",
    "uppsägningstider": "uppsägningstid",
    "uppsägningstiderna": "uppsägningstid",
    "uppsägningstidernas": "uppsägningstid",
    "uppsägningstiders": "uppsägningstid",
    "uppsägningstids": "uppsägningstid",
    "uppsätt": "uppsätta",
    "uppsättande": "uppsätta",
    "uppsättanden": "uppsättande",
    "uppsättandena": "uppsättande",
    "uppsättandenas": "uppsättande",
    "uppsättandens": "uppsättande",
    "uppsättandes": "uppsättande",
    "uppsättandet": "uppsättande",
    "uppsättandets": "uppsättande",
    "uppsättar": "uppsättare",
    "uppsättaren": "uppsättare",
    "uppsättarens": "uppsättare",
    "uppsättares": "uppsättare",
    "uppsättarna": "uppsättare",
    "uppsättarnas": "uppsättare",
    "uppsättas": "uppsätta",
    "uppsätter": "uppsätta",
    "uppsättes": "uppsätta",
    "uppsättningar": "uppsättning",
    "uppsättningarna": "uppsättning",
    "uppsättningarnas": "uppsättning",
    "uppsättningars": "uppsättning",
    "uppsättningen": "uppsättning",
    "uppsättningens": "uppsättning",
    "uppsättnings": "uppsättning",
    "uppsättningsinstrumenten": "uppsättningsinstrument",
    "uppsättningsinstrumentens": "uppsättningsinstrument",
    "uppsättningsinstrumentet": "uppsättningsinstrument",
    "uppsättningsinstrumentets": "uppsättningsinstrument",
    "uppsättningsinstruments": "uppsättningsinstrument",
    "uppsättningsmålen": "uppsättningsmål",
    "uppsättningsmålens": "uppsättningsmål",
    "uppsättningsmålet": "uppsättningsmål",
    "uppsättningsmålets": "uppsättningsmål",
    "uppsättningsmåls": "uppsättningsmål",
    "uppsätts": "uppsätta",
    "uppsåten": "uppsåt",
    "uppsåtens": "uppsåt",
    "uppsåtet": "uppsåt",
    "uppsåtets": "uppsåt",
    "uppsåtliga": "uppsåtlig",
    "uppsåtligare": "uppsåtlig",
    "uppsåtligares": "uppsåtlig",
    "uppsåtligas": "uppsåtlig",
    "uppsåtligast": "uppsåtlig",
    "uppsåtligaste": "uppsåtlig",
    "uppsåtligastes": "uppsåtlig",
    "uppsåtligasts": "uppsåtlig",
    "uppsåtlige": "uppsåtlig",
    "uppsåtliges": "uppsåtlig",
    "uppsåtligheten": "uppsåtlighet",
    "uppsåtlighetens": "uppsåtlighet",
    "uppsåtlighets": "uppsåtlighet",
    "uppsåtligs": "uppsåtlig",
    "uppsåtligt": "uppsåtlig",
    "uppsåtligts": "uppsåtlig",
    "uppsåts": "uppsåt",
    "uppsåtsbrotten": "uppsåtsbrott",
    "uppsåtsbrottens": "uppsåtsbrott",
    "uppsåtsbrottet": "uppsåtsbrott",
    "uppsåtsbrottets": "uppsåtsbrott",
    "uppsåtsbrotts": "uppsåtsbrott",
    "uppsög": "uppsuga",
    "uppsöge": "uppsuga",
    "uppsöges": "uppsuga",
    "uppsögs": "uppsuga",
    "uppsök": "uppsöka",
    "uppsökande": "uppsöka",
    "uppsökanden": "uppsökande",
    "uppsökandena": "uppsökande",
    "uppsökandenas": "uppsökande",
    "uppsökandens": "uppsökande",
    "uppsökandes": "uppsökande",
    "uppsökandet": "uppsökande",
    "uppsökandets": "uppsökande",
    "uppsökas": "uppsöka",
    "uppsöker": "uppsöka",
    "uppsökes": "uppsöka",
    "uppsöks": "uppsöka",
    "uppsökt": "uppsöka",
    "uppsökta": "uppsöka",
    "uppsöktas": "uppsöka",
    "uppsökte": "uppsöka",
    "uppsöktes": "uppsöka",
    "uppsökts": "uppsöka",
    "upptag": "uppta",
    "upptaga": "uppta",
    "upptagande": "uppta",
    "upptaganden": "upptagande",
    "upptagandena": "upptagande",
    "upptagandenas": "upptagande",
    "upptagandens": "upptagande",
    "upptagandes": "upptagande",
    "upptagandet": "upptagande",
    "upptagandets": "upptagande",
    "upptagas": "uppta",
    "upptage": "uppta",
    "upptagen": "uppta",
    "upptagenheten": "upptagenhet",
    "upptagenhetens": "upptagenhet",
    "upptagenheter": "upptagenhet",
    "upptagenheterna": "upptagenhet",
    "upptagenheternas": "upptagenhet",
    "upptagenheters": "upptagenhet",
    "upptagenhets": "upptagenhet",
    "upptagens": "upptagen",
    "upptager": "uppta",
    "upptages": "uppta",
    "upptaget": "upptagen",
    "upptagets": "upptagen",
    "upptagit": "uppta",
    "upptagits": "uppta",
    "upptagna": "upptagen",
    "upptagnare": "upptagen",
    "upptagnares": "upptagen",
    "upptagnas": "upptagen",
    "upptagnast": "upptagen",
    "upptagnaste": "upptagen",
    "upptagnastes": "upptagen",
    "upptagnasts": "upptagen",
    "upptagne": "upptagen",
    "upptagnes": "upptagen",
    "upptagningar": "upptagning",
    "upptagningarna": "upptagning",
    "upptagningarnas": "upptagning",
    "upptagningars": "upptagning",
    "upptagningen": "upptagning",
    "upptagningens": "upptagning",
    "upptagnings": "upptagning",
    "upptagningsceremonien": "upptagningsceremoni",
    "upptagningsceremoniens": "upptagningsceremoni",
    "upptagningsceremonier": "upptagningsceremoni",
    "upptagningsceremonierna": "upptagningsceremoni",
    "upptagningsceremoniernas": "upptagningsceremoni",
    "upptagningsceremoniers": "upptagningsceremoni",
    "upptagningsceremonin": "upptagningsceremoni",
    "upptagningsceremonins": "upptagningsceremoni",
    "upptagningsceremonis": "upptagningsceremoni",
    "upptagningshemmen": "upptagningshem",
    "upptagningshemmens": "upptagningshem",
    "upptagningshemmet": "upptagningshem",
    "upptagningshemmets": "upptagningshem",
    "upptagningshems": "upptagningshem",
    "upptagningsområden": "upptagningsområde",
    "upptagningsområdena": "upptagningsområde",
    "upptagningsområdenas": "upptagningsområde",
    "upptagningsområdens": "upptagningsområde",
    "upptagningsområdes": "upptagningsområde",
    "upptagningsområdet": "upptagningsområde",
    "upptagningsområdets": "upptagningsområde",
    "upptags": "upptag",
    "upptakten": "upptakt",
    "upptaktens": "upptakt",
    "upptakter": "upptakt",
    "upptakterna": "upptakt",
    "upptakternas": "upptakt",
    "upptakters": "upptakt",
    "upptakts": "upptakt",
    "upptar": "uppta",
    "upptas": "uppta",
    "upptaxerad": "upptaxera",
    "upptaxerade": "upptaxera",
    "upptaxerades": "upptaxera",
    "upptaxerads": "upptaxera",
    "upptaxerande": "upptaxera",
    "upptaxeranden": "upptaxerande",
    "upptaxerandena": "upptaxerande",
    "upptaxerandenas": "upptaxerande",
    "upptaxerandens": "upptaxerande",
    "upptaxerandes": "upptaxerande",
    "upptaxerandet": "upptaxerande",
    "upptaxerandets": "upptaxerande",
    "upptaxerar": "upptaxera",
    "upptaxeras": "upptaxera",
    "upptaxerat": "upptaxera",
    "upptaxerats": "upptaxera",
    "upptaxerbara": "upptaxerbar",
    "upptaxerbarare": "upptaxerbar",
    "upptaxerbarares": "upptaxerbar",
    "upptaxerbaras": "upptaxerbar",
    "upptaxerbarast": "upptaxerbar",
    "upptaxerbaraste": "upptaxerbar",
    "upptaxerbarastes": "upptaxerbar",
    "upptaxerbarasts": "upptaxerbar",
    "upptaxerbare": "upptaxerbar",
    "upptaxerbares": "upptaxerbar",
    "upptaxerbarheten": "upptaxerbarhet",
    "upptaxerbarhetens": "upptaxerbarhet",
    "upptaxerbarhets": "upptaxerbarhet",
    "upptaxerbars": "upptaxerbar",
    "upptaxerbart": "upptaxerbar",
    "upptaxerbarts": "upptaxerbar",
    "upptaxeringar": "upptaxering",
    "upptaxeringarna": "upptaxering",
    "upptaxeringarnas": "upptaxering",
    "upptaxeringars": "upptaxering",
    "upptaxeringen": "upptaxering",
    "upptaxeringens": "upptaxering",
    "upptaxerings": "upptaxering",
    "uppteckn": "uppteckna",
    "upptecknad": "uppteckna",
    "upptecknade": "uppteckna",
    "upptecknades": "uppteckna",
    "upptecknads": "uppteckna",
    "upptecknande": "uppteckna",
    "upptecknanden": "upptecknande",
    "upptecknandena": "upptecknande",
    "upptecknandenas": "upptecknande",
    "upptecknandens": "upptecknande",
    "upptecknandes": "upptecknande",
    "upptecknandet": "upptecknande",
    "upptecknandets": "upptecknande",
    "upptecknar": "upptecknare",
    "upptecknaren": "upptecknare",
    "upptecknarens": "upptecknare",
    "upptecknares": "upptecknare",
    "upptecknarna": "upptecknare",
    "upptecknarnas": "upptecknare",
    "upptecknas": "uppteckna",
    "upptecknat": "uppteckna",
    "upptecknats": "uppteckna",
    "uppteckningar": "uppteckning",
    "uppteckningarna": "uppteckning",
    "uppteckningarnas": "uppteckning",
    "uppteckningars": "uppteckning",
    "uppteckningen": "uppteckning",
    "uppteckningens": "uppteckning",
    "upptecknings": "uppteckning",
    "upptiningar": "upptining",
    "upptiningarna": "upptining",
    "upptiningarnas": "upptining",
    "upptiningars": "upptining",
    "upptiningen": "upptining",
    "upptiningens": "upptining",
    "upptinings": "upptining",
    "upptog": "uppta",
    "upptoge": "uppta",
    "upptoges": "uppta",
    "upptogs": "uppta",
    "upptorn": "upptorna",
    "upptornad": "upptorna",
    "upptornade": "upptorna",
    "upptornades": "upptorna",
    "upptornads": "upptorna",
    "upptornande": "upptorna",
    "upptornanden": "upptornande",
    "upptornandena": "upptornande",
    "upptornandenas": "upptornande",
    "upptornandens": "upptornande",
    "upptornandes": "upptornande",
    "upptornandet": "upptornande",
    "upptornandets": "upptornande",
    "upptornar": "upptorna",
    "upptornas": "upptorna",
    "upptornat": "upptorna",
    "upptornats": "upptorna",
    "upptramp": "upptrampa",
    "upptrampad": "upptrampa",
    "upptrampade": "upptrampad",
    "upptrampades": "upptrampad",
    "upptrampads": "upptrampad",
    "upptrampande": "upptrampa",
    "upptrampanden": "upptrampande",
    "upptrampandena": "upptrampande",
    "upptrampandenas": "upptrampande",
    "upptrampandens": "upptrampande",
    "upptrampandes": "upptrampande",
    "upptrampandet": "upptrampande",
    "upptrampandets": "upptrampande",
    "upptrampar": "upptrampa",
    "upptrampas": "upptrampa",
    "upptrampat": "upptrampad",
    "upptrampats": "upptrampad",
    "upptrapp": "upptrappa",
    "upptrappad": "upptrappa",
    "upptrappade": "upptrappa",
    "upptrappades": "upptrappa",
    "upptrappads": "upptrappa",
    "upptrappande": "upptrappa",
    "upptrappanden": "upptrappande",
    "upptrappandena": "upptrappande",
    "upptrappandenas": "upptrappande",
    "upptrappandens": "upptrappande",
    "upptrappandes": "upptrappande",
    "upptrappandet": "upptrappande",
    "upptrappandets": "upptrappande",
    "upptrappar": "upptrappa",
    "upptrappas": "upptrappa",
    "upptrappat": "upptrappa",
    "upptrappats": "upptrappa",
    "upptrappningar": "upptrappning",
    "upptrappningarna": "upptrappning",
    "upptrappningarnas": "upptrappning",
    "upptrappningars": "upptrappning",
    "upptrappningen": "upptrappning",
    "upptrappningens": "upptrappning",
    "upptrappnings": "upptrappning",
    "upptriss": "upptrissa",
    "upptrissad": "upptrissa",
    "upptrissade": "upptrissa",
    "upptrissades": "upptrissa",
    "upptrissads": "upptrissa",
    "upptrissande": "upptrissa",
    "upptrissanden": "upptrissande",
    "upptrissandena": "upptrissande",
    "upptrissandenas": "upptrissande",
    "upptrissandens": "upptrissande",
    "upptrissandes": "upptrissande",
    "upptrissandet": "upptrissande",
    "upptrissandets": "upptrissande",
    "upptrissar": "upptrissa",
    "upptrissas": "upptrissa",
    "upptrissat": "upptrissa",
    "upptrissats": "upptrissa",
    "upptrycken": "upptryck",
    "upptryckens": "upptryck",
    "upptrycket": "upptryck",
    "upptryckets": "upptryck",
    "upptryckningar": "upptryckning",
    "upptryckningarna": "upptryckning",
    "upptryckningarnas": "upptryckning",
    "upptryckningars": "upptryckning",
    "upptryckningen": "upptryckning",
    "upptryckningens": "upptryckning",
    "upptrycknings": "upptryckning",
    "upptrycks": "upptryck",
    "uppträd": "uppträda",
    "uppträdande": "uppträda",
    "uppträdanden": "uppträdande",
    "uppträdandena": "uppträdande",
    "uppträdandenas": "uppträdande",
    "uppträdandens": "uppträdande",
    "uppträdandes": "uppträdande",
    "uppträdandet": "uppträdande",
    "uppträdandets": "uppträdande",
    "uppträdas": "uppträda",
    "uppträdd": "uppträda",
    "uppträdda": "uppträda",
    "uppträddas": "uppträda",
    "uppträdde": "uppträda",
    "uppträddes": "uppträda",
    "uppträdds": "uppträda",
    "uppträden": "uppträde",
    "uppträdena": "uppträde",
    "uppträdenas": "uppträde",
    "uppträdens": "uppträde",
    "uppträder": "uppträda",
    "uppträdes": "uppträde",
    "uppträdet": "uppträde",
    "uppträdets": "uppträde",
    "uppträds": "uppträde",
    "uppträtt": "uppträda",
    "uppträtts": "uppträda",
    "upptuktelsen": "upptuktelse",
    "upptuktelsens": "upptuktelse",
    "upptuktelser": "upptuktelse",
    "upptuktelserna": "upptuktelse",
    "upptuktelsernas": "upptuktelse",
    "upptuktelsers": "upptuktelse",
    "upptuktelses": "upptuktelse",
    "upptäck": "upptäcka",
    "upptäckande": "upptäcka",
    "upptäckanden": "upptäckande",
    "upptäckandena": "upptäckande",
    "upptäckandenas": "upptäckande",
    "upptäckandens": "upptäckande",
    "upptäckandes": "upptäckande",
    "upptäckandet": "upptäckande",
    "upptäckandets": "upptäckande",
    "upptäckar": "upptäckare",
    "upptäckaren": "upptäckare",
    "upptäckarens": "upptäckare",
    "upptäckares": "upptäckare",
    "upptäckarglädjen": "upptäckarglädje",
    "upptäckarglädjens": "upptäckarglädje",
    "upptäckarglädjes": "upptäckarglädje",
    "upptäckarna": "upptäckare",
    "upptäckarnas": "upptäckare",
    "upptäckas": "upptäcka",
    "upptäcker": "upptäcka",
    "upptäckes": "upptäcka",
    "upptäcks": "upptäcka",
    "upptäckt": "upptäcka",
    "upptäckta": "upptäcka",
    "upptäcktas": "upptäcka",
    "upptäckte": "upptäcka",
    "upptäckten": "upptäckt",
    "upptäcktens": "upptäckt",
    "upptäckter": "upptäckt",
    "upptäckterna": "upptäckt",
    "upptäckternas": "upptäckt",
    "upptäckters": "upptäckt",
    "upptäcktes": "upptäcka",
    "upptäckts": "upptäckt",
    "upptäcktsfärden": "upptäcktsfärd",
    "upptäcktsfärdens": "upptäcktsfärd",
    "upptäcktsfärder": "upptäcktsfärd",
    "upptäcktsfärderna": "upptäcktsfärd",
    "upptäcktsfärdernas": "upptäcktsfärd",
    "upptäcktsfärders": "upptäcktsfärd",
    "upptäcktsfärds": "upptäcktsfärd",
    "upptäcktsresan": "upptäcktsresa",
    "upptäcktsresanden": "upptäcktsresande",
    "upptäcktsresandena": "upptäcktsresande",
    "upptäcktsresandenas": "upptäcktsresande",
    "upptäcktsresandens": "upptäcktsresande",
    "upptäcktsresandes": "upptäcktsresande",
    "upptäcktsresans": "upptäcktsresa",
    "upptäcktsresas": "upptäcktsresa",
    "upptäcktsrese": "upptäcktsresa",
    "upptäcktsresor": "upptäcktsresa",
    "upptäcktsresorna": "upptäcktsresa",
    "upptäcktsresornas": "upptäcktsresa",
    "upptäcktsresors": "upptäcktsresa",
    "upptänd": "upptända",
    "upptända": "upptänd",
    "upptändande": "upptända",
    "upptändanden": "upptändande",
    "upptändandena": "upptändande",
    "upptändandenas": "upptändande",
    "upptändandens": "upptändande",
    "upptändandes": "upptändande",
    "upptändandet": "upptändande",
    "upptändandets": "upptändande",
    "upptändare": "upptänd",
    "upptändares": "upptänd",
    "upptändas": "upptända",
    "upptändast": "upptänd",
    "upptändaste": "upptänd",
    "upptändastes": "upptänd",
    "upptändasts": "upptänd",
    "upptände": "upptända",
    "upptänder": "upptända",
    "upptändes": "upptända",
    "upptändheten": "upptändhet",
    "upptändhetens": "upptändhet",
    "upptändhets": "upptändhet",
    "upptänds": "upptända",
    "upptänkliga": "upptänklig",
    "upptänkligare": "upptänklig",
    "upptänkligares": "upptänklig",
    "upptänkligas": "upptänklig",
    "upptänkligast": "upptänklig",
    "upptänkligaste": "upptänklig",
    "upptänkligastes": "upptänklig",
    "upptänkligasts": "upptänklig",
    "upptänklige": "upptänklig",
    "upptänkliges": "upptänklig",
    "upptänkligs": "upptänklig",
    "upptänkligt": "upptänklig",
    "upptänkligts": "upptänklig",
    "upptänt": "upptända",
    "upptänts": "upptända",
    "upptågen": "upptåg",
    "upptågens": "upptåg",
    "upptåget": "upptåg",
    "upptågets": "upptåg",
    "upptågs": "upptåg",
    "upptågsmakar": "upptågsmakare",
    "upptågsmakaren": "upptågsmakare",
    "upptågsmakarens": "upptågsmakare",
    "upptågsmakares": "upptågsmakare",
    "upptågsmakarna": "upptågsmakare",
    "upptågsmakarnas": "upptågsmakare",
    "uppvaknandes": "uppvaknande",
    "uppvaknandet": "uppvaknande",
    "uppvaknandets": "uppvaknande",
    "uppvakningsögonblicken": "uppvakningsögonblick",
    "uppvakningsögonblickens": "uppvakningsögonblick",
    "uppvakningsögonblicket": "uppvakningsögonblick",
    "uppvakningsögonblickets": "uppvakningsögonblick",
    "uppvakningsögonblicks": "uppvakningsögonblick",
    "uppvakt": "uppvakta",
    "uppvaktad": "uppvakta",
    "uppvaktade": "uppvakta",
    "uppvaktades": "uppvakta",
    "uppvaktads": "uppvakta",
    "uppvaktande": "uppvakta",
    "uppvaktanden": "uppvaktande",
    "uppvaktandena": "uppvaktande",
    "uppvaktandenas": "uppvaktande",
    "uppvaktandens": "uppvaktande",
    "uppvaktandes": "uppvaktande",
    "uppvaktandet": "uppvaktande",
    "uppvaktandets": "uppvaktande",
    "uppvaktar": "uppvakta",
    "uppvaktas": "uppvakta",
    "uppvaktat": "uppvakta",
    "uppvaktats": "uppvakta",
    "uppvaktningar": "uppvaktning",
    "uppvaktningarna": "uppvaktning",
    "uppvaktningarnas": "uppvaktning",
    "uppvaktningars": "uppvaktning",
    "uppvaktningen": "uppvaktning",
    "uppvaktningens": "uppvaktning",
    "uppvaktnings": "uppvaktning",
    "uppviglad": "uppvigla",
    "uppviglade": "uppvigla",
    "uppviglades": "uppvigla",
    "uppviglads": "uppvigla",
    "uppviglande": "uppvigla",
    "uppviglanden": "uppviglande",
    "uppviglandena": "uppviglande",
    "uppviglandenas": "uppviglande",
    "uppviglandens": "uppviglande",
    "uppviglandes": "uppviglande",
    "uppviglandet": "uppviglande",
    "uppviglandets": "uppviglande",
    "uppviglar": "uppviglare",
    "uppviglaren": "uppviglare",
    "uppviglarens": "uppviglare",
    "uppviglares": "uppviglare",
    "uppviglarna": "uppviglare",
    "uppviglarnas": "uppviglare",
    "uppviglas": "uppvigla",
    "uppviglat": "uppvigla",
    "uppviglats": "uppvigla",
    "uppviglingar": "uppvigling",
    "uppviglingarna": "uppvigling",
    "uppviglingarnas": "uppvigling",
    "uppviglingars": "uppvigling",
    "uppviglingen": "uppvigling",
    "uppviglingens": "uppvigling",
    "uppviglings": "uppvigling",
    "uppvikta": "uppvikt",
    "uppviktas": "uppvikt",
    "uppvikte": "uppvikt",
    "uppviktes": "uppvikt",
    "uppvikts": "uppvikt",
    "uppvilade": "uppvilad",
    "uppvilades": "uppvilad",
    "uppvilads": "uppvilad",
    "uppvilat": "uppvilad",
    "uppvilats": "uppvilad",
    "uppvindar": "uppvind",
    "uppvindarna": "uppvind",
    "uppvindarnas": "uppvind",
    "uppvindars": "uppvind",
    "uppvinden": "uppvind",
    "uppvindens": "uppvind",
    "uppvinds": "uppvind",
    "uppvisad": "uppvisa",
    "uppvisade": "uppvisa",
    "uppvisades": "uppvisa",
    "uppvisads": "uppvisa",
    "uppvisande": "uppvisa",
    "uppvisanden": "uppvisande",
    "uppvisandena": "uppvisande",
    "uppvisandenas": "uppvisande",
    "uppvisandens": "uppvisande",
    "uppvisandes": "uppvisande",
    "uppvisandet": "uppvisande",
    "uppvisandets": "uppvisande",
    "uppvisar": "uppvisa",
    "uppvisas": "uppvisa",
    "uppvisat": "uppvisa",
    "uppvisats": "uppvisa",
    "uppvisningar": "uppvisning",
    "uppvisningarna": "uppvisning",
    "uppvisningarnas": "uppvisning",
    "uppvisningars": "uppvisning",
    "uppvisningen": "uppvisning",
    "uppvisningens": "uppvisning",
    "uppvisnings": "uppvisning",
    "uppvuxe": "uppväxa",
    "uppvuxen": "uppväxa",
    "uppvuxens": "uppvuxen",
    "uppvuxet": "uppvuxen",
    "uppvuxets": "uppvuxen",
    "uppvuxit": "uppväxa",
    "uppvuxna": "uppvuxen",
    "uppvuxnare": "uppvuxen",
    "uppvuxnares": "uppvuxen",
    "uppvuxnas": "uppvuxen",
    "uppvuxnast": "uppvuxen",
    "uppvuxnaste": "uppvuxen",
    "uppvuxnastes": "uppvuxen",
    "uppvuxnasts": "uppvuxen",
    "uppvuxne": "uppvuxen",
    "uppvuxnes": "uppvuxen",
    "uppväck": "uppväcka",
    "uppväckande": "uppväcka",
    "uppväckanden": "uppväckande",
    "uppväckandena": "uppväckande",
    "uppväckandenas": "uppväckande",
    "uppväckandens": "uppväckande",
    "uppväckandes": "uppväckande",
    "uppväckandet": "uppväckande",
    "uppväckandets": "uppväckande",
    "uppväckas": "uppväcka",
    "uppväckelsen": "uppväckelse",
    "uppväckelsens": "uppväckelse",
    "uppväckelser": "uppväckelse",
    "uppväckelserna": "uppväckelse",
    "uppväckelsernas": "uppväckelse",
    "uppväckelsers": "uppväckelse",
    "uppväckelses": "uppväckelse",
    "uppväcker": "uppväcka",
    "uppväckes": "uppväcka",
    "uppväcks": "uppväcka",
    "uppväckt": "uppväcka",
    "uppväckta": "uppväcka",
    "uppväcktas": "uppväcka",
    "uppväckte": "uppväcka",
    "uppväcktes": "uppväcka",
    "uppväckts": "uppväcka",
    "uppväg": "uppväga",
    "uppvägande": "uppväga",
    "uppväganden": "uppvägande",
    "uppvägandena": "uppvägande",
    "uppvägandenas": "uppvägande",
    "uppvägandens": "uppvägande",
    "uppvägandes": "uppvägande",
    "uppvägandet": "uppvägande",
    "uppvägandets": "uppvägande",
    "uppvägas": "uppväga",
    "uppvägd": "uppväga",
    "uppvägda": "uppväga",
    "uppvägdas": "uppväga",
    "uppvägde": "uppväga",
    "uppvägdes": "uppväga",
    "uppvägds": "uppväga",
    "uppväger": "uppväga",
    "uppväges": "uppväga",
    "uppvägningar": "uppvägning",
    "uppvägningarna": "uppvägning",
    "uppvägningarnas": "uppvägning",
    "uppvägningars": "uppvägning",
    "uppvägningen": "uppvägning",
    "uppvägningens": "uppvägning",
    "uppvägnings": "uppvägning",
    "uppvägs": "uppväga",
    "uppvägt": "uppväga",
    "uppvägts": "uppväga",
    "uppvärderad": "uppvärdera",
    "uppvärderade": "uppvärdera",
    "uppvärderades": "uppvärdera",
    "uppvärderads": "uppvärdera",
    "uppvärderande": "uppvärdera",
    "uppvärderanden": "uppvärderande",
    "uppvärderandena": "uppvärderande",
    "uppvärderandenas": "uppvärderande",
    "uppvärderandens": "uppvärderande",
    "uppvärderandes": "uppvärderande",
    "uppvärderandet": "uppvärderande",
    "uppvärderandets": "uppvärderande",
    "uppvärderar": "uppvärdera",
    "uppvärderas": "uppvärdera",
    "uppvärderat": "uppvärdera",
    "uppvärderats": "uppvärdera",
    "uppvärderbara": "uppvärderbar",
    "uppvärderbarare": "uppvärderbar",
    "uppvärderbarares": "uppvärderbar",
    "uppvärderbaras": "uppvärderbar",
    "uppvärderbarast": "uppvärderbar",
    "uppvärderbaraste": "uppvärderbar",
    "uppvärderbarastes": "uppvärderbar",
    "uppvärderbarasts": "uppvärderbar",
    "uppvärderbare": "uppvärderbar",
    "uppvärderbares": "uppvärderbar",
    "uppvärderbarheten": "uppvärderbarhet",
    "uppvärderbarhetens": "uppvärderbarhet",
    "uppvärderbarhets": "uppvärderbarhet",
    "uppvärderbars": "uppvärderbar",
    "uppvärderbart": "uppvärderbar",
    "uppvärderbarts": "uppvärderbar",
    "uppvärderingar": "uppvärdering",
    "uppvärderingarna": "uppvärdering",
    "uppvärderingarnas": "uppvärdering",
    "uppvärderingars": "uppvärdering",
    "uppvärderingen": "uppvärdering",
    "uppvärderingens": "uppvärdering",
    "uppvärderings": "uppvärdering",
    "uppvärm": "uppvärma",
    "uppvärmande": "uppvärma",
    "uppvärmanden": "uppvärmande",
    "uppvärmandena": "uppvärmande",
    "uppvärmandenas": "uppvärmande",
    "uppvärmandens": "uppvärmande",
    "uppvärmandes": "uppvärmande",
    "uppvärmandet": "uppvärmande",
    "uppvärmandets": "uppvärmande",
    "uppvärmas": "uppvärma",
    "uppvärmd": "uppvärma",
    "uppvärmda": "uppvärma",
    "uppvärmdas": "uppvärma",
    "uppvärmde": "uppvärma",
    "uppvärmdes": "uppvärma",
    "uppvärmds": "uppvärma",
    "uppvärmer": "uppvärma",
    "uppvärmningar": "uppvärmning",
    "uppvärmningarna": "uppvärmning",
    "uppvärmningarnas": "uppvärmning",
    "uppvärmningars": "uppvärmning",
    "uppvärmningen": "uppvärmning",
    "uppvärmningens": "uppvärmning",
    "uppvärmnings": "uppvärmning",
    "uppvärmningsströmmen": "uppvärmningsström",
    "uppvärmningsströmmens": "uppvärmningsström",
    "uppvärmningsströms": "uppvärmningsström",
    "uppvärms": "uppvärma",
    "uppvärmt": "uppvärma",
    "uppvärmts": "uppvärma",
    "uppväx": "uppväxa",
    "uppväxande": "uppväxa",
    "uppväxanden": "uppväxande",
    "uppväxandena": "uppväxande",
    "uppväxandenas": "uppväxande",
    "uppväxandens": "uppväxande",
    "uppväxandes": "uppväxande",
    "uppväxandet": "uppväxande",
    "uppväxandets": "uppväxande",
    "uppväxe": "uppväxa",
    "uppväxer": "uppväxa",
    "uppväxt": "uppväxa",
    "uppväxte": "uppväxa",
    "uppväxten": "uppväxt",
    "uppväxtens": "uppväxt",
    "uppväxtmiljöer": "uppväxtmiljö",
    "uppväxtmiljöerna": "uppväxtmiljö",
    "uppväxtmiljöernas": "uppväxtmiljö",
    "uppväxtmiljöers": "uppväxtmiljö",
    "uppväxtmiljön": "uppväxtmiljö",
    "uppväxtmiljöns": "uppväxtmiljö",
    "uppväxtmiljös": "uppväxtmiljö",
    "uppväxts": "uppväxt",
    "uppät": "uppäta",
    "uppätande": "uppäta",
    "uppätanden": "uppätande",
    "uppätandena": "uppätande",
    "uppätandenas": "uppätande",
    "uppätandens": "uppätande",
    "uppätandes": "uppätande",
    "uppätandet": "uppätande",
    "uppätandets": "uppätande",
    "uppätas": "uppäta",
    "uppäte": "uppäta",
    "uppäten": "uppäta",
    "uppätens": "uppäta",
    "uppäter": "uppäta",
    "uppätes": "uppäta",
    "uppätet": "uppäta",
    "uppätets": "uppäta",
    "uppätit": "uppäta",
    "uppätits": "uppäta",
    "uppätna": "uppäta",
    "uppätnas": "uppäta",
    "uppätne": "uppäta",
    "uppätnes": "uppäta",
    "uppäts": "uppäta",
    "uppåkta": "uppåkt",
    "uppåktas": "uppåkt",
    "uppåkte": "uppåkt",
    "uppåktes": "uppåkt",
    "uppåkts": "uppåkt",
    "uppånedvända": "uppånedvänd",
    "uppånedvändare": "uppånedvänd",
    "uppånedvändares": "uppånedvänd",
    "uppånedvändas": "uppånedvänd",
    "uppånedvändast": "uppånedvänd",
    "uppånedvändaste": "uppånedvänd",
    "uppånedvändastes": "uppånedvänd",
    "uppånedvändasts": "uppånedvänd",
    "uppånedvände": "uppånedvänd",
    "uppånedvändes": "uppånedvänd",
    "uppånedvändheten": "uppånedvändhet",
    "uppånedvändhetens": "uppånedvändhet",
    "uppånedvändhets": "uppånedvändhet",
    "uppånedvänds": "uppånedvänd",
    "uppånedvänt": "uppånedvänd",
    "uppånedvänts": "uppånedvänd",
    "uppånervända": "uppånervänd",
    "uppånervändare": "uppånervänd",
    "uppånervändares": "uppånervänd",
    "uppånervändas": "uppånervänd",
    "uppånervändast": "uppånervänd",
    "uppånervändaste": "uppånervänd",
    "uppånervändastes": "uppånervänd",
    "uppånervändasts": "uppånervänd",
    "uppånervände": "uppånervänd",
    "uppånervändes": "uppånervänd",
    "uppånervändheten": "uppånervändhet",
    "uppånervändhetens": "uppånervändhet",
    "uppånervändhets": "uppånervändhet",
    "uppånervänds": "uppånervänd",
    "uppånervänt": "uppånervänd",
    "uppånervänts": "uppånervänd",
    "uppåt": "uppäta",
    "uppåte": "uppäta",
    "uppåtes": "uppäta",
    "uppåtgåendes": "uppåtgående",
    "uppåtgåendet": "uppåtgående",
    "uppåtgåendets": "uppåtgående",
    "uppåtkammade": "uppåtkammad",
    "uppåtkammades": "uppåtkammad",
    "uppåtkammads": "uppåtkammad",
    "uppåtkammat": "uppåtkammad",
    "uppåtkammats": "uppåtkammad",
    "uppåtriktade": "uppåtriktad",
    "uppåtriktades": "uppåtriktad",
    "uppåtriktads": "uppåtriktad",
    "uppåtriktat": "uppåtriktad",
    "uppåtriktats": "uppåtriktad",
    "uppåts": "uppäta",
    "uppåtsträvar": "uppåtsträvare",
    "uppåtsträvaren": "uppåtsträvare",
    "uppåtsträvarens": "uppåtsträvare",
    "uppåtsträvares": "uppåtsträvare",
    "uppåtsträvarna": "uppåtsträvare",
    "uppåtsträvarnas": "uppåtsträvare",
    "uppöv": "uppöva",
    "uppövad": "uppöva",
    "uppövade": "uppöva",
    "uppövades": "uppöva",
    "uppövads": "uppöva",
    "uppövande": "uppöva",
    "uppövanden": "uppövande",
    "uppövandena": "uppövande",
    "uppövandenas": "uppövande",
    "uppövandens": "uppövande",
    "uppövandes": "uppövande",
    "uppövandet": "uppövande",
    "uppövandets": "uppövande",
    "uppövar": "uppöva",
    "uppövas": "uppöva",
    "uppövat": "uppöva",
    "uppövats": "uppöva",
    "ur-ur-kroppen-upplevelsen": "ur-ur-kroppen-upplevelse",
    "ur-ur-kroppen-upplevelsens": "ur-ur-kroppen-upplevelse",
    "ur-ur-kroppen-upplevelser": "ur-ur-kroppen-upplevelse",
    "ur-ur-kroppen-upplevelserna": "ur-ur-kroppen-upplevelse",
    "ur-ur-kroppen-upplevelsernas": "ur-ur-kroppen-upplevelse",
    "ur-ur-kroppen-upplevelsers": "ur-ur-kroppen-upplevelse",
    "ur-ur-kroppen-upplevelses": "ur-ur-kroppen-upplevelse",
    "uraktlät": "uraktlåta",
    "uraktläts": "uraktlåta",
    "uraktlåt": "uraktlåta",
    "uraktlåtande": "uraktlåta",
    "uraktlåtanden": "uraktlåtande",
    "uraktlåtandena": "uraktlåtande",
    "uraktlåtandenas": "uraktlåtande",
    "uraktlåtandens": "uraktlåtande",
    "uraktlåtandes": "uraktlåtande",
    "uraktlåtandet": "uraktlåtande",
    "uraktlåtandets": "uraktlåtande",
    "uraktlåtas": "uraktlåta",
    "uraktlåte": "uraktlåta",
    "uraktlåten": "uraktlåta",
    "uraktlåtenheten": "uraktlåtenhet",
    "uraktlåtenhetens": "uraktlåtenhet",
    "uraktlåtenheter": "uraktlåtenhet",
    "uraktlåtenheterna": "uraktlåtenhet",
    "uraktlåtenheternas": "uraktlåtenhet",
    "uraktlåtenheters": "uraktlåtenhet",
    "uraktlåtenhets": "uraktlåtenhet",
    "uraktlåtens": "uraktlåta",
    "uraktlåter": "uraktlåta",
    "uraktlåtes": "uraktlåta",
    "uraktlåtet": "uraktlåta",
    "uraktlåtets": "uraktlåta",
    "uraktlåtit": "uraktlåta",
    "uraktlåtits": "uraktlåta",
    "uraktlåtna": "uraktlåta",
    "uraktlåtnas": "uraktlåta",
    "uraktlåtne": "uraktlåta",
    "uraktlåtnes": "uraktlåta",
    "uraktlåts": "uraktlåta",
    "uraliska": "uralisk",
    "uraliskare": "uralisk",
    "uraliskares": "uralisk",
    "uraliskas": "uralisk",
    "uraliskast": "uralisk",
    "uraliskaste": "uralisk",
    "uraliskastes": "uralisk",
    "uraliskasts": "uralisk",
    "uraliske": "uralisk",
    "uraliskes": "uralisk",
    "uralisks": "uralisk",
    "uraliskt": "uralisk",
    "uraliskts": "uralisk",
    "uralska": "uralsk",
    "uralskare": "uralsk",
    "uralskares": "uralsk",
    "uralskas": "uralsk",
    "uralskast": "uralsk",
    "uralskaste": "uralsk",
    "uralskastes": "uralsk",
    "uralskasts": "uralsk",
    "uralske": "uralsk",
    "uralskes": "uralsk",
    "uralsks": "uralsk",
    "uralskt": "uralsk",
    "uralskts": "uralsk",
    "uralstringar": "uralstring",
    "uralstringarna": "uralstring",
    "uralstringarnas": "uralstring",
    "uralstringars": "uralstring",
    "uralstringen": "uralstring",
    "uralstringens": "uralstring",
    "uralstrings": "uralstring",
    "uranblyet": "uranbly",
    "uranblyets": "uranbly",
    "uranblys": "uranbly",
    "uranblyt": "uranbly",
    "uranblyts": "uranbly",
    "uranen": "uran",
    "uranens": "uran",
    "uranet": "uran",
    "uranets": "uran",
    "uranglasen": "uranglas",
    "uranglasens": "uranglas",
    "uranglaset": "uranglas",
    "uranglasets": "uranglas",
    "uranglimmern": "uranglimmer",
    "uranglimmerns": "uranglimmer",
    "uranglimmers": "uranglimmer",
    "urans": "uran",
    "uranstapeln": "uranstapel",
    "uranstapelns": "uranstapel",
    "uranstapels": "uranstapel",
    "uranstaplar": "uranstapel",
    "uranstaplarna": "uranstapel",
    "uranstaplarnas": "uranstapel",
    "uranstaplars": "uranstapel",
    "uranutvinningar": "uranutvinning",
    "uranutvinningarna": "uranutvinning",
    "uranutvinningarnas": "uranutvinning",
    "uranutvinningars": "uranutvinning",
    "uranutvinningen": "uranutvinning",
    "uranutvinningens": "uranutvinning",
    "uranutvinnings": "uranutvinning",
    "urar": "ur",
    "urarna": "ur",
    "urarnas": "ur",
    "urars": "ur",
    "urart": "urarta",
    "urartad": "urarta",
    "urartade": "urarta",
    "urartades": "urarta",
    "urartads": "urarta",
    "urartande": "urarta",
    "urartanden": "urartande",
    "urartandena": "urartande",
    "urartandenas": "urartande",
    "urartandens": "urartande",
    "urartandes": "urartande",
    "urartandet": "urartande",
    "urartandets": "urartande",
    "urartar": "urarta",
    "urartas": "urarta",
    "urartat": "urarta",
    "urartats": "urarta",
    "urarvaboen": "urarvabo",
    "urarvaboens": "urarvabo",
    "urarvaboet": "urarvabo",
    "urarvaboets": "urarvabo",
    "urarvabon": "urarvabo",
    "urarvabona": "urarvabo",
    "urarvabonas": "urarvabo",
    "urarvabons": "urarvabo",
    "urarvabos": "urarvabo",
    "urarvabot": "urarvabo",
    "urarvabots": "urarvabo",
    "urarvakonkursen": "urarvakonkurs",
    "urarvakonkursens": "urarvakonkurs",
    "urarvakonkurser": "urarvakonkurs",
    "urarvakonkurserna": "urarvakonkurs",
    "urarvakonkursernas": "urarvakonkurs",
    "urarvakonkursers": "urarvakonkurs",
    "urbana": "urban",
    "urbanare": "urban",
    "urbanares": "urban",
    "urbanas": "urban",
    "urbanast": "urban",
    "urbanaste": "urban",
    "urbanastes": "urban",
    "urbanasts": "urban",
    "urbane": "urban",
    "urbanes": "urban",
    "urbaniserad": "urbanisera",
    "urbaniserade": "urbanisera",
    "urbaniserades": "urbanisera",
    "urbaniserads": "urbanisera",
    "urbaniserande": "urbanisera",
    "urbaniseranden": "urbaniserande",
    "urbaniserandena": "urbaniserande",
    "urbaniserandenas": "urbaniserande",
    "urbaniserandens": "urbaniserande",
    "urbaniserandes": "urbaniserande",
    "urbaniserandet": "urbaniserande",
    "urbaniserandets": "urbaniserande",
    "urbaniserar": "urbanisera",
    "urbaniseras": "urbanisera",
    "urbaniserat": "urbanisera",
    "urbaniserats": "urbanisera",
    "urbaniserbara": "urbaniserbar",
    "urbaniserbarare": "urbaniserbar",
    "urbaniserbarares": "urbaniserbar",
    "urbaniserbaras": "urbaniserbar",
    "urbaniserbarast": "urbaniserbar",
    "urbaniserbaraste": "urbaniserbar",
    "urbaniserbarastes": "urbaniserbar",
    "urbaniserbarasts": "urbaniserbar",
    "urbaniserbare": "urbaniserbar",
    "urbaniserbares": "urbaniserbar",
    "urbaniserbarheten": "urbaniserbarhet",
    "urbaniserbarhetens": "urbaniserbarhet",
    "urbaniserbarhets": "urbaniserbarhet",
    "urbaniserbars": "urbaniserbar",
    "urbaniserbart": "urbaniserbar",
    "urbaniserbarts": "urbaniserbar",
    "urbaniseringar": "urbanisering",
    "urbaniseringarna": "urbanisering",
    "urbaniseringarnas": "urbanisering",
    "urbaniseringars": "urbanisering",
    "urbaniseringen": "urbanisering",
    "urbaniseringens": "urbanisering",
    "urbaniserings": "urbanisering",
    "urbanismen": "urbanism",
    "urbanismens": "urbanism",
    "urbanismer": "urbanism",
    "urbanismerna": "urbanism",
    "urbanismernas": "urbanism",
    "urbanismers": "urbanism",
    "urbanisms": "urbanism",
    "urbanistiska": "urbanistisk",
    "urbanistiskare": "urbanistisk",
    "urbanistiskares": "urbanistisk",
    "urbanistiskas": "urbanistisk",
    "urbanistiskast": "urbanistisk",
    "urbanistiskaste": "urbanistisk",
    "urbanistiskastes": "urbanistisk",
    "urbanistiskasts": "urbanistisk",
    "urbanistiske": "urbanistisk",
    "urbanistiskes": "urbanistisk",
    "urbanistisks": "urbanistisk",
    "urbanistiskt": "urbanistisk",
    "urbanistiskts": "urbanistisk",
    "urbaniteten": "urbanitet",
    "urbanitetens": "urbanitet",
    "urbaniteter": "urbanitet",
    "urbaniteterna": "urbanitet",
    "urbaniteternas": "urbanitet",
    "urbaniteters": "urbanitet",
    "urbanitets": "urbanitet",
    "urbans": "urban",
    "urbant": "urban",
    "urbants": "urban",
    "urbefolkningar": "urbefolkning",
    "urbefolkningarna": "urbefolkning",
    "urbefolkningarnas": "urbefolkning",
    "urbefolkningars": "urbefolkning",
    "urbefolkningen": "urbefolkning",
    "urbefolkningens": "urbefolkning",
    "urbefolknings": "urbefolkning",
    "urbenade": "urbenad",
    "urbenades": "urbenad",
    "urbenads": "urbenad",
    "urbenat": "urbenad",
    "urbenats": "urbenad",
    "urberget": "urberg",
    "urbergets": "urberg",
    "urbergs": "urberg",
    "urbergsplatåer": "urbergsplatå",
    "urbergsplatåerna": "urbergsplatå",
    "urbergsplatåernas": "urbergsplatå",
    "urbergsplatåers": "urbergsplatå",
    "urbergsplatån": "urbergsplatå",
    "urbergsplatåns": "urbergsplatå",
    "urbergsplatås": "urbergsplatå",
    "urbergsterrängen": "urbergsterräng",
    "urbergsterrängens": "urbergsterräng",
    "urbergsterränger": "urbergsterräng",
    "urbergsterrängerna": "urbergsterräng",
    "urbergsterrängernas": "urbergsterräng",
    "urbergsterrängers": "urbergsterräng",
    "urbergsterrängs": "urbergsterräng",
    "urbilden": "urbild",
    "urbildens": "urbild",
    "urbilder": "urbild",
    "urbilderna": "urbild",
    "urbildernas": "urbild",
    "urbilders": "urbild",
    "urbilds": "urbild",
    "urblekta": "urblekt",
    "urblektare": "urblekt",
    "urblektares": "urblekt",
    "urblektas": "urblekt",
    "urblektast": "urblekt",
    "urblektaste": "urblekt",
    "urblektastes": "urblekt",
    "urblektasts": "urblekt",
    "urblekte": "urblekt",
    "urblektes": "urblekt",
    "urblekts": "urblekt",
    "urblåsta": "urblåst",
    "urblåstare": "urblåst",
    "urblåstares": "urblåst",
    "urblåstas": "urblåst",
    "urblåstast": "urblåst",
    "urblåstaste": "urblåst",
    "urblåstastes": "urblåst",
    "urblåstasts": "urblåst",
    "urblåste": "urblåst",
    "urblåstes": "urblåst",
    "urblåsts": "urblåst",
    "urbränningar": "urbränning",
    "urbränningarna": "urbränning",
    "urbränningarnas": "urbränning",
    "urbränningars": "urbränning",
    "urbränningen": "urbränning",
    "urbränningens": "urbränning",
    "urbrännings": "urbränning",
    "urcellen": "urcell",
    "urcellens": "urcell",
    "urceller": "urcell",
    "urcellerna": "urcell",
    "urcellernas": "urcell",
    "urcellers": "urcell",
    "urcells": "urcell",
    "urdjuren": "urdjur",
    "urdjurens": "urdjur",
    "urdjuret": "urdjur",
    "urdjurets": "urdjur",
    "urdjurs": "urdjur",
    "urdjurscellen": "urdjurscell",
    "urdjurscellens": "urdjurscell",
    "urdjursceller": "urdjurscell",
    "urdjurscellerna": "urdjurscell",
    "urdjurscellernas": "urdjurscell",
    "urdjurscellers": "urdjurscell",
    "urdjurscells": "urdjurscell",
    "urdus": "urdu",
    "urdåliga": "urdålig",
    "urdåligare": "urdålig",
    "urdåligares": "urdålig",
    "urdåligas": "urdålig",
    "urdåligast": "urdålig",
    "urdåligaste": "urdålig",
    "urdåligastes": "urdålig",
    "urdåligasts": "urdålig",
    "urdålige": "urdålig",
    "urdåliges": "urdålig",
    "urdåligheten": "urdålighet",
    "urdålighetens": "urdålighet",
    "urdåligheter": "urdålighet",
    "urdåligheterna": "urdålighet",
    "urdåligheternas": "urdålighet",
    "urdåligheters": "urdålighet",
    "urdålighets": "urdålighet",
    "urdåligs": "urdålig",
    "urdåligt": "urdålig",
    "urdåligts": "urdålig",
    "urean": "urea",
    "ureans": "urea",
    "ureas": "urea",
    "ureasen": "ureas",
    "ureasens": "ureas",
    "ureaser": "ureas",
    "ureaserna": "ureas",
    "ureasernas": "ureas",
    "ureasers": "ureas",
    "uremien": "uremi",
    "uremiens": "uremi",
    "uremin": "uremi",
    "uremins": "uremi",
    "uremis": "uremi",
    "uren": "ur",
    "urens": "ur",
    "uret": "ur",
    "uretanen": "uretan",
    "uretanens": "uretan",
    "uretanplasten": "uretanplast",
    "uretanplastens": "uretanplast",
    "uretanplaster": "uretanplast",
    "uretanplasterna": "uretanplast",
    "uretanplasternas": "uretanplast",
    "uretanplasters": "uretanplast",
    "uretanplasts": "uretanplast",
    "uretans": "uretan",
    "urets": "ur",
    "urexplosionen": "urexplosion",
    "urexplosionens": "urexplosion",
    "urexplosioner": "urexplosion",
    "urexplosionerna": "urexplosion",
    "urexplosionernas": "urexplosion",
    "urexplosioners": "urexplosion",
    "urexplosions": "urexplosion",
    "urfadern": "urfader",
    "urfaderns": "urfader",
    "urfaders": "urfader",
    "urfinsk": "urfinska",
    "urfinskan": "urfinska",
    "urfinskans": "urfinska",
    "urfinskas": "urfinska",
    "urfjällsjordar": "urfjällsjord",
    "urfjällsjordarna": "urfjällsjord",
    "urfjällsjordarnas": "urfjällsjord",
    "urfjällsjordars": "urfjällsjord",
    "urfjällsjorden": "urfjällsjord",
    "urfjällsjordens": "urfjällsjord",
    "urfjällsjords": "urfjällsjord",
    "urfolken": "urfolk",
    "urfolkens": "urfolk",
    "urfolket": "urfolk",
    "urfolkets": "urfolk",
    "urfolks": "urfolk",
    "urformationen": "urformation",
    "urformationens": "urformation",
    "urformationer": "urformation",
    "urformationerna": "urformation",
    "urformationernas": "urformation",
    "urformationers": "urformation",
    "urformations": "urformation",
    "urfäder": "urfader",
    "urfäderna": "urfader",
    "urfädernas": "urfader",
    "urfäders": "urfader",
    "urfällda": "urfälld",
    "urfälldare": "urfälld",
    "urfälldares": "urfälld",
    "urfälldas": "urfälld",
    "urfälldast": "urfälld",
    "urfälldaste": "urfälld",
    "urfälldastes": "urfälld",
    "urfälldasts": "urfälld",
    "urfällde": "urfälld",
    "urfälldes": "urfälld",
    "urfällds": "urfälld",
    "urfällt": "urfälld",
    "urfällts": "urfälld",
    "urfågeln": "urfågel",
    "urfågelns": "urfågel",
    "urfågels": "urfågel",
    "urfåglar": "urfågel",
    "urfåglarna": "urfågel",
    "urfåglarnas": "urfågel",
    "urfåglars": "urfågel",
    "urfåniga": "urfånig",
    "urfånigare": "urfånig",
    "urfånigares": "urfånig",
    "urfånigas": "urfånig",
    "urfånigast": "urfånig",
    "urfånigaste": "urfånig",
    "urfånigastes": "urfånig",
    "urfånigasts": "urfånig",
    "urfånige": "urfånig",
    "urfåniges": "urfånig",
    "urfånigheten": "urfånighet",
    "urfånighetens": "urfånighet",
    "urfånighets": "urfånighet",
    "urfånigs": "urfånig",
    "urfånigt": "urfånig",
    "urfånigts": "urfånig",
    "urgamla": "urgammal",
    "urgamlas": "urgammal",
    "urgamle": "urgammal",
    "urgamles": "urgammal",
    "urgammals": "urgammal",
    "urgammalt": "urgammal",
    "urgammalts": "urgammal",
    "urgerade": "urgera",
    "urgerades": "urgera",
    "urgerande": "urgera",
    "urgeranden": "urgerande",
    "urgerandena": "urgerande",
    "urgerandenas": "urgerande",
    "urgerandens": "urgerande",
    "urgerandes": "urgerande",
    "urgerandet": "urgerande",
    "urgerandets": "urgerande",
    "urgerar": "urgera",
    "urgeras": "urgera",
    "urgerat": "urgera",
    "urgerats": "urgera",
    "urgeringar": "urgering",
    "urgeringarna": "urgering",
    "urgeringarnas": "urgering",
    "urgeringars": "urgering",
    "urgeringen": "urgering",
    "urgeringens": "urgering",
    "urgerings": "urgering",
    "urgermansk": "urgermanska",
    "urgermanska": "urgermansk",
    "urgermanskan": "urgermanska",
    "urgermanskans": "urgermanska",
    "urgermanskare": "urgermansk",
    "urgermanskares": "urgermansk",
    "urgermanskas": "urgermanska",
    "urgermanskast": "urgermansk",
    "urgermanskaste": "urgermansk",
    "urgermanskastes": "urgermansk",
    "urgermanskasts": "urgermansk",
    "urgermanske": "urgermansk",
    "urgermanskes": "urgermansk",
    "urgermansks": "urgermansk",
    "urgermanskt": "urgermansk",
    "urgermanskts": "urgermansk",
    "urgröpningar": "urgröpning",
    "urgröpningarna": "urgröpning",
    "urgröpningarnas": "urgröpning",
    "urgröpningars": "urgröpning",
    "urgröpningen": "urgröpning",
    "urgröpningens": "urgröpning",
    "urgröpnings": "urgröpning",
    "urgröpta": "urgröpt",
    "urgröptare": "urgröpt",
    "urgröptares": "urgröpt",
    "urgröptas": "urgröpt",
    "urgröptast": "urgröpt",
    "urgröptaste": "urgröpt",
    "urgröptastes": "urgröpt",
    "urgröptasts": "urgröpt",
    "urgröpte": "urgröpt",
    "urgröptes": "urgröpt",
    "urgröpts": "urgröpt",
    "urhemmen": "urhem",
    "urhemmens": "urhem",
    "urhemmet": "urhem",
    "urhemmets": "urhem",
    "urhems": "urhem",
    "urholk": "urholka",
    "urholkad": "urholka",
    "urholkade": "urholka",
    "urholkades": "urholka",
    "urholkads": "urholka",
    "urholkande": "urholka",
    "urholkanden": "urholkande",
    "urholkandena": "urholkande",
    "urholkandenas": "urholkande",
    "urholkandens": "urholkande",
    "urholkandes": "urholkande",
    "urholkandet": "urholkande",
    "urholkandets": "urholkande",
    "urholkar": "urholka",
    "urholkas": "urholka",
    "urholkat": "urholka",
    "urholkats": "urholka",
    "uribagar": "uribag",
    "uribagarna": "uribag",
    "uribagarnas": "uribag",
    "uribagars": "uribag",
    "uribagen": "uribag",
    "uribagens": "uribag",
    "uribags": "uribag",
    "uridioten": "uridiot",
    "uridiotens": "uridiot",
    "uridioter": "uridiot",
    "uridioterna": "uridiot",
    "uridioternas": "uridiot",
    "uridioters": "uridiot",
    "uridiots": "uridiot",
    "uridomen": "uridom",
    "uridomens": "uridom",
    "uridomer": "uridom",
    "uridomerna": "uridom",
    "uridomernas": "uridom",
    "uridomers": "uridom",
    "uridoms": "uridom",
    "uriebreven": "uriebrev",
    "uriebrevens": "uriebrev",
    "uriebrevet": "uriebrev",
    "uriebrevets": "uriebrev",
    "uriebrevs": "uriebrev",
    "urinavsöndringar": "urinavsöndring",
    "urinavsöndringarna": "urinavsöndring",
    "urinavsöndringarnas": "urinavsöndring",
    "urinavsöndringars": "urinavsöndring",
    "urinavsöndringen": "urinavsöndring",
    "urinavsöndringens": "urinavsöndring",
    "urinavsöndrings": "urinavsöndring",
    "urinblås": "urinblåsa",
    "urinblåsan": "urinblåsa",
    "urinblåsans": "urinblåsa",
    "urinblåsas": "urinblåsa",
    "urinblåse": "urinblåsa",
    "urinblåsor": "urinblåsa",
    "urinblåsorna": "urinblåsa",
    "urinblåsornas": "urinblåsa",
    "urinblåsors": "urinblåsa",
    "urinbrunnar": "urinbrunn",
    "urinbrunnarna": "urinbrunn",
    "urinbrunnarnas": "urinbrunn",
    "urinbrunnars": "urinbrunn",
    "urinbrunnen": "urinbrunn",
    "urinbrunnens": "urinbrunn",
    "urinbrunns": "urinbrunn",
    "urinbyggar": "urinbyggare",
    "urinbyggaren": "urinbyggare",
    "urinbyggarens": "urinbyggare",
    "urinbyggares": "urinbyggare",
    "urinbyggarna": "urinbyggare",
    "urinbyggarnas": "urinbyggare",
    "urindoeuropeiska": "urindoeuropeisk",
    "urindoeuropeiskare": "urindoeuropeisk",
    "urindoeuropeiskares": "urindoeuropeisk",
    "urindoeuropeiskas": "urindoeuropeisk",
    "urindoeuropeiskast": "urindoeuropeisk",
    "urindoeuropeiskaste": "urindoeuropeisk",
    "urindoeuropeiskastes": "urindoeuropeisk",
    "urindoeuropeiskasts": "urindoeuropeisk",
    "urindoeuropeiske": "urindoeuropeisk",
    "urindoeuropeiskes": "urindoeuropeisk",
    "urindoeuropeisks": "urindoeuropeisk",
    "urindoeuropeiskt": "urindoeuropeisk",
    "urindoeuropeiskts": "urindoeuropeisk",
    "urinen": "urin",
    "urinens": "urin",
    "urinerade": "urinera",
    "urinerades": "urinera",
    "urinerande": "urinera",
    "urineranden": "urinerande",
    "urinerandena": "urinerande",
    "urinerandenas": "urinerande",
    "urinerandens": "urinerande",
    "urinerandes": "urinerande",
    "urinerandet": "urinerande",
    "urinerandets": "urinerande",
    "urinerar": "urinera",
    "urineras": "urinera",
    "urinerat": "urinera",
    "urinerats": "urinera",
    "urineringar": "urinering",
    "urineringarna": "urinering",
    "urineringarnas": "urinering",
    "urineringars": "urinering",
    "urineringen": "urinering",
    "urineringens": "urinering",
    "urinerings": "urinering",
    "urinförgiftningar": "urinförgiftning",
    "urinförgiftningarna": "urinförgiftning",
    "urinförgiftningarnas": "urinförgiftning",
    "urinförgiftningars": "urinförgiftning",
    "urinförgiftningen": "urinförgiftning",
    "urinförgiftningens": "urinförgiftning",
    "urinförgiftnings": "urinförgiftning",
    "urinkurar": "urinkur",
    "urinkurarna": "urinkur",
    "urinkurarnas": "urinkur",
    "urinkurars": "urinkur",
    "urinkuren": "urinkur",
    "urinkurens": "urinkur",
    "urinkurs": "urinkur",
    "urinledar": "urinledare",
    "urinledaren": "urinledare",
    "urinledarens": "urinledare",
    "urinledares": "urinledare",
    "urinledarna": "urinledare",
    "urinledarnas": "urinledare",
    "urinnevånar": "urinnevånare",
    "urinnevånaren": "urinnevånare",
    "urinnevånarens": "urinnevånare",
    "urinnevånares": "urinnevånare",
    "urinnevånarna": "urinnevånare",
    "urinnevånarnas": "urinnevånare",
    "urinoaren": "urinoar",
    "urinoarens": "urinoar",
    "urinoarer": "urinoar",
    "urinoarerna": "urinoar",
    "urinoarernas": "urinoar",
    "urinoarers": "urinoar",
    "urinoars": "urinoar",
    "urinorganen": "urinorgan",
    "urinorganens": "urinorgan",
    "urinorganet": "urinorgan",
    "urinorganets": "urinorgan",
    "urinorgans": "urinorgan",
    "urinproven": "urinprov",
    "urinprovens": "urinprov",
    "urinprover": "urinprov",
    "urinproverna": "urinprov",
    "urinprovernas": "urinprov",
    "urinprovers": "urinprov",
    "urinprovet": "urinprov",
    "urinprovets": "urinprov",
    "urinprovs": "urinprov",
    "urinrören": "urinrör",
    "urinrörens": "urinrör",
    "urinröret": "urinrör",
    "urinrörets": "urinrör",
    "urinrörs": "urinrör",
    "urins": "urin",
    "urinstinkten": "urinstinkt",
    "urinstinktens": "urinstinkt",
    "urinstinkter": "urinstinkt",
    "urinstinkterna": "urinstinkt",
    "urinstinkternas": "urinstinkt",
    "urinstinkters": "urinstinkt",
    "urinstinkts": "urinstinkt",
    "urinstockningar": "urinstockning",
    "urinstockningarna": "urinstockning",
    "urinstockningarnas": "urinstockning",
    "urinstockningars": "urinstockning",
    "urinstockningen": "urinstockning",
    "urinstockningens": "urinstockning",
    "urinstocknings": "urinstockning",
    "urinstämman": "urinstämma",
    "urinstämmans": "urinstämma",
    "urinstämmas": "urinstämma",
    "urinsyran": "urinsyra",
    "urinsyrans": "urinsyra",
    "urinsyras": "urinsyra",
    "urinsyre": "urinsyra",
    "urinträngningar": "urinträngning",
    "urinträngningarna": "urinträngning",
    "urinträngningarnas": "urinträngning",
    "urinträngningars": "urinträngning",
    "urinträngningen": "urinträngning",
    "urinträngningens": "urinträngning",
    "urinträngnings": "urinträngning",
    "urinvägar": "urinväg",
    "urinvägarna": "urinvägar",
    "urinvägarnas": "urinvägar",
    "urinvägars": "urinvägar",
    "urinvägen": "urinväg",
    "urinvägens": "urinväg",
    "urinvägs": "urinvägar",
    "urinvägsinfektionen": "urinvägsinfektion",
    "urinvägsinfektionens": "urinvägsinfektion",
    "urinvägsinfektioner": "urinvägsinfektion",
    "urinvägsinfektionerna": "urinvägsinfektion",
    "urinvägsinfektionernas": "urinvägsinfektion",
    "urinvägsinfektioners": "urinvägsinfektion",
    "urinvägsinfektions": "urinvägsinfektion",
    "urinvånar": "urinvånare",
    "urinvånaren": "urinvånare",
    "urinvånarens": "urinvånare",
    "urinvånares": "urinvånare",
    "urinvånarna": "urinvånare",
    "urinvånarnas": "urinvånare",
    "urinämnes": "urinämne",
    "urinämnet": "urinämne",
    "urinämnets": "urinämne",
    "urkalk": "urkalka",
    "urkalkad": "urkalka",
    "urkalkade": "urkalka",
    "urkalkades": "urkalka",
    "urkalkads": "urkalka",
    "urkalkande": "urkalka",
    "urkalkanden": "urkalkande",
    "urkalkandena": "urkalkande",
    "urkalkandenas": "urkalkande",
    "urkalkandens": "urkalkande",
    "urkalkandes": "urkalkande",
    "urkalkandet": "urkalkande",
    "urkalkandets": "urkalkande",
    "urkalkar": "urkalka",
    "urkalkas": "urkalka",
    "urkalkat": "urkalka",
    "urkalkats": "urkalka",
    "urkalkstenar": "urkalksten",
    "urkalkstenarna": "urkalksten",
    "urkalkstenarnas": "urkalksten",
    "urkalkstenars": "urkalksten",
    "urkalkstenen": "urkalksten",
    "urkalkstenens": "urkalksten",
    "urkalkstens": "urkalksten",
    "urklippen": "urklipp",
    "urklippens": "urklipp",
    "urklippet": "urklipp",
    "urklippets": "urklipp",
    "urklipps": "urklipp",
    "urkokta": "urkokt",
    "urkoktare": "urkokt",
    "urkoktares": "urkokt",
    "urkoktas": "urkokt",
    "urkoktast": "urkokt",
    "urkoktaste": "urkokt",
    "urkoktastes": "urkokt",
    "urkoktasts": "urkokt",
    "urkokte": "urkokt",
    "urkoktes": "urkokt",
    "urkokts": "urkokt",
    "urkopplade": "urkopplad",
    "urkopplades": "urkopplad",
    "urkopplads": "urkopplad",
    "urkopplat": "urkopplad",
    "urkopplats": "urkopplad",
    "urkramade": "urkramad",
    "urkramades": "urkramad",
    "urkramads": "urkramad",
    "urkramat": "urkramad",
    "urkramats": "urkramad",
    "urkristendomar": "urkristendom",
    "urkristendomarna": "urkristendom",
    "urkristendomarnas": "urkristendom",
    "urkristendomars": "urkristendom",
    "urkristendomen": "urkristendom",
    "urkristendomens": "urkristendom",
    "urkristendoms": "urkristendom",
    "urkunden": "urkund",
    "urkundens": "urkund",
    "urkunder": "urkund",
    "urkunderna": "urkund",
    "urkundernas": "urkund",
    "urkunders": "urkund",
    "urkundliga": "urkundlig",
    "urkundligare": "urkundlig",
    "urkundligares": "urkundlig",
    "urkundligas": "urkundlig",
    "urkundligast": "urkundlig",
    "urkundligaste": "urkundlig",
    "urkundligastes": "urkundlig",
    "urkundligasts": "urkundlig",
    "urkundlige": "urkundlig",
    "urkundliges": "urkundlig",
    "urkundligheten": "urkundlighet",
    "urkundlighetens": "urkundlighet",
    "urkundlighets": "urkundlighet",
    "urkundligs": "urkundlig",
    "urkundligt": "urkundlig",
    "urkundligts": "urkundlig",
    "urkunds": "urkund",
    "urkundsforskningar": "urkundsforskning",
    "urkundsforskningarna": "urkundsforskning",
    "urkundsforskningarnas": "urkundsforskning",
    "urkundsforskningars": "urkundsforskning",
    "urkundsforskningen": "urkundsforskning",
    "urkundsforskningens": "urkundsforskning",
    "urkundsforsknings": "urkundsforskning",
    "urladdar": "urladdare",
    "urladdaren": "urladdare",
    "urladdarens": "urladdare",
    "urladdares": "urladdare",
    "urladdarna": "urladdare",
    "urladdarnas": "urladdare",
    "urladdningar": "urladdning",
    "urladdningarna": "urladdning",
    "urladdningarnas": "urladdning",
    "urladdningars": "urladdning",
    "urladdningen": "urladdning",
    "urladdningens": "urladdning",
    "urladdnings": "urladdning",
    "urladdningsrören": "urladdningsrör",
    "urladdningsrörens": "urladdningsrör",
    "urladdningsröret": "urladdningsrör",
    "urladdningsrörets": "urladdningsrör",
    "urladdningsrörs": "urladdningsrör",
    "urlak": "urlaka",
    "urlakad": "urlaka",
    "urlakade": "urlakad",
    "urlakades": "urlakad",
    "urlakads": "urlakad",
    "urlakande": "urlaka",
    "urlakanden": "urlakande",
    "urlakandena": "urlakande",
    "urlakandenas": "urlakande",
    "urlakandens": "urlakande",
    "urlakandes": "urlakande",
    "urlakandet": "urlakande",
    "urlakandets": "urlakande",
    "urlakar": "urlaka",
    "urlakas": "urlaka",
    "urlakat": "urlakad",
    "urlakats": "urlakad",
    "urlakningar": "urlakning",
    "urlakningarna": "urlakning",
    "urlakningarnas": "urlakning",
    "urlakningars": "urlakning",
    "urlakningen": "urlakning",
    "urlakningens": "urlakning",
    "urlaknings": "urlakning",
    "urlastningar": "urlastning",
    "urlastningarna": "urlastning",
    "urlastningarnas": "urlastning",
    "urlastningars": "urlastning",
    "urlastningen": "urlastning",
    "urlastningens": "urlastning",
    "urlastnings": "urlastning",
    "urledvrickningar": "urledvrickning",
    "urledvrickningarna": "urledvrickning",
    "urledvrickningarnas": "urledvrickning",
    "urledvrickningars": "urledvrickning",
    "urledvrickningen": "urledvrickning",
    "urledvrickningens": "urledvrickning",
    "urledvricknings": "urledvrickning",
    "urledvridningar": "urledvridning",
    "urledvridningarna": "urledvridning",
    "urledvridningarnas": "urledvridning",
    "urledvridningars": "urledvridning",
    "urledvridningen": "urledvridning",
    "urledvridningens": "urledvridning",
    "urledvridnings": "urledvridning",
    "urmakar": "urmakare",
    "urmakaren": "urmakare",
    "urmakarens": "urmakare",
    "urmakares": "urmakare",
    "urmakarna": "urmakare",
    "urmakarnas": "urmakare",
    "urmakerier": "urmakeri",
    "urmakerierna": "urmakeri",
    "urmakeriernas": "urmakeri",
    "urmakeriers": "urmakeri",
    "urmakeriet": "urmakeri",
    "urmakeriets": "urmakeri",
    "urmakeris": "urmakeri",
    "urmakerit": "urmakeri",
    "urmakerits": "urmakeri",
    "urminneshävden": "urminneshävd",
    "urminneshävdens": "urminneshävd",
    "urminneshävder": "urminneshävd",
    "urminneshävderna": "urminneshävd",
    "urminneshävdernas": "urminneshävd",
    "urminneshävders": "urminneshävd",
    "urminneshävds": "urminneshävd",
    "urmodiga": "urmodig",
    "urmodigare": "urmodig",
    "urmodigares": "urmodig",
    "urmodigas": "urmodig",
    "urmodigast": "urmodig",
    "urmodigaste": "urmodig",
    "urmodigastes": "urmodig",
    "urmodigasts": "urmodig",
    "urmodige": "urmodig",
    "urmodiges": "urmodig",
    "urmodigheten": "urmodighet",
    "urmodighetens": "urmodighet",
    "urmodighets": "urmodighet",
    "urmodigs": "urmodig",
    "urmodigt": "urmodig",
    "urmodigts": "urmodig",
    "urmänniskan": "urmänniska",
    "urmänniskans": "urmänniska",
    "urmänniskas": "urmänniska",
    "urmännisko": "urmänniska",
    "urmänniskor": "urmänniska",
    "urmänniskorna": "urmänniska",
    "urmänniskornas": "urmänniska",
    "urmänniskors": "urmänniska",
    "urn": "urna",
    "urnan": "urna",
    "urnans": "urna",
    "urnas": "urna",
    "urne": "urna",
    "urnebrandgropar": "urnebrandgrop",
    "urnebrandgroparna": "urnebrandgrop",
    "urnebrandgroparnas": "urnebrandgrop",
    "urnebrandgropars": "urnebrandgrop",
    "urnebrandgropen": "urnebrandgrop",
    "urnebrandgropens": "urnebrandgrop",
    "urnebrandgrops": "urnebrandgrop",
    "urnegravar": "urnegrav",
    "urnegravarna": "urnegrav",
    "urnegravarnas": "urnegrav",
    "urnegravars": "urnegrav",
    "urnegraven": "urnegrav",
    "urnegravens": "urnegrav",
    "urnegravs": "urnegrav",
    "urnformade": "urnformad",
    "urnformades": "urnformad",
    "urnformads": "urnformad",
    "urnformat": "urnformad",
    "urnformats": "urnformad",
    "urngravar": "urngrav",
    "urngravarna": "urngrav",
    "urngravarnas": "urngrav",
    "urngravars": "urngrav",
    "urngraven": "urngrav",
    "urngravens": "urngrav",
    "urngravs": "urngrav",
    "urnkull": "urnkulle",
    "urnkullar": "urnkulle",
    "urnkullarna": "urnkulle",
    "urnkullarnas": "urnkulle",
    "urnkullars": "urnkulle",
    "urnkullen": "urnkulle",
    "urnkullens": "urnkulle",
    "urnkulles": "urnkulle",
    "urnkulls": "urnkulle",
    "urnor": "urna",
    "urnordisk": "urnordiska",
    "urnordiska": "urnordisk",
    "urnordiskan": "urnordiska",
    "urnordiskans": "urnordiska",
    "urnordiskare": "urnordisk",
    "urnordiskares": "urnordisk",
    "urnordiskas": "urnordiska",
    "urnordiskast": "urnordisk",
    "urnordiskaste": "urnordisk",
    "urnordiskastes": "urnordisk",
    "urnordiskasts": "urnordisk",
    "urnordiske": "urnordisk",
    "urnordiskes": "urnordisk",
    "urnordisks": "urnordisk",
    "urnordiskt": "urnordisk",
    "urnordiskts": "urnordisk",
    "urnorna": "urna",
    "urnornas": "urna",
    "urnors": "urna",
    "urns": "urna",
    "urnupens": "urnupen",
    "urnupet": "urnupen",
    "urnupets": "urnupen",
    "urnupna": "urnupen",
    "urnupnare": "urnupen",
    "urnupnares": "urnupen",
    "urnupnas": "urnupen",
    "urnupnast": "urnupen",
    "urnupnaste": "urnupen",
    "urnupnastes": "urnupen",
    "urnupnasts": "urnupen",
    "urnupne": "urnupen",
    "urnupnes": "urnupen",
    "urnyckeln": "urnyckel",
    "urnyckelns": "urnyckel",
    "urnyckels": "urnyckel",
    "urnycklar": "urnyckel",
    "urnycklarna": "urnyckel",
    "urnycklarnas": "urnyckel",
    "urnycklars": "urnyckel",
    "uroceanen": "urocean",
    "uroceanens": "urocean",
    "uroceaner": "urocean",
    "uroceanerna": "urocean",
    "uroceanernas": "urocean",
    "uroceaners": "urocean",
    "uroceans": "urocean",
    "urogenitalapparaten": "urogenitalapparat",
    "urogenitalapparatens": "urogenitalapparat",
    "urogenitalapparater": "urogenitalapparat",
    "urogenitalapparaterna": "urogenitalapparat",
    "urogenitalapparaternas": "urogenitalapparat",
    "urogenitalapparaters": "urogenitalapparat",
    "urogenitalapparats": "urogenitalapparat",
    "urogenitalorganen": "urogenitalorgan",
    "urogenitalorganens": "urogenitalorgan",
    "urogenitalorganet": "urogenitalorgan",
    "urogenitalorganets": "urogenitalorgan",
    "urogenitalorgans": "urogenitalorgan",
    "urogenitalöppningar": "urogenitalöppning",
    "urogenitalöppningarna": "urogenitalöppning",
    "urogenitalöppningarnas": "urogenitalöppning",
    "urogenitalöppningars": "urogenitalöppning",
    "urogenitalöppningen": "urogenitalöppning",
    "urogenitalöppningens": "urogenitalöppning",
    "urogenitalöppnings": "urogenitalöppning",
    "urografien": "urografi",
    "urografiens": "urografi",
    "urografin": "urografi",
    "urografins": "urografi",
    "urografis": "urografi",
    "urologen": "urolog",
    "urologens": "urolog",
    "urologer": "urolog",
    "urologerna": "urolog",
    "urologernas": "urolog",
    "urologers": "urolog",
    "urologien": "urologi",
    "urologiens": "urologi",
    "urologin": "urologi",
    "urologins": "urologi",
    "urologis": "urologi",
    "urologiska": "urologisk",
    "urologiskare": "urologisk",
    "urologiskares": "urologisk",
    "urologiskas": "urologisk",
    "urologiskast": "urologisk",
    "urologiskaste": "urologisk",
    "urologiskastes": "urologisk",
    "urologiskasts": "urologisk",
    "urologiske": "urologisk",
    "urologiskes": "urologisk",
    "urologisks": "urologisk",
    "urologiskt": "urologisk",
    "urologiskts": "urologisk",
    "urologs": "urolog",
    "urormbunk": "urormbunke",
    "urormbunkar": "urormbunke",
    "urormbunkarna": "urormbunke",
    "urormbunkarnas": "urormbunke",
    "urormbunkars": "urormbunke",
    "urormbunken": "urormbunke",
    "urormbunkens": "urormbunke",
    "urormbunkes": "urormbunke",
    "urormbunks": "urormbunke",
    "urox": "uroxe",
    "uroxar": "uroxe",
    "uroxarna": "uroxe",
    "uroxarnas": "uroxe",
    "uroxars": "uroxe",
    "uroxen": "uroxe",
    "uroxens": "uroxe",
    "uroxes": "uroxe",
    "urplocket": "urplock",
    "urplockets": "urplock",
    "urplocks": "urplock",
    "urpremiären": "urpremiär",
    "urpremiärens": "urpremiär",
    "urpremiärer": "urpremiär",
    "urpremiärerna": "urpremiär",
    "urpremiärernas": "urpremiär",
    "urpremiärers": "urpremiär",
    "urpremiärs": "urpremiär",
    "urringade": "urringad",
    "urringades": "urringad",
    "urringads": "urringad",
    "urringat": "urringad",
    "urringats": "urringad",
    "urringningar": "urringning",
    "urringningarna": "urringning",
    "urringningarnas": "urringning",
    "urringningars": "urringning",
    "urringningen": "urringning",
    "urringningens": "urringning",
    "urringnings": "urringning",
    "urs": "ur",
    "ursak": "ursaka",
    "ursakad": "ursaka",
    "ursakade": "ursaka",
    "ursakades": "ursaka",
    "ursakads": "ursaka",
    "ursakande": "ursaka",
    "ursakanden": "ursakande",
    "ursakandena": "ursakande",
    "ursakandenas": "ursakande",
    "ursakandens": "ursakande",
    "ursakandes": "ursakande",
    "ursakandet": "ursakande",
    "ursakandets": "ursakande",
    "ursakar": "ursaka",
    "ursakas": "ursaka",
    "ursakat": "ursaka",
    "ursakats": "ursaka",
    "ursamen": "ursame",
    "ursamens": "ursame",
    "ursamer": "ursame",
    "ursamerna": "ursame",
    "ursamernas": "ursame",
    "ursamers": "ursame",
    "ursames": "ursame",
    "ursinnes": "ursinne",
    "ursinnet": "ursinne",
    "ursinnets": "ursinne",
    "ursinniga": "ursinnig",
    "ursinnigare": "ursinnig",
    "ursinnigares": "ursinnig",
    "ursinnigas": "ursinnig",
    "ursinnigast": "ursinnig",
    "ursinnigaste": "ursinnig",
    "ursinnigastes": "ursinnig",
    "ursinnigasts": "ursinnig",
    "ursinnige": "ursinnig",
    "ursinniges": "ursinnig",
    "ursinnigheten": "ursinnighet",
    "ursinnighetens": "ursinnighet",
    "ursinnighets": "ursinnighet",
    "ursinnigs": "ursinnig",
    "ursinnigt": "ursinnig",
    "ursinnigts": "ursinnig",
    "ursinningslösa": "ursinningslös",
    "ursinningslösare": "ursinningslös",
    "ursinningslösares": "ursinningslös",
    "ursinningslösas": "ursinningslös",
    "ursinningslösast": "ursinningslös",
    "ursinningslösaste": "ursinningslös",
    "ursinningslösastes": "ursinningslös",
    "ursinningslösasts": "ursinningslös",
    "ursinningslöse": "ursinningslös",
    "ursinningslöses": "ursinningslös",
    "ursinningslöst": "ursinningslös",
    "ursinningslösts": "ursinningslös",
    "urskild": "urskilja",
    "urskilda": "urskilja",
    "urskildas": "urskilja",
    "urskilde": "urskilja",
    "urskildes": "urskilja",
    "urskilds": "urskilja",
    "urskilj": "urskilja",
    "urskiljande": "urskilja",
    "urskiljanden": "urskiljande",
    "urskiljandena": "urskiljande",
    "urskiljandenas": "urskiljande",
    "urskiljandens": "urskiljande",
    "urskiljandes": "urskiljande",
    "urskiljandet": "urskiljande",
    "urskiljandets": "urskiljande",
    "urskiljas": "urskilja",
    "urskiljbara": "urskiljbar",
    "urskiljbarare": "urskiljbar",
    "urskiljbarares": "urskiljbar",
    "urskiljbaras": "urskiljbar",
    "urskiljbarast": "urskiljbar",
    "urskiljbaraste": "urskiljbar",
    "urskiljbarastes": "urskiljbar",
    "urskiljbarasts": "urskiljbar",
    "urskiljbare": "urskiljbar",
    "urskiljbares": "urskiljbar",
    "urskiljbarheten": "urskiljbarhet",
    "urskiljbarhetens": "urskiljbarhet",
    "urskiljbarhets": "urskiljbarhet",
    "urskiljbars": "urskiljbar",
    "urskiljbart": "urskiljbar",
    "urskiljbarts": "urskiljbar",
    "urskiljer": "urskilja",
    "urskiljes": "urskilja",
    "urskiljningar": "urskiljning",
    "urskiljningarna": "urskiljning",
    "urskiljningarnas": "urskiljning",
    "urskiljningars": "urskiljning",
    "urskiljningen": "urskiljning",
    "urskiljningens": "urskiljning",
    "urskiljnings": "urskiljning",
    "urskiljningslösa": "urskiljningslös",
    "urskiljningslösare": "urskiljningslös",
    "urskiljningslösares": "urskiljningslös",
    "urskiljningslösas": "urskiljningslös",
    "urskiljningslösast": "urskiljningslös",
    "urskiljningslösaste": "urskiljningslös",
    "urskiljningslösastes": "urskiljningslös",
    "urskiljningslösasts": "urskiljningslös",
    "urskiljningslöse": "urskiljningslös",
    "urskiljningslöses": "urskiljningslös",
    "urskiljningslösheten": "urskiljningslöshet",
    "urskiljningslöshetens": "urskiljningslöshet",
    "urskiljningslöshets": "urskiljningslöshet",
    "urskiljningslöst": "urskiljningslös",
    "urskiljningslösts": "urskiljningslös",
    "urskiljs": "urskilja",
    "urskillningar": "urskillning",
    "urskillningarna": "urskillning",
    "urskillningarnas": "urskillning",
    "urskillningars": "urskillning",
    "urskillningen": "urskillning",
    "urskillningens": "urskillning",
    "urskillnings": "urskillning",
    "urskillningslösa": "urskillningslös",
    "urskillningslösare": "urskillningslös",
    "urskillningslösares": "urskillningslös",
    "urskillningslösas": "urskillningslös",
    "urskillningslösast": "urskillningslös",
    "urskillningslösaste": "urskillningslös",
    "urskillningslösastes": "urskillningslös",
    "urskillningslösasts": "urskillningslös",
    "urskillningslöse": "urskillningslös",
    "urskillningslöses": "urskillningslös",
    "urskillningslösheten": "urskillningslöshet",
    "urskillningslöshetens": "urskillningslöshet",
    "urskillningslöshets": "urskillningslöshet",
    "urskillningslöst": "urskillningslös",
    "urskillningslösts": "urskillningslös",
    "urskilt": "urskilja",
    "urskilts": "urskilja",
    "urskogar": "urskog",
    "urskogarna": "urskog",
    "urskogarnas": "urskog",
    "urskogars": "urskog",
    "urskogen": "urskog",
    "urskogens": "urskog",
    "urskogs": "urskog",
    "urskrien": "urskri",
    "urskriens": "urskri",
    "urskriet": "urskri",
    "urskriets": "urskri",
    "urskrin": "urskri",
    "urskrina": "urskri",
    "urskrinas": "urskri",
    "urskrins": "urskri",
    "urskris": "urskri",
    "urskrit": "urskri",
    "urskrits": "urskri",
    "urskuld": "urskulda",
    "urskuldad": "urskulda",
    "urskuldade": "urskulda",
    "urskuldades": "urskulda",
    "urskuldads": "urskulda",
    "urskuldande": "urskulda",
    "urskuldanden": "urskuldande",
    "urskuldandena": "urskuldande",
    "urskuldandenas": "urskuldande",
    "urskuldandens": "urskuldande",
    "urskuldandes": "urskuldande",
    "urskuldandet": "urskuldande",
    "urskuldandets": "urskuldande",
    "urskuldans": "urskuldan",
    "urskuldar": "urskulda",
    "urskuldas": "urskulda",
    "urskuldat": "urskulda",
    "urskuldats": "urskulda",
    "urskålade": "urskålad",
    "urskålades": "urskålad",
    "urskålads": "urskålad",
    "urskålat": "urskålad",
    "urskålats": "urskålad",
    "urskönj": "urskönja",
    "urskönjande": "urskönja",
    "urskönjanden": "urskönjande",
    "urskönjandena": "urskönjande",
    "urskönjandenas": "urskönjande",
    "urskönjandens": "urskönjande",
    "urskönjandes": "urskönjande",
    "urskönjandet": "urskönjande",
    "urskönjandets": "urskönjande",
    "urskönjas": "urskönja",
    "urskönjd": "urskönja",
    "urskönjda": "urskönja",
    "urskönjdas": "urskönja",
    "urskönjde": "urskönja",
    "urskönjdes": "urskönja",
    "urskönjds": "urskönja",
    "urskönjer": "urskönja",
    "urskönjes": "urskönja",
    "urskönjs": "urskönja",
    "urskönjt": "urskönja",
    "urskönjts": "urskönja",
    "urslemmet": "urslem",
    "urslemmets": "urslem",
    "urslems": "urslem",
    "ursmällar": "ursmäll",
    "ursmällarna": "ursmäll",
    "ursmällarnas": "ursmäll",
    "ursmällars": "ursmäll",
    "ursmällen": "ursmäll",
    "ursmällens": "ursmäll",
    "ursmälls": "ursmäll",
    "ursmällsteorien": "ursmällsteori",
    "ursmällsteoriens": "ursmällsteori",
    "ursmällsteorier": "ursmällsteori",
    "ursmällsteorierna": "ursmällsteori",
    "ursmällsteoriernas": "ursmällsteori",
    "ursmällsteoriers": "ursmällsteori",
    "ursmällsteorin": "ursmällsteori",
    "ursmällsteorins": "ursmällsteori",
    "ursmällsteoris": "ursmällsteori",
    "ursnygga": "ursnygg",
    "ursnyggare": "ursnygg",
    "ursnyggares": "ursnygg",
    "ursnyggas": "ursnygg",
    "ursnyggast": "ursnygg",
    "ursnyggaste": "ursnygg",
    "ursnyggastes": "ursnygg",
    "ursnyggasts": "ursnygg",
    "ursnygge": "ursnygg",
    "ursnygges": "ursnygg",
    "ursnyggheten": "ursnygghet",
    "ursnygghetens": "ursnygghet",
    "ursnygghets": "ursnygghet",
    "ursnyggs": "ursnygg",
    "ursnyggt": "ursnygg",
    "ursnyggts": "ursnygg",
    "ursopp": "ursoppa",
    "ursoppan": "ursoppa",
    "ursoppans": "ursoppa",
    "ursoppas": "ursoppa",
    "ursoppe": "ursoppa",
    "ursoppor": "ursoppa",
    "ursopporna": "ursoppa",
    "ursoppornas": "ursoppa",
    "ursoppors": "ursoppa",
    "ursopps": "ursoppa",
    "ursprungen": "ursprung",
    "ursprungens": "ursprung",
    "ursprunget": "ursprung",
    "ursprungets": "ursprung",
    "ursprungliga": "ursprunglig",
    "ursprungligare": "ursprunglig",
    "ursprungligares": "ursprunglig",
    "ursprungligas": "ursprunglig",
    "ursprungligast": "ursprunglig",
    "ursprungligaste": "ursprunglig",
    "ursprungligastes": "ursprunglig",
    "ursprungligasts": "ursprunglig",
    "ursprunglige": "ursprunglig",
    "ursprungliges": "ursprunglig",
    "ursprungligheten": "ursprunglighet",
    "ursprunglighetens": "ursprunglighet",
    "ursprunglighets": "ursprunglighet",
    "ursprungligs": "ursprunglig",
    "ursprungligt": "ursprunglig",
    "ursprungligts": "ursprunglig",
    "ursprungs": "ursprung",
    "ursprungsarten": "ursprungsart",
    "ursprungsartens": "ursprungsart",
    "ursprungsarter": "ursprungsart",
    "ursprungsarterna": "ursprungsart",
    "ursprungsarternas": "ursprungsart",
    "ursprungsarters": "ursprungsart",
    "ursprungsarts": "ursprungsart",
    "ursprungsattesten": "ursprungsattest",
    "ursprungsattestens": "ursprungsattest",
    "ursprungsattester": "ursprungsattest",
    "ursprungsattesterna": "ursprungsattest",
    "ursprungsattesternas": "ursprungsattest",
    "ursprungsattesters": "ursprungsattest",
    "ursprungsattests": "ursprungsattest",
    "ursprungsbefolkningar": "ursprungsbefolkning",
    "ursprungsbefolkningarna": "ursprungsbefolkning",
    "ursprungsbefolkningarnas": "ursprungsbefolkning",
    "ursprungsbefolkningars": "ursprungsbefolkning",
    "ursprungsbefolkningen": "ursprungsbefolkning",
    "ursprungsbefolkningens": "ursprungsbefolkning",
    "ursprungsbefolknings": "ursprungsbefolkning",
    "ursprungsbeteckningar": "ursprungsbeteckning",
    "ursprungsbeteckningarna": "ursprungsbeteckning",
    "ursprungsbeteckningarnas": "ursprungsbeteckning",
    "ursprungsbeteckningars": "ursprungsbeteckning",
    "ursprungsbeteckningen": "ursprungsbeteckning",
    "ursprungsbeteckningens": "ursprungsbeteckning",
    "ursprungsbetecknings": "ursprungsbeteckning",
    "ursprungsbevisen": "ursprungsbevis",
    "ursprungsbevisens": "ursprungsbevis",
    "ursprungsbeviset": "ursprungsbevis",
    "ursprungsbevisets": "ursprungsbevis",
    "ursprungscellen": "ursprungscell",
    "ursprungscellens": "ursprungscell",
    "ursprungsceller": "ursprungscell",
    "ursprungscellerna": "ursprungscell",
    "ursprungscellernas": "ursprungscell",
    "ursprungscellers": "ursprungscell",
    "ursprungscells": "ursprungscell",
    "ursprungscertifikaten": "ursprungscertifikat",
    "ursprungscertifikatens": "ursprungscertifikat",
    "ursprungscertifikatet": "ursprungscertifikat",
    "ursprungscertifikatets": "ursprungscertifikat",
    "ursprungscertifikats": "ursprungscertifikat",
    "ursprungsdokumentationen": "ursprungsdokumentation",
    "ursprungsdokumentationens": "ursprungsdokumentation",
    "ursprungsdokumentationer": "ursprungsdokumentation",
    "ursprungsdokumentationerna": "ursprungsdokumentation",
    "ursprungsdokumentationernas": "ursprungsdokumentation",
    "ursprungsdokumentationers": "ursprungsdokumentation",
    "ursprungsdokumentations": "ursprungsdokumentation",
    "ursprungslandet": "ursprungsland",
    "ursprungslandets": "ursprungsland",
    "ursprungslands": "ursprungsland",
    "ursprungslägen": "ursprungsläge",
    "ursprungslägena": "ursprungsläge",
    "ursprungslägenas": "ursprungsläge",
    "ursprungslägens": "ursprungsläge",
    "ursprungsläges": "ursprungsläge",
    "ursprungsläget": "ursprungsläge",
    "ursprungslägets": "ursprungsläge",
    "ursprungsländer": "ursprungsland",
    "ursprungsländerna": "ursprungsland",
    "ursprungsländernas": "ursprungsland",
    "ursprungsländers": "ursprungsland",
    "ursprungsmärk": "ursprungsmärka",
    "ursprungsmärkande": "ursprungsmärka",
    "ursprungsmärkanden": "ursprungsmärkande",
    "ursprungsmärkandena": "ursprungsmärkande",
    "ursprungsmärkandenas": "ursprungsmärkande",
    "ursprungsmärkandens": "ursprungsmärkande",
    "ursprungsmärkandes": "ursprungsmärkande",
    "ursprungsmärkandet": "ursprungsmärkande",
    "ursprungsmärkandets": "ursprungsmärkande",
    "ursprungsmärkas": "ursprungsmärka",
    "ursprungsmärker": "ursprungsmärka",
    "ursprungsmärkes": "ursprungsmärka",
    "ursprungsmärks": "ursprungsmärka",
    "ursprungsmärkt": "ursprungsmärka",
    "ursprungsmärkta": "ursprungsmärka",
    "ursprungsmärktas": "ursprungsmärka",
    "ursprungsmärkte": "ursprungsmärka",
    "ursprungsmärktes": "ursprungsmärka",
    "ursprungsmärkts": "ursprungsmärka",
    "ursprungsorten": "ursprungsort",
    "ursprungsortens": "ursprungsort",
    "ursprungsorter": "ursprungsort",
    "ursprungsorterna": "ursprungsort",
    "ursprungsorternas": "ursprungsort",
    "ursprungsorters": "ursprungsort",
    "ursprungsorts": "ursprungsort",
    "urspråken": "urspråk",
    "urspråkens": "urspråk",
    "urspråket": "urspråk",
    "urspråkets": "urspråk",
    "urspråks": "urspråk",
    "urspårade": "urspårad",
    "urspårades": "urspårad",
    "urspårads": "urspårad",
    "urspårat": "urspårad",
    "urspårats": "urspårad",
    "urspårningar": "urspårning",
    "urspårningarna": "urspårning",
    "urspårningarnas": "urspårning",
    "urspårningars": "urspårning",
    "urspårningen": "urspårning",
    "urspårningens": "urspårning",
    "urspårnings": "urspårning",
    "urstyva": "urstyv",
    "urstyvare": "urstyv",
    "urstyvares": "urstyv",
    "urstyvas": "urstyv",
    "urstyvast": "urstyv",
    "urstyvaste": "urstyv",
    "urstyvastes": "urstyv",
    "urstyvasts": "urstyv",
    "urstyve": "urstyv",
    "urstyves": "urstyv",
    "urstyvheten": "urstyvhet",
    "urstyvhetens": "urstyvhet",
    "urstyvhets": "urstyvhet",
    "urstyvs": "urstyv",
    "urstyvt": "urstyv",
    "urstyvts": "urstyv",
    "ursäkt": "ursäkta",
    "ursäktad": "ursäkta",
    "ursäktade": "ursäkta",
    "ursäktades": "ursäkta",
    "ursäktads": "ursäkta",
    "ursäktande": "ursäkta",
    "ursäktanden": "ursäktande",
    "ursäktandena": "ursäktande",
    "ursäktandenas": "ursäktande",
    "ursäktandens": "ursäktande",
    "ursäktandes": "ursäktande",
    "ursäktandet": "ursäktande",
    "ursäktandets": "ursäktande",
    "ursäktar": "ursäkta",
    "ursäktas": "ursäkta",
    "ursäktat": "ursäkta",
    "ursäktats": "ursäkta",
    "ursäkten": "ursäkt",
    "ursäktens": "ursäkt",
    "ursäkter": "ursäkt",
    "ursäkterna": "ursäkt",
    "ursäkternas": "ursäkt",
    "ursäkters": "ursäkt",
    "ursäktliga": "ursäktlig",
    "ursäktligare": "ursäktlig",
    "ursäktligares": "ursäktlig",
    "ursäktligas": "ursäktlig",
    "ursäktligast": "ursäktlig",
    "ursäktligaste": "ursäktlig",
    "ursäktligastes": "ursäktlig",
    "ursäktligasts": "ursäktlig",
    "ursäktlige": "ursäktlig",
    "ursäktliges": "ursäktlig",
    "ursäktligheten": "ursäktlighet",
    "ursäktlighetens": "ursäktlighet",
    "ursäktlighets": "ursäktlighet",
    "ursäktligs": "ursäktlig",
    "ursäktligt": "ursäktlig",
    "ursäktligts": "ursäktlig",
    "ursäkts": "ursäkt",
    "urtagbara": "urtagbar",
    "urtagbarare": "urtagbar",
    "urtagbarares": "urtagbar",
    "urtagbaras": "urtagbar",
    "urtagbarast": "urtagbar",
    "urtagbaraste": "urtagbar",
    "urtagbarastes": "urtagbar",
    "urtagbarasts": "urtagbar",
    "urtagbare": "urtagbar",
    "urtagbares": "urtagbar",
    "urtagbarheten": "urtagbarhet",
    "urtagbarhetens": "urtagbarhet",
    "urtagbarhets": "urtagbarhet",
    "urtagbars": "urtagbar",
    "urtagbart": "urtagbar",
    "urtagbarts": "urtagbar",
    "urtagen": "urtag",
    "urtagens": "urtagen",
    "urtaget": "urtagen",
    "urtagets": "urtagen",
    "urtagna": "urtagen",
    "urtagnare": "urtagen",
    "urtagnares": "urtagen",
    "urtagnas": "urtagen",
    "urtagnast": "urtagen",
    "urtagnaste": "urtagen",
    "urtagnastes": "urtagen",
    "urtagnasts": "urtagen",
    "urtagne": "urtagen",
    "urtagnes": "urtagen",
    "urtags": "urtag",
    "urtappningar": "urtappning",
    "urtappningarna": "urtappning",
    "urtappningarnas": "urtappning",
    "urtappningars": "urtappning",
    "urtappningen": "urtappning",
    "urtappningens": "urtappning",
    "urtappnings": "urtappning",
    "urtavel": "urtavla",
    "urtavlan": "urtavla",
    "urtavlans": "urtavla",
    "urtavlas": "urtavla",
    "urtavle": "urtavla",
    "urtavlor": "urtavla",
    "urtavlorna": "urtavla",
    "urtavlornas": "urtavla",
    "urtavlors": "urtavla",
    "urtexten": "urtext",
    "urtextens": "urtext",
    "urtexter": "urtext",
    "urtexterna": "urtext",
    "urtexternas": "urtext",
    "urtexters": "urtext",
    "urtexts": "urtext",
    "urtiden": "urtid",
    "urtidens": "urtid",
    "urtids": "urtid",
    "urtillstånden": "urtillstånd",
    "urtillståndens": "urtillstånd",
    "urtillståndet": "urtillstånd",
    "urtillståndets": "urtillstånd",
    "urtillstånds": "urtillstånd",
    "urtjusiga": "urtjusig",
    "urtjusigare": "urtjusig",
    "urtjusigares": "urtjusig",
    "urtjusigas": "urtjusig",
    "urtjusigast": "urtjusig",
    "urtjusigaste": "urtjusig",
    "urtjusigastes": "urtjusig",
    "urtjusigasts": "urtjusig",
    "urtjusige": "urtjusig",
    "urtjusiges": "urtjusig",
    "urtjusigheten": "urtjusighet",
    "urtjusighetens": "urtjusighet",
    "urtjusighets": "urtjusighet",
    "urtjusigs": "urtjusig",
    "urtjusigt": "urtjusig",
    "urtjusigts": "urtjusig",
    "urtvättade": "urtvättad",
    "urtvättades": "urtvättad",
    "urtvättads": "urtvättad",
    "urtvättat": "urtvättad",
    "urtvättats": "urtvättad",
    "urtypen": "urtyp",
    "urtypens": "urtyp",
    "urtyper": "urtyp",
    "urtyperna": "urtyp",
    "urtypernas": "urtyp",
    "urtypers": "urtyp",
    "urtyps": "urtyp",
    "uruguayanska": "uruguayansk",
    "uruguayanskan": "uruguayanska",
    "uruguayanskans": "uruguayanska",
    "uruguayanskare": "uruguayansk",
    "uruguayanskares": "uruguayansk",
    "uruguayanskas": "uruguayanska",
    "uruguayanskast": "uruguayansk",
    "uruguayanskaste": "uruguayansk",
    "uruguayanskastes": "uruguayansk",
    "uruguayanskasts": "uruguayansk",
    "uruguayanske": "uruguayanska",
    "uruguayanskes": "uruguayansk",
    "uruguayanskor": "uruguayanska",
    "uruguayanskorna": "uruguayanska",
    "uruguayanskornas": "uruguayanska",
    "uruguayanskors": "uruguayanska",
    "uruguayansks": "uruguayansk",
    "uruguayanskt": "uruguayansk",
    "uruguayanskts": "uruguayansk",
    "uruguayar": "uruguayare",
    "uruguayaren": "uruguayare",
    "uruguayarens": "uruguayare",
    "uruguayares": "uruguayare",
    "uruguayarna": "uruguayare",
    "uruguayarnas": "uruguayare",
    "uruguayska": "uruguaysk",
    "uruguayskare": "uruguaysk",
    "uruguayskares": "uruguaysk",
    "uruguayskas": "uruguaysk",
    "uruguayskast": "uruguaysk",
    "uruguayskaste": "uruguaysk",
    "uruguayskastes": "uruguaysk",
    "uruguayskasts": "uruguaysk",
    "uruguayske": "uruguaysk",
    "uruguayskes": "uruguaysk",
    "uruguaysks": "uruguaysk",
    "uruguayskt": "uruguaysk",
    "uruguayskts": "uruguaysk",
    "uruppför": "uruppföra",
    "uruppförande": "uruppföra",
    "uruppföranden": "uruppförande",
    "uruppförandena": "uruppförande",
    "uruppförandenas": "uruppförande",
    "uruppförandens": "uruppförande",
    "uruppförandes": "uruppförande",
    "uruppförandet": "uruppförande",
    "uruppförandets": "uruppförande",
    "uruppföras": "uruppföra",
    "uruppförd": "uruppföra",
    "uruppförda": "uruppföra",
    "uruppfördas": "uruppföra",
    "uruppförde": "uruppföra",
    "uruppfördes": "uruppföra",
    "uruppförds": "uruppföra",
    "uruppföres": "uruppföra",
    "uruppförs": "uruppföra",
    "uruppfört": "uruppföra",
    "uruppförts": "uruppföra",
    "urusels": "urusel",
    "uruselt": "urusel",
    "uruselts": "urusel",
    "urusla": "urusel",
    "uruslare": "urusel",
    "uruslares": "urusel",
    "uruslas": "urusel",
    "uruslast": "urusel",
    "uruslaste": "urusel",
    "uruslastes": "urusel",
    "uruslasts": "urusel",
    "urusle": "urusel",
    "urusles": "urusel",
    "urvalen": "urval",
    "urvalens": "urval",
    "urvalet": "urval",
    "urvalets": "urval",
    "urvals": "urval",
    "urvalsinstrumenten": "urvalsinstrument",
    "urvalsinstrumentens": "urvalsinstrument",
    "urvalsinstrumentet": "urvalsinstrument",
    "urvalsinstrumentets": "urvalsinstrument",
    "urvalsinstruments": "urvalsinstrument",
    "urvalsundersökningar": "urvalsundersökning",
    "urvalsundersökningarna": "urvalsundersökning",
    "urvalsundersökningarnas": "urvalsundersökning",
    "urvalsundersökningars": "urvalsundersökning",
    "urvalsundersökningen": "urvalsundersökning",
    "urvalsundersökningens": "urvalsundersökning",
    "urvalsundersöknings": "urvalsundersökning",
    "urvattnade": "urvattnad",
    "urvattnades": "urvattnad",
    "urvattnads": "urvattnad",
    "urvattnat": "urvattnad",
    "urvattnats": "urvattnad",
    "urvattningen": "urvattning",
    "urvattningens": "urvattning",
    "urvattnings": "urvattning",
    "urverken": "urverk",
    "urverkens": "urverk",
    "urverket": "urverk",
    "urverkets": "urverk",
    "urverks": "urverk",
    "urvuxens": "urvuxen",
    "urvuxet": "urvuxen",
    "urvuxets": "urvuxen",
    "urvuxna": "urvuxen",
    "urvuxnare": "urvuxen",
    "urvuxnares": "urvuxen",
    "urvuxnas": "urvuxen",
    "urvuxnast": "urvuxen",
    "urvuxnaste": "urvuxen",
    "urvuxnastes": "urvuxen",
    "urvuxnasts": "urvuxen",
    "urvuxne": "urvuxen",
    "urvuxnes": "urvuxen",
    "urväxta": "urväxt",
    "urväxtare": "urväxt",
    "urväxtares": "urväxt",
    "urväxtas": "urväxt",
    "urväxtast": "urväxt",
    "urväxtaste": "urväxt",
    "urväxtastes": "urväxt",
    "urväxtasts": "urväxt",
    "urväxte": "urväxt",
    "urväxtes": "urväxt",
    "urväxts": "urväxt",
    "uräldre": "urgammal",
    "uräldres": "urgammal",
    "uräldst": "urgammal",
    "uräldsta": "urgammal",
    "uräldstas": "urgammal",
    "uräldste": "urgammal",
    "uräldstes": "urgammal",
    "uräldsts": "urgammal",
    "uråldriga": "uråldrig",
    "uråldrigare": "uråldrig",
    "uråldrigares": "uråldrig",
    "uråldrigas": "uråldrig",
    "uråldrigast": "uråldrig",
    "uråldrigaste": "uråldrig",
    "uråldrigastes": "uråldrig",
    "uråldrigasts": "uråldrig",
    "uråldrige": "uråldrig",
    "uråldriges": "uråldrig",
    "uråldrigheten": "uråldrighet",
    "uråldrighetens": "uråldrighet",
    "uråldrighets": "uråldrighet",
    "uråldrigs": "uråldrig",
    "uråldrigt": "uråldrig",
    "uråldrigts": "uråldrig",
    "usansen": "usans",
    "usansens": "usans",
    "usanser": "usans",
    "usanserna": "usans",
    "usansernas": "usans",
    "usansers": "usans",
    "usb-minnen": "usb-minne",
    "usb-minnena": "usb-minne",
    "usb-minnenas": "usb-minne",
    "usb-minnens": "usb-minne",
    "usb-minnes": "usb-minne",
    "usb-minnet": "usb-minne",
    "usb-minnets": "usb-minne",
    "uschliga": "uschlig",
    "uschligare": "uschlig",
    "uschligares": "uschlig",
    "uschligas": "uschlig",
    "uschligast": "uschlig",
    "uschligaste": "uschlig",
    "uschligastes": "uschlig",
    "uschligasts": "uschlig",
    "uschlige": "uschlig",
    "uschliges": "uschlig",
    "uschligheten": "uschlighet",
    "uschlighetens": "uschlighet",
    "uschligheter": "uschlighet",
    "uschligheterna": "uschlighet",
    "uschligheternas": "uschlighet",
    "uschligheters": "uschlighet",
    "uschlighets": "uschlighet",
    "uschligs": "uschlig",
    "uschligt": "uschlig",
    "uschligts": "uschlig",
    "uselheten": "uselhet",
    "uselhetens": "uselhet",
    "uselheter": "uselhet",
    "uselheterna": "uselhet",
    "uselheternas": "uselhet",
    "uselheters": "uselhet",
    "uselhets": "uselhet",
    "usels": "usel",
    "uselt": "usel",
    "uselts": "usel",
    "usla": "usel",
    "uslare": "usel",
    "uslares": "usel",
    "uslas": "usel",
    "uslast": "usel",
    "uslaste": "usel",
    "uslastes": "usel",
    "uslasts": "usel",
    "usle": "usel",
    "usles": "usel",
    "usliga": "uslig",
    "usligare": "uslig",
    "usligares": "uslig",
    "usligas": "uslig",
    "usligast": "uslig",
    "usligaste": "uslig",
    "usligastes": "uslig",
    "usligasts": "uslig",
    "uslige": "uslig",
    "usliges": "uslig",
    "usligheten": "uslighet",
    "uslighetens": "uslighet",
    "usligheter": "uslighet",
    "usligheterna": "uslighet",
    "usligheternas": "uslighet",
    "usligheters": "uslighet",
    "uslighets": "uslighet",
    "usligs": "uslig",
    "usligt": "uslig",
    "usligts": "uslig",
    "uslingar": "usling",
    "uslingarna": "usling",
    "uslingarnas": "usling",
    "uslingars": "usling",
    "uslingen": "usling",
    "uslingens": "usling",
    "uslings": "usling",
    "usuella": "usuell",
    "usuellare": "usuell",
    "usuellares": "usuell",
    "usuellas": "usuell",
    "usuellast": "usuell",
    "usuellaste": "usuell",
    "usuellastes": "usuell",
    "usuellasts": "usuell",
    "usuelle": "usuell",
    "usuelles": "usuell",
    "usuells": "usuell",
    "usuellt": "usuell",
    "usuellts": "usuell",
    "usurpationen": "usurpation",
    "usurpationens": "usurpation",
    "usurpationer": "usurpation",
    "usurpationerna": "usurpation",
    "usurpationernas": "usurpation",
    "usurpationers": "usurpation",
    "usurpations": "usurpation",
    "usurpatorer": "usurpator",
    "usurpatorerna": "usurpator",
    "usurpatorernas": "usurpator",
    "usurpatorers": "usurpator",
    "usurpatorn": "usurpator",
    "usurpatorns": "usurpator",
    "usurpators": "usurpator",
    "usurperad": "usurpera",
    "usurperade": "usurpera",
    "usurperades": "usurpera",
    "usurperads": "usurpera",
    "usurperande": "usurpera",
    "usurperanden": "usurperande",
    "usurperandena": "usurperande",
    "usurperandenas": "usurperande",
    "usurperandens": "usurperande",
    "usurperandes": "usurperande",
    "usurperandet": "usurperande",
    "usurperandets": "usurperande",
    "usurperar": "usurpera",
    "usurperas": "usurpera",
    "usurperat": "usurpera",
    "usurperats": "usurpera",
    "usurperbara": "usurperbar",
    "usurperbarare": "usurperbar",
    "usurperbarares": "usurperbar",
    "usurperbaras": "usurperbar",
    "usurperbarast": "usurperbar",
    "usurperbaraste": "usurperbar",
    "usurperbarastes": "usurperbar",
    "usurperbarasts": "usurperbar",
    "usurperbare": "usurperbar",
    "usurperbares": "usurperbar",
    "usurperbarheten": "usurperbarhet",
    "usurperbarhetens": "usurperbarhet",
    "usurperbarhets": "usurperbarhet",
    "usurperbars": "usurperbar",
    "usurperbart": "usurperbar",
    "usurperbarts": "usurperbar",
    "usurperingar": "usurpering",
    "usurperingarna": "usurpering",
    "usurperingarnas": "usurpering",
    "usurperingars": "usurpering",
    "usurperingen": "usurpering",
    "usurperingens": "usurpering",
    "usurperings": "usurpering",
    "utackorderad": "utackordera",
    "utackorderade": "utackordera",
    "utackorderades": "utackordera",
    "utackorderads": "utackordera",
    "utackorderande": "utackordera",
    "utackorderanden": "utackorderande",
    "utackorderandena": "utackorderande",
    "utackorderandenas": "utackorderande",
    "utackorderandens": "utackorderande",
    "utackorderandes": "utackorderande",
    "utackorderandet": "utackorderande",
    "utackorderandets": "utackorderande",
    "utackorderar": "utackordera",
    "utackorderas": "utackordera",
    "utackorderat": "utackordera",
    "utackorderats": "utackordera",
    "utackorderbara": "utackorderbar",
    "utackorderbarare": "utackorderbar",
    "utackorderbarares": "utackorderbar",
    "utackorderbaras": "utackorderbar",
    "utackorderbarast": "utackorderbar",
    "utackorderbaraste": "utackorderbar",
    "utackorderbarastes": "utackorderbar",
    "utackorderbarasts": "utackorderbar",
    "utackorderbare": "utackorderbar",
    "utackorderbares": "utackorderbar",
    "utackorderbarheten": "utackorderbarhet",
    "utackorderbarhetens": "utackorderbarhet",
    "utackorderbarhets": "utackorderbarhet",
    "utackorderbars": "utackorderbar",
    "utackorderbart": "utackorderbar",
    "utackorderbarts": "utackorderbar",
    "utackorderingar": "utackordering",
    "utackorderingarna": "utackordering",
    "utackorderingarnas": "utackordering",
    "utackorderingars": "utackordering",
    "utackorderingen": "utackordering",
    "utackorderingens": "utackordering",
    "utackorderings": "utackordering",
    "utagerade": "utagerad",
    "utagerades": "utagerad",
    "utagerads": "utagerad",
    "utagerat": "utagerad",
    "utagerats": "utagerad",
    "utandades": "utandas",
    "utandats": "utandas",
    "utandningar": "utandning",
    "utandningarna": "utandning",
    "utandningarnas": "utandning",
    "utandningars": "utandning",
    "utandningen": "utandning",
    "utandningens": "utandning",
    "utandnings": "utandning",
    "utandningsluften": "utandningsluft",
    "utandningsluftens": "utandningsluft",
    "utandningslufts": "utandningsluft",
    "utandningsproven": "utandningsprov",
    "utandningsprovens": "utandningsprov",
    "utandningsprovet": "utandningsprov",
    "utandningsprovets": "utandningsprov",
    "utandningsprovs": "utandningsprov",
    "utanförskapen": "utanförskap",
    "utanförskapens": "utanförskap",
    "utanförskapet": "utanförskap",
    "utanförskapets": "utanförskap",
    "utanförskaps": "utanförskap",
    "utanläx": "utanläxa",
    "utanläxan": "utanläxa",
    "utanläxans": "utanläxa",
    "utanläxas": "utanläxa",
    "utanläxe": "utanläxa",
    "utanläxor": "utanläxa",
    "utanläxorna": "utanläxa",
    "utanläxornas": "utanläxa",
    "utanläxors": "utanläxa",
    "utannonserad": "utannonsera",
    "utannonserade": "utannonsera",
    "utannonserades": "utannonsera",
    "utannonserads": "utannonsera",
    "utannonserande": "utannonsera",
    "utannonseranden": "utannonserande",
    "utannonserandena": "utannonserande",
    "utannonserandenas": "utannonserande",
    "utannonserandens": "utannonserande",
    "utannonserandes": "utannonserande",
    "utannonserandet": "utannonserande",
    "utannonserandets": "utannonserande",
    "utannonserar": "utannonsera",
    "utannonseras": "utannonsera",
    "utannonserat": "utannonsera",
    "utannonserats": "utannonsera",
    "utannonserbara": "utannonserbar",
    "utannonserbarare": "utannonserbar",
    "utannonserbarares": "utannonserbar",
    "utannonserbaras": "utannonserbar",
    "utannonserbarast": "utannonserbar",
    "utannonserbaraste": "utannonserbar",
    "utannonserbarastes": "utannonserbar",
    "utannonserbarasts": "utannonserbar",
    "utannonserbare": "utannonserbar",
    "utannonserbares": "utannonserbar",
    "utannonserbarheten": "utannonserbarhet",
    "utannonserbarhetens": "utannonserbarhet",
    "utannonserbarhets": "utannonserbarhet",
    "utannonserbars": "utannonserbar",
    "utannonserbart": "utannonserbar",
    "utannonserbarts": "utannonserbar",
    "utannonseringar": "utannonsering",
    "utannonseringarna": "utannonsering",
    "utannonseringarnas": "utannonsering",
    "utannonseringars": "utannonsering",
    "utannonseringen": "utannonsering",
    "utannonseringens": "utannonsering",
    "utannonserings": "utannonsering",
    "utanordn": "utanordna",
    "utanordnad": "utanordna",
    "utanordnade": "utanordna",
    "utanordnades": "utanordna",
    "utanordnads": "utanordna",
    "utanordnande": "utanordna",
    "utanordnanden": "utanordnande",
    "utanordnandena": "utanordnande",
    "utanordnandenas": "utanordnande",
    "utanordnandens": "utanordnande",
    "utanordnandes": "utanordnande",
    "utanordnandet": "utanordnande",
    "utanordnandets": "utanordnande",
    "utanordnar": "utanordna",
    "utanordnas": "utanordna",
    "utanordnat": "utanordna",
    "utanordnats": "utanordna",
    "utanpåskjort": "utanpåskjorta",
    "utanpåskjortan": "utanpåskjorta",
    "utanpåskjortans": "utanpåskjorta",
    "utanpåskjortas": "utanpåskjorta",
    "utanpåskjorte": "utanpåskjorta",
    "utanpåskjortor": "utanpåskjorta",
    "utanpåskjortorna": "utanpåskjorta",
    "utanpåskjortornas": "utanpåskjorta",
    "utanpåskjortors": "utanpåskjorta",
    "utanpåskjorts": "utanpåskjorta",
    "utanpåskriften": "utanpåskrift",
    "utanpåskriftens": "utanpåskrift",
    "utanpåskrifter": "utanpåskrift",
    "utanpåskrifterna": "utanpåskrift",
    "utanpåskrifternas": "utanpåskrift",
    "utanpåskrifters": "utanpåskrift",
    "utanpåskrifts": "utanpåskrift",
    "utanskriften": "utanskrift",
    "utanskriftens": "utanskrift",
    "utanskrifter": "utanskrift",
    "utanskrifterna": "utanskrift",
    "utanskrifternas": "utanskrift",
    "utanskrifters": "utanskrift",
    "utanskrifts": "utanskrift",
    "utantillmässiga": "utantillmässig",
    "utantillmässigare": "utantillmässig",
    "utantillmässigares": "utantillmässig",
    "utantillmässigas": "utantillmässig",
    "utantillmässigast": "utantillmässig",
    "utantillmässigaste": "utantillmässig",
    "utantillmässigastes": "utantillmässig",
    "utantillmässigasts": "utantillmässig",
    "utantillmässige": "utantillmässig",
    "utantillmässiges": "utantillmässig",
    "utantillmässigs": "utantillmässig",
    "utantillmässigt": "utantillmässig",
    "utantillmässigts": "utantillmässig",
    "utantilläx": "utantilläxa",
    "utantilläxan": "utantilläxa",
    "utantilläxans": "utantilläxa",
    "utantilläxas": "utantilläxa",
    "utantilläxe": "utantilläxa",
    "utantilläxor": "utantilläxa",
    "utantilläxorna": "utantilläxa",
    "utantilläxornas": "utantilläxa",
    "utantilläxors": "utantilläxa",
    "utanverken": "utanverk",
    "utanverkens": "utanverk",
    "utanverket": "utanverk",
    "utanverkets": "utanverk",
    "utanverks": "utanverk",
    "utarbet": "utarbeta",
    "utarbetad": "utarbeta",
    "utarbetade": "utarbetad",
    "utarbetades": "utarbetad",
    "utarbetads": "utarbetad",
    "utarbetande": "utarbeta",
    "utarbetanden": "utarbetande",
    "utarbetandena": "utarbetande",
    "utarbetandenas": "utarbetande",
    "utarbetandens": "utarbetande",
    "utarbetandes": "utarbetande",
    "utarbetandet": "utarbetande",
    "utarbetandets": "utarbetande",
    "utarbetar": "utarbeta",
    "utarbetas": "utarbeta",
    "utarbetat": "utarbetad",
    "utarbetats": "utarbetad",
    "utarm": "utarma",
    "utarmad": "utarma",
    "utarmade": "utarmad",
    "utarmades": "utarmad",
    "utarmads": "utarmad",
    "utarmande": "utarma",
    "utarmanden": "utarmande",
    "utarmandena": "utarmande",
    "utarmandenas": "utarmande",
    "utarmandens": "utarmande",
    "utarmandes": "utarmande",
    "utarmandet": "utarmande",
    "utarmandets": "utarmande",
    "utarmar": "utarma",
    "utarmas": "utarma",
    "utarmat": "utarmad",
    "utarmats": "utarmad",
    "utarrenderad": "utarrendera",
    "utarrenderade": "utarrendera",
    "utarrenderades": "utarrendera",
    "utarrenderads": "utarrendera",
    "utarrenderande": "utarrendera",
    "utarrenderanden": "utarrenderande",
    "utarrenderandena": "utarrenderande",
    "utarrenderandenas": "utarrenderande",
    "utarrenderandens": "utarrenderande",
    "utarrenderandes": "utarrenderande",
    "utarrenderandet": "utarrenderande",
    "utarrenderandets": "utarrenderande",
    "utarrenderar": "utarrendera",
    "utarrenderas": "utarrendera",
    "utarrenderat": "utarrendera",
    "utarrenderats": "utarrendera",
    "utarrenderbara": "utarrenderbar",
    "utarrenderbarare": "utarrenderbar",
    "utarrenderbarares": "utarrenderbar",
    "utarrenderbaras": "utarrenderbar",
    "utarrenderbarast": "utarrenderbar",
    "utarrenderbaraste": "utarrenderbar",
    "utarrenderbarastes": "utarrenderbar",
    "utarrenderbarasts": "utarrenderbar",
    "utarrenderbare": "utarrenderbar",
    "utarrenderbares": "utarrenderbar",
    "utarrenderbarheten": "utarrenderbarhet",
    "utarrenderbarhetens": "utarrenderbarhet",
    "utarrenderbarhets": "utarrenderbarhet",
    "utarrenderbars": "utarrenderbar",
    "utarrenderbart": "utarrenderbar",
    "utarrenderbarts": "utarrenderbar",
    "utarrenderingar": "utarrendering",
    "utarrenderingarna": "utarrendering",
    "utarrenderingarnas": "utarrendering",
    "utarrenderingars": "utarrendering",
    "utarrenderingen": "utarrendering",
    "utarrenderingens": "utarrendering",
    "utarrenderings": "utarrendering",
    "utbalanserad": "utbalansera",
    "utbalanserade": "utbalansera",
    "utbalanserades": "utbalansera",
    "utbalanserads": "utbalansera",
    "utbalanserande": "utbalansera",
    "utbalanseranden": "utbalanserande",
    "utbalanserandena": "utbalanserande",
    "utbalanserandenas": "utbalanserande",
    "utbalanserandens": "utbalanserande",
    "utbalanserandes": "utbalanserande",
    "utbalanserandet": "utbalanserande",
    "utbalanserandets": "utbalanserande",
    "utbalanserar": "utbalansera",
    "utbalanseras": "utbalansera",
    "utbalanserat": "utbalansera",
    "utbalanserats": "utbalansera",
    "utbalanserbara": "utbalanserbar",
    "utbalanserbarare": "utbalanserbar",
    "utbalanserbarares": "utbalanserbar",
    "utbalanserbaras": "utbalanserbar",
    "utbalanserbarast": "utbalanserbar",
    "utbalanserbaraste": "utbalanserbar",
    "utbalanserbarastes": "utbalanserbar",
    "utbalanserbarasts": "utbalanserbar",
    "utbalanserbare": "utbalanserbar",
    "utbalanserbares": "utbalanserbar",
    "utbalanserbarheten": "utbalanserbarhet",
    "utbalanserbarhetens": "utbalanserbarhet",
    "utbalanserbarhets": "utbalanserbarhet",
    "utbalanserbars": "utbalanserbar",
    "utbalanserbart": "utbalanserbar",
    "utbalanserbarts": "utbalanserbar",
    "utbalanseringar": "utbalansering",
    "utbalanseringarna": "utbalansering",
    "utbalanseringarnas": "utbalansering",
    "utbalanseringars": "utbalansering",
    "utbalanseringen": "utbalansering",
    "utbalanseringens": "utbalansering",
    "utbalanserings": "utbalansering",
    "utbasunerad": "utbasunera",
    "utbasunerade": "utbasunera",
    "utbasunerades": "utbasunera",
    "utbasunerads": "utbasunera",
    "utbasunerande": "utbasunera",
    "utbasuneranden": "utbasunerande",
    "utbasunerandena": "utbasunerande",
    "utbasunerandenas": "utbasunerande",
    "utbasunerandens": "utbasunerande",
    "utbasunerandes": "utbasunerande",
    "utbasunerandet": "utbasunerande",
    "utbasunerandets": "utbasunerande",
    "utbasunerar": "utbasunera",
    "utbasuneras": "utbasunera",
    "utbasunerat": "utbasunera",
    "utbasunerats": "utbasunera",
    "utbasunerbara": "utbasunerbar",
    "utbasunerbarare": "utbasunerbar",
    "utbasunerbarares": "utbasunerbar",
    "utbasunerbaras": "utbasunerbar",
    "utbasunerbarast": "utbasunerbar",
    "utbasunerbaraste": "utbasunerbar",
    "utbasunerbarastes": "utbasunerbar",
    "utbasunerbarasts": "utbasunerbar",
    "utbasunerbare": "utbasunerbar",
    "utbasunerbares": "utbasunerbar",
    "utbasunerbarheten": "utbasunerbarhet",
    "utbasunerbarhetens": "utbasunerbarhet",
    "utbasunerbarhets": "utbasunerbarhet",
    "utbasunerbars": "utbasunerbar",
    "utbasunerbart": "utbasunerbar",
    "utbasunerbarts": "utbasunerbar",
    "utbasuneringar": "utbasunering",
    "utbasuneringarna": "utbasunering",
    "utbasuneringarnas": "utbasunering",
    "utbasuneringars": "utbasunering",
    "utbasuneringen": "utbasunering",
    "utbasuneringens": "utbasunering",
    "utbasunerings": "utbasunering",
    "utbekom": "utbekomma",
    "utbekomet": "utbekomma",
    "utbekomets": "utbekomma",
    "utbekommande": "utbekomma",
    "utbekommanden": "utbekommande",
    "utbekommandena": "utbekommande",
    "utbekommandenas": "utbekommande",
    "utbekommandens": "utbekommande",
    "utbekommandes": "utbekommande",
    "utbekommandet": "utbekommande",
    "utbekommandets": "utbekommande",
    "utbekommas": "utbekomma",
    "utbekomme": "utbekomma",
    "utbekommen": "utbekomma",
    "utbekommens": "utbekomma",
    "utbekommer": "utbekomma",
    "utbekommes": "utbekomma",
    "utbekommit": "utbekomma",
    "utbekommits": "utbekomma",
    "utbekomna": "utbekomma",
    "utbekomnas": "utbekomma",
    "utbekomne": "utbekomma",
    "utbekomnes": "utbekomma",
    "utbekoms": "utbekomma",
    "utbetal": "utbetala",
    "utbetalad": "utbetala",
    "utbetalade": "utbetala",
    "utbetalades": "utbetala",
    "utbetalads": "utbetala",
    "utbetalande": "utbetala",
    "utbetalanden": "utbetalande",
    "utbetalandena": "utbetalande",
    "utbetalandenas": "utbetalande",
    "utbetalandens": "utbetalande",
    "utbetalandes": "utbetalande",
    "utbetalandet": "utbetalande",
    "utbetalandets": "utbetalande",
    "utbetalar": "utbetala",
    "utbetalas": "utbetala",
    "utbetalat": "utbetala",
    "utbetalats": "utbetala",
    "utbetald": "utbetala",
    "utbetalda": "utbetala",
    "utbetaldas": "utbetala",
    "utbetalde": "utbetala",
    "utbetaldes": "utbetala",
    "utbetalds": "utbetala",
    "utbetalningar": "utbetalning",
    "utbetalningarna": "utbetalning",
    "utbetalningarnas": "utbetalning",
    "utbetalningars": "utbetalning",
    "utbetalningen": "utbetalning",
    "utbetalningens": "utbetalning",
    "utbetalnings": "utbetalning",
    "utbetalningskorten": "utbetalningskort",
    "utbetalningskortens": "utbetalningskort",
    "utbetalningskortet": "utbetalningskort",
    "utbetalningskortets": "utbetalningskort",
    "utbetalningskorts": "utbetalningskort",
    "utbetalningsordern": "utbetalningsorder",
    "utbetalningsorderna": "utbetalningsorder",
    "utbetalningsordernas": "utbetalningsorder",
    "utbetalningsorderns": "utbetalningsorder",
    "utbetalningsorders": "utbetalningsorder",
    "utbetalningsordrar": "utbetalningsorder",
    "utbetalningsordrarna": "utbetalningsorder",
    "utbetalningsordrarnas": "utbetalningsorder",
    "utbetalningsordrars": "utbetalningsorder",
    "utbetalt": "utbetala",
    "utbetalte": "utbetala",
    "utbetaltes": "utbetala",
    "utbetalts": "utbetala",
    "utbild": "utbilda",
    "utbildad": "utbilda",
    "utbildade": "utbilda",
    "utbildades": "utbilda",
    "utbildads": "utbilda",
    "utbildande": "utbilda",
    "utbildanden": "utbildande",
    "utbildandena": "utbildande",
    "utbildandenas": "utbildande",
    "utbildandens": "utbildande",
    "utbildandes": "utbildande",
    "utbildandet": "utbildande",
    "utbildandets": "utbildande",
    "utbildar": "utbilda",
    "utbildas": "utbilda",
    "utbildat": "utbilda",
    "utbildats": "utbilda",
    "utbildningar": "utbildning",
    "utbildningarna": "utbildning",
    "utbildningarnas": "utbildning",
    "utbildningars": "utbildning",
    "utbildningen": "utbildning",
    "utbildningens": "utbildning",
    "utbildnings": "utbildning",
    "utbildningsbidragen": "utbildningsbidrag",
    "utbildningsbidragens": "utbildningsbidrag",
    "utbildningsbidraget": "utbildningsbidrag",
    "utbildningsbidragets": "utbildningsbidrag",
    "utbildningsbidrags": "utbildningsbidrag",
    "utbildningsdepartementen": "utbildningsdepartement",
    "utbildningsdepartementens": "utbildningsdepartement",
    "utbildningsdepartementet": "utbildningsdepartement",
    "utbildningsdepartementets": "utbildningsdepartement",
    "utbildningsdepartements": "utbildningsdepartement",
    "utbildningsexplosionen": "utbildningsexplosion",
    "utbildningsexplosionens": "utbildningsexplosion",
    "utbildningsexplosioner": "utbildningsexplosion",
    "utbildningsexplosionerna": "utbildningsexplosion",
    "utbildningsexplosionernas": "utbildningsexplosion",
    "utbildningsexplosioners": "utbildningsexplosion",
    "utbildningsexplosions": "utbildningsexplosion",
    "utbildningsgapen": "utbildningsgap",
    "utbildningsgapens": "utbildningsgap",
    "utbildningsgapet": "utbildningsgap",
    "utbildningsgapets": "utbildningsgap",
    "utbildningsgaps": "utbildningsgap",
    "utbildningsklyftan": "utbildningsklyfta",
    "utbildningsklyftans": "utbildningsklyfta",
    "utbildningsklyftas": "utbildningsklyfta",
    "utbildningsklyfte": "utbildningsklyfta",
    "utbildningsklyftor": "utbildningsklyfta",
    "utbildningsklyftorna": "utbildningsklyfta",
    "utbildningsklyftornas": "utbildningsklyfta",
    "utbildningsklyftors": "utbildningsklyfta",
    "utbildningslinjen": "utbildningslinje",
    "utbildningslinjens": "utbildningslinje",
    "utbildningslinjer": "utbildningslinje",
    "utbildningslinjerna": "utbildningslinje",
    "utbildningslinjernas": "utbildningslinje",
    "utbildningslinjers": "utbildningslinje",
    "utbildningslinjes": "utbildningslinje",
    "utbildningsmässiga": "utbildningsmässig",
    "utbildningsmässigare": "utbildningsmässig",
    "utbildningsmässigares": "utbildningsmässig",
    "utbildningsmässigas": "utbildningsmässig",
    "utbildningsmässigast": "utbildningsmässig",
    "utbildningsmässigaste": "utbildningsmässig",
    "utbildningsmässigastes": "utbildningsmässig",
    "utbildningsmässigasts": "utbildningsmässig",
    "utbildningsmässige": "utbildningsmässig",
    "utbildningsmässiges": "utbildningsmässig",
    "utbildningsmässigs": "utbildningsmässig",
    "utbildningsmässigt": "utbildningsmässig",
    "utbildningsmässigts": "utbildningsmässig",
    "utbildningsnivåer": "utbildningsnivå",
    "utbildningsnivåerna": "utbildningsnivå",
    "utbildningsnivåernas": "utbildningsnivå",
    "utbildningsnivåers": "utbildningsnivå",
    "utbildningsnivån": "utbildningsnivå",
    "utbildningsnivåns": "utbildningsnivå",
    "utbildningsnivås": "utbildningsnivå",
    "utbildningspolitiken": "utbildningspolitik",
    "utbildningspolitikens": "utbildningspolitik",
    "utbildningspolitiks": "utbildningspolitik",
    "utbildningspolitiska": "utbildningspolitisk",
    "utbildningspolitiskas": "utbildningspolitisk",
    "utbildningspolitiske": "utbildningspolitisk",
    "utbildningspolitiskes": "utbildningspolitisk",
    "utbildningspolitisks": "utbildningspolitisk",
    "utbildningspolitiskt": "utbildningspolitisk",
    "utbildningspolitiskts": "utbildningspolitisk",
    "utbildningsprogrammen": "utbildningsprogram",
    "utbildningsprogrammens": "utbildningsprogram",
    "utbildningsprogrammet": "utbildningsprogram",
    "utbildningsprogrammets": "utbildningsprogram",
    "utbildningsprograms": "utbildningsprogram",
    "utbildningssystemen": "utbildningssystem",
    "utbildningssystemens": "utbildningssystem",
    "utbildningssystemet": "utbildningssystem",
    "utbildningssystemets": "utbildningssystem",
    "utbildningssystems": "utbildningssystem",
    "utbildningstiden": "utbildningstid",
    "utbildningstidens": "utbildningstid",
    "utbildningstider": "utbildningstid",
    "utbildningstiderna": "utbildningstid",
    "utbildningstidernas": "utbildningstid",
    "utbildningstiders": "utbildningstid",
    "utbildningstids": "utbildningstid",
    "utbildningsvägar": "utbildningsväg",
    "utbildningsvägarna": "utbildningsväg",
    "utbildningsvägarnas": "utbildningsväg",
    "utbildningsvägars": "utbildningsväg",
    "utbildningsvägen": "utbildningsväg",
    "utbildningsvägens": "utbildningsväg",
    "utbildningsvägs": "utbildningsväg",
    "utbjud": "utbjuda",
    "utbjudande": "utbjuda",
    "utbjudanden": "utbjudande",
    "utbjudandena": "utbjudande",
    "utbjudandenas": "utbjudande",
    "utbjudandens": "utbjudande",
    "utbjudandes": "utbjudande",
    "utbjudandet": "utbjudande",
    "utbjudandets": "utbjudande",
    "utbjudas": "utbjuda",
    "utbjude": "utbjuda",
    "utbjuden": "utbjuda",
    "utbjudens": "utbjuda",
    "utbjuder": "utbjuda",
    "utbjudes": "utbjuda",
    "utbjudet": "utbjuda",
    "utbjudets": "utbjuda",
    "utbjudit": "utbjuda",
    "utbjudits": "utbjuda",
    "utbjudna": "utbjuda",
    "utbjudnas": "utbjuda",
    "utbjudne": "utbjuda",
    "utbjudnes": "utbjuda",
    "utbjuds": "utbjuda",
    "utbjöd": "utbjuda",
    "utbjöde": "utbjuda",
    "utbjödes": "utbjuda",
    "utbjöds": "utbjuda",
    "utblickar": "utblick",
    "utblickarna": "utblick",
    "utblickarnas": "utblick",
    "utblickars": "utblick",
    "utblicken": "utblick",
    "utblickens": "utblick",
    "utblicks": "utblick",
    "utblommade": "utblommad",
    "utblommades": "utblommad",
    "utblommads": "utblommad",
    "utblommat": "utblommad",
    "utblommats": "utblommad",
    "utblottade": "utblottad",
    "utblottades": "utblottad",
    "utblottads": "utblottad",
    "utblottat": "utblottad",
    "utblottats": "utblottad",
    "utblåsningar": "utblåsning",
    "utblåsningarna": "utblåsning",
    "utblåsningarnas": "utblåsning",
    "utblåsningars": "utblåsning",
    "utblåsningen": "utblåsning",
    "utblåsningens": "utblåsning",
    "utblåsnings": "utblåsning",
    "utbombad": "utbomba",
    "utbombade": "utbomba",
    "utbombades": "utbomba",
    "utbombads": "utbomba",
    "utbombande": "utbomba",
    "utbombanden": "utbombande",
    "utbombandena": "utbombande",
    "utbombandenas": "utbombande",
    "utbombandens": "utbombande",
    "utbombandes": "utbombande",
    "utbombandet": "utbombande",
    "utbombandets": "utbombande",
    "utbombar": "utbomba",
    "utbombas": "utbomba",
    "utbombat": "utbomba",
    "utbombats": "utbomba",
    "utbon": "utbo",
    "utbons": "utbo",
    "utbor": "utbo",
    "utbordar": "utbordare",
    "utbordaren": "utbordare",
    "utbordarens": "utbordare",
    "utbordares": "utbordare",
    "utbordarna": "utbordare",
    "utbordarnas": "utbordare",
    "utborna": "utbo",
    "utbornas": "utbo",
    "utbors": "utbo",
    "utbos": "utbo",
    "utbragt": "utbringa",
    "utbragte": "utbringa",
    "utbragtes": "utbringa",
    "utbragts": "utbringa",
    "utbrast": "utbrista",
    "utbrasts": "utbrista",
    "utbred": "utbre",
    "utbreda": "utbre",
    "utbredande": "utbre",
    "utbredanden": "utbredande",
    "utbredandena": "utbredande",
    "utbredandenas": "utbredande",
    "utbredandens": "utbredande",
    "utbredandes": "utbredande",
    "utbredandet": "utbredande",
    "utbredandets": "utbredande",
    "utbredas": "utbre",
    "utbredd": "utbre",
    "utbredda": "utbredd",
    "utbreddare": "utbredd",
    "utbreddares": "utbredd",
    "utbreddas": "utbredd",
    "utbreddast": "utbredd",
    "utbreddaste": "utbredd",
    "utbreddastes": "utbredd",
    "utbreddasts": "utbredd",
    "utbredde": "utbredd",
    "utbreddes": "utbredd",
    "utbreddheten": "utbreddhet",
    "utbreddhetens": "utbreddhet",
    "utbreddhets": "utbreddhet",
    "utbredds": "utbredd",
    "utbreder": "utbre",
    "utbredningar": "utbredning",
    "utbredningarna": "utbredning",
    "utbredningarnas": "utbredning",
    "utbredningars": "utbredning",
    "utbredningen": "utbredning",
    "utbredningens": "utbredning",
    "utbrednings": "utbredning",
    "utbredningscentra": "utbredningscentrum",
    "utbredningscentrana": "utbredningscentrum",
    "utbredningscentranas": "utbredningscentrum",
    "utbredningscentras": "utbredningscentrum",
    "utbredningscentrumen": "utbredningscentrum",
    "utbredningscentrumens": "utbredningscentrum",
    "utbredningscentrumet": "utbredningscentrum",
    "utbredningscentrumets": "utbredningscentrum",
    "utbredningscentrums": "utbredningscentrum",
    "utbredningsområden": "utbredningsområde",
    "utbredningsområdena": "utbredningsområde",
    "utbredningsområdenas": "utbredningsområde",
    "utbredningsområdens": "utbredningsområde",
    "utbredningsområdes": "utbredningsområde",
    "utbredningsområdet": "utbredningsområde",
    "utbredningsområdets": "utbredningsområde",
    "utbreds": "utbre",
    "utbreende": "utbre",
    "utbreenden": "utbreende",
    "utbreendena": "utbreende",
    "utbreendenas": "utbreende",
    "utbreendens": "utbreende",
    "utbreendes": "utbreende",
    "utbreendet": "utbreende",
    "utbreendets": "utbreende",
    "utbrer": "utbre",
    "utbres": "utbre",
    "utbrett": "utbredd",
    "utbretts": "utbredd",
    "utbring": "utbringa",
    "utbringad": "utbringa",
    "utbringade": "utbringa",
    "utbringades": "utbringa",
    "utbringads": "utbringa",
    "utbringande": "utbringa",
    "utbringanden": "utbringande",
    "utbringandena": "utbringande",
    "utbringandenas": "utbringande",
    "utbringandens": "utbringande",
    "utbringandes": "utbringande",
    "utbringandet": "utbringande",
    "utbringandets": "utbringande",
    "utbringar": "utbringa",
    "utbringas": "utbringa",
    "utbringat": "utbringa",
    "utbringats": "utbringa",
    "utbrist": "utbrista",
    "utbristande": "utbrista",
    "utbristanden": "utbristande",
    "utbristandena": "utbristande",
    "utbristandenas": "utbristande",
    "utbristandens": "utbristande",
    "utbristandes": "utbristande",
    "utbristandet": "utbristande",
    "utbristandets": "utbristande",
    "utbristas": "utbrista",
    "utbriste": "utbrista",
    "utbrister": "utbrista",
    "utbristes": "utbrista",
    "utbrists": "utbrista",
    "utbroderad": "utbrodera",
    "utbroderade": "utbrodera",
    "utbroderades": "utbrodera",
    "utbroderads": "utbrodera",
    "utbroderande": "utbrodera",
    "utbroderanden": "utbroderande",
    "utbroderandena": "utbroderande",
    "utbroderandenas": "utbroderande",
    "utbroderandens": "utbroderande",
    "utbroderandes": "utbroderande",
    "utbroderandet": "utbroderande",
    "utbroderandets": "utbroderande",
    "utbroderar": "utbrodera",
    "utbroderas": "utbrodera",
    "utbroderat": "utbrodera",
    "utbroderats": "utbrodera",
    "utbroderbara": "utbroderbar",
    "utbroderbarare": "utbroderbar",
    "utbroderbarares": "utbroderbar",
    "utbroderbaras": "utbroderbar",
    "utbroderbarast": "utbroderbar",
    "utbroderbaraste": "utbroderbar",
    "utbroderbarastes": "utbroderbar",
    "utbroderbarasts": "utbroderbar",
    "utbroderbare": "utbroderbar",
    "utbroderbares": "utbroderbar",
    "utbroderbarheten": "utbroderbarhet",
    "utbroderbarhetens": "utbroderbarhet",
    "utbroderbarhets": "utbroderbarhet",
    "utbroderbars": "utbroderbar",
    "utbroderbart": "utbroderbar",
    "utbroderbarts": "utbroderbar",
    "utbroderingar": "utbrodering",
    "utbroderingarna": "utbrodering",
    "utbroderingarnas": "utbrodering",
    "utbroderingars": "utbrodering",
    "utbroderingen": "utbrodering",
    "utbroderingens": "utbrodering",
    "utbroderings": "utbrodering",
    "utbrotten": "utbrott",
    "utbrottens": "utbrott",
    "utbrottet": "utbrott",
    "utbrottets": "utbrott",
    "utbrotts": "utbrott",
    "utbrunna": "utbrunnen",
    "utbrunnare": "utbrunnen",
    "utbrunnares": "utbrunnen",
    "utbrunnas": "utbrunnen",
    "utbrunnast": "utbrunnen",
    "utbrunnaste": "utbrunnen",
    "utbrunnastes": "utbrunnen",
    "utbrunnasts": "utbrunnen",
    "utbrunne": "utbrunnen",
    "utbrunnens": "utbrunnen",
    "utbrunnes": "utbrunnen",
    "utbrunnet": "utbrunnen",
    "utbrunnets": "utbrunnen",
    "utbruste": "utbrista",
    "utbrusten": "utbrista",
    "utbrustens": "utbrista",
    "utbrustes": "utbrista",
    "utbrustet": "utbrista",
    "utbrustets": "utbrista",
    "utbrustit": "utbrista",
    "utbrustits": "utbrista",
    "utbrustna": "utbrista",
    "utbrustnas": "utbrista",
    "utbrustne": "utbrista",
    "utbrustnes": "utbrista",
    "utbruten": "utbryta",
    "utbrutens": "utbryta",
    "utbrutet": "utbryta",
    "utbrutets": "utbryta",
    "utbrutit": "utbryta",
    "utbrutits": "utbryta",
    "utbrutna": "utbryta",
    "utbrutnas": "utbryta",
    "utbrutne": "utbryta",
    "utbrutnes": "utbryta",
    "utbryt": "utbryta",
    "utbrytande": "utbryta",
    "utbrytanden": "utbrytande",
    "utbrytandena": "utbrytande",
    "utbrytandenas": "utbrytande",
    "utbrytandens": "utbrytande",
    "utbrytandes": "utbrytande",
    "utbrytandet": "utbrytande",
    "utbrytandets": "utbrytande",
    "utbrytar": "utbrytare",
    "utbrytaren": "utbrytare",
    "utbrytarens": "utbrytare",
    "utbrytares": "utbrytare",
    "utbrytarkungar": "utbrytarkung",
    "utbrytarkungarna": "utbrytarkung",
    "utbrytarkungarnas": "utbrytarkung",
    "utbrytarkungars": "utbrytarkung",
    "utbrytarkungen": "utbrytarkung",
    "utbrytarkungens": "utbrytarkung",
    "utbrytarkungs": "utbrytarkung",
    "utbrytarna": "utbrytare",
    "utbrytarnas": "utbrytare",
    "utbrytarregionen": "utbrytarregion",
    "utbrytarregionens": "utbrytarregion",
    "utbrytarregioner": "utbrytarregion",
    "utbrytarregionerna": "utbrytarregion",
    "utbrytarregionernas": "utbrytarregion",
    "utbrytarregioners": "utbrytarregion",
    "utbrytarregions": "utbrytarregion",
    "utbrytarstaten": "utbrytarstat",
    "utbrytarstatens": "utbrytarstat",
    "utbrytarstater": "utbrytarstat",
    "utbrytarstaterna": "utbrytarstat",
    "utbrytarstaternas": "utbrytarstat",
    "utbrytarstaters": "utbrytarstat",
    "utbrytarstats": "utbrytarstat",
    "utbrytas": "utbryta",
    "utbryte": "utbryta",
    "utbryter": "utbryta",
    "utbrytes": "utbryta",
    "utbrytningar": "utbrytning",
    "utbrytningarna": "utbrytning",
    "utbrytningarnas": "utbrytning",
    "utbrytningars": "utbrytning",
    "utbrytningen": "utbrytning",
    "utbrytningens": "utbrytning",
    "utbrytnings": "utbrytning",
    "utbryts": "utbryta",
    "utbrända": "utbränd",
    "utbrändare": "utbränd",
    "utbrändares": "utbränd",
    "utbrändas": "utbränd",
    "utbrändast": "utbränd",
    "utbrändaste": "utbränd",
    "utbrändastes": "utbränd",
    "utbrändasts": "utbränd",
    "utbrände": "utbränd",
    "utbrändes": "utbränd",
    "utbrändheten": "utbrändhet",
    "utbrändhetens": "utbrändhet",
    "utbrändhets": "utbrändhet",
    "utbränds": "utbränd",
    "utbränt": "utbränd",
    "utbränts": "utbränd",
    "utbröt": "utbryta",
    "utbröte": "utbryta",
    "utbrötes": "utbryta",
    "utbröts": "utbryta",
    "utbu": "utbua",
    "utbuad": "utbua",
    "utbuade": "utbuad",
    "utbuades": "utbuad",
    "utbuads": "utbuad",
    "utbuande": "utbua",
    "utbuanden": "utbuande",
    "utbuandena": "utbuande",
    "utbuandenas": "utbuande",
    "utbuandens": "utbuande",
    "utbuandes": "utbuande",
    "utbuandet": "utbuande",
    "utbuandets": "utbuande",
    "utbuar": "utbua",
    "utbuas": "utbua",
    "utbuat": "utbuad",
    "utbuats": "utbuad",
    "utbuden": "utbud",
    "utbudens": "utbud",
    "utbudet": "utbud",
    "utbudets": "utbud",
    "utbuds": "utbud",
    "utbudspolitiken": "utbudspolitik",
    "utbudspolitikens": "utbudspolitik",
    "utbudspolitiks": "utbudspolitik",
    "utbuktade": "utbuktad",
    "utbuktades": "utbuktad",
    "utbuktads": "utbuktad",
    "utbuktat": "utbuktad",
    "utbuktats": "utbuktad",
    "utbuktningar": "utbuktning",
    "utbuktningarna": "utbuktning",
    "utbuktningarnas": "utbuktning",
    "utbuktningars": "utbuktning",
    "utbuktningen": "utbuktning",
    "utbuktningens": "utbuktning",
    "utbuktnings": "utbuktning",
    "utbygg": "utbygga",
    "utbyggande": "utbygga",
    "utbygganden": "utbyggande",
    "utbyggandena": "utbyggande",
    "utbyggandenas": "utbyggande",
    "utbyggandens": "utbyggande",
    "utbyggandes": "utbyggande",
    "utbyggandet": "utbyggande",
    "utbyggandets": "utbyggande",
    "utbyggas": "utbygga",
    "utbyggbara": "utbyggbar",
    "utbyggbarare": "utbyggbar",
    "utbyggbarares": "utbyggbar",
    "utbyggbaras": "utbyggbar",
    "utbyggbarast": "utbyggbar",
    "utbyggbaraste": "utbyggbar",
    "utbyggbarastes": "utbyggbar",
    "utbyggbarasts": "utbyggbar",
    "utbyggbare": "utbyggbar",
    "utbyggbares": "utbyggbar",
    "utbyggbarheten": "utbyggbarhet",
    "utbyggbarhetens": "utbyggbarhet",
    "utbyggbarhets": "utbyggbarhet",
    "utbyggbars": "utbyggbar",
    "utbyggbart": "utbyggbar",
    "utbyggbarts": "utbyggbar",
    "utbyggd": "utbygga",
    "utbyggda": "utbyggd",
    "utbyggdare": "utbyggd",
    "utbyggdares": "utbyggd",
    "utbyggdas": "utbyggd",
    "utbyggdast": "utbyggd",
    "utbyggdaste": "utbyggd",
    "utbyggdastes": "utbyggd",
    "utbyggdasts": "utbyggd",
    "utbyggde": "utbyggd",
    "utbyggdes": "utbyggd",
    "utbyggds": "utbyggd",
    "utbyggen": "utbygge",
    "utbyggena": "utbygge",
    "utbyggenas": "utbygge",
    "utbyggens": "utbygge",
    "utbygger": "utbygga",
    "utbygges": "utbygge",
    "utbygget": "utbygge",
    "utbyggets": "utbygge",
    "utbyggnaden": "utbyggnad",
    "utbyggnadens": "utbyggnad",
    "utbyggnader": "utbyggnad",
    "utbyggnaderna": "utbyggnad",
    "utbyggnadernas": "utbyggnad",
    "utbyggnaders": "utbyggnad",
    "utbyggnads": "utbyggnad",
    "utbyggs": "utbygga",
    "utbyggt": "utbyggd",
    "utbyggts": "utbyggd",
    "utbyt": "utbyta",
    "utbytande": "utbyta",
    "utbytanden": "utbytande",
    "utbytandena": "utbytande",
    "utbytandenas": "utbytande",
    "utbytandens": "utbytande",
    "utbytandes": "utbytande",
    "utbytandet": "utbytande",
    "utbytandets": "utbytande",
    "utbytas": "utbyta",
    "utbytbara": "utbytbar",
    "utbytbarare": "utbytbar",
    "utbytbarares": "utbytbar",
    "utbytbaras": "utbytbar",
    "utbytbarast": "utbytbar",
    "utbytbaraste": "utbytbar",
    "utbytbarastes": "utbytbar",
    "utbytbarasts": "utbytbar",
    "utbytbare": "utbytbar",
    "utbytbares": "utbytbar",
    "utbytbarheten": "utbytbarhet",
    "utbytbarhetens": "utbytbarhet",
    "utbytbarheter": "utbytbarhet",
    "utbytbarheterna": "utbytbarhet",
    "utbytbarheternas": "utbytbarhet",
    "utbytbarheters": "utbytbarhet",
    "utbytbarhets": "utbytbarhet",
    "utbytbars": "utbytbar",
    "utbytbart": "utbytbar",
    "utbytbarts": "utbytbar",
    "utbyten": "utbyte",
    "utbytena": "utbyte",
    "utbytenas": "utbyte",
    "utbytens": "utbyte",
    "utbyter": "utbyta",
    "utbytes": "utbyte",
    "utbytet": "utbyte",
    "utbytets": "utbyte",
    "utbyts": "utbyta",
    "utbytt": "utbyta",
    "utbytta": "utbyta",
    "utbyttas": "utbyta",
    "utbytte": "utbyta",
    "utbyttes": "utbyta",
    "utbytts": "utbyta",
    "utbäringar": "utbäring",
    "utbäringarna": "utbäring",
    "utbäringarnas": "utbäring",
    "utbäringars": "utbäring",
    "utbäringen": "utbäring",
    "utbäringens": "utbäring",
    "utbärings": "utbäring",
    "utbärningar": "utbärning",
    "utbärningarna": "utbärning",
    "utbärningarnas": "utbärning",
    "utbärningars": "utbärning",
    "utbärningen": "utbärning",
    "utbärningens": "utbärning",
    "utbärnings": "utbärning",
    "utbölingar": "utböling",
    "utbölingarna": "utböling",
    "utbölingarnas": "utböling",
    "utbölingars": "utböling",
    "utbölingen": "utböling",
    "utbölingens": "utböling",
    "utbölings": "utböling",
    "utbördingar": "utbörding",
    "utbördingarna": "utbörding",
    "utbördingarnas": "utbörding",
    "utbördingars": "utbörding",
    "utbördingen": "utbörding",
    "utbördingens": "utbörding",
    "utbördings": "utbörding",
    "utdebiterad": "utdebitera",
    "utdebiterade": "utdebitera",
    "utdebiterades": "utdebitera",
    "utdebiterads": "utdebitera",
    "utdebiterande": "utdebitera",
    "utdebiteranden": "utdebiterande",
    "utdebiterandena": "utdebiterande",
    "utdebiterandenas": "utdebiterande",
    "utdebiterandens": "utdebiterande",
    "utdebiterandes": "utdebiterande",
    "utdebiterandet": "utdebiterande",
    "utdebiterandets": "utdebiterande",
    "utdebiterar": "utdebitera",
    "utdebiteras": "utdebitera",
    "utdebiterat": "utdebitera",
    "utdebiterats": "utdebitera",
    "utdebiterbara": "utdebiterbar",
    "utdebiterbarare": "utdebiterbar",
    "utdebiterbarares": "utdebiterbar",
    "utdebiterbaras": "utdebiterbar",
    "utdebiterbarast": "utdebiterbar",
    "utdebiterbaraste": "utdebiterbar",
    "utdebiterbarastes": "utdebiterbar",
    "utdebiterbarasts": "utdebiterbar",
    "utdebiterbare": "utdebiterbar",
    "utdebiterbares": "utdebiterbar",
    "utdebiterbarheten": "utdebiterbarhet",
    "utdebiterbarhetens": "utdebiterbarhet",
    "utdebiterbarhets": "utdebiterbarhet",
    "utdebiterbars": "utdebiterbar",
    "utdebiterbart": "utdebiterbar",
    "utdebiterbarts": "utdebiterbar",
    "utdebiteringar": "utdebitering",
    "utdebiteringarna": "utdebitering",
    "utdebiteringarnas": "utdebitering",
    "utdebiteringars": "utdebitering",
    "utdebiteringen": "utdebitering",
    "utdebiteringens": "utdebitering",
    "utdebiterings": "utdebitering",
    "utdel": "utdela",
    "utdelad": "utdela",
    "utdelade": "utdela",
    "utdelades": "utdela",
    "utdelads": "utdela",
    "utdelande": "utdela",
    "utdelanden": "utdelande",
    "utdelandena": "utdelande",
    "utdelandenas": "utdelande",
    "utdelandens": "utdelande",
    "utdelandes": "utdelande",
    "utdelandet": "utdelande",
    "utdelandets": "utdelande",
    "utdelar": "utdela",
    "utdelas": "utdela",
    "utdelat": "utdela",
    "utdelats": "utdela",
    "utdelningar": "utdelning",
    "utdelningarna": "utdelning",
    "utdelningarnas": "utdelning",
    "utdelningars": "utdelning",
    "utdelningen": "utdelning",
    "utdelningens": "utdelning",
    "utdelnings": "utdelning",
    "utdik": "utdika",
    "utdikad": "utdika",
    "utdikade": "utdika",
    "utdikades": "utdika",
    "utdikads": "utdika",
    "utdikande": "utdika",
    "utdikanden": "utdikande",
    "utdikandena": "utdikande",
    "utdikandenas": "utdikande",
    "utdikandens": "utdikande",
    "utdikandes": "utdikande",
    "utdikandet": "utdikande",
    "utdikandets": "utdikande",
    "utdikar": "utdika",
    "utdikas": "utdika",
    "utdikat": "utdika",
    "utdikats": "utdika",
    "utdockningar": "utdockning",
    "utdockningarna": "utdockning",
    "utdockningarnas": "utdockning",
    "utdockningars": "utdockning",
    "utdockningen": "utdockning",
    "utdockningens": "utdockning",
    "utdocknings": "utdockning",
    "utdrag": "utdra",
    "utdraga": "utdra",
    "utdragande": "utdra",
    "utdraganden": "utdragande",
    "utdragandena": "utdragande",
    "utdragandenas": "utdragande",
    "utdragandens": "utdragande",
    "utdragandes": "utdragande",
    "utdragandet": "utdragande",
    "utdragandets": "utdragande",
    "utdragar": "utdragare",
    "utdragaren": "utdragare",
    "utdragarens": "utdragare",
    "utdragares": "utdragare",
    "utdragarna": "utdragare",
    "utdragarnas": "utdragare",
    "utdragas": "utdra",
    "utdragbara": "utdragbar",
    "utdragbarare": "utdragbar",
    "utdragbarares": "utdragbar",
    "utdragbaras": "utdragbar",
    "utdragbarast": "utdragbar",
    "utdragbaraste": "utdragbar",
    "utdragbarastes": "utdragbar",
    "utdragbarasts": "utdragbar",
    "utdragbare": "utdragbar",
    "utdragbares": "utdragbar",
    "utdragbarheten": "utdragbarhet",
    "utdragbarhetens": "utdragbarhet",
    "utdragbarhets": "utdragbarhet",
    "utdragbars": "utdragbar",
    "utdragbart": "utdragbar",
    "utdragbarts": "utdragbar",
    "utdrage": "utdra",
    "utdragen": "utdrag",
    "utdragens": "utdragen",
    "utdrager": "utdra",
    "utdrages": "utdra",
    "utdraget": "utdragen",
    "utdragets": "utdragen",
    "utdragit": "utdra",
    "utdragits": "utdra",
    "utdragna": "utdragen",
    "utdragnare": "utdragen",
    "utdragnares": "utdragen",
    "utdragnas": "utdragen",
    "utdragnast": "utdragen",
    "utdragnaste": "utdragen",
    "utdragnastes": "utdragen",
    "utdragnasts": "utdragen",
    "utdragne": "utdragen",
    "utdragnes": "utdragen",
    "utdragningar": "utdragning",
    "utdragningarna": "utdragning",
    "utdragningarnas": "utdragning",
    "utdragningars": "utdragning",
    "utdragningen": "utdragning",
    "utdragningens": "utdragning",
    "utdragnings": "utdragning",
    "utdrags": "utdrag",
    "utdragslåd": "utdragslåda",
    "utdragslådan": "utdragslåda",
    "utdragslådans": "utdragslåda",
    "utdragslådas": "utdragslåda",
    "utdragslåde": "utdragslåda",
    "utdragslådor": "utdragslåda",
    "utdragslådorna": "utdragslåda",
    "utdragslådornas": "utdragslåda",
    "utdragslådors": "utdragslåda",
    "utdragslåds": "utdragslåda",
    "utdragssoff": "utdragssoffa",
    "utdragssoffan": "utdragssoffa",
    "utdragssoffans": "utdragssoffa",
    "utdragssoffas": "utdragssoffa",
    "utdragssoffe": "utdragssoffa",
    "utdragssoffor": "utdragssoffa",
    "utdragssofforna": "utdragssoffa",
    "utdragssoffornas": "utdragssoffa",
    "utdragssoffors": "utdragssoffa",
    "utdragssoffs": "utdragssoffa",
    "utdragssömmar": "utdragssöm",
    "utdragssömmarna": "utdragssöm",
    "utdragssömmarnas": "utdragssöm",
    "utdragssömmars": "utdragssöm",
    "utdragssömmen": "utdragssöm",
    "utdragssömmens": "utdragssöm",
    "utdragssöms": "utdragssöm",
    "utdrar": "utdra",
    "utdras": "utdra",
    "utdrev": "utdriva",
    "utdrevs": "utdriva",
    "utdriv": "utdriva",
    "utdrivande": "utdriva",
    "utdrivanden": "utdrivande",
    "utdrivandena": "utdrivande",
    "utdrivandenas": "utdrivande",
    "utdrivandens": "utdrivande",
    "utdrivandes": "utdrivande",
    "utdrivandet": "utdrivande",
    "utdrivandets": "utdrivande",
    "utdrivas": "utdriva",
    "utdrive": "utdriva",
    "utdriven": "utdriva",
    "utdrivens": "utdriva",
    "utdriver": "utdriva",
    "utdrives": "utdriva",
    "utdrivet": "utdriva",
    "utdrivets": "utdriva",
    "utdrivit": "utdriva",
    "utdrivits": "utdriva",
    "utdrivna": "utdriva",
    "utdrivnas": "utdriva",
    "utdrivne": "utdriva",
    "utdrivnes": "utdriva",
    "utdrivningar": "utdrivning",
    "utdrivningarna": "utdrivning",
    "utdrivningarnas": "utdrivning",
    "utdrivningars": "utdrivning",
    "utdrivningen": "utdrivning",
    "utdrivningens": "utdrivning",
    "utdrivnings": "utdrivning",
    "utdrivs": "utdriva",
    "utdrog": "utdra",
    "utdroge": "utdra",
    "utdroges": "utdra",
    "utdrogs": "utdra",
    "utdruckens": "utdrucken",
    "utdrucket": "utdrucken",
    "utdruckets": "utdrucken",
    "utdruckna": "utdrucken",
    "utdrucknare": "utdrucken",
    "utdrucknares": "utdrucken",
    "utdrucknas": "utdrucken",
    "utdrucknast": "utdrucken",
    "utdrucknaste": "utdrucken",
    "utdrucknastes": "utdrucken",
    "utdrucknasts": "utdrucken",
    "utdruckne": "utdrucken",
    "utdrucknes": "utdrucken",
    "utdunst": "utdunsta",
    "utdunstad": "utdunsta",
    "utdunstade": "utdunsta",
    "utdunstades": "utdunsta",
    "utdunstads": "utdunsta",
    "utdunstande": "utdunsta",
    "utdunstanden": "utdunstande",
    "utdunstandena": "utdunstande",
    "utdunstandenas": "utdunstande",
    "utdunstandens": "utdunstande",
    "utdunstandes": "utdunstande",
    "utdunstandet": "utdunstande",
    "utdunstandets": "utdunstande",
    "utdunstar": "utdunsta",
    "utdunstas": "utdunsta",
    "utdunstat": "utdunsta",
    "utdunstats": "utdunsta",
    "utdunstningar": "utdunstning",
    "utdunstningarna": "utdunstning",
    "utdunstningarnas": "utdunstning",
    "utdunstningars": "utdunstning",
    "utdunstningen": "utdunstning",
    "utdunstningens": "utdunstning",
    "utdunstnings": "utdunstning",
    "utdunstningskärlen": "utdunstningskärl",
    "utdunstningskärlens": "utdunstningskärl",
    "utdunstningskärlet": "utdunstningskärl",
    "utdunstningskärlets": "utdunstningskärl",
    "utdunstningskärls": "utdunstningskärl",
    "utdöda": "utdöd",
    "utdödare": "utdöd",
    "utdödares": "utdöd",
    "utdödas": "utdöd",
    "utdödast": "utdöd",
    "utdödaste": "utdöd",
    "utdödastes": "utdöd",
    "utdödasts": "utdöd",
    "utdöde": "utdöd",
    "utdödes": "utdöd",
    "utdödheten": "utdödhet",
    "utdödhetens": "utdödhet",
    "utdödhets": "utdödhet",
    "utdöds": "utdöd",
    "utdöendes": "utdöende",
    "utdöendet": "utdöende",
    "utdöendets": "utdöende",
    "utdöm": "utdöma",
    "utdömande": "utdöma",
    "utdömanden": "utdömande",
    "utdömandena": "utdömande",
    "utdömandenas": "utdömande",
    "utdömandens": "utdömande",
    "utdömandes": "utdömande",
    "utdömandet": "utdömande",
    "utdömandets": "utdömande",
    "utdömas": "utdöma",
    "utdömd": "utdöma",
    "utdömda": "utdöma",
    "utdömdas": "utdöma",
    "utdömde": "utdöma",
    "utdömdes": "utdöma",
    "utdömds": "utdöma",
    "utdömer": "utdöma",
    "utdöms": "utdöma",
    "utdömt": "utdöma",
    "utdömts": "utdöma",
    "utdött": "utdöd",
    "utdötts": "utdöd",
    "uteblev": "utebli",
    "utebleve": "utebli",
    "uteblienden": "utebliende",
    "utebliendena": "utebliende",
    "utebliendenas": "utebliende",
    "utebliendens": "utebliende",
    "utebliendes": "utebliende",
    "utebliendet": "utebliende",
    "utebliendets": "utebliende",
    "uteblir": "utebli",
    "utebliv": "utebli",
    "utebliva": "utebli",
    "uteblivande": "utebli",
    "uteblivanden": "uteblivande",
    "uteblivandena": "uteblivande",
    "uteblivandenas": "uteblivande",
    "uteblivandens": "uteblivande",
    "uteblivandes": "uteblivande",
    "uteblivandet": "uteblivande",
    "uteblivandets": "uteblivande",
    "uteblive": "utebli",
    "utebliven": "utebli",
    "uteblivens": "utebli",
    "utebliver": "utebli",
    "uteblivet": "utebli",
    "uteblivets": "utebli",
    "uteblivit": "utebli",
    "uteblivna": "utebli",
    "uteblivnas": "utebli",
    "uteblivne": "utebli",
    "uteblivnes": "utebli",
    "utebruket": "utebruk",
    "utebrukets": "utebruk",
    "utebruks": "utebruk",
    "utedassen": "utedass",
    "utedassens": "utedass",
    "utedasset": "utedass",
    "utedassets": "utedass",
    "uteffekten": "uteffekt",
    "uteffektens": "uteffekt",
    "uteffekts": "uteffekt",
    "utefåren": "utefår",
    "utefårens": "utefår",
    "utefåret": "utefår",
    "utefårets": "utefår",
    "utefårs": "utefår",
    "uteförsvaret": "uteförsvar",
    "uteförsvarets": "uteförsvar",
    "uteförsvars": "uteförsvar",
    "utegrillar": "utegrill",
    "utegrillarna": "utegrill",
    "utegrillarnas": "utegrill",
    "utegrillars": "utegrill",
    "utegrillen": "utegrill",
    "utegrillens": "utegrill",
    "utegrills": "utegrill",
    "utegångsfåren": "utegångsfår",
    "utegångsfårens": "utegångsfår",
    "utegångsfåret": "utegångsfår",
    "utegångsfårets": "utegångsfår",
    "utegångsfårs": "utegångsfår",
    "utegångsförbuden": "utegångsförbud",
    "utegångsförbudens": "utegångsförbud",
    "utegångsförbudet": "utegångsförbud",
    "utegångsförbudets": "utegångsförbud",
    "utegångsförbuds": "utegångsförbud",
    "utekvällar": "utekväll",
    "utekvällarna": "utekväll",
    "utekvällarnas": "utekväll",
    "utekvällars": "utekväll",
    "utekvällen": "utekväll",
    "utekvällens": "utekväll",
    "utekvälls": "utekväll",
    "utelagen": "utelag",
    "utelagens": "utelag",
    "utelaget": "utelag",
    "utelagets": "utelag",
    "utelags": "utelag",
    "uteliggar": "uteliggare",
    "uteliggaren": "uteliggare",
    "uteliggarens": "uteliggare",
    "uteliggares": "uteliggare",
    "uteliggarna": "uteliggare",
    "uteliggarnas": "uteliggare",
    "utelivet": "uteliv",
    "utelivets": "uteliv",
    "utelivs": "uteliv",
    "utelämn": "utelämna",
    "utelämnad": "utelämna",
    "utelämnade": "utelämna",
    "utelämnades": "utelämna",
    "utelämnads": "utelämna",
    "utelämnande": "utelämna",
    "utelämnanden": "utelämnande",
    "utelämnandena": "utelämnande",
    "utelämnandenas": "utelämnande",
    "utelämnandens": "utelämnande",
    "utelämnandes": "utelämnande",
    "utelämnandet": "utelämnande",
    "utelämnandets": "utelämnande",
    "utelämnar": "utelämna",
    "utelämnas": "utelämna",
    "utelämnat": "utelämna",
    "utelämnats": "utelämna",
    "utelämningsteckens": "utelämningstecken",
    "utelämningstecknen": "utelämningstecken",
    "utelämningstecknens": "utelämningstecken",
    "utelämningstecknet": "utelämningstecken",
    "utelämningstecknets": "utelämningstecken",
    "utelås": "utelåsa",
    "utelåsande": "utelåsa",
    "utelåsanden": "utelåsande",
    "utelåsandena": "utelåsande",
    "utelåsandenas": "utelåsande",
    "utelåsandens": "utelåsande",
    "utelåsandes": "utelåsande",
    "utelåsandet": "utelåsande",
    "utelåsandets": "utelåsande",
    "utelåsas": "utelåsa",
    "utelåser": "utelåsa",
    "utelåses": "utelåsa",
    "utelåst": "utelåsa",
    "utelåsta": "utelåsa",
    "utelåstas": "utelåsa",
    "utelåste": "utelåsa",
    "utelåstes": "utelåsa",
    "utelåsts": "utelåsa",
    "utemiljöer": "utemiljö",
    "utemiljöerna": "utemiljö",
    "utemiljöernas": "utemiljö",
    "utemiljöers": "utemiljö",
    "utemiljön": "utemiljö",
    "utemiljöns": "utemiljö",
    "utemiljös": "utemiljö",
    "utemöbeln": "utemöbel",
    "utemöbelns": "utemöbel",
    "utemöbels": "utemöbel",
    "utemöbler": "utemöbel",
    "utemöblerna": "utemöbel",
    "utemöblernas": "utemöbel",
    "utemöblers": "utemöbel",
    "utensilie": "utensilier",
    "utensilierna": "utensilier",
    "utensiliernas": "utensilier",
    "utensiliers": "utensilier",
    "uteplatsen": "uteplats",
    "uteplatsens": "uteplats",
    "uteplatser": "uteplats",
    "uteplatserna": "uteplats",
    "uteplatsernas": "uteplats",
    "uteplatsers": "uteplats",
    "uterummen": "uterum",
    "uterummens": "uterum",
    "uterummet": "uterum",
    "uterummets": "uterum",
    "uterums": "uterum",
    "uteserveringar": "uteservering",
    "uteserveringarna": "uteservering",
    "uteserveringarnas": "uteservering",
    "uteserveringars": "uteservering",
    "uteserveringen": "uteservering",
    "uteserveringens": "uteservering",
    "uteserverings": "uteservering",
    "uteslut": "utesluta",
    "uteslutande": "utesluta",
    "uteslutanden": "uteslutande",
    "uteslutandena": "uteslutande",
    "uteslutandenas": "uteslutande",
    "uteslutandens": "uteslutande",
    "uteslutandes": "uteslutande",
    "uteslutandet": "uteslutande",
    "uteslutandets": "uteslutande",
    "uteslutas": "utesluta",
    "uteslute": "utesluta",
    "utesluten": "utesluta",
    "uteslutens": "utesluta",
    "utesluter": "utesluta",
    "uteslutes": "utesluta",
    "uteslutet": "utesluta",
    "uteslutets": "utesluta",
    "uteslutit": "utesluta",
    "uteslutits": "utesluta",
    "uteslutna": "utesluta",
    "uteslutnas": "utesluta",
    "uteslutne": "utesluta",
    "uteslutnes": "utesluta",
    "uteslutningar": "uteslutning",
    "uteslutningarna": "uteslutning",
    "uteslutningarnas": "uteslutning",
    "uteslutningars": "uteslutning",
    "uteslutningen": "uteslutning",
    "uteslutningens": "uteslutning",
    "uteslutnings": "uteslutning",
    "uteslutningsmetoden": "uteslutningsmetod",
    "uteslutningsmetodens": "uteslutningsmetod",
    "uteslutningsmetods": "uteslutningsmetod",
    "utesluts": "utesluta",
    "uteslöt": "utesluta",
    "uteslöte": "utesluta",
    "uteslötes": "utesluta",
    "uteslöts": "utesluta",
    "utespelar": "utespelare",
    "utespelaren": "utespelare",
    "utespelarens": "utespelare",
    "utespelares": "utespelare",
    "utespelarna": "utespelare",
    "utespelarnas": "utespelare",
    "utestäng": "utestänga",
    "utestängande": "utestänga",
    "utestänganden": "utestängande",
    "utestängandena": "utestängande",
    "utestängandenas": "utestängande",
    "utestängandens": "utestängande",
    "utestängandes": "utestängande",
    "utestängandet": "utestängande",
    "utestängandets": "utestängande",
    "utestängas": "utestänga",
    "utestängd": "utestänga",
    "utestängda": "utestänga",
    "utestängdas": "utestänga",
    "utestängde": "utestänga",
    "utestängdes": "utestänga",
    "utestängds": "utestänga",
    "utestänger": "utestänga",
    "utestänges": "utestänga",
    "utestängs": "utestänga",
    "utestängt": "utestänga",
    "utestängts": "utestänga",
    "utetermometern": "utetermometer",
    "utetermometerns": "utetermometer",
    "utetermometers": "utetermometer",
    "utetermometrar": "utetermometer",
    "utetermometrarna": "utetermometer",
    "utetermometrarnas": "utetermometer",
    "utetermometrars": "utetermometer",
    "utevaron": "utevaro",
    "utevarons": "utevaro",
    "utevaros": "utevaro",
    "utexaminerad": "utexaminera",
    "utexaminerade": "utexaminera",
    "utexaminerades": "utexaminera",
    "utexaminerads": "utexaminera",
    "utexaminerande": "utexaminera",
    "utexamineranden": "utexaminerande",
    "utexaminerandena": "utexaminerande",
    "utexaminerandenas": "utexaminerande",
    "utexaminerandens": "utexaminerande",
    "utexaminerandes": "utexaminerande",
    "utexaminerandet": "utexaminerande",
    "utexaminerandets": "utexaminerande",
    "utexaminerar": "utexaminera",
    "utexamineras": "utexaminera",
    "utexaminerat": "utexaminera",
    "utexaminerats": "utexaminera",
    "utexaminerbara": "utexaminerbar",
    "utexaminerbarare": "utexaminerbar",
    "utexaminerbarares": "utexaminerbar",
    "utexaminerbaras": "utexaminerbar",
    "utexaminerbarast": "utexaminerbar",
    "utexaminerbaraste": "utexaminerbar",
    "utexaminerbarastes": "utexaminerbar",
    "utexaminerbarasts": "utexaminerbar",
    "utexaminerbare": "utexaminerbar",
    "utexaminerbares": "utexaminerbar",
    "utexaminerbarheten": "utexaminerbarhet",
    "utexaminerbarhetens": "utexaminerbarhet",
    "utexaminerbarhets": "utexaminerbarhet",
    "utexaminerbars": "utexaminerbar",
    "utexaminerbart": "utexaminerbar",
    "utexaminerbarts": "utexaminerbar",
    "utexamineringar": "utexaminering",
    "utexamineringarna": "utexaminering",
    "utexamineringarnas": "utexaminering",
    "utexamineringars": "utexaminering",
    "utexamineringen": "utexaminering",
    "utexamineringens": "utexaminering",
    "utexaminerings": "utexaminering",
    "utexperimenterad": "utexperimentera",
    "utexperimenterade": "utexperimentera",
    "utexperimenterades": "utexperimentera",
    "utexperimenterads": "utexperimentera",
    "utexperimenterande": "utexperimentera",
    "utexperimenteranden": "utexperimenterande",
    "utexperimenterandena": "utexperimenterande",
    "utexperimenterandenas": "utexperimenterande",
    "utexperimenterandens": "utexperimenterande",
    "utexperimenterandes": "utexperimenterande",
    "utexperimenterandet": "utexperimenterande",
    "utexperimenterandets": "utexperimenterande",
    "utexperimenterar": "utexperimentera",
    "utexperimenteras": "utexperimentera",
    "utexperimenterat": "utexperimentera",
    "utexperimenterats": "utexperimentera",
    "utexperimenterbara": "utexperimenterbar",
    "utexperimenterbarare": "utexperimenterbar",
    "utexperimenterbarares": "utexperimenterbar",
    "utexperimenterbaras": "utexperimenterbar",
    "utexperimenterbarast": "utexperimenterbar",
    "utexperimenterbaraste": "utexperimenterbar",
    "utexperimenterbarastes": "utexperimenterbar",
    "utexperimenterbarasts": "utexperimenterbar",
    "utexperimenterbare": "utexperimenterbar",
    "utexperimenterbares": "utexperimenterbar",
    "utexperimenterbarheten": "utexperimenterbarhet",
    "utexperimenterbarhetens": "utexperimenterbarhet",
    "utexperimenterbarhets": "utexperimenterbarhet",
    "utexperimenterbars": "utexperimenterbar",
    "utexperimenterbart": "utexperimenterbar",
    "utexperimenterbarts": "utexperimenterbar",
    "utexperimenteringar": "utexperimentering",
    "utexperimenteringarna": "utexperimentering",
    "utexperimenteringarnas": "utexperimentering",
    "utexperimenteringars": "utexperimentering",
    "utexperimenteringen": "utexperimentering",
    "utexperimenteringens": "utexperimentering",
    "utexperimenterings": "utexperimentering",
    "uteätar": "uteätare",
    "uteätaren": "uteätare",
    "uteätarens": "uteätare",
    "uteätares": "uteätare",
    "uteätarna": "uteätare",
    "uteätarnas": "uteätare",
    "utfall": "utfalla",
    "utfallande": "utfalla",
    "utfallanden": "utfallande",
    "utfallandena": "utfallande",
    "utfallandenas": "utfallande",
    "utfallandens": "utfallande",
    "utfallandes": "utfallande",
    "utfallandet": "utfallande",
    "utfallandets": "utfallande",
    "utfallas": "utfalla",
    "utfalle": "utfalla",
    "utfallen": "utfalla",
    "utfallens": "utfalla",
    "utfaller": "utfalla",
    "utfalles": "utfalla",
    "utfallet": "utfalla",
    "utfallets": "utfalla",
    "utfallit": "utfalla",
    "utfallits": "utfalla",
    "utfallna": "utfalla",
    "utfallnas": "utfalla",
    "utfallne": "utfalla",
    "utfallnes": "utfalla",
    "utfalls": "utfalla",
    "utfallsdiken": "utfallsdike",
    "utfallsdikena": "utfallsdike",
    "utfallsdikenas": "utfallsdike",
    "utfallsdikens": "utfallsdike",
    "utfallsdikes": "utfallsdike",
    "utfallsdiket": "utfallsdike",
    "utfallsdikets": "utfallsdike",
    "utfallsportar": "utfallsport",
    "utfallsportarna": "utfallsport",
    "utfallsportarnas": "utfallsport",
    "utfallsportars": "utfallsport",
    "utfallsporten": "utfallsport",
    "utfallsportens": "utfallsport",
    "utfallsports": "utfallsport",
    "utfallsproven": "utfallsprov",
    "utfallsprovens": "utfallsprov",
    "utfallsprover": "utfallsprov",
    "utfallsproverna": "utfallsprov",
    "utfallsprovernas": "utfallsprov",
    "utfallsprovers": "utfallsprov",
    "utfallsprovet": "utfallsprov",
    "utfallsprovets": "utfallsprov",
    "utfallsprovs": "utfallsprov",
    "utfallsrummen": "utfallsrum",
    "utfallsrummens": "utfallsrum",
    "utfallsrummet": "utfallsrum",
    "utfallsrummets": "utfallsrum",
    "utfallsrums": "utfallsrum",
    "utfallsrymden": "utfallsrymd",
    "utfallsrymdens": "utfallsrymd",
    "utfallsrymder": "utfallsrymd",
    "utfallsrymderna": "utfallsrymd",
    "utfallsrymdernas": "utfallsrymd",
    "utfallsrymders": "utfallsrymd",
    "utfallsrymds": "utfallsrymd",
    "utfarten": "utfart",
    "utfartens": "utfart",
    "utfarter": "utfart",
    "utfarterna": "utfart",
    "utfarternas": "utfart",
    "utfarters": "utfart",
    "utfarts": "utfart",
    "utfattiga": "utfattig",
    "utfattigare": "utfattig",
    "utfattigares": "utfattig",
    "utfattigas": "utfattig",
    "utfattigast": "utfattig",
    "utfattigaste": "utfattig",
    "utfattigastes": "utfattig",
    "utfattigasts": "utfattig",
    "utfattige": "utfattig",
    "utfattiges": "utfattig",
    "utfattigheten": "utfattighet",
    "utfattighetens": "utfattighet",
    "utfattighets": "utfattighet",
    "utfattigs": "utfattig",
    "utfattigt": "utfattig",
    "utfattigts": "utfattig",
    "utfestade": "utfestad",
    "utfestades": "utfestad",
    "utfestads": "utfestad",
    "utfestat": "utfestad",
    "utfestats": "utfestad",
    "utfick": "utfå",
    "utficks": "utfå",
    "utfinge": "utfå",
    "utfinges": "utfå",
    "utfisk": "utfiska",
    "utfiskad": "utfiska",
    "utfiskade": "utfiska",
    "utfiskades": "utfiska",
    "utfiskads": "utfiska",
    "utfiskande": "utfiska",
    "utfiskanden": "utfiskande",
    "utfiskandena": "utfiskande",
    "utfiskandenas": "utfiskande",
    "utfiskandens": "utfiskande",
    "utfiskandes": "utfiskande",
    "utfiskandet": "utfiskande",
    "utfiskandets": "utfiskande",
    "utfiskar": "utfiska",
    "utfiskas": "utfiska",
    "utfiskat": "utfiska",
    "utfiskats": "utfiska",
    "utfiskningen": "utfiskning",
    "utfiskningens": "utfiskning",
    "utfisknings": "utfiskning",
    "utflagg": "utflagga",
    "utflaggad": "utflagga",
    "utflaggade": "utflagga",
    "utflaggades": "utflagga",
    "utflaggads": "utflagga",
    "utflaggande": "utflagga",
    "utflagganden": "utflaggande",
    "utflaggandena": "utflaggande",
    "utflaggandenas": "utflaggande",
    "utflaggandens": "utflaggande",
    "utflaggandes": "utflaggande",
    "utflaggandet": "utflaggande",
    "utflaggandets": "utflaggande",
    "utflaggar": "utflagga",
    "utflaggas": "utflagga",
    "utflaggat": "utflagga",
    "utflaggats": "utflagga",
    "utflaggningar": "utflaggning",
    "utflaggningarna": "utflaggning",
    "utflaggningarnas": "utflaggning",
    "utflaggningars": "utflaggning",
    "utflaggningen": "utflaggning",
    "utflaggningens": "utflaggning",
    "utflaggnings": "utflaggning",
    "utflugens": "utflugen",
    "utfluget": "utflugen",
    "utflugets": "utflugen",
    "utflugna": "utflugen",
    "utflugnare": "utflugen",
    "utflugnares": "utflugen",
    "utflugnas": "utflugen",
    "utflugnast": "utflugen",
    "utflugnaste": "utflugen",
    "utflugnastes": "utflugen",
    "utflugnasts": "utflugen",
    "utflugne": "utflugen",
    "utflugnes": "utflugen",
    "utflykten": "utflykt",
    "utflyktens": "utflykt",
    "utflykter": "utflykt",
    "utflykterna": "utflykt",
    "utflykternas": "utflykt",
    "utflykters": "utflykt",
    "utflykts": "utflykt",
    "utflyttningar": "utflyttning",
    "utflyttningarna": "utflyttning",
    "utflyttningarnas": "utflyttning",
    "utflyttningars": "utflyttning",
    "utflyttningen": "utflyttning",
    "utflyttningens": "utflyttning",
    "utflyttnings": "utflyttning",
    "utflyttningslänen": "utflyttningslän",
    "utflyttningslänens": "utflyttningslän",
    "utflyttningslänet": "utflyttningslän",
    "utflyttningslänets": "utflyttningslän",
    "utflyttningslängden": "utflyttningslängd",
    "utflyttningslängdens": "utflyttningslängd",
    "utflyttningslängder": "utflyttningslängd",
    "utflyttningslängderna": "utflyttningslängd",
    "utflyttningslängdernas": "utflyttningslängd",
    "utflyttningslängders": "utflyttningslängd",
    "utflyttningslängds": "utflyttningslängd",
    "utflyttningsläns": "utflyttningslän",
    "utflöden": "utflöde",
    "utflödena": "utflöde",
    "utflödenas": "utflöde",
    "utflödens": "utflöde",
    "utflödes": "utflöde",
    "utflödet": "utflöde",
    "utflödets": "utflöde",
    "utfodrad": "utfodra",
    "utfodrade": "utfodra",
    "utfodrades": "utfodra",
    "utfodrads": "utfodra",
    "utfodrande": "utfodra",
    "utfodranden": "utfodrande",
    "utfodrandena": "utfodrande",
    "utfodrandenas": "utfodrande",
    "utfodrandens": "utfodrande",
    "utfodrandes": "utfodrande",
    "utfodrandet": "utfodrande",
    "utfodrandets": "utfodrande",
    "utfodrar": "utfodra",
    "utfodras": "utfodra",
    "utfodrat": "utfodra",
    "utfodrats": "utfodra",
    "utfodringar": "utfodring",
    "utfodringarna": "utfodring",
    "utfodringarnas": "utfodring",
    "utfodringars": "utfodring",
    "utfodringen": "utfodring",
    "utfodringens": "utfodring",
    "utfodrings": "utfodring",
    "utfodringsjournalen": "utfodringsjournal",
    "utfodringsjournalens": "utfodringsjournal",
    "utfodringsjournaler": "utfodringsjournal",
    "utfodringsjournalerna": "utfodringsjournal",
    "utfodringsjournalernas": "utfodringsjournal",
    "utfodringsjournalers": "utfodringsjournal",
    "utfodringsjournals": "utfodringsjournal",
    "utfodringsstaten": "utfodringsstat",
    "utfodringsstatens": "utfodringsstat",
    "utfodringsstater": "utfodringsstat",
    "utfodringsstaterna": "utfodringsstat",
    "utfodringsstaternas": "utfodringsstat",
    "utfodringsstaters": "utfodringsstat",
    "utfodringsstats": "utfodringsstat",
    "utfordrad": "utfordra",
    "utfordrade": "utfordra",
    "utfordrades": "utfordra",
    "utfordrads": "utfordra",
    "utfordrande": "utfordra",
    "utfordranden": "utfordrande",
    "utfordrandena": "utfordrande",
    "utfordrandenas": "utfordrande",
    "utfordrandens": "utfordrande",
    "utfordrandes": "utfordrande",
    "utfordrandet": "utfordrande",
    "utfordrandets": "utfordrande",
    "utfordrar": "utfordra",
    "utfordras": "utfordra",
    "utfordrat": "utfordra",
    "utfordrats": "utfordra",
    "utform": "utforma",
    "utformad": "utforma",
    "utformade": "utforma",
    "utformades": "utforma",
    "utformads": "utforma",
    "utformande": "utforma",
    "utformanden": "utformande",
    "utformandena": "utformande",
    "utformandenas": "utformande",
    "utformandens": "utformande",
    "utformandes": "utformande",
    "utformandet": "utformande",
    "utformandets": "utformande",
    "utformar": "utforma",
    "utformas": "utforma",
    "utformat": "utforma",
    "utformats": "utforma",
    "utformningar": "utformning",
    "utformningarna": "utformning",
    "utformningarnas": "utformning",
    "utformningars": "utformning",
    "utformningen": "utformning",
    "utformningens": "utformning",
    "utformnings": "utformning",
    "utforsk": "utforska",
    "utforskad": "utforska",
    "utforskade": "utforska",
    "utforskades": "utforska",
    "utforskads": "utforska",
    "utforskande": "utforska",
    "utforskanden": "utforskande",
    "utforskandena": "utforskande",
    "utforskandenas": "utforskande",
    "utforskandens": "utforskande",
    "utforskandes": "utforskande",
    "utforskandet": "utforskande",
    "utforskandets": "utforskande",
    "utforskar": "utforskare",
    "utforskaren": "utforskare",
    "utforskarens": "utforskare",
    "utforskares": "utforskare",
    "utforskarna": "utforskare",
    "utforskarnas": "utforskare",
    "utforskas": "utforska",
    "utforskat": "utforska",
    "utforskats": "utforska",
    "utforskningar": "utforskning",
    "utforskningarna": "utforskning",
    "utforskningarnas": "utforskning",
    "utforskningars": "utforskning",
    "utforskningen": "utforskning",
    "utforskningens": "utforskning",
    "utforsknings": "utforskning",
    "utfrakt": "utfrakta",
    "utfraktad": "utfrakta",
    "utfraktade": "utfrakta",
    "utfraktades": "utfrakta",
    "utfraktads": "utfrakta",
    "utfraktande": "utfrakta",
    "utfraktanden": "utfraktande",
    "utfraktandena": "utfraktande",
    "utfraktandenas": "utfraktande",
    "utfraktandens": "utfraktande",
    "utfraktandes": "utfraktande",
    "utfraktandet": "utfraktande",
    "utfraktandets": "utfraktande",
    "utfraktar": "utfrakta",
    "utfraktas": "utfrakta",
    "utfraktat": "utfrakta",
    "utfraktats": "utfrakta",
    "utfrusens": "utfrusen",
    "utfruset": "utfrusen",
    "utfrusets": "utfrusen",
    "utfrusna": "utfrusen",
    "utfrusnare": "utfrusen",
    "utfrusnares": "utfrusen",
    "utfrusnas": "utfrusen",
    "utfrusnast": "utfrusen",
    "utfrusnaste": "utfrusen",
    "utfrusnastes": "utfrusen",
    "utfrusnasts": "utfrusen",
    "utfrusne": "utfrusen",
    "utfrusnes": "utfrusen",
    "utfrysningar": "utfrysning",
    "utfrysningarna": "utfrysning",
    "utfrysningarnas": "utfrysning",
    "utfrysningars": "utfrysning",
    "utfrysningen": "utfrysning",
    "utfrysningens": "utfrysning",
    "utfrysnings": "utfrysning",
    "utfrysta": "utfryst",
    "utfrystare": "utfryst",
    "utfrystares": "utfryst",
    "utfrystas": "utfryst",
    "utfrystast": "utfryst",
    "utfrystaste": "utfryst",
    "utfrystastes": "utfryst",
    "utfrystasts": "utfryst",
    "utfryste": "utfryst",
    "utfrystes": "utfryst",
    "utfrystheten": "utfrysthet",
    "utfrysthetens": "utfrysthet",
    "utfrysthets": "utfrysthet",
    "utfrysts": "utfryst",
    "utfråg": "utfråga",
    "utfrågad": "utfråga",
    "utfrågade": "utfråga",
    "utfrågades": "utfråga",
    "utfrågads": "utfråga",
    "utfrågande": "utfråga",
    "utfråganden": "utfrågande",
    "utfrågandena": "utfrågande",
    "utfrågandenas": "utfrågande",
    "utfrågandens": "utfrågande",
    "utfrågandes": "utfrågande",
    "utfrågandet": "utfrågande",
    "utfrågandets": "utfrågande",
    "utfrågar": "utfråga",
    "utfrågas": "utfråga",
    "utfrågat": "utfråga",
    "utfrågats": "utfråga",
    "utfrågningar": "utfrågning",
    "utfrågningarna": "utfrågning",
    "utfrågningarnas": "utfrågning",
    "utfrågningars": "utfrågning",
    "utfrågningen": "utfrågning",
    "utfrågningens": "utfrågning",
    "utfrågnings": "utfrågning",
    "utfyll": "utfylla",
    "utfyllande": "utfylla",
    "utfyllanden": "utfyllande",
    "utfyllandena": "utfyllande",
    "utfyllandenas": "utfyllande",
    "utfyllandens": "utfyllande",
    "utfyllandes": "utfyllande",
    "utfyllandet": "utfyllande",
    "utfyllandets": "utfyllande",
    "utfyllas": "utfylla",
    "utfylld": "utfylla",
    "utfyllda": "utfylla",
    "utfylldas": "utfylla",
    "utfyllde": "utfylla",
    "utfylldes": "utfylla",
    "utfyllds": "utfylla",
    "utfyller": "utfylla",
    "utfylles": "utfylla",
    "utfyllnaden": "utfyllnad",
    "utfyllnadens": "utfyllnad",
    "utfyllnader": "utfyllnad",
    "utfyllnaderna": "utfyllnad",
    "utfyllnadernas": "utfyllnad",
    "utfyllnaders": "utfyllnad",
    "utfyllnads": "utfyllnad",
    "utfyllningar": "utfyllning",
    "utfyllningarna": "utfyllning",
    "utfyllningarnas": "utfyllning",
    "utfyllningars": "utfyllning",
    "utfyllningen": "utfyllning",
    "utfyllningens": "utfyllning",
    "utfyllnings": "utfyllning",
    "utfylls": "utfylla",
    "utfyllt": "utfylla",
    "utfyllts": "utfylla",
    "utfäll": "utfälla",
    "utfällande": "utfälla",
    "utfällanden": "utfällande",
    "utfällandena": "utfällande",
    "utfällandenas": "utfällande",
    "utfällandens": "utfällande",
    "utfällandes": "utfällande",
    "utfällandet": "utfällande",
    "utfällandets": "utfällande",
    "utfällas": "utfälla",
    "utfällbara": "utfällbar",
    "utfällbarare": "utfällbar",
    "utfällbarares": "utfällbar",
    "utfällbaras": "utfällbar",
    "utfällbarast": "utfällbar",
    "utfällbaraste": "utfällbar",
    "utfällbarastes": "utfällbar",
    "utfällbarasts": "utfällbar",
    "utfällbare": "utfällbar",
    "utfällbares": "utfällbar",
    "utfällbarheten": "utfällbarhet",
    "utfällbarhetens": "utfällbarhet",
    "utfällbarhets": "utfällbarhet",
    "utfällbars": "utfällbar",
    "utfällbart": "utfällbar",
    "utfällbarts": "utfällbar",
    "utfälld": "utfälla",
    "utfällda": "utfälla",
    "utfälldas": "utfälla",
    "utfällde": "utfälla",
    "utfälldes": "utfälla",
    "utfällds": "utfälla",
    "utfäller": "utfälla",
    "utfälles": "utfälla",
    "utfällningar": "utfällning",
    "utfällningarna": "utfällning",
    "utfällningarnas": "utfällning",
    "utfällningars": "utfällning",
    "utfällningen": "utfällning",
    "utfällningens": "utfällning",
    "utfällnings": "utfällning",
    "utfälls": "utfälla",
    "utfällt": "utfälla",
    "utfällts": "utfälla",
    "utfärd": "utfärda",
    "utfärdad": "utfärda",
    "utfärdade": "utfärda",
    "utfärdades": "utfärda",
    "utfärdads": "utfärda",
    "utfärdande": "utfärda",
    "utfärdanden": "utfärdande",
    "utfärdandena": "utfärdande",
    "utfärdandenas": "utfärdande",
    "utfärdandens": "utfärdande",
    "utfärdandes": "utfärdande",
    "utfärdandet": "utfärdande",
    "utfärdandets": "utfärdande",
    "utfärdar": "utfärda",
    "utfärdas": "utfärda",
    "utfärdat": "utfärda",
    "utfärdats": "utfärda",
    "utfärden": "utfärd",
    "utfärdens": "utfärd",
    "utfärder": "utfärd",
    "utfärderna": "utfärd",
    "utfärdernas": "utfärd",
    "utfärders": "utfärd",
    "utfärds": "utfärd",
    "utfäst": "utfästa",
    "utfästande": "utfästa",
    "utfästanden": "utfästande",
    "utfästandena": "utfästande",
    "utfästandenas": "utfästande",
    "utfästandens": "utfästande",
    "utfästandes": "utfästande",
    "utfästandet": "utfästande",
    "utfästandets": "utfästande",
    "utfästas": "utfästa",
    "utfäste": "utfästa",
    "utfästelsen": "utfästelse",
    "utfästelsens": "utfästelse",
    "utfästelser": "utfästelse",
    "utfästelserna": "utfästelse",
    "utfästelsernas": "utfästelse",
    "utfästelsers": "utfästelse",
    "utfästelses": "utfästelse",
    "utfäster": "utfästa",
    "utfästes": "utfästa",
    "utfästs": "utfästa",
    "utfående": "utfå",
    "utfåenden": "utfående",
    "utfåendena": "utfående",
    "utfåendenas": "utfående",
    "utfåendens": "utfående",
    "utfåendes": "utfående",
    "utfåendet": "utfående",
    "utfåendets": "utfående",
    "utfår": "utfå",
    "utfås": "utfå",
    "utfått": "utfå",
    "utfåtts": "utfå",
    "utföll": "utfalla",
    "utfölle": "utfalla",
    "utfölles": "utfalla",
    "utfölls": "utfalla",
    "utför": "utföra",
    "utförande": "utföra",
    "utföranden": "utförande",
    "utförandena": "utförande",
    "utförandenas": "utförande",
    "utförandens": "utförande",
    "utförandes": "utförande",
    "utförandet": "utförande",
    "utförandets": "utförande",
    "utföras": "utföra",
    "utförbara": "utförbar",
    "utförbarare": "utförbar",
    "utförbarares": "utförbar",
    "utförbaras": "utförbar",
    "utförbarast": "utförbar",
    "utförbaraste": "utförbar",
    "utförbarastes": "utförbar",
    "utförbarasts": "utförbar",
    "utförbare": "utförbar",
    "utförbares": "utförbar",
    "utförbarheten": "utförbarhet",
    "utförbarhetens": "utförbarhet",
    "utförbarhets": "utförbarhet",
    "utförbars": "utförbar",
    "utförbart": "utförbar",
    "utförbarts": "utförbar",
    "utförd": "utföra",
    "utförda": "utföra",
    "utfördas": "utföra",
    "utförde": "utföra",
    "utfördes": "utföra",
    "utförds": "utföra",
    "utföres": "utföra",
    "utföringar": "utföring",
    "utföringarna": "utföring",
    "utföringarnas": "utföring",
    "utföringars": "utföring",
    "utföringen": "utföring",
    "utföringens": "utföring",
    "utförings": "utföring",
    "utförliga": "utförlig",
    "utförligare": "utförlig",
    "utförligares": "utförlig",
    "utförligas": "utförlig",
    "utförligast": "utförlig",
    "utförligaste": "utförlig",
    "utförligastes": "utförlig",
    "utförligasts": "utförlig",
    "utförlige": "utförlig",
    "utförliges": "utförlig",
    "utförligheten": "utförlighet",
    "utförlighetens": "utförlighet",
    "utförlighets": "utförlighet",
    "utförligs": "utförlig",
    "utförligt": "utförlig",
    "utförligts": "utförlig",
    "utförs": "utföra",
    "utförsback": "utförsbacke",
    "utförsbackar": "utförsbacke",
    "utförsbackarna": "utförsbacke",
    "utförsbackarnas": "utförsbacke",
    "utförsbackars": "utförsbacke",
    "utförsbacken": "utförsbacke",
    "utförsbackens": "utförsbacke",
    "utförsbackes": "utförsbacke",
    "utförsbacks": "utförsbacke",
    "utförseln": "utförsel",
    "utförselns": "utförsel",
    "utförsels": "utförsel",
    "utförsgåvan": "utförsgåva",
    "utförsgåvans": "utförsgåva",
    "utförsgåvas": "utförsgåva",
    "utförsgåve": "utförsgåva",
    "utförsgåvo": "utförsgåva",
    "utförsgåvor": "utförsgåva",
    "utförsgåvorna": "utförsgåva",
    "utförsgåvornas": "utförsgåva",
    "utförsgåvors": "utförsgåva",
    "utförslöp": "utförslöpa",
    "utförslöpan": "utförslöpa",
    "utförslöpans": "utförslöpa",
    "utförslöpas": "utförslöpa",
    "utförslöpe": "utförslöpa",
    "utförslöpor": "utförslöpa",
    "utförslöporna": "utförslöpa",
    "utförslöpornas": "utförslöpa",
    "utförslöpors": "utförslöpa",
    "utförslöps": "utförslöpa",
    "utförsäkrade": "utförsäkrad",
    "utförsäkrades": "utförsäkrad",
    "utförsäkrads": "utförsäkrad",
    "utförsäkrat": "utförsäkrad",
    "utförsäkrats": "utförsäkrad",
    "utförsälj": "utförsälja",
    "utförsäljande": "utförsälja",
    "utförsäljanden": "utförsäljande",
    "utförsäljandena": "utförsäljande",
    "utförsäljandenas": "utförsäljande",
    "utförsäljandens": "utförsäljande",
    "utförsäljandes": "utförsäljande",
    "utförsäljandet": "utförsäljande",
    "utförsäljandets": "utförsäljande",
    "utförsäljas": "utförsälja",
    "utförsäljer": "utförsälja",
    "utförsäljes": "utförsälja",
    "utförsäljningar": "utförsäljning",
    "utförsäljningarna": "utförsäljning",
    "utförsäljningarnas": "utförsäljning",
    "utförsäljningars": "utförsäljning",
    "utförsäljningen": "utförsäljning",
    "utförsäljningens": "utförsäljning",
    "utförsäljnings": "utförsäljning",
    "utförsäljs": "utförsälja",
    "utförsåkar": "utförsåkare",
    "utförsåkaren": "utförsåkare",
    "utförsåkarens": "utförsåkare",
    "utförsåkares": "utförsåkare",
    "utförsåkarna": "utförsåkare",
    "utförsåkarnas": "utförsåkare",
    "utförsåkningar": "utförsåkning",
    "utförsåkningarna": "utförsåkning",
    "utförsåkningarnas": "utförsåkning",
    "utförsåkningars": "utförsåkning",
    "utförsåkningen": "utförsåkning",
    "utförsåkningens": "utförsåkning",
    "utförsåknings": "utförsåkning",
    "utförsåld": "utförsälja",
    "utförsålda": "utförsälja",
    "utförsåldas": "utförsälja",
    "utförsålde": "utförsälja",
    "utförsåldes": "utförsälja",
    "utförsålds": "utförsälja",
    "utförsålt": "utförsälja",
    "utförsålts": "utförsälja",
    "utfört": "utföra",
    "utförts": "utföra",
    "utgallringar": "utgallring",
    "utgallringarna": "utgallring",
    "utgallringarnas": "utgallring",
    "utgallringars": "utgallring",
    "utgallringen": "utgallring",
    "utgallringens": "utgallring",
    "utgallrings": "utgallring",
    "utgamla": "utgammal",
    "utgamlas": "utgammal",
    "utgamle": "utgammal",
    "utgamles": "utgammal",
    "utgammals": "utgammal",
    "utgammalt": "utgammal",
    "utgammalts": "utgammal",
    "utgav": "utge",
    "utgavs": "utge",
    "utgeende": "utge",
    "utgeenden": "utgeende",
    "utgeendena": "utgeende",
    "utgeendenas": "utgeende",
    "utgeendens": "utgeende",
    "utgeendes": "utgeende",
    "utgeendet": "utgeende",
    "utgeendets": "utgeende",
    "utger": "utge",
    "utges": "utge",
    "utgett": "utge",
    "utgetts": "utge",
    "utgick": "utgå",
    "utgicks": "utgå",
    "utgiften": "utgift",
    "utgiftens": "utgift",
    "utgifter": "utgift",
    "utgifterna": "utgift",
    "utgifternas": "utgift",
    "utgifters": "utgift",
    "utgifts": "utgift",
    "utgiftsbudgetar": "utgiftsbudget",
    "utgiftsbudgetarna": "utgiftsbudget",
    "utgiftsbudgetarnas": "utgiftsbudget",
    "utgiftsbudgetars": "utgiftsbudget",
    "utgiftsbudgeten": "utgiftsbudget",
    "utgiftsbudgetens": "utgiftsbudget",
    "utgiftsbudgeter": "utgiftsbudget",
    "utgiftsbudgeterna": "utgiftsbudget",
    "utgiftsbudgeternas": "utgiftsbudget",
    "utgiftsbudgeters": "utgiftsbudget",
    "utgiftsbudgets": "utgiftsbudget",
    "utgiftsdisciplinen": "utgiftsdisciplin",
    "utgiftsdisciplinens": "utgiftsdisciplin",
    "utgiftsdisciplins": "utgiftsdisciplin",
    "utgiftsskatten": "utgiftsskatt",
    "utgiftsskattens": "utgiftsskatt",
    "utgiftsskatter": "utgiftsskatt",
    "utgiftsskatterna": "utgiftsskatt",
    "utgiftsskatternas": "utgiftsskatt",
    "utgiftsskatters": "utgiftsskatt",
    "utgiftsskatts": "utgiftsskatt",
    "utgiftsverifikationen": "utgiftsverifikation",
    "utgiftsverifikationens": "utgiftsverifikation",
    "utgiftsverifikationer": "utgiftsverifikation",
    "utgiftsverifikationerna": "utgiftsverifikation",
    "utgiftsverifikationernas": "utgiftsverifikation",
    "utgiftsverifikationers": "utgiftsverifikation",
    "utgiftsverifikations": "utgiftsverifikation",
    "utginge": "utgå",
    "utginges": "utgå",
    "utgiv": "utge",
    "utgiva": "utge",
    "utgivande": "utge",
    "utgivanden": "utgivande",
    "utgivandena": "utgivande",
    "utgivandenas": "utgivande",
    "utgivandens": "utgivande",
    "utgivandes": "utgivande",
    "utgivandet": "utgivande",
    "utgivandets": "utgivande",
    "utgivar": "utgivare",
    "utgivaren": "utgivare",
    "utgivarens": "utgivare",
    "utgivares": "utgivare",
    "utgivarna": "utgivare",
    "utgivarnas": "utgivare",
    "utgivas": "utge",
    "utgive": "utge",
    "utgiven": "utge",
    "utgivens": "utge",
    "utgiver": "utge",
    "utgives": "utge",
    "utgivet": "utge",
    "utgivets": "utge",
    "utgivit": "utge",
    "utgivits": "utge",
    "utgivna": "utge",
    "utgivnas": "utge",
    "utgivne": "utge",
    "utgivnes": "utge",
    "utgivningar": "utgivning",
    "utgivningarna": "utgivning",
    "utgivningarnas": "utgivning",
    "utgivningars": "utgivning",
    "utgivningen": "utgivning",
    "utgivningens": "utgivning",
    "utgivnings": "utgivning",
    "utgivningsbevisen": "utgivningsbevis",
    "utgivningsbevisens": "utgivningsbevis",
    "utgivningsbeviset": "utgivningsbevis",
    "utgivningsbevisets": "utgivningsbevis",
    "utgivs": "utge",
    "utgjord": "utgöra",
    "utgjorda": "utgöra",
    "utgjordas": "utgöra",
    "utgjorde": "utgöra",
    "utgjordes": "utgöra",
    "utgjords": "utgöra",
    "utgjort": "utgöra",
    "utgjorts": "utgöra",
    "utgjut": "utgjuta",
    "utgjutande": "utgjuta",
    "utgjutanden": "utgjutande",
    "utgjutandena": "utgjutande",
    "utgjutandenas": "utgjutande",
    "utgjutandens": "utgjutande",
    "utgjutandes": "utgjutande",
    "utgjutandet": "utgjutande",
    "utgjutandets": "utgjutande",
    "utgjutas": "utgjuta",
    "utgjute": "utgjuta",
    "utgjutelsen": "utgjutelse",
    "utgjutelsens": "utgjutelse",
    "utgjutelser": "utgjutelse",
    "utgjutelserna": "utgjutelse",
    "utgjutelsernas": "utgjutelse",
    "utgjutelsers": "utgjutelse",
    "utgjutelses": "utgjutelse",
    "utgjuten": "utgjuta",
    "utgjutens": "utgjuta",
    "utgjuter": "utgjuta",
    "utgjutes": "utgjuta",
    "utgjutet": "utgjuta",
    "utgjutets": "utgjuta",
    "utgjutit": "utgjuta",
    "utgjutits": "utgjuta",
    "utgjutna": "utgjuta",
    "utgjutnas": "utgjuta",
    "utgjutne": "utgjuta",
    "utgjutnes": "utgjuta",
    "utgjutningar": "utgjutning",
    "utgjutningarna": "utgjutning",
    "utgjutningarnas": "utgjutning",
    "utgjutningars": "utgjutning",
    "utgjutningen": "utgjutning",
    "utgjutningens": "utgjutning",
    "utgjutnings": "utgjutning",
    "utgjuts": "utgjuta",
    "utgles": "utglesa",
    "utglesad": "utglesa",
    "utglesade": "utglesa",
    "utglesades": "utglesa",
    "utglesads": "utglesa",
    "utglesande": "utglesa",
    "utglesanden": "utglesande",
    "utglesandena": "utglesande",
    "utglesandenas": "utglesande",
    "utglesandens": "utglesande",
    "utglesandes": "utglesande",
    "utglesandet": "utglesande",
    "utglesandets": "utglesande",
    "utglesar": "utglesa",
    "utglesas": "utglesa",
    "utglesat": "utglesa",
    "utglesats": "utglesa",
    "utglesningar": "utglesning",
    "utglesningarna": "utglesning",
    "utglesningarnas": "utglesning",
    "utglesningars": "utglesning",
    "utglesningen": "utglesning",
    "utglesningens": "utglesning",
    "utglesnings": "utglesning",
    "utgrund": "utgrunda",
    "utgrundad": "utgrunda",
    "utgrundade": "utgrunda",
    "utgrundades": "utgrunda",
    "utgrundads": "utgrunda",
    "utgrundande": "utgrunda",
    "utgrundanden": "utgrundande",
    "utgrundandena": "utgrundande",
    "utgrundandenas": "utgrundande",
    "utgrundandens": "utgrundande",
    "utgrundandes": "utgrundande",
    "utgrundandet": "utgrundande",
    "utgrundandets": "utgrundande",
    "utgrundar": "utgrunda",
    "utgrundas": "utgrunda",
    "utgrundat": "utgrunda",
    "utgrundats": "utgrunda",
    "utgräv": "utgräva",
    "utgrävande": "utgräva",
    "utgrävanden": "utgrävande",
    "utgrävandena": "utgrävande",
    "utgrävandenas": "utgrävande",
    "utgrävandens": "utgrävande",
    "utgrävandes": "utgrävande",
    "utgrävandet": "utgrävande",
    "utgrävandets": "utgrävande",
    "utgrävar": "utgrävare",
    "utgrävaren": "utgrävare",
    "utgrävarens": "utgrävare",
    "utgrävares": "utgrävare",
    "utgrävarna": "utgrävare",
    "utgrävarnas": "utgrävare",
    "utgrävas": "utgräva",
    "utgrävd": "utgräva",
    "utgrävda": "utgräva",
    "utgrävdas": "utgräva",
    "utgrävde": "utgräva",
    "utgrävdes": "utgräva",
    "utgrävds": "utgräva",
    "utgräver": "utgräva",
    "utgräves": "utgräva",
    "utgrävningar": "utgrävning",
    "utgrävningarna": "utgrävning",
    "utgrävningarnas": "utgrävning",
    "utgrävningars": "utgrävning",
    "utgrävningen": "utgrävning",
    "utgrävningens": "utgrävning",
    "utgrävnings": "utgrävning",
    "utgrävningsplatsen": "utgrävningsplats",
    "utgrävningsplatsens": "utgrävningsplats",
    "utgrävningsplatser": "utgrävningsplats",
    "utgrävningsplatserna": "utgrävningsplats",
    "utgrävningsplatsernas": "utgrävningsplats",
    "utgrävningsplatsers": "utgrävningsplats",
    "utgrävningsresultaten": "utgrävningsresultat",
    "utgrävningsresultatens": "utgrävningsresultat",
    "utgrävningsresultatet": "utgrävningsresultat",
    "utgrävningsresultatets": "utgrävningsresultat",
    "utgrävningsresultats": "utgrävningsresultat",
    "utgrävs": "utgräva",
    "utgrävt": "utgräva",
    "utgrävts": "utgräva",
    "utgående": "utgå",
    "utgåenden": "utgående",
    "utgåendena": "utgående",
    "utgåendenas": "utgående",
    "utgåendens": "utgående",
    "utgåendes": "utgående",
    "utgåendet": "utgående",
    "utgåendets": "utgående",
    "utgångar": "utgång",
    "utgångarna": "utgång",
    "utgångarnas": "utgång",
    "utgångars": "utgång",
    "utgånge": "utgå",
    "utgången": "utgång",
    "utgångens": "utgång",
    "utgånges": "utgå",
    "utgånget": "utgå",
    "utgångets": "utgå",
    "utgångna": "utgå",
    "utgångnas": "utgå",
    "utgångne": "utgå",
    "utgångnes": "utgå",
    "utgångs": "utgång",
    "utgångsdatumen": "utgångsdatum",
    "utgångsdatumens": "utgångsdatum",
    "utgångsdatumet": "utgångsdatum",
    "utgångsdatumets": "utgångsdatum",
    "utgångsdatums": "utgångsdatum",
    "utgångshastigheten": "utgångshastighet",
    "utgångshastighetens": "utgångshastighet",
    "utgångshastigheter": "utgångshastighet",
    "utgångshastigheterna": "utgångshastighet",
    "utgångshastigheternas": "utgångshastighet",
    "utgångshastigheters": "utgångshastighet",
    "utgångshastighets": "utgångshastighet",
    "utgångslägen": "utgångsläge",
    "utgångslägena": "utgångsläge",
    "utgångslägenas": "utgångsläge",
    "utgångslägens": "utgångsläge",
    "utgångsläges": "utgångsläge",
    "utgångsläget": "utgångsläge",
    "utgångslägets": "utgångsläge",
    "utgångsmarschen": "utgångsmarsch",
    "utgångsmarschens": "utgångsmarsch",
    "utgångsmarscher": "utgångsmarsch",
    "utgångsmarscherna": "utgångsmarsch",
    "utgångsmarschernas": "utgångsmarsch",
    "utgångsmarschers": "utgångsmarsch",
    "utgångsmarschs": "utgångsmarsch",
    "utgångsmaterialen": "utgångsmaterial",
    "utgångsmaterialens": "utgångsmaterial",
    "utgångsmaterialet": "utgångsmaterial",
    "utgångsmaterialets": "utgångsmaterial",
    "utgångsmaterials": "utgångsmaterial",
    "utgångspositionen": "utgångsposition",
    "utgångspositionens": "utgångsposition",
    "utgångspositioner": "utgångsposition",
    "utgångspositionerna": "utgångsposition",
    "utgångspositionernas": "utgångsposition",
    "utgångspositioners": "utgångsposition",
    "utgångspositions": "utgångsposition",
    "utgångspunkten": "utgångspunkt",
    "utgångspunktens": "utgångspunkt",
    "utgångspunkter": "utgångspunkt",
    "utgångspunkterna": "utgångspunkt",
    "utgångspunkternas": "utgångspunkt",
    "utgångspunkters": "utgångspunkt",
    "utgångspunkts": "utgångspunkt",
    "utgångsraden": "utgångsrad",
    "utgångsradens": "utgångsrad",
    "utgångsrader": "utgångsrad",
    "utgångsraderna": "utgångsrad",
    "utgångsradernas": "utgångsrad",
    "utgångsraders": "utgångsrad",
    "utgångsrads": "utgångsrad",
    "utgångsställningar": "utgångsställning",
    "utgångsställningarna": "utgångsställning",
    "utgångsställningarnas": "utgångsställning",
    "utgångsställningars": "utgångsställning",
    "utgångsställningen": "utgångsställning",
    "utgångsställningens": "utgångsställning",
    "utgångsställnings": "utgångsställning",
    "utgår": "utgå",
    "utgårdar": "utgård",
    "utgårdarna": "utgård",
    "utgårdarnas": "utgård",
    "utgårdars": "utgård",
    "utgården": "utgård",
    "utgårdens": "utgård",
    "utgårds": "utgård",
    "utgås": "utgå",
    "utgått": "utgå",
    "utgåtts": "utgå",
    "utgåvan": "utgåva",
    "utgåvans": "utgåva",
    "utgåvas": "utgåva",
    "utgåve": "utge",
    "utgåves": "utge",
    "utgåvo": "utgåva",
    "utgåvor": "utgåva",
    "utgåvorna": "utgåva",
    "utgåvornas": "utgåva",
    "utgåvors": "utgåva",
    "utgödslingar": "utgödsling",
    "utgödslingarna": "utgödsling",
    "utgödslingarnas": "utgödsling",
    "utgödslingars": "utgödsling",
    "utgödslingen": "utgödsling",
    "utgödslingens": "utgödsling",
    "utgödslings": "utgödsling",
    "utgör": "utgöra",
    "utgörande": "utgöra",
    "utgöranden": "utgörande",
    "utgörandena": "utgörande",
    "utgörandenas": "utgörande",
    "utgörandens": "utgörande",
    "utgörandes": "utgörande",
    "utgörandet": "utgörande",
    "utgörandets": "utgörande",
    "utgöras": "utgöra",
    "utgöres": "utgöra",
    "utgörs": "utgöra",
    "utgöt": "utgjuta",
    "utgöte": "utgjuta",
    "utgötes": "utgjuta",
    "utgöts": "utgjuta",
    "uthalar": "uthalare",
    "uthalaren": "uthalare",
    "uthalarens": "uthalare",
    "uthalares": "uthalare",
    "uthalarna": "uthalare",
    "uthalarnas": "uthalare",
    "uthamnar": "uthamn",
    "uthamnarna": "uthamn",
    "uthamnarnas": "uthamn",
    "uthamnars": "uthamn",
    "uthamnen": "uthamn",
    "uthamnens": "uthamn",
    "uthamns": "uthamn",
    "uthamrad": "uthamra",
    "uthamrade": "uthamra",
    "uthamrades": "uthamra",
    "uthamrads": "uthamra",
    "uthamrande": "uthamra",
    "uthamranden": "uthamrande",
    "uthamrandena": "uthamrande",
    "uthamrandenas": "uthamrande",
    "uthamrandens": "uthamrande",
    "uthamrandes": "uthamrande",
    "uthamrandet": "uthamrande",
    "uthamrandets": "uthamrande",
    "uthamrar": "uthamra",
    "uthamras": "uthamra",
    "uthamrat": "uthamra",
    "uthamrats": "uthamra",
    "uthoppen": "uthopp",
    "uthoppens": "uthopp",
    "uthoppet": "uthopp",
    "uthoppets": "uthopp",
    "uthopps": "uthopp",
    "uthuggningar": "uthuggning",
    "uthuggningarna": "uthuggning",
    "uthuggningarnas": "uthuggning",
    "uthuggningars": "uthuggning",
    "uthuggningen": "uthuggning",
    "uthuggningens": "uthuggning",
    "uthuggnings": "uthuggning",
    "uthungrade": "uthungrad",
    "uthungrades": "uthungrad",
    "uthungrads": "uthungrad",
    "uthungrat": "uthungrad",
    "uthungrats": "uthungrad",
    "uthungringar": "uthungring",
    "uthungringarna": "uthungring",
    "uthungringarnas": "uthungring",
    "uthungringars": "uthungring",
    "uthungringen": "uthungring",
    "uthungringens": "uthungring",
    "uthungrings": "uthungring",
    "uthusen": "uthus",
    "uthusens": "uthus",
    "uthuset": "uthus",
    "uthusets": "uthus",
    "uthusnyckeln": "uthusnyckel",
    "uthusnyckelns": "uthusnyckel",
    "uthusnyckels": "uthusnyckel",
    "uthusnycklar": "uthusnyckel",
    "uthusnycklarna": "uthusnyckel",
    "uthusnycklarnas": "uthusnyckel",
    "uthusnycklars": "uthusnyckel",
    "uthusväggar": "uthusvägg",
    "uthusväggarna": "uthusvägg",
    "uthusväggarnas": "uthusvägg",
    "uthusväggars": "uthusvägg",
    "uthusväggen": "uthusvägg",
    "uthusväggens": "uthusvägg",
    "uthusväggs": "uthusvägg",
    "uthyr": "uthyra",
    "uthyrande": "uthyra",
    "uthyranden": "uthyrande",
    "uthyrandena": "uthyrande",
    "uthyrandenas": "uthyrande",
    "uthyrandens": "uthyrande",
    "uthyrandes": "uthyrande",
    "uthyrandet": "uthyrande",
    "uthyrandets": "uthyrande",
    "uthyras": "uthyra",
    "uthyrd": "uthyra",
    "uthyrda": "uthyra",
    "uthyrdas": "uthyra",
    "uthyrde": "uthyra",
    "uthyrdes": "uthyra",
    "uthyrds": "uthyra",
    "uthyres": "uthyra",
    "uthyrningar": "uthyrning",
    "uthyrningarna": "uthyrning",
    "uthyrningarnas": "uthyrning",
    "uthyrningars": "uthyrning",
    "uthyrningen": "uthyrning",
    "uthyrningens": "uthyrning",
    "uthyrnings": "uthyrning",
    "uthyrningsrummen": "uthyrningsrum",
    "uthyrningsrummens": "uthyrningsrum",
    "uthyrningsrummet": "uthyrningsrum",
    "uthyrningsrummets": "uthyrningsrum",
    "uthyrningsrums": "uthyrningsrum",
    "uthyrs": "uthyra",
    "uthyrt": "uthyra",
    "uthyrts": "uthyra",
    "uthärd": "uthärda",
    "uthärdad": "uthärda",
    "uthärdade": "uthärda",
    "uthärdades": "uthärda",
    "uthärdads": "uthärda",
    "uthärdande": "uthärda",
    "uthärdanden": "uthärdande",
    "uthärdandena": "uthärdande",
    "uthärdandenas": "uthärdande",
    "uthärdandens": "uthärdande",
    "uthärdandes": "uthärdande",
    "uthärdandet": "uthärdande",
    "uthärdandets": "uthärdande",
    "uthärdar": "uthärda",
    "uthärdas": "uthärda",
    "uthärdat": "uthärda",
    "uthärdats": "uthärda",
    "uthärdliga": "uthärdlig",
    "uthärdligare": "uthärdlig",
    "uthärdligares": "uthärdlig",
    "uthärdligas": "uthärdlig",
    "uthärdligast": "uthärdlig",
    "uthärdligaste": "uthärdlig",
    "uthärdligastes": "uthärdlig",
    "uthärdligasts": "uthärdlig",
    "uthärdlige": "uthärdlig",
    "uthärdliges": "uthärdlig",
    "uthärdligheten": "uthärdlighet",
    "uthärdlighetens": "uthärdlighet",
    "uthärdlighets": "uthärdlighet",
    "uthärdligs": "uthärdlig",
    "uthärdligt": "uthärdlig",
    "uthärdligts": "uthärdlig",
    "uthålliga": "uthållig",
    "uthålligare": "uthållig",
    "uthålligares": "uthållig",
    "uthålligas": "uthållig",
    "uthålligast": "uthållig",
    "uthålligaste": "uthållig",
    "uthålligastes": "uthållig",
    "uthålligasts": "uthållig",
    "uthållige": "uthållig",
    "uthålliges": "uthållig",
    "uthålligheten": "uthållighet",
    "uthållighetens": "uthållighet",
    "uthålligheter": "uthållighet",
    "uthålligheterna": "uthållighet",
    "uthålligheternas": "uthållighet",
    "uthålligheters": "uthållighet",
    "uthållighets": "uthållighet",
    "uthållighetslöpningar": "uthållighetslöpning",
    "uthållighetslöpningarna": "uthållighetslöpning",
    "uthållighetslöpningarnas": "uthållighetslöpning",
    "uthållighetslöpningars": "uthållighetslöpning",
    "uthållighetslöpningen": "uthållighetslöpning",
    "uthållighetslöpningens": "uthållighetslöpning",
    "uthållighetslöpnings": "uthållighetslöpning",
    "uthållighetstävlingar": "uthållighetstävling",
    "uthållighetstävlingarna": "uthållighetstävling",
    "uthållighetstävlingarnas": "uthållighetstävling",
    "uthållighetstävlingars": "uthållighetstävling",
    "uthållighetstävlingen": "uthållighetstävling",
    "uthållighetstävlingens": "uthållighetstävling",
    "uthållighetstävlings": "uthållighetstävling",
    "uthålligs": "uthållig",
    "uthålligt": "uthållig",
    "uthålligts": "uthållig",
    "uthållningar": "uthållning",
    "uthållningarna": "uthållning",
    "uthållningarnas": "uthållning",
    "uthållningars": "uthållning",
    "uthållningen": "uthållning",
    "uthållningens": "uthållning",
    "uthållnings": "uthållning",
    "utilismen": "utilism",
    "utilismens": "utilism",
    "utilismer": "utilism",
    "utilismerna": "utilism",
    "utilismernas": "utilism",
    "utilismers": "utilism",
    "utilisms": "utilism",
    "utilisten": "utilist",
    "utilistens": "utilist",
    "utilister": "utilist",
    "utilisterna": "utilist",
    "utilisternas": "utilist",
    "utilisters": "utilist",
    "utilistiska": "utilistisk",
    "utilistiskare": "utilistisk",
    "utilistiskares": "utilistisk",
    "utilistiskas": "utilistisk",
    "utilistiskast": "utilistisk",
    "utilistiskaste": "utilistisk",
    "utilistiskastes": "utilistisk",
    "utilistiskasts": "utilistisk",
    "utilistiske": "utilistisk",
    "utilistiskes": "utilistisk",
    "utilistisks": "utilistisk",
    "utilistiskt": "utilistisk",
    "utilistiskts": "utilistisk",
    "utilists": "utilist",
    "utilitarismen": "utilitarism",
    "utilitarismens": "utilitarism",
    "utilitarismer": "utilitarism",
    "utilitarismerna": "utilitarism",
    "utilitarismernas": "utilitarism",
    "utilitarismers": "utilitarism",
    "utilitarisms": "utilitarism",
    "utilitaristen": "utilitarist",
    "utilitaristens": "utilitarist",
    "utilitarister": "utilitarist",
    "utilitaristerna": "utilitarist",
    "utilitaristernas": "utilitarist",
    "utilitaristers": "utilitarist",
    "utilitaristiska": "utilitaristisk",
    "utilitaristiskare": "utilitaristisk",
    "utilitaristiskares": "utilitaristisk",
    "utilitaristiskas": "utilitaristisk",
    "utilitaristiskast": "utilitaristisk",
    "utilitaristiskaste": "utilitaristisk",
    "utilitaristiskastes": "utilitaristisk",
    "utilitaristiskasts": "utilitaristisk",
    "utilitaristiske": "utilitaristisk",
    "utilitaristiskes": "utilitaristisk",
    "utilitaristisks": "utilitaristisk",
    "utilitaristiskt": "utilitaristisk",
    "utilitaristiskts": "utilitaristisk",
    "utilitarists": "utilitarist",
    "utjorden": "utjord",
    "utjordens": "utjord",
    "utjords": "utjord",
    "utjämn": "utjämna",
    "utjämnad": "utjämna",
    "utjämnade": "utjämna",
    "utjämnades": "utjämna",
    "utjämnads": "utjämna",
    "utjämnande": "utjämna",
    "utjämnanden": "utjämnande",
    "utjämnandena": "utjämnande",
    "utjämnandenas": "utjämnande",
    "utjämnandens": "utjämnande",
    "utjämnandes": "utjämnande",
    "utjämnandet": "utjämnande",
    "utjämnandets": "utjämnande",
    "utjämnar": "utjämna",
    "utjämnas": "utjämna",
    "utjämnat": "utjämna",
    "utjämnats": "utjämna",
    "utjämningar": "utjämning",
    "utjämningarna": "utjämning",
    "utjämningarnas": "utjämning",
    "utjämningars": "utjämning",
    "utjämningen": "utjämning",
    "utjämningens": "utjämning",
    "utjämnings": "utjämning",
    "utjämningsmandaten": "utjämningsmandat",
    "utjämningsmandatens": "utjämningsmandat",
    "utjämningsmandatet": "utjämningsmandat",
    "utjämningsmandatets": "utjämningsmandat",
    "utjämningsmandats": "utjämningsmandat",
    "utkammad": "utkamma",
    "utkammade": "utkamma",
    "utkammades": "utkamma",
    "utkammads": "utkamma",
    "utkammande": "utkamma",
    "utkammanden": "utkammande",
    "utkammandena": "utkammande",
    "utkammandenas": "utkammande",
    "utkammandens": "utkammande",
    "utkammandes": "utkammande",
    "utkammandet": "utkammande",
    "utkammandets": "utkammande",
    "utkammar": "utkamma",
    "utkammas": "utkamma",
    "utkammat": "utkamma",
    "utkammats": "utkamma",
    "utkanten": "utkant",
    "utkantens": "utkant",
    "utkanter": "utkant",
    "utkanterna": "utkant",
    "utkanternas": "utkant",
    "utkanters": "utkant",
    "utkants": "utkant",
    "utkast": "utkasta",
    "utkastad": "utkasta",
    "utkastade": "utkasta",
    "utkastades": "utkasta",
    "utkastads": "utkasta",
    "utkastande": "utkasta",
    "utkastanden": "utkastande",
    "utkastandena": "utkastande",
    "utkastandenas": "utkastande",
    "utkastandens": "utkastande",
    "utkastandes": "utkastande",
    "utkastandet": "utkastande",
    "utkastandets": "utkastande",
    "utkastar": "utkastare",
    "utkastaren": "utkastare",
    "utkastarens": "utkastare",
    "utkastares": "utkastare",
    "utkastarna": "utkastare",
    "utkastarnas": "utkastare",
    "utkastas": "utkasta",
    "utkastat": "utkasta",
    "utkastats": "utkasta",
    "utkasten": "utkast",
    "utkastens": "utkast",
    "utkastet": "utkast",
    "utkastets": "utkast",
    "utkasts": "utkast",
    "utkikar": "utkik",
    "utkikarna": "utkik",
    "utkikarnas": "utkik",
    "utkikars": "utkik",
    "utkiken": "utkik",
    "utkikens": "utkik",
    "utkiks": "utkik",
    "utkikspunkten": "utkikspunkt",
    "utkikspunktens": "utkikspunkt",
    "utkikspunkter": "utkikspunkt",
    "utkikspunkterna": "utkikspunkt",
    "utkikspunkternas": "utkikspunkt",
    "utkikspunkters": "utkikspunkt",
    "utkikspunkts": "utkikspunkt",
    "utklar": "utklara",
    "utklarad": "utklara",
    "utklarade": "utklara",
    "utklarades": "utklara",
    "utklarads": "utklara",
    "utklarande": "utklara",
    "utklaranden": "utklarande",
    "utklarandena": "utklarande",
    "utklarandenas": "utklarande",
    "utklarandens": "utklarande",
    "utklarandes": "utklarande",
    "utklarandet": "utklarande",
    "utklarandets": "utklarande",
    "utklarar": "utklara",
    "utklaras": "utklara",
    "utklarat": "utklara",
    "utklarats": "utklara",
    "utklarerad": "utklarera",
    "utklarerade": "utklarera",
    "utklarerades": "utklarera",
    "utklarerads": "utklarera",
    "utklarerande": "utklarera",
    "utklareranden": "utklarerande",
    "utklarerandena": "utklarerande",
    "utklarerandenas": "utklarerande",
    "utklarerandens": "utklarerande",
    "utklarerandes": "utklarerande",
    "utklarerandet": "utklarerande",
    "utklarerandets": "utklarerande",
    "utklarerar": "utklarera",
    "utklareras": "utklarera",
    "utklarerat": "utklarera",
    "utklarerats": "utklarera",
    "utklarerbara": "utklarerbar",
    "utklarerbarare": "utklarerbar",
    "utklarerbarares": "utklarerbar",
    "utklarerbaras": "utklarerbar",
    "utklarerbarast": "utklarerbar",
    "utklarerbaraste": "utklarerbar",
    "utklarerbarastes": "utklarerbar",
    "utklarerbarasts": "utklarerbar",
    "utklarerbare": "utklarerbar",
    "utklarerbares": "utklarerbar",
    "utklarerbarheten": "utklarerbarhet",
    "utklarerbarhetens": "utklarerbarhet",
    "utklarerbarhets": "utklarerbarhet",
    "utklarerbars": "utklarerbar",
    "utklarerbart": "utklarerbar",
    "utklarerbarts": "utklarerbar",
    "utklareringar": "utklarering",
    "utklareringarna": "utklarering",
    "utklareringarnas": "utklarering",
    "utklareringars": "utklarering",
    "utklareringen": "utklarering",
    "utklareringens": "utklarering",
    "utklarerings": "utklarering",
    "utklass": "utklassa",
    "utklassad": "utklassa",
    "utklassade": "utklassa",
    "utklassades": "utklassa",
    "utklassads": "utklassa",
    "utklassande": "utklassa",
    "utklassanden": "utklassande",
    "utklassandena": "utklassande",
    "utklassandenas": "utklassande",
    "utklassandens": "utklassande",
    "utklassandes": "utklassande",
    "utklassandet": "utklassande",
    "utklassandets": "utklassande",
    "utklassar": "utklassa",
    "utklassas": "utklassa",
    "utklassat": "utklassa",
    "utklassats": "utklassa",
    "utklassningar": "utklassning",
    "utklassningarna": "utklassning",
    "utklassningarnas": "utklassning",
    "utklassningars": "utklassning",
    "utklassningen": "utklassning",
    "utklassningens": "utklassning",
    "utklassnings": "utklassning",
    "utklippen": "utklipp",
    "utklippens": "utklipp",
    "utklippet": "utklipp",
    "utklippets": "utklipp",
    "utklipps": "utklipp",
    "utkluven": "utklyva",
    "utkluvens": "utklyva",
    "utkluvet": "utklyva",
    "utkluvets": "utklyva",
    "utkluvit": "utklyva",
    "utkluvits": "utklyva",
    "utkluvna": "utklyva",
    "utkluvnas": "utklyva",
    "utkluvne": "utklyva",
    "utkluvnes": "utklyva",
    "utklyv": "utklyva",
    "utklyvande": "utklyva",
    "utklyvanden": "utklyvande",
    "utklyvandena": "utklyvande",
    "utklyvandenas": "utklyvande",
    "utklyvandens": "utklyvande",
    "utklyvandes": "utklyvande",
    "utklyvandet": "utklyvande",
    "utklyvandets": "utklyvande",
    "utklyvas": "utklyva",
    "utklyve": "utklyva",
    "utklyver": "utklyva",
    "utklyves": "utklyva",
    "utklyvs": "utklyva",
    "utklädda": "utklädd",
    "utkläddare": "utklädd",
    "utkläddares": "utklädd",
    "utkläddas": "utklädd",
    "utkläddast": "utklädd",
    "utkläddaste": "utklädd",
    "utkläddastes": "utklädd",
    "utkläddasts": "utklädd",
    "utklädde": "utklädd",
    "utkläddes": "utklädd",
    "utklädds": "utklädd",
    "utklädseln": "utklädsel",
    "utklädselns": "utklädsel",
    "utklädsels": "utklädsel",
    "utklängningar": "utklängning",
    "utklängningarna": "utklängning",
    "utklängningarnas": "utklängning",
    "utklängningars": "utklängning",
    "utklängningen": "utklängning",
    "utklängningens": "utklängning",
    "utklängnings": "utklängning",
    "utklätt": "utklädd",
    "utklätts": "utklädd",
    "utklöv": "utklyva",
    "utklöve": "utklyva",
    "utklöves": "utklyva",
    "utklövs": "utklyva",
    "utkom": "utkomma",
    "utkomet": "utkomma",
    "utkomets": "utkomma",
    "utkommande": "utkomma",
    "utkommanden": "utkommande",
    "utkommandena": "utkommande",
    "utkommandenas": "utkommande",
    "utkommandens": "utkommande",
    "utkommandes": "utkommande",
    "utkommandet": "utkommande",
    "utkommandets": "utkommande",
    "utkommas": "utkomma",
    "utkomme": "utkomma",
    "utkommen": "utkomma",
    "utkommenderad": "utkommendera",
    "utkommenderade": "utkommendera",
    "utkommenderades": "utkommendera",
    "utkommenderads": "utkommendera",
    "utkommenderande": "utkommendera",
    "utkommenderanden": "utkommenderande",
    "utkommenderandena": "utkommenderande",
    "utkommenderandenas": "utkommenderande",
    "utkommenderandens": "utkommenderande",
    "utkommenderandes": "utkommenderande",
    "utkommenderandet": "utkommenderande",
    "utkommenderandets": "utkommenderande",
    "utkommenderar": "utkommendera",
    "utkommenderas": "utkommendera",
    "utkommenderat": "utkommendera",
    "utkommenderats": "utkommendera",
    "utkommenderbara": "utkommenderbar",
    "utkommenderbarare": "utkommenderbar",
    "utkommenderbarares": "utkommenderbar",
    "utkommenderbaras": "utkommenderbar",
    "utkommenderbarast": "utkommenderbar",
    "utkommenderbaraste": "utkommenderbar",
    "utkommenderbarastes": "utkommenderbar",
    "utkommenderbarasts": "utkommenderbar",
    "utkommenderbare": "utkommenderbar",
    "utkommenderbares": "utkommenderbar",
    "utkommenderbarheten": "utkommenderbarhet",
    "utkommenderbarhetens": "utkommenderbarhet",
    "utkommenderbarhets": "utkommenderbarhet",
    "utkommenderbars": "utkommenderbar",
    "utkommenderbart": "utkommenderbar",
    "utkommenderbarts": "utkommenderbar",
    "utkommenderingar": "utkommendering",
    "utkommenderingarna": "utkommendering",
    "utkommenderingarnas": "utkommendering",
    "utkommenderingars": "utkommendering",
    "utkommenderingen": "utkommendering",
    "utkommenderingens": "utkommendering",
    "utkommenderings": "utkommendering",
    "utkommens": "utkomma",
    "utkommer": "utkomma",
    "utkommes": "utkomma",
    "utkommit": "utkomma",
    "utkommits": "utkomma",
    "utkomna": "utkomma",
    "utkomnas": "utkomma",
    "utkomne": "utkomma",
    "utkomnes": "utkomma",
    "utkoms": "utkomma",
    "utkomsten": "utkomst",
    "utkomstens": "utkomst",
    "utkomsts": "utkomst",
    "utkonkurrerad": "utkonkurrera",
    "utkonkurrerade": "utkonkurrera",
    "utkonkurrerades": "utkonkurrera",
    "utkonkurrerads": "utkonkurrera",
    "utkonkurrerande": "utkonkurrera",
    "utkonkurreranden": "utkonkurrerande",
    "utkonkurrerandena": "utkonkurrerande",
    "utkonkurrerandenas": "utkonkurrerande",
    "utkonkurrerandens": "utkonkurrerande",
    "utkonkurrerandes": "utkonkurrerande",
    "utkonkurrerandet": "utkonkurrerande",
    "utkonkurrerandets": "utkonkurrerande",
    "utkonkurrerar": "utkonkurrera",
    "utkonkurreras": "utkonkurrera",
    "utkonkurrerat": "utkonkurrera",
    "utkonkurrerats": "utkonkurrera",
    "utkonkurrerbara": "utkonkurrerbar",
    "utkonkurrerbarare": "utkonkurrerbar",
    "utkonkurrerbarares": "utkonkurrerbar",
    "utkonkurrerbaras": "utkonkurrerbar",
    "utkonkurrerbarast": "utkonkurrerbar",
    "utkonkurrerbaraste": "utkonkurrerbar",
    "utkonkurrerbarastes": "utkonkurrerbar",
    "utkonkurrerbarasts": "utkonkurrerbar",
    "utkonkurrerbare": "utkonkurrerbar",
    "utkonkurrerbares": "utkonkurrerbar",
    "utkonkurrerbarheten": "utkonkurrerbarhet",
    "utkonkurrerbarhetens": "utkonkurrerbarhet",
    "utkonkurrerbarhets": "utkonkurrerbarhet",
    "utkonkurrerbars": "utkonkurrerbar",
    "utkonkurrerbart": "utkonkurrerbar",
    "utkonkurrerbarts": "utkonkurrerbar",
    "utkonkurreringar": "utkonkurrering",
    "utkonkurreringarna": "utkonkurrering",
    "utkonkurreringarnas": "utkonkurrering",
    "utkonkurreringars": "utkonkurrering",
    "utkonkurreringen": "utkonkurrering",
    "utkonkurreringens": "utkonkurrering",
    "utkonkurrerings": "utkonkurrering",
    "utkor": "utkora",
    "utkorad": "utkora",
    "utkorade": "utkorad",
    "utkorades": "utkorad",
    "utkorads": "utkorad",
    "utkorande": "utkora",
    "utkoranden": "utkorande",
    "utkorandena": "utkorande",
    "utkorandenas": "utkorande",
    "utkorandens": "utkorande",
    "utkorandes": "utkorande",
    "utkorandet": "utkorande",
    "utkorandets": "utkorande",
    "utkorar": "utkora",
    "utkoras": "utkora",
    "utkorat": "utkorad",
    "utkorats": "utkorad",
    "utkorelsen": "utkorelse",
    "utkorelsens": "utkorelse",
    "utkorelser": "utkorelse",
    "utkorelserna": "utkorelse",
    "utkorelsernas": "utkorelse",
    "utkorelsers": "utkorelse",
    "utkorelses": "utkorelse",
    "utkragningar": "utkragning",
    "utkragningarna": "utkragning",
    "utkragningarnas": "utkragning",
    "utkragningars": "utkragning",
    "utkragningen": "utkragning",
    "utkragningens": "utkragning",
    "utkragnings": "utkragning",
    "utkristalliserad": "utkristallisera",
    "utkristalliserade": "utkristallisera",
    "utkristalliserades": "utkristallisera",
    "utkristalliserads": "utkristallisera",
    "utkristalliserande": "utkristallisera",
    "utkristalliseranden": "utkristalliserande",
    "utkristalliserandena": "utkristalliserande",
    "utkristalliserandenas": "utkristalliserande",
    "utkristalliserandens": "utkristalliserande",
    "utkristalliserandes": "utkristalliserande",
    "utkristalliserandet": "utkristalliserande",
    "utkristalliserandets": "utkristalliserande",
    "utkristalliserar": "utkristallisera",
    "utkristalliseras": "utkristallisera",
    "utkristalliserat": "utkristallisera",
    "utkristalliserats": "utkristallisera",
    "utkristalliserbara": "utkristalliserbar",
    "utkristalliserbarare": "utkristalliserbar",
    "utkristalliserbarares": "utkristalliserbar",
    "utkristalliserbaras": "utkristalliserbar",
    "utkristalliserbarast": "utkristalliserbar",
    "utkristalliserbaraste": "utkristalliserbar",
    "utkristalliserbarastes": "utkristalliserbar",
    "utkristalliserbarasts": "utkristalliserbar",
    "utkristalliserbare": "utkristalliserbar",
    "utkristalliserbares": "utkristalliserbar",
    "utkristalliserbarheten": "utkristalliserbarhet",
    "utkristalliserbarhetens": "utkristalliserbarhet",
    "utkristalliserbarhets": "utkristalliserbarhet",
    "utkristalliserbars": "utkristalliserbar",
    "utkristalliserbart": "utkristalliserbar",
    "utkristalliserbarts": "utkristalliserbar",
    "utkristalliseringar": "utkristallisering",
    "utkristalliseringarna": "utkristallisering",
    "utkristalliseringarnas": "utkristallisering",
    "utkristalliseringars": "utkristallisering",
    "utkristalliseringen": "utkristallisering",
    "utkristalliseringens": "utkristallisering",
    "utkristalliserings": "utkristallisering",
    "utkräv": "utkräva",
    "utkrävande": "utkräva",
    "utkrävanden": "utkrävande",
    "utkrävandena": "utkrävande",
    "utkrävandenas": "utkrävande",
    "utkrävandens": "utkrävande",
    "utkrävandes": "utkrävande",
    "utkrävandet": "utkrävande",
    "utkrävandets": "utkrävande",
    "utkrävas": "utkräva",
    "utkrävd": "utkräva",
    "utkrävda": "utkräva",
    "utkrävdas": "utkräva",
    "utkrävde": "utkräva",
    "utkrävdes": "utkräva",
    "utkrävds": "utkräva",
    "utkräver": "utkräva",
    "utkräves": "utkräva",
    "utkrävs": "utkräva",
    "utkrävt": "utkräva",
    "utkrävts": "utkräva",
    "utkvitterad": "utkvittera",
    "utkvitterade": "utkvittera",
    "utkvitterades": "utkvittera",
    "utkvitterads": "utkvittera",
    "utkvitterande": "utkvittera",
    "utkvitteranden": "utkvitterande",
    "utkvitterandena": "utkvitterande",
    "utkvitterandenas": "utkvitterande",
    "utkvitterandens": "utkvitterande",
    "utkvitterandes": "utkvitterande",
    "utkvitterandet": "utkvitterande",
    "utkvitterandets": "utkvitterande",
    "utkvitterar": "utkvittera",
    "utkvitteras": "utkvittera",
    "utkvitterat": "utkvittera",
    "utkvitterats": "utkvittera",
    "utkvitterbara": "utkvitterbar",
    "utkvitterbarare": "utkvitterbar",
    "utkvitterbarares": "utkvitterbar",
    "utkvitterbaras": "utkvitterbar",
    "utkvitterbarast": "utkvitterbar",
    "utkvitterbaraste": "utkvitterbar",
    "utkvitterbarastes": "utkvitterbar",
    "utkvitterbarasts": "utkvitterbar",
    "utkvitterbare": "utkvitterbar",
    "utkvitterbares": "utkvitterbar",
    "utkvitterbarheten": "utkvitterbarhet",
    "utkvitterbarhetens": "utkvitterbarhet",
    "utkvitterbarhets": "utkvitterbarhet",
    "utkvitterbars": "utkvitterbar",
    "utkvitterbart": "utkvitterbar",
    "utkvitterbarts": "utkvitterbar",
    "utkvitteringar": "utkvittering",
    "utkvitteringarna": "utkvittering",
    "utkvitteringarnas": "utkvittering",
    "utkvitteringars": "utkvittering",
    "utkvitteringen": "utkvittering",
    "utkvitteringens": "utkvittering",
    "utkvitterings": "utkvittering",
    "utkyl": "utkyla",
    "utkylande": "utkyla",
    "utkylanden": "utkylande",
    "utkylandena": "utkylande",
    "utkylandenas": "utkylande",
    "utkylandens": "utkylande",
    "utkylandes": "utkylande",
    "utkylandet": "utkylande",
    "utkylandets": "utkylande",
    "utkylas": "utkyla",
    "utkyld": "utkyla",
    "utkylda": "utkyld",
    "utkyldare": "utkyld",
    "utkyldares": "utkyld",
    "utkyldas": "utkyld",
    "utkyldast": "utkyld",
    "utkyldaste": "utkyld",
    "utkyldastes": "utkyld",
    "utkyldasts": "utkyld",
    "utkylde": "utkyld",
    "utkyldes": "utkyld",
    "utkyldheten": "utkyldhet",
    "utkyldhetens": "utkyldhet",
    "utkyldhets": "utkyldhet",
    "utkylds": "utkyld",
    "utkyler": "utkyla",
    "utkyles": "utkyla",
    "utkyls": "utkyla",
    "utkylt": "utkyld",
    "utkylts": "utkyld",
    "utkämp": "utkämpa",
    "utkämpad": "utkämpa",
    "utkämpade": "utkämpa",
    "utkämpades": "utkämpa",
    "utkämpads": "utkämpa",
    "utkämpande": "utkämpa",
    "utkämpanden": "utkämpande",
    "utkämpandena": "utkämpande",
    "utkämpandenas": "utkämpande",
    "utkämpandens": "utkämpande",
    "utkämpandes": "utkämpande",
    "utkämpandet": "utkämpande",
    "utkämpandets": "utkämpande",
    "utkämpar": "utkämpa",
    "utkämpas": "utkämpa",
    "utkämpat": "utkämpa",
    "utkämpats": "utkämpa",
    "utkörar": "utkörare",
    "utköraren": "utkörare",
    "utkörarens": "utkörare",
    "utkörares": "utkörare",
    "utkörarna": "utkörare",
    "utkörarnas": "utkörare",
    "utkörda": "utkörd",
    "utkördare": "utkörd",
    "utkördares": "utkörd",
    "utkördas": "utkörd",
    "utkördast": "utkörd",
    "utkördaste": "utkörd",
    "utkördastes": "utkörd",
    "utkördasts": "utkörd",
    "utkörde": "utkörd",
    "utkördes": "utkörd",
    "utkördheten": "utkördhet",
    "utkördhetens": "utkördhet",
    "utkördhets": "utkördhet",
    "utkörds": "utkörd",
    "utkörningar": "utkörning",
    "utkörningarna": "utkörning",
    "utkörningarnas": "utkörning",
    "utkörningars": "utkörning",
    "utkörningen": "utkörning",
    "utkörningens": "utkörning",
    "utkörnings": "utkörning",
    "utkört": "utkörd",
    "utkörts": "utkörd",
    "utla": "utlägga",
    "utlade": "utlägga",
    "utlades": "utlägga",
    "utlagd": "utlägga",
    "utlagda": "utlägga",
    "utlagdas": "utlägga",
    "utlagde": "utlägga",
    "utlagdes": "utlägga",
    "utlagds": "utlägga",
    "utlagt": "utlägga",
    "utlagts": "utlägga",
    "utlandet": "utland",
    "utlandets": "utland",
    "utlands": "utland",
    "utlandsförsäljningen": "utlandsförsäljning",
    "utlandsförsäljningens": "utlandsförsäljning",
    "utlandsförsäljnings": "utlandsförsäljning",
    "utlandskorrespondenten": "utlandskorrespondent",
    "utlandskorrespondentens": "utlandskorrespondent",
    "utlandskorrespondenter": "utlandskorrespondent",
    "utlandskorrespondenterna": "utlandskorrespondent",
    "utlandskorrespondenternas": "utlandskorrespondent",
    "utlandskorrespondenters": "utlandskorrespondent",
    "utlandskorrespondents": "utlandskorrespondent",
    "utlandslektorer": "utlandslektor",
    "utlandslektorerna": "utlandslektor",
    "utlandslektorernas": "utlandslektor",
    "utlandslektorers": "utlandslektor",
    "utlandslektorn": "utlandslektor",
    "utlandslektorns": "utlandslektor",
    "utlandslektors": "utlandslektor",
    "utlandsresan": "utlandsresa",
    "utlandsresans": "utlandsresa",
    "utlandsresas": "utlandsresa",
    "utlandsrese": "utlandsresa",
    "utlandsresor": "utlandsresa",
    "utlandsresorna": "utlandsresa",
    "utlandsresornas": "utlandsresa",
    "utlandsresors": "utlandsresa",
    "utlandssoldaten": "utlandssoldat",
    "utlandssoldatens": "utlandssoldat",
    "utlandssoldater": "utlandssoldat",
    "utlandssoldaterna": "utlandssoldat",
    "utlandssoldaternas": "utlandssoldat",
    "utlandssoldaters": "utlandssoldat",
    "utlandssoldats": "utlandssoldat",
    "utlandssvenskan": "utlandssvenska",
    "utlandssvenskans": "utlandssvenska",
    "utlandssvenskar": "utlandssvensk",
    "utlandssvenskarna": "utlandssvensk",
    "utlandssvenskarnas": "utlandssvensk",
    "utlandssvenskars": "utlandssvensk",
    "utlandssvenskas": "utlandssvenska",
    "utlandssvenske": "utlandssvenska",
    "utlandssvensken": "utlandssvensk",
    "utlandssvenskens": "utlandssvensk",
    "utlandssvenskor": "utlandssvenska",
    "utlandssvenskorna": "utlandssvenska",
    "utlandssvenskornas": "utlandssvenska",
    "utlandssvenskors": "utlandssvenska",
    "utlandssvensks": "utlandssvensk",
    "utlandstjänsten": "utlandstjänst",
    "utlandstjänstens": "utlandstjänst",
    "utlandstjänsts": "utlandstjänst",
    "utlandsuppdragen": "utlandsuppdrag",
    "utlandsuppdragens": "utlandsuppdrag",
    "utlandsuppdraget": "utlandsuppdrag",
    "utlandsuppdragets": "utlandsuppdrag",
    "utlandsuppdrags": "utlandsuppdrag",
    "utlas": "utlägga",
    "utleda": "utled",
    "utledare": "utled",
    "utledares": "utled",
    "utledas": "utled",
    "utledast": "utled",
    "utledaste": "utled",
    "utledastes": "utled",
    "utledasts": "utled",
    "utlede": "utled",
    "utledes": "utled",
    "utledheten": "utledhet",
    "utledhetens": "utledhet",
    "utledhets": "utledhet",
    "utleds": "utled",
    "utledsens": "utledsen",
    "utledset": "utledsen",
    "utledsets": "utledsen",
    "utledsna": "utledsen",
    "utledsnare": "utledsen",
    "utledsnares": "utledsen",
    "utledsnas": "utledsen",
    "utledsnast": "utledsen",
    "utledsnaste": "utledsen",
    "utledsnastes": "utledsen",
    "utledsnasts": "utledsen",
    "utledsne": "utledsen",
    "utledsnes": "utledsen",
    "utlett": "utled",
    "utletts": "utled",
    "utlevade": "utlevad",
    "utlevades": "utlevad",
    "utlevads": "utlevad",
    "utlevat": "utlevad",
    "utlevats": "utlevad",
    "utlevelsen": "utlevelse",
    "utlevelsens": "utlevelse",
    "utlevelses": "utlevelse",
    "utljuden": "utljud",
    "utljudens": "utljud",
    "utljudet": "utljud",
    "utljudets": "utljud",
    "utljuds": "utljud",
    "utloggningar": "utloggning",
    "utloggningarna": "utloggning",
    "utloggningarnas": "utloggning",
    "utloggningars": "utloggning",
    "utloggningen": "utloggning",
    "utloggningens": "utloggning",
    "utloggnings": "utloggning",
    "utlokaliserad": "utlokalisera",
    "utlokaliserade": "utlokalisera",
    "utlokaliserades": "utlokalisera",
    "utlokaliserads": "utlokalisera",
    "utlokaliserande": "utlokalisera",
    "utlokaliseranden": "utlokaliserande",
    "utlokaliserandena": "utlokaliserande",
    "utlokaliserandenas": "utlokaliserande",
    "utlokaliserandens": "utlokaliserande",
    "utlokaliserandes": "utlokaliserande",
    "utlokaliserandet": "utlokaliserande",
    "utlokaliserandets": "utlokaliserande",
    "utlokaliserar": "utlokalisera",
    "utlokaliseras": "utlokalisera",
    "utlokaliserat": "utlokalisera",
    "utlokaliserats": "utlokalisera",
    "utlokaliserbara": "utlokaliserbar",
    "utlokaliserbarare": "utlokaliserbar",
    "utlokaliserbarares": "utlokaliserbar",
    "utlokaliserbaras": "utlokaliserbar",
    "utlokaliserbarast": "utlokaliserbar",
    "utlokaliserbaraste": "utlokaliserbar",
    "utlokaliserbarastes": "utlokaliserbar",
    "utlokaliserbarasts": "utlokaliserbar",
    "utlokaliserbare": "utlokaliserbar",
    "utlokaliserbares": "utlokaliserbar",
    "utlokaliserbarheten": "utlokaliserbarhet",
    "utlokaliserbarhetens": "utlokaliserbarhet",
    "utlokaliserbarhets": "utlokaliserbarhet",
    "utlokaliserbars": "utlokaliserbar",
    "utlokaliserbart": "utlokaliserbar",
    "utlokaliserbarts": "utlokaliserbar",
    "utlokaliseringar": "utlokalisering",
    "utlokaliseringarna": "utlokalisering",
    "utlokaliseringarnas": "utlokalisering",
    "utlokaliseringars": "utlokalisering",
    "utlokaliseringen": "utlokalisering",
    "utlokaliseringens": "utlokalisering",
    "utlokaliserings": "utlokalisering",
    "utloppen": "utlopp",
    "utloppens": "utlopp",
    "utloppet": "utlopp",
    "utloppets": "utlopp",
    "utlopps": "utlopp",
    "utlott": "utlotta",
    "utlottad": "utlotta",
    "utlottade": "utlotta",
    "utlottades": "utlotta",
    "utlottads": "utlotta",
    "utlottande": "utlotta",
    "utlottanden": "utlottande",
    "utlottandena": "utlottande",
    "utlottandenas": "utlottande",
    "utlottandens": "utlottande",
    "utlottandes": "utlottande",
    "utlottandet": "utlottande",
    "utlottandets": "utlottande",
    "utlottar": "utlotta",
    "utlottas": "utlotta",
    "utlottat": "utlotta",
    "utlottats": "utlotta",
    "utlov": "utlova",
    "utlovad": "utlova",
    "utlovade": "utlova",
    "utlovades": "utlova",
    "utlovads": "utlova",
    "utlovande": "utlova",
    "utlovanden": "utlovande",
    "utlovandena": "utlovande",
    "utlovandenas": "utlovande",
    "utlovandens": "utlovande",
    "utlovandes": "utlovande",
    "utlovandet": "utlovande",
    "utlovandets": "utlovande",
    "utlovar": "utlova",
    "utlovas": "utlova",
    "utlovat": "utlova",
    "utlovats": "utlova",
    "utlupen": "utlöpa",
    "utlupens": "utlöpa",
    "utlupet": "utlöpa",
    "utlupets": "utlöpa",
    "utlupna": "utlöpa",
    "utlupnas": "utlöpa",
    "utlupne": "utlöpa",
    "utlupnes": "utlöpa",
    "utlys": "utlysa",
    "utlysande": "utlysa",
    "utlysanden": "utlysande",
    "utlysandena": "utlysande",
    "utlysandenas": "utlysande",
    "utlysandens": "utlysande",
    "utlysandes": "utlysande",
    "utlysandet": "utlysande",
    "utlysandets": "utlysande",
    "utlysas": "utlysa",
    "utlyser": "utlysa",
    "utlyses": "utlysa",
    "utlyst": "utlysa",
    "utlysta": "utlysa",
    "utlystas": "utlysa",
    "utlyste": "utlysa",
    "utlystes": "utlysa",
    "utlysts": "utlysa",
    "utlägg": "utlägga",
    "utläggande": "utlägga",
    "utlägganden": "utläggande",
    "utläggandena": "utläggande",
    "utläggandenas": "utläggande",
    "utläggandens": "utläggande",
    "utläggandes": "utläggande",
    "utläggandet": "utläggande",
    "utläggandets": "utläggande",
    "utläggas": "utlägga",
    "utläggen": "utlägg",
    "utläggens": "utlägg",
    "utlägger": "utlägga",
    "utlägges": "utlägga",
    "utlägget": "utlägg",
    "utläggets": "utlägg",
    "utläggningar": "utläggning",
    "utläggningarna": "utläggning",
    "utläggningarnas": "utläggning",
    "utläggningars": "utläggning",
    "utläggningen": "utläggning",
    "utläggningens": "utläggning",
    "utläggnings": "utläggning",
    "utläggs": "utlägga",
    "utlämnad": "utlämna",
    "utlämnade": "utlämna",
    "utlämnades": "utlämna",
    "utlämnads": "utlämna",
    "utlämnande": "utlämna",
    "utlämnanden": "utlämnande",
    "utlämnandena": "utlämnande",
    "utlämnandenas": "utlämnande",
    "utlämnandens": "utlämnande",
    "utlämnandes": "utlämnande",
    "utlämnandet": "utlämnande",
    "utlämnandets": "utlämnande",
    "utlämnar": "utlämna",
    "utlämnas": "utlämna",
    "utlämnat": "utlämna",
    "utlämnats": "utlämna",
    "utlämningar": "utlämning",
    "utlämningarna": "utlämning",
    "utlämningarnas": "utlämning",
    "utlämningars": "utlämning",
    "utlämningen": "utlämning",
    "utlämningens": "utlämning",
    "utlämnings": "utlämning",
    "utländsk": "utländska",
    "utländska": "utländsk",
    "utländskan": "utländska",
    "utländskans": "utländska",
    "utländskare": "utländsk",
    "utländskares": "utländsk",
    "utländskas": "utländska",
    "utländskast": "utländsk",
    "utländskaste": "utländsk",
    "utländskastes": "utländsk",
    "utländskasts": "utländsk",
    "utländske": "utländska",
    "utländskes": "utländsk",
    "utländskor": "utländska",
    "utländskorna": "utländska",
    "utländskornas": "utländska",
    "utländskors": "utländska",
    "utländsks": "utländsk",
    "utländskt": "utländsk",
    "utländskts": "utländsk",
    "utlänningar": "utlänning",
    "utlänningarna": "utlänning",
    "utlänningarnas": "utlänning",
    "utlänningars": "utlänning",
    "utlänningen": "utlänning",
    "utlänningens": "utlänning",
    "utlännings": "utlänning",
    "utlärda": "utlärd",
    "utlärdare": "utlärd",
    "utlärdares": "utlärd",
    "utlärdas": "utlärd",
    "utlärdast": "utlärd",
    "utlärdaste": "utlärd",
    "utlärdastes": "utlärd",
    "utlärdasts": "utlärd",
    "utlärde": "utlärd",
    "utlärdes": "utlärd",
    "utlärds": "utlärd",
    "utlärt": "utlärd",
    "utlärts": "utlärd",
    "utläs": "utläsa",
    "utläsande": "utläsa",
    "utläsanden": "utläsande",
    "utläsandena": "utläsande",
    "utläsandenas": "utläsande",
    "utläsandens": "utläsande",
    "utläsandes": "utläsande",
    "utläsandet": "utläsande",
    "utläsandets": "utläsande",
    "utläsas": "utläsa",
    "utläser": "utläsa",
    "utläses": "utläsa",
    "utläst": "utläsa",
    "utlästa": "utläsa",
    "utlästas": "utläsa",
    "utläste": "utläsa",
    "utlästes": "utläsa",
    "utlästs": "utläsa",
    "utlån": "utlåna",
    "utlånade": "utlåna",
    "utlånades": "utlåna",
    "utlånande": "utlåna",
    "utlånanden": "utlånande",
    "utlånandena": "utlånande",
    "utlånandenas": "utlånande",
    "utlånandens": "utlånande",
    "utlånandes": "utlånande",
    "utlånandet": "utlånande",
    "utlånandets": "utlånande",
    "utlånar": "utlånare",
    "utlånaren": "utlånare",
    "utlånarens": "utlånare",
    "utlånares": "utlånare",
    "utlånarna": "utlånare",
    "utlånarnas": "utlånare",
    "utlånas": "utlåna",
    "utlånat": "utlåna",
    "utlånats": "utlåna",
    "utlåningar": "utlåning",
    "utlåningarna": "utlåning",
    "utlåningarnas": "utlåning",
    "utlåningars": "utlåning",
    "utlåningen": "utlåning",
    "utlåningens": "utlåning",
    "utlånings": "utlåning",
    "utlåtanden": "utlåtande",
    "utlåtandena": "utlåtande",
    "utlåtandenas": "utlåtande",
    "utlåtandens": "utlåtande",
    "utlåtandes": "utlåtande",
    "utlåtandet": "utlåtande",
    "utlåtandets": "utlåtande",
    "utlåtelsen": "utlåtelse",
    "utlåtelsens": "utlåtelse",
    "utlåtelser": "utlåtelse",
    "utlåtelserna": "utlåtelse",
    "utlåtelsernas": "utlåtelse",
    "utlåtelsers": "utlåtelse",
    "utlåtelses": "utlåtelse",
    "utlöp": "utlöpa",
    "utlöpande": "utlöpa",
    "utlöpanden": "utlöpande",
    "utlöpandena": "utlöpande",
    "utlöpandenas": "utlöpande",
    "utlöpandens": "utlöpande",
    "utlöpandes": "utlöpande",
    "utlöpandet": "utlöpande",
    "utlöpandets": "utlöpande",
    "utlöpar": "utlöpare",
    "utlöparen": "utlöpare",
    "utlöparens": "utlöpare",
    "utlöpares": "utlöpare",
    "utlöparna": "utlöpare",
    "utlöparnas": "utlöpare",
    "utlöpas": "utlöpa",
    "utlöper": "utlöpa",
    "utlöpes": "utlöpa",
    "utlöps": "utlöpa",
    "utlöpt": "utlöpa",
    "utlöpte": "utlöpa",
    "utlöptes": "utlöpa",
    "utlöpts": "utlöpa",
    "utlös": "utlösa",
    "utlösande": "utlösa",
    "utlösanden": "utlösande",
    "utlösandena": "utlösande",
    "utlösandenas": "utlösande",
    "utlösandens": "utlösande",
    "utlösandes": "utlösande",
    "utlösandet": "utlösande",
    "utlösandets": "utlösande",
    "utlösar": "utlösare",
    "utlösaren": "utlösare",
    "utlösarens": "utlösare",
    "utlösares": "utlösare",
    "utlösarna": "utlösare",
    "utlösarnas": "utlösare",
    "utlösas": "utlösa",
    "utlöser": "utlösa",
    "utlöses": "utlösa",
    "utlösningar": "utlösning",
    "utlösningarna": "utlösning",
    "utlösningarnas": "utlösning",
    "utlösningars": "utlösning",
    "utlösningen": "utlösning",
    "utlösningens": "utlösning",
    "utlösnings": "utlösning",
    "utlöst": "utlösa",
    "utlösta": "utlösa",
    "utlöstas": "utlösa",
    "utlöste": "utlösa",
    "utlöstes": "utlösa",
    "utlösts": "utlösa",
    "utman": "utmana",
    "utmanad": "utmana",
    "utmanade": "utmana",
    "utmanades": "utmana",
    "utmanads": "utmana",
    "utmanande": "utmana",
    "utmananden": "utmanande",
    "utmanandena": "utmanande",
    "utmanandenas": "utmanande",
    "utmanandens": "utmanande",
    "utmanandes": "utmanande",
    "utmanandet": "utmanande",
    "utmanandets": "utmanande",
    "utmanar": "utmanare",
    "utmanaren": "utmanare",
    "utmanarens": "utmanare",
    "utmanares": "utmanare",
    "utmanarna": "utmanare",
    "utmanarnas": "utmanare",
    "utmanas": "utmana",
    "utmanat": "utmana",
    "utmanats": "utmana",
    "utmaningar": "utmaning",
    "utmaningarna": "utmaning",
    "utmaningarnas": "utmaning",
    "utmaningars": "utmaning",
    "utmaningen": "utmaning",
    "utmaningens": "utmaning",
    "utmanings": "utmaning",
    "utmanövrerad": "utmanövrera",
    "utmanövrerade": "utmanövrera",
    "utmanövrerades": "utmanövrera",
    "utmanövrerads": "utmanövrera",
    "utmanövrerande": "utmanövrera",
    "utmanövreranden": "utmanövrerande",
    "utmanövrerandena": "utmanövrerande",
    "utmanövrerandenas": "utmanövrerande",
    "utmanövrerandens": "utmanövrerande",
    "utmanövrerandes": "utmanövrerande",
    "utmanövrerandet": "utmanövrerande",
    "utmanövrerandets": "utmanövrerande",
    "utmanövrerar": "utmanövrera",
    "utmanövreras": "utmanövrera",
    "utmanövrerat": "utmanövrera",
    "utmanövrerats": "utmanövrera",
    "utmanövrerbara": "utmanövrerbar",
    "utmanövrerbarare": "utmanövrerbar",
    "utmanövrerbarares": "utmanövrerbar",
    "utmanövrerbaras": "utmanövrerbar",
    "utmanövrerbarast": "utmanövrerbar",
    "utmanövrerbaraste": "utmanövrerbar",
    "utmanövrerbarastes": "utmanövrerbar",
    "utmanövrerbarasts": "utmanövrerbar",
    "utmanövrerbare": "utmanövrerbar",
    "utmanövrerbares": "utmanövrerbar",
    "utmanövrerbarheten": "utmanövrerbarhet",
    "utmanövrerbarhetens": "utmanövrerbarhet",
    "utmanövrerbarhets": "utmanövrerbarhet",
    "utmanövrerbars": "utmanövrerbar",
    "utmanövrerbart": "utmanövrerbar",
    "utmanövrerbarts": "utmanövrerbar",
    "utmanövreringar": "utmanövrering",
    "utmanövreringarna": "utmanövrering",
    "utmanövreringarnas": "utmanövrering",
    "utmanövreringars": "utmanövrering",
    "utmanövreringen": "utmanövrering",
    "utmanövreringens": "utmanövrering",
    "utmanövrerings": "utmanövrering",
    "utmarken": "utmark",
    "utmarkens": "utmark",
    "utmarker": "utmark",
    "utmarkerna": "utmark",
    "utmarkernas": "utmark",
    "utmarkers": "utmark",
    "utmarks": "utmark",
    "utmarschen": "utmarsch",
    "utmarschens": "utmarsch",
    "utmarscher": "utmarsch",
    "utmarscherna": "utmarsch",
    "utmarschernas": "utmarsch",
    "utmarschers": "utmarsch",
    "utmarschs": "utmarsch",
    "utmatningar": "utmatning",
    "utmatningarna": "utmatning",
    "utmatningarnas": "utmatning",
    "utmatningars": "utmatning",
    "utmatningen": "utmatning",
    "utmatningens": "utmatning",
    "utmatnings": "utmatning",
    "utmatt": "utmatta",
    "utmattad": "utmatta",
    "utmattade": "utmattad",
    "utmattades": "utmattad",
    "utmattads": "utmattad",
    "utmattande": "utmatta",
    "utmattanden": "utmattande",
    "utmattandena": "utmattande",
    "utmattandenas": "utmattande",
    "utmattandens": "utmattande",
    "utmattandes": "utmattande",
    "utmattandet": "utmattande",
    "utmattandets": "utmattande",
    "utmattar": "utmatta",
    "utmattas": "utmatta",
    "utmattat": "utmattad",
    "utmattats": "utmattad",
    "utmattningar": "utmattning",
    "utmattningarna": "utmattning",
    "utmattningarnas": "utmattning",
    "utmattningars": "utmattning",
    "utmattningen": "utmattning",
    "utmattningens": "utmattning",
    "utmattnings": "utmattning",
    "utmattningsskadan": "utmattningsskada",
    "utmattningsskadans": "utmattningsskada",
    "utmattningsskadas": "utmattningsskada",
    "utmattningsskade": "utmattningsskada",
    "utmattningsskador": "utmattningsskada",
    "utmattningsskadorna": "utmattningsskada",
    "utmattningsskadornas": "utmattningsskada",
    "utmattningsskadors": "utmattningsskada",
    "utmejslad": "utmejsla",
    "utmejslade": "utmejsla",
    "utmejslades": "utmejsla",
    "utmejslads": "utmejsla",
    "utmejslande": "utmejsla",
    "utmejslanden": "utmejslande",
    "utmejslandena": "utmejslande",
    "utmejslandenas": "utmejslande",
    "utmejslandens": "utmejslande",
    "utmejslandes": "utmejslande",
    "utmejslandet": "utmejslande",
    "utmejslandets": "utmejslande",
    "utmejslar": "utmejsla",
    "utmejslas": "utmejsla",
    "utmejslat": "utmejsla",
    "utmejslats": "utmejsla",
    "utminuterad": "utminutera",
    "utminuterade": "utminutera",
    "utminuterades": "utminutera",
    "utminuterads": "utminutera",
    "utminuterande": "utminutera",
    "utminuteranden": "utminuterande",
    "utminuterandena": "utminuterande",
    "utminuterandenas": "utminuterande",
    "utminuterandens": "utminuterande",
    "utminuterandes": "utminuterande",
    "utminuterandet": "utminuterande",
    "utminuterandets": "utminuterande",
    "utminuterar": "utminutera",
    "utminuteras": "utminutera",
    "utminuterat": "utminutera",
    "utminuterats": "utminutera",
    "utminuterbara": "utminuterbar",
    "utminuterbarare": "utminuterbar",
    "utminuterbarares": "utminuterbar",
    "utminuterbaras": "utminuterbar",
    "utminuterbarast": "utminuterbar",
    "utminuterbaraste": "utminuterbar",
    "utminuterbarastes": "utminuterbar",
    "utminuterbarasts": "utminuterbar",
    "utminuterbare": "utminuterbar",
    "utminuterbares": "utminuterbar",
    "utminuterbarheten": "utminuterbarhet",
    "utminuterbarhetens": "utminuterbarhet",
    "utminuterbarhets": "utminuterbarhet",
    "utminuterbars": "utminuterbar",
    "utminuterbart": "utminuterbar",
    "utminuterbarts": "utminuterbar",
    "utminuteringar": "utminutering",
    "utminuteringarna": "utminutering",
    "utminuteringarnas": "utminutering",
    "utminuteringars": "utminutering",
    "utminuteringen": "utminutering",
    "utminuteringens": "utminutering",
    "utminuterings": "utminutering",
    "utmynn": "utmynna",
    "utmynnad": "utmynna",
    "utmynnade": "utmynna",
    "utmynnades": "utmynna",
    "utmynnads": "utmynna",
    "utmynnande": "utmynna",
    "utmynnanden": "utmynnande",
    "utmynnandena": "utmynnande",
    "utmynnandenas": "utmynnande",
    "utmynnandens": "utmynnande",
    "utmynnandes": "utmynnande",
    "utmynnandet": "utmynnande",
    "utmynnandets": "utmynnande",
    "utmynnar": "utmynna",
    "utmynnas": "utmynna",
    "utmynnat": "utmynna",
    "utmynnats": "utmynna",
    "utmärglade": "utmärglad",
    "utmärglades": "utmärglad",
    "utmärglads": "utmärglad",
    "utmärglat": "utmärglad",
    "utmärglats": "utmärglad",
    "utmärk": "utmärka",
    "utmärkande": "utmärka",
    "utmärkanden": "utmärkande",
    "utmärkandena": "utmärkande",
    "utmärkandenas": "utmärkande",
    "utmärkandens": "utmärkande",
    "utmärkandes": "utmärkande",
    "utmärkandet": "utmärkande",
    "utmärkandets": "utmärkande",
    "utmärkas": "utmärka",
    "utmärkelsen": "utmärkelse",
    "utmärkelsens": "utmärkelse",
    "utmärkelser": "utmärkelse",
    "utmärkelserna": "utmärkelse",
    "utmärkelsernas": "utmärkelse",
    "utmärkelsers": "utmärkelse",
    "utmärkelses": "utmärkelse",
    "utmärker": "utmärka",
    "utmärkes": "utmärka",
    "utmärkningar": "utmärkning",
    "utmärkningarna": "utmärkning",
    "utmärkningarnas": "utmärkning",
    "utmärkningars": "utmärkning",
    "utmärkningen": "utmärkning",
    "utmärkningens": "utmärkning",
    "utmärknings": "utmärkning",
    "utmärks": "utmärka",
    "utmärkt": "utmärka",
    "utmärkta": "utmärkt",
    "utmärktare": "utmärkt",
    "utmärktares": "utmärkt",
    "utmärktas": "utmärkt",
    "utmärktast": "utmärkt",
    "utmärktaste": "utmärkt",
    "utmärktastes": "utmärkt",
    "utmärktasts": "utmärkt",
    "utmärkte": "utmärkt",
    "utmärktes": "utmärkt",
    "utmärktheten": "utmärkthet",
    "utmärkthetens": "utmärkthet",
    "utmärkthets": "utmärkthet",
    "utmärkts": "utmärkt",
    "utmät": "utmäta",
    "utmätande": "utmäta",
    "utmätanden": "utmätande",
    "utmätandena": "utmätande",
    "utmätandenas": "utmätande",
    "utmätandens": "utmätande",
    "utmätandes": "utmätande",
    "utmätandet": "utmätande",
    "utmätandets": "utmätande",
    "utmätas": "utmäta",
    "utmäter": "utmäta",
    "utmätes": "utmäta",
    "utmätningar": "utmätning",
    "utmätningarna": "utmätning",
    "utmätningarnas": "utmätning",
    "utmätningars": "utmätning",
    "utmätningen": "utmätning",
    "utmätningens": "utmätning",
    "utmätnings": "utmätning",
    "utmäts": "utmäta",
    "utmätt": "utmäta",
    "utmätta": "utmäta",
    "utmättas": "utmäta",
    "utmätte": "utmäta",
    "utmättes": "utmäta",
    "utmätts": "utmäta",
    "utmål": "utmåla",
    "utmålad": "utmåla",
    "utmålade": "utmåla",
    "utmålades": "utmåla",
    "utmålads": "utmåla",
    "utmålande": "utmåla",
    "utmålanden": "utmålande",
    "utmålandena": "utmålande",
    "utmålandenas": "utmålande",
    "utmålandens": "utmålande",
    "utmålandes": "utmålande",
    "utmålandet": "utmålande",
    "utmålandets": "utmålande",
    "utmålar": "utmåla",
    "utmålas": "utmåla",
    "utmålat": "utmåla",
    "utmålats": "utmåla",
    "utmålen": "utmål",
    "utmålens": "utmål",
    "utmålet": "utmål",
    "utmålets": "utmål",
    "utmåls": "utmål",
    "utmönstrad": "utmönstra",
    "utmönstrade": "utmönstra",
    "utmönstrades": "utmönstra",
    "utmönstrads": "utmönstra",
    "utmönstrande": "utmönstra",
    "utmönstranden": "utmönstrande",
    "utmönstrandena": "utmönstrande",
    "utmönstrandenas": "utmönstrande",
    "utmönstrandens": "utmönstrande",
    "utmönstrandes": "utmönstrande",
    "utmönstrandet": "utmönstrande",
    "utmönstrandets": "utmönstrande",
    "utmönstrar": "utmönstra",
    "utmönstras": "utmönstra",
    "utmönstrat": "utmönstra",
    "utmönstrats": "utmönstra",
    "utnyttj": "utnyttja",
    "utnyttjad": "utnyttja",
    "utnyttjade": "utnyttja",
    "utnyttjades": "utnyttja",
    "utnyttjads": "utnyttja",
    "utnyttjande": "utnyttja",
    "utnyttjanden": "utnyttjande",
    "utnyttjandena": "utnyttjande",
    "utnyttjandenas": "utnyttjande",
    "utnyttjandens": "utnyttjande",
    "utnyttjandes": "utnyttjande",
    "utnyttjandet": "utnyttjande",
    "utnyttjandets": "utnyttjande",
    "utnyttjar": "utnyttjare",
    "utnyttjaren": "utnyttjare",
    "utnyttjarens": "utnyttjare",
    "utnyttjares": "utnyttjare",
    "utnyttjarna": "utnyttjare",
    "utnyttjarnas": "utnyttjare",
    "utnyttjas": "utnyttja",
    "utnyttjat": "utnyttja",
    "utnyttjats": "utnyttja",
    "utnämn": "utnämna",
    "utnämnande": "utnämna",
    "utnämnanden": "utnämnande",
    "utnämnandena": "utnämnande",
    "utnämnandenas": "utnämnande",
    "utnämnandens": "utnämnande",
    "utnämnandes": "utnämnande",
    "utnämnandet": "utnämnande",
    "utnämnandets": "utnämnande",
    "utnämnas": "utnämna",
    "utnämnd": "utnämna",
    "utnämnda": "utnämna",
    "utnämndas": "utnämna",
    "utnämnde": "utnämna",
    "utnämndes": "utnämna",
    "utnämnds": "utnämna",
    "utnämner": "utnämna",
    "utnämnes": "utnämna",
    "utnämns": "utnämna",
    "utnämnt": "utnämna",
    "utnämnts": "utnämna",
    "utnötningar": "utnötning",
    "utnötningarna": "utnötning",
    "utnötningarnas": "utnötning",
    "utnötningars": "utnötning",
    "utnötningen": "utnötning",
    "utnötningens": "utnötning",
    "utnötnings": "utnötning",
    "utnötta": "utnött",
    "utnöttare": "utnött",
    "utnöttares": "utnött",
    "utnöttas": "utnött",
    "utnöttast": "utnött",
    "utnöttaste": "utnött",
    "utnöttastes": "utnött",
    "utnöttasts": "utnött",
    "utnötte": "utnött",
    "utnöttes": "utnött",
    "utnöttheten": "utnötthet",
    "utnötthetens": "utnötthet",
    "utnötthets": "utnötthet",
    "utnötts": "utnött",
    "utombordar": "utombordare",
    "utombordaren": "utombordare",
    "utombordarens": "utombordare",
    "utombordares": "utombordare",
    "utombordarna": "utombordare",
    "utombordarnas": "utombordare",
    "utombordsmotorer": "utombordsmotor",
    "utombordsmotorerna": "utombordsmotor",
    "utombordsmotorernas": "utombordsmotor",
    "utombordsmotorers": "utombordsmotor",
    "utombordsmotorn": "utombordsmotor",
    "utombordsmotorns": "utombordsmotor",
    "utombordsmotors": "utombordsmotor",
    "utomeuropeiska": "utomeuropeisk",
    "utomeuropeiskare": "utomeuropeisk",
    "utomeuropeiskares": "utomeuropeisk",
    "utomeuropeiskas": "utomeuropeisk",
    "utomeuropeiskast": "utomeuropeisk",
    "utomeuropeiskaste": "utomeuropeisk",
    "utomeuropeiskastes": "utomeuropeisk",
    "utomeuropeiskasts": "utomeuropeisk",
    "utomeuropeiske": "utomeuropeisk",
    "utomeuropeiskes": "utomeuropeisk",
    "utomeuropeisks": "utomeuropeisk",
    "utomeuropeiskt": "utomeuropeisk",
    "utomeuropeiskts": "utomeuropeisk",
    "utomhusbaden": "utomhusbad",
    "utomhusbadens": "utomhusbad",
    "utomhusbadet": "utomhusbad",
    "utomhusbadets": "utomhusbad",
    "utomhusbads": "utomhusbad",
    "utomhusbaren": "utomhusbar",
    "utomhusbarens": "utomhusbar",
    "utomhusbarer": "utomhusbar",
    "utomhusbarerna": "utomhusbar",
    "utomhusbarernas": "utomhusbar",
    "utomhusbarers": "utomhusbar",
    "utomhusbars": "utomhusbar",
    "utomhusbelysningar": "utomhusbelysning",
    "utomhusbelysningarna": "utomhusbelysning",
    "utomhusbelysningarnas": "utomhusbelysning",
    "utomhusbelysningars": "utomhusbelysning",
    "utomhusbelysningen": "utomhusbelysning",
    "utomhusbelysningens": "utomhusbelysning",
    "utomhusbelysnings": "utomhusbelysning",
    "utomhusbruket": "utomhusbruk",
    "utomhusbrukets": "utomhusbruk",
    "utomhusbruks": "utomhusbruk",
    "utomhuskonserten": "utomhuskonsert",
    "utomhuskonsertens": "utomhuskonsert",
    "utomhuskonserter": "utomhuskonsert",
    "utomhuskonserterna": "utomhuskonsert",
    "utomhuskonserternas": "utomhuskonsert",
    "utomhuskonserters": "utomhuskonsert",
    "utomhuskonserts": "utomhuskonsert",
    "utomhuslamp": "utomhuslampa",
    "utomhuslampan": "utomhuslampa",
    "utomhuslampans": "utomhuslampa",
    "utomhuslampas": "utomhuslampa",
    "utomhuslampe": "utomhuslampa",
    "utomhuslampor": "utomhuslampa",
    "utomhuslamporna": "utomhuslampa",
    "utomhuslampornas": "utomhuslampa",
    "utomhuslampors": "utomhuslampa",
    "utomhuslamps": "utomhuslampa",
    "utomjordingar": "utomjording",
    "utomjordingarna": "utomjording",
    "utomjordingarnas": "utomjording",
    "utomjordingars": "utomjording",
    "utomjordingen": "utomjording",
    "utomjordingens": "utomjording",
    "utomjordings": "utomjording",
    "utomjordiska": "utomjordisk",
    "utomjordiskare": "utomjordisk",
    "utomjordiskares": "utomjordisk",
    "utomjordiskas": "utomjordisk",
    "utomjordiskast": "utomjordisk",
    "utomjordiskaste": "utomjordisk",
    "utomjordiskastes": "utomjordisk",
    "utomjordiskasts": "utomjordisk",
    "utomjordiske": "utomjordisk",
    "utomjordiskes": "utomjordisk",
    "utomjordisks": "utomjordisk",
    "utomjordiskt": "utomjordisk",
    "utomjordiskts": "utomjordisk",
    "utomkvedshavandeskapen": "utomkvedshavandeskap",
    "utomkvedshavandeskapens": "utomkvedshavandeskap",
    "utomkvedshavandeskapet": "utomkvedshavandeskap",
    "utomkvedshavandeskapets": "utomkvedshavandeskap",
    "utomkvedshavandeskaps": "utomkvedshavandeskap",
    "utomordentliga": "utomordentlig",
    "utomordentligare": "utomordentlig",
    "utomordentligares": "utomordentlig",
    "utomordentligas": "utomordentlig",
    "utomordentligast": "utomordentlig",
    "utomordentligaste": "utomordentlig",
    "utomordentligastes": "utomordentlig",
    "utomordentligasts": "utomordentlig",
    "utomordentlige": "utomordentlig",
    "utomordentliges": "utomordentlig",
    "utomordentligheten": "utomordentlighet",
    "utomordentlighetens": "utomordentlighet",
    "utomordentlighets": "utomordentlighet",
    "utomordentligs": "utomordentlig",
    "utomordentligt": "utomordentlig",
    "utomordentligts": "utomordentlig",
    "utomparlamentariska": "utomparlamentarisk",
    "utomparlamentariskare": "utomparlamentarisk",
    "utomparlamentariskares": "utomparlamentarisk",
    "utomparlamentariskas": "utomparlamentarisk",
    "utomparlamentariskast": "utomparlamentarisk",
    "utomparlamentariskaste": "utomparlamentarisk",
    "utomparlamentariskastes": "utomparlamentarisk",
    "utomparlamentariskasts": "utomparlamentarisk",
    "utomparlamentariske": "utomparlamentarisk",
    "utomparlamentariskes": "utomparlamentarisk",
    "utomparlamentarisks": "utomparlamentarisk",
    "utomparlamentariskt": "utomparlamentarisk",
    "utomparlamentariskts": "utomparlamentarisk",
    "utomäktenskapliga": "utomäktenskaplig",
    "utomäktenskapligare": "utomäktenskaplig",
    "utomäktenskapligares": "utomäktenskaplig",
    "utomäktenskapligas": "utomäktenskaplig",
    "utomäktenskapligast": "utomäktenskaplig",
    "utomäktenskapligaste": "utomäktenskaplig",
    "utomäktenskapligastes": "utomäktenskaplig",
    "utomäktenskapligasts": "utomäktenskaplig",
    "utomäktenskaplige": "utomäktenskaplig",
    "utomäktenskapliges": "utomäktenskaplig",
    "utomäktenskapligheten": "utomäktenskaplighet",
    "utomäktenskaplighetens": "utomäktenskaplighet",
    "utomäktenskaplighets": "utomäktenskaplighet",
    "utomäktenskapligs": "utomäktenskaplig",
    "utomäktenskapligt": "utomäktenskaplig",
    "utomäktenskapligts": "utomäktenskaplig",
    "utopien": "utopi",
    "utopiens": "utopi",
    "utopier": "utopi",
    "utopierna": "utopi",
    "utopiernas": "utopi",
    "utopiers": "utopi",
    "utopin": "utopi",
    "utopins": "utopi",
    "utopis": "utopi",
    "utopiska": "utopisk",
    "utopiskare": "utopisk",
    "utopiskares": "utopisk",
    "utopiskas": "utopisk",
    "utopiskast": "utopisk",
    "utopiskaste": "utopisk",
    "utopiskastes": "utopisk",
    "utopiskasts": "utopisk",
    "utopiske": "utopisk",
    "utopiskes": "utopisk",
    "utopisks": "utopisk",
    "utopiskt": "utopisk",
    "utopiskts": "utopisk",
    "utopisten": "utopist",
    "utopistens": "utopist",
    "utopister": "utopist",
    "utopisterna": "utopist",
    "utopisternas": "utopist",
    "utopisters": "utopist",
    "utopists": "utopist",
    "utpek": "utpeka",
    "utpekad": "utpeka",
    "utpekade": "utpeka",
    "utpekades": "utpeka",
    "utpekads": "utpeka",
    "utpekande": "utpeka",
    "utpekanden": "utpekande",
    "utpekandena": "utpekande",
    "utpekandenas": "utpekande",
    "utpekandens": "utpekande",
    "utpekandes": "utpekande",
    "utpekandet": "utpekande",
    "utpekandets": "utpekande",
    "utpekar": "utpeka",
    "utpekas": "utpeka",
    "utpekat": "utpeka",
    "utpekats": "utpeka",
    "utpinade": "utpinad",
    "utpinades": "utpinad",
    "utpinads": "utpinad",
    "utpinat": "utpinad",
    "utpinats": "utpinad",
    "utplacerad": "utplacera",
    "utplacerade": "utplacera",
    "utplacerades": "utplacera",
    "utplacerads": "utplacera",
    "utplacerande": "utplacera",
    "utplaceranden": "utplacerande",
    "utplacerandena": "utplacerande",
    "utplacerandenas": "utplacerande",
    "utplacerandens": "utplacerande",
    "utplacerandes": "utplacerande",
    "utplacerandet": "utplacerande",
    "utplacerandets": "utplacerande",
    "utplacerar": "utplacera",
    "utplaceras": "utplacera",
    "utplacerat": "utplacera",
    "utplacerats": "utplacera",
    "utplacerbara": "utplacerbar",
    "utplacerbarare": "utplacerbar",
    "utplacerbarares": "utplacerbar",
    "utplacerbaras": "utplacerbar",
    "utplacerbarast": "utplacerbar",
    "utplacerbaraste": "utplacerbar",
    "utplacerbarastes": "utplacerbar",
    "utplacerbarasts": "utplacerbar",
    "utplacerbare": "utplacerbar",
    "utplacerbares": "utplacerbar",
    "utplacerbarheten": "utplacerbarhet",
    "utplacerbarhetens": "utplacerbarhet",
    "utplacerbarhets": "utplacerbarhet",
    "utplacerbars": "utplacerbar",
    "utplacerbart": "utplacerbar",
    "utplacerbarts": "utplacerbar",
    "utplaceringar": "utplacering",
    "utplaceringarna": "utplacering",
    "utplaceringarnas": "utplacering",
    "utplaceringars": "utplacering",
    "utplaceringen": "utplacering",
    "utplaceringens": "utplacering",
    "utplacerings": "utplacering",
    "utplundrad": "utplundra",
    "utplundrade": "utplundra",
    "utplundrades": "utplundra",
    "utplundrads": "utplundra",
    "utplundrande": "utplundra",
    "utplundranden": "utplundrande",
    "utplundrandena": "utplundrande",
    "utplundrandenas": "utplundrande",
    "utplundrandens": "utplundrande",
    "utplundrandes": "utplundrande",
    "utplundrandet": "utplundrande",
    "utplundrandets": "utplundrande",
    "utplundrar": "utplundra",
    "utplundras": "utplundra",
    "utplundrat": "utplundra",
    "utplundrats": "utplundra",
    "utplån": "utplåna",
    "utplånad": "utplåna",
    "utplånade": "utplåna",
    "utplånades": "utplåna",
    "utplånads": "utplåna",
    "utplånande": "utplåna",
    "utplånanden": "utplånande",
    "utplånandena": "utplånande",
    "utplånandenas": "utplånande",
    "utplånandens": "utplånande",
    "utplånandes": "utplånande",
    "utplånandet": "utplånande",
    "utplånandets": "utplånande",
    "utplånar": "utplåna",
    "utplånas": "utplåna",
    "utplånat": "utplåna",
    "utplånats": "utplåna",
    "utposten": "utpost",
    "utpostens": "utpost",
    "utposter": "utpost",
    "utposterad": "utpostera",
    "utposterade": "utposterad",
    "utposterades": "utposterad",
    "utposterads": "utposterad",
    "utposterande": "utpostera",
    "utposteranden": "utposterande",
    "utposterandena": "utposterande",
    "utposterandenas": "utposterande",
    "utposterandens": "utposterande",
    "utposterandes": "utposterande",
    "utposterandet": "utposterande",
    "utposterandets": "utposterande",
    "utposterar": "utpostera",
    "utposteras": "utpostera",
    "utposterat": "utposterad",
    "utposterats": "utposterad",
    "utposterbara": "utposterbar",
    "utposterbarare": "utposterbar",
    "utposterbarares": "utposterbar",
    "utposterbaras": "utposterbar",
    "utposterbarast": "utposterbar",
    "utposterbaraste": "utposterbar",
    "utposterbarastes": "utposterbar",
    "utposterbarasts": "utposterbar",
    "utposterbare": "utposterbar",
    "utposterbares": "utposterbar",
    "utposterbarheten": "utposterbarhet",
    "utposterbarhetens": "utposterbarhet",
    "utposterbarhets": "utposterbarhet",
    "utposterbars": "utposterbar",
    "utposterbart": "utposterbar",
    "utposterbarts": "utposterbar",
    "utposterna": "utpost",
    "utposternas": "utpost",
    "utposters": "utpost",
    "utposts": "utpost",
    "utpress": "utpressa",
    "utpressad": "utpressa",
    "utpressade": "utpressa",
    "utpressades": "utpressa",
    "utpressads": "utpressa",
    "utpressande": "utpressa",
    "utpressanden": "utpressande",
    "utpressandena": "utpressande",
    "utpressandenas": "utpressande",
    "utpressandens": "utpressande",
    "utpressandes": "utpressande",
    "utpressandet": "utpressande",
    "utpressandets": "utpressande",
    "utpressar": "utpressare",
    "utpressaren": "utpressare",
    "utpressarens": "utpressare",
    "utpressares": "utpressare",
    "utpressarna": "utpressare",
    "utpressarnas": "utpressare",
    "utpressas": "utpressa",
    "utpressat": "utpressa",
    "utpressats": "utpressa",
    "utpressningar": "utpressning",
    "utpressningarna": "utpressning",
    "utpressningarnas": "utpressning",
    "utpressningars": "utpressning",
    "utpressningen": "utpressning",
    "utpressningens": "utpressning",
    "utpressnings": "utpressning",
    "utpressningsmedels": "utpressningsmedel",
    "utpressningsmedlen": "utpressningsmedel",
    "utpressningsmedlens": "utpressningsmedel",
    "utpressningsmedlet": "utpressningsmedel",
    "utpressningsmedlets": "utpressningsmedel",
    "utpressningsrättegångar": "utpressningsrättegång",
    "utpressningsrättegångarna": "utpressningsrättegång",
    "utpressningsrättegångarnas": "utpressningsrättegång",
    "utpressningsrättegångars": "utpressningsrättegång",
    "utpressningsrättegången": "utpressningsrättegång",
    "utpressningsrättegångens": "utpressningsrättegång",
    "utpressningsrättegångs": "utpressningsrättegång",
    "utprick": "utpricka",
    "utprickad": "utpricka",
    "utprickade": "utpricka",
    "utprickades": "utpricka",
    "utprickads": "utpricka",
    "utprickande": "utpricka",
    "utprickanden": "utprickande",
    "utprickandena": "utprickande",
    "utprickandenas": "utprickande",
    "utprickandens": "utprickande",
    "utprickandes": "utprickande",
    "utprickandet": "utprickande",
    "utprickandets": "utprickande",
    "utprickar": "utpricka",
    "utprickas": "utpricka",
    "utprickat": "utpricka",
    "utprickats": "utpricka",
    "utprickningar": "utprickning",
    "utprickningarna": "utprickning",
    "utprickningarnas": "utprickning",
    "utprickningars": "utprickning",
    "utprickningen": "utprickning",
    "utprickningens": "utprickning",
    "utpricknings": "utprickning",
    "utprov": "utprova",
    "utprovad": "utprova",
    "utprovade": "utprova",
    "utprovades": "utprova",
    "utprovads": "utprova",
    "utprovande": "utprova",
    "utprovanden": "utprovande",
    "utprovandena": "utprovande",
    "utprovandenas": "utprovande",
    "utprovandens": "utprovande",
    "utprovandes": "utprovande",
    "utprovandet": "utprovande",
    "utprovandets": "utprovande",
    "utprovar": "utprova",
    "utprovas": "utprova",
    "utprovat": "utprova",
    "utprovats": "utprova",
    "utpräglade": "utpräglad",
    "utpräglades": "utpräglad",
    "utpräglads": "utpräglad",
    "utpräglat": "utpräglad",
    "utpräglats": "utpräglad",
    "utpröv": "utpröva",
    "utprövad": "utpröva",
    "utprövade": "utpröva",
    "utprövades": "utpröva",
    "utprövads": "utpröva",
    "utprövande": "utpröva",
    "utprövanden": "utprövande",
    "utprövandena": "utprövande",
    "utprövandenas": "utprövande",
    "utprövandens": "utprövande",
    "utprövandes": "utprövande",
    "utprövandet": "utprövande",
    "utprövandets": "utprövande",
    "utprövar": "utpröva",
    "utprövas": "utpröva",
    "utprövat": "utpröva",
    "utprövats": "utpröva",
    "utpumpade": "utpumpad",
    "utpumpades": "utpumpad",
    "utpumpads": "utpumpad",
    "utpumpat": "utpumpad",
    "utpumpats": "utpumpad",
    "utpyntade": "utpyntad",
    "utpyntades": "utpyntad",
    "utpyntads": "utpyntad",
    "utpyntat": "utpyntad",
    "utpyntats": "utpyntad",
    "utraderad": "utradera",
    "utraderade": "utradera",
    "utraderades": "utradera",
    "utraderads": "utradera",
    "utraderande": "utradera",
    "utraderanden": "utraderande",
    "utraderandena": "utraderande",
    "utraderandenas": "utraderande",
    "utraderandens": "utraderande",
    "utraderandes": "utraderande",
    "utraderandet": "utraderande",
    "utraderandets": "utraderande",
    "utraderar": "utradera",
    "utraderas": "utradera",
    "utraderat": "utradera",
    "utraderats": "utradera",
    "utraderbara": "utraderbar",
    "utraderbarare": "utraderbar",
    "utraderbarares": "utraderbar",
    "utraderbaras": "utraderbar",
    "utraderbarast": "utraderbar",
    "utraderbaraste": "utraderbar",
    "utraderbarastes": "utraderbar",
    "utraderbarasts": "utraderbar",
    "utraderbare": "utraderbar",
    "utraderbares": "utraderbar",
    "utraderbarheten": "utraderbarhet",
    "utraderbarhetens": "utraderbarhet",
    "utraderbarhets": "utraderbarhet",
    "utraderbars": "utraderbar",
    "utraderbart": "utraderbar",
    "utraderbarts": "utraderbar",
    "utraderingar": "utradering",
    "utraderingarna": "utradering",
    "utraderingarnas": "utradering",
    "utraderingars": "utradering",
    "utraderingen": "utradering",
    "utraderingens": "utradering",
    "utraderings": "utradering",
    "utrangerad": "utrangera",
    "utrangerade": "utrangera",
    "utrangerades": "utrangera",
    "utrangerads": "utrangera",
    "utrangerande": "utrangera",
    "utrangeranden": "utrangerande",
    "utrangerandena": "utrangerande",
    "utrangerandenas": "utrangerande",
    "utrangerandens": "utrangerande",
    "utrangerandes": "utrangerande",
    "utrangerandet": "utrangerande",
    "utrangerandets": "utrangerande",
    "utrangerar": "utrangera",
    "utrangeras": "utrangera",
    "utrangerat": "utrangera",
    "utrangerats": "utrangera",
    "utrangerbara": "utrangerbar",
    "utrangerbarare": "utrangerbar",
    "utrangerbarares": "utrangerbar",
    "utrangerbaras": "utrangerbar",
    "utrangerbarast": "utrangerbar",
    "utrangerbaraste": "utrangerbar",
    "utrangerbarastes": "utrangerbar",
    "utrangerbarasts": "utrangerbar",
    "utrangerbare": "utrangerbar",
    "utrangerbares": "utrangerbar",
    "utrangerbarheten": "utrangerbarhet",
    "utrangerbarhetens": "utrangerbarhet",
    "utrangerbarhets": "utrangerbarhet",
    "utrangerbars": "utrangerbar",
    "utrangerbart": "utrangerbar",
    "utrangerbarts": "utrangerbar",
    "utrangeringar": "utrangering",
    "utrangeringarna": "utrangering",
    "utrangeringarnas": "utrangering",
    "utrangeringars": "utrangering",
    "utrangeringen": "utrangering",
    "utrangeringens": "utrangering",
    "utrangerings": "utrangering",
    "utred": "utreda",
    "utredande": "utreda",
    "utredanden": "utredande",
    "utredandena": "utredande",
    "utredandenas": "utredande",
    "utredandens": "utredande",
    "utredandes": "utredande",
    "utredandet": "utredande",
    "utredandets": "utredande",
    "utredar": "utredare",
    "utredaren": "utredare",
    "utredarens": "utredare",
    "utredares": "utredare",
    "utredarna": "utredare",
    "utredarnas": "utredare",
    "utredas": "utreda",
    "utredd": "utreda",
    "utredda": "utreda",
    "utreddas": "utreda",
    "utredde": "utreda",
    "utreddes": "utreda",
    "utredds": "utreda",
    "utreder": "utreda",
    "utredes": "utreda",
    "utredningar": "utredning",
    "utredningarna": "utredning",
    "utredningarnas": "utredning",
    "utredningars": "utredning",
    "utredningen": "utredning",
    "utredningens": "utredning",
    "utrednings": "utredning",
    "utredningsmannen": "utredningsman",
    "utredningsmannens": "utredningsman",
    "utredningsmans": "utredningsman",
    "utredningsmän": "utredningsman",
    "utredningsmännen": "utredningsman",
    "utredningsmännens": "utredningsman",
    "utredningsmäns": "utredningsman",
    "utredningsmässiga": "utredningsmässig",
    "utredningsmässigare": "utredningsmässig",
    "utredningsmässigares": "utredningsmässig",
    "utredningsmässigas": "utredningsmässig",
    "utredningsmässigast": "utredningsmässig",
    "utredningsmässigaste": "utredningsmässig",
    "utredningsmässigastes": "utredningsmässig",
    "utredningsmässigasts": "utredningsmässig",
    "utredningsmässige": "utredningsmässig",
    "utredningsmässiges": "utredningsmässig",
    "utredningsmässigs": "utredningsmässig",
    "utredningsmässigt": "utredningsmässig",
    "utredningsmässigts": "utredningsmässig",
    "utreds": "utreda",
    "utrens": "utrensa",
    "utrensad": "utrensa",
    "utrensade": "utrensa",
    "utrensades": "utrensa",
    "utrensads": "utrensa",
    "utrensande": "utrensa",
    "utrensanden": "utrensande",
    "utrensandena": "utrensande",
    "utrensandenas": "utrensande",
    "utrensandens": "utrensande",
    "utrensandes": "utrensande",
    "utrensandet": "utrensande",
    "utrensandets": "utrensande",
    "utrensar": "utrensa",
    "utrensas": "utrensa",
    "utrensat": "utrensa",
    "utrensats": "utrensa",
    "utrensningar": "utrensning",
    "utrensningarna": "utrensning",
    "utrensningarnas": "utrensning",
    "utrensningars": "utrensning",
    "utrensningen": "utrensning",
    "utrensningens": "utrensning",
    "utrensnings": "utrensning",
    "utrerade": "utrerad",
    "utrerades": "utrerad",
    "utrerads": "utrerad",
    "utrerat": "utrerad",
    "utrerats": "utrerad",
    "utresan": "utresa",
    "utresans": "utresa",
    "utresas": "utresa",
    "utrese": "utresa",
    "utreseförbuden": "utreseförbud",
    "utreseförbudens": "utreseförbud",
    "utreseförbudet": "utreseförbud",
    "utreseförbudets": "utreseförbud",
    "utreseförbuds": "utreseförbud",
    "utresetillstånden": "utresetillstånd",
    "utresetillståndens": "utresetillstånd",
    "utresetillståndet": "utresetillstånd",
    "utresetillståndets": "utresetillstånd",
    "utresetillstånds": "utresetillstånd",
    "utresor": "utresa",
    "utresorna": "utresa",
    "utresornas": "utresa",
    "utresors": "utresa",
    "utrett": "utreda",
    "utretts": "utreda",
    "utriggade": "utriggad",
    "utriggades": "utriggad",
    "utriggads": "utriggad",
    "utriggar": "utriggare",
    "utriggaren": "utriggare",
    "utriggarens": "utriggare",
    "utriggares": "utriggare",
    "utriggarna": "utriggare",
    "utriggarnas": "utriggare",
    "utriggat": "utriggad",
    "utriggats": "utriggad",
    "utrikesdepartementen": "utrikesdepartement",
    "utrikesdepartementens": "utrikesdepartement",
    "utrikesdepartementet": "utrikesdepartement",
    "utrikesdepartementets": "utrikesdepartement",
    "utrikesdepartements": "utrikesdepartement",
    "utrikeshandeln": "utrikeshandel",
    "utrikeshandelns": "utrikeshandel",
    "utrikeshandels": "utrikeshandel",
    "utrikeshandelsministern": "utrikeshandelsminister",
    "utrikeshandelsministerns": "utrikeshandelsminister",
    "utrikeshandelsministers": "utrikeshandelsminister",
    "utrikeshandelsministrar": "utrikeshandelsminister",
    "utrikeshandelsministrarna": "utrikeshandelsminister",
    "utrikeshandelsministrarnas": "utrikeshandelsminister",
    "utrikeshandelsministrars": "utrikeshandelsminister",
    "utrikeskorrespondenten": "utrikeskorrespondent",
    "utrikeskorrespondentens": "utrikeskorrespondent",
    "utrikeskorrespondenter": "utrikeskorrespondent",
    "utrikeskorrespondenterna": "utrikeskorrespondent",
    "utrikeskorrespondenternas": "utrikeskorrespondent",
    "utrikeskorrespondenters": "utrikeskorrespondent",
    "utrikeskorrespondents": "utrikeskorrespondent",
    "utrikesministern": "utrikesminister",
    "utrikesministerns": "utrikesminister",
    "utrikesministers": "utrikesminister",
    "utrikesministrar": "utrikesminister",
    "utrikesministrarna": "utrikesminister",
    "utrikesministrarnas": "utrikesminister",
    "utrikesministrars": "utrikesminister",
    "utrikespassagerar": "utrikespassagerare",
    "utrikespassageraren": "utrikespassagerare",
    "utrikespassagerarens": "utrikespassagerare",
    "utrikespassagerares": "utrikespassagerare",
    "utrikespassagerarna": "utrikespassagerare",
    "utrikespassagerarnas": "utrikespassagerare",
    "utrikespolitiken": "utrikespolitik",
    "utrikespolitikens": "utrikespolitik",
    "utrikespolitiks": "utrikespolitik",
    "utrikespolitiska": "utrikespolitisk",
    "utrikespolitiskare": "utrikespolitisk",
    "utrikespolitiskares": "utrikespolitisk",
    "utrikespolitiskas": "utrikespolitisk",
    "utrikespolitiskast": "utrikespolitisk",
    "utrikespolitiskaste": "utrikespolitisk",
    "utrikespolitiskastes": "utrikespolitisk",
    "utrikespolitiskasts": "utrikespolitisk",
    "utrikespolitiske": "utrikespolitisk",
    "utrikespolitiskes": "utrikespolitisk",
    "utrikespolitisks": "utrikespolitisk",
    "utrikespolitiskt": "utrikespolitisk",
    "utrikespolitiskts": "utrikespolitisk",
    "utrikestrafiken": "utrikestrafik",
    "utrikestrafikens": "utrikestrafik",
    "utrikestrafiks": "utrikestrafik",
    "utrikisk": "utrikiska",
    "utrikiska": "utrikisk",
    "utrikiskan": "utrikiska",
    "utrikiskans": "utrikiska",
    "utrikiskare": "utrikisk",
    "utrikiskares": "utrikisk",
    "utrikiskas": "utrikiska",
    "utrikiskast": "utrikisk",
    "utrikiskaste": "utrikisk",
    "utrikiskastes": "utrikisk",
    "utrikiskasts": "utrikisk",
    "utrikiske": "utrikisk",
    "utrikiskes": "utrikisk",
    "utrikisks": "utrikisk",
    "utrikiskt": "utrikisk",
    "utrikiskts": "utrikisk",
    "utrop": "utropa",
    "utropad": "utropa",
    "utropade": "utropa",
    "utropades": "utropa",
    "utropads": "utropa",
    "utropande": "utropa",
    "utropanden": "utropande",
    "utropandena": "utropande",
    "utropandenas": "utropande",
    "utropandens": "utropande",
    "utropandes": "utropande",
    "utropandet": "utropande",
    "utropandets": "utropande",
    "utropar": "utropare",
    "utroparen": "utropare",
    "utroparens": "utropare",
    "utropares": "utropare",
    "utroparna": "utropare",
    "utroparnas": "utropare",
    "utropas": "utropa",
    "utropat": "utropa",
    "utropats": "utropa",
    "utropen": "utrop",
    "utropens": "utrop",
    "utropet": "utrop",
    "utropets": "utrop",
    "utrops": "utrop",
    "utropsorden": "utropsord",
    "utropsordens": "utropsord",
    "utropsordet": "utropsord",
    "utropsordets": "utropsord",
    "utropsords": "utropsord",
    "utropsteckens": "utropstecken",
    "utropstecknen": "utropstecken",
    "utropstecknens": "utropstecken",
    "utropstecknet": "utropstecken",
    "utropstecknets": "utropstecken",
    "utrot": "utrota",
    "utrotad": "utrota",
    "utrotade": "utrota",
    "utrotades": "utrota",
    "utrotads": "utrota",
    "utrotande": "utrota",
    "utrotanden": "utrotande",
    "utrotandena": "utrotande",
    "utrotandenas": "utrotande",
    "utrotandens": "utrotande",
    "utrotandes": "utrotande",
    "utrotandet": "utrotande",
    "utrotandets": "utrotande",
    "utrotar": "utrota",
    "utrotas": "utrota",
    "utrotat": "utrota",
    "utrotats": "utrota",
    "utrotningar": "utrotning",
    "utrotningarna": "utrotning",
    "utrotningarnas": "utrotning",
    "utrotningars": "utrotning",
    "utrotningen": "utrotning",
    "utrotningens": "utrotning",
    "utrotnings": "utrotning",
    "utrotningshotade": "utrotningshotad",
    "utrotningshotades": "utrotningshotad",
    "utrotningshotads": "utrotningshotad",
    "utrotningshotat": "utrotningshotad",
    "utrotningshotats": "utrotningshotad",
    "utrotningslägerna": "utrotningsläger",
    "utrotningslägernas": "utrotningsläger",
    "utrotningslägers": "utrotningsläger",
    "utrotningslägren": "utrotningsläger",
    "utrotningslägrens": "utrotningsläger",
    "utrotningslägret": "utrotningsläger",
    "utrotningslägrets": "utrotningsläger",
    "utrullade": "utrullad",
    "utrullades": "utrullad",
    "utrullads": "utrullad",
    "utrullat": "utrullad",
    "utrullats": "utrullad",
    "utrumet": "utrum",
    "utrumets": "utrum",
    "utrums": "utrum",
    "utrust": "utrusta",
    "utrustad": "utrusta",
    "utrustade": "utrusta",
    "utrustades": "utrusta",
    "utrustads": "utrusta",
    "utrustande": "utrusta",
    "utrustanden": "utrustande",
    "utrustandena": "utrustande",
    "utrustandenas": "utrustande",
    "utrustandens": "utrustande",
    "utrustandes": "utrustande",
    "utrustandet": "utrustande",
    "utrustandets": "utrustande",
    "utrustar": "utrusta",
    "utrustas": "utrusta",
    "utrustat": "utrusta",
    "utrustats": "utrusta",
    "utrustningar": "utrustning",
    "utrustningarna": "utrustning",
    "utrustningarnas": "utrustning",
    "utrustningars": "utrustning",
    "utrustningen": "utrustning",
    "utrustningens": "utrustning",
    "utrustnings": "utrustning",
    "utryckningar": "utryckning",
    "utryckningarna": "utryckning",
    "utryckningarnas": "utryckning",
    "utryckningars": "utryckning",
    "utryckningen": "utryckning",
    "utryckningens": "utryckning",
    "utrycknings": "utryckning",
    "utrym": "utrymma",
    "utrymd": "utrymma",
    "utrymda": "utrymma",
    "utrymdas": "utrymma",
    "utrymde": "utrymma",
    "utrymdes": "utrymma",
    "utrymds": "utrymma",
    "utrymmande": "utrymma",
    "utrymmanden": "utrymmande",
    "utrymmandena": "utrymmande",
    "utrymmandenas": "utrymmande",
    "utrymmandens": "utrymmande",
    "utrymmandes": "utrymmande",
    "utrymmandet": "utrymmande",
    "utrymmandets": "utrymmande",
    "utrymmas": "utrymma",
    "utrymmen": "utrymme",
    "utrymmena": "utrymme",
    "utrymmenas": "utrymme",
    "utrymmens": "utrymme",
    "utrymmer": "utrymma",
    "utrymmes": "utrymme",
    "utrymmesmässiga": "utrymmesmässig",
    "utrymmesmässigare": "utrymmesmässig",
    "utrymmesmässigares": "utrymmesmässig",
    "utrymmesmässigas": "utrymmesmässig",
    "utrymmesmässigast": "utrymmesmässig",
    "utrymmesmässigaste": "utrymmesmässig",
    "utrymmesmässigastes": "utrymmesmässig",
    "utrymmesmässigasts": "utrymmesmässig",
    "utrymmesmässige": "utrymmesmässig",
    "utrymmesmässiges": "utrymmesmässig",
    "utrymmesmässigs": "utrymmesmässig",
    "utrymmesmässigt": "utrymmesmässig",
    "utrymmesmässigts": "utrymmesmässig",
    "utrymmesstandarden": "utrymmesstandard",
    "utrymmesstandardens": "utrymmesstandard",
    "utrymmesstandarder": "utrymmesstandard",
    "utrymmesstandarderna": "utrymmesstandard",
    "utrymmesstandardernas": "utrymmesstandard",
    "utrymmesstandarders": "utrymmesstandard",
    "utrymmesstandards": "utrymmesstandard",
    "utrymmet": "utrymme",
    "utrymmets": "utrymme",
    "utrymningar": "utrymning",
    "utrymningarna": "utrymning",
    "utrymningarnas": "utrymning",
    "utrymningars": "utrymning",
    "utrymningen": "utrymning",
    "utrymningens": "utrymning",
    "utrymnings": "utrymning",
    "utryms": "utrymma",
    "utrymt": "utrymma",
    "utrymts": "utrymma",
    "uträknade": "uträknad",
    "uträknades": "uträknad",
    "uträknads": "uträknad",
    "uträknat": "uträknad",
    "uträknats": "uträknad",
    "uträkningar": "uträkning",
    "uträkningarna": "uträkning",
    "uträkningarnas": "uträkning",
    "uträkningars": "uträkning",
    "uträkningen": "uträkning",
    "uträkningens": "uträkning",
    "uträknings": "uträkning",
    "uträtt": "uträtta",
    "uträttad": "uträtta",
    "uträttade": "uträtta",
    "uträttades": "uträtta",
    "uträttads": "uträtta",
    "uträttande": "uträtta",
    "uträttanden": "uträttande",
    "uträttandena": "uträttande",
    "uträttandenas": "uträttande",
    "uträttandens": "uträttande",
    "uträttandes": "uträttande",
    "uträttandet": "uträttande",
    "uträttandets": "uträttande",
    "uträttar": "uträtta",
    "uträttas": "uträtta",
    "uträttat": "uträtta",
    "uträttats": "uträtta",
    "utrön": "utröna",
    "utrönande": "utröna",
    "utrönanden": "utrönande",
    "utrönandena": "utrönande",
    "utrönandenas": "utrönande",
    "utrönandens": "utrönande",
    "utrönandes": "utrönande",
    "utrönandet": "utrönande",
    "utrönandets": "utrönande",
    "utrönas": "utröna",
    "utröner": "utröna",
    "utrönes": "utröna",
    "utröns": "utröna",
    "utrönt": "utröna",
    "utrönta": "utröna",
    "utröntas": "utröna",
    "utrönte": "utröna",
    "utröntes": "utröna",
    "utrönts": "utröna",
    "utsade": "utsäga",
    "utsades": "utsäga",
    "utsagan": "utsaga",
    "utsagans": "utsaga",
    "utsagas": "utsaga",
    "utsagd": "utsäga",
    "utsagda": "utsagd",
    "utsagdare": "utsagd",
    "utsagdares": "utsagd",
    "utsagdas": "utsagd",
    "utsagdast": "utsagd",
    "utsagdaste": "utsagd",
    "utsagdastes": "utsagd",
    "utsagdasts": "utsagd",
    "utsagde": "utsagd",
    "utsagdes": "utsagd",
    "utsagds": "utsagd",
    "utsage": "utsaga",
    "utsago": "utsaga",
    "utsagor": "utsaga",
    "utsagorna": "utsaga",
    "utsagornas": "utsaga",
    "utsagors": "utsaga",
    "utsagos": "utsago",
    "utsagt": "utsagd",
    "utsagts": "utsagd",
    "utsatt": "utsätta",
    "utsatta": "utsätta",
    "utsattare": "utsatt",
    "utsattares": "utsatt",
    "utsattas": "utsätta",
    "utsattast": "utsatt",
    "utsattaste": "utsatt",
    "utsattastes": "utsatt",
    "utsattasts": "utsatt",
    "utsatte": "utsätta",
    "utsattes": "utsätta",
    "utsattheten": "utsatthet",
    "utsatthetens": "utsatthet",
    "utsatthets": "utsatthet",
    "utsatts": "utsätta",
    "utschasade": "utschasad",
    "utschasades": "utschasad",
    "utschasads": "utschasad",
    "utschasat": "utschasad",
    "utschasats": "utschasad",
    "utsedd": "utse",
    "utsedda": "utse",
    "utseddas": "utse",
    "utsedde": "utse",
    "utseddes": "utse",
    "utsedds": "utse",
    "utseende": "utse",
    "utseendefixeringar": "utseendefixering",
    "utseendefixeringarna": "utseendefixering",
    "utseendefixeringarnas": "utseendefixering",
    "utseendefixeringars": "utseendefixering",
    "utseendefixeringen": "utseendefixering",
    "utseendefixeringens": "utseendefixering",
    "utseendefixerings": "utseendefixering",
    "utseendemässiga": "utseendemässig",
    "utseendemässigare": "utseendemässig",
    "utseendemässigares": "utseendemässig",
    "utseendemässigas": "utseendemässig",
    "utseendemässigast": "utseendemässig",
    "utseendemässigaste": "utseendemässig",
    "utseendemässigastes": "utseendemässig",
    "utseendemässigasts": "utseendemässig",
    "utseendemässige": "utseendemässig",
    "utseendemässiges": "utseendemässig",
    "utseendemässigs": "utseendemässig",
    "utseendemässigt": "utseendemässig",
    "utseendemässigts": "utseendemässig",
    "utseenden": "utseende",
    "utseendena": "utseende",
    "utseendenas": "utseende",
    "utseendens": "utseende",
    "utseendes": "utseende",
    "utseendet": "utseende",
    "utseendets": "utseende",
    "utser": "utse",
    "utses": "utse",
    "utsett": "utse",
    "utsetts": "utse",
    "utsidan": "utsida",
    "utsidans": "utsida",
    "utsidas": "utsida",
    "utside": "utsida",
    "utsides": "utsida",
    "utsidor": "utsida",
    "utsidorna": "utsida",
    "utsidornas": "utsida",
    "utsidors": "utsida",
    "utsikten": "utsikt",
    "utsiktens": "utsikt",
    "utsikter": "utsikt",
    "utsikterna": "utsikter",
    "utsikternas": "utsikter",
    "utsikters": "utsikter",
    "utsikts": "utsikter",
    "utsiktslösa": "utsiktslös",
    "utsiktslösare": "utsiktslös",
    "utsiktslösares": "utsiktslös",
    "utsiktslösas": "utsiktslös",
    "utsiktslösast": "utsiktslös",
    "utsiktslösaste": "utsiktslös",
    "utsiktslösastes": "utsiktslös",
    "utsiktslösasts": "utsiktslös",
    "utsiktslöse": "utsiktslös",
    "utsiktslöses": "utsiktslös",
    "utsiktslösheten": "utsiktslöshet",
    "utsiktslöshetens": "utsiktslöshet",
    "utsiktslöshets": "utsiktslöshet",
    "utsiktslöst": "utsiktslös",
    "utsiktslösts": "utsiktslös",
    "utsiktspunkten": "utsiktspunkt",
    "utsiktspunktens": "utsiktspunkt",
    "utsiktspunkter": "utsiktspunkt",
    "utsiktspunkterna": "utsiktspunkt",
    "utsiktspunkternas": "utsiktspunkt",
    "utsiktspunkters": "utsiktspunkt",
    "utsiktspunkts": "utsiktspunkt",
    "utsiktstornen": "utsiktstorn",
    "utsiktstornens": "utsiktstorn",
    "utsiktstornet": "utsiktstorn",
    "utsiktstornets": "utsiktstorn",
    "utsiktstorns": "utsiktstorn",
    "utsir": "utsira",
    "utsirad": "utsira",
    "utsirade": "utsira",
    "utsirades": "utsira",
    "utsirads": "utsira",
    "utsirande": "utsira",
    "utsiranden": "utsirande",
    "utsirandena": "utsirande",
    "utsirandenas": "utsirande",
    "utsirandens": "utsirande",
    "utsirandes": "utsirande",
    "utsirandet": "utsirande",
    "utsirandets": "utsirande",
    "utsirar": "utsira",
    "utsiras": "utsira",
    "utsirat": "utsira",
    "utsirats": "utsira",
    "utsjasade": "utsjasad",
    "utsjasades": "utsjasad",
    "utsjasads": "utsjasad",
    "utsjasat": "utsjasad",
    "utsjasats": "utsjasad",
    "utsjöfiskes": "utsjöfiske",
    "utsjöfisket": "utsjöfiske",
    "utsjöfiskets": "utsjöfiske",
    "utskepp": "utskeppa",
    "utskeppad": "utskeppa",
    "utskeppade": "utskeppa",
    "utskeppades": "utskeppa",
    "utskeppads": "utskeppa",
    "utskeppande": "utskeppa",
    "utskeppanden": "utskeppande",
    "utskeppandena": "utskeppande",
    "utskeppandenas": "utskeppande",
    "utskeppandens": "utskeppande",
    "utskeppandes": "utskeppande",
    "utskeppandet": "utskeppande",
    "utskeppandets": "utskeppande",
    "utskeppar": "utskeppa",
    "utskeppas": "utskeppa",
    "utskeppat": "utskeppa",
    "utskeppats": "utskeppa",
    "utskicken": "utskick",
    "utskickens": "utskick",
    "utskicket": "utskick",
    "utskickets": "utskick",
    "utskicks": "utskick",
    "utskild": "utskilja",
    "utskilda": "utskilja",
    "utskildas": "utskilja",
    "utskilde": "utskilja",
    "utskildes": "utskilja",
    "utskilds": "utskilja",
    "utskilj": "utskilja",
    "utskiljande": "utskilja",
    "utskiljanden": "utskiljande",
    "utskiljandena": "utskiljande",
    "utskiljandenas": "utskiljande",
    "utskiljandens": "utskiljande",
    "utskiljandes": "utskiljande",
    "utskiljandet": "utskiljande",
    "utskiljandets": "utskiljande",
    "utskiljas": "utskilja",
    "utskiljer": "utskilja",
    "utskiljes": "utskilja",
    "utskiljs": "utskilja",
    "utskilt": "utskilja",
    "utskilts": "utskilja",
    "utskotten": "utskott",
    "utskottens": "utskott",
    "utskottet": "utskott",
    "utskottets": "utskott",
    "utskotts": "utskott",
    "utskottsordföranden": "utskottsordförande",
    "utskottsordförandena": "utskottsordförande",
    "utskottsordförandenas": "utskottsordförande",
    "utskottsordförandens": "utskottsordförande",
    "utskottsordförandes": "utskottsordförande",
    "utskottsvar": "utskottsvara",
    "utskottsvaran": "utskottsvara",
    "utskottsvarans": "utskottsvara",
    "utskottsvaras": "utskottsvara",
    "utskottsvare": "utskottsvara",
    "utskottsvaror": "utskottsvara",
    "utskottsvarorna": "utskottsvara",
    "utskottsvarornas": "utskottsvara",
    "utskottsvarors": "utskottsvara",
    "utskottsvars": "utskottsvara",
    "utskottsvirkes": "utskottsvirke",
    "utskottsvirket": "utskottsvirke",
    "utskottsvirkets": "utskottsvirke",
    "utskoven": "utskov",
    "utskovens": "utskov",
    "utskovet": "utskov",
    "utskovets": "utskov",
    "utskovs": "utskov",
    "utskrev": "utskriva",
    "utskrevs": "utskriva",
    "utskriften": "utskrift",
    "utskriftens": "utskrift",
    "utskrifter": "utskrift",
    "utskrifterna": "utskrift",
    "utskrifternas": "utskrift",
    "utskrifters": "utskrift",
    "utskrifts": "utskrift",
    "utskriv": "utskriva",
    "utskrivande": "utskriva",
    "utskrivanden": "utskrivande",
    "utskrivandena": "utskrivande",
    "utskrivandenas": "utskrivande",
    "utskrivandens": "utskrivande",
    "utskrivandes": "utskrivande",
    "utskrivandet": "utskrivande",
    "utskrivandets": "utskrivande",
    "utskrivas": "utskriva",
    "utskrive": "utskriva",
    "utskriver": "utskriva",
    "utskrives": "utskriva",
    "utskrivit": "utskriva",
    "utskrivits": "utskriva",
    "utskrivningar": "utskrivning",
    "utskrivningarna": "utskrivning",
    "utskrivningarnas": "utskrivning",
    "utskrivningars": "utskrivning",
    "utskrivningen": "utskrivning",
    "utskrivningens": "utskrivning",
    "utskrivnings": "utskrivning",
    "utskrivs": "utskriva",
    "utskurens": "utskuren",
    "utskuret": "utskuren",
    "utskurets": "utskuren",
    "utskurna": "utskuren",
    "utskurnas": "utskuren",
    "utskurne": "utskuren",
    "utskurnes": "utskuren",
    "utskylden": "utskyld",
    "utskyldens": "utskyld",
    "utskylder": "utskyld",
    "utskylderna": "utskyld",
    "utskyldernas": "utskyld",
    "utskylders": "utskyld",
    "utskylds": "utskyld",
    "utskällda": "utskälld",
    "utskälldare": "utskälld",
    "utskälldares": "utskälld",
    "utskälldas": "utskälld",
    "utskälldast": "utskälld",
    "utskälldaste": "utskälld",
    "utskälldastes": "utskälld",
    "utskälldasts": "utskälld",
    "utskällde": "utskälld",
    "utskälldes": "utskälld",
    "utskällds": "utskälld",
    "utskällningar": "utskällning",
    "utskällningarna": "utskällning",
    "utskällningarnas": "utskällning",
    "utskällningars": "utskällning",
    "utskällningen": "utskällning",
    "utskällningens": "utskällning",
    "utskällnings": "utskällning",
    "utskällt": "utskälld",
    "utskällts": "utskälld",
    "utskämda": "utskämd",
    "utskämdare": "utskämd",
    "utskämdares": "utskämd",
    "utskämdas": "utskämd",
    "utskämdast": "utskämd",
    "utskämdaste": "utskämd",
    "utskämdastes": "utskämd",
    "utskämdasts": "utskämd",
    "utskämde": "utskämd",
    "utskämdes": "utskämd",
    "utskämdheten": "utskämdhet",
    "utskämdhetens": "utskämdhet",
    "utskämdhets": "utskämdhet",
    "utskämds": "utskämd",
    "utskämt": "utskämd",
    "utskämts": "utskämd",
    "utskänk": "utskänka",
    "utskänkande": "utskänka",
    "utskänkanden": "utskänkande",
    "utskänkandena": "utskänkande",
    "utskänkandenas": "utskänkande",
    "utskänkandens": "utskänkande",
    "utskänkandes": "utskänkande",
    "utskänkandet": "utskänkande",
    "utskänkandets": "utskänkande",
    "utskänkas": "utskänka",
    "utskänker": "utskänka",
    "utskänkes": "utskänka",
    "utskänkningar": "utskänkning",
    "utskänkningarna": "utskänkning",
    "utskänkningarnas": "utskänkning",
    "utskänkningars": "utskänkning",
    "utskänkningen": "utskänkning",
    "utskänkningens": "utskänkning",
    "utskänknings": "utskänkning",
    "utskänkningstillstånden": "utskänkningstillstånd",
    "utskänkningstillståndens": "utskänkningstillstånd",
    "utskänkningstillståndet": "utskänkningstillstånd",
    "utskänkningstillståndets": "utskänkningstillstånd",
    "utskänkningstillstånds": "utskänkningstillstånd",
    "utskänks": "utskänka",
    "utskänkt": "utskänka",
    "utskänkta": "utskänka",
    "utskänktas": "utskänka",
    "utskänkte": "utskänka",
    "utskänktes": "utskänka",
    "utskänkts": "utskänka",
    "utskärgården": "utskärgård",
    "utskärgårdens": "utskärgård",
    "utskärgårds": "utskärgård",
    "utskåpningar": "utskåpning",
    "utskåpningarna": "utskåpning",
    "utskåpningarnas": "utskåpning",
    "utskåpningars": "utskåpning",
    "utskåpningen": "utskåpning",
    "utskåpningens": "utskåpning",
    "utskåpnings": "utskåpning",
    "utslagen": "utslag",
    "utslagens": "utslagen",
    "utslaget": "utslagen",
    "utslagets": "utslagen",
    "utslagna": "utslagen",
    "utslagnare": "utslagen",
    "utslagnares": "utslagen",
    "utslagnas": "utslagen",
    "utslagnast": "utslagen",
    "utslagnaste": "utslagen",
    "utslagnastes": "utslagen",
    "utslagnasts": "utslagen",
    "utslagne": "utslagen",
    "utslagnes": "utslagen",
    "utslagningar": "utslagning",
    "utslagningarna": "utslagning",
    "utslagningarnas": "utslagning",
    "utslagningars": "utslagning",
    "utslagningen": "utslagning",
    "utslagningens": "utslagning",
    "utslagnings": "utslagning",
    "utslagningsmekanismen": "utslagningsmekanism",
    "utslagningsmekanismens": "utslagningsmekanism",
    "utslagningsmekanismer": "utslagningsmekanism",
    "utslagningsmekanismerna": "utslagningsmekanism",
    "utslagningsmekanismernas": "utslagningsmekanism",
    "utslagningsmekanismers": "utslagningsmekanism",
    "utslagningsmekanisms": "utslagningsmekanism",
    "utslags": "utslag",
    "utslagsfrågan": "utslagsfråga",
    "utslagsfrågans": "utslagsfråga",
    "utslagsfrågas": "utslagsfråga",
    "utslagsfråge": "utslagsfråga",
    "utslagsfrågor": "utslagsfråga",
    "utslagsfrågorna": "utslagsfråga",
    "utslagsfrågornas": "utslagsfråga",
    "utslagsfrågors": "utslagsfråga",
    "utslagsrösten": "utslagsröst",
    "utslagsröstens": "utslagsröst",
    "utslagsröster": "utslagsröst",
    "utslagsrösterna": "utslagsröst",
    "utslagsrösternas": "utslagsröst",
    "utslagsrösters": "utslagsröst",
    "utslagsrösts": "utslagsröst",
    "utslagstävlingar": "utslagstävling",
    "utslagstävlingarna": "utslagstävling",
    "utslagstävlingarnas": "utslagstävling",
    "utslagstävlingars": "utslagstävling",
    "utslagstävlingen": "utslagstävling",
    "utslagstävlingens": "utslagstävling",
    "utslagstävlings": "utslagstävling",
    "utslitens": "utsliten",
    "utslitet": "utsliten",
    "utslitets": "utsliten",
    "utslitna": "utsliten",
    "utslitnare": "utsliten",
    "utslitnares": "utsliten",
    "utslitnas": "utsliten",
    "utslitnast": "utsliten",
    "utslitnaste": "utsliten",
    "utslitnastes": "utsliten",
    "utslitnasts": "utsliten",
    "utslitne": "utsliten",
    "utslitnes": "utsliten",
    "utslocknade": "utslocknad",
    "utslocknades": "utslocknad",
    "utslocknads": "utslocknad",
    "utslocknat": "utslocknad",
    "utslocknats": "utslocknad",
    "utslung": "utslunga",
    "utslungad": "utslunga",
    "utslungade": "utslunga",
    "utslungades": "utslunga",
    "utslungads": "utslunga",
    "utslungande": "utslunga",
    "utslunganden": "utslungande",
    "utslungandena": "utslungande",
    "utslungandenas": "utslungande",
    "utslungandens": "utslungande",
    "utslungandes": "utslungande",
    "utslungandet": "utslungande",
    "utslungandets": "utslungande",
    "utslungar": "utslunga",
    "utslungas": "utslunga",
    "utslungat": "utslunga",
    "utslungats": "utslunga",
    "utslutningar": "utslutning",
    "utslutningarna": "utslutning",
    "utslutningarnas": "utslutning",
    "utslutningars": "utslutning",
    "utslutningen": "utslutning",
    "utslutningens": "utslutning",
    "utslutnings": "utslutning",
    "utsläck": "utsläcka",
    "utsläckande": "utsläcka",
    "utsläckanden": "utsläckande",
    "utsläckandena": "utsläckande",
    "utsläckandenas": "utsläckande",
    "utsläckandens": "utsläckande",
    "utsläckandes": "utsläckande",
    "utsläckandet": "utsläckande",
    "utsläckandets": "utsläckande",
    "utsläckas": "utsläcka",
    "utsläcker": "utsläcka",
    "utsläckes": "utsläcka",
    "utsläckningar": "utsläckning",
    "utsläckningarna": "utsläckning",
    "utsläckningarnas": "utsläckning",
    "utsläckningars": "utsläckning",
    "utsläckningen": "utsläckning",
    "utsläckningens": "utsläckning",
    "utsläcknings": "utsläckning",
    "utsläcks": "utsläcka",
    "utsläckt": "utsläcka",
    "utsläckta": "utsläcka",
    "utsläcktas": "utsläcka",
    "utsläckte": "utsläcka",
    "utsläcktes": "utsläcka",
    "utsläckts": "utsläcka",
    "utsläpade": "utsläpad",
    "utsläpades": "utsläpad",
    "utsläpads": "utsläpad",
    "utsläpat": "utsläpad",
    "utsläpats": "utsläpad",
    "utsläppen": "utsläpp",
    "utsläppens": "utsläpp",
    "utsläppet": "utsläpp",
    "utsläppets": "utsläpp",
    "utsläpps": "utsläpp",
    "utsläppsminskningar": "utsläppsminskning",
    "utsläppsminskningarna": "utsläppsminskning",
    "utsläppsminskningarnas": "utsläppsminskning",
    "utsläppsminskningars": "utsläppsminskning",
    "utsläppsminskningen": "utsläppsminskning",
    "utsläppsminskningens": "utsläppsminskning",
    "utsläppsminsknings": "utsläppsminskning",
    "utsläppsnationen": "utsläppsnation",
    "utsläppsnationens": "utsläppsnation",
    "utsläppsnationer": "utsläppsnation",
    "utsläppsnationerna": "utsläppsnation",
    "utsläppsnationernas": "utsläppsnation",
    "utsläppsnationers": "utsläppsnation",
    "utsläppsnations": "utsläppsnation",
    "utslät": "utsläta",
    "utslätad": "utsläta",
    "utslätade": "utsläta",
    "utslätades": "utsläta",
    "utslätads": "utsläta",
    "utslätande": "utsläta",
    "utslätanden": "utslätande",
    "utslätandena": "utslätande",
    "utslätandenas": "utslätande",
    "utslätandens": "utslätande",
    "utslätandes": "utslätande",
    "utslätandet": "utslätande",
    "utslätandets": "utslätande",
    "utslätar": "utsläta",
    "utslätas": "utsläta",
    "utslätat": "utsläta",
    "utslätats": "utsläta",
    "utsmyck": "utsmycka",
    "utsmyckad": "utsmycka",
    "utsmyckade": "utsmyckad",
    "utsmyckades": "utsmyckad",
    "utsmyckads": "utsmyckad",
    "utsmyckande": "utsmycka",
    "utsmyckanden": "utsmyckande",
    "utsmyckandena": "utsmyckande",
    "utsmyckandenas": "utsmyckande",
    "utsmyckandens": "utsmyckande",
    "utsmyckandes": "utsmyckande",
    "utsmyckandet": "utsmyckande",
    "utsmyckandets": "utsmyckande",
    "utsmyckar": "utsmycka",
    "utsmyckas": "utsmycka",
    "utsmyckat": "utsmyckad",
    "utsmyckats": "utsmyckad",
    "utsmyckningar": "utsmyckning",
    "utsmyckningarna": "utsmyckning",
    "utsmyckningarnas": "utsmyckning",
    "utsmyckningars": "utsmyckning",
    "utsmyckningen": "utsmyckning",
    "utsmyckningens": "utsmyckning",
    "utsmycknings": "utsmyckning",
    "utsnitten": "utsnitt",
    "utsnittens": "utsnitt",
    "utsnittet": "utsnitt",
    "utsnittets": "utsnitt",
    "utsnitts": "utsnitt",
    "utsoten": "utsot",
    "utsotens": "utsot",
    "utsots": "utsot",
    "utspan": "utspana",
    "utspanad": "utspana",
    "utspanade": "utspana",
    "utspanades": "utspana",
    "utspanads": "utspana",
    "utspanande": "utspana",
    "utspananden": "utspanande",
    "utspanandena": "utspanande",
    "utspanandenas": "utspanande",
    "utspanandens": "utspanande",
    "utspanandes": "utspanande",
    "utspanandet": "utspanande",
    "utspanandets": "utspanande",
    "utspanar": "utspana",
    "utspanas": "utspana",
    "utspanat": "utspana",
    "utspanats": "utspana",
    "utsparkade": "utsparkad",
    "utsparkades": "utsparkad",
    "utsparkads": "utsparkad",
    "utsparkar": "utspark",
    "utsparkarna": "utspark",
    "utsparkarnas": "utspark",
    "utsparkars": "utspark",
    "utsparkat": "utsparkad",
    "utsparkats": "utsparkad",
    "utsparken": "utspark",
    "utsparkens": "utspark",
    "utsparks": "utspark",
    "utspekulerade": "utspekulerad",
    "utspekulerades": "utspekulerad",
    "utspekulerads": "utspekulerad",
    "utspekulerat": "utspekulerad",
    "utspekulerats": "utspekulerad",
    "utspelades": "utspelas",
    "utspelats": "utspelas",
    "utspelen": "utspel",
    "utspelens": "utspel",
    "utspelet": "utspel",
    "utspelets": "utspel",
    "utspels": "utspel",
    "utspis": "utspisa",
    "utspisad": "utspisa",
    "utspisade": "utspisa",
    "utspisades": "utspisa",
    "utspisads": "utspisa",
    "utspisande": "utspisa",
    "utspisanden": "utspisande",
    "utspisandena": "utspisande",
    "utspisandenas": "utspisande",
    "utspisandens": "utspisande",
    "utspisandes": "utspisande",
    "utspisandet": "utspisande",
    "utspisandets": "utspisande",
    "utspisar": "utspisa",
    "utspisas": "utspisa",
    "utspisat": "utspisa",
    "utspisats": "utspisa",
    "utspisningar": "utspisning",
    "utspisningarna": "utspisning",
    "utspisningarnas": "utspisning",
    "utspisningars": "utspisning",
    "utspisningen": "utspisning",
    "utspisningens": "utspisning",
    "utspisnings": "utspisning",
    "utspisningsställen": "utspisningsställe",
    "utspisningsställena": "utspisningsställe",
    "utspisningsställenas": "utspisningsställe",
    "utspisningsställens": "utspisningsställe",
    "utspisningsställes": "utspisningsställe",
    "utspisningsstället": "utspisningsställe",
    "utspisningsställets": "utspisningsställe",
    "utspred": "utsprida",
    "utsprede": "utsprida",
    "utspredes": "utsprida",
    "utspreds": "utsprida",
    "utsprid": "utsprida",
    "utspridande": "utsprida",
    "utspridanden": "utspridande",
    "utspridandena": "utspridande",
    "utspridandenas": "utspridande",
    "utspridandens": "utspridande",
    "utspridandes": "utspridande",
    "utspridandet": "utspridande",
    "utspridandets": "utspridande",
    "utspridas": "utsprida",
    "utspridd": "utsprida",
    "utspridda": "utspridd",
    "utspriddare": "utspridd",
    "utspriddares": "utspridd",
    "utspriddas": "utspridd",
    "utspriddast": "utspridd",
    "utspriddaste": "utspridd",
    "utspriddastes": "utspridd",
    "utspriddasts": "utspridd",
    "utspridde": "utspridd",
    "utspriddes": "utspridd",
    "utspriddheten": "utspriddhet",
    "utspriddhetens": "utspriddhet",
    "utspriddhets": "utspriddhet",
    "utspridds": "utspridd",
    "utspride": "utsprida",
    "utsprider": "utsprida",
    "utsprides": "utsprida",
    "utspridit": "utsprida",
    "utspridits": "utsprida",
    "utsprids": "utsprida",
    "utspritt": "utspridd",
    "utspritts": "utspridd",
    "utsprungens": "utsprungen",
    "utsprunget": "utsprungen",
    "utsprungets": "utsprungen",
    "utsprungna": "utsprungen",
    "utsprungnare": "utsprungen",
    "utsprungnares": "utsprungen",
    "utsprungnas": "utsprungen",
    "utsprungnast": "utsprungen",
    "utsprungnaste": "utsprungen",
    "utsprungnastes": "utsprungen",
    "utsprungnasts": "utsprungen",
    "utsprungne": "utsprungen",
    "utsprungnes": "utsprungen",
    "utsprången": "utsprång",
    "utsprångens": "utsprång",
    "utsprånget": "utsprång",
    "utsprångets": "utsprång",
    "utsprångs": "utsprång",
    "utspydd": "utspy",
    "utspydda": "utspy",
    "utspyddas": "utspy",
    "utspydde": "utspy",
    "utspyddes": "utspy",
    "utspydds": "utspy",
    "utspyende": "utspy",
    "utspyenden": "utspyende",
    "utspyendena": "utspyende",
    "utspyendenas": "utspyende",
    "utspyendens": "utspyende",
    "utspyendes": "utspyende",
    "utspyendet": "utspyende",
    "utspyendets": "utspyende",
    "utspyr": "utspy",
    "utspys": "utspy",
    "utspytt": "utspy",
    "utspytts": "utspy",
    "utspädda": "utspädd",
    "utspäddare": "utspädd",
    "utspäddares": "utspädd",
    "utspäddas": "utspädd",
    "utspäddast": "utspädd",
    "utspäddaste": "utspädd",
    "utspäddastes": "utspädd",
    "utspäddasts": "utspädd",
    "utspädde": "utspädd",
    "utspäddes": "utspädd",
    "utspäddheten": "utspäddhet",
    "utspäddhetens": "utspäddhet",
    "utspäddhets": "utspäddhet",
    "utspädds": "utspädd",
    "utspände": "utspänd",
    "utspändes": "utspänd",
    "utspändheten": "utspändhet",
    "utspändhetens": "utspändhet",
    "utspändhets": "utspändhet",
    "utspänds": "utspänd",
    "utspänningar": "utspänning",
    "utspänningarna": "utspänning",
    "utspänningarnas": "utspänning",
    "utspänningars": "utspänning",
    "utspänningen": "utspänning",
    "utspänningens": "utspänning",
    "utspännings": "utspänning",
    "utspänt": "utspänd",
    "utspänts": "utspänd",
    "utspärr": "utspärra",
    "utspärrad": "utspärra",
    "utspärrade": "utspärra",
    "utspärrades": "utspärra",
    "utspärrads": "utspärra",
    "utspärrande": "utspärra",
    "utspärranden": "utspärrande",
    "utspärrandena": "utspärrande",
    "utspärrandenas": "utspärrande",
    "utspärrandens": "utspärrande",
    "utspärrandes": "utspärrande",
    "utspärrandet": "utspärrande",
    "utspärrandets": "utspärrande",
    "utspärrar": "utspärra",
    "utspärras": "utspärra",
    "utspärrat": "utspärra",
    "utspärrats": "utspärra",
    "utspätt": "utspädd",
    "utspätts": "utspädd",
    "utspökade": "utspökad",
    "utspökades": "utspökad",
    "utspökads": "utspökad",
    "utspökat": "utspökad",
    "utspökats": "utspökad",
    "utstak": "utstaka",
    "utstakad": "utstaka",
    "utstakade": "utstaka",
    "utstakades": "utstaka",
    "utstakads": "utstaka",
    "utstakande": "utstaka",
    "utstakanden": "utstakande",
    "utstakandena": "utstakande",
    "utstakandenas": "utstakande",
    "utstakandens": "utstakande",
    "utstakandes": "utstakande",
    "utstakandet": "utstakande",
    "utstakandets": "utstakande",
    "utstakar": "utstaka",
    "utstakas": "utstaka",
    "utstakat": "utstaka",
    "utstakats": "utstaka",
    "utstod": "utstå",
    "utstode": "utstå",
    "utstodes": "utstå",
    "utstods": "utstå",
    "utstofferad": "utstoffera",
    "utstofferade": "utstofferad",
    "utstofferades": "utstofferad",
    "utstofferads": "utstofferad",
    "utstofferande": "utstoffera",
    "utstofferanden": "utstofferande",
    "utstofferandena": "utstofferande",
    "utstofferandenas": "utstofferande",
    "utstofferandens": "utstofferande",
    "utstofferandes": "utstofferande",
    "utstofferandet": "utstofferande",
    "utstofferandets": "utstofferande",
    "utstofferar": "utstoffera",
    "utstofferas": "utstoffera",
    "utstofferat": "utstofferad",
    "utstofferats": "utstofferad",
    "utstofferbara": "utstofferbar",
    "utstofferbarare": "utstofferbar",
    "utstofferbarares": "utstofferbar",
    "utstofferbaras": "utstofferbar",
    "utstofferbarast": "utstofferbar",
    "utstofferbaraste": "utstofferbar",
    "utstofferbarastes": "utstofferbar",
    "utstofferbarasts": "utstofferbar",
    "utstofferbare": "utstofferbar",
    "utstofferbares": "utstofferbar",
    "utstofferbarheten": "utstofferbarhet",
    "utstofferbarhetens": "utstofferbarhet",
    "utstofferbarhets": "utstofferbarhet",
    "utstofferbars": "utstofferbar",
    "utstofferbart": "utstofferbar",
    "utstofferbarts": "utstofferbar",
    "utstofferingar": "utstoffering",
    "utstofferingarna": "utstoffering",
    "utstofferingarnas": "utstoffering",
    "utstofferingars": "utstoffering",
    "utstofferingen": "utstoffering",
    "utstofferingens": "utstoffering",
    "utstofferings": "utstoffering",
    "utsträck": "utsträcka",
    "utsträckande": "utsträcka",
    "utsträckanden": "utsträckande",
    "utsträckandena": "utsträckande",
    "utsträckandenas": "utsträckande",
    "utsträckandens": "utsträckande",
    "utsträckandes": "utsträckande",
    "utsträckandet": "utsträckande",
    "utsträckandets": "utsträckande",
    "utsträckas": "utsträcka",
    "utsträcker": "utsträcka",
    "utsträckes": "utsträcka",
    "utsträckningar": "utsträckning",
    "utsträckningarna": "utsträckning",
    "utsträckningarnas": "utsträckning",
    "utsträckningars": "utsträckning",
    "utsträckningen": "utsträckning",
    "utsträckningens": "utsträckning",
    "utsträcknings": "utsträckning",
    "utsträcks": "utsträcka",
    "utsträckt": "utsträcka",
    "utsträckta": "utsträcka",
    "utsträcktas": "utsträcka",
    "utsträckte": "utsträcka",
    "utsträcktes": "utsträcka",
    "utsträckts": "utsträcka",
    "utstrål": "utstråla",
    "utstrålad": "utstråla",
    "utstrålade": "utstråla",
    "utstrålades": "utstråla",
    "utstrålads": "utstråla",
    "utstrålande": "utstråla",
    "utstrålanden": "utstrålande",
    "utstrålandena": "utstrålande",
    "utstrålandenas": "utstrålande",
    "utstrålandens": "utstrålande",
    "utstrålandes": "utstrålande",
    "utstrålandet": "utstrålande",
    "utstrålandets": "utstrålande",
    "utstrålar": "utstråla",
    "utstrålas": "utstråla",
    "utstrålat": "utstråla",
    "utstrålats": "utstråla",
    "utstrålningar": "utstrålning",
    "utstrålningarna": "utstrålning",
    "utstrålningarnas": "utstrålning",
    "utstrålningars": "utstrålning",
    "utstrålningen": "utstrålning",
    "utstrålningens": "utstrålning",
    "utstrålnings": "utstrålning",
    "utstuderade": "utstuderad",
    "utstuderades": "utstuderad",
    "utstuderads": "utstuderad",
    "utstuderat": "utstuderad",
    "utstuderats": "utstuderad",
    "utstyrda": "utstyrd",
    "utstyrdare": "utstyrd",
    "utstyrdares": "utstyrd",
    "utstyrdas": "utstyrd",
    "utstyrdast": "utstyrd",
    "utstyrdaste": "utstyrd",
    "utstyrdastes": "utstyrd",
    "utstyrdasts": "utstyrd",
    "utstyrde": "utstyrd",
    "utstyrdes": "utstyrd",
    "utstyrds": "utstyrd",
    "utstyrseln": "utstyrsel",
    "utstyrselns": "utstyrsel",
    "utstyrsels": "utstyrsel",
    "utstyrslar": "utstyrsel",
    "utstyrslarna": "utstyrsel",
    "utstyrslarnas": "utstyrsel",
    "utstyrslars": "utstyrsel",
    "utstyrt": "utstyrd",
    "utstyrts": "utstyrd",
    "utställ": "utställa",
    "utställande": "utställa",
    "utställanden": "utställande",
    "utställandena": "utställande",
    "utställandenas": "utställande",
    "utställandens": "utställande",
    "utställandes": "utställande",
    "utställandet": "utställande",
    "utställandets": "utställande",
    "utställar": "utställare",
    "utställaren": "utställare",
    "utställarens": "utställare",
    "utställares": "utställare",
    "utställarna": "utställare",
    "utställarnas": "utställare",
    "utställas": "utställa",
    "utställd": "utställa",
    "utställda": "utställd",
    "utställdare": "utställd",
    "utställdares": "utställd",
    "utställdas": "utställd",
    "utställdast": "utställd",
    "utställdaste": "utställd",
    "utställdastes": "utställd",
    "utställdasts": "utställd",
    "utställde": "utställd",
    "utställdes": "utställd",
    "utställds": "utställd",
    "utställelsen": "utställelse",
    "utställelsens": "utställelse",
    "utställelser": "utställelse",
    "utställelserna": "utställelse",
    "utställelsernas": "utställelse",
    "utställelsers": "utställelse",
    "utställelses": "utställelse",
    "utställer": "utställa",
    "utställes": "utställa",
    "utställningar": "utställning",
    "utställningarna": "utställning",
    "utställningarnas": "utställning",
    "utställningars": "utställning",
    "utställningen": "utställning",
    "utställningens": "utställning",
    "utställnings": "utställning",
    "utställs": "utställa",
    "utställt": "utställd",
    "utställts": "utställd",
    "utstående": "utstå",
    "utståenden": "utstående",
    "utståendena": "utstående",
    "utståendenas": "utstående",
    "utståendens": "utstående",
    "utståendes": "utstående",
    "utståendet": "utstående",
    "utståendets": "utstående",
    "utstånden": "utstå",
    "utståndens": "utstånden",
    "utståndet": "utstånden",
    "utståndets": "utstånden",
    "utståndna": "utstånden",
    "utståndnas": "utstånden",
    "utståndne": "utstånden",
    "utståndnes": "utstånden",
    "utstår": "utstå",
    "utstås": "utstå",
    "utstått": "utstå",
    "utståtts": "utstå",
    "utstöt": "utstöta",
    "utstötande": "utstöta",
    "utstötanden": "utstötande",
    "utstötandena": "utstötande",
    "utstötandenas": "utstötande",
    "utstötandens": "utstötande",
    "utstötandes": "utstötande",
    "utstötandet": "utstötande",
    "utstötandets": "utstötande",
    "utstötas": "utstöta",
    "utstöter": "utstöta",
    "utstötes": "utstöta",
    "utstöts": "utstöta",
    "utstött": "utstöta",
    "utstötta": "utstött",
    "utstöttas": "utstött",
    "utstötte": "utstött",
    "utstöttes": "utstött",
    "utstöttheten": "utstötthet",
    "utstötthetens": "utstötthet",
    "utstötthets": "utstötthet",
    "utstötts": "utstött",
    "utsuddade": "utsuddad",
    "utsuddades": "utsuddad",
    "utsuddads": "utsuddad",
    "utsuddat": "utsuddad",
    "utsuddats": "utsuddad",
    "utsug": "utsuga",
    "utsugande": "utsuga",
    "utsuganden": "utsugande",
    "utsugandena": "utsugande",
    "utsugandenas": "utsugande",
    "utsugandens": "utsugande",
    "utsugandes": "utsugande",
    "utsugandet": "utsugande",
    "utsugandets": "utsugande",
    "utsugas": "utsuga",
    "utsuge": "utsuga",
    "utsugen": "utsuga",
    "utsugens": "utsuga",
    "utsuger": "utsuga",
    "utsuges": "utsuga",
    "utsuget": "utsuga",
    "utsugets": "utsuga",
    "utsugit": "utsuga",
    "utsugits": "utsuga",
    "utsugna": "utsuga",
    "utsugnas": "utsuga",
    "utsugne": "utsuga",
    "utsugnes": "utsuga",
    "utsugningar": "utsugning",
    "utsugningarna": "utsugning",
    "utsugningarnas": "utsugning",
    "utsugningars": "utsugning",
    "utsugningen": "utsugning",
    "utsugningens": "utsugning",
    "utsugnings": "utsugning",
    "utsugs": "utsuga",
    "utsvultens": "utsvulten",
    "utsvultet": "utsvulten",
    "utsvultets": "utsvulten",
    "utsvultna": "utsvulten",
    "utsvultnare": "utsvulten",
    "utsvultnares": "utsvulten",
    "utsvultnas": "utsvulten",
    "utsvultnast": "utsvulten",
    "utsvultnaste": "utsvulten",
    "utsvultnastes": "utsvulten",
    "utsvultnasts": "utsvulten",
    "utsvultne": "utsvulten",
    "utsvultnes": "utsvulten",
    "utsvängda": "utsvängd",
    "utsvängdare": "utsvängd",
    "utsvängdares": "utsvängd",
    "utsvängdas": "utsvängd",
    "utsvängdast": "utsvängd",
    "utsvängdaste": "utsvängd",
    "utsvängdastes": "utsvängd",
    "utsvängdasts": "utsvängd",
    "utsvängde": "utsvängd",
    "utsvängdes": "utsvängd",
    "utsvängdheten": "utsvängdhet",
    "utsvängdhetens": "utsvängdhet",
    "utsvängdhets": "utsvängdhet",
    "utsvängds": "utsvängd",
    "utsvängt": "utsvängd",
    "utsvängts": "utsvängd",
    "utsvävningar": "utsvävning",
    "utsvävningarna": "utsvävning",
    "utsvävningarnas": "utsvävning",
    "utsvävningars": "utsvävning",
    "utsvävningen": "utsvävning",
    "utsvävningens": "utsvävning",
    "utsvävnings": "utsvävning",
    "utsyn": "utsyna",
    "utsynad": "utsyna",
    "utsynade": "utsyna",
    "utsynades": "utsyna",
    "utsynads": "utsyna",
    "utsynande": "utsyna",
    "utsynanden": "utsynande",
    "utsynandena": "utsynande",
    "utsynandenas": "utsynande",
    "utsynandens": "utsynande",
    "utsynandes": "utsynande",
    "utsynandet": "utsynande",
    "utsynandets": "utsynande",
    "utsynar": "utsyna",
    "utsynas": "utsyna",
    "utsynat": "utsyna",
    "utsynats": "utsyna",
    "utsäden": "utsäde",
    "utsädena": "utsäde",
    "utsädenas": "utsäde",
    "utsädens": "utsäde",
    "utsädes": "utsäde",
    "utsädet": "utsäde",
    "utsädets": "utsäde",
    "utsäg": "utsäga",
    "utsägande": "utsäga",
    "utsäganden": "utsägande",
    "utsägandena": "utsägande",
    "utsägandenas": "utsägande",
    "utsägandens": "utsägande",
    "utsägandes": "utsägande",
    "utsägandet": "utsägande",
    "utsägandets": "utsägande",
    "utsägas": "utsäga",
    "utsäger": "utsäga",
    "utsäges": "utsäga",
    "utsägs": "utsäga",
    "utsänd": "utsända",
    "utsändande": "utsända",
    "utsändanden": "utsändande",
    "utsändandena": "utsändande",
    "utsändandenas": "utsändande",
    "utsändandens": "utsändande",
    "utsändandes": "utsändande",
    "utsändandet": "utsändande",
    "utsändandets": "utsändande",
    "utsändas": "utsända",
    "utsände": "utsända",
    "utsänder": "utsända",
    "utsändes": "utsända",
    "utsändningar": "utsändning",
    "utsändningarna": "utsändning",
    "utsändningarnas": "utsändning",
    "utsändningars": "utsändning",
    "utsändningen": "utsändning",
    "utsändningens": "utsändning",
    "utsändnings": "utsändning",
    "utsänds": "utsända",
    "utsänt": "utsända",
    "utsänts": "utsända",
    "utsätt": "utsätta",
    "utsättande": "utsätta",
    "utsättanden": "utsättande",
    "utsättandena": "utsättande",
    "utsättandenas": "utsättande",
    "utsättandens": "utsättande",
    "utsättandes": "utsättande",
    "utsättandet": "utsättande",
    "utsättandets": "utsättande",
    "utsättas": "utsätta",
    "utsätter": "utsätta",
    "utsättes": "utsätta",
    "utsätts": "utsätta",
    "utsåg": "utse",
    "utsåge": "utse",
    "utsåges": "utse",
    "utsågs": "utse",
    "utsålda": "utsåld",
    "utsåldare": "utsåld",
    "utsåldares": "utsåld",
    "utsåldas": "utsåld",
    "utsåldast": "utsåld",
    "utsåldaste": "utsåld",
    "utsåldastes": "utsåld",
    "utsåldasts": "utsåld",
    "utsålde": "utsåld",
    "utsåldes": "utsåld",
    "utsålds": "utsåld",
    "utsålt": "utsåld",
    "utsålts": "utsåld",
    "utsög": "utsuga",
    "utsöge": "utsuga",
    "utsöges": "utsuga",
    "utsögs": "utsuga",
    "utsök": "utsöka",
    "utsökande": "utsöka",
    "utsökanden": "utsökande",
    "utsökandena": "utsökande",
    "utsökandenas": "utsökande",
    "utsökandens": "utsökande",
    "utsökandes": "utsökande",
    "utsökandet": "utsökande",
    "utsökandets": "utsökande",
    "utsökas": "utsöka",
    "utsöker": "utsöka",
    "utsökes": "utsöka",
    "utsökningar": "utsökning",
    "utsökningarna": "utsökning",
    "utsökningarnas": "utsökning",
    "utsökningars": "utsökning",
    "utsökningen": "utsökning",
    "utsökningens": "utsökning",
    "utsöknings": "utsökning",
    "utsöks": "utsöka",
    "utsökt": "utsöka",
    "utsökta": "utsökt",
    "utsöktare": "utsökt",
    "utsöktares": "utsökt",
    "utsöktas": "utsökt",
    "utsöktast": "utsökt",
    "utsöktaste": "utsökt",
    "utsöktastes": "utsökt",
    "utsöktasts": "utsökt",
    "utsökte": "utsökt",
    "utsöktes": "utsökt",
    "utsöktheten": "utsökthet",
    "utsökthetens": "utsökthet",
    "utsöktheter": "utsökthet",
    "utsöktheterna": "utsökthet",
    "utsöktheternas": "utsökthet",
    "utsöktheters": "utsökthet",
    "utsökthets": "utsökthet",
    "utsökts": "utsökt",
    "utsöndrad": "utsöndra",
    "utsöndrade": "utsöndra",
    "utsöndrades": "utsöndra",
    "utsöndrads": "utsöndra",
    "utsöndrande": "utsöndra",
    "utsöndranden": "utsöndrande",
    "utsöndrandena": "utsöndrande",
    "utsöndrandenas": "utsöndrande",
    "utsöndrandens": "utsöndrande",
    "utsöndrandes": "utsöndrande",
    "utsöndrandet": "utsöndrande",
    "utsöndrandets": "utsöndrande",
    "utsöndrar": "utsöndra",
    "utsöndras": "utsöndra",
    "utsöndrat": "utsöndra",
    "utsöndrats": "utsöndra",
    "utsöndringar": "utsöndring",
    "utsöndringarna": "utsöndring",
    "utsöndringarnas": "utsöndring",
    "utsöndringars": "utsöndring",
    "utsöndringen": "utsöndring",
    "utsöndringens": "utsöndring",
    "utsöndrings": "utsöndring",
    "utsöndringsorganen": "utsöndringsorgan",
    "utsöndringsorganens": "utsöndringsorgan",
    "utsöndringsorganet": "utsöndringsorgan",
    "utsöndringsorganets": "utsöndringsorgan",
    "utsöndringsorgans": "utsöndringsorgan",
    "utsövda": "utsövd",
    "utsövdare": "utsövd",
    "utsövdares": "utsövd",
    "utsövdas": "utsövd",
    "utsövdast": "utsövd",
    "utsövdaste": "utsövd",
    "utsövdastes": "utsövd",
    "utsövdasts": "utsövd",
    "utsövde": "utsövd",
    "utsövdes": "utsövd",
    "utsövdheten": "utsövdhet",
    "utsövdhetens": "utsövdhet",
    "utsövdhets": "utsövdhet",
    "utsövds": "utsövd",
    "utsövt": "utsövd",
    "utsövts": "utsövd",
    "uttagbara": "uttagbar",
    "uttagbaras": "uttagbar",
    "uttagbare": "uttagbar",
    "uttagbares": "uttagbar",
    "uttagbars": "uttagbar",
    "uttagbart": "uttagbar",
    "uttagbarts": "uttagbar",
    "uttagen": "uttag",
    "uttagens": "uttag",
    "uttaget": "uttag",
    "uttagets": "uttag",
    "uttagningar": "uttagning",
    "uttagningarna": "uttagning",
    "uttagningarnas": "uttagning",
    "uttagningars": "uttagning",
    "uttagningen": "uttagning",
    "uttagningens": "uttagning",
    "uttagnings": "uttagning",
    "uttags": "uttag",
    "uttal": "uttala",
    "uttalad": "uttala",
    "uttalade": "uttalad",
    "uttalades": "uttalad",
    "uttalads": "uttalad",
    "uttalande": "uttala",
    "uttalanden": "uttalande",
    "uttalandena": "uttalande",
    "uttalandenas": "uttalande",
    "uttalandens": "uttalande",
    "uttalandes": "uttalande",
    "uttalandet": "uttalande",
    "uttalandets": "uttalande",
    "uttalar": "uttala",
    "uttalas": "uttala",
    "uttalat": "uttalad",
    "uttalats": "uttalad",
    "uttalen": "uttal",
    "uttalens": "uttal",
    "uttalet": "uttal",
    "uttalets": "uttal",
    "uttals": "uttal",
    "uttalsbeteckningar": "uttalsbeteckning",
    "uttalsbeteckningarna": "uttalsbeteckning",
    "uttalsbeteckningarnas": "uttalsbeteckning",
    "uttalsbeteckningars": "uttalsbeteckning",
    "uttalsbeteckningen": "uttalsbeteckning",
    "uttalsbeteckningens": "uttalsbeteckning",
    "uttalsbetecknings": "uttalsbeteckning",
    "uttalsenliga": "uttalsenlig",
    "uttalsenligare": "uttalsenlig",
    "uttalsenligares": "uttalsenlig",
    "uttalsenligas": "uttalsenlig",
    "uttalsenligast": "uttalsenlig",
    "uttalsenligaste": "uttalsenlig",
    "uttalsenligastes": "uttalsenlig",
    "uttalsenligasts": "uttalsenlig",
    "uttalsenlige": "uttalsenlig",
    "uttalsenliges": "uttalsenlig",
    "uttalsenligheten": "uttalsenlighet",
    "uttalsenlighetens": "uttalsenlighet",
    "uttalsenlighets": "uttalsenlighet",
    "uttalsenligs": "uttalsenlig",
    "uttalsenligt": "uttalsenlig",
    "uttalsenligts": "uttalsenlig",
    "uttalsfelen": "uttalsfel",
    "uttalsfelens": "uttalsfel",
    "uttalsfelet": "uttalsfel",
    "uttalsfelets": "uttalsfel",
    "uttalsfels": "uttalsfel",
    "uttalsteckens": "uttalstecken",
    "uttalstecknen": "uttalstecken",
    "uttalstecknens": "uttalstecken",
    "uttalstecknet": "uttalstecken",
    "uttalstecknets": "uttalstecken",
    "uttaxerad": "uttaxera",
    "uttaxerade": "uttaxera",
    "uttaxerades": "uttaxera",
    "uttaxerads": "uttaxera",
    "uttaxerande": "uttaxera",
    "uttaxeranden": "uttaxerande",
    "uttaxerandena": "uttaxerande",
    "uttaxerandenas": "uttaxerande",
    "uttaxerandens": "uttaxerande",
    "uttaxerandes": "uttaxerande",
    "uttaxerandet": "uttaxerande",
    "uttaxerandets": "uttaxerande",
    "uttaxerar": "uttaxera",
    "uttaxeras": "uttaxera",
    "uttaxerat": "uttaxera",
    "uttaxerats": "uttaxera",
    "uttaxerbara": "uttaxerbar",
    "uttaxerbarare": "uttaxerbar",
    "uttaxerbarares": "uttaxerbar",
    "uttaxerbaras": "uttaxerbar",
    "uttaxerbarast": "uttaxerbar",
    "uttaxerbaraste": "uttaxerbar",
    "uttaxerbarastes": "uttaxerbar",
    "uttaxerbarasts": "uttaxerbar",
    "uttaxerbare": "uttaxerbar",
    "uttaxerbares": "uttaxerbar",
    "uttaxerbarheten": "uttaxerbarhet",
    "uttaxerbarhetens": "uttaxerbarhet",
    "uttaxerbarhets": "uttaxerbarhet",
    "uttaxerbars": "uttaxerbar",
    "uttaxerbart": "uttaxerbar",
    "uttaxerbarts": "uttaxerbar",
    "uttaxeringar": "uttaxering",
    "uttaxeringarna": "uttaxering",
    "uttaxeringarnas": "uttaxering",
    "uttaxeringars": "uttaxering",
    "uttaxeringen": "uttaxering",
    "uttaxeringens": "uttaxering",
    "uttaxerings": "uttaxering",
    "uttern": "utter",
    "utterns": "utter",
    "utters": "utter",
    "uttittade": "uttittad",
    "uttittades": "uttittad",
    "uttittads": "uttittad",
    "uttittat": "uttittad",
    "uttittats": "uttittad",
    "uttjatade": "uttjatad",
    "uttjatades": "uttjatad",
    "uttjatads": "uttjatad",
    "uttjatat": "uttjatad",
    "uttjatats": "uttjatad",
    "uttjänade": "uttjänad",
    "uttjänades": "uttjänad",
    "uttjänads": "uttjänad",
    "uttjänat": "uttjänad",
    "uttjänats": "uttjänad",
    "uttjänta": "uttjänt",
    "uttjäntare": "uttjänt",
    "uttjäntares": "uttjänt",
    "uttjäntas": "uttjänt",
    "uttjäntast": "uttjänt",
    "uttjäntaste": "uttjänt",
    "uttjäntastes": "uttjänt",
    "uttjäntasts": "uttjänt",
    "uttjänte": "uttjänt",
    "uttjäntes": "uttjänt",
    "uttjäntheten": "uttjänthet",
    "uttjänthetens": "uttjänthet",
    "uttjänthets": "uttjänthet",
    "uttjänts": "uttjänt",
    "uttolk": "uttolka",
    "uttolkad": "uttolka",
    "uttolkade": "uttolka",
    "uttolkades": "uttolka",
    "uttolkads": "uttolka",
    "uttolkande": "uttolka",
    "uttolkanden": "uttolkande",
    "uttolkandena": "uttolkande",
    "uttolkandenas": "uttolkande",
    "uttolkandens": "uttolkande",
    "uttolkandes": "uttolkande",
    "uttolkandet": "uttolkande",
    "uttolkandets": "uttolkande",
    "uttolkar": "uttolka",
    "uttolkas": "uttolka",
    "uttolkat": "uttolka",
    "uttolkats": "uttolka",
    "uttorkanden": "uttorkande",
    "uttorkandena": "uttorkande",
    "uttorkandenas": "uttorkande",
    "uttorkandens": "uttorkande",
    "uttorkandes": "uttorkande",
    "uttorkandet": "uttorkande",
    "uttorkandets": "uttorkande",
    "uttrar": "utter",
    "uttrarna": "utter",
    "uttrarnas": "utter",
    "uttrars": "utter",
    "uttryck": "uttrycka",
    "uttryckande": "uttrycka",
    "uttryckanden": "uttryckande",
    "uttryckandena": "uttryckande",
    "uttryckandenas": "uttryckande",
    "uttryckandens": "uttryckande",
    "uttryckandes": "uttryckande",
    "uttryckandet": "uttryckande",
    "uttryckandets": "uttryckande",
    "uttryckas": "uttrycka",
    "uttrycken": "uttryck",
    "uttryckens": "uttryck",
    "uttrycker": "uttrycka",
    "uttryckes": "uttrycka",
    "uttrycket": "uttryck",
    "uttryckets": "uttryck",
    "uttryckliga": "uttrycklig",
    "uttryckligare": "uttrycklig",
    "uttryckligares": "uttrycklig",
    "uttryckligas": "uttrycklig",
    "uttryckligast": "uttrycklig",
    "uttryckligaste": "uttrycklig",
    "uttryckligastes": "uttrycklig",
    "uttryckligasts": "uttrycklig",
    "uttrycklige": "uttrycklig",
    "uttryckliges": "uttrycklig",
    "uttryckligheten": "uttrycklighet",
    "uttrycklighetens": "uttrycklighet",
    "uttrycklighets": "uttrycklighet",
    "uttryckligs": "uttrycklig",
    "uttryckligt": "uttrycklig",
    "uttryckligts": "uttrycklig",
    "uttrycks": "uttrycka",
    "uttrycksformen": "uttrycksform",
    "uttrycksformens": "uttrycksform",
    "uttrycksformer": "uttrycksform",
    "uttrycksformerna": "uttrycksform",
    "uttrycksformernas": "uttrycksform",
    "uttrycksformers": "uttrycksform",
    "uttrycksforms": "uttrycksform",
    "uttrycksfulla": "uttrycksfull",
    "uttrycksfullare": "uttrycksfull",
    "uttrycksfullares": "uttrycksfull",
    "uttrycksfullas": "uttrycksfull",
    "uttrycksfullast": "uttrycksfull",
    "uttrycksfullaste": "uttrycksfull",
    "uttrycksfullastes": "uttrycksfull",
    "uttrycksfullasts": "uttrycksfull",
    "uttrycksfulle": "uttrycksfull",
    "uttrycksfulles": "uttrycksfull",
    "uttrycksfullheten": "uttrycksfullhet",
    "uttrycksfullhetens": "uttrycksfullhet",
    "uttrycksfullhets": "uttrycksfullhet",
    "uttrycksfulls": "uttrycksfull",
    "uttrycksfullt": "uttrycksfull",
    "uttrycksfullts": "uttrycksfull",
    "uttryckslösa": "uttryckslös",
    "uttryckslösare": "uttryckslös",
    "uttryckslösares": "uttryckslös",
    "uttryckslösas": "uttryckslös",
    "uttryckslösast": "uttryckslös",
    "uttryckslösaste": "uttryckslös",
    "uttryckslösastes": "uttryckslös",
    "uttryckslösasts": "uttryckslös",
    "uttryckslöse": "uttryckslös",
    "uttryckslöses": "uttryckslös",
    "uttryckslösheten": "uttryckslöshet",
    "uttryckslöshetens": "uttryckslöshet",
    "uttryckslöshets": "uttryckslöshet",
    "uttryckslöst": "uttryckslös",
    "uttryckslösts": "uttryckslös",
    "uttrycksmedels": "uttrycksmedel",
    "uttrycksmedlen": "uttrycksmedel",
    "uttrycksmedlens": "uttrycksmedel",
    "uttrycksmedlet": "uttrycksmedel",
    "uttrycksmedlets": "uttrycksmedel",
    "uttrycksmässiga": "uttrycksmässig",
    "uttrycksmässigare": "uttrycksmässig",
    "uttrycksmässigares": "uttrycksmässig",
    "uttrycksmässigas": "uttrycksmässig",
    "uttrycksmässigast": "uttrycksmässig",
    "uttrycksmässigaste": "uttrycksmässig",
    "uttrycksmässigastes": "uttrycksmässig",
    "uttrycksmässigasts": "uttrycksmässig",
    "uttrycksmässige": "uttrycksmässig",
    "uttrycksmässiges": "uttrycksmässig",
    "uttrycksmässigs": "uttrycksmässig",
    "uttrycksmässigt": "uttrycksmässig",
    "uttrycksmässigts": "uttrycksmässig",
    "uttryckssätten": "uttryckssätt",
    "uttryckssättens": "uttryckssätt",
    "uttryckssättet": "uttryckssätt",
    "uttryckssättets": "uttryckssätt",
    "uttryckssätts": "uttryckssätt",
    "uttryckt": "uttrycka",
    "uttryckta": "uttrycka",
    "uttrycktas": "uttrycka",
    "uttryckte": "uttrycka",
    "uttrycktes": "uttrycka",
    "uttryckts": "uttrycka",
    "utträd": "utträda",
    "utträdande": "utträda",
    "utträdanden": "utträdande",
    "utträdandena": "utträdande",
    "utträdandenas": "utträdande",
    "utträdandens": "utträdande",
    "utträdandes": "utträdande",
    "utträdandet": "utträdande",
    "utträdandets": "utträdande",
    "utträdas": "utträda",
    "utträdd": "utträda",
    "utträdda": "utträda",
    "utträddas": "utträda",
    "utträdde": "utträda",
    "utträddes": "utträda",
    "utträdds": "utträda",
    "utträden": "utträde",
    "utträdena": "utträde",
    "utträdenas": "utträde",
    "utträdens": "utträde",
    "utträder": "utträda",
    "utträdes": "utträde",
    "utträdet": "utträde",
    "utträdets": "utträde",
    "utträds": "utträda",
    "utträtt": "utträda",
    "utträtts": "utträda",
    "uttråkade": "uttråkad",
    "uttråkades": "uttråkad",
    "uttråkads": "uttråkad",
    "uttråkat": "uttråkad",
    "uttråkats": "uttråkad",
    "uttrött": "uttrötta",
    "uttröttad": "uttrötta",
    "uttröttade": "uttröttad",
    "uttröttades": "uttröttad",
    "uttröttads": "uttröttad",
    "uttröttande": "uttrötta",
    "uttröttanden": "uttröttande",
    "uttröttandena": "uttröttande",
    "uttröttandenas": "uttröttande",
    "uttröttandens": "uttröttande",
    "uttröttandes": "uttröttande",
    "uttröttandet": "uttröttande",
    "uttröttandets": "uttröttande",
    "uttröttar": "uttrötta",
    "uttröttas": "uttrötta",
    "uttröttat": "uttröttad",
    "uttröttats": "uttröttad",
    "uttunn": "uttunna",
    "uttunnad": "uttunna",
    "uttunnade": "uttunnad",
    "uttunnades": "uttunnad",
    "uttunnads": "uttunnad",
    "uttunnande": "uttunna",
    "uttunnanden": "uttunnande",
    "uttunnandena": "uttunnande",
    "uttunnandenas": "uttunnande",
    "uttunnandens": "uttunnande",
    "uttunnandes": "uttunnande",
    "uttunnandet": "uttunnande",
    "uttunnandets": "uttunnande",
    "uttunnar": "uttunna",
    "uttunnas": "uttunna",
    "uttunnat": "uttunnad",
    "uttunnats": "uttunnad",
    "uttyd": "uttyda",
    "uttydande": "uttyda",
    "uttydanden": "uttydande",
    "uttydandena": "uttydande",
    "uttydandenas": "uttydande",
    "uttydandens": "uttydande",
    "uttydandes": "uttydande",
    "uttydandet": "uttydande",
    "uttydandets": "uttydande",
    "uttydas": "uttyda",
    "uttydd": "uttyda",
    "uttydda": "uttyda",
    "uttyddas": "uttyda",
    "uttydde": "uttyda",
    "uttyddes": "uttyda",
    "uttydds": "uttyda",
    "uttyder": "uttyda",
    "uttydes": "uttyda",
    "uttyds": "uttyda",
    "uttytt": "uttyda",
    "uttytts": "uttyda",
    "uttänj": "uttänja",
    "uttänjande": "uttänja",
    "uttänjanden": "uttänjande",
    "uttänjandena": "uttänjande",
    "uttänjandenas": "uttänjande",
    "uttänjandens": "uttänjande",
    "uttänjandes": "uttänjande",
    "uttänjandet": "uttänjande",
    "uttänjandets": "uttänjande",
    "uttänjas": "uttänja",
    "uttänjd": "uttänja",
    "uttänjda": "uttänjd",
    "uttänjdare": "uttänjd",
    "uttänjdares": "uttänjd",
    "uttänjdas": "uttänjd",
    "uttänjdast": "uttänjd",
    "uttänjdaste": "uttänjd",
    "uttänjdastes": "uttänjd",
    "uttänjdasts": "uttänjd",
    "uttänjde": "uttänjd",
    "uttänjdes": "uttänjd",
    "uttänjds": "uttänjd",
    "uttänjer": "uttänja",
    "uttänjes": "uttänja",
    "uttänjningar": "uttänjning",
    "uttänjningarna": "uttänjning",
    "uttänjningarnas": "uttänjning",
    "uttänjningars": "uttänjning",
    "uttänjningen": "uttänjning",
    "uttänjningens": "uttänjning",
    "uttänjnings": "uttänjning",
    "uttänjs": "uttänja",
    "uttänjt": "uttänjd",
    "uttänjts": "uttänjd",
    "uttänkta": "uttänkt",
    "uttänktare": "uttänkt",
    "uttänktares": "uttänkt",
    "uttänktas": "uttänkt",
    "uttänktast": "uttänkt",
    "uttänktaste": "uttänkt",
    "uttänktastes": "uttänkt",
    "uttänktasts": "uttänkt",
    "uttänkte": "uttänkt",
    "uttänktes": "uttänkt",
    "uttänktheten": "uttänkthet",
    "uttänkthetens": "uttänkthet",
    "uttänkthets": "uttänkthet",
    "uttänkts": "uttänkt",
    "uttågen": "uttåg",
    "uttågens": "uttåg",
    "uttåget": "uttåg",
    "uttågets": "uttåg",
    "uttågs": "uttåg",
    "uttöjda": "uttöjd",
    "uttöjdare": "uttöjd",
    "uttöjdares": "uttöjd",
    "uttöjdas": "uttöjd",
    "uttöjdast": "uttöjd",
    "uttöjdaste": "uttöjd",
    "uttöjdastes": "uttöjd",
    "uttöjdasts": "uttöjd",
    "uttöjde": "uttöjd",
    "uttöjdes": "uttöjd",
    "uttöjds": "uttöjd",
    "uttöjt": "uttöjd",
    "uttöjts": "uttöjd",
    "uttöm": "uttömma",
    "uttömd": "uttömma",
    "uttömda": "uttömma",
    "uttömdas": "uttömma",
    "uttömde": "uttömma",
    "uttömdes": "uttömma",
    "uttömds": "uttömma",
    "uttömmande": "uttömma",
    "uttömmanden": "uttömmande",
    "uttömmandena": "uttömmande",
    "uttömmandenas": "uttömmande",
    "uttömmandens": "uttömmande",
    "uttömmandes": "uttömmande",
    "uttömmandet": "uttömmande",
    "uttömmandets": "uttömmande",
    "uttömmas": "uttömma",
    "uttömmer": "uttömma",
    "uttöms": "uttömma",
    "uttömt": "uttömma",
    "uttömts": "uttömma",
    "utvakade": "utvakad",
    "utvakades": "utvakad",
    "utvakads": "utvakad",
    "utvakat": "utvakad",
    "utvakats": "utvakad",
    "utvald": "utvälja",
    "utvalda": "utvälja",
    "utvaldare": "utvald",
    "utvaldares": "utvald",
    "utvaldas": "utvälja",
    "utvaldast": "utvald",
    "utvaldaste": "utvald",
    "utvaldastes": "utvald",
    "utvaldasts": "utvald",
    "utvalde": "utvälja",
    "utvaldes": "utvälja",
    "utvaldheten": "utvaldhet",
    "utvaldhetens": "utvaldhet",
    "utvaldhets": "utvaldhet",
    "utvalds": "utvälja",
    "utvalt": "utvälja",
    "utvalts": "utvälja",
    "utvandrad": "utvandra",
    "utvandrade": "utvandra",
    "utvandrades": "utvandra",
    "utvandrads": "utvandra",
    "utvandrande": "utvandra",
    "utvandranden": "utvandrande",
    "utvandrandena": "utvandrande",
    "utvandrandenas": "utvandrande",
    "utvandrandens": "utvandrande",
    "utvandrandes": "utvandrande",
    "utvandrandet": "utvandrande",
    "utvandrandets": "utvandrande",
    "utvandrar": "utvandrare",
    "utvandraren": "utvandrare",
    "utvandrarens": "utvandrare",
    "utvandrares": "utvandrare",
    "utvandrarna": "utvandrare",
    "utvandrarnas": "utvandrare",
    "utvandras": "utvandra",
    "utvandrat": "utvandra",
    "utvandrats": "utvandra",
    "utvandringar": "utvandring",
    "utvandringarna": "utvandring",
    "utvandringarnas": "utvandring",
    "utvandringars": "utvandring",
    "utvandringen": "utvandring",
    "utvandringens": "utvandring",
    "utvandrings": "utvandring",
    "utvann": "utvinna",
    "utvanns": "utvinna",
    "utvecklad": "utveckla",
    "utvecklade": "utvecklad",
    "utvecklades": "utvecklas",
    "utvecklads": "utvecklad",
    "utvecklande": "utveckla",
    "utvecklanden": "utvecklande",
    "utvecklandena": "utvecklande",
    "utvecklandenas": "utvecklande",
    "utvecklandens": "utvecklande",
    "utvecklandes": "utvecklande",
    "utvecklandet": "utvecklande",
    "utvecklandets": "utvecklande",
    "utvecklar": "utveckla",
    "utvecklas": "utveckla",
    "utvecklat": "utvecklad",
    "utvecklats": "utvecklas",
    "utvecklingar": "utveckling",
    "utvecklingarna": "utveckling",
    "utvecklingarnas": "utveckling",
    "utvecklingars": "utveckling",
    "utvecklingen": "utveckling",
    "utvecklingens": "utveckling",
    "utvecklings": "utveckling",
    "utvecklingsarbeten": "utvecklingsarbete",
    "utvecklingsarbetena": "utvecklingsarbete",
    "utvecklingsarbetenas": "utvecklingsarbete",
    "utvecklingsarbetens": "utvecklingsarbete",
    "utvecklingsarbetes": "utvecklingsarbete",
    "utvecklingsarbetet": "utvecklingsarbete",
    "utvecklingsarbetets": "utvecklingsarbete",
    "utvecklingsarbets": "utvecklingsarbete",
    "utvecklingsgrenar": "utvecklingsgren",
    "utvecklingsgrenarna": "utvecklingsgren",
    "utvecklingsgrenarnas": "utvecklingsgren",
    "utvecklingsgrenars": "utvecklingsgren",
    "utvecklingsgrenen": "utvecklingsgren",
    "utvecklingsgrenens": "utvecklingsgren",
    "utvecklingsgrens": "utvecklingsgren",
    "utvecklingshistorian": "utvecklingshistoria",
    "utvecklingshistorians": "utvecklingshistoria",
    "utvecklingshistorias": "utvecklingshistoria",
    "utvecklingshistorien": "utvecklingshistoria",
    "utvecklingshistoriens": "utvecklingshistoria",
    "utvecklingshämmade": "utvecklingshämmad",
    "utvecklingshämmades": "utvecklingshämmad",
    "utvecklingshämmads": "utvecklingshämmad",
    "utvecklingshämmat": "utvecklingshämmad",
    "utvecklingshämmats": "utvecklingshämmad",
    "utvecklingslandet": "utvecklingsland",
    "utvecklingslandets": "utvecklingsland",
    "utvecklingslands": "utvecklingsland",
    "utvecklingsländer": "utvecklingsland",
    "utvecklingsländerna": "utvecklingsland",
    "utvecklingsländernas": "utvecklingsland",
    "utvecklingsländers": "utvecklingsland",
    "utvecklingsläran": "utvecklingslära",
    "utvecklingslärans": "utvecklingslära",
    "utvecklingsläras": "utvecklingslära",
    "utvecklingsmässiga": "utvecklingsmässig",
    "utvecklingsmässigare": "utvecklingsmässig",
    "utvecklingsmässigares": "utvecklingsmässig",
    "utvecklingsmässigas": "utvecklingsmässig",
    "utvecklingsmässigast": "utvecklingsmässig",
    "utvecklingsmässigaste": "utvecklingsmässig",
    "utvecklingsmässigastes": "utvecklingsmässig",
    "utvecklingsmässigasts": "utvecklingsmässig",
    "utvecklingsmässige": "utvecklingsmässig",
    "utvecklingsmässiges": "utvecklingsmässig",
    "utvecklingsmässigheten": "utvecklingsmässighet",
    "utvecklingsmässighetens": "utvecklingsmässighet",
    "utvecklingsmässighets": "utvecklingsmässighet",
    "utvecklingsmässigs": "utvecklingsmässig",
    "utvecklingsmässigt": "utvecklingsmässig",
    "utvecklingsmässigts": "utvecklingsmässig",
    "utvecklingsmöjligheten": "utvecklingsmöjlighet",
    "utvecklingsmöjlighetens": "utvecklingsmöjlighet",
    "utvecklingsmöjligheter": "utvecklingsmöjlighet",
    "utvecklingsmöjligheterna": "utvecklingsmöjlighet",
    "utvecklingsmöjligheternas": "utvecklingsmöjlighet",
    "utvecklingsmöjligheters": "utvecklingsmöjlighet",
    "utvecklingsmöjlighets": "utvecklingsmöjlighet",
    "utvecklingsplanen": "utvecklingsplan",
    "utvecklingsplanens": "utvecklingsplan",
    "utvecklingsplanet": "utvecklingsplan",
    "utvecklingsplanets": "utvecklingsplan",
    "utvecklingsplans": "utvecklingsplan",
    "utvecklingsprocessen": "utvecklingsprocess",
    "utvecklingsprocessens": "utvecklingsprocess",
    "utvecklingsprocesser": "utvecklingsprocess",
    "utvecklingsprocesserna": "utvecklingsprocess",
    "utvecklingsprocessernas": "utvecklingsprocess",
    "utvecklingsprocessers": "utvecklingsprocess",
    "utvecklingsrubbningar": "utvecklingsrubbning",
    "utvecklingsrubbningarna": "utvecklingsrubbning",
    "utvecklingsrubbningarnas": "utvecklingsrubbning",
    "utvecklingsrubbningars": "utvecklingsrubbning",
    "utvecklingsrubbningen": "utvecklingsrubbning",
    "utvecklingsrubbningens": "utvecklingsrubbning",
    "utvecklingsrubbnings": "utvecklingsrubbning",
    "utvecklingsserien": "utvecklingsserie",
    "utvecklingsseriens": "utvecklingsserie",
    "utvecklingsserier": "utvecklingsserie",
    "utvecklingsserierna": "utvecklingsserie",
    "utvecklingsseriernas": "utvecklingsserie",
    "utvecklingsseriers": "utvecklingsserie",
    "utvecklingsseries": "utvecklingsserie",
    "utvecklingsskeden": "utvecklingsskede",
    "utvecklingsskedena": "utvecklingsskede",
    "utvecklingsskedenas": "utvecklingsskede",
    "utvecklingsskedens": "utvecklingsskede",
    "utvecklingsskedes": "utvecklingsskede",
    "utvecklingsskedet": "utvecklingsskede",
    "utvecklingsskedets": "utvecklingsskede",
    "utvecklingssprången": "utvecklingssprång",
    "utvecklingssprångens": "utvecklingssprång",
    "utvecklingssprånget": "utvecklingssprång",
    "utvecklingssprångets": "utvecklingssprång",
    "utvecklingssprångs": "utvecklingssprång",
    "utvecklingsstadie": "utvecklingsstadium",
    "utvecklingsstadier": "utvecklingsstadium",
    "utvecklingsstadierna": "utvecklingsstadium",
    "utvecklingsstadiernas": "utvecklingsstadium",
    "utvecklingsstadiers": "utvecklingsstadium",
    "utvecklingsstadiet": "utvecklingsstadium",
    "utvecklingsstadiets": "utvecklingsstadium",
    "utvecklingsstadiums": "utvecklingsstadium",
    "utvecklingsstöden": "utvecklingsstöd",
    "utvecklingsstödens": "utvecklingsstöd",
    "utvecklingsstödet": "utvecklingsstöd",
    "utvecklingsstödets": "utvecklingsstöd",
    "utvecklingsstöds": "utvecklingsstöd",
    "utvecklingsstörda": "utvecklingsstörd",
    "utvecklingsstördare": "utvecklingsstörd",
    "utvecklingsstördares": "utvecklingsstörd",
    "utvecklingsstördas": "utvecklingsstörd",
    "utvecklingsstördast": "utvecklingsstörd",
    "utvecklingsstördaste": "utvecklingsstörd",
    "utvecklingsstördastes": "utvecklingsstörd",
    "utvecklingsstördasts": "utvecklingsstörd",
    "utvecklingsstörde": "utvecklingsstörd",
    "utvecklingsstördes": "utvecklingsstörd",
    "utvecklingsstörds": "utvecklingsstörd",
    "utvecklingsstörningar": "utvecklingsstörning",
    "utvecklingsstörningarna": "utvecklingsstörning",
    "utvecklingsstörningarnas": "utvecklingsstörning",
    "utvecklingsstörningars": "utvecklingsstörning",
    "utvecklingsstörningen": "utvecklingsstörning",
    "utvecklingsstörningens": "utvecklingsstörning",
    "utvecklingsstörnings": "utvecklingsstörning",
    "utvecklingsstört": "utvecklingsstörd",
    "utvecklingsstörts": "utvecklingsstörd",
    "utvecklingstrapp": "utvecklingstrappa",
    "utvecklingstrappan": "utvecklingstrappa",
    "utvecklingstrappans": "utvecklingstrappa",
    "utvecklingstrappas": "utvecklingstrappa",
    "utvecklingstrappe": "utvecklingstrappa",
    "utvecklingstrappor": "utvecklingstrappa",
    "utvecklingstrapporna": "utvecklingstrappa",
    "utvecklingstrappornas": "utvecklingstrappa",
    "utvecklingstrappors": "utvecklingstrappa",
    "utvecklingstrapps": "utvecklingstrappa",
    "utvecklingsträden": "utvecklingsträd",
    "utvecklingsträdens": "utvecklingsträd",
    "utvecklingsträdet": "utvecklingsträd",
    "utvecklingsträdets": "utvecklingsträd",
    "utvecklingsträds": "utvecklingsträd",
    "utverk": "utverka",
    "utverkad": "utverka",
    "utverkade": "utverka",
    "utverkades": "utverka",
    "utverkads": "utverka",
    "utverkande": "utverka",
    "utverkanden": "utverkande",
    "utverkandena": "utverkande",
    "utverkandenas": "utverkande",
    "utverkandens": "utverkande",
    "utverkandes": "utverkande",
    "utverkandet": "utverkande",
    "utverkandets": "utverkande",
    "utverkar": "utverka",
    "utverkas": "utverka",
    "utverkat": "utverka",
    "utverkats": "utverka",
    "utvidg": "utvidga",
    "utvidgad": "utvidga",
    "utvidgade": "utvidga",
    "utvidgades": "utvidga",
    "utvidgads": "utvidga",
    "utvidgande": "utvidga",
    "utvidganden": "utvidgande",
    "utvidgandena": "utvidgande",
    "utvidgandenas": "utvidgande",
    "utvidgandens": "utvidgande",
    "utvidgandes": "utvidgande",
    "utvidgandet": "utvidgande",
    "utvidgandets": "utvidgande",
    "utvidgar": "utvidga",
    "utvidgas": "utvidga",
    "utvidgat": "utvidga",
    "utvidgats": "utvidga",
    "utvidgningar": "utvidgning",
    "utvidgningarna": "utvidgning",
    "utvidgningarnas": "utvidgning",
    "utvidgningars": "utvidgning",
    "utvidgningen": "utvidgning",
    "utvidgningens": "utvidgning",
    "utvidgnings": "utvidgning",
    "utviken": "utvik",
    "utvikens": "utvik",
    "utviket": "utvik",
    "utvikets": "utvik",
    "utvikningar": "utvikning",
    "utvikningarna": "utvikning",
    "utvikningarnas": "utvikning",
    "utvikningars": "utvikning",
    "utvikningen": "utvikning",
    "utvikningens": "utvikning",
    "utviknings": "utvikning",
    "utvikningsbilden": "utvikningsbild",
    "utvikningsbildens": "utvikningsbild",
    "utvikningsbilder": "utvikningsbild",
    "utvikningsbilderna": "utvikningsbild",
    "utvikningsbildernas": "utvikningsbild",
    "utvikningsbilders": "utvikningsbild",
    "utvikningsbilds": "utvikningsbild",
    "utvikningsbrudar": "utvikningsbrud",
    "utvikningsbrudarna": "utvikningsbrud",
    "utvikningsbrudarnas": "utvikningsbrud",
    "utvikningsbrudars": "utvikningsbrud",
    "utvikningsbruden": "utvikningsbrud",
    "utvikningsbrudens": "utvikningsbrud",
    "utvikningsbruds": "utvikningsbrud",
    "utvikningspojk": "utvikningspojke",
    "utvikningspojkar": "utvikningspojke",
    "utvikningspojkarna": "utvikningspojke",
    "utvikningspojkarnas": "utvikningspojke",
    "utvikningspojkars": "utvikningspojke",
    "utvikningspojken": "utvikningspojke",
    "utvikningspojkens": "utvikningspojke",
    "utvikningspojkes": "utvikningspojke",
    "utvikningspojks": "utvikningspojke",
    "utviks": "utvik",
    "utviksbladen": "utviksblad",
    "utviksbladens": "utviksblad",
    "utviksbladet": "utviksblad",
    "utviksbladets": "utviksblad",
    "utviksblads": "utviksblad",
    "utvilade": "utvilad",
    "utvilades": "utvilad",
    "utvilads": "utvilad",
    "utvilat": "utvilad",
    "utvilats": "utvilad",
    "utvinn": "utvinna",
    "utvinnande": "utvinna",
    "utvinnanden": "utvinnande",
    "utvinnandena": "utvinnande",
    "utvinnandenas": "utvinnande",
    "utvinnandens": "utvinnande",
    "utvinnandes": "utvinnande",
    "utvinnandet": "utvinnande",
    "utvinnandets": "utvinnande",
    "utvinnas": "utvinna",
    "utvinne": "utvinna",
    "utvinner": "utvinna",
    "utvinnes": "utvinna",
    "utvinningar": "utvinning",
    "utvinningarna": "utvinning",
    "utvinningarnas": "utvinning",
    "utvinningars": "utvinning",
    "utvinningen": "utvinning",
    "utvinningens": "utvinning",
    "utvinnings": "utvinning",
    "utvinns": "utvinna",
    "utvis": "utvisa",
    "utvisad": "utvisa",
    "utvisade": "utvisa",
    "utvisades": "utvisa",
    "utvisads": "utvisa",
    "utvisande": "utvisa",
    "utvisanden": "utvisande",
    "utvisandena": "utvisande",
    "utvisandenas": "utvisande",
    "utvisandens": "utvisande",
    "utvisandes": "utvisande",
    "utvisandet": "utvisande",
    "utvisandets": "utvisande",
    "utvisar": "utvisa",
    "utvisas": "utvisa",
    "utvisat": "utvisa",
    "utvisats": "utvisa",
    "utvisningar": "utvisning",
    "utvisningarna": "utvisning",
    "utvisningarnas": "utvisning",
    "utvisningars": "utvisning",
    "utvisningen": "utvisning",
    "utvisningens": "utvisning",
    "utvisnings": "utvisning",
    "utvisningsbåsen": "utvisningsbås",
    "utvisningsbåsens": "utvisningsbås",
    "utvisningsbåset": "utvisningsbås",
    "utvisningsbåsets": "utvisningsbås",
    "utvunna": "utvinna",
    "utvunnas": "utvinna",
    "utvunne": "utvinna",
    "utvunnen": "utvinna",
    "utvunnens": "utvinna",
    "utvunnes": "utvinna",
    "utvunnet": "utvinna",
    "utvunnets": "utvinna",
    "utvunnit": "utvinna",
    "utvunnits": "utvinna",
    "utvägar": "utväg",
    "utvägarna": "utväg",
    "utvägarnas": "utväg",
    "utvägars": "utväg",
    "utvägen": "utväg",
    "utvägens": "utväg",
    "utvägs": "utväg",
    "utvälj": "utvälja",
    "utväljande": "utvälja",
    "utväljanden": "utväljande",
    "utväljandena": "utväljande",
    "utväljandenas": "utväljande",
    "utväljandens": "utväljande",
    "utväljandes": "utväljande",
    "utväljandet": "utväljande",
    "utväljandets": "utväljande",
    "utväljas": "utvälja",
    "utväljer": "utvälja",
    "utväljes": "utvälja",
    "utväljs": "utvälja",
    "utvändiga": "utvändig",
    "utvändigare": "utvändig",
    "utvändigares": "utvändig",
    "utvändigas": "utvändig",
    "utvändigast": "utvändig",
    "utvändigaste": "utvändig",
    "utvändigastes": "utvändig",
    "utvändigasts": "utvändig",
    "utvändige": "utvändig",
    "utvändiges": "utvändig",
    "utvändigheten": "utvändighet",
    "utvändighetens": "utvändighet",
    "utvändighets": "utvändighet",
    "utvändigs": "utvändig",
    "utvändigt": "utvändig",
    "utvändigts": "utvändig",
    "utvärderad": "utvärdera",
    "utvärderade": "utvärdera",
    "utvärderades": "utvärdera",
    "utvärderads": "utvärdera",
    "utvärderande": "utvärdera",
    "utvärderanden": "utvärderande",
    "utvärderandena": "utvärderande",
    "utvärderandenas": "utvärderande",
    "utvärderandens": "utvärderande",
    "utvärderandes": "utvärderande",
    "utvärderandet": "utvärderande",
    "utvärderandets": "utvärderande",
    "utvärderar": "utvärdera",
    "utvärderas": "utvärdera",
    "utvärderat": "utvärdera",
    "utvärderats": "utvärdera",
    "utvärderbara": "utvärderbar",
    "utvärderbarare": "utvärderbar",
    "utvärderbarares": "utvärderbar",
    "utvärderbaras": "utvärderbar",
    "utvärderbarast": "utvärderbar",
    "utvärderbaraste": "utvärderbar",
    "utvärderbarastes": "utvärderbar",
    "utvärderbarasts": "utvärderbar",
    "utvärderbare": "utvärderbar",
    "utvärderbares": "utvärderbar",
    "utvärderbarheten": "utvärderbarhet",
    "utvärderbarhetens": "utvärderbarhet",
    "utvärderbarhets": "utvärderbarhet",
    "utvärderbars": "utvärderbar",
    "utvärderbart": "utvärderbar",
    "utvärderbarts": "utvärderbar",
    "utvärderingar": "utvärdering",
    "utvärderingarna": "utvärdering",
    "utvärderingarnas": "utvärdering",
    "utvärderingars": "utvärdering",
    "utvärderingen": "utvärdering",
    "utvärderingens": "utvärdering",
    "utvärderings": "utvärdering",
    "utvärderingsenheten": "utvärderingsenhet",
    "utvärderingsenhetens": "utvärderingsenhet",
    "utvärderingsenheter": "utvärderingsenhet",
    "utvärderingsenheterna": "utvärderingsenhet",
    "utvärderingsenheternas": "utvärderingsenhet",
    "utvärderingsenheters": "utvärderingsenhet",
    "utvärderingsenhets": "utvärderingsenhet",
    "utvärdshusen": "utvärdshus",
    "utvärdshusens": "utvärdshus",
    "utvärdshuset": "utvärdshus",
    "utvärdshusets": "utvärdshus",
    "utväxlad": "utväxla",
    "utväxlade": "utväxla",
    "utväxlades": "utväxla",
    "utväxlads": "utväxla",
    "utväxlande": "utväxla",
    "utväxlanden": "utväxlande",
    "utväxlandena": "utväxlande",
    "utväxlandenas": "utväxlande",
    "utväxlandens": "utväxlande",
    "utväxlandes": "utväxlande",
    "utväxlandet": "utväxlande",
    "utväxlandets": "utväxlande",
    "utväxlar": "utväxla",
    "utväxlas": "utväxla",
    "utväxlat": "utväxla",
    "utväxlats": "utväxla",
    "utväxlingar": "utväxling",
    "utväxlingarna": "utväxling",
    "utväxlingarnas": "utväxling",
    "utväxlingars": "utväxling",
    "utväxlingen": "utväxling",
    "utväxlingens": "utväxling",
    "utväxlings": "utväxling",
    "utväxten": "utväxt",
    "utväxtens": "utväxt",
    "utväxter": "utväxt",
    "utväxterna": "utväxt",
    "utväxternas": "utväxt",
    "utväxters": "utväxt",
    "utväxts": "utväxt",
    "utägan": "utäga",
    "utägans": "utäga",
    "utägas": "utäga",
    "utäge": "utäga",
    "utägo": "utäga",
    "utägor": "utäga",
    "utägorna": "utäga",
    "utägornas": "utäga",
    "utägors": "utäga",
    "utåtriktade": "utåtriktad",
    "utåtriktades": "utåtriktad",
    "utåtriktads": "utåtriktad",
    "utåtriktat": "utåtriktad",
    "utåtriktats": "utåtriktad",
    "utåtvända": "utåtvänd",
    "utåtvändare": "utåtvänd",
    "utåtvändares": "utåtvänd",
    "utåtvändas": "utåtvänd",
    "utåtvändast": "utåtvänd",
    "utåtvändaste": "utåtvänd",
    "utåtvändastes": "utåtvänd",
    "utåtvändasts": "utåtvänd",
    "utåtvände": "utåtvänd",
    "utåtvändes": "utåtvänd",
    "utåtvändheten": "utåtvändhet",
    "utåtvändhetens": "utåtvändhet",
    "utåtvändhets": "utåtvändhet",
    "utåtvänds": "utåtvänd",
    "utåtvänt": "utåtvänd",
    "utåtvänts": "utåtvänd",
    "utök": "utöka",
    "utökad": "utöka",
    "utökade": "utöka",
    "utökades": "utöka",
    "utökads": "utöka",
    "utökande": "utöka",
    "utökanden": "utökande",
    "utökandena": "utökande",
    "utökandenas": "utökande",
    "utökandens": "utökande",
    "utökandes": "utökande",
    "utökandet": "utökande",
    "utökandets": "utökande",
    "utökar": "utöka",
    "utökas": "utöka",
    "utökat": "utöka",
    "utökats": "utöka",
    "utöv": "utöva",
    "utövad": "utöva",
    "utövade": "utöva",
    "utövades": "utöva",
    "utövads": "utöva",
    "utövande": "utöva",
    "utövanden": "utövande",
    "utövandena": "utövande",
    "utövandenas": "utövande",
    "utövandens": "utövande",
    "utövandes": "utövande",
    "utövandet": "utövande",
    "utövandets": "utövande",
    "utövar": "utövare",
    "utövaren": "utövare",
    "utövarens": "utövare",
    "utövares": "utövare",
    "utövarna": "utövare",
    "utövarnas": "utövare",
    "utövas": "utöva",
    "utövat": "utöva",
    "utövats": "utöva",
    "utövningen": "utövning",
    "utövningens": "utövning",
    "utövnings": "utövning",
    "uvar": "uv",
    "uvarna": "uv",
    "uvarnas": "uv",
    "uvars": "uv",
    "uven": "uv",
    "uvens": "uv",
    "uvertyren": "uvertyr",
    "uvertyrens": "uvertyr",
    "uvertyrer": "uvertyr",
    "uvertyrerna": "uvertyr",
    "uvertyrernas": "uvertyr",
    "uvertyrers": "uvertyr",
    "uvertyrs": "uvertyr",
    "uvs": "uv",
    "uvulara": "uvular",
    "uvularare": "uvular",
    "uvularares": "uvular",
    "uvularas": "uvular",
    "uvularast": "uvular",
    "uvularaste": "uvular",
    "uvularastes": "uvular",
    "uvularasts": "uvular",
    "uvulare": "uvular",
    "uvularen": "uvular",
    "uvularens": "uvular",
    "uvularer": "uvular",
    "uvularerna": "uvular",
    "uvularernas": "uvular",
    "uvularers": "uvular",
    "uvulares": "uvular",
    "uvulars": "uvular",
    "uvulart": "uvular",
    "uvularts": "uvular",
    "uzbeken": "uzbek",
    "uzbekens": "uzbek",
    "uzbeker": "uzbek",
    "uzbekerna": "uzbek",
    "uzbekernas": "uzbek",
    "uzbekers": "uzbek",
    "uzbekisk": "uzbekiska",
    "uzbekiska": "uzbekisk",
    "uzbekiskan": "uzbekiska",
    "uzbekiskans": "uzbekiska",
    "uzbekiskare": "uzbekisk",
    "uzbekiskares": "uzbekisk",
    "uzbekiskas": "uzbekiska",
    "uzbekiskast": "uzbekisk",
    "uzbekiskaste": "uzbekisk",
    "uzbekiskastes": "uzbekisk",
    "uzbekiskasts": "uzbekisk",
    "uzbekiske": "uzbekiska",
    "uzbekiskes": "uzbekisk",
    "uzbekiskor": "uzbekiska",
    "uzbekiskorna": "uzbekiska",
    "uzbekiskornas": "uzbekiska",
    "uzbekiskors": "uzbekiska",
    "uzbekisks": "uzbekisk",
    "uzbekiskt": "uzbekisk",
    "uzbekiskts": "uzbekisk",
    "uzbeks": "uzbek",
    "v-et": "v",
    "v-ets": "v",
    "v-n": "v",
    "v-na": "v",
    "v-nas": "v",
    "v-ns": "v",
    "v-s": "v",
    "v-t": "v",
    "v-ts": "v",
    "v:et": "v",
    "v:ets": "v",
    "v:n": "v",
    "v:na": "v",
    "v:nas": "v",
    "v:ns": "v",
    "v:s": "v",
    "v:t": "v",
    "v:ts": "v",
    "vab-dagar": "vab-dag",
    "vab-dagars": "vab-dag",
    "vab-dags": "vab-dag",
    "vabarna": "vab",
    "vabars": "vab",
    "vabb": "vabba",
    "vabb-dagar": "vabb-dag",
    "vabb-dagarna": "vabb-dag",
    "vabb-dagarnas": "vabb-dag",
    "vabb-dagars": "vabb-dag",
    "vabb-dagen": "vabb-dag",
    "vabb-dagens": "vabb-dag",
    "vabb-dags": "vabb-dag",
    "vabbad": "vabba",
    "vabbade": "vabba",
    "vabbades": "vabba",
    "vabbads": "vabba",
    "vabbande": "vabba",
    "vabbanden": "vabbande",
    "vabbandena": "vabbande",
    "vabbandenas": "vabbande",
    "vabbandens": "vabbande",
    "vabbandes": "vabbande",
    "vabbandet": "vabbande",
    "vabbandets": "vabbande",
    "vabbar": "vabbare",
    "vabbaren": "vabbare",
    "vabbarens": "vabbare",
    "vabbares": "vabbare",
    "vabbarna": "vabbare",
    "vabbarnas": "vabbare",
    "vabbars": "vabb",
    "vabbas": "vabba",
    "vabbat": "vabba",
    "vabbats": "vabba",
    "vabbdagar": "vabbdag",
    "vabbdagarna": "vabbdag",
    "vabbdagarnas": "vabbdag",
    "vabbdagars": "vabbdag",
    "vabbdagen": "vabbdag",
    "vabbdagens": "vabbdag",
    "vabbdags": "vabbdag",
    "vabbens": "vabb",
    "vabbets": "vabb",
    "vabdagar": "vabdag",
    "vabdagarna": "vabdag",
    "vabdagarnas": "vabdag",
    "vabdagars": "vabdag",
    "vabdagen": "vabdag",
    "vabdagens": "vabdag",
    "vabdags": "vabdag",
    "vaben": "vab",
    "vabet": "vab",
    "vabs": "vab",
    "vaccinationen": "vaccination",
    "vaccinationens": "vaccination",
    "vaccinationer": "vaccination",
    "vaccinationerna": "vaccination",
    "vaccinationernas": "vaccination",
    "vaccinationers": "vaccination",
    "vaccinations": "vaccination",
    "vaccinationsköer": "vaccinationskö",
    "vaccinationsköerna": "vaccinationskö",
    "vaccinationsköernas": "vaccinationskö",
    "vaccinationsköers": "vaccinationskö",
    "vaccinationskön": "vaccinationskö",
    "vaccinationsköns": "vaccinationskö",
    "vaccinationskös": "vaccinationskö",
    "vaccinationstvånget": "vaccinationstvång",
    "vaccinationstvångets": "vaccinationstvång",
    "vaccinationstvångs": "vaccinationstvång",
    "vaccinatören": "vaccinatör",
    "vaccinatörens": "vaccinatör",
    "vaccinatörer": "vaccinatör",
    "vaccinatörerna": "vaccinatör",
    "vaccinatörernas": "vaccinatör",
    "vaccinatörers": "vaccinatör",
    "vaccinatörs": "vaccinatör",
    "vaccinbristen": "vaccinbrist",
    "vaccinbristens": "vaccinbrist",
    "vaccinbrists": "vaccinbrist",
    "vaccinen": "vaccin",
    "vaccinens": "vaccin",
    "vacciner": "vaccin",
    "vaccinerad": "vaccinera",
    "vaccinerade": "vaccinera",
    "vaccinerades": "vaccinera",
    "vaccinerads": "vaccinera",
    "vaccinerande": "vaccinera",
    "vaccineranden": "vaccinerande",
    "vaccinerandena": "vaccinerande",
    "vaccinerandenas": "vaccinerande",
    "vaccinerandens": "vaccinerande",
    "vaccinerandes": "vaccinerande",
    "vaccinerandet": "vaccinerande",
    "vaccinerandets": "vaccinerande",
    "vaccinerar": "vaccinera",
    "vaccineras": "vaccinera",
    "vaccinerat": "vaccinera",
    "vaccinerats": "vaccinera",
    "vaccinerbara": "vaccinerbar",
    "vaccinerbarare": "vaccinerbar",
    "vaccinerbarares": "vaccinerbar",
    "vaccinerbaras": "vaccinerbar",
    "vaccinerbarast": "vaccinerbar",
    "vaccinerbaraste": "vaccinerbar",
    "vaccinerbarastes": "vaccinerbar",
    "vaccinerbarasts": "vaccinerbar",
    "vaccinerbare": "vaccinerbar",
    "vaccinerbares": "vaccinerbar",
    "vaccinerbarheten": "vaccinerbarhet",
    "vaccinerbarhetens": "vaccinerbarhet",
    "vaccinerbarhets": "vaccinerbarhet",
    "vaccinerbars": "vaccinerbar",
    "vaccinerbart": "vaccinerbar",
    "vaccinerbarts": "vaccinerbar",
    "vaccineringar": "vaccinering",
    "vaccineringarna": "vaccinering",
    "vaccineringarnas": "vaccinering",
    "vaccineringars": "vaccinering",
    "vaccineringen": "vaccinering",
    "vaccineringens": "vaccinering",
    "vaccinerings": "vaccinering",
    "vaccineringshysterien": "vaccineringshysteri",
    "vaccineringshysteriens": "vaccineringshysteri",
    "vaccineringshysterin": "vaccineringshysteri",
    "vaccineringshysterins": "vaccineringshysteri",
    "vaccineringshysteris": "vaccineringshysteri",
    "vaccineringsturbulensen": "vaccineringsturbulens",
    "vaccineringsturbulensens": "vaccineringsturbulens",
    "vaccinerna": "vaccin",
    "vaccinernas": "vaccin",
    "vacciners": "vaccin",
    "vaccinet": "vaccin",
    "vaccinets": "vaccin",
    "vaccins": "vaccin",
    "vackerheten": "vackerhet",
    "vackerhetens": "vackerhet",
    "vackerhets": "vackerhet",
    "vackers": "vacker",
    "vackert": "vacker",
    "vackerts": "vacker",
    "vacklade": "vackla",
    "vacklades": "vackla",
    "vacklande": "vackla",
    "vacklanden": "vacklande",
    "vacklandena": "vacklande",
    "vacklandenas": "vacklande",
    "vacklandens": "vacklande",
    "vacklandes": "vacklande",
    "vacklandet": "vacklande",
    "vacklandets": "vacklande",
    "vacklans": "vacklan",
    "vacklar": "vackla",
    "vacklas": "vackla",
    "vacklat": "vackla",
    "vacklats": "vackla",
    "vackra": "vacker",
    "vackrare": "vacker",
    "vackrares": "vacker",
    "vackras": "vacker",
    "vackrast": "vacker",
    "vackraste": "vacker",
    "vackrastes": "vacker",
    "vackrasts": "vacker",
    "vackre": "vacker",
    "vackres": "vacker",
    "vacuumbromsar": "vacuumbroms",
    "vacuumbromsarna": "vacuumbroms",
    "vacuumbromsarnas": "vacuumbroms",
    "vacuumbromsars": "vacuumbroms",
    "vacuumbromsen": "vacuumbroms",
    "vacuumbromsens": "vacuumbroms",
    "vacuumen": "vacuum",
    "vacuumens": "vacuum",
    "vacuumet": "vacuum",
    "vacuumets": "vacuum",
    "vacuumförpackningar": "vacuumförpackning",
    "vacuumförpackningarna": "vacuumförpackning",
    "vacuumförpackningarnas": "vacuumförpackning",
    "vacuumförpackningars": "vacuumförpackning",
    "vacuumförpackningen": "vacuumförpackning",
    "vacuumförpackningens": "vacuumförpackning",
    "vacuumförpacknings": "vacuumförpackning",
    "vacuumkammar": "vacuumkammare",
    "vacuumkammaren": "vacuumkammare",
    "vacuumkammarens": "vacuumkammare",
    "vacuumkammares": "vacuumkammare",
    "vacuumkamrar": "vacuumkammare",
    "vacuumkamrarna": "vacuumkammare",
    "vacuumkamrarnas": "vacuumkammare",
    "vacuumkamrars": "vacuumkammare",
    "vacuumklock": "vacuumklocka",
    "vacuumklockan": "vacuumklocka",
    "vacuumklockans": "vacuumklocka",
    "vacuumklockas": "vacuumklocka",
    "vacuumklocke": "vacuumklocka",
    "vacuumklockor": "vacuumklocka",
    "vacuumklockorna": "vacuumklocka",
    "vacuumklockornas": "vacuumklocka",
    "vacuumklockors": "vacuumklocka",
    "vacuumklocks": "vacuumklocka",
    "vacuumlamp": "vacuumlampa",
    "vacuumlampan": "vacuumlampa",
    "vacuumlampans": "vacuumlampa",
    "vacuumlampas": "vacuumlampa",
    "vacuumlampe": "vacuumlampa",
    "vacuumlampor": "vacuumlampa",
    "vacuumlamporna": "vacuumlampa",
    "vacuumlampornas": "vacuumlampa",
    "vacuumlampors": "vacuumlampa",
    "vacuumlamps": "vacuumlampa",
    "vacuummaterian": "vacuummateria",
    "vacuummaterians": "vacuummateria",
    "vacuummaterias": "vacuummateria",
    "vacuummaterier": "vacuummateria",
    "vacuummaterierna": "vacuummateria",
    "vacuummateriernas": "vacuummateria",
    "vacuummateriers": "vacuummateria",
    "vacuummetern": "vacuummeter",
    "vacuummeterns": "vacuummeter",
    "vacuummeters": "vacuummeter",
    "vacuummetrar": "vacuummeter",
    "vacuummetrarna": "vacuummeter",
    "vacuummetrarnas": "vacuummeter",
    "vacuummetrars": "vacuummeter",
    "vacuumpumpar": "vacuumpump",
    "vacuumpumparna": "vacuumpump",
    "vacuumpumparnas": "vacuumpump",
    "vacuumpumpars": "vacuumpump",
    "vacuumpumpen": "vacuumpump",
    "vacuumpumpens": "vacuumpump",
    "vacuumpumps": "vacuumpump",
    "vacuumregulatorer": "vacuumregulator",
    "vacuumregulatorerna": "vacuumregulator",
    "vacuumregulatorernas": "vacuumregulator",
    "vacuumregulatorers": "vacuumregulator",
    "vacuumregulatorn": "vacuumregulator",
    "vacuumregulatorns": "vacuumregulator",
    "vacuumregulators": "vacuumregulator",
    "vacuums": "vacuum",
    "vacuumsugar": "vacuumsug",
    "vacuumsugarna": "vacuumsug",
    "vacuumsugarnas": "vacuumsug",
    "vacuumsugars": "vacuumsug",
    "vacuumsugen": "vacuumsug",
    "vacuumsugens": "vacuumsug",
    "vacuumsugs": "vacuumsug",
    "vacuumtoaletten": "vacuumtoalett",
    "vacuumtoalettens": "vacuumtoalett",
    "vacuumtoaletter": "vacuumtoalett",
    "vacuumtoaletterna": "vacuumtoalett",
    "vacuumtoaletternas": "vacuumtoalett",
    "vacuumtoaletters": "vacuumtoalett",
    "vacuumtoaletts": "vacuumtoalett",
    "vacuumtorkningar": "vacuumtorkning",
    "vacuumtorkningarna": "vacuumtorkning",
    "vacuumtorkningarnas": "vacuumtorkning",
    "vacuumtorkningars": "vacuumtorkning",
    "vacuumtorkningen": "vacuumtorkning",
    "vacuumtorkningens": "vacuumtorkning",
    "vacuumtorknings": "vacuumtorkning",
    "vad": "vada",
    "vadad": "vada",
    "vadade": "vada",
    "vadades": "vada",
    "vadads": "vada",
    "vadande": "vada",
    "vadanden": "vadande",
    "vadandena": "vadande",
    "vadandenas": "vadande",
    "vadandens": "vadande",
    "vadandes": "vadande",
    "vadandet": "vadande",
    "vadandets": "vadande",
    "vadar": "vadare",
    "vadaren": "vadare",
    "vadarens": "vadare",
    "vadares": "vadare",
    "vadarfågeln": "vadarfågel",
    "vadarfågelns": "vadarfågel",
    "vadarfågels": "vadarfågel",
    "vadarfåglar": "vadarfågel",
    "vadarfåglarna": "vadarfågel",
    "vadarfåglarnas": "vadarfågel",
    "vadarfåglars": "vadarfågel",
    "vadarna": "vadare",
    "vadarnas": "vadare",
    "vadars": "vad",
    "vadas": "vada",
    "vadat": "vada",
    "vadats": "vada",
    "vadbara": "vadbar",
    "vadbarare": "vadbar",
    "vadbarares": "vadbar",
    "vadbaras": "vadbar",
    "vadbarast": "vadbar",
    "vadbaraste": "vadbar",
    "vadbarastes": "vadbar",
    "vadbarasts": "vadbar",
    "vadbare": "vadbar",
    "vadbares": "vadbar",
    "vadbarheten": "vadbarhet",
    "vadbarhetens": "vadbarhet",
    "vadbarhets": "vadbarhet",
    "vadbars": "vadbar",
    "vadbart": "vadbar",
    "vadbarts": "vadbar",
    "vaddar": "vadd",
    "vaddarna": "vadd",
    "vaddarnas": "vadd",
    "vaddars": "vadd",
    "vadden": "vadd",
    "vaddens": "vadd",
    "vadderad": "vaddera",
    "vadderade": "vaddera",
    "vadderades": "vaddera",
    "vadderads": "vaddera",
    "vadderande": "vaddera",
    "vadderanden": "vadderande",
    "vadderandena": "vadderande",
    "vadderandenas": "vadderande",
    "vadderandens": "vadderande",
    "vadderandes": "vadderande",
    "vadderandet": "vadderande",
    "vadderandets": "vadderande",
    "vadderar": "vaddera",
    "vadderas": "vaddera",
    "vadderat": "vaddera",
    "vadderats": "vaddera",
    "vadderbara": "vadderbar",
    "vadderbarare": "vadderbar",
    "vadderbarares": "vadderbar",
    "vadderbaras": "vadderbar",
    "vadderbarast": "vadderbar",
    "vadderbaraste": "vadderbar",
    "vadderbarastes": "vadderbar",
    "vadderbarasts": "vadderbar",
    "vadderbare": "vadderbar",
    "vadderbares": "vadderbar",
    "vadderbarheten": "vadderbarhet",
    "vadderbarhetens": "vadderbarhet",
    "vadderbarhets": "vadderbarhet",
    "vadderbars": "vadderbar",
    "vadderbart": "vadderbar",
    "vadderbarts": "vadderbar",
    "vadderingar": "vaddering",
    "vadderingarna": "vaddering",
    "vadderingarnas": "vaddering",
    "vadderingars": "vaddering",
    "vadderingen": "vaddering",
    "vadderingens": "vaddering",
    "vadderings": "vaddering",
    "vadds": "vadd",
    "vadeinlag": "vadeinlaga",
    "vadeinlagan": "vadeinlaga",
    "vadeinlagans": "vadeinlaga",
    "vadeinlagas": "vadeinlaga",
    "vadeinlage": "vadeinlaga",
    "vadeinlagor": "vadeinlaga",
    "vadeinlagorna": "vadeinlaga",
    "vadeinlagornas": "vadeinlaga",
    "vadeinlagors": "vadeinlaga",
    "vadeinlags": "vadeinlaga",
    "vademecumen": "vademecum",
    "vademecumens": "vademecum",
    "vademecumet": "vademecum",
    "vademecumets": "vademecum",
    "vademecums": "vademecum",
    "vaden": "vad",
    "vadens": "vad",
    "vader": "vad",
    "vaderna": "vad",
    "vadernas": "vad",
    "vaders": "vad",
    "vadet": "vad",
    "vadets": "vad",
    "vadfoten": "vadfot",
    "vadfotens": "vadfot",
    "vadfots": "vadfot",
    "vadfötter": "vadfot",
    "vadfötterna": "vadfot",
    "vadfötternas": "vadfot",
    "vadfötters": "vadfot",
    "vadhelsts": "vadhelst",
    "vadhållar": "vadhållare",
    "vadhållaren": "vadhållare",
    "vadhållarens": "vadhållare",
    "vadhållares": "vadhållare",
    "vadhållarna": "vadhållare",
    "vadhållarnas": "vadhållare",
    "vadhållningar": "vadhållning",
    "vadhållningarna": "vadhållning",
    "vadhållningarnas": "vadhållning",
    "vadhållningars": "vadhållning",
    "vadhållningen": "vadhållning",
    "vadhållningens": "vadhållning",
    "vadhållnings": "vadhållning",
    "vadlånga": "vadlång",
    "vadlångare": "vadlång",
    "vadlångares": "vadlång",
    "vadlångas": "vadlång",
    "vadlångast": "vadlång",
    "vadlångaste": "vadlång",
    "vadlångastes": "vadlång",
    "vadlångasts": "vadlång",
    "vadlånge": "vadlång",
    "vadlånges": "vadlång",
    "vadlångs": "vadlång",
    "vadlångt": "vadlång",
    "vadlångts": "vadlång",
    "vadmalen": "vadmal",
    "vadmalens": "vadmal",
    "vadmalet": "vadmal",
    "vadmalets": "vadmal",
    "vadmals": "vadmal",
    "vador": "vad",
    "vadorna": "vad",
    "vadornas": "vad",
    "vadors": "vad",
    "vadosa": "vados",
    "vadosare": "vados",
    "vadosares": "vados",
    "vadosas": "vados",
    "vadosast": "vados",
    "vadosaste": "vados",
    "vadosastes": "vados",
    "vadosasts": "vados",
    "vadose": "vados",
    "vadoses": "vados",
    "vadost": "vados",
    "vadosts": "vados",
    "vads": "vad",
    "vadslagningar": "vadslagning",
    "vadslagningarna": "vadslagning",
    "vadslagningarnas": "vadslagning",
    "vadslagningars": "vadslagning",
    "vadslagningen": "vadslagning",
    "vadslagningens": "vadslagning",
    "vadslagnings": "vadslagning",
    "vaga": "vag",
    "vagabonden": "vagabond",
    "vagabondens": "vagabond",
    "vagabonder": "vagabond",
    "vagabonderade": "vagabondera",
    "vagabonderades": "vagabondera",
    "vagabonderande": "vagabondera",
    "vagabonderanden": "vagabonderande",
    "vagabonderandena": "vagabonderande",
    "vagabonderandenas": "vagabonderande",
    "vagabonderandens": "vagabonderande",
    "vagabonderandes": "vagabonderande",
    "vagabonderandet": "vagabonderande",
    "vagabonderandets": "vagabonderande",
    "vagabonderar": "vagabondera",
    "vagabonderas": "vagabondera",
    "vagabonderat": "vagabondera",
    "vagabonderats": "vagabondera",
    "vagabonderingar": "vagabondering",
    "vagabonderingarna": "vagabondering",
    "vagabonderingarnas": "vagabondering",
    "vagabonderingars": "vagabondering",
    "vagabonderingen": "vagabondering",
    "vagabonderingens": "vagabondering",
    "vagabonderings": "vagabondering",
    "vagabonderna": "vagabond",
    "vagabondernas": "vagabond",
    "vagabonders": "vagabond",
    "vagabondlivet": "vagabondliv",
    "vagabondlivets": "vagabondliv",
    "vagabondlivs": "vagabondliv",
    "vagabondnaturen": "vagabondnatur",
    "vagabondnaturens": "vagabondnatur",
    "vagabondnaturer": "vagabondnatur",
    "vagabondnaturerna": "vagabondnatur",
    "vagabondnaturernas": "vagabondnatur",
    "vagabondnaturers": "vagabondnatur",
    "vagabondnaturs": "vagabondnatur",
    "vagabonds": "vagabond",
    "vaganten": "vagant",
    "vagantens": "vagant",
    "vaganter": "vagant",
    "vaganterna": "vagant",
    "vaganternas": "vagant",
    "vaganters": "vagant",
    "vagants": "vagant",
    "vagare": "vag",
    "vagares": "vag",
    "vagas": "vag",
    "vagast": "vag",
    "vagaste": "vag",
    "vagastes": "vag",
    "vagasts": "vag",
    "vage": "vag",
    "vageln": "vagel",
    "vagelns": "vagel",
    "vagels": "vagel",
    "vages": "vag",
    "vagg": "vagga",
    "vaggad": "vagga",
    "vaggade": "vagga",
    "vaggades": "vagga",
    "vaggads": "vagga",
    "vaggan": "vagga",
    "vaggande": "vagga",
    "vagganden": "vaggande",
    "vaggandena": "vaggande",
    "vaggandenas": "vaggande",
    "vaggandens": "vaggande",
    "vaggandes": "vaggande",
    "vaggandet": "vaggande",
    "vaggandets": "vaggande",
    "vaggans": "vagga",
    "vaggar": "vagga",
    "vaggas": "vagga",
    "vaggat": "vagga",
    "vaggats": "vagga",
    "vagge": "vagga",
    "vaggor": "vagga",
    "vaggorna": "vagga",
    "vaggornas": "vagga",
    "vaggors": "vagga",
    "vaggs": "vagga",
    "vaggsången": "vaggsång",
    "vaggsångens": "vaggsång",
    "vaggsånger": "vaggsång",
    "vaggsångerna": "vaggsång",
    "vaggsångernas": "vaggsång",
    "vaggsångers": "vaggsång",
    "vaggsångs": "vaggsång",
    "vaggtrycken": "vaggtryck",
    "vaggtryckens": "vaggtryck",
    "vaggtrycket": "vaggtryck",
    "vaggtryckets": "vaggtryck",
    "vaggtrycks": "vaggtryck",
    "vaggvis": "vaggvisa",
    "vaggvisan": "vaggvisa",
    "vaggvisans": "vaggvisa",
    "vaggvisas": "vaggvisa",
    "vaggvise": "vaggvisa",
    "vaggvisor": "vaggvisa",
    "vaggvisorna": "vaggvisa",
    "vaggvisornas": "vaggvisa",
    "vaggvisors": "vaggvisa",
    "vagheten": "vaghet",
    "vaghetens": "vaghet",
    "vaghets": "vaghet",
    "vagin": "vagina",
    "vaginala": "vaginal",
    "vaginalare": "vaginal",
    "vaginalares": "vaginal",
    "vaginalas": "vaginal",
    "vaginalast": "vaginal",
    "vaginalaste": "vaginal",
    "vaginalastes": "vaginal",
    "vaginalasts": "vaginal",
    "vaginale": "vaginal",
    "vaginales": "vaginal",
    "vaginals": "vaginal",
    "vaginalt": "vaginal",
    "vaginalts": "vaginal",
    "vaginan": "vagina",
    "vaginans": "vagina",
    "vaginas": "vagina",
    "vagine": "vagina",
    "vaginismen": "vaginism",
    "vaginismens": "vaginism",
    "vaginismer": "vaginism",
    "vaginismerna": "vaginism",
    "vaginismernas": "vaginism",
    "vaginismers": "vaginism",
    "vaginisms": "vaginism",
    "vaginor": "vagina",
    "vaginorna": "vagina",
    "vaginornas": "vagina",
    "vaginors": "vagina",
    "vagins": "vagina",
    "vaglar": "vagel",
    "vaglarna": "vagel",
    "vaglarnas": "vagel",
    "vaglars": "vagel",
    "vagnar": "vagn",
    "vagnarna": "vagn",
    "vagnarnas": "vagn",
    "vagnars": "vagn",
    "vagnbjörnar": "vagnbjörn",
    "vagnbjörnarna": "vagnbjörn",
    "vagnbjörnarnas": "vagnbjörn",
    "vagnbjörnars": "vagnbjörn",
    "vagnbjörnen": "vagnbjörn",
    "vagnbjörnens": "vagnbjörn",
    "vagnbjörns": "vagnbjörn",
    "vagnborgar": "vagnborg",
    "vagnborgarna": "vagnborg",
    "vagnborgarnas": "vagnborg",
    "vagnborgars": "vagnborg",
    "vagnborgen": "vagnborg",
    "vagnborgens": "vagnborg",
    "vagnborgs": "vagnborg",
    "vagnen": "vagn",
    "vagnens": "vagn",
    "vagnhallar": "vagnhall",
    "vagnhallarna": "vagnhall",
    "vagnhallarnas": "vagnhall",
    "vagnhallars": "vagnhall",
    "vagnhallen": "vagnhall",
    "vagnhallens": "vagnhall",
    "vagnhalls": "vagnhall",
    "vagnparken": "vagnpark",
    "vagnparkens": "vagnpark",
    "vagnparker": "vagnpark",
    "vagnparkerna": "vagnpark",
    "vagnparkernas": "vagnpark",
    "vagnparkers": "vagnpark",
    "vagnparks": "vagnpark",
    "vagns": "vagn",
    "vagnsdörrar": "vagnsdörr",
    "vagnsdörrarna": "vagnsdörr",
    "vagnsdörrarnas": "vagnsdörr",
    "vagnsdörrars": "vagnsdörr",
    "vagnsdörren": "vagnsdörr",
    "vagnsdörrens": "vagnsdörr",
    "vagnsdörrs": "vagnsdörr",
    "vagnshäckar": "vagnshäck",
    "vagnshäckarna": "vagnshäck",
    "vagnshäckarnas": "vagnshäck",
    "vagnshäckars": "vagnshäck",
    "vagnshäcken": "vagnshäck",
    "vagnshäckens": "vagnshäck",
    "vagnshäcks": "vagnshäck",
    "vagnskadeförsäkringar": "vagnskadeförsäkring",
    "vagnskadeförsäkringarna": "vagnskadeförsäkring",
    "vagnskadeförsäkringarnas": "vagnskadeförsäkring",
    "vagnskadeförsäkringars": "vagnskadeförsäkring",
    "vagnskadeförsäkringen": "vagnskadeförsäkring",
    "vagnskadeförsäkringens": "vagnskadeförsäkring",
    "vagnskadeförsäkrings": "vagnskadeförsäkring",
    "vagnskorgar": "vagnskorg",
    "vagnskorgarna": "vagnskorg",
    "vagnskorgarnas": "vagnskorg",
    "vagnskorgars": "vagnskorg",
    "vagnskorgen": "vagnskorg",
    "vagnskorgens": "vagnskorg",
    "vagnskorgs": "vagnskorg",
    "vagnslasten": "vagnslast",
    "vagnslastens": "vagnslast",
    "vagnslaster": "vagnslast",
    "vagnslasterna": "vagnslast",
    "vagnslasternas": "vagnslast",
    "vagnslasters": "vagnslast",
    "vagnslasts": "vagnslast",
    "vagnsliders": "vagnslider",
    "vagnslidren": "vagnslider",
    "vagnslidrens": "vagnslider",
    "vagnslidret": "vagnslider",
    "vagnslidrets": "vagnslider",
    "vagnsätten": "vagnsätt",
    "vagnsättens": "vagnsätt",
    "vagnsättet": "vagnsätt",
    "vagnsättets": "vagnsätt",
    "vagnsätts": "vagnsätt",
    "vagongen": "vagong",
    "vagongens": "vagong",
    "vagonger": "vagong",
    "vagongerna": "vagong",
    "vagongernas": "vagong",
    "vagongers": "vagong",
    "vagongs": "vagong",
    "vags": "vag",
    "vagt": "vag",
    "vagts": "vag",
    "vaj": "vaja",
    "vajad": "vaja",
    "vajade": "vaja",
    "vajades": "vaja",
    "vajads": "vaja",
    "vajan": "vaja",
    "vajande": "vaja",
    "vajanden": "vajande",
    "vajandena": "vajande",
    "vajandenas": "vajande",
    "vajandens": "vajande",
    "vajandes": "vajande",
    "vajandet": "vajande",
    "vajandets": "vajande",
    "vajans": "vaja",
    "vajar": "vaja",
    "vajas": "vaja",
    "vajat": "vaja",
    "vajats": "vaja",
    "vaje": "vaja",
    "vajern": "vajer",
    "vajerns": "vajer",
    "vajers": "vajer",
    "vajor": "vaja",
    "vajorna": "vaja",
    "vajornas": "vaja",
    "vajors": "vaja",
    "vajrar": "vajer",
    "vajrarna": "vajer",
    "vajrarnas": "vajer",
    "vajrars": "vajer",
    "vajs": "vaja",
    "vak": "vaka",
    "vakad": "vaka",
    "vakade": "vaka",
    "vakades": "vaka",
    "vakads": "vaka",
    "vakan": "vaka",
    "vakande": "vaka",
    "vakanden": "vakande",
    "vakandena": "vakande",
    "vakandenas": "vakande",
    "vakandens": "vakande",
    "vakandes": "vakande",
    "vakandet": "vakande",
    "vakandets": "vakande",
    "vakans": "vaka",
    "vakansen": "vakans",
    "vakansens": "vakans",
    "vakanser": "vakans",
    "vakanserna": "vakans",
    "vakansernas": "vakans",
    "vakansers": "vakans",
    "vakansförordnanden": "vakansförordnande",
    "vakansförordnandena": "vakansförordnande",
    "vakansförordnandenas": "vakansförordnande",
    "vakansförordnandens": "vakansförordnande",
    "vakansförordnandes": "vakansförordnande",
    "vakansförordnandet": "vakansförordnande",
    "vakansförordnandets": "vakansförordnande",
    "vakanssatt": "vakanssätta",
    "vakanssatta": "vakanssätta",
    "vakanssattas": "vakanssätta",
    "vakanssatte": "vakanssätta",
    "vakanssattes": "vakanssätta",
    "vakanssatts": "vakanssätta",
    "vakanssätt": "vakanssätta",
    "vakanssättande": "vakanssätta",
    "vakanssättanden": "vakanssättande",
    "vakanssättandena": "vakanssättande",
    "vakanssättandenas": "vakanssättande",
    "vakanssättandens": "vakanssättande",
    "vakanssättandes": "vakanssättande",
    "vakanssättandet": "vakanssättande",
    "vakanssättandets": "vakanssättande",
    "vakanssättas": "vakanssätta",
    "vakanssätter": "vakanssätta",
    "vakanssättes": "vakanssätta",
    "vakanssätts": "vakanssätta",
    "vakansvikarien": "vakansvikarie",
    "vakansvikariens": "vakansvikarie",
    "vakansvikarier": "vakansvikarie",
    "vakansvikarierna": "vakansvikarie",
    "vakansvikariernas": "vakansvikarie",
    "vakansvikariers": "vakansvikarie",
    "vakansvikaries": "vakansvikarie",
    "vakanta": "vakant",
    "vakantare": "vakant",
    "vakantares": "vakant",
    "vakantas": "vakant",
    "vakantast": "vakant",
    "vakantaste": "vakant",
    "vakantastes": "vakant",
    "vakantasts": "vakant",
    "vakante": "vakant",
    "vakantes": "vakant",
    "vakants": "vakant",
    "vakantsatt": "vakantsätta",
    "vakantsatta": "vakantsätta",
    "vakantsattas": "vakantsätta",
    "vakantsatte": "vakantsätta",
    "vakantsattes": "vakantsätta",
    "vakantsatts": "vakantsätta",
    "vakantsätt": "vakantsätta",
    "vakantsättande": "vakantsätta",
    "vakantsättanden": "vakantsättande",
    "vakantsättandena": "vakantsättande",
    "vakantsättandenas": "vakantsättande",
    "vakantsättandens": "vakantsättande",
    "vakantsättandes": "vakantsättande",
    "vakantsättandet": "vakantsättande",
    "vakantsättandets": "vakantsättande",
    "vakantsättas": "vakantsätta",
    "vakantsätter": "vakantsätta",
    "vakantsättes": "vakantsätta",
    "vakantsätts": "vakantsätta",
    "vakar": "vakare",
    "vakaren": "vakare",
    "vakarens": "vakare",
    "vakares": "vakare",
    "vakarna": "vakare",
    "vakarnas": "vakare",
    "vakars": "vak",
    "vakas": "vaka",
    "vakat": "vaka",
    "vakats": "vaka",
    "vake": "vaka",
    "vaken": "vak",
    "vakens": "vaken",
    "vaket": "vaken",
    "vakets": "vaken",
    "vakfågeln": "vakfågel",
    "vakfågelns": "vakfågel",
    "vakfågels": "vakfågel",
    "vakfåglar": "vakfågel",
    "vakfåglarna": "vakfågel",
    "vakfåglarnas": "vakfågel",
    "vakfåglars": "vakfågel",
    "vakna": "vaken",
    "vaknad": "vakna",
    "vaknade": "vakna",
    "vaknades": "vakna",
    "vaknads": "vakna",
    "vaknande": "vakna",
    "vaknanden": "vaknande",
    "vaknandena": "vaknande",
    "vaknandenas": "vaknande",
    "vaknandens": "vaknande",
    "vaknandes": "vaknande",
    "vaknandet": "vaknande",
    "vaknandets": "vaknande",
    "vaknar": "vakna",
    "vaknare": "vaken",
    "vaknares": "vaken",
    "vaknas": "vakna",
    "vaknast": "vaken",
    "vaknaste": "vaken",
    "vaknastes": "vaken",
    "vaknasts": "vaken",
    "vaknat": "vakna",
    "vaknatn": "vaknatt",
    "vaknatns": "vaknatt",
    "vaknats": "vakna",
    "vaknatten": "vaknatt",
    "vaknattens": "vaknatt",
    "vaknatts": "vaknatt",
    "vakne": "vaken",
    "vaknes": "vaken",
    "vaknätter": "vaknatt",
    "vaknätterna": "vaknatt",
    "vaknätternas": "vaknatt",
    "vaknätters": "vaknatt",
    "vakor": "vaka",
    "vakorna": "vaka",
    "vakornas": "vaka",
    "vakors": "vaka",
    "vaks": "vaka",
    "vaksamheten": "vaksamhet",
    "vaksamhetens": "vaksamhet",
    "vaksamhets": "vaksamhet",
    "vaksamma": "vaksam",
    "vaksammare": "vaksam",
    "vaksammares": "vaksam",
    "vaksammas": "vaksam",
    "vaksammast": "vaksam",
    "vaksammaste": "vaksam",
    "vaksammastes": "vaksam",
    "vaksammasts": "vaksam",
    "vaksamme": "vaksam",
    "vaksammes": "vaksam",
    "vaksams": "vaksam",
    "vaksamt": "vaksam",
    "vaksamts": "vaksam",
    "vaksinationen": "vaksination",
    "vaksinationens": "vaksination",
    "vaksinationer": "vaksination",
    "vaksinationerna": "vaksination",
    "vaksinationernas": "vaksination",
    "vaksinationers": "vaksination",
    "vaksinations": "vaksination",
    "vaksinatören": "vaksinatör",
    "vaksinatörens": "vaksinatör",
    "vaksinatörer": "vaksinatör",
    "vaksinatörerna": "vaksinatör",
    "vaksinatörernas": "vaksinatör",
    "vaksinatörers": "vaksinatör",
    "vaksinatörs": "vaksinatör",
    "vaksinen": "vaksin",
    "vaksinens": "vaksin",
    "vaksinerad": "vaksinera",
    "vaksinerade": "vaksinera",
    "vaksinerades": "vaksinera",
    "vaksinerads": "vaksinera",
    "vaksinerande": "vaksinera",
    "vaksineranden": "vaksinerande",
    "vaksinerandena": "vaksinerande",
    "vaksinerandenas": "vaksinerande",
    "vaksinerandens": "vaksinerande",
    "vaksinerandes": "vaksinerande",
    "vaksinerandet": "vaksinerande",
    "vaksinerandets": "vaksinerande",
    "vaksinerar": "vaksinera",
    "vaksineras": "vaksinera",
    "vaksinerat": "vaksinera",
    "vaksinerats": "vaksinera",
    "vaksinerbara": "vaksinerbar",
    "vaksinerbarare": "vaksinerbar",
    "vaksinerbarares": "vaksinerbar",
    "vaksinerbaras": "vaksinerbar",
    "vaksinerbarast": "vaksinerbar",
    "vaksinerbaraste": "vaksinerbar",
    "vaksinerbarastes": "vaksinerbar",
    "vaksinerbarasts": "vaksinerbar",
    "vaksinerbare": "vaksinerbar",
    "vaksinerbares": "vaksinerbar",
    "vaksinerbarheten": "vaksinerbarhet",
    "vaksinerbarhetens": "vaksinerbarhet",
    "vaksinerbarhets": "vaksinerbarhet",
    "vaksinerbars": "vaksinerbar",
    "vaksinerbart": "vaksinerbar",
    "vaksinerbarts": "vaksinerbar",
    "vaksineringar": "vaksinering",
    "vaksineringarna": "vaksinering",
    "vaksineringarnas": "vaksinering",
    "vaksineringars": "vaksinering",
    "vaksineringen": "vaksinering",
    "vaksineringens": "vaksinering",
    "vaksinerings": "vaksinering",
    "vaksinet": "vaksin",
    "vaksinets": "vaksin",
    "vaksins": "vaksin",
    "vakt": "vakta",
    "vaktad": "vakta",
    "vaktade": "vakta",
    "vaktades": "vakta",
    "vaktads": "vakta",
    "vaktande": "vakta",
    "vaktanden": "vaktande",
    "vaktandena": "vaktande",
    "vaktandenas": "vaktande",
    "vaktandens": "vaktande",
    "vaktandes": "vaktande",
    "vaktandet": "vaktande",
    "vaktandets": "vaktande",
    "vaktar": "vakta",
    "vaktarresten": "vaktarrest",
    "vaktarrestens": "vaktarrest",
    "vaktarrester": "vaktarrest",
    "vaktarresterna": "vaktarrest",
    "vaktarresternas": "vaktarrest",
    "vaktarresters": "vaktarrest",
    "vaktarrests": "vaktarrest",
    "vaktas": "vakta",
    "vaktat": "vakta",
    "vaktats": "vakta",
    "vaktavlösningar": "vaktavlösning",
    "vaktavlösningarna": "vaktavlösning",
    "vaktavlösningarnas": "vaktavlösning",
    "vaktavlösningars": "vaktavlösning",
    "vaktavlösningen": "vaktavlösning",
    "vaktavlösningens": "vaktavlösning",
    "vaktavlösnings": "vaktavlösning",
    "vaktbrick": "vaktbricka",
    "vaktbrickan": "vaktbricka",
    "vaktbrickans": "vaktbricka",
    "vaktbrickas": "vaktbricka",
    "vaktbricke": "vaktbricka",
    "vaktbrickor": "vaktbricka",
    "vaktbrickorna": "vaktbricka",
    "vaktbrickornas": "vaktbricka",
    "vaktbrickors": "vaktbricka",
    "vaktbricks": "vaktbricka",
    "vakteln": "vaktel",
    "vaktelns": "vaktel",
    "vaktels": "vaktel",
    "vakten": "vakt",
    "vaktens": "vakt",
    "vakter": "vakt",
    "vakterna": "vakt",
    "vakternas": "vakt",
    "vakters": "vakt",
    "vakthavanden": "vakthavande",
    "vakthavandena": "vakthavande",
    "vakthavandenas": "vakthavande",
    "vakthavandens": "vakthavande",
    "vakthavandes": "vakthavande",
    "vakthundar": "vakthund",
    "vakthundarna": "vakthund",
    "vakthundarnas": "vakthund",
    "vakthundars": "vakthund",
    "vakthunden": "vakthund",
    "vakthundens": "vakthund",
    "vakthunds": "vakthund",
    "vakthållningar": "vakthållning",
    "vakthållningarna": "vakthållning",
    "vakthållningarnas": "vakthållning",
    "vakthållningars": "vakthållning",
    "vakthållningen": "vakthållning",
    "vakthållningens": "vakthållning",
    "vakthållnings": "vakthållning",
    "vaktkurar": "vaktkur",
    "vaktkurarna": "vaktkur",
    "vaktkurarnas": "vaktkur",
    "vaktkurars": "vaktkur",
    "vaktkuren": "vaktkur",
    "vaktkurens": "vaktkur",
    "vaktkurs": "vaktkur",
    "vaktlar": "vaktel",
    "vaktlarna": "vaktel",
    "vaktlarnas": "vaktel",
    "vaktlars": "vaktel",
    "vaktmannen": "vaktman",
    "vaktmannens": "vaktman",
    "vaktmans": "vaktman",
    "vaktmän": "vaktman",
    "vaktmännen": "vaktman",
    "vaktmännens": "vaktman",
    "vaktmäns": "vaktman",
    "vaktmästar": "vaktmästare",
    "vaktmästaren": "vaktmästare",
    "vaktmästarens": "vaktmästare",
    "vaktmästares": "vaktmästare",
    "vaktmästarna": "vaktmästare",
    "vaktmästarnas": "vaktmästare",
    "vaktmästerier": "vaktmästeri",
    "vaktmästerierna": "vaktmästeri",
    "vaktmästeriernas": "vaktmästeri",
    "vaktmästeriers": "vaktmästeri",
    "vaktmästeriet": "vaktmästeri",
    "vaktmästeriets": "vaktmästeri",
    "vaktmästeris": "vaktmästeri",
    "vaktmästerit": "vaktmästeri",
    "vaktmästerits": "vaktmästeri",
    "vaktparaden": "vaktparad",
    "vaktparadens": "vaktparad",
    "vaktparader": "vaktparad",
    "vaktparaderna": "vaktparad",
    "vaktparadernas": "vaktparad",
    "vaktparaders": "vaktparad",
    "vaktparads": "vaktparad",
    "vaktposten": "vaktpost",
    "vaktpostens": "vaktpost",
    "vaktposter": "vaktpost",
    "vaktposterna": "vaktpost",
    "vaktposternas": "vaktpost",
    "vaktposters": "vaktpost",
    "vaktposts": "vaktpost",
    "vakts": "vakt",
    "vaktstyrkan": "vaktstyrka",
    "vaktstyrkans": "vaktstyrka",
    "vaktstyrkas": "vaktstyrka",
    "vaktstyrke": "vaktstyrka",
    "vaktstyrkor": "vaktstyrka",
    "vaktstyrkorna": "vaktstyrka",
    "vaktstyrkornas": "vaktstyrka",
    "vaktstyrkors": "vaktstyrka",
    "vakttornen": "vakttorn",
    "vakttornens": "vakttorn",
    "vakttornet": "vakttorn",
    "vakttornets": "vakttorn",
    "vakttorns": "vakttorn",
    "vaktuniformen": "vaktuniform",
    "vaktuniformens": "vaktuniform",
    "vaktuniformer": "vaktuniform",
    "vaktuniformerna": "vaktuniform",
    "vaktuniformernas": "vaktuniform",
    "vaktuniformers": "vaktuniform",
    "vaktuniforms": "vaktuniform",
    "vakuumbromsar": "vakuumbroms",
    "vakuumbromsarna": "vakuumbroms",
    "vakuumbromsarnas": "vakuumbroms",
    "vakuumbromsars": "vakuumbroms",
    "vakuumbromsen": "vakuumbroms",
    "vakuumbromsens": "vakuumbroms",
    "vakuumen": "vakuum",
    "vakuumens": "vakuum",
    "vakuumet": "vakuum",
    "vakuumets": "vakuum",
    "vakuumförpackningar": "vakuumförpackning",
    "vakuumförpackningarna": "vakuumförpackning",
    "vakuumförpackningarnas": "vakuumförpackning",
    "vakuumförpackningars": "vakuumförpackning",
    "vakuumförpackningen": "vakuumförpackning",
    "vakuumförpackningens": "vakuumförpackning",
    "vakuumförpacknings": "vakuumförpackning",
    "vakuumkammar": "vakuumkammare",
    "vakuumkammaren": "vakuumkammare",
    "vakuumkammarens": "vakuumkammare",
    "vakuumkammares": "vakuumkammare",
    "vakuumkamrar": "vakuumkammare",
    "vakuumkamrarna": "vakuumkammare",
    "vakuumkamrarnas": "vakuumkammare",
    "vakuumkamrars": "vakuumkammare",
    "vakuumklock": "vakuumklocka",
    "vakuumklockan": "vakuumklocka",
    "vakuumklockans": "vakuumklocka",
    "vakuumklockas": "vakuumklocka",
    "vakuumklocke": "vakuumklocka",
    "vakuumklockor": "vakuumklocka",
    "vakuumklockorna": "vakuumklocka",
    "vakuumklockornas": "vakuumklocka",
    "vakuumklockors": "vakuumklocka",
    "vakuumklocks": "vakuumklocka",
    "vakuumlamp": "vakuumlampa",
    "vakuumlampan": "vakuumlampa",
    "vakuumlampans": "vakuumlampa",
    "vakuumlampas": "vakuumlampa",
    "vakuumlampe": "vakuumlampa",
    "vakuumlampor": "vakuumlampa",
    "vakuumlamporna": "vakuumlampa",
    "vakuumlampornas": "vakuumlampa",
    "vakuumlampors": "vakuumlampa",
    "vakuumlamps": "vakuumlampa",
    "vakuummaterian": "vakuummateria",
    "vakuummaterians": "vakuummateria",
    "vakuummaterias": "vakuummateria",
    "vakuummaterier": "vakuummateria",
    "vakuummaterierna": "vakuummateria",
    "vakuummateriernas": "vakuummateria",
    "vakuummateriers": "vakuummateria",
    "vakuummetern": "vakuummeter",
    "vakuummeterns": "vakuummeter",
    "vakuummeters": "vakuummeter",
    "vakuummetrar": "vakuummeter",
    "vakuummetrarna": "vakuummeter",
    "vakuummetrarnas": "vakuummeter",
    "vakuummetrars": "vakuummeter",
    "vakuumpumpar": "vakuumpump",
    "vakuumpumparna": "vakuumpump",
    "vakuumpumparnas": "vakuumpump",
    "vakuumpumpars": "vakuumpump",
    "vakuumpumpen": "vakuumpump",
    "vakuumpumpens": "vakuumpump",
    "vakuumpumps": "vakuumpump",
    "vakuumregulatorer": "vakuumregulator",
    "vakuumregulatorerna": "vakuumregulator",
    "vakuumregulatorernas": "vakuumregulator",
    "vakuumregulatorers": "vakuumregulator",
    "vakuumregulatorn": "vakuumregulator",
    "vakuumregulatorns": "vakuumregulator",
    "vakuumregulators": "vakuumregulator",
    "vakuums": "vakuum",
    "vakuumsugar": "vakuumsug",
    "vakuumsugarna": "vakuumsug",
    "vakuumsugarnas": "vakuumsug",
    "vakuumsugars": "vakuumsug",
    "vakuumsugen": "vakuumsug",
    "vakuumsugens": "vakuumsug",
    "vakuumsugs": "vakuumsug",
    "vakuumtoaletten": "vakuumtoalett",
    "vakuumtoalettens": "vakuumtoalett",
    "vakuumtoaletter": "vakuumtoalett",
    "vakuumtoaletterna": "vakuumtoalett",
    "vakuumtoaletternas": "vakuumtoalett",
    "vakuumtoaletters": "vakuumtoalett",
    "vakuumtoaletts": "vakuumtoalett",
    "vakuumtorkningar": "vakuumtorkning",
    "vakuumtorkningarna": "vakuumtorkning",
    "vakuumtorkningarnas": "vakuumtorkning",
    "vakuumtorkningars": "vakuumtorkning",
    "vakuumtorkningen": "vakuumtorkning",
    "vakuumtorkningens": "vakuumtorkning",
    "vakuumtorknings": "vakuumtorkning",
    "val": "vala",
    "valack": "valacka",
    "valackad": "valacka",
    "valackade": "valacka",
    "valackades": "valacka",
    "valackads": "valacka",
    "valackande": "valacka",
    "valackanden": "valackande",
    "valackandena": "valackande",
    "valackandenas": "valackande",
    "valackandens": "valackande",
    "valackandes": "valackande",
    "valackandet": "valackande",
    "valackandets": "valackande",
    "valackar": "valacka",
    "valackas": "valacka",
    "valackat": "valacka",
    "valackats": "valacka",
    "valacken": "valack",
    "valackens": "valack",
    "valacker": "valack",
    "valackerna": "valack",
    "valackernas": "valack",
    "valackers": "valack",
    "valacks": "valack",
    "valaffischen": "valaffisch",
    "valaffischens": "valaffisch",
    "valaffischer": "valaffisch",
    "valaffischerna": "valaffisch",
    "valaffischernas": "valaffisch",
    "valaffischers": "valaffisch",
    "valaffischs": "valaffisch",
    "valan": "vala",
    "valans": "vala",
    "valapparaten": "valapparat",
    "valapparatens": "valapparat",
    "valapparater": "valapparat",
    "valapparaterna": "valapparat",
    "valapparaternas": "valapparat",
    "valapparaters": "valapparat",
    "valapparats": "valapparat",
    "valar": "val",
    "valarbetar": "valarbetare",
    "valarbetaren": "valarbetare",
    "valarbetarens": "valarbetare",
    "valarbetares": "valarbetare",
    "valarbetarna": "valarbetare",
    "valarbetarnas": "valarbetare",
    "valarna": "val",
    "valarnas": "val",
    "valars": "val",
    "valas": "vala",
    "valbara": "valbar",
    "valbarare": "valbar",
    "valbarares": "valbar",
    "valbaras": "valbar",
    "valbarast": "valbar",
    "valbaraste": "valbar",
    "valbarastes": "valbar",
    "valbarasts": "valbar",
    "valbare": "valbar",
    "valbares": "valbar",
    "valbarheten": "valbarhet",
    "valbarhetens": "valbarhet",
    "valbarhets": "valbarhet",
    "valbarometern": "valbarometer",
    "valbarometerns": "valbarometer",
    "valbarometers": "valbarometer",
    "valbarometrar": "valbarometer",
    "valbarometrarna": "valbarometer",
    "valbarometrarnas": "valbarometer",
    "valbarometrars": "valbarometer",
    "valbars": "valbar",
    "valbart": "valbar",
    "valbarts": "valbar",
    "valberedningar": "valberedning",
    "valberedningarna": "valberedning",
    "valberedningarnas": "valberedning",
    "valberedningars": "valberedning",
    "valberedningen": "valberedning",
    "valberedningens": "valberedning",
    "valberednings": "valberedning",
    "valbiskopar": "valbiskop",
    "valbiskoparna": "valbiskop",
    "valbiskoparnas": "valbiskop",
    "valbiskopars": "valbiskop",
    "valbiskopen": "valbiskop",
    "valbiskopens": "valbiskop",
    "valbiskops": "valbiskop",
    "valbodar": "valbod",
    "valbodarna": "valbod",
    "valbodarnas": "valbod",
    "valbodars": "valbod",
    "valboden": "valbod",
    "valbodens": "valbod",
    "valbods": "valbod",
    "valborgs": "valborg",
    "valborgsmässoaftnar": "valborgsmässoafton",
    "valborgsmässoaftnarna": "valborgsmässoafton",
    "valborgsmässoaftnarnas": "valborgsmässoafton",
    "valborgsmässoaftnars": "valborgsmässoafton",
    "valborgsmässoaftonen": "valborgsmässoafton",
    "valborgsmässoaftonens": "valborgsmässoafton",
    "valborgsmässoaftons": "valborgsmässoafton",
    "valboskapen": "valboskap",
    "valboskapens": "valboskap",
    "valboskaps": "valboskap",
    "valbyråer": "valbyrå",
    "valbyråerna": "valbyrå",
    "valbyråernas": "valbyrå",
    "valbyråers": "valbyrå",
    "valbyrån": "valbyrå",
    "valbyråns": "valbyrå",
    "valbyrås": "valbyrå",
    "vald": "välja",
    "valda": "välja",
    "valdas": "välja",
    "valde": "välja",
    "valdebatten": "valdebatt",
    "valdebattens": "valdebatt",
    "valdebatter": "valdebatt",
    "valdebatterna": "valdebatt",
    "valdebatternas": "valdebatt",
    "valdebatters": "valdebatt",
    "valdebatts": "valdebatt",
    "valdeltaganden": "valdeltagande",
    "valdeltagandena": "valdeltagande",
    "valdeltagandenas": "valdeltagande",
    "valdeltagandens": "valdeltagande",
    "valdeltagandes": "valdeltagande",
    "valdeltagandet": "valdeltagande",
    "valdeltagandets": "valdeltagande",
    "valdeltagar": "valdeltagare",
    "valdeltagaren": "valdeltagare",
    "valdeltagarens": "valdeltagare",
    "valdeltagares": "valdeltagare",
    "valdeltagarna": "valdeltagare",
    "valdeltagarnas": "valdeltagare",
    "valdes": "välja",
    "valdistrikten": "valdistrikt",
    "valdistriktens": "valdistrikt",
    "valdistriktet": "valdistrikt",
    "valdistriktets": "valdistrikt",
    "valdistrikts": "valdistrikt",
    "valds": "välja",
    "vale": "vala",
    "valen": "val",
    "valens": "valen",
    "valenselektronen": "valenselektron",
    "valenselektronens": "valenselektron",
    "valenselektroner": "valenselektron",
    "valenselektronerna": "valenselektron",
    "valenselektronernas": "valenselektron",
    "valenselektroners": "valenselektron",
    "valenselektrons": "valenselektron",
    "valensen": "valens",
    "valensens": "valens",
    "valenser": "valens",
    "valenserna": "valens",
    "valensernas": "valens",
    "valensers": "valens",
    "valenstalen": "valenstal",
    "valenstalens": "valenstal",
    "valenstalet": "valenstal",
    "valenstalets": "valenstal",
    "valenstals": "valenstal",
    "valerianan": "valeriana",
    "valerianans": "valeriana",
    "valerianas": "valeriana",
    "valet": "valen",
    "valets": "valen",
    "valfiaskon": "valfiasko",
    "valfiaskona": "valfiasko",
    "valfiaskonas": "valfiasko",
    "valfiaskons": "valfiasko",
    "valfiaskos": "valfiasko",
    "valfiaskot": "valfiasko",
    "valfiaskots": "valfiasko",
    "valfiffels": "valfiffel",
    "valfifflet": "valfiffel",
    "valfifflets": "valfiffel",
    "valfiskar": "valfisk",
    "valfiskarna": "valfisk",
    "valfiskarnas": "valfisk",
    "valfiskars": "valfisk",
    "valfisken": "valfisk",
    "valfiskens": "valfisk",
    "valfisks": "valfisk",
    "valfläsket": "valfläsk",
    "valfläskets": "valfläsk",
    "valfläsks": "valfläsk",
    "valfria": "valfri",
    "valfriare": "valfri",
    "valfriares": "valfri",
    "valfrias": "valfri",
    "valfriast": "valfri",
    "valfriaste": "valfri",
    "valfriastes": "valfri",
    "valfriasts": "valfri",
    "valfrie": "valfri",
    "valfries": "valfri",
    "valfriheten": "valfrihet",
    "valfrihetens": "valfrihet",
    "valfriheter": "valfrihet",
    "valfriheterna": "valfrihet",
    "valfriheternas": "valfrihet",
    "valfriheters": "valfrihet",
    "valfrihets": "valfrihet",
    "valfris": "valfri",
    "valfritt": "valfri",
    "valfritts": "valfri",
    "valfrändskapen": "valfrändskap",
    "valfrändskapens": "valfrändskap",
    "valfrändskaper": "valfrändskap",
    "valfrändskaperna": "valfrändskap",
    "valfrändskapernas": "valfrändskap",
    "valfrändskapers": "valfrändskap",
    "valfrändskaps": "valfrändskap",
    "valfurstar": "valfurste",
    "valfurstarna": "valfurste",
    "valfurstarnas": "valfurste",
    "valfurstars": "valfurste",
    "valfursten": "valfurste",
    "valfurstens": "valfurste",
    "valfurstes": "valfurste",
    "valfusk": "valfuska",
    "valfuskade": "valfuska",
    "valfuskades": "valfuska",
    "valfuskande": "valfuska",
    "valfuskanden": "valfuskande",
    "valfuskandena": "valfuskande",
    "valfuskandenas": "valfuskande",
    "valfuskandens": "valfuskande",
    "valfuskandes": "valfuskande",
    "valfuskandet": "valfuskande",
    "valfuskandets": "valfuskande",
    "valfuskar": "valfuska",
    "valfuskas": "valfuska",
    "valfuskat": "valfuska",
    "valfuskats": "valfuska",
    "valfusket": "valfusk",
    "valfuskets": "valfusk",
    "valfusks": "valfusk",
    "valfångar": "valfångare",
    "valfångaren": "valfångare",
    "valfångarens": "valfångare",
    "valfångares": "valfångare",
    "valfångarna": "valfångare",
    "valfångarnas": "valfångare",
    "valfångsten": "valfångst",
    "valfångstens": "valfångst",
    "valfångsts": "valfångst",
    "valförlusten": "valförlust",
    "valförlustens": "valförlust",
    "valförluster": "valförlust",
    "valförlusterna": "valförlust",
    "valförlusternas": "valförlust",
    "valförlusters": "valförlust",
    "valförlusts": "valförlust",
    "valförvantskapen": "valförvantskap",
    "valförvantskapens": "valförvantskap",
    "valförvantskaps": "valförvantskap",
    "valgranskningar": "valgranskning",
    "valgranskningarna": "valgranskning",
    "valgranskningarnas": "valgranskning",
    "valgranskningars": "valgranskning",
    "valgranskningen": "valgranskning",
    "valgranskningens": "valgranskning",
    "valgransknings": "valgranskning",
    "valgranskningsskommissionen": "valgranskningsskommission",
    "valgranskningsskommissionens": "valgranskningsskommission",
    "valgranskningsskommissioner": "valgranskningsskommission",
    "valgranskningsskommissionerna": "valgranskningsskommission",
    "valgranskningsskommissionernas": "valgranskningsskommission",
    "valgranskningsskommissioners": "valgranskningsskommission",
    "valgranskningsskommissions": "valgranskningsskommission",
    "valhemligheten": "valhemlighet",
    "valhemlighetens": "valhemlighet",
    "valhemligheter": "valhemlighet",
    "valhemligheterna": "valhemlighet",
    "valhemligheternas": "valhemlighet",
    "valhemligheters": "valhemlighet",
    "valhemlighets": "valhemlighet",
    "valhänta": "valhänt",
    "valhäntare": "valhänt",
    "valhäntares": "valhänt",
    "valhäntas": "valhänt",
    "valhäntast": "valhänt",
    "valhäntaste": "valhänt",
    "valhäntastes": "valhänt",
    "valhäntasts": "valhänt",
    "valhänte": "valhänt",
    "valhäntes": "valhänt",
    "valhäntheten": "valhänthet",
    "valhänthetens": "valhänthet",
    "valhäntheter": "valhänthet",
    "valhäntheterna": "valhänthet",
    "valhäntheternas": "valhänthet",
    "valhäntheters": "valhänthet",
    "valhänthets": "valhänthet",
    "valhänts": "valhänt",
    "valida": "valid",
    "validare": "valid",
    "validares": "valid",
    "validas": "valid",
    "validast": "valid",
    "validaste": "valid",
    "validastes": "valid",
    "validasts": "valid",
    "valide": "valid",
    "valides": "valid",
    "validiteten": "validitet",
    "validitetens": "validitet",
    "validiteter": "validitet",
    "validiteterna": "validitet",
    "validiteternas": "validitet",
    "validiteters": "validitet",
    "validitets": "validitet",
    "valids": "valid",
    "valiumen": "valium",
    "valiumens": "valium",
    "valiumet": "valium",
    "valiumets": "valium",
    "valiums": "valium",
    "valk": "valka",
    "valkad": "valka",
    "valkade": "valka",
    "valkades": "valka",
    "valkads": "valka",
    "valkampanjen": "valkampanj",
    "valkampanjens": "valkampanj",
    "valkampanjer": "valkampanj",
    "valkampanjerna": "valkampanj",
    "valkampanjernas": "valkampanj",
    "valkampanjers": "valkampanj",
    "valkampanjs": "valkampanj",
    "valkande": "valka",
    "valkanden": "valkande",
    "valkandena": "valkande",
    "valkandenas": "valkande",
    "valkandens": "valkande",
    "valkandes": "valkande",
    "valkandet": "valkande",
    "valkandets": "valkande",
    "valkaosen": "valkaos",
    "valkaosens": "valkaos",
    "valkaoset": "valkaos",
    "valkaosets": "valkaos",
    "valkar": "valkare",
    "valkaren": "valkare",
    "valkarens": "valkare",
    "valkares": "valkare",
    "valkarna": "valkare",
    "valkarnas": "valkare",
    "valkars": "valk",
    "valkas": "valka",
    "valkat": "valka",
    "valkats": "valka",
    "valken": "valk",
    "valkens": "valk",
    "valkerier": "valkeri",
    "valkerierna": "valkeri",
    "valkeriernas": "valkeri",
    "valkeriers": "valkeri",
    "valkeriet": "valkeri",
    "valkeriets": "valkeri",
    "valkeris": "valkeri",
    "valkerit": "valkeri",
    "valkerits": "valkeri",
    "valkgarv": "valkgarva",
    "valkgarvad": "valkgarva",
    "valkgarvade": "valkgarva",
    "valkgarvades": "valkgarva",
    "valkgarvads": "valkgarva",
    "valkgarvande": "valkgarva",
    "valkgarvanden": "valkgarvande",
    "valkgarvandena": "valkgarvande",
    "valkgarvandenas": "valkgarvande",
    "valkgarvandens": "valkgarvande",
    "valkgarvandes": "valkgarvande",
    "valkgarvandet": "valkgarvande",
    "valkgarvandets": "valkgarvande",
    "valkgarvar": "valkgarva",
    "valkgarvas": "valkgarva",
    "valkgarvat": "valkgarva",
    "valkgarvats": "valkgarva",
    "valkiga": "valkig",
    "valkigare": "valkig",
    "valkigares": "valkig",
    "valkigas": "valkig",
    "valkigast": "valkig",
    "valkigaste": "valkig",
    "valkigastes": "valkig",
    "valkigasts": "valkig",
    "valkige": "valkig",
    "valkiges": "valkig",
    "valkigheten": "valkighet",
    "valkighetens": "valkighet",
    "valkighets": "valkighet",
    "valkigs": "valkig",
    "valkigt": "valkig",
    "valkigts": "valkig",
    "valklagomålen": "valklagomål",
    "valklagomålens": "valklagomål",
    "valklagomålet": "valklagomål",
    "valklagomålets": "valklagomål",
    "valklagomåls": "valklagomål",
    "valkokerier": "valkokeri",
    "valkokerierna": "valkokeri",
    "valkokeriernas": "valkokeri",
    "valkokeriers": "valkokeri",
    "valkokeriet": "valkokeri",
    "valkokeriets": "valkokeri",
    "valkokeris": "valkokeri",
    "valkokerit": "valkokeri",
    "valkokerits": "valkokeri",
    "valkommissionen": "valkommission",
    "valkommissionens": "valkommission",
    "valkommissioner": "valkommission",
    "valkommissionerna": "valkommission",
    "valkommissionernas": "valkommission",
    "valkommissioners": "valkommission",
    "valkommissions": "valkommission",
    "valkretsar": "valkrets",
    "valkretsarna": "valkrets",
    "valkretsarnas": "valkrets",
    "valkretsars": "valkrets",
    "valkretsen": "valkrets",
    "valkretsens": "valkrets",
    "valks": "valk",
    "valkuverten": "valkuvert",
    "valkuvertens": "valkuvert",
    "valkuvertet": "valkuvert",
    "valkuvertets": "valkuvert",
    "valkuverts": "valkuvert",
    "valkyrian": "valkyria",
    "valkyrians": "valkyria",
    "valkyrias": "valkyria",
    "valkyrie": "valkyria",
    "valkyrior": "valkyria",
    "valkyriorna": "valkyria",
    "valkyriornas": "valkyria",
    "valkyriors": "valkyria",
    "valkyrjan": "valkyrja",
    "valkyrjans": "valkyrja",
    "valkyrjas": "valkyrja",
    "valkyrje": "valkyrja",
    "valkyrjor": "valkyrja",
    "valkyrjorna": "valkyrja",
    "valkyrjornas": "valkyrja",
    "valkyrjors": "valkyrja",
    "vall": "valla",
    "vallad": "valla",
    "vallade": "valla",
    "vallades": "valla",
    "vallads": "valla",
    "vallan": "valla",
    "vallande": "valla",
    "vallanden": "vallande",
    "vallandena": "vallande",
    "vallandenas": "vallande",
    "vallandens": "vallande",
    "vallandes": "vallande",
    "vallandet": "vallande",
    "vallandets": "vallande",
    "vallans": "valla",
    "vallar": "vallare",
    "vallaren": "vallare",
    "vallarens": "vallare",
    "vallares": "vallare",
    "vallarna": "vallare",
    "vallarnas": "vallare",
    "vallars": "vall",
    "vallas": "valla",
    "vallat": "valla",
    "vallats": "valla",
    "vallbond": "vallbonde",
    "vallbonden": "vallbonde",
    "vallbondens": "vallbonde",
    "vallbondes": "vallbonde",
    "vallbonds": "vallbonde",
    "vallbönder": "vallbonde",
    "vallbönderna": "vallbonde",
    "vallböndernas": "vallbonde",
    "vallbönders": "vallbonde",
    "valle": "valla",
    "vallen": "vall",
    "vallens": "vall",
    "vallfarten": "vallfart",
    "vallfartens": "vallfart",
    "vallfarter": "vallfart",
    "vallfarterna": "vallfart",
    "vallfarternas": "vallfart",
    "vallfarters": "vallfart",
    "vallfarts": "vallfart",
    "vallfartsorten": "vallfartsort",
    "vallfartsortens": "vallfartsort",
    "vallfartsorter": "vallfartsort",
    "vallfartsorterna": "vallfartsort",
    "vallfartsorternas": "vallfartsort",
    "vallfartsorters": "vallfartsort",
    "vallfartsorts": "vallfartsort",
    "vallflick": "vallflicka",
    "vallflickan": "vallflicka",
    "vallflickans": "vallflicka",
    "vallflickas": "vallflicka",
    "vallflicke": "vallflicka",
    "vallflickor": "vallflicka",
    "vallflickorna": "vallflicka",
    "vallflickornas": "vallflicka",
    "vallflickors": "vallflicka",
    "vallflicks": "vallflicka",
    "vallfärd": "vallfärda",
    "vallfärdad": "vallfärda",
    "vallfärdade": "vallfärda",
    "vallfärdades": "vallfärda",
    "vallfärdads": "vallfärda",
    "vallfärdande": "vallfärda",
    "vallfärdanden": "vallfärdande",
    "vallfärdandena": "vallfärdande",
    "vallfärdandenas": "vallfärdande",
    "vallfärdandens": "vallfärdande",
    "vallfärdandes": "vallfärdande",
    "vallfärdandet": "vallfärdande",
    "vallfärdandets": "vallfärdande",
    "vallfärdar": "vallfärda",
    "vallfärdas": "vallfärda",
    "vallfärdat": "vallfärda",
    "vallfärdats": "vallfärda",
    "vallfärden": "vallfärd",
    "vallfärdens": "vallfärd",
    "vallfärder": "vallfärd",
    "vallfärderna": "vallfärd",
    "vallfärdernas": "vallfärd",
    "vallfärders": "vallfärd",
    "vallfärds": "vallfärd",
    "vallgravar": "vallgrav",
    "vallgravarna": "vallgrav",
    "vallgravarnas": "vallgrav",
    "vallgravars": "vallgrav",
    "vallgraven": "vallgrav",
    "vallgravens": "vallgrav",
    "vallgravs": "vallgrav",
    "vallhornen": "vallhorn",
    "vallhornens": "vallhorn",
    "vallhornet": "vallhorn",
    "vallhornets": "vallhorn",
    "vallhorns": "vallhorn",
    "vallhundar": "vallhund",
    "vallhundarna": "vallhund",
    "vallhundarnas": "vallhund",
    "vallhundars": "vallhund",
    "vallhunden": "vallhund",
    "vallhundens": "vallhund",
    "vallhunds": "vallhund",
    "vallhöet": "vallhö",
    "vallhöets": "vallhö",
    "vallhös": "vallhö",
    "vallhöt": "vallhö",
    "vallhöts": "vallhö",
    "vallistan": "vallista",
    "vallistans": "vallista",
    "vallistas": "vallista",
    "valliste": "vallista",
    "vallistor": "vallista",
    "vallistorna": "vallista",
    "vallistornas": "vallista",
    "vallistors": "vallista",
    "vallkrassen": "vallkrasse",
    "vallkrassens": "vallkrasse",
    "vallkrasses": "vallkrasse",
    "vallmofröen": "vallmofrö",
    "vallmofröens": "vallmofrö",
    "vallmofröet": "vallmofrö",
    "vallmofröets": "vallmofrö",
    "vallmofrön": "vallmofrö",
    "vallmofröna": "vallmofrö",
    "vallmofrönas": "vallmofrö",
    "vallmofröns": "vallmofrö",
    "vallmofrös": "vallmofrö",
    "vallmofröt": "vallmofrö",
    "vallmofröts": "vallmofrö",
    "vallmon": "vallmo",
    "vallmons": "vallmo",
    "vallmoodlingar": "vallmoodling",
    "vallmoodlingarna": "vallmoodling",
    "vallmoodlingarnas": "vallmoodling",
    "vallmoodlingars": "vallmoodling",
    "vallmoodlingen": "vallmoodling",
    "vallmoodlingens": "vallmoodling",
    "vallmoodlings": "vallmoodling",
    "vallmor": "vallmo",
    "vallmorna": "vallmo",
    "vallmornas": "vallmo",
    "vallmors": "vallmo",
    "vallmos": "vallmo",
    "vallmoteet": "vallmote",
    "vallmoteets": "vallmote",
    "vallmotes": "vallmote",
    "vallmotet": "vallmote",
    "vallmotets": "vallmote",
    "vallmoväxten": "vallmoväxt",
    "vallmoväxtens": "vallmoväxt",
    "vallmoväxter": "vallmoväxt",
    "vallmoväxterna": "vallmoväxt",
    "vallmoväxternas": "vallmoväxt",
    "vallmoväxters": "vallmoväxt",
    "vallmoväxts": "vallmoväxt",
    "vallningstabellen": "vallningstabell",
    "vallningstabellens": "vallningstabell",
    "vallningstabeller": "vallningstabell",
    "vallningstabellerna": "vallningstabell",
    "vallningstabellernas": "vallningstabell",
    "vallningstabellers": "vallningstabell",
    "vallningstabells": "vallningstabell",
    "vallokalen": "vallokal",
    "vallokalens": "vallokal",
    "vallokaler": "vallokal",
    "vallokalerna": "vallokal",
    "vallokalernas": "vallokal",
    "vallokalers": "vallokal",
    "vallokals": "vallokal",
    "vallokalsundersökningar": "vallokalsundersökning",
    "vallokalsundersökningarna": "vallokalsundersökning",
    "vallokalsundersökningarnas": "vallokalsundersökning",
    "vallokalsundersökningars": "vallokalsundersökning",
    "vallokalsundersökningen": "vallokalsundersökning",
    "vallokalsundersökningens": "vallokalsundersökning",
    "vallokalsundersöknings": "vallokalsundersökning",
    "vallonen": "vallon",
    "vallonens": "vallon",
    "valloner": "vallon",
    "vallonerna": "vallon",
    "vallonernas": "vallon",
    "valloners": "vallon",
    "vallons": "vallon",
    "vallonska": "vallonsk",
    "vallonskare": "vallonsk",
    "vallonskares": "vallonsk",
    "vallonskas": "vallonsk",
    "vallonskast": "vallonsk",
    "vallonskaste": "vallonsk",
    "vallonskastes": "vallonsk",
    "vallonskasts": "vallonsk",
    "vallonske": "vallonsk",
    "vallonskes": "vallonsk",
    "vallonsks": "vallonsk",
    "vallonskt": "vallonsk",
    "vallonskts": "vallonsk",
    "vallonsmides": "vallonsmide",
    "vallonsmidet": "vallonsmide",
    "vallonsmidets": "vallonsmide",
    "vallor": "valla",
    "vallorna": "valla",
    "vallornas": "valla",
    "vallors": "valla",
    "vallpojk": "vallpojke",
    "vallpojkar": "vallpojke",
    "vallpojkarna": "vallpojke",
    "vallpojkarnas": "vallpojke",
    "vallpojkars": "vallpojke",
    "vallpojken": "vallpojke",
    "vallpojkens": "vallpojke",
    "vallpojkes": "vallpojke",
    "vallpojks": "vallpojke",
    "valls": "valla",
    "vallväxten": "vallväxt",
    "vallväxtens": "vallväxt",
    "vallväxter": "vallväxt",
    "vallväxterna": "vallväxt",
    "vallväxternas": "vallväxt",
    "vallväxters": "vallväxt",
    "vallväxts": "vallväxt",
    "vallängden": "vallängd",
    "vallängdens": "vallängd",
    "vallängder": "vallängd",
    "vallängderna": "vallängd",
    "vallängdernas": "vallängd",
    "vallängders": "vallängd",
    "vallängds": "vallängd",
    "vallöften": "vallöfte",
    "vallöftena": "vallöfte",
    "vallöftenas": "vallöfte",
    "vallöftens": "vallöfte",
    "vallöftes": "vallöfte",
    "vallöftet": "vallöfte",
    "vallöftets": "vallöfte",
    "valmade": "valmad",
    "valmades": "valmad",
    "valmads": "valmad",
    "valmagneten": "valmagnet",
    "valmagnetens": "valmagnet",
    "valmagneter": "valmagnet",
    "valmagneterna": "valmagnet",
    "valmagneternas": "valmagnet",
    "valmagneters": "valmagnet",
    "valmagnets": "valmagnet",
    "valmanifesten": "valmanifest",
    "valmanifestens": "valmanifest",
    "valmanifestet": "valmanifest",
    "valmanifestets": "valmanifest",
    "valmanifests": "valmanifest",
    "valmannen": "valman",
    "valmannens": "valman",
    "valmans": "valman",
    "valmanskåren": "valmanskår",
    "valmanskårens": "valmanskår",
    "valmanskårer": "valmanskår",
    "valmanskårerna": "valmanskår",
    "valmanskårernas": "valmanskår",
    "valmanskårers": "valmanskår",
    "valmanskårs": "valmanskår",
    "valmaren": "valmar",
    "valmarens": "valmar",
    "valmaret": "valmar",
    "valmarets": "valmar",
    "valmars": "valmar",
    "valmaskinerier": "valmaskineri",
    "valmaskinerierna": "valmaskineri",
    "valmaskineriernas": "valmaskineri",
    "valmaskineriers": "valmaskineri",
    "valmaskineriet": "valmaskineri",
    "valmaskineriets": "valmaskineri",
    "valmaskineris": "valmaskineri",
    "valmaskinerit": "valmaskineri",
    "valmaskinerits": "valmaskineri",
    "valmat": "valmad",
    "valmatematiken": "valmatematik",
    "valmatematikens": "valmatematik",
    "valmatematiks": "valmatematik",
    "valmats": "valmad",
    "valmtaken": "valmtak",
    "valmtakens": "valmtak",
    "valmtaket": "valmtak",
    "valmtakets": "valmtak",
    "valmtaks": "valmtak",
    "valmän": "valman",
    "valmännen": "valman",
    "valmännens": "valman",
    "valmäns": "valman",
    "valmöjligheten": "valmöjlighet",
    "valmöjlighetens": "valmöjlighet",
    "valmöjligheter": "valmöjlighet",
    "valmöjligheterna": "valmöjlighet",
    "valmöjligheternas": "valmöjlighet",
    "valmöjligheters": "valmöjlighet",
    "valmöjlighets": "valmöjlighet",
    "valmöten": "valmöte",
    "valmötena": "valmöte",
    "valmötenas": "valmöte",
    "valmötens": "valmöte",
    "valmötes": "valmöte",
    "valmötet": "valmöte",
    "valmötets": "valmöte",
    "valn": "valna",
    "valna": "valen",
    "valnad": "valna",
    "valnade": "valna",
    "valnades": "valna",
    "valnads": "valna",
    "valnande": "valna",
    "valnanden": "valnande",
    "valnandena": "valnande",
    "valnandenas": "valnande",
    "valnandens": "valnande",
    "valnandes": "valnande",
    "valnandet": "valnande",
    "valnandets": "valnande",
    "valnar": "valna",
    "valnare": "valen",
    "valnares": "valen",
    "valnas": "valna",
    "valnast": "valen",
    "valnaste": "valen",
    "valnastes": "valen",
    "valnasts": "valen",
    "valnat": "valna",
    "valnats": "valna",
    "valne": "valen",
    "valnes": "valen",
    "valnöten": "valnöt",
    "valnötens": "valnöt",
    "valnöts": "valnöt",
    "valnötsbetsade": "valnötsbetsad",
    "valnötsbetsades": "valnötsbetsad",
    "valnötsbetsads": "valnötsbetsad",
    "valnötsbetsat": "valnötsbetsad",
    "valnötsbetsats": "valnötsbetsad",
    "valnötsgråa": "valnötsgrå",
    "valnötsgråare": "valnötsgrå",
    "valnötsgråares": "valnötsgrå",
    "valnötsgråas": "valnötsgrå",
    "valnötsgråast": "valnötsgrå",
    "valnötsgråaste": "valnötsgrå",
    "valnötsgråastes": "valnötsgrå",
    "valnötsgråasts": "valnötsgrå",
    "valnötsgråe": "valnötsgrå",
    "valnötsgråes": "valnötsgrå",
    "valnötsgrås": "valnötsgrå",
    "valnötsgrått": "valnötsgrå",
    "valnötsgråtts": "valnötsgrå",
    "valnötsträden": "valnötsträd",
    "valnötsträdens": "valnötsträd",
    "valnötsträdet": "valnötsträd",
    "valnötsträdets": "valnötsträd",
    "valnötsträds": "valnötsträd",
    "valnötsträet": "valnötsträ",
    "valnötsträets": "valnötsträ",
    "valnötsträs": "valnötsträ",
    "valnötsträt": "valnötsträ",
    "valnötsträts": "valnötsträ",
    "valnötstårt": "valnötstårta",
    "valnötstårtan": "valnötstårta",
    "valnötstårtans": "valnötstårta",
    "valnötstårtas": "valnötstårta",
    "valnötstårte": "valnötstårta",
    "valnötstårtor": "valnötstårta",
    "valnötstårtorna": "valnötstårta",
    "valnötstårtornas": "valnötstårta",
    "valnötstårtors": "valnötstårta",
    "valnötstårts": "valnötstårta",
    "valnötter": "valnöt",
    "valnötterna": "valnöt",
    "valnötternas": "valnöt",
    "valnötters": "valnöt",
    "valomgångar": "valomgång",
    "valomgångarna": "valomgång",
    "valomgångarnas": "valomgång",
    "valomgångars": "valomgång",
    "valomgången": "valomgång",
    "valomgångens": "valomgång",
    "valomgångs": "valomgång",
    "valor": "vala",
    "valorisationen": "valorisation",
    "valorisationens": "valorisation",
    "valorisationer": "valorisation",
    "valorisationerna": "valorisation",
    "valorisationernas": "valorisation",
    "valorisationers": "valorisation",
    "valorisations": "valorisation",
    "valorna": "vala",
    "valornas": "vala",
    "valors": "vala",
    "valp": "valpa",
    "valpad": "valpa",
    "valpade": "valpa",
    "valpades": "valpa",
    "valpads": "valpa",
    "valpaktiga": "valpaktig",
    "valpaktigare": "valpaktig",
    "valpaktigares": "valpaktig",
    "valpaktigas": "valpaktig",
    "valpaktigast": "valpaktig",
    "valpaktigaste": "valpaktig",
    "valpaktigastes": "valpaktig",
    "valpaktigasts": "valpaktig",
    "valpaktige": "valpaktig",
    "valpaktiges": "valpaktig",
    "valpaktigheten": "valpaktighet",
    "valpaktighetens": "valpaktighet",
    "valpaktighets": "valpaktighet",
    "valpaktigs": "valpaktig",
    "valpaktigt": "valpaktig",
    "valpaktigts": "valpaktig",
    "valpande": "valpa",
    "valpanden": "valpande",
    "valpandena": "valpande",
    "valpandenas": "valpande",
    "valpandens": "valpande",
    "valpandes": "valpande",
    "valpandet": "valpande",
    "valpandets": "valpande",
    "valpar": "valpa",
    "valparna": "valp",
    "valparnas": "valp",
    "valpars": "valp",
    "valpas": "valpa",
    "valpat": "valpa",
    "valpats": "valpa",
    "valpen": "valp",
    "valpens": "valp",
    "valpiga": "valpig",
    "valpigare": "valpig",
    "valpigares": "valpig",
    "valpigas": "valpig",
    "valpigast": "valpig",
    "valpigaste": "valpig",
    "valpigastes": "valpig",
    "valpigasts": "valpig",
    "valpige": "valpig",
    "valpiges": "valpig",
    "valpigheten": "valpighet",
    "valpighetens": "valpighet",
    "valpighets": "valpighet",
    "valpigs": "valpig",
    "valpigt": "valpig",
    "valpigts": "valpig",
    "valplatsen": "valplats",
    "valplatsens": "valplats",
    "valplatser": "valplats",
    "valplatserna": "valplats",
    "valplatsernas": "valplats",
    "valplatsers": "valplats",
    "valpropagandan": "valpropaganda",
    "valpropagandans": "valpropaganda",
    "valpropagandas": "valpropaganda",
    "valpropagandor": "valpropaganda",
    "valpropagandorna": "valpropaganda",
    "valpropagandornas": "valpropaganda",
    "valpropagandors": "valpropaganda",
    "valps": "valp",
    "valpsjukan": "valpsjuka",
    "valpsjukans": "valpsjuka",
    "valpsjukas": "valpsjuka",
    "valpsjuke": "valpsjuka",
    "valpsjuks": "valpsjuka",
    "valraven": "valrav",
    "valravens": "valrav",
    "valravs": "valrav",
    "valresultaten": "valresultat",
    "valresultatens": "valresultat",
    "valresultatet": "valresultat",
    "valresultatets": "valresultat",
    "valresultats": "valresultat",
    "valriken": "valrike",
    "valrikena": "valrike",
    "valrikenas": "valrike",
    "valrikens": "valrike",
    "valrikes": "valrike",
    "valriket": "valrike",
    "valrikets": "valrike",
    "valrossar": "valross",
    "valrossarna": "valross",
    "valrossarnas": "valross",
    "valrossars": "valross",
    "valrossen": "valross",
    "valrossens": "valross",
    "valrossmustaschen": "valrossmustasch",
    "valrossmustaschens": "valrossmustasch",
    "valrossmustascher": "valrossmustasch",
    "valrossmustascherna": "valrossmustasch",
    "valrossmustaschernas": "valrossmustasch",
    "valrossmustaschers": "valrossmustasch",
    "valrossmustaschs": "valrossmustasch",
    "valrätten": "valrätt",
    "valrättens": "valrätt",
    "valrätts": "valrätt",
    "valrörelsen": "valrörelse",
    "valrörelsens": "valrörelse",
    "valrörelser": "valrörelse",
    "valrörelserna": "valrörelse",
    "valrörelsernas": "valrörelse",
    "valrörelsers": "valrörelse",
    "valrörelses": "valrörelse",
    "vals": "valsa",
    "valsad": "valsa",
    "valsade": "valsa",
    "valsades": "valsa",
    "valsads": "valsa",
    "valsande": "valsa",
    "valsanden": "valsande",
    "valsandena": "valsande",
    "valsandenas": "valsande",
    "valsandens": "valsande",
    "valsandes": "valsande",
    "valsandet": "valsande",
    "valsandets": "valsande",
    "valsar": "valsa",
    "valsarna": "vals",
    "valsarnas": "vals",
    "valsars": "vals",
    "valsas": "valsa",
    "valsat": "valsa",
    "valsats": "valsa",
    "valsedeln": "valsedel",
    "valsedelns": "valsedel",
    "valsedels": "valsedel",
    "valsedlar": "valsedel",
    "valsedlarna": "valsedel",
    "valsedlarnas": "valsedel",
    "valsedlars": "valsedel",
    "valsegern": "valseger",
    "valsegerns": "valseger",
    "valsegers": "valseger",
    "valsegrar": "valseger",
    "valsegrarna": "valseger",
    "valsegrarnas": "valseger",
    "valsegrars": "valseger",
    "valsen": "vals",
    "valsens": "vals",
    "valser": "vals",
    "valserna": "vals",
    "valsernas": "vals",
    "valsers": "vals",
    "valsituationen": "valsituation",
    "valsituationens": "valsituation",
    "valsituationer": "valsituation",
    "valsituationerna": "valsituation",
    "valsituationernas": "valsituation",
    "valsituationers": "valsituation",
    "valsituations": "valsituation",
    "valsjärnet": "valsjärn",
    "valsjärnets": "valsjärn",
    "valsjärns": "valsjärn",
    "valskärmar": "valskärm",
    "valskärmarna": "valskärm",
    "valskärmarnas": "valskärm",
    "valskärmars": "valskärm",
    "valskärmen": "valskärm",
    "valskärmens": "valskärm",
    "valskärms": "valskärm",
    "valspråken": "valspråk",
    "valspråkens": "valspråk",
    "valspråket": "valspråk",
    "valspråkets": "valspråk",
    "valspråks": "valspråk",
    "valspurten": "valspurt",
    "valspurtens": "valspurt",
    "valspurter": "valspurt",
    "valspurterna": "valspurt",
    "valspurternas": "valspurt",
    "valspurters": "valspurt",
    "valspurts": "valspurt",
    "valstrategien": "valstrategi",
    "valstrategiens": "valstrategi",
    "valstrategier": "valstrategi",
    "valstrategierna": "valstrategi",
    "valstrategiernas": "valstrategi",
    "valstrategiers": "valstrategi",
    "valstrategin": "valstrategi",
    "valstrategins": "valstrategi",
    "valstrategis": "valstrategi",
    "valstugan": "valstuga",
    "valstugans": "valstuga",
    "valstugas": "valstuga",
    "valstuge": "valstuga",
    "valstugeaffären": "valstugeaffär",
    "valstugeaffärens": "valstugeaffär",
    "valstugeaffärer": "valstugeaffär",
    "valstugeaffärerna": "valstugeaffär",
    "valstugeaffärernas": "valstugeaffär",
    "valstugeaffärers": "valstugeaffär",
    "valstugeaffärs": "valstugeaffär",
    "valstugeaktivisten": "valstugeaktivist",
    "valstugeaktivistens": "valstugeaktivist",
    "valstugeaktivister": "valstugeaktivist",
    "valstugeaktivisterna": "valstugeaktivist",
    "valstugeaktivisternas": "valstugeaktivist",
    "valstugeaktivisters": "valstugeaktivist",
    "valstugeaktivists": "valstugeaktivist",
    "valstugeavslöjanden": "valstugeavslöjande",
    "valstugeavslöjandena": "valstugeavslöjande",
    "valstugeavslöjandenas": "valstugeavslöjande",
    "valstugeavslöjandens": "valstugeavslöjande",
    "valstugeavslöjandes": "valstugeavslöjande",
    "valstugeavslöjandet": "valstugeavslöjande",
    "valstugeavslöjandets": "valstugeavslöjande",
    "valstugor": "valstuga",
    "valstugorna": "valstuga",
    "valstugornas": "valstuga",
    "valstugors": "valstuga",
    "valstugu": "valstuga",
    "valsverken": "valsverk",
    "valsverkens": "valsverk",
    "valsverket": "valsverk",
    "valsverkets": "valsverk",
    "valsverks": "valsverk",
    "valsätten": "valsätt",
    "valsättens": "valsätt",
    "valsättet": "valsätt",
    "valsättets": "valsätt",
    "valsätts": "valsätt",
    "valsören": "valsör",
    "valsörens": "valsör",
    "valsörer": "valsör",
    "valsörerna": "valsör",
    "valsörernas": "valsör",
    "valsörers": "valsör",
    "valsörs": "valsör",
    "valt": "välja",
    "valthornen": "valthorn",
    "valthornens": "valthorn",
    "valthornet": "valthorn",
    "valthornets": "valthorn",
    "valthorns": "valthorn",
    "valtranen": "valtran",
    "valtranens": "valtran",
    "valtrans": "valtran",
    "valts": "välja",
    "valurn": "valurna",
    "valurnan": "valurna",
    "valurnans": "valurna",
    "valurnas": "valurna",
    "valurne": "valurna",
    "valurnor": "valurna",
    "valurnorna": "valurna",
    "valurnornas": "valurna",
    "valurnors": "valurna",
    "valurns": "valurna",
    "valutaaffären": "valutaaffär",
    "valutaaffärens": "valutaaffär",
    "valutaaffärer": "valutaaffär",
    "valutaaffärerna": "valutaaffär",
    "valutaaffärernas": "valutaaffär",
    "valutaaffärers": "valutaaffär",
    "valutaaffärs": "valutaaffär",
    "valutabrotten": "valutabrott",
    "valutabrottens": "valutabrott",
    "valutabrottet": "valutabrott",
    "valutabrottets": "valutabrott",
    "valutabrotts": "valutabrott",
    "valutafonden": "valutafond",
    "valutafondens": "valutafond",
    "valutafonder": "valutafond",
    "valutafonderna": "valutafond",
    "valutafondernas": "valutafond",
    "valutafonders": "valutafond",
    "valutafonds": "valutafond",
    "valutahandeln": "valutahandel",
    "valutahandelns": "valutahandel",
    "valutahandels": "valutahandel",
    "valutaklausulen": "valutaklausul",
    "valutaklausulens": "valutaklausul",
    "valutaklausuler": "valutaklausul",
    "valutaklausulerna": "valutaklausul",
    "valutaklausulernas": "valutaklausul",
    "valutaklausulers": "valutaklausul",
    "valutaklausuls": "valutaklausul",
    "valutakursen": "valutakurs",
    "valutakursens": "valutakurs",
    "valutakurser": "valutakurs",
    "valutakurserna": "valutakurs",
    "valutakursernas": "valutakurs",
    "valutakursers": "valutakurs",
    "valutamässiga": "valutamässig",
    "valutamässigare": "valutamässig",
    "valutamässigares": "valutamässig",
    "valutamässigas": "valutamässig",
    "valutamässigast": "valutamässig",
    "valutamässigaste": "valutamässig",
    "valutamässigastes": "valutamässig",
    "valutamässigasts": "valutamässig",
    "valutamässige": "valutamässig",
    "valutamässiges": "valutamässig",
    "valutamässigs": "valutamässig",
    "valutamässigt": "valutamässig",
    "valutamässigts": "valutamässig",
    "valutan": "valuta",
    "valutans": "valuta",
    "valutapolitiken": "valutapolitik",
    "valutapolitikens": "valutapolitik",
    "valutapolitiks": "valutapolitik",
    "valutapolitiska": "valutapolitisk",
    "valutapolitiskas": "valutapolitisk",
    "valutapolitiske": "valutapolitisk",
    "valutapolitiskes": "valutapolitisk",
    "valutapolitisks": "valutapolitisk",
    "valutapolitiskt": "valutapolitisk",
    "valutapolitiskts": "valutapolitisk",
    "valutaregleringar": "valutareglering",
    "valutaregleringarna": "valutareglering",
    "valutaregleringarnas": "valutareglering",
    "valutaregleringars": "valutareglering",
    "valutaregleringen": "valutareglering",
    "valutaregleringens": "valutareglering",
    "valutareglerings": "valutareglering",
    "valutareserven": "valutareserv",
    "valutareservens": "valutareserv",
    "valutareserver": "valutareserv",
    "valutareserverna": "valutareserv",
    "valutareservernas": "valutareserv",
    "valutareservers": "valutareserv",
    "valutareservs": "valutareserv",
    "valutarestriktionerna": "valutarestriktioner",
    "valutarestriktionernas": "valutarestriktioner",
    "valutarestriktioners": "valutarestriktioner",
    "valutarestriktions": "valutarestriktioner",
    "valutas": "valuta",
    "valutasvinen": "valutasvin",
    "valutasvinens": "valutasvin",
    "valutasvinet": "valutasvin",
    "valutasvinets": "valutasvin",
    "valutasvins": "valutasvin",
    "valutaunionen": "valutaunion",
    "valutaunionens": "valutaunion",
    "valutaunioner": "valutaunion",
    "valutaunionerna": "valutaunion",
    "valutaunionernas": "valutaunion",
    "valutaunioners": "valutaunion",
    "valutaunions": "valutaunion",
    "valute": "valuta",
    "valuterad": "valutera",
    "valuterade": "valutera",
    "valuterades": "valutera",
    "valuterads": "valutera",
    "valuterande": "valutera",
    "valuteranden": "valuterande",
    "valuterandena": "valuterande",
    "valuterandenas": "valuterande",
    "valuterandens": "valuterande",
    "valuterandes": "valuterande",
    "valuterandet": "valuterande",
    "valuterandets": "valuterande",
    "valuterar": "valutera",
    "valuteras": "valutera",
    "valuterat": "valutera",
    "valuterats": "valutera",
    "valuterbara": "valuterbar",
    "valuterbarare": "valuterbar",
    "valuterbarares": "valuterbar",
    "valuterbaras": "valuterbar",
    "valuterbarast": "valuterbar",
    "valuterbaraste": "valuterbar",
    "valuterbarastes": "valuterbar",
    "valuterbarasts": "valuterbar",
    "valuterbare": "valuterbar",
    "valuterbares": "valuterbar",
    "valuterbarheten": "valuterbarhet",
    "valuterbarhetens": "valuterbarhet",
    "valuterbarhets": "valuterbarhet",
    "valuterbars": "valuterbar",
    "valuterbart": "valuterbar",
    "valuterbarts": "valuterbar",
    "valuteringar": "valutering",
    "valuteringarna": "valutering",
    "valuteringarnas": "valutering",
    "valuteringars": "valutering",
    "valuteringen": "valutering",
    "valuteringens": "valutering",
    "valuterings": "valutering",
    "valutgångar": "valutgång",
    "valutgångarna": "valutgång",
    "valutgångarnas": "valutgång",
    "valutgångars": "valutgång",
    "valutgången": "valutgång",
    "valutgångens": "valutgång",
    "valutgångs": "valutgång",
    "valutor": "valuta",
    "valutorna": "valuta",
    "valutornas": "valuta",
    "valutors": "valuta",
    "valvbåg": "valvbåge",
    "valvbågar": "valvbåge",
    "valvbågarna": "valvbåge",
    "valvbågarnas": "valvbåge",
    "valvbågars": "valvbåge",
    "valvbågen": "valvbåge",
    "valvbågens": "valvbåge",
    "valvbåges": "valvbåge",
    "valvbågs": "valvbåge",
    "valveln": "valvel",
    "valvelns": "valvel",
    "valvels": "valvel",
    "valven": "valv",
    "valvens": "valv",
    "valverad": "valvera",
    "valverade": "valvera",
    "valverades": "valvera",
    "valverads": "valvera",
    "valverande": "valvera",
    "valveranden": "valverande",
    "valverandena": "valverande",
    "valverandenas": "valverande",
    "valverandens": "valverande",
    "valverandes": "valverande",
    "valverandet": "valverande",
    "valverandets": "valverande",
    "valverar": "valvera",
    "valveras": "valvera",
    "valverat": "valvera",
    "valverats": "valvera",
    "valverbara": "valverbar",
    "valverbarare": "valverbar",
    "valverbarares": "valverbar",
    "valverbaras": "valverbar",
    "valverbarast": "valverbar",
    "valverbaraste": "valverbar",
    "valverbarastes": "valverbar",
    "valverbarasts": "valverbar",
    "valverbare": "valverbar",
    "valverbares": "valverbar",
    "valverbarheten": "valverbarhet",
    "valverbarhetens": "valverbarhet",
    "valverbarhets": "valverbarhet",
    "valverbars": "valverbar",
    "valverbart": "valverbar",
    "valverbarts": "valverbar",
    "valveringar": "valvering",
    "valveringarna": "valvering",
    "valveringarnas": "valvering",
    "valveringars": "valvering",
    "valveringen": "valvering",
    "valveringens": "valvering",
    "valverings": "valvering",
    "valvet": "valv",
    "valvets": "valv",
    "valvler": "valvel",
    "valvlerna": "valvel",
    "valvlernas": "valvel",
    "valvlers": "valvel",
    "valvportar": "valvport",
    "valvportarna": "valvport",
    "valvportarnas": "valvport",
    "valvportars": "valvport",
    "valvporten": "valvport",
    "valvportens": "valvport",
    "valvports": "valvport",
    "valvs": "valv",
    "valvslagningar": "valvslagning",
    "valvslagningarna": "valvslagning",
    "valvslagningarnas": "valvslagning",
    "valvslagningars": "valvslagning",
    "valvslagningen": "valvslagning",
    "valvslagningens": "valvslagning",
    "valvslagnings": "valvslagning",
    "valvstupståendes": "valvstupstående",
    "valvstupståendet": "valvstupstående",
    "valvstupståendets": "valvstupstående",
    "valören": "valör",
    "valörens": "valör",
    "valörer": "valör",
    "valörerna": "valör",
    "valörernas": "valör",
    "valörers": "valör",
    "valörmåleriet": "valörmåleri",
    "valörmåleriets": "valörmåleri",
    "valörmåleris": "valörmåleri",
    "valörmålerit": "valörmåleri",
    "valörmålerits": "valörmåleri",
    "valörs": "valör",
    "valörtrycket": "valörtryck",
    "valörtryckets": "valörtryck",
    "valörtrycks": "valörtryck",
    "vamp": "vampa",
    "vampad": "vampa",
    "vampade": "vampa",
    "vampades": "vampa",
    "vampads": "vampa",
    "vampande": "vampa",
    "vampanden": "vampande",
    "vampandena": "vampande",
    "vampandenas": "vampande",
    "vampandens": "vampande",
    "vampandes": "vampande",
    "vampandet": "vampande",
    "vampandets": "vampande",
    "vampar": "vampa",
    "vamparna": "vamp",
    "vamparnas": "vamp",
    "vampars": "vamp",
    "vampas": "vampa",
    "vampat": "vampa",
    "vampats": "vampa",
    "vampen": "vamp",
    "vampens": "vamp",
    "vamper": "vamp",
    "vamperna": "vamp",
    "vampernas": "vamp",
    "vampers": "vamp",
    "vampiga": "vampig",
    "vampigare": "vampig",
    "vampigares": "vampig",
    "vampigas": "vampig",
    "vampigast": "vampig",
    "vampigaste": "vampig",
    "vampigastes": "vampig",
    "vampigasts": "vampig",
    "vampige": "vampig",
    "vampiges": "vampig",
    "vampigheten": "vampighet",
    "vampighetens": "vampighet",
    "vampighets": "vampighet",
    "vampigs": "vampig",
    "vampigt": "vampig",
    "vampigts": "vampig",
    "vamps": "vamp",
    "vampyren": "vampyr",
    "vampyrens": "vampyr",
    "vampyrer": "vampyr",
    "vampyrerna": "vampyr",
    "vampyrernas": "vampyr",
    "vampyrers": "vampyr",
    "vampyrromanen": "vampyrroman",
    "vampyrromanens": "vampyrroman",
    "vampyrromaner": "vampyrroman",
    "vampyrromanerna": "vampyrroman",
    "vampyrromanernas": "vampyrroman",
    "vampyrromaners": "vampyrroman",
    "vampyrromans": "vampyrroman",
    "vampyrs": "vampyr",
    "vana": "van",
    "vanadinen": "vanadin",
    "vanadinens": "vanadin",
    "vanadinet": "vanadin",
    "vanadinets": "vanadin",
    "vanadins": "vanadin",
    "vanadinskaften": "vanadinskaft",
    "vanadinskaftens": "vanadinskaft",
    "vanadinskaftet": "vanadinskaft",
    "vanadinskaftets": "vanadinskaft",
    "vanadinskafts": "vanadinskaft",
    "vanadinstålen": "vanadinstål",
    "vanadinstålens": "vanadinstål",
    "vanadinstålet": "vanadinstål",
    "vanadinstålets": "vanadinstål",
    "vanadinståls": "vanadinstål",
    "vanan": "vana",
    "vanans": "vana",
    "vanare": "van",
    "vanares": "van",
    "vanartade": "vanartad",
    "vanartades": "vanartas",
    "vanartads": "vanartad",
    "vanartat": "vanartad",
    "vanartats": "vanartas",
    "vanartiga": "vanartig",
    "vanartigare": "vanartig",
    "vanartigares": "vanartig",
    "vanartigas": "vanartig",
    "vanartigast": "vanartig",
    "vanartigaste": "vanartig",
    "vanartigastes": "vanartig",
    "vanartigasts": "vanartig",
    "vanartige": "vanartig",
    "vanartiges": "vanartig",
    "vanartigheten": "vanartighet",
    "vanartighetens": "vanartighet",
    "vanartighets": "vanartighet",
    "vanartigs": "vanartig",
    "vanartigt": "vanartig",
    "vanartigts": "vanartig",
    "vanas": "vana",
    "vanast": "van",
    "vanaste": "van",
    "vanastes": "van",
    "vanasts": "van",
    "vand": "vänja",
    "vanda": "vänja",
    "vandalen": "vandal",
    "vandalens": "vandal",
    "vandaler": "vandal",
    "vandalerna": "vandal",
    "vandalernas": "vandal",
    "vandalers": "vandal",
    "vandaliserad": "vandalisera",
    "vandaliserade": "vandalisera",
    "vandaliserades": "vandalisera",
    "vandaliserads": "vandalisera",
    "vandaliserande": "vandalisera",
    "vandaliseranden": "vandaliserande",
    "vandaliserandena": "vandaliserande",
    "vandaliserandenas": "vandaliserande",
    "vandaliserandens": "vandaliserande",
    "vandaliserandes": "vandaliserande",
    "vandaliserandet": "vandaliserande",
    "vandaliserandets": "vandaliserande",
    "vandaliserar": "vandalisera",
    "vandaliseras": "vandalisera",
    "vandaliserat": "vandalisera",
    "vandaliserats": "vandalisera",
    "vandaliserbara": "vandaliserbar",
    "vandaliserbarare": "vandaliserbar",
    "vandaliserbarares": "vandaliserbar",
    "vandaliserbaras": "vandaliserbar",
    "vandaliserbarast": "vandaliserbar",
    "vandaliserbaraste": "vandaliserbar",
    "vandaliserbarastes": "vandaliserbar",
    "vandaliserbarasts": "vandaliserbar",
    "vandaliserbare": "vandaliserbar",
    "vandaliserbares": "vandaliserbar",
    "vandaliserbarheten": "vandaliserbarhet",
    "vandaliserbarhetens": "vandaliserbarhet",
    "vandaliserbarhets": "vandaliserbarhet",
    "vandaliserbars": "vandaliserbar",
    "vandaliserbart": "vandaliserbar",
    "vandaliserbarts": "vandaliserbar",
    "vandaliseringar": "vandalisering",
    "vandaliseringarna": "vandalisering",
    "vandaliseringarnas": "vandalisering",
    "vandaliseringars": "vandalisering",
    "vandaliseringen": "vandalisering",
    "vandaliseringens": "vandalisering",
    "vandaliserings": "vandalisering",
    "vandaliska": "vandalisk",
    "vandaliskare": "vandalisk",
    "vandaliskares": "vandalisk",
    "vandaliskas": "vandalisk",
    "vandaliskast": "vandalisk",
    "vandaliskaste": "vandalisk",
    "vandaliskastes": "vandalisk",
    "vandaliskasts": "vandalisk",
    "vandaliske": "vandalisk",
    "vandaliskes": "vandalisk",
    "vandalisks": "vandalisk",
    "vandaliskt": "vandalisk",
    "vandaliskts": "vandalisk",
    "vandalismen": "vandalism",
    "vandalismens": "vandalism",
    "vandalismer": "vandalism",
    "vandalismerna": "vandalism",
    "vandalismernas": "vandalism",
    "vandalismers": "vandalism",
    "vandalisms": "vandalism",
    "vandals": "vandal",
    "vandas": "vänja",
    "vande": "vänja",
    "vandeln": "vandel",
    "vandelns": "vandel",
    "vandels": "vandel",
    "vandes": "vänja",
    "vandrad": "vandra",
    "vandrade": "vandra",
    "vandrades": "vandra",
    "vandrads": "vandra",
    "vandrande": "vandra",
    "vandranden": "vandrande",
    "vandrandena": "vandrande",
    "vandrandenas": "vandrande",
    "vandrandens": "vandrande",
    "vandrandes": "vandrande",
    "vandrandet": "vandrande",
    "vandrandets": "vandrande",
    "vandrar": "vandrare",
    "vandrarcellen": "vandrarcell",
    "vandrarcellens": "vandrarcell",
    "vandrarceller": "vandrarcell",
    "vandrarcellerna": "vandrarcell",
    "vandrarcellernas": "vandrarcell",
    "vandrarcellers": "vandrarcell",
    "vandrarcells": "vandrarcell",
    "vandraren": "vandrare",
    "vandrarens": "vandrare",
    "vandrares": "vandrare",
    "vandrarfolken": "vandrarfolk",
    "vandrarfolkens": "vandrarfolk",
    "vandrarfolket": "vandrarfolk",
    "vandrarfolkets": "vandrarfolk",
    "vandrarfolks": "vandrarfolk",
    "vandrarhemmen": "vandrarhem",
    "vandrarhemmens": "vandrarhem",
    "vandrarhemmet": "vandrarhem",
    "vandrarhemmets": "vandrarhem",
    "vandrarhems": "vandrarhem",
    "vandrarkäng": "vandrarkänga",
    "vandrarkängan": "vandrarkänga",
    "vandrarkängans": "vandrarkänga",
    "vandrarkängas": "vandrarkänga",
    "vandrarkänge": "vandrarkänga",
    "vandrarkängor": "vandrarkänga",
    "vandrarkängorna": "vandrarkänga",
    "vandrarkängornas": "vandrarkänga",
    "vandrarkängors": "vandrarkänga",
    "vandrarkängs": "vandrarkänga",
    "vandrarna": "vandrare",
    "vandrarnas": "vandrare",
    "vandras": "vandra",
    "vandrat": "vandra",
    "vandrats": "vandra",
    "vandringar": "vandring",
    "vandringarna": "vandring",
    "vandringarnas": "vandring",
    "vandringars": "vandring",
    "vandringen": "vandring",
    "vandringens": "vandring",
    "vandrings": "vandring",
    "vandringscellen": "vandringscell",
    "vandringscellens": "vandringscell",
    "vandringsceller": "vandringscell",
    "vandringscellerna": "vandringscell",
    "vandringscellernas": "vandringscell",
    "vandringscellers": "vandringscell",
    "vandringscells": "vandringscell",
    "vandringsfiskar": "vandringsfisk",
    "vandringsfiskarna": "vandringsfisk",
    "vandringsfiskarnas": "vandringsfisk",
    "vandringsfiskars": "vandringsfisk",
    "vandringsfisken": "vandringsfisk",
    "vandringsfiskens": "vandringsfisk",
    "vandringsfisks": "vandringsfisk",
    "vandringsfolken": "vandringsfolk",
    "vandringsfolkens": "vandringsfolk",
    "vandringsfolket": "vandringsfolk",
    "vandringsfolkets": "vandringsfolk",
    "vandringsfolks": "vandringsfolk",
    "vandringsleden": "vandringsled",
    "vandringsledens": "vandringsled",
    "vandringsleder": "vandringsled",
    "vandringslederna": "vandringsled",
    "vandringsledernas": "vandringsled",
    "vandringsleders": "vandringsled",
    "vandringsleds": "vandringsled",
    "vandringslusten": "vandringslust",
    "vandringslustens": "vandringslust",
    "vandringslusts": "vandringslust",
    "vandringsmannen": "vandringsman",
    "vandringsmannens": "vandringsman",
    "vandringsmans": "vandringsman",
    "vandringsmän": "vandringsman",
    "vandringsmännen": "vandringsman",
    "vandringsmännens": "vandringsman",
    "vandringsmäns": "vandringsman",
    "vandringspokalen": "vandringspokal",
    "vandringspokalens": "vandringspokal",
    "vandringspokaler": "vandringspokal",
    "vandringspokalerna": "vandringspokal",
    "vandringspokalernas": "vandringspokal",
    "vandringspokalers": "vandringspokal",
    "vandringspokals": "vandringspokal",
    "vandringsprisen": "vandringspris",
    "vandringsprisens": "vandringspris",
    "vandringspriser": "vandringspris",
    "vandringspriserna": "vandringspris",
    "vandringsprisernas": "vandringspris",
    "vandringsprisers": "vandringspris",
    "vandringspriset": "vandringspris",
    "vandringsprisets": "vandringspris",
    "vandringsutställningar": "vandringsutställning",
    "vandringsutställningarna": "vandringsutställning",
    "vandringsutställningarnas": "vandringsutställning",
    "vandringsutställningars": "vandringsutställning",
    "vandringsutställningen": "vandringsutställning",
    "vandringsutställningens": "vandringsutställning",
    "vandringsutställnings": "vandringsutställning",
    "vandringsvågrören": "vandringsvågrör",
    "vandringsvågrörens": "vandringsvågrör",
    "vandringsvågröret": "vandringsvågrör",
    "vandringsvågrörets": "vandringsvågrör",
    "vandringsvågrörs": "vandringsvågrör",
    "vandringsåren": "vandringsår",
    "vandringsårens": "vandringsår",
    "vandringsåret": "vandringsår",
    "vandringsårets": "vandringsår",
    "vandringsårs": "vandringsår",
    "vands": "vänja",
    "vane": "vana",
    "vanebildningar": "vanebildning",
    "vanebildningarna": "vanebildning",
    "vanebildningarnas": "vanebildning",
    "vanebildningars": "vanebildning",
    "vanebildningen": "vanebildning",
    "vanebildningens": "vanebildning",
    "vanebildnings": "vanebildning",
    "vanedjuren": "vanedjur",
    "vanedjurens": "vanedjur",
    "vanedjuret": "vanedjur",
    "vanedjurets": "vanedjur",
    "vanedjurs": "vanedjur",
    "vanedrinkar": "vanedrinkare",
    "vanedrinkaren": "vanedrinkare",
    "vanedrinkarens": "vanedrinkare",
    "vanedrinkares": "vanedrinkare",
    "vanedrinkarna": "vanedrinkare",
    "vanedrinkarnas": "vanedrinkare",
    "vanekristens": "vanekristen",
    "vanekristet": "vanekristen",
    "vanekristets": "vanekristen",
    "vanekristna": "vanekristen",
    "vanekristnare": "vanekristen",
    "vanekristnares": "vanekristen",
    "vanekristnas": "vanekristen",
    "vanekristnast": "vanekristen",
    "vanekristnaste": "vanekristen",
    "vanekristnastes": "vanekristen",
    "vanekristnasts": "vanekristen",
    "vanekristne": "vanekristen",
    "vanekristnes": "vanekristen",
    "vanemänniskan": "vanemänniska",
    "vanemänniskans": "vanemänniska",
    "vanemänniskas": "vanemänniska",
    "vanemännisko": "vanemänniska",
    "vanemänniskor": "vanemänniska",
    "vanemänniskorna": "vanemänniska",
    "vanemänniskornas": "vanemänniska",
    "vanemänniskors": "vanemänniska",
    "vanemässiga": "vanemässig",
    "vanemässigare": "vanemässig",
    "vanemässigares": "vanemässig",
    "vanemässigas": "vanemässig",
    "vanemässigast": "vanemässig",
    "vanemässigaste": "vanemässig",
    "vanemässigastes": "vanemässig",
    "vanemässigasts": "vanemässig",
    "vanemässige": "vanemässig",
    "vanemässiges": "vanemässig",
    "vanemässigheten": "vanemässighet",
    "vanemässighetens": "vanemässighet",
    "vanemässighets": "vanemässighet",
    "vanemässigs": "vanemässig",
    "vanemässigt": "vanemässig",
    "vanemässigts": "vanemässig",
    "vanen": "van",
    "vanens": "van",
    "vaner": "van",
    "vanerna": "van",
    "vanernas": "van",
    "vaners": "van",
    "vanes": "van",
    "vanesaken": "vanesak",
    "vanesakens": "vanesak",
    "vanesaker": "vanesak",
    "vanesakerna": "vanesak",
    "vanesakernas": "vanesak",
    "vanesakers": "vanesak",
    "vanesaks": "vanesak",
    "vanetänkandes": "vanetänkande",
    "vanetänkandet": "vanetänkande",
    "vanetänkandets": "vanetänkande",
    "vanfrejden": "vanfrejd",
    "vanfrejdens": "vanfrejd",
    "vanfrejds": "vanfrejd",
    "vanföra": "vanför",
    "vanförare": "vanför",
    "vanförares": "vanför",
    "vanföras": "vanför",
    "vanförast": "vanför",
    "vanföraste": "vanför",
    "vanförastes": "vanför",
    "vanförasts": "vanför",
    "vanföre": "vanför",
    "vanföres": "vanför",
    "vanföreställningar": "vanföreställning",
    "vanföreställningarna": "vanföreställning",
    "vanföreställningarnas": "vanföreställning",
    "vanföreställningars": "vanföreställning",
    "vanföreställningen": "vanföreställning",
    "vanföreställningens": "vanföreställning",
    "vanföreställnings": "vanföreställning",
    "vanförheten": "vanförhet",
    "vanförhetens": "vanförhet",
    "vanförheter": "vanförhet",
    "vanförheterna": "vanförhet",
    "vanförheternas": "vanförhet",
    "vanförheters": "vanförhet",
    "vanförhets": "vanförhet",
    "vanförs": "vanför",
    "vanfört": "vanför",
    "vanförts": "vanför",
    "vanhederliga": "vanhederlig",
    "vanhederligare": "vanhederlig",
    "vanhederligares": "vanhederlig",
    "vanhederligas": "vanhederlig",
    "vanhederligast": "vanhederlig",
    "vanhederligaste": "vanhederlig",
    "vanhederligastes": "vanhederlig",
    "vanhederligasts": "vanhederlig",
    "vanhederlige": "vanhederlig",
    "vanhederliges": "vanhederlig",
    "vanhederligheten": "vanhederlighet",
    "vanhederlighetens": "vanhederlighet",
    "vanhederlighets": "vanhederlighet",
    "vanhederligs": "vanhederlig",
    "vanhederligt": "vanhederlig",
    "vanhederligts": "vanhederlig",
    "vanhedern": "vanheder",
    "vanhederns": "vanheder",
    "vanheders": "vanheder",
    "vanhedrad": "vanhedra",
    "vanhedrade": "vanhedra",
    "vanhedrades": "vanhedra",
    "vanhedrads": "vanhedra",
    "vanhedrande": "vanhedra",
    "vanhedranden": "vanhedrande",
    "vanhedrandena": "vanhedrande",
    "vanhedrandenas": "vanhedrande",
    "vanhedrandens": "vanhedrande",
    "vanhedrandes": "vanhedrande",
    "vanhedrandet": "vanhedrande",
    "vanhedrandets": "vanhedrande",
    "vanhedrar": "vanhedra",
    "vanhedras": "vanhedra",
    "vanhedrat": "vanhedra",
    "vanhedrats": "vanhedra",
    "vanhelgad": "vanhelga",
    "vanhelgade": "vanhelga",
    "vanhelgades": "vanhelga",
    "vanhelgads": "vanhelga",
    "vanhelgande": "vanhelga",
    "vanhelganden": "vanhelgande",
    "vanhelgandena": "vanhelgande",
    "vanhelgandenas": "vanhelgande",
    "vanhelgandens": "vanhelgande",
    "vanhelgandes": "vanhelgande",
    "vanhelgandet": "vanhelgande",
    "vanhelgandets": "vanhelgande",
    "vanhelgar": "vanhelga",
    "vanhelgas": "vanhelga",
    "vanhelgat": "vanhelga",
    "vanhelgats": "vanhelga",
    "vanhelgden": "vanhelgd",
    "vanhelgdens": "vanhelgd",
    "vanhelgds": "vanhelgd",
    "vanheten": "vanhet",
    "vanhetens": "vanhet",
    "vanhets": "vanhet",
    "vanhävden": "vanhävd",
    "vanhävdens": "vanhävd",
    "vanhävds": "vanhävd",
    "vaniljen": "vanilj",
    "vaniljens": "vanilj",
    "vaniljgiffeln": "vaniljgiffel",
    "vaniljgiffelns": "vaniljgiffel",
    "vaniljgiffels": "vaniljgiffel",
    "vaniljgifflar": "vaniljgiffel",
    "vaniljgifflarna": "vaniljgiffel",
    "vaniljgifflarnas": "vaniljgiffel",
    "vaniljgifflars": "vaniljgiffel",
    "vaniljs": "vanilj",
    "vaniljsockers": "vaniljsocker",
    "vaniljsockret": "vaniljsocker",
    "vaniljsockrets": "vaniljsocker",
    "vaniljvispen": "vaniljvisp",
    "vaniljvispens": "vaniljvisp",
    "vaniljvispet": "vaniljvisp",
    "vaniljvispets": "vaniljvisp",
    "vaniljvisps": "vaniljvisp",
    "vanillinen": "vanillin",
    "vanillinens": "vanillin",
    "vanilliner": "vanillin",
    "vanillinerna": "vanillin",
    "vanillinernas": "vanillin",
    "vanilliners": "vanillin",
    "vanillinet": "vanillin",
    "vanillinets": "vanillin",
    "vanillins": "vanillin",
    "vank": "vanka",
    "vankad": "vanka",
    "vankade": "vanka",
    "vankades": "vankas",
    "vankads": "vanka",
    "vankande": "vanka",
    "vankanden": "vankande",
    "vankandena": "vankande",
    "vankandenas": "vankande",
    "vankandens": "vankande",
    "vankandes": "vankande",
    "vankandet": "vankande",
    "vankandets": "vankande",
    "vankanten": "vankant",
    "vankantens": "vankant",
    "vankanter": "vankant",
    "vankanterna": "vankant",
    "vankanternas": "vankant",
    "vankanters": "vankant",
    "vankants": "vankant",
    "vankar": "vanka",
    "vankas": "vanka",
    "vankat": "vanka",
    "vankats": "vankas",
    "vankelmodet": "vankelmod",
    "vankelmodets": "vankelmod",
    "vankelmodiga": "vankelmodig",
    "vankelmodigare": "vankelmodig",
    "vankelmodigares": "vankelmodig",
    "vankelmodigas": "vankelmodig",
    "vankelmodigast": "vankelmodig",
    "vankelmodigaste": "vankelmodig",
    "vankelmodigastes": "vankelmodig",
    "vankelmodigasts": "vankelmodig",
    "vankelmodige": "vankelmodig",
    "vankelmodiges": "vankelmodig",
    "vankelmodigheten": "vankelmodighet",
    "vankelmodighetens": "vankelmodighet",
    "vankelmodighets": "vankelmodighet",
    "vankelmodigs": "vankelmodig",
    "vankelmodigt": "vankelmodig",
    "vankelmodigts": "vankelmodig",
    "vankelmods": "vankelmod",
    "vanks": "vank",
    "vanliga": "vanlig",
    "vanligare": "vanlig",
    "vanligares": "vanlig",
    "vanligas": "vanlig",
    "vanligast": "vanlig",
    "vanligaste": "vanlig",
    "vanligastes": "vanlig",
    "vanligasts": "vanlig",
    "vanlige": "vanlig",
    "vanliges": "vanlig",
    "vanligheten": "vanlighet",
    "vanlighetens": "vanlighet",
    "vanligheter": "vanlighet",
    "vanligheterna": "vanlighet",
    "vanligheternas": "vanlighet",
    "vanligheters": "vanlighet",
    "vanlighets": "vanlighet",
    "vanligs": "vanlig",
    "vanligt": "vanlig",
    "vanligts": "vanlig",
    "vanlottade": "vanlottad",
    "vanlottades": "vanlottad",
    "vanlottads": "vanlottad",
    "vanlottat": "vanlottad",
    "vanlottats": "vanlottad",
    "vanmakten": "vanmakt",
    "vanmaktens": "vanmakt",
    "vanmakts": "vanmakt",
    "vanmäktiga": "vanmäktig",
    "vanmäktigare": "vanmäktig",
    "vanmäktigares": "vanmäktig",
    "vanmäktigas": "vanmäktig",
    "vanmäktigast": "vanmäktig",
    "vanmäktigaste": "vanmäktig",
    "vanmäktigastes": "vanmäktig",
    "vanmäktigasts": "vanmäktig",
    "vanmäktige": "vanmäktig",
    "vanmäktiges": "vanmäktig",
    "vanmäktigheten": "vanmäktighet",
    "vanmäktighetens": "vanmäktighet",
    "vanmäktighets": "vanmäktighet",
    "vanmäktigs": "vanmäktig",
    "vanmäktigt": "vanmäktig",
    "vanmäktigts": "vanmäktig",
    "vann": "vinna",
    "vannad": "vanna",
    "vannade": "vanna",
    "vannades": "vanna",
    "vannads": "vanna",
    "vannan": "vanna",
    "vannande": "vanna",
    "vannanden": "vannande",
    "vannandena": "vannande",
    "vannandenas": "vannande",
    "vannandens": "vannande",
    "vannandes": "vannande",
    "vannandet": "vannande",
    "vannandets": "vannande",
    "vannans": "vanna",
    "vannar": "vanna",
    "vannas": "vanna",
    "vannat": "vanna",
    "vannats": "vanna",
    "vanne": "vanna",
    "vannor": "vanna",
    "vannorna": "vanna",
    "vannornas": "vanna",
    "vannors": "vanna",
    "vanns": "vinna",
    "vanor": "vana",
    "vanorna": "vana",
    "vanornas": "vana",
    "vanors": "vana",
    "vanpryd": "vanpryda",
    "vanprydande": "vanpryda",
    "vanprydanden": "vanprydande",
    "vanprydandena": "vanprydande",
    "vanprydandenas": "vanprydande",
    "vanprydandens": "vanprydande",
    "vanprydandes": "vanprydande",
    "vanprydandet": "vanprydande",
    "vanprydandets": "vanprydande",
    "vanprydas": "vanpryda",
    "vanprydd": "vanpryda",
    "vanprydda": "vanpryda",
    "vanpryddas": "vanpryda",
    "vanprydde": "vanpryda",
    "vanpryddes": "vanpryda",
    "vanprydds": "vanpryda",
    "vanpryder": "vanpryda",
    "vanprydes": "vanpryda",
    "vanpryds": "vanpryda",
    "vanprytt": "vanpryda",
    "vanprytts": "vanpryda",
    "vanryktes": "vanrykte",
    "vanryktet": "vanrykte",
    "vanryktets": "vanrykte",
    "vans": "van",
    "vansinnes": "vansinne",
    "vansinnesdåden": "vansinnesdåd",
    "vansinnesdådens": "vansinnesdåd",
    "vansinnesdådet": "vansinnesdåd",
    "vansinnesdådets": "vansinnesdåd",
    "vansinnesdåds": "vansinnesdåd",
    "vansinneskörningar": "vansinneskörning",
    "vansinneskörningarna": "vansinneskörning",
    "vansinneskörningarnas": "vansinneskörning",
    "vansinneskörningars": "vansinneskörning",
    "vansinneskörningen": "vansinneskörning",
    "vansinneskörningens": "vansinneskörning",
    "vansinneskörnings": "vansinneskörning",
    "vansinnet": "vansinne",
    "vansinnets": "vansinne",
    "vansinniga": "vansinnig",
    "vansinnigare": "vansinnig",
    "vansinnigares": "vansinnig",
    "vansinnigas": "vansinnig",
    "vansinnigast": "vansinnig",
    "vansinnigaste": "vansinnig",
    "vansinnigastes": "vansinnig",
    "vansinnigasts": "vansinnig",
    "vansinnige": "vansinnig",
    "vansinniges": "vansinnig",
    "vansinnigheten": "vansinnighet",
    "vansinnighetens": "vansinnighet",
    "vansinnigheter": "vansinnighet",
    "vansinnigheterna": "vansinnighet",
    "vansinnigheternas": "vansinnighet",
    "vansinnigheters": "vansinnighet",
    "vansinnighets": "vansinnighet",
    "vansinnigs": "vansinnig",
    "vansinnigt": "vansinnig",
    "vansinnigts": "vansinnig",
    "vanskapade": "vanskapad",
    "vanskapades": "vanskapad",
    "vanskapads": "vanskapad",
    "vanskapat": "vanskapad",
    "vanskapats": "vanskapad",
    "vanskapliga": "vanskaplig",
    "vanskapligare": "vanskaplig",
    "vanskapligares": "vanskaplig",
    "vanskapligas": "vanskaplig",
    "vanskapligast": "vanskaplig",
    "vanskapligaste": "vanskaplig",
    "vanskapligastes": "vanskaplig",
    "vanskapligasts": "vanskaplig",
    "vanskaplige": "vanskaplig",
    "vanskapliges": "vanskaplig",
    "vanskapligheten": "vanskaplighet",
    "vanskaplighetens": "vanskaplighet",
    "vanskaplighets": "vanskaplighet",
    "vanskapligs": "vanskaplig",
    "vanskapligt": "vanskaplig",
    "vanskapligts": "vanskaplig",
    "vanskapnaden": "vanskapnad",
    "vanskapnadens": "vanskapnad",
    "vanskapnader": "vanskapnad",
    "vanskapnaderna": "vanskapnad",
    "vanskapnadernas": "vanskapnad",
    "vanskapnaders": "vanskapnad",
    "vanskapnads": "vanskapnad",
    "vanskapta": "vanskapt",
    "vanskaptare": "vanskapt",
    "vanskaptares": "vanskapt",
    "vanskaptas": "vanskapt",
    "vanskaptast": "vanskapt",
    "vanskaptaste": "vanskapt",
    "vanskaptastes": "vanskapt",
    "vanskaptasts": "vanskapt",
    "vanskapte": "vanskapt",
    "vanskaptes": "vanskapt",
    "vanskaptheten": "vanskapthet",
    "vanskapthetens": "vanskapthet",
    "vanskaptheter": "vanskapthet",
    "vanskaptheterna": "vanskapthet",
    "vanskaptheternas": "vanskapthet",
    "vanskaptheters": "vanskapthet",
    "vanskapthets": "vanskapthet",
    "vanskapts": "vanskapt",
    "vanskliga": "vansklig",
    "vanskligare": "vansklig",
    "vanskligares": "vansklig",
    "vanskligas": "vansklig",
    "vanskligast": "vansklig",
    "vanskligaste": "vansklig",
    "vanskligastes": "vansklig",
    "vanskligasts": "vansklig",
    "vansklige": "vansklig",
    "vanskliges": "vansklig",
    "vanskligheten": "vansklighet",
    "vansklighetens": "vansklighet",
    "vanskligheter": "vansklighet",
    "vanskligheterna": "vansklighet",
    "vanskligheternas": "vansklighet",
    "vanskligheters": "vansklighet",
    "vansklighets": "vansklighet",
    "vanskligs": "vansklig",
    "vanskligt": "vansklig",
    "vanskligts": "vansklig",
    "vansköt": "vansköta",
    "vanskötande": "vansköta",
    "vanskötanden": "vanskötande",
    "vanskötandena": "vanskötande",
    "vanskötandenas": "vanskötande",
    "vanskötandens": "vanskötande",
    "vanskötandes": "vanskötande",
    "vanskötandet": "vanskötande",
    "vanskötandets": "vanskötande",
    "vanskötas": "vansköta",
    "vansköter": "vansköta",
    "vanskötes": "vansköta",
    "vansköts": "vansköta",
    "vanskötseln": "vanskötsel",
    "vanskötselns": "vanskötsel",
    "vanskötsels": "vanskötsel",
    "vanskött": "vansköta",
    "vanskötta": "vansköta",
    "vansköttas": "vansköta",
    "vanskötte": "vansköta",
    "vansköttes": "vansköta",
    "vanskötts": "vansköta",
    "vansläktades": "vansläktas",
    "vansläktats": "vansläktas",
    "vanstarka": "vanstark",
    "vanstarkare": "vanstark",
    "vanstarkares": "vanstark",
    "vanstarkas": "vanstark",
    "vanstarkast": "vanstark",
    "vanstarkaste": "vanstark",
    "vanstarkastes": "vanstark",
    "vanstarkasts": "vanstark",
    "vanstarke": "vanstark",
    "vanstarkes": "vanstark",
    "vanstarkheten": "vanstarkhet",
    "vanstarkhetens": "vanstarkhet",
    "vanstarkhets": "vanstarkhet",
    "vanstarks": "vanstark",
    "vanstarkt": "vanstark",
    "vanstarkts": "vanstark",
    "vanstyr": "vanstyra",
    "vanstyrande": "vanstyra",
    "vanstyranden": "vanstyrande",
    "vanstyrandena": "vanstyrande",
    "vanstyrandenas": "vanstyrande",
    "vanstyrandens": "vanstyrande",
    "vanstyrandes": "vanstyrande",
    "vanstyrandet": "vanstyrande",
    "vanstyrandets": "vanstyrande",
    "vanstyras": "vanstyra",
    "vanstyrd": "vanstyra",
    "vanstyrda": "vanstyra",
    "vanstyrdas": "vanstyra",
    "vanstyrde": "vanstyra",
    "vanstyrdes": "vanstyra",
    "vanstyrds": "vanstyra",
    "vanstyren": "vanstyre",
    "vanstyrena": "vanstyre",
    "vanstyrenas": "vanstyre",
    "vanstyrens": "vanstyre",
    "vanstyres": "vanstyre",
    "vanstyret": "vanstyre",
    "vanstyrets": "vanstyre",
    "vanstyrs": "vanstyra",
    "vanstyrt": "vanstyra",
    "vanstyrts": "vanstyra",
    "vanställ": "vanställa",
    "vanställande": "vanställa",
    "vanställanden": "vanställande",
    "vanställandena": "vanställande",
    "vanställandenas": "vanställande",
    "vanställandens": "vanställande",
    "vanställandes": "vanställande",
    "vanställandet": "vanställande",
    "vanställandets": "vanställande",
    "vanställas": "vanställa",
    "vanställd": "vanställa",
    "vanställda": "vanställa",
    "vanställdas": "vanställa",
    "vanställde": "vanställa",
    "vanställdes": "vanställa",
    "vanställds": "vanställa",
    "vanställer": "vanställa",
    "vanställes": "vanställa",
    "vanställs": "vanställa",
    "vanställt": "vanställa",
    "vanställts": "vanställa",
    "vant": "vante",
    "vantar": "vante",
    "vantarna": "vante",
    "vantarnas": "vante",
    "vantars": "vante",
    "vanten": "vante",
    "vantens": "vante",
    "vanter": "vant",
    "vanterna": "vant",
    "vanternas": "vant",
    "vanters": "vant",
    "vantes": "vante",
    "vantet": "vant",
    "vantets": "vant",
    "vantolk": "vantolka",
    "vantolkad": "vantolka",
    "vantolkade": "vantolka",
    "vantolkades": "vantolka",
    "vantolkads": "vantolka",
    "vantolkande": "vantolka",
    "vantolkanden": "vantolkande",
    "vantolkandena": "vantolkande",
    "vantolkandenas": "vantolkande",
    "vantolkandens": "vantolkande",
    "vantolkandes": "vantolkande",
    "vantolkandet": "vantolkande",
    "vantolkandets": "vantolkande",
    "vantolkar": "vantolka",
    "vantolkas": "vantolka",
    "vantolkat": "vantolka",
    "vantolkats": "vantolka",
    "vantrivdes": "vantrivas",
    "vantrivs": "vantrivas",
    "vantrivseln": "vantrivsel",
    "vantrivselns": "vantrivsel",
    "vantrivsels": "vantrivsel",
    "vantrivts": "vantrivas",
    "vantrogens": "vantrogen",
    "vantroget": "vantrogen",
    "vantrogets": "vantrogen",
    "vantrogna": "vantrogen",
    "vantrognare": "vantrogen",
    "vantrognares": "vantrogen",
    "vantrognas": "vantrogen",
    "vantrognast": "vantrogen",
    "vantrognaste": "vantrogen",
    "vantrognastes": "vantrogen",
    "vantrognasts": "vantrogen",
    "vantrogne": "vantrogen",
    "vantrognes": "vantrogen",
    "vantron": "vantro",
    "vantrons": "vantro",
    "vantros": "vantro",
    "vants": "vante",
    "vantskruvar": "vantskruv",
    "vantskruvarna": "vantskruv",
    "vantskruvarnas": "vantskruv",
    "vantskruvars": "vantskruv",
    "vantskruven": "vantskruv",
    "vantskruvens": "vantskruv",
    "vantskruvs": "vantskruv",
    "vantspridar": "vantspridare",
    "vantspridaren": "vantspridare",
    "vantspridarens": "vantspridare",
    "vantspridares": "vantspridare",
    "vantspridarna": "vantspridare",
    "vantspridarnas": "vantspridare",
    "vanuatisk": "vanuatiska",
    "vanuatiska": "vanuatisk",
    "vanuatiskan": "vanuatiska",
    "vanuatiskans": "vanuatiska",
    "vanuatiskare": "vanuatisk",
    "vanuatiskares": "vanuatisk",
    "vanuatiskas": "vanuatiska",
    "vanuatiskast": "vanuatisk",
    "vanuatiskaste": "vanuatisk",
    "vanuatiskastes": "vanuatisk",
    "vanuatiskasts": "vanuatisk",
    "vanuatiske": "vanuatiska",
    "vanuatiskes": "vanuatisk",
    "vanuatiskor": "vanuatiska",
    "vanuatiskorna": "vanuatiska",
    "vanuatiskornas": "vanuatiska",
    "vanuatiskors": "vanuatiska",
    "vanuatisks": "vanuatisk",
    "vanuatiskt": "vanuatisk",
    "vanuatiskts": "vanuatisk",
    "vanuatuern": "vanuatuer",
    "vanuatuerna": "vanuatuer",
    "vanuatuernas": "vanuatuer",
    "vanuatuerns": "vanuatuer",
    "vanuatuers": "vanuatuer",
    "vanvettet": "vanvett",
    "vanvettets": "vanvett",
    "vanvettiga": "vanvettig",
    "vanvettigare": "vanvettig",
    "vanvettigares": "vanvettig",
    "vanvettigas": "vanvettig",
    "vanvettigast": "vanvettig",
    "vanvettigaste": "vanvettig",
    "vanvettigastes": "vanvettig",
    "vanvettigasts": "vanvettig",
    "vanvettige": "vanvettig",
    "vanvettiges": "vanvettig",
    "vanvettigheten": "vanvettighet",
    "vanvettighetens": "vanvettighet",
    "vanvettigheter": "vanvettighet",
    "vanvettigheterna": "vanvettighet",
    "vanvettigheternas": "vanvettighet",
    "vanvettigheters": "vanvettighet",
    "vanvettighets": "vanvettighet",
    "vanvettigs": "vanvettig",
    "vanvettigt": "vanvettig",
    "vanvettigts": "vanvettig",
    "vanvetts": "vanvett",
    "vanvård": "vanvårda",
    "vanvårdad": "vanvårda",
    "vanvårdade": "vanvårda",
    "vanvårdades": "vanvårda",
    "vanvårdads": "vanvårda",
    "vanvårdande": "vanvårda",
    "vanvårdanden": "vanvårdande",
    "vanvårdandena": "vanvårdande",
    "vanvårdandenas": "vanvårdande",
    "vanvårdandens": "vanvårdande",
    "vanvårdandes": "vanvårdande",
    "vanvårdandet": "vanvårdande",
    "vanvårdandets": "vanvårdande",
    "vanvårdar": "vanvårda",
    "vanvårdas": "vanvårda",
    "vanvårdat": "vanvårda",
    "vanvårdats": "vanvårda",
    "vanvården": "vanvård",
    "vanvårdens": "vanvård",
    "vanvårds": "vanvård",
    "vanvörd": "vanvörda",
    "vanvördad": "vanvörda",
    "vanvördade": "vanvörda",
    "vanvördades": "vanvörda",
    "vanvördads": "vanvörda",
    "vanvördande": "vanvörda",
    "vanvördanden": "vanvördande",
    "vanvördandena": "vanvördande",
    "vanvördandenas": "vanvördande",
    "vanvördandens": "vanvördande",
    "vanvördandes": "vanvördande",
    "vanvördandet": "vanvördande",
    "vanvördandets": "vanvördande",
    "vanvördar": "vanvörda",
    "vanvördas": "vanvörda",
    "vanvördat": "vanvörda",
    "vanvördats": "vanvörda",
    "vanvördiga": "vanvördig",
    "vanvördigare": "vanvördig",
    "vanvördigares": "vanvördig",
    "vanvördigas": "vanvördig",
    "vanvördigast": "vanvördig",
    "vanvördigaste": "vanvördig",
    "vanvördigastes": "vanvördig",
    "vanvördigasts": "vanvördig",
    "vanvördige": "vanvördig",
    "vanvördiges": "vanvördig",
    "vanvördigheten": "vanvördighet",
    "vanvördighetens": "vanvördighet",
    "vanvördighets": "vanvördighet",
    "vanvördigs": "vanvördig",
    "vanvördigt": "vanvördig",
    "vanvördigts": "vanvördig",
    "vanvördnaden": "vanvördnad",
    "vanvördnadens": "vanvördnad",
    "vanvördnader": "vanvördnad",
    "vanvördnaderna": "vanvördnad",
    "vanvördnadernas": "vanvördnad",
    "vanvördnaders": "vanvördnad",
    "vanvördnads": "vanvördnad",
    "vanär": "vanära",
    "vanärad": "vanära",
    "vanärade": "vanära",
    "vanärades": "vanära",
    "vanärads": "vanära",
    "vanäran": "vanära",
    "vanärande": "vanära",
    "vanäranden": "vanärande",
    "vanärandena": "vanärande",
    "vanärandenas": "vanärande",
    "vanärandens": "vanärande",
    "vanärandes": "vanärande",
    "vanärandet": "vanärande",
    "vanärandets": "vanärande",
    "vanärans": "vanära",
    "vanärar": "vanära",
    "vanäras": "vanära",
    "vanärat": "vanära",
    "vanärats": "vanära",
    "vapenarsenalen": "vapenarsenal",
    "vapenarsenalens": "vapenarsenal",
    "vapenarsenaler": "vapenarsenal",
    "vapenarsenalerna": "vapenarsenal",
    "vapenarsenalernas": "vapenarsenal",
    "vapenarsenalers": "vapenarsenal",
    "vapenarsenals": "vapenarsenal",
    "vapenboken": "vapenbok",
    "vapenbokens": "vapenbok",
    "vapenboks": "vapenbok",
    "vapenbraket": "vapenbrak",
    "vapenbrakets": "vapenbrak",
    "vapenbraks": "vapenbrak",
    "vapenbrodern": "vapenbroder",
    "vapenbroderns": "vapenbroder",
    "vapenbroders": "vapenbroder",
    "vapenbröder": "vapenbroder",
    "vapenbröderna": "vapenbroder",
    "vapenbrödernas": "vapenbroder",
    "vapenbröders": "vapenbroder",
    "vapenböcker": "vapenbok",
    "vapenböckerna": "vapenbok",
    "vapenböckernas": "vapenbok",
    "vapenböckers": "vapenbok",
    "vapendansen": "vapendans",
    "vapendansens": "vapendans",
    "vapendanser": "vapendans",
    "vapendanserna": "vapendans",
    "vapendansernas": "vapendans",
    "vapendansers": "vapendans",
    "vapendragar": "vapendragare",
    "vapendragaren": "vapendragare",
    "vapendragarens": "vapendragare",
    "vapendragares": "vapendragare",
    "vapendragarna": "vapendragare",
    "vapendragarnas": "vapendragare",
    "vapenfabriken": "vapenfabrik",
    "vapenfabrikens": "vapenfabrik",
    "vapenfabriker": "vapenfabrik",
    "vapenfabrikerna": "vapenfabrik",
    "vapenfabrikernas": "vapenfabrik",
    "vapenfabrikers": "vapenfabrik",
    "vapenfabriks": "vapenfabrik",
    "vapenfria": "vapenfri",
    "vapenfriare": "vapenfri",
    "vapenfriares": "vapenfri",
    "vapenfrias": "vapenfri",
    "vapenfriast": "vapenfri",
    "vapenfriaste": "vapenfri",
    "vapenfriastes": "vapenfri",
    "vapenfriasts": "vapenfri",
    "vapenfrie": "vapenfri",
    "vapenfries": "vapenfri",
    "vapenfris": "vapenfri",
    "vapenfritt": "vapenfri",
    "vapenfritts": "vapenfri",
    "vapenfynden": "vapenfynd",
    "vapenfyndens": "vapenfynd",
    "vapenfyndet": "vapenfynd",
    "vapenfyndets": "vapenfynd",
    "vapenfynds": "vapenfynd",
    "vapenföra": "vapenför",
    "vapenförare": "vapenför",
    "vapenförares": "vapenför",
    "vapenföras": "vapenför",
    "vapenförast": "vapenför",
    "vapenföraste": "vapenför",
    "vapenförastes": "vapenför",
    "vapenförasts": "vapenför",
    "vapenföre": "vapenför",
    "vapenföres": "vapenför",
    "vapenförheten": "vapenförhet",
    "vapenförhetens": "vapenförhet",
    "vapenförhets": "vapenförhet",
    "vapenförs": "vapenför",
    "vapenfört": "vapenför",
    "vapenförts": "vapenför",
    "vapengrenar": "vapengren",
    "vapengrenarna": "vapengren",
    "vapengrenarnas": "vapengren",
    "vapengrenars": "vapengren",
    "vapengrenen": "vapengren",
    "vapengrenens": "vapengren",
    "vapengrens": "vapengren",
    "vapenhusen": "vapenhus",
    "vapenhusens": "vapenhus",
    "vapenhuset": "vapenhus",
    "vapenhusets": "vapenhus",
    "vapenlagerna": "vapenlager",
    "vapenlagernas": "vapenlager",
    "vapenlagers": "vapenlager",
    "vapenlagren": "vapenlager",
    "vapenlagrens": "vapenlager",
    "vapenlagret": "vapenlager",
    "vapenlagrets": "vapenlager",
    "vapenlekar": "vapenlek",
    "vapenlekarna": "vapenlek",
    "vapenlekarnas": "vapenlek",
    "vapenlekars": "vapenlek",
    "vapenleken": "vapenlek",
    "vapenlekens": "vapenlek",
    "vapenleks": "vapenlek",
    "vapenlösa": "vapenlös",
    "vapenlösare": "vapenlös",
    "vapenlösares": "vapenlös",
    "vapenlösas": "vapenlös",
    "vapenlösast": "vapenlös",
    "vapenlösaste": "vapenlös",
    "vapenlösastes": "vapenlös",
    "vapenlösasts": "vapenlös",
    "vapenlöse": "vapenlös",
    "vapenlöses": "vapenlös",
    "vapenlösheten": "vapenlöshet",
    "vapenlöshetens": "vapenlöshet",
    "vapenlöshets": "vapenlöshet",
    "vapenlöst": "vapenlös",
    "vapenlösts": "vapenlös",
    "vapenmakten": "vapenmakt",
    "vapenmaktens": "vapenmakt",
    "vapenmakts": "vapenmakt",
    "vapenmässiga": "vapenmässig",
    "vapenmässigare": "vapenmässig",
    "vapenmässigares": "vapenmässig",
    "vapenmässigas": "vapenmässig",
    "vapenmässigast": "vapenmässig",
    "vapenmässigaste": "vapenmässig",
    "vapenmässigastes": "vapenmässig",
    "vapenmässigasts": "vapenmässig",
    "vapenmässige": "vapenmässig",
    "vapenmässiges": "vapenmässig",
    "vapenmässigs": "vapenmässig",
    "vapenmässigt": "vapenmässig",
    "vapenmässigts": "vapenmässig",
    "vapenrockar": "vapenrock",
    "vapenrockarna": "vapenrock",
    "vapenrockarnas": "vapenrock",
    "vapenrockars": "vapenrock",
    "vapenrocken": "vapenrock",
    "vapenrockens": "vapenrock",
    "vapenrocks": "vapenrock",
    "vapens": "vapen",
    "vapenskiften": "vapenskifte",
    "vapenskiftena": "vapenskifte",
    "vapenskiftenas": "vapenskifte",
    "vapenskiftens": "vapenskifte",
    "vapenskiftes": "vapenskifte",
    "vapenskiftet": "vapenskifte",
    "vapenskiftets": "vapenskifte",
    "vapenskramlet": "vapenskrammel",
    "vapenskramlets": "vapenskrammel",
    "vapenskrammels": "vapenskrammel",
    "vapensköldar": "vapensköld",
    "vapensköldarna": "vapensköld",
    "vapensköldarnas": "vapensköld",
    "vapensköldars": "vapensköld",
    "vapenskölden": "vapensköld",
    "vapensköldens": "vapensköld",
    "vapenskölds": "vapensköld",
    "vapenslagen": "vapenslag",
    "vapenslagens": "vapenslag",
    "vapenslaget": "vapenslag",
    "vapenslagets": "vapenslag",
    "vapenslags": "vapenslag",
    "vapensmeden": "vapensmed",
    "vapensmedens": "vapensmed",
    "vapensmeder": "vapensmed",
    "vapensmederna": "vapensmed",
    "vapensmedernas": "vapensmed",
    "vapensmeders": "vapensmed",
    "vapensmeds": "vapensmed",
    "vapensmides": "vapensmide",
    "vapensmidet": "vapensmide",
    "vapensmidets": "vapensmide",
    "vapenstillestånden": "vapenstillestånd",
    "vapenstilleståndens": "vapenstillestånd",
    "vapenstilleståndet": "vapenstillestånd",
    "vapenstilleståndets": "vapenstillestånd",
    "vapenstillestånds": "vapenstillestånd",
    "vapensystemen": "vapensystem",
    "vapensystemens": "vapensystem",
    "vapensystemet": "vapensystem",
    "vapensystemets": "vapensystem",
    "vapensystems": "vapensystem",
    "vapentjänsten": "vapentjänst",
    "vapentjänstens": "vapentjänst",
    "vapentjänsts": "vapentjänst",
    "vapentypen": "vapentyp",
    "vapentypens": "vapentyp",
    "vapentyper": "vapentyp",
    "vapentyperna": "vapentyp",
    "vapentypernas": "vapentyp",
    "vapentypers": "vapentyp",
    "vapentyps": "vapentyp",
    "vapenunderhållet": "vapenunderhåll",
    "vapenunderhållets": "vapenunderhåll",
    "vapenunderhålls": "vapenunderhåll",
    "vapenvilan": "vapenvila",
    "vapenvilans": "vapenvila",
    "vapenvilas": "vapenvila",
    "vapenvile": "vapenvila",
    "vapenvilo": "vapenvila",
    "vapenvilor": "vapenvila",
    "vapenvilorna": "vapenvila",
    "vapenvilornas": "vapenvila",
    "vapenvilors": "vapenvila",
    "vapenvägr": "vapenvägra",
    "vapenvägrade": "vapenvägra",
    "vapenvägrades": "vapenvägra",
    "vapenvägrande": "vapenvägra",
    "vapenvägranden": "vapenvägrande",
    "vapenvägrandena": "vapenvägrande",
    "vapenvägrandenas": "vapenvägrande",
    "vapenvägrandens": "vapenvägrande",
    "vapenvägrandes": "vapenvägrande",
    "vapenvägrandet": "vapenvägrande",
    "vapenvägrandets": "vapenvägrande",
    "vapenvägrans": "vapenvägran",
    "vapenvägrar": "vapenvägrare",
    "vapenvägraren": "vapenvägrare",
    "vapenvägrarens": "vapenvägrare",
    "vapenvägrares": "vapenvägrare",
    "vapenvägrarna": "vapenvägrare",
    "vapenvägrarnas": "vapenvägrare",
    "vapenvägras": "vapenvägra",
    "vapenvägrat": "vapenvägra",
    "vapenvägrats": "vapenvägra",
    "vapnen": "vapen",
    "vapnens": "vapen",
    "vapnet": "vapen",
    "vapnets": "vapen",
    "vapören": "vapör",
    "vapörens": "vapör",
    "vapörer": "vapör",
    "vapörerna": "vapör",
    "vapörernas": "vapör",
    "vapörers": "vapör",
    "vapörs": "vapör",
    "var": "vara",
    "varade": "vara",
    "varades": "varas",
    "varaktiga": "varaktig",
    "varaktigare": "varaktig",
    "varaktigares": "varaktig",
    "varaktigas": "varaktig",
    "varaktigast": "varaktig",
    "varaktigaste": "varaktig",
    "varaktigastes": "varaktig",
    "varaktigasts": "varaktig",
    "varaktige": "varaktig",
    "varaktiges": "varaktig",
    "varaktigheten": "varaktighet",
    "varaktighetens": "varaktighet",
    "varaktigheter": "varaktighet",
    "varaktigheterna": "varaktighet",
    "varaktigheternas": "varaktighet",
    "varaktigheters": "varaktighet",
    "varaktighets": "varaktighet",
    "varaktigs": "varaktig",
    "varaktigt": "varaktig",
    "varaktigts": "varaktig",
    "varan": "vara",
    "varande": "vara",
    "varanden": "varande",
    "varandena": "varande",
    "varandenas": "varande",
    "varandens": "varande",
    "varandes": "varande",
    "varandet": "varande",
    "varandets": "varande",
    "varandras": "varandra",
    "varanen": "varan",
    "varanens": "varan",
    "varaner": "varan",
    "varanerna": "varan",
    "varanernas": "varan",
    "varaners": "varan",
    "varannans": "varannan",
    "varanns": "varann",
    "varans": "varan",
    "varar": "vara",
    "varas": "vara",
    "varat": "vara",
    "varats": "varas",
    "varbildningar": "varbildning",
    "varbildningarna": "varbildning",
    "varbildningarnas": "varbildning",
    "varbildningars": "varbildning",
    "varbildningen": "varbildning",
    "varbildningens": "varbildning",
    "varbildnings": "varbildning",
    "varblås": "varblåsa",
    "varblåsan": "varblåsa",
    "varblåsans": "varblåsa",
    "varblåsas": "varblåsa",
    "varblåse": "varblåsa",
    "varblåsor": "varblåsa",
    "varblåsorna": "varblåsa",
    "varblåsornas": "varblåsa",
    "varblåsors": "varblåsa",
    "varbygeln": "varbygel",
    "varbygelns": "varbygel",
    "varbygels": "varbygel",
    "varbyglar": "varbygel",
    "varbyglarna": "varbygel",
    "varbyglarnas": "varbygel",
    "varbyglars": "varbygel",
    "vard": "varde",
    "vardagar": "vardag",
    "vardagarna": "vardag",
    "vardagarnas": "vardag",
    "vardagars": "vardag",
    "vardagen": "vardag",
    "vardagens": "vardag",
    "vardagliga": "vardaglig",
    "vardagligare": "vardaglig",
    "vardagligares": "vardaglig",
    "vardagligas": "vardaglig",
    "vardagligast": "vardaglig",
    "vardagligaste": "vardaglig",
    "vardagligastes": "vardaglig",
    "vardagligasts": "vardaglig",
    "vardaglige": "vardaglig",
    "vardagliges": "vardaglig",
    "vardagligheten": "vardaglighet",
    "vardaglighetens": "vardaglighet",
    "vardagligheter": "vardaglighet",
    "vardagligheterna": "vardaglighet",
    "vardagligheternas": "vardaglighet",
    "vardagligheters": "vardaglighet",
    "vardaglighets": "vardaglighet",
    "vardagligs": "vardaglig",
    "vardagligt": "vardaglig",
    "vardagligts": "vardaglig",
    "vardags": "vardag",
    "vardagsangelägenheten": "vardagsangelägenhet",
    "vardagsangelägenhetens": "vardagsangelägenhet",
    "vardagsangelägenheter": "vardagsangelägenhet",
    "vardagsangelägenheterna": "vardagsangelägenhet",
    "vardagsangelägenheternas": "vardagsangelägenhet",
    "vardagsangelägenheters": "vardagsangelägenhet",
    "vardagsangelägenhets": "vardagsangelägenhet",
    "vardagsfesten": "vardagsfest",
    "vardagsfestens": "vardagsfest",
    "vardagsfester": "vardagsfest",
    "vardagsfesterna": "vardagsfest",
    "vardagsfesternas": "vardagsfest",
    "vardagsfesters": "vardagsfest",
    "vardagsfests": "vardagsfest",
    "vardagsfestutstyrseln": "vardagsfestutstyrsel",
    "vardagsfestutstyrselns": "vardagsfestutstyrsel",
    "vardagsfestutstyrsels": "vardagsfestutstyrsel",
    "vardagsfestutstyrslar": "vardagsfestutstyrsel",
    "vardagsfestutstyrslarna": "vardagsfestutstyrsel",
    "vardagsfestutstyrslarnas": "vardagsfestutstyrsel",
    "vardagsfestutstyrslars": "vardagsfestutstyrsel",
    "vardagsfrasen": "vardagsfras",
    "vardagsfrasens": "vardagsfras",
    "vardagsfraser": "vardagsfras",
    "vardagsfraserna": "vardagsfras",
    "vardagsfrasernas": "vardagsfras",
    "vardagsfrasers": "vardagsfras",
    "vardagsförståelsen": "vardagsförståelse",
    "vardagsförståelsens": "vardagsförståelse",
    "vardagsförståelses": "vardagsförståelse",
    "vardagskläderna": "vardagskläder",
    "vardagsklädernas": "vardagskläder",
    "vardagskläders": "vardagskläder",
    "vardagsklädes": "vardagskläder",
    "vardagskläds": "vardagskläder",
    "vardagsliven": "vardagsliv",
    "vardagslivens": "vardagsliv",
    "vardagslivet": "vardagsliv",
    "vardagslivets": "vardagsliv",
    "vardagslivs": "vardagsliv",
    "vardagslyxen": "vardagslyx",
    "vardagslyxens": "vardagslyx",
    "vardagsmaten": "vardagsmat",
    "vardagsmatens": "vardagsmat",
    "vardagsmats": "vardagsmat",
    "vardagsmässiga": "vardagsmässig",
    "vardagsmässigare": "vardagsmässig",
    "vardagsmässigares": "vardagsmässig",
    "vardagsmässigas": "vardagsmässig",
    "vardagsmässigast": "vardagsmässig",
    "vardagsmässigaste": "vardagsmässig",
    "vardagsmässigastes": "vardagsmässig",
    "vardagsmässigasts": "vardagsmässig",
    "vardagsmässige": "vardagsmässig",
    "vardagsmässiges": "vardagsmässig",
    "vardagsmässigs": "vardagsmässig",
    "vardagsmässigt": "vardagsmässig",
    "vardagsmässigts": "vardagsmässig",
    "vardagsrasismen": "vardagsrasism",
    "vardagsrasismens": "vardagsrasism",
    "vardagsrasisms": "vardagsrasism",
    "vardagsrummen": "vardagsrum",
    "vardagsrummens": "vardagsrum",
    "vardagsrummet": "vardagsrum",
    "vardagsrummets": "vardagsrum",
    "vardagsrums": "vardagsrum",
    "vardagsrumsmöbeln": "vardagsrumsmöbel",
    "vardagsrumsmöbelns": "vardagsrumsmöbel",
    "vardagsrumsmöbels": "vardagsrumsmöbel",
    "vardagsrumsmöbler": "vardagsrumsmöbel",
    "vardagsrumsmöblerna": "vardagsrumsmöbel",
    "vardagsrumsmöblernas": "vardagsrumsmöbel",
    "vardagsrumsmöblers": "vardagsrumsmöbel",
    "vardagsrätten": "vardagsrätt",
    "vardagsrättens": "vardagsrätt",
    "vardagsrätter": "vardagsrätt",
    "vardagsrätterna": "vardagsrätt",
    "vardagsrätternas": "vardagsrätt",
    "vardagsrätters": "vardagsrätt",
    "vardagsrätts": "vardagsrätt",
    "vardagstänkanden": "vardagstänkande",
    "vardagstänkandena": "vardagstänkande",
    "vardagstänkandenas": "vardagstänkande",
    "vardagstänkandens": "vardagstänkande",
    "vardagstänkandes": "vardagstänkande",
    "vardagstänkandet": "vardagstänkande",
    "vardagstänkandets": "vardagstänkande",
    "vardagsupplevelsen": "vardagsupplevelse",
    "vardagsupplevelsens": "vardagsupplevelse",
    "vardagsupplevelser": "vardagsupplevelse",
    "vardagsupplevelserna": "vardagsupplevelse",
    "vardagsupplevelsernas": "vardagsupplevelse",
    "vardagsupplevelsers": "vardagsupplevelse",
    "vardagsupplevelses": "vardagsupplevelse",
    "vardande": "varda",
    "vardanden": "vardande",
    "vardandena": "vardande",
    "vardandenas": "vardande",
    "vardandens": "vardande",
    "vardandes": "vardande",
    "vardandet": "vardande",
    "vardandets": "vardande",
    "vardar": "varde",
    "vardarna": "varde",
    "vardarnas": "varde",
    "vardars": "varde",
    "varde": "varda",
    "varden": "varde",
    "vardens": "varde",
    "varder": "varda",
    "varderas": "vardera",
    "vardes": "varde",
    "vards": "varde",
    "vare": "vara",
    "varelsen": "varelse",
    "varelsens": "varelse",
    "varelser": "varelse",
    "varelserna": "varelse",
    "varelsernas": "varelse",
    "varelsers": "varelse",
    "varelses": "varelse",
    "varendas": "varenda",
    "varende": "varenda",
    "varendes": "varenda",
    "vares": "vara",
    "varet": "var",
    "varets": "var",
    "varevig": "vareviga",
    "varevigs": "vareviga",
    "varfågeln": "varfågel",
    "varfågelns": "varfågel",
    "varfågels": "varfågel",
    "varfåglar": "varfågel",
    "varfåglarna": "varfågel",
    "varfåglarnas": "varfågel",
    "varfåglars": "varfågel",
    "varg": "varga",
    "vargad": "varga",
    "vargade": "varga",
    "vargades": "varga",
    "vargads": "varga",
    "vargande": "varga",
    "varganden": "vargande",
    "vargandena": "vargande",
    "vargandenas": "vargande",
    "vargandens": "vargande",
    "vargandes": "vargande",
    "vargandet": "vargande",
    "vargandets": "vargande",
    "vargar": "varga",
    "vargarna": "varg",
    "vargarnas": "varg",
    "vargars": "varg",
    "vargas": "varga",
    "vargat": "varga",
    "vargatiderna": "vargatider",
    "vargatidernas": "vargatider",
    "vargatiders": "vargatider",
    "vargatids": "vargatider",
    "vargats": "varga",
    "vargavintern": "vargavinter",
    "vargavinterns": "vargavinter",
    "vargavinters": "vargavinter",
    "vargavintrar": "vargavinter",
    "vargavintrarna": "vargavinter",
    "vargavintrarnas": "vargavinter",
    "vargavintrars": "vargavinter",
    "vargen": "varg",
    "vargens": "varg",
    "vargeringar": "vargering",
    "vargeringarna": "vargering",
    "vargeringarnas": "vargering",
    "vargeringars": "vargering",
    "vargeringen": "vargering",
    "vargeringens": "vargering",
    "vargerings": "vargering",
    "varggropar": "varggrop",
    "varggroparna": "varggrop",
    "varggroparnas": "varggrop",
    "varggropars": "varggrop",
    "varggropen": "varggrop",
    "varggropens": "varggrop",
    "varggrops": "varggrop",
    "varghagels": "varghagel",
    "varghaglen": "varghagel",
    "varghaglens": "varghagel",
    "varghaglet": "varghagel",
    "varghaglets": "varghagel",
    "varghon": "varghona",
    "varghonan": "varghona",
    "varghonans": "varghona",
    "varghonas": "varghona",
    "varghone": "varghona",
    "varghonor": "varghona",
    "varghonorna": "varghona",
    "varghonornas": "varghona",
    "varghonors": "varghona",
    "varghons": "varghona",
    "varginnan": "varginna",
    "varginnans": "varginna",
    "varginnas": "varginna",
    "varginne": "varginna",
    "varginnor": "varginna",
    "varginnorna": "varginna",
    "varginnornas": "varginna",
    "varginnors": "varginna",
    "vargs": "varg",
    "vargtim": "vargtimme",
    "vargtimman": "vargtimma",
    "vargtimmans": "vargtimma",
    "vargtimmar": "vargtimme",
    "vargtimmarna": "vargtimme",
    "vargtimmarnas": "vargtimme",
    "vargtimmars": "vargtimme",
    "vargtimmas": "vargtimma",
    "vargtimmen": "vargtimme",
    "vargtimmens": "vargtimme",
    "vargtimmes": "vargtimme",
    "vargtims": "vargtimme",
    "vargtäta": "vargtät",
    "vargtätare": "vargtät",
    "vargtätares": "vargtät",
    "vargtätas": "vargtät",
    "vargtätast": "vargtät",
    "vargtätaste": "vargtät",
    "vargtätastes": "vargtät",
    "vargtätasts": "vargtät",
    "vargtäte": "vargtät",
    "vargtätes": "vargtät",
    "vargtätheten": "vargtäthet",
    "vargtäthetens": "vargtäthet",
    "vargtäthets": "vargtäthet",
    "vargtäts": "vargtät",
    "vargtätt": "vargtät",
    "vargtätts": "vargtät",
    "vargungar": "vargunge",
    "vargungarna": "vargunge",
    "vargungarnas": "vargunge",
    "vargungars": "vargunge",
    "vargungen": "vargunge",
    "vargungens": "vargunge",
    "vargunges": "vargunge",
    "varhärdar": "varhärd",
    "varhärdarna": "varhärd",
    "varhärdarnas": "varhärd",
    "varhärdars": "varhärd",
    "varhärden": "varhärd",
    "varhärdens": "varhärd",
    "varhärds": "varhärd",
    "variabeln": "variabel",
    "variabelns": "variabel",
    "variabels": "variabel",
    "variabelt": "variabel",
    "variabelts": "variabel",
    "variabiliteten": "variabilitet",
    "variabilitetens": "variabilitet",
    "variabiliteter": "variabilitet",
    "variabiliteterna": "variabilitet",
    "variabiliteternas": "variabilitet",
    "variabiliteters": "variabilitet",
    "variabilitets": "variabilitet",
    "variabla": "variabel",
    "variablare": "variabel",
    "variablares": "variabel",
    "variablas": "variabel",
    "variablast": "variabel",
    "variablaste": "variabel",
    "variablastes": "variabel",
    "variablasts": "variabel",
    "variable": "variabel",
    "variabler": "variabel",
    "variablerna": "variabel",
    "variablernas": "variabel",
    "variablers": "variabel",
    "variables": "variabel",
    "varian": "varia",
    "variana": "varia",
    "varianas": "varia",
    "varians": "varia",
    "variansanalysen": "variansanalys",
    "variansanalysens": "variansanalys",
    "variansen": "varians",
    "variansens": "varians",
    "varianser": "varians",
    "varianserna": "varians",
    "variansernas": "varians",
    "variansers": "varians",
    "varianten": "variant",
    "variantens": "variant",
    "varianter": "variant",
    "varianterna": "variant",
    "varianternas": "variant",
    "varianters": "variant",
    "variants": "variant",
    "varias": "varia",
    "variationen": "variation",
    "variationens": "variation",
    "variationer": "variation",
    "variationerna": "variation",
    "variationernas": "variation",
    "variationers": "variation",
    "variations": "variation",
    "variationsbredden": "variationsbredd",
    "variationsbreddens": "variationsbredd",
    "variationsbredder": "variationsbredd",
    "variationsbredderna": "variationsbredd",
    "variationsbreddernas": "variationsbredd",
    "variationsbredders": "variationsbredd",
    "variationsbredds": "variationsbredd",
    "variationsinstrumenten": "variationsinstrument",
    "variationsinstrumentens": "variationsinstrument",
    "variationsinstrumentet": "variationsinstrument",
    "variationsinstrumentets": "variationsinstrument",
    "variationsinstruments": "variationsinstrument",
    "variationskalkylen": "variationskalkyl",
    "variationskalkylens": "variationskalkyl",
    "variationskalkyls": "variationskalkyl",
    "variatorer": "variator",
    "variatorerna": "variator",
    "variatorernas": "variator",
    "variatorers": "variator",
    "variatorn": "variator",
    "variatorns": "variator",
    "variators": "variator",
    "varierad": "variera",
    "varierade": "variera",
    "varierades": "variera",
    "varierads": "variera",
    "varierande": "variera",
    "varieranden": "varierande",
    "varierandena": "varierande",
    "varierandenas": "varierande",
    "varierandens": "varierande",
    "varierandes": "varierande",
    "varierandet": "varierande",
    "varierandets": "varierande",
    "varierar": "variera",
    "varieras": "variera",
    "varierat": "variera",
    "varierats": "variera",
    "varierbara": "varierbar",
    "varierbarare": "varierbar",
    "varierbarares": "varierbar",
    "varierbaras": "varierbar",
    "varierbarast": "varierbar",
    "varierbaraste": "varierbar",
    "varierbarastes": "varierbar",
    "varierbarasts": "varierbar",
    "varierbare": "varierbar",
    "varierbares": "varierbar",
    "varierbarheten": "varierbarhet",
    "varierbarhetens": "varierbarhet",
    "varierbarhets": "varierbarhet",
    "varierbars": "varierbar",
    "varierbart": "varierbar",
    "varierbarts": "varierbar",
    "varieringar": "variering",
    "varieringarna": "variering",
    "varieringarnas": "variering",
    "varieringars": "variering",
    "varieringen": "variering",
    "varieringens": "variering",
    "varierings": "variering",
    "varieteten": "varietet",
    "varietetens": "varietet",
    "varieteter": "varietet",
    "varieteterna": "varietet",
    "varieteternas": "varietet",
    "varieteters": "varietet",
    "varietets": "varietet",
    "varietéartisten": "varietéartist",
    "varietéartistens": "varietéartist",
    "varietéartister": "varietéartist",
    "varietéartisterna": "varietéartist",
    "varietéartisternas": "varietéartist",
    "varietéartisters": "varietéartist",
    "varietéartists": "varietéartist",
    "varietéer": "varieté",
    "varietéerna": "varieté",
    "varietéernas": "varieté",
    "varietéers": "varieté",
    "varietén": "varieté",
    "varieténs": "varieté",
    "varietés": "varieté",
    "variga": "varig",
    "varigare": "varig",
    "varigares": "varig",
    "varigas": "varig",
    "varigast": "varig",
    "varigaste": "varig",
    "varigastes": "varig",
    "varigasts": "varig",
    "varige": "varig",
    "variges": "varig",
    "varigs": "varig",
    "varigt": "varig",
    "varigts": "varig",
    "variometern": "variometer",
    "variometerns": "variometer",
    "variometers": "variometer",
    "variometrar": "variometer",
    "variometrarna": "variometer",
    "variometrarnas": "variometer",
    "variometrars": "variometer",
    "varit": "vara",
    "varits": "vara",
    "varjagen": "varjag",
    "varjagens": "varjag",
    "varjager": "varjag",
    "varjagerna": "varjag",
    "varjagernas": "varjag",
    "varjagers": "varjag",
    "varjags": "varjag",
    "varjes": "varje",
    "varkunnsamheten": "varkunnsamhet",
    "varkunnsamhetens": "varkunnsamhet",
    "varkunnsamhets": "varkunnsamhet",
    "varkunnsamma": "varkunnsam",
    "varkunnsammare": "varkunnsam",
    "varkunnsammares": "varkunnsam",
    "varkunnsammas": "varkunnsam",
    "varkunnsammast": "varkunnsam",
    "varkunnsammaste": "varkunnsam",
    "varkunnsammastes": "varkunnsam",
    "varkunnsammasts": "varkunnsam",
    "varkunnsamme": "varkunnsam",
    "varkunnsammes": "varkunnsam",
    "varkunnsams": "varkunnsam",
    "varkunnsamt": "varkunnsam",
    "varkunnsamts": "varkunnsam",
    "varliga": "varlig",
    "varligare": "varlig",
    "varligares": "varlig",
    "varligas": "varlig",
    "varligast": "varlig",
    "varligaste": "varlig",
    "varligastes": "varlig",
    "varligasts": "varlig",
    "varlige": "varlig",
    "varliges": "varlig",
    "varligheten": "varlighet",
    "varlighetens": "varlighet",
    "varlighets": "varlighet",
    "varligs": "varlig",
    "varligt": "varlig",
    "varligts": "varlig",
    "varma": "varm",
    "varmare": "varm",
    "varmares": "varm",
    "varmas": "varm",
    "varmast": "varm",
    "varmaste": "varm",
    "varmastes": "varm",
    "varmasts": "varm",
    "varmbaden": "varmbad",
    "varmbadens": "varmbad",
    "varmbadet": "varmbad",
    "varmbadets": "varmbad",
    "varmbads": "varmbad",
    "varmbloden": "varmblod",
    "varmblodens": "varmblod",
    "varmblodet": "varmblod",
    "varmblodets": "varmblod",
    "varmblodiga": "varmblodig",
    "varmblodigare": "varmblodig",
    "varmblodigares": "varmblodig",
    "varmblodigas": "varmblodig",
    "varmblodigast": "varmblodig",
    "varmblodigaste": "varmblodig",
    "varmblodigastes": "varmblodig",
    "varmblodigasts": "varmblodig",
    "varmblodige": "varmblodig",
    "varmblodiges": "varmblodig",
    "varmblodigheten": "varmblodighet",
    "varmblodighetens": "varmblodighet",
    "varmblodighets": "varmblodighet",
    "varmblodigs": "varmblodig",
    "varmblodigt": "varmblodig",
    "varmblodigts": "varmblodig",
    "varmblods": "varmblod",
    "varmbon": "varmbona",
    "varmbonad": "varmbona",
    "varmbonade": "varmbona",
    "varmbonades": "varmbona",
    "varmbonads": "varmbona",
    "varmbonande": "varmbona",
    "varmbonanden": "varmbonande",
    "varmbonandena": "varmbonande",
    "varmbonandenas": "varmbonande",
    "varmbonandens": "varmbonande",
    "varmbonandes": "varmbonande",
    "varmbonandet": "varmbonande",
    "varmbonandets": "varmbonande",
    "varmbonar": "varmbona",
    "varmbonas": "varmbona",
    "varmbonat": "varmbona",
    "varmbonats": "varmbona",
    "varmbräckta": "varmbräckt",
    "varmbräcktare": "varmbräckt",
    "varmbräcktares": "varmbräckt",
    "varmbräcktas": "varmbräckt",
    "varmbräcktast": "varmbräckt",
    "varmbräcktaste": "varmbräckt",
    "varmbräcktastes": "varmbräckt",
    "varmbräcktasts": "varmbräckt",
    "varmbräckte": "varmbräckt",
    "varmbräcktes": "varmbräckt",
    "varmbräckts": "varmbräckt",
    "varme": "varm",
    "varmes": "varm",
    "varmfronten": "varmfront",
    "varmfrontens": "varmfront",
    "varmfronter": "varmfront",
    "varmfronterna": "varmfront",
    "varmfronternas": "varmfront",
    "varmfronters": "varmfront",
    "varmfronts": "varmfront",
    "varmförtennade": "varmförtennad",
    "varmförtennades": "varmförtennad",
    "varmförtennads": "varmförtennad",
    "varmförtennat": "varmförtennad",
    "varmförtennats": "varmförtennad",
    "varmgaragen": "varmgarage",
    "varmgaragens": "varmgarage",
    "varmgarages": "varmgarage",
    "varmgaraget": "varmgarage",
    "varmgaragets": "varmgarage",
    "varmgången": "varmgång",
    "varmgångens": "varmgång",
    "varmgångs": "varmgång",
    "varmheten": "varmhet",
    "varmhetens": "varmhet",
    "varmhets": "varmhet",
    "varmhjärtade": "varmhjärtad",
    "varmhjärtades": "varmhjärtad",
    "varmhjärtads": "varmhjärtad",
    "varmhjärtat": "varmhjärtad",
    "varmhjärtats": "varmhjärtad",
    "varmhållningar": "varmhållning",
    "varmhållningarna": "varmhållning",
    "varmhållningarnas": "varmhållning",
    "varmhållningars": "varmhållning",
    "varmhållningen": "varmhållning",
    "varmhållningens": "varmhållning",
    "varmhållnings": "varmhållning",
    "varmkör": "varmköra",
    "varmkörande": "varmköra",
    "varmköranden": "varmkörande",
    "varmkörandena": "varmkörande",
    "varmkörandenas": "varmkörande",
    "varmkörandens": "varmkörande",
    "varmkörandes": "varmkörande",
    "varmkörandet": "varmkörande",
    "varmkörandets": "varmkörande",
    "varmköras": "varmköra",
    "varmkörd": "varmköra",
    "varmkörda": "varmköra",
    "varmkördas": "varmköra",
    "varmkörde": "varmköra",
    "varmkördes": "varmköra",
    "varmkörds": "varmköra",
    "varmköres": "varmköra",
    "varmkörs": "varmköra",
    "varmkört": "varmköra",
    "varmkörts": "varmköra",
    "varmluften": "varmluft",
    "varmluftens": "varmluft",
    "varmluftpistolen": "varmluftpistol",
    "varmluftpistolens": "varmluftpistol",
    "varmluftpistoler": "varmluftpistol",
    "varmluftpistolerna": "varmluftpistol",
    "varmluftpistolernas": "varmluftpistol",
    "varmluftpistolers": "varmluftpistol",
    "varmluftpistols": "varmluftpistol",
    "varmlufts": "varmluft",
    "varmluftsfläktar": "varmluftsfläkt",
    "varmluftsfläktarna": "varmluftsfläkt",
    "varmluftsfläktarnas": "varmluftsfläkt",
    "varmluftsfläktars": "varmluftsfläkt",
    "varmluftsfläkten": "varmluftsfläkt",
    "varmluftsfläktens": "varmluftsfläkt",
    "varmluftsfläkts": "varmluftsfläkt",
    "varmluftsridåer": "varmluftsridå",
    "varmluftsridåerna": "varmluftsridå",
    "varmluftsridåernas": "varmluftsridå",
    "varmluftsridåers": "varmluftsridå",
    "varmluftsridån": "varmluftsridå",
    "varmluftsridåns": "varmluftsridå",
    "varmluftsridås": "varmluftsridå",
    "varmluftssystemen": "varmluftssystem",
    "varmluftssystemens": "varmluftssystem",
    "varmluftssystemet": "varmluftssystem",
    "varmluftssystemets": "varmluftssystem",
    "varmluftssystems": "varmluftssystem",
    "varmrätten": "varmrätt",
    "varmrättens": "varmrätt",
    "varmrätter": "varmrätt",
    "varmrätterna": "varmrätt",
    "varmrätternas": "varmrätt",
    "varmrätters": "varmrätt",
    "varmrätts": "varmrätt",
    "varmrök": "varmröka",
    "varmrökande": "varmröka",
    "varmrökandes": "varmröka",
    "varmrökas": "varmröka",
    "varmröker": "varmröka",
    "varmrökes": "varmröka",
    "varmröks": "varmröka",
    "varmrökt": "varmröka",
    "varmrökta": "varmröka",
    "varmröktas": "varmröka",
    "varmrökte": "varmröka",
    "varmröktes": "varmröka",
    "varmrökts": "varmröka",
    "varms": "varm",
    "varmt": "varm",
    "varmts": "varm",
    "varmvattenberedar": "varmvattenberedare",
    "varmvattenberedaren": "varmvattenberedare",
    "varmvattenberedarens": "varmvattenberedare",
    "varmvattenberedares": "varmvattenberedare",
    "varmvattenberedarna": "varmvattenberedare",
    "varmvattenberedarnas": "varmvattenberedare",
    "varmvattens": "varmvatten",
    "varmvattensberedar": "varmvattensberedare",
    "varmvattensberedaren": "varmvattensberedare",
    "varmvattensberedarens": "varmvattensberedare",
    "varmvattensberedares": "varmvattensberedare",
    "varmvattensberedarna": "varmvattensberedare",
    "varmvattensberedarnas": "varmvattensberedare",
    "varmvattenssystemen": "varmvattenssystem",
    "varmvattenssystemens": "varmvattenssystem",
    "varmvattenssystemet": "varmvattenssystem",
    "varmvattenssystemets": "varmvattenssystem",
    "varmvattenssystems": "varmvattenssystem",
    "varmvattensystemen": "varmvattensystem",
    "varmvattensystemens": "varmvattensystem",
    "varmvattensystemet": "varmvattensystem",
    "varmvattensystemets": "varmvattensystem",
    "varmvattensystems": "varmvattensystem",
    "varmvattnen": "varmvatten",
    "varmvattnens": "varmvatten",
    "varmvattnet": "varmvatten",
    "varmvattnets": "varmvatten",
    "varn": "varna",
    "varnad": "varna",
    "varnade": "varna",
    "varnades": "varna",
    "varnads": "varna",
    "varnagels": "varnagel",
    "varnande": "varna",
    "varnanden": "varnande",
    "varnandena": "varnande",
    "varnandenas": "varnande",
    "varnandens": "varnande",
    "varnandes": "varnande",
    "varnandet": "varnande",
    "varnandets": "varnande",
    "varnar": "varna",
    "varnas": "varna",
    "varnat": "varna",
    "varnats": "varna",
    "varningar": "varning",
    "varningarna": "varning",
    "varningarnas": "varning",
    "varningars": "varning",
    "varningen": "varning",
    "varningens": "varning",
    "varnings": "varning",
    "varningsflagg": "varningsflagga",
    "varningsflaggan": "varningsflagga",
    "varningsflaggans": "varningsflagga",
    "varningsflaggas": "varningsflagga",
    "varningsflagge": "varningsflagga",
    "varningsflaggor": "varningsflagga",
    "varningsflaggorna": "varningsflagga",
    "varningsflaggornas": "varningsflagga",
    "varningsflaggors": "varningsflagga",
    "varningsflaggs": "varningsflagga",
    "varningsklock": "varningsklocka",
    "varningsklockan": "varningsklocka",
    "varningsklockans": "varningsklocka",
    "varningsklockas": "varningsklocka",
    "varningsklocke": "varningsklocka",
    "varningsklockor": "varningsklocka",
    "varningsklockorna": "varningsklocka",
    "varningsklockornas": "varningsklocka",
    "varningsklockors": "varningsklocka",
    "varningsklocks": "varningsklocka",
    "varningslamp": "varningslampa",
    "varningslampan": "varningslampa",
    "varningslampans": "varningslampa",
    "varningslampas": "varningslampa",
    "varningslampe": "varningslampa",
    "varningslampor": "varningslampa",
    "varningslamporna": "varningslampa",
    "varningslampornas": "varningslampa",
    "varningslampors": "varningslampa",
    "varningslamps": "varningslampa",
    "varningsljusen": "varningsljus",
    "varningsljusens": "varningsljus",
    "varningsljuset": "varningsljus",
    "varningsljusets": "varningsljus",
    "varningsmärken": "varningsmärke",
    "varningsmärkena": "varningsmärke",
    "varningsmärkenas": "varningsmärke",
    "varningsmärkens": "varningsmärke",
    "varningsmärkes": "varningsmärke",
    "varningsmärket": "varningsmärke",
    "varningsmärkets": "varningsmärke",
    "varningsropen": "varningsrop",
    "varningsropens": "varningsrop",
    "varningsropet": "varningsrop",
    "varningsropets": "varningsrop",
    "varningsrops": "varningsrop",
    "varningssignalen": "varningssignal",
    "varningssignalens": "varningssignal",
    "varningssignaler": "varningssignal",
    "varningssignalerna": "varningssignal",
    "varningssignalernas": "varningssignal",
    "varningssignalers": "varningssignal",
    "varningssignals": "varningssignal",
    "varningsskotten": "varningsskott",
    "varningsskottens": "varningsskott",
    "varningsskottet": "varningsskott",
    "varningsskottets": "varningsskott",
    "varningsskotts": "varningsskott",
    "varningsteckens": "varningstecken",
    "varningstecknen": "varningstecken",
    "varningstecknens": "varningstecken",
    "varningstecknet": "varningstecken",
    "varningstecknets": "varningstecken",
    "varningstriangeln": "varningstriangel",
    "varningstriangelns": "varningstriangel",
    "varningstriangels": "varningstriangel",
    "varningstrianglar": "varningstriangel",
    "varningstrianglarna": "varningstriangel",
    "varningstrianglarnas": "varningstriangel",
    "varningstrianglars": "varningstriangel",
    "varor": "vara",
    "varorna": "vara",
    "varornas": "vara",
    "varors": "vara",
    "varp": "varpa",
    "varpad": "varpa",
    "varpade": "varpa",
    "varpades": "varpa",
    "varpads": "varpa",
    "varpan": "varpa",
    "varpande": "varpa",
    "varpanden": "varpande",
    "varpandena": "varpande",
    "varpandenas": "varpande",
    "varpandens": "varpande",
    "varpandes": "varpande",
    "varpandet": "varpande",
    "varpandets": "varpande",
    "varpans": "varpa",
    "varpar": "varpa",
    "varparna": "varp",
    "varparnas": "varp",
    "varpars": "varp",
    "varpas": "varpa",
    "varpat": "varpa",
    "varpats": "varpa",
    "varpbommar": "varpbom",
    "varpbommarna": "varpbom",
    "varpbommarnas": "varpbom",
    "varpbommars": "varpbom",
    "varpbommen": "varpbom",
    "varpbommens": "varpbom",
    "varpboms": "varpbom",
    "varpe": "varpa",
    "varpen": "varp",
    "varpens": "varp",
    "varpet": "varp",
    "varpets": "varp",
    "varpningar": "varpning",
    "varpningarna": "varpning",
    "varpningarnas": "varpning",
    "varpningars": "varpning",
    "varpningen": "varpning",
    "varpningens": "varpning",
    "varpnings": "varpning",
    "varpor": "varpa",
    "varporna": "varpa",
    "varpornas": "varpa",
    "varpors": "varpa",
    "varps": "varpa",
    "varpstick": "varpsticka",
    "varpstickan": "varpsticka",
    "varpstickans": "varpsticka",
    "varpstickas": "varpsticka",
    "varpsticke": "varpsticka",
    "varpstickor": "varpsticka",
    "varpstickorna": "varpsticka",
    "varpstickornas": "varpsticka",
    "varpstickors": "varpsticka",
    "varpsticks": "varpsticka",
    "varptrikån": "varptrikå",
    "varptrikåns": "varptrikå",
    "varptrikås": "varptrikå",
    "varptrådar": "varptråd",
    "varptrådarna": "varptråd",
    "varptrådarnas": "varptråd",
    "varptrådars": "varptråd",
    "varptråden": "varptråd",
    "varptrådens": "varptråd",
    "varptråds": "varptråd",
    "vars": "vara",
    "varsamheten": "varsamhet",
    "varsamhetens": "varsamhet",
    "varsamhets": "varsamhet",
    "varsamma": "varsam",
    "varsammare": "varsam",
    "varsammares": "varsam",
    "varsammas": "varsam",
    "varsammast": "varsam",
    "varsammaste": "varsam",
    "varsammastes": "varsam",
    "varsammasts": "varsam",
    "varsamme": "varsam",
    "varsammes": "varsam",
    "varsams": "varsam",
    "varsamt": "varsam",
    "varsamts": "varsam",
    "varseblev": "varsebli",
    "varsebleve": "varsebli",
    "varseblir": "varsebli",
    "varsebliv": "varsebli",
    "varsebliva": "varsebli",
    "varseblivande": "varsebli",
    "varseblivanden": "varseblivande",
    "varseblivandena": "varseblivande",
    "varseblivandenas": "varseblivande",
    "varseblivandens": "varseblivande",
    "varseblivandes": "varseblivande",
    "varseblivandet": "varseblivande",
    "varseblivandets": "varseblivande",
    "varseblive": "varsebli",
    "varsebliven": "varsebli",
    "varseblivens": "varsebli",
    "varsebliver": "varsebli",
    "varseblivet": "varsebli",
    "varseblivets": "varsebli",
    "varseblivit": "varsebli",
    "varseblivna": "varsebli",
    "varseblivnas": "varsebli",
    "varseblivne": "varsebli",
    "varseblivnes": "varsebli",
    "varseblivningar": "varseblivning",
    "varseblivningarna": "varseblivning",
    "varseblivningarnas": "varseblivning",
    "varseblivningars": "varseblivning",
    "varseblivningen": "varseblivning",
    "varseblivningens": "varseblivning",
    "varseblivnings": "varseblivning",
    "varseblivningsfenomenen": "varseblivningsfenomen",
    "varseblivningsfenomenens": "varseblivningsfenomen",
    "varseblivningsfenomenet": "varseblivningsfenomen",
    "varseblivningsfenomenets": "varseblivningsfenomen",
    "varseblivningsfenomens": "varseblivningsfenomen",
    "varsel": "varsla",
    "varseloverallen": "varseloverall",
    "varseloverallens": "varseloverall",
    "varseloveraller": "varseloverall",
    "varseloverallerna": "varseloverall",
    "varseloverallernas": "varseloverall",
    "varseloverallers": "varseloverall",
    "varseloveralls": "varseloverall",
    "varsels": "varsel",
    "varsina": "varsin",
    "varsinas": "varsin",
    "varsins": "varsin",
    "varsitt": "varsin",
    "varsitts": "varsin",
    "varskodd": "varsko",
    "varskodda": "varsko",
    "varskoddas": "varsko",
    "varskodde": "varsko",
    "varskoddes": "varsko",
    "varskodds": "varsko",
    "varskoende": "varsko",
    "varskoenden": "varskoende",
    "varskoendena": "varskoende",
    "varskoendenas": "varskoende",
    "varskoendens": "varskoende",
    "varskoendes": "varskoende",
    "varskoendet": "varskoende",
    "varskoendets": "varskoende",
    "varskor": "varsko",
    "varskos": "varsko",
    "varskott": "varsko",
    "varskotts": "varsko",
    "varslad": "varsla",
    "varslade": "varsla",
    "varslades": "varsla",
    "varslads": "varsla",
    "varslande": "varsla",
    "varslanden": "varslande",
    "varslandena": "varslande",
    "varslandenas": "varslande",
    "varslandens": "varslande",
    "varslandes": "varslande",
    "varslandet": "varslande",
    "varslandets": "varslande",
    "varslar": "varsla",
    "varslas": "varsla",
    "varslat": "varsla",
    "varslats": "varsla",
    "varslen": "varsel",
    "varslens": "varsel",
    "varslet": "varsel",
    "varslets": "varsel",
    "varsn": "varsna",
    "varsnad": "varsna",
    "varsnade": "varsna",
    "varsnades": "varsna",
    "varsnads": "varsna",
    "varsnande": "varsna",
    "varsnanden": "varsnande",
    "varsnandena": "varsnande",
    "varsnandenas": "varsnande",
    "varsnandens": "varsnande",
    "varsnandes": "varsnande",
    "varsnandet": "varsnande",
    "varsnandets": "varsnande",
    "varsnar": "varsna",
    "varsnas": "varsna",
    "varsnat": "varsna",
    "varsnats": "varsna",
    "vart": "varda",
    "vartannat": "varannan",
    "vartannats": "varannan",
    "vartdera": "vardera",
    "vartderas": "vardera",
    "vartenda": "varenda",
    "vartendas": "varenda",
    "varteviga": "vareviga",
    "vartevigas": "vareviga",
    "varts": "var",
    "varu": "vara",
    "varubelåningar": "varubelåning",
    "varubelåningarna": "varubelåning",
    "varubelåningarnas": "varubelåning",
    "varubelåningars": "varubelåning",
    "varubelåningen": "varubelåning",
    "varubelåningens": "varubelåning",
    "varubelånings": "varubelåning",
    "varubeteckningar": "varubeteckning",
    "varubeteckningarna": "varubeteckning",
    "varubeteckningarnas": "varubeteckning",
    "varubeteckningars": "varubeteckning",
    "varubeteckningen": "varubeteckning",
    "varubeteckningens": "varubeteckning",
    "varubetecknings": "varubeteckning",
    "varubilar": "varubil",
    "varubilarna": "varubil",
    "varubilarnas": "varubil",
    "varubilars": "varubil",
    "varubilen": "varubil",
    "varubilens": "varubil",
    "varubils": "varubil",
    "varubuden": "varubud",
    "varubudens": "varubud",
    "varubudet": "varubud",
    "varubudets": "varubud",
    "varubuds": "varubud",
    "varubussar": "varubuss",
    "varubussarna": "varubuss",
    "varubussarnas": "varubuss",
    "varubussars": "varubuss",
    "varubussen": "varubuss",
    "varubussens": "varubuss",
    "varudeklarationen": "varudeklaration",
    "varudeklarationens": "varudeklaration",
    "varudeklarationer": "varudeklaration",
    "varudeklarationerna": "varudeklaration",
    "varudeklarationernas": "varudeklaration",
    "varudeklarationers": "varudeklaration",
    "varudeklarations": "varudeklaration",
    "varudeklarationsnämnden": "varudeklarationsnämnd",
    "varudeklarationsnämndens": "varudeklarationsnämnd",
    "varudeklarationsnämnds": "varudeklarationsnämnd",
    "varudeklarerad": "varudeklarera",
    "varudeklarerade": "varudeklarera",
    "varudeklarerades": "varudeklarera",
    "varudeklarerads": "varudeklarera",
    "varudeklarerande": "varudeklarera",
    "varudeklareranden": "varudeklarerande",
    "varudeklarerandena": "varudeklarerande",
    "varudeklarerandenas": "varudeklarerande",
    "varudeklarerandens": "varudeklarerande",
    "varudeklarerandes": "varudeklarerande",
    "varudeklarerandet": "varudeklarerande",
    "varudeklarerandets": "varudeklarerande",
    "varudeklarerar": "varudeklarera",
    "varudeklareras": "varudeklarera",
    "varudeklarerat": "varudeklarera",
    "varudeklarerats": "varudeklarera",
    "varudeklarerbara": "varudeklarerbar",
    "varudeklarerbarare": "varudeklarerbar",
    "varudeklarerbarares": "varudeklarerbar",
    "varudeklarerbaras": "varudeklarerbar",
    "varudeklarerbarast": "varudeklarerbar",
    "varudeklarerbaraste": "varudeklarerbar",
    "varudeklarerbarastes": "varudeklarerbar",
    "varudeklarerbarasts": "varudeklarerbar",
    "varudeklarerbare": "varudeklarerbar",
    "varudeklarerbares": "varudeklarerbar",
    "varudeklarerbarheten": "varudeklarerbarhet",
    "varudeklarerbarhetens": "varudeklarerbarhet",
    "varudeklarerbarhets": "varudeklarerbarhet",
    "varudeklarerbars": "varudeklarerbar",
    "varudeklarerbart": "varudeklarerbar",
    "varudeklarerbarts": "varudeklarerbar",
    "varudeklareringar": "varudeklarering",
    "varudeklareringarna": "varudeklarering",
    "varudeklareringarnas": "varudeklarering",
    "varudeklareringars": "varudeklarering",
    "varudeklareringen": "varudeklarering",
    "varudeklareringens": "varudeklarering",
    "varudeklarerings": "varudeklarering",
    "varufaktan": "varufakta",
    "varufaktana": "varufakta",
    "varufaktanas": "varufakta",
    "varufaktans": "varufakta",
    "varufaktas": "varufakta",
    "varufaktat": "varufakta",
    "varufaktats": "varufakta",
    "varuhavar": "varuhavare",
    "varuhavaren": "varuhavare",
    "varuhavarens": "varuhavare",
    "varuhavares": "varuhavare",
    "varuhavarna": "varuhavare",
    "varuhavarnas": "varuhavare",
    "varuhusen": "varuhus",
    "varuhusens": "varuhus",
    "varuhuset": "varuhus",
    "varuhusets": "varuhus",
    "varuhyll": "varuhylla",
    "varuhyllan": "varuhylla",
    "varuhyllans": "varuhylla",
    "varuhyllas": "varuhylla",
    "varuhylle": "varuhylla",
    "varuhyllor": "varuhylla",
    "varuhyllorna": "varuhylla",
    "varuhyllornas": "varuhylla",
    "varuhyllors": "varuhylla",
    "varuhylls": "varuhylla",
    "varuintagen": "varuintag",
    "varuintagens": "varuintag",
    "varuintaget": "varuintag",
    "varuintagets": "varuintag",
    "varuintags": "varuintag",
    "varulvar": "varulv",
    "varulvarna": "varulv",
    "varulvarnas": "varulv",
    "varulvars": "varulv",
    "varulven": "varulv",
    "varulvens": "varulv",
    "varulvs": "varulv",
    "varulånen": "varulån",
    "varulånens": "varulån",
    "varulånet": "varulån",
    "varulånets": "varulån",
    "varulåns": "varulån",
    "varumängden": "varumängd",
    "varumängdens": "varumängd",
    "varumängder": "varumängd",
    "varumängderna": "varumängd",
    "varumängdernas": "varumängd",
    "varumängders": "varumängd",
    "varumängds": "varumängd",
    "varumärken": "varumärke",
    "varumärkena": "varumärke",
    "varumärkenas": "varumärke",
    "varumärkens": "varumärke",
    "varumärkes": "varumärke",
    "varumärkeshaverier": "varumärkeshaveri",
    "varumärkeshaverierna": "varumärkeshaveri",
    "varumärkeshaveriernas": "varumärkeshaveri",
    "varumärkeshaveriers": "varumärkeshaveri",
    "varumärkeshaveriet": "varumärkeshaveri",
    "varumärkeshaveriets": "varumärkeshaveri",
    "varumärkeshaveris": "varumärkeshaveri",
    "varumärkeshaverit": "varumärkeshaveri",
    "varumärkeshaverits": "varumärkeshaveri",
    "varumärket": "varumärke",
    "varumärkets": "varumärke",
    "varupartier": "varuparti",
    "varupartierna": "varuparti",
    "varupartiernas": "varuparti",
    "varupartiers": "varuparti",
    "varupartiet": "varuparti",
    "varupartiets": "varuparti",
    "varupartis": "varuparti",
    "varupartit": "varuparti",
    "varupartits": "varuparti",
    "varuprisen": "varupris",
    "varuprisens": "varupris",
    "varupriser": "varupris",
    "varupriserna": "varupris",
    "varuprisernas": "varupris",
    "varuprisers": "varupris",
    "varupriset": "varupris",
    "varuprisets": "varupris",
    "varuproven": "varuprov",
    "varuprovens": "varuprov",
    "varuprover": "varuprov",
    "varuproverna": "varuprov",
    "varuprovernas": "varuprov",
    "varuprovers": "varuprov",
    "varuprovet": "varuprov",
    "varuprovets": "varuprov",
    "varuprovs": "varuprov",
    "varuskatten": "varuskatt",
    "varuskattens": "varuskatt",
    "varuskatter": "varuskatt",
    "varuskatterna": "varuskatt",
    "varuskatternas": "varuskatt",
    "varuskatters": "varuskatt",
    "varuskatts": "varuskatt",
    "varutransporten": "varutransport",
    "varutransportens": "varutransport",
    "varutransporter": "varutransport",
    "varutransporterna": "varutransport",
    "varutransporternas": "varutransport",
    "varutransporters": "varutransport",
    "varutransports": "varutransport",
    "varuvagnar": "varuvagn",
    "varuvagnarna": "varuvagn",
    "varuvagnarnas": "varuvagn",
    "varuvagnars": "varuvagn",
    "varuvagnen": "varuvagn",
    "varuvagnens": "varuvagn",
    "varuvagns": "varuvagn",
    "varv": "varva",
    "varvad": "varva",
    "varvade": "varva",
    "varvades": "varva",
    "varvads": "varva",
    "varvande": "varva",
    "varvanden": "varvande",
    "varvandena": "varvande",
    "varvandenas": "varvande",
    "varvandens": "varvande",
    "varvandes": "varvande",
    "varvandet": "varvande",
    "varvandets": "varvande",
    "varvar": "varva",
    "varvas": "varva",
    "varvat": "varva",
    "varvats": "varva",
    "varven": "varv",
    "varvens": "varv",
    "varvet": "varv",
    "varvets": "varv",
    "varviga": "varvig",
    "varvigare": "varvig",
    "varvigares": "varvig",
    "varvigas": "varvig",
    "varvigast": "varvig",
    "varvigaste": "varvig",
    "varvigastes": "varvig",
    "varvigasts": "varvig",
    "varvige": "varvig",
    "varviges": "varvig",
    "varvigheten": "varvighet",
    "varvighetens": "varvighet",
    "varvighets": "varvighet",
    "varvigs": "varvig",
    "varvigt": "varvig",
    "varvigts": "varvig",
    "varvmätar": "varvmätare",
    "varvmätaren": "varvmätare",
    "varvmätarens": "varvmätare",
    "varvmätares": "varvmätare",
    "varvmätarna": "varvmätare",
    "varvmätarnas": "varvmätare",
    "varvräknar": "varvräknare",
    "varvräknaren": "varvräknare",
    "varvräknarens": "varvräknare",
    "varvräknares": "varvräknare",
    "varvräknarna": "varvräknare",
    "varvräknarnas": "varvräknare",
    "varvs": "varv",
    "varvsarbetar": "varvsarbetare",
    "varvsarbetaren": "varvsarbetare",
    "varvsarbetarens": "varvsarbetare",
    "varvsarbetares": "varvsarbetare",
    "varvsarbetarna": "varvsarbetare",
    "varvsarbetarnas": "varvsarbetare",
    "varvsflug": "varvsfluga",
    "varvsflugan": "varvsfluga",
    "varvsflugans": "varvsfluga",
    "varvsflugas": "varvsfluga",
    "varvsfluge": "varvsfluga",
    "varvsflugor": "varvsfluga",
    "varvsflugorna": "varvsfluga",
    "varvsflugornas": "varvsfluga",
    "varvsflugors": "varvsfluga",
    "varvsflugs": "varvsfluga",
    "varvsindustrien": "varvsindustri",
    "varvsindustriens": "varvsindustri",
    "varvsindustrier": "varvsindustri",
    "varvsindustrierna": "varvsindustri",
    "varvsindustriernas": "varvsindustri",
    "varvsindustriers": "varvsindustri",
    "varvsindustrin": "varvsindustri",
    "varvsindustrins": "varvsindustri",
    "varvsindustris": "varvsindustri",
    "varvtalen": "varvtal",
    "varvtalens": "varvtal",
    "varvtalet": "varvtal",
    "varvtalets": "varvtal",
    "varvtals": "varvtal",
    "vas": "vase",
    "vasallen": "vasall",
    "vasallens": "vasall",
    "vasaller": "vasall",
    "vasallerna": "vasall",
    "vasallernas": "vasall",
    "vasallers": "vasall",
    "vasalls": "vasall",
    "vasallstaten": "vasallstat",
    "vasallstatens": "vasallstat",
    "vasallstater": "vasallstat",
    "vasallstaterna": "vasallstat",
    "vasallstaternas": "vasallstat",
    "vasallstaters": "vasallstat",
    "vasallstats": "vasallstat",
    "vasaordnar": "vasaorden",
    "vasaordnarna": "vasaorden",
    "vasaordnarnas": "vasaorden",
    "vasaordnars": "vasaorden",
    "vasaordnen": "vasaorden",
    "vasaordnens": "vasaorden",
    "vasar": "vase",
    "vasarna": "vase",
    "vasarnas": "vase",
    "vasars": "vase",
    "vasektomien": "vasektomi",
    "vasektomiens": "vasektomi",
    "vasektomier": "vasektomi",
    "vasektomierna": "vasektomi",
    "vasektomiernas": "vasektomi",
    "vasektomiers": "vasektomi",
    "vasektomin": "vasektomi",
    "vasektomins": "vasektomi",
    "vasektomis": "vasektomi",
    "vaselinen": "vaselin",
    "vaselinens": "vaselin",
    "vaselinet": "vaselin",
    "vaselinets": "vaselin",
    "vaselins": "vaselin",
    "vasen": "vase",
    "vasens": "vase",
    "vaser": "vas",
    "vaserna": "vas",
    "vasernas": "vas",
    "vasers": "vas",
    "vases": "vase",
    "vask": "vaska",
    "vaskad": "vaska",
    "vaskade": "vaska",
    "vaskades": "vaska",
    "vaskads": "vaska",
    "vaskande": "vaska",
    "vaskanden": "vaskande",
    "vaskandena": "vaskande",
    "vaskandenas": "vaskande",
    "vaskandens": "vaskande",
    "vaskandes": "vaskande",
    "vaskandet": "vaskande",
    "vaskandets": "vaskande",
    "vaskar": "vasker",
    "vaskarna": "vasker",
    "vaskarnas": "vasker",
    "vaskars": "vasker",
    "vaskas": "vaska",
    "vaskat": "vaska",
    "vaskats": "vaska",
    "vasken": "vask",
    "vaskens": "vask",
    "vaskern": "vasker",
    "vaskerns": "vasker",
    "vaskers": "vasker",
    "vasket": "vask",
    "vaskets": "vask",
    "vaskmalmen": "vaskmalm",
    "vaskmalmens": "vaskmalm",
    "vaskmalms": "vaskmalm",
    "vaskrar": "vasker",
    "vaskrarna": "vasker",
    "vaskrarnas": "vasker",
    "vaskrars": "vasker",
    "vasks": "vask",
    "vaskulära": "vaskulär",
    "vaskulärare": "vaskulär",
    "vaskulärares": "vaskulär",
    "vaskuläras": "vaskulär",
    "vaskulärast": "vaskulär",
    "vaskuläraste": "vaskulär",
    "vaskulärastes": "vaskulär",
    "vaskulärasts": "vaskulär",
    "vaskuläre": "vaskulär",
    "vaskuläres": "vaskulär",
    "vaskulärs": "vaskulär",
    "vaskulärt": "vaskulär",
    "vaskulärts": "vaskulär",
    "vasografien": "vasografi",
    "vasografiens": "vasografi",
    "vasografin": "vasografi",
    "vasografins": "vasografi",
    "vasografis": "vasografi",
    "vasomotoriska": "vasomotorisk",
    "vasomotoriskare": "vasomotorisk",
    "vasomotoriskares": "vasomotorisk",
    "vasomotoriskas": "vasomotorisk",
    "vasomotoriskast": "vasomotorisk",
    "vasomotoriskaste": "vasomotorisk",
    "vasomotoriskastes": "vasomotorisk",
    "vasomotoriskasts": "vasomotorisk",
    "vasomotoriske": "vasomotorisk",
    "vasomotoriskes": "vasomotorisk",
    "vasomotorisks": "vasomotorisk",
    "vasomotoriskt": "vasomotorisk",
    "vasomotoriskts": "vasomotorisk",
    "vassa": "vass",
    "vassar": "vass",
    "vassare": "vass",
    "vassares": "vass",
    "vassarna": "vass",
    "vassarnas": "vass",
    "vassars": "vass",
    "vassas": "vass",
    "vassast": "vass",
    "vassaste": "vass",
    "vassastes": "vass",
    "vassasts": "vass",
    "vassbuken": "vassbuk",
    "vassbukens": "vassbuk",
    "vassbuks": "vassbuk",
    "vasse": "vass",
    "vassen": "vass",
    "vassens": "vass",
    "vasses": "vass",
    "vassgjord": "vassgöra",
    "vassgjorda": "vassgöra",
    "vassgjordas": "vassgöra",
    "vassgjorde": "vassgöra",
    "vassgjordes": "vassgöra",
    "vassgjords": "vassgöra",
    "vassgjort": "vassgöra",
    "vassgjorts": "vassgöra",
    "vassgör": "vassgöra",
    "vassgörande": "vassgöra",
    "vassgöranden": "vassgörande",
    "vassgörandena": "vassgörande",
    "vassgörandenas": "vassgörande",
    "vassgörandens": "vassgörande",
    "vassgörandes": "vassgörande",
    "vassgörandet": "vassgörande",
    "vassgörandets": "vassgörande",
    "vassgöras": "vassgöra",
    "vassgöres": "vassgöra",
    "vassgörs": "vassgöra",
    "vassheten": "vasshet",
    "vasshetens": "vasshet",
    "vasshets": "vasshet",
    "vasslan": "vassla",
    "vasslans": "vassla",
    "vasslas": "vassla",
    "vasslen": "vassle",
    "vasslens": "vassle",
    "vassles": "vassle",
    "vassliga": "vasslig",
    "vassligare": "vasslig",
    "vassligares": "vasslig",
    "vassligas": "vasslig",
    "vassligast": "vasslig",
    "vassligaste": "vasslig",
    "vassligastes": "vasslig",
    "vassligasts": "vasslig",
    "vasslige": "vasslig",
    "vassliges": "vasslig",
    "vassligheten": "vasslighet",
    "vasslighetens": "vasslighet",
    "vasslighets": "vasslighet",
    "vassligs": "vasslig",
    "vassligt": "vasslig",
    "vassligts": "vasslig",
    "vassrugg": "vassrugge",
    "vassruggar": "vassrugge",
    "vassruggarna": "vassrugge",
    "vassruggarnas": "vassrugge",
    "vassruggars": "vassrugge",
    "vassruggen": "vassrugge",
    "vassruggens": "vassrugge",
    "vassrugges": "vassrugge",
    "vassruggs": "vassrugge",
    "vassrören": "vassrör",
    "vassrörens": "vassrör",
    "vassröret": "vassrör",
    "vassrörets": "vassrör",
    "vassrörs": "vassrör",
    "vasst": "vass",
    "vassts": "vass",
    "vaterbommar": "vaterbom",
    "vaterbommarna": "vaterbom",
    "vaterbommarnas": "vaterbom",
    "vaterbommars": "vaterbom",
    "vaterbommen": "vaterbom",
    "vaterbommens": "vaterbom",
    "vaterboms": "vaterbom",
    "vaterborden": "vaterbord",
    "vaterbordens": "vaterbord",
    "vaterbordet": "vaterbord",
    "vaterbordets": "vaterbord",
    "vaterbords": "vaterbord",
    "vatikanska": "vatikansk",
    "vatikanskare": "vatikansk",
    "vatikanskares": "vatikansk",
    "vatikanskas": "vatikansk",
    "vatikanskast": "vatikansk",
    "vatikanskaste": "vatikansk",
    "vatikanskastes": "vatikansk",
    "vatikanskasts": "vatikansk",
    "vatikanske": "vatikansk",
    "vatikanskes": "vatikansk",
    "vatikansks": "vatikansk",
    "vatikanskt": "vatikansk",
    "vatikanskts": "vatikansk",
    "vattblåa": "vattblå",
    "vattblåare": "vattblå",
    "vattblåares": "vattblå",
    "vattblåas": "vattblå",
    "vattblåast": "vattblå",
    "vattblåaste": "vattblå",
    "vattblåastes": "vattblå",
    "vattblåasts": "vattblå",
    "vattblåe": "vattblå",
    "vattblåes": "vattblå",
    "vattblås": "vattblå",
    "vattblått": "vattblå",
    "vattblåtts": "vattblå",
    "vattenaloen": "vattenaloe",
    "vattenaloens": "vattenaloe",
    "vattenaloes": "vattenaloe",
    "vattenavläsningar": "vattenavläsning",
    "vattenavläsningarna": "vattenavläsning",
    "vattenavläsningarnas": "vattenavläsning",
    "vattenavläsningars": "vattenavläsning",
    "vattenavläsningen": "vattenavläsning",
    "vattenavläsningens": "vattenavläsning",
    "vattenavläsnings": "vattenavläsning",
    "vattenbaden": "vattenbad",
    "vattenbadens": "vattenbad",
    "vattenbadet": "vattenbad",
    "vattenbadets": "vattenbad",
    "vattenbads": "vattenbad",
    "vattenbaserade": "vattenbaserad",
    "vattenbaserades": "vattenbaserad",
    "vattenbaserads": "vattenbaserad",
    "vattenbaserat": "vattenbaserad",
    "vattenbaserats": "vattenbaserad",
    "vattenbehållar": "vattenbehållare",
    "vattenbehållaren": "vattenbehållare",
    "vattenbehållarens": "vattenbehållare",
    "vattenbehållares": "vattenbehållare",
    "vattenbehållarna": "vattenbehållare",
    "vattenbehållarnas": "vattenbehållare",
    "vattenbien": "vattenbi",
    "vattenbiens": "vattenbi",
    "vattenbiet": "vattenbi",
    "vattenbiets": "vattenbi",
    "vattenbin": "vattenbi",
    "vattenbina": "vattenbi",
    "vattenbinas": "vattenbi",
    "vattenbins": "vattenbi",
    "vattenbis": "vattenbi",
    "vattenbit": "vattenbi",
    "vattenbits": "vattenbi",
    "vattenblasket": "vattenblask",
    "vattenblaskets": "vattenblask",
    "vattenblasks": "vattenblask",
    "vattenblomningar": "vattenblomning",
    "vattenblomningarna": "vattenblomning",
    "vattenblomningarnas": "vattenblomning",
    "vattenblomningars": "vattenblomning",
    "vattenblomningen": "vattenblomning",
    "vattenblomningens": "vattenblomning",
    "vattenblomnings": "vattenblomning",
    "vattenblåa": "vattenblå",
    "vattenblåare": "vattenblå",
    "vattenblåares": "vattenblå",
    "vattenblåas": "vattenblå",
    "vattenblåast": "vattenblå",
    "vattenblåaste": "vattenblå",
    "vattenblåastes": "vattenblå",
    "vattenblåasts": "vattenblå",
    "vattenblåe": "vattenblå",
    "vattenblåes": "vattenblå",
    "vattenblås": "vattenblåsa",
    "vattenblåsan": "vattenblåsa",
    "vattenblåsans": "vattenblåsa",
    "vattenblåsas": "vattenblåsa",
    "vattenblåse": "vattenblåsa",
    "vattenblåsor": "vattenblåsa",
    "vattenblåsorna": "vattenblåsa",
    "vattenblåsornas": "vattenblåsa",
    "vattenblåsors": "vattenblåsa",
    "vattenblått": "vattenblå",
    "vattenblåtts": "vattenblå",
    "vattenbristen": "vattenbrist",
    "vattenbristens": "vattenbrist",
    "vattenbrister": "vattenbrist",
    "vattenbristerna": "vattenbrist",
    "vattenbristernas": "vattenbrist",
    "vattenbristers": "vattenbrist",
    "vattenbrists": "vattenbrist",
    "vattenbruken": "vattenbruk",
    "vattenbrukens": "vattenbruk",
    "vattenbruket": "vattenbruk",
    "vattenbrukets": "vattenbruk",
    "vattenbruks": "vattenbruk",
    "vattenbrynet": "vattenbryn",
    "vattenbrynets": "vattenbryn",
    "vattenbryns": "vattenbryn",
    "vattenburens": "vattenburen",
    "vattenburet": "vattenburen",
    "vattenburets": "vattenburen",
    "vattenburna": "vattenburen",
    "vattenburnare": "vattenburen",
    "vattenburnares": "vattenburen",
    "vattenburnas": "vattenburen",
    "vattenburnast": "vattenburen",
    "vattenburnaste": "vattenburen",
    "vattenburnastes": "vattenburen",
    "vattenburnasts": "vattenburen",
    "vattenburne": "vattenburen",
    "vattenburnes": "vattenburen",
    "vattenbyggnaden": "vattenbyggnad",
    "vattenbyggnadens": "vattenbyggnad",
    "vattenbyggnader": "vattenbyggnad",
    "vattenbyggnaderna": "vattenbyggnad",
    "vattenbyggnadernas": "vattenbyggnad",
    "vattenbyggnaders": "vattenbyggnad",
    "vattenbyggnads": "vattenbyggnad",
    "vattenbyggnadskonsten": "vattenbyggnadskonst",
    "vattenbyggnadskonstens": "vattenbyggnadskonst",
    "vattenbyggnadskonsts": "vattenbyggnadskonst",
    "vattencykeln": "vattencykel",
    "vattencykelns": "vattencykel",
    "vattencykels": "vattencykel",
    "vattencyklar": "vattencykel",
    "vattencyklarna": "vattencykel",
    "vattencyklarnas": "vattencykel",
    "vattencyklars": "vattencykel",
    "vattendelar": "vattendelare",
    "vattendelaren": "vattendelare",
    "vattendelarens": "vattendelare",
    "vattendelares": "vattendelare",
    "vattendelarna": "vattendelare",
    "vattendelarnas": "vattendelare",
    "vattendjupen": "vattendjup",
    "vattendjupens": "vattendjup",
    "vattendjupet": "vattendjup",
    "vattendjupets": "vattendjup",
    "vattendjups": "vattendjup",
    "vattendjuren": "vattendjur",
    "vattendjurens": "vattendjur",
    "vattendjuret": "vattendjur",
    "vattendjurets": "vattendjur",
    "vattendjurs": "vattendjur",
    "vattendomstolar": "vattendomstol",
    "vattendomstolarna": "vattendomstol",
    "vattendomstolarnas": "vattendomstol",
    "vattendomstolars": "vattendomstol",
    "vattendomstolen": "vattendomstol",
    "vattendomstolens": "vattendomstol",
    "vattendomstols": "vattendomstol",
    "vattendragen": "vattendrag",
    "vattendragens": "vattendrag",
    "vattendraget": "vattendrag",
    "vattendragets": "vattendrag",
    "vattendrags": "vattendrag",
    "vattendrivens": "vattendriven",
    "vattendrivet": "vattendriven",
    "vattendrivets": "vattendriven",
    "vattendrivna": "vattendriven",
    "vattendrivnare": "vattendriven",
    "vattendrivnares": "vattendriven",
    "vattendrivnas": "vattendriven",
    "vattendrivnast": "vattendriven",
    "vattendrivnaste": "vattendriven",
    "vattendrivnastes": "vattendriven",
    "vattendrivnasts": "vattendriven",
    "vattendrivne": "vattendriven",
    "vattendrivnes": "vattendriven",
    "vattendropp": "vattendroppe",
    "vattendroppar": "vattendroppe",
    "vattendropparna": "vattendroppe",
    "vattendropparnas": "vattendroppe",
    "vattendroppars": "vattendroppe",
    "vattendroppen": "vattendroppe",
    "vattendroppens": "vattendroppe",
    "vattendroppes": "vattendroppe",
    "vattendropps": "vattendroppe",
    "vattenfallen": "vattenfall",
    "vattenfallens": "vattenfall",
    "vattenfallet": "vattenfall",
    "vattenfallets": "vattenfall",
    "vattenfalls": "vattenfall",
    "vattenfasen": "vattenfas",
    "vattenfasens": "vattenfas",
    "vattenfaser": "vattenfas",
    "vattenfaserna": "vattenfas",
    "vattenfasernas": "vattenfas",
    "vattenfasers": "vattenfas",
    "vattenfasta": "vattenfast",
    "vattenfastare": "vattenfast",
    "vattenfastares": "vattenfast",
    "vattenfastas": "vattenfast",
    "vattenfastast": "vattenfast",
    "vattenfastaste": "vattenfast",
    "vattenfastastes": "vattenfast",
    "vattenfastasts": "vattenfast",
    "vattenfaste": "vattenfast",
    "vattenfastes": "vattenfast",
    "vattenfastheten": "vattenfasthet",
    "vattenfasthetens": "vattenfasthet",
    "vattenfasthets": "vattenfasthet",
    "vattenfasts": "vattenfast",
    "vattenflask": "vattenflaska",
    "vattenflaskan": "vattenflaska",
    "vattenflaskans": "vattenflaska",
    "vattenflaskas": "vattenflaska",
    "vattenflaske": "vattenflaska",
    "vattenflaskor": "vattenflaska",
    "vattenflaskorna": "vattenflaska",
    "vattenflaskornas": "vattenflaska",
    "vattenflaskors": "vattenflaska",
    "vattenflöden": "vattenflöde",
    "vattenflödena": "vattenflöde",
    "vattenflödenas": "vattenflöde",
    "vattenflödens": "vattenflöde",
    "vattenflödes": "vattenflöde",
    "vattenflödet": "vattenflöde",
    "vattenflödets": "vattenflöde",
    "vattenfyllda": "vattenfylld",
    "vattenfylldare": "vattenfylld",
    "vattenfylldares": "vattenfylld",
    "vattenfylldas": "vattenfylld",
    "vattenfylldast": "vattenfylld",
    "vattenfylldaste": "vattenfylld",
    "vattenfylldastes": "vattenfylld",
    "vattenfylldasts": "vattenfylld",
    "vattenfyllde": "vattenfylld",
    "vattenfylldes": "vattenfylld",
    "vattenfyllds": "vattenfylld",
    "vattenfyllt": "vattenfylld",
    "vattenfyllts": "vattenfylld",
    "vattenfärgen": "vattenfärg",
    "vattenfärgens": "vattenfärg",
    "vattenfärger": "vattenfärg",
    "vattenfärgerna": "vattenfärg",
    "vattenfärgernas": "vattenfärg",
    "vattenfärgers": "vattenfärg",
    "vattenfärgs": "vattenfärg",
    "vattenfågeln": "vattenfågel",
    "vattenfågelns": "vattenfågel",
    "vattenfågels": "vattenfågel",
    "vattenfåglar": "vattenfågel",
    "vattenfåglarna": "vattenfågel",
    "vattenfåglarnas": "vattenfågel",
    "vattenfåglars": "vattenfågel",
    "vattenförbrukningen": "vattenförbrukning",
    "vattenförbrukningens": "vattenförbrukning",
    "vattenförbruknings": "vattenförbrukning",
    "vattenföroreningar": "vattenförorening",
    "vattenföroreningarna": "vattenförorening",
    "vattenföroreningarnas": "vattenförorening",
    "vattenföroreningars": "vattenförorening",
    "vattenföroreningen": "vattenförorening",
    "vattenföroreningens": "vattenförorening",
    "vattenförorenings": "vattenförorening",
    "vattengeler": "vattengel",
    "vattengelerna": "vattengel",
    "vattengelernas": "vattengel",
    "vattengelers": "vattengel",
    "vattengelet": "vattengel",
    "vattengelets": "vattengel",
    "vattengels": "vattengel",
    "vattenglasen": "vattenglas",
    "vattenglasens": "vattenglas",
    "vattenglaset": "vattenglas",
    "vattenglasets": "vattenglas",
    "vattenhalten": "vattenhalt",
    "vattenhaltens": "vattenhalt",
    "vattenhalter": "vattenhalt",
    "vattenhalterna": "vattenhalt",
    "vattenhalternas": "vattenhalt",
    "vattenhalters": "vattenhalt",
    "vattenhalts": "vattenhalt",
    "vattenhjulen": "vattenhjul",
    "vattenhjulens": "vattenhjul",
    "vattenhjulet": "vattenhjul",
    "vattenhjulets": "vattenhjul",
    "vattenhjuls": "vattenhjul",
    "vattenhyacinten": "vattenhyacint",
    "vattenhyacintens": "vattenhyacint",
    "vattenhyacinter": "vattenhyacint",
    "vattenhyacinterna": "vattenhyacint",
    "vattenhyacinternas": "vattenhyacint",
    "vattenhyacinters": "vattenhyacint",
    "vattenhyacints": "vattenhyacint",
    "vattenhålen": "vattenhål",
    "vattenhålens": "vattenhål",
    "vattenhålet": "vattenhål",
    "vattenhålets": "vattenhål",
    "vattenhåls": "vattenhål",
    "vattenhöljen": "vattenhölje",
    "vattenhöljena": "vattenhölje",
    "vattenhöljenas": "vattenhölje",
    "vattenhöljens": "vattenhölje",
    "vattenhöljes": "vattenhölje",
    "vattenhöljet": "vattenhölje",
    "vattenhöljets": "vattenhölje",
    "vattenhöljs": "vattenhölje",
    "vattenkammad": "vattenkamma",
    "vattenkammade": "vattenkamma",
    "vattenkammades": "vattenkamma",
    "vattenkammads": "vattenkamma",
    "vattenkammande": "vattenkamma",
    "vattenkammanden": "vattenkammande",
    "vattenkammandena": "vattenkammande",
    "vattenkammandenas": "vattenkammande",
    "vattenkammandens": "vattenkammande",
    "vattenkammandes": "vattenkammande",
    "vattenkammandet": "vattenkammande",
    "vattenkammandets": "vattenkammande",
    "vattenkammar": "vattenkamma",
    "vattenkammas": "vattenkamma",
    "vattenkammat": "vattenkamma",
    "vattenkammats": "vattenkamma",
    "vattenkannan": "vattenkanna",
    "vattenkannans": "vattenkanna",
    "vattenkannas": "vattenkanna",
    "vattenkanne": "vattenkanna",
    "vattenkannor": "vattenkanna",
    "vattenkannorna": "vattenkanna",
    "vattenkannornas": "vattenkanna",
    "vattenkannors": "vattenkanna",
    "vattenkanonen": "vattenkanon",
    "vattenkanonens": "vattenkanon",
    "vattenkanoner": "vattenkanon",
    "vattenkanonerna": "vattenkanon",
    "vattenkanonernas": "vattenkanon",
    "vattenkanoners": "vattenkanon",
    "vattenkanons": "vattenkanon",
    "vattenkastningen": "vattenkastning",
    "vattenkastningens": "vattenkastning",
    "vattenkastnings": "vattenkastning",
    "vattenklosetten": "vattenklosett",
    "vattenklosettens": "vattenklosett",
    "vattenklosetter": "vattenklosett",
    "vattenklosetterna": "vattenklosett",
    "vattenklosetternas": "vattenklosett",
    "vattenklosetters": "vattenklosett",
    "vattenklosetts": "vattenklosett",
    "vattenklövern": "vattenklöver",
    "vattenklöverns": "vattenklöver",
    "vattenklövers": "vattenklöver",
    "vattenkokar": "vattenkokare",
    "vattenkokaren": "vattenkokare",
    "vattenkokarens": "vattenkokare",
    "vattenkokares": "vattenkokare",
    "vattenkokarna": "vattenkokare",
    "vattenkokarnas": "vattenkokare",
    "vattenkopplingar": "vattenkoppling",
    "vattenkopplingarna": "vattenkoppling",
    "vattenkopplingarnas": "vattenkoppling",
    "vattenkopplingars": "vattenkoppling",
    "vattenkopplingen": "vattenkoppling",
    "vattenkopplingens": "vattenkoppling",
    "vattenkopplings": "vattenkoppling",
    "vattenkopporna": "vattenkoppor",
    "vattenkoppornas": "vattenkoppor",
    "vattenkoppors": "vattenkoppor",
    "vattenkopps": "vattenkoppor",
    "vattenkraften": "vattenkraft",
    "vattenkraftens": "vattenkraft",
    "vattenkrafts": "vattenkraft",
    "vattenkraftverken": "vattenkraftverk",
    "vattenkraftverkens": "vattenkraftverk",
    "vattenkraftverket": "vattenkraftverk",
    "vattenkraftverkets": "vattenkraftverk",
    "vattenkraftverks": "vattenkraftverk",
    "vattenkranar": "vattenkran",
    "vattenkranarna": "vattenkran",
    "vattenkranarnas": "vattenkran",
    "vattenkranars": "vattenkran",
    "vattenkranen": "vattenkran",
    "vattenkranens": "vattenkran",
    "vattenkrans": "vattenkran",
    "vattenkrassen": "vattenkrasse",
    "vattenkrassens": "vattenkrasse",
    "vattenkrasses": "vattenkrasse",
    "vattenkulturen": "vattenkultur",
    "vattenkulturens": "vattenkultur",
    "vattenkulturer": "vattenkultur",
    "vattenkulturerna": "vattenkultur",
    "vattenkulturernas": "vattenkultur",
    "vattenkulturers": "vattenkultur",
    "vattenkulturs": "vattenkultur",
    "vattenkvarnar": "vattenkvarn",
    "vattenkvarnarna": "vattenkvarn",
    "vattenkvarnarnas": "vattenkvarn",
    "vattenkvarnars": "vattenkvarn",
    "vattenkvarnen": "vattenkvarn",
    "vattenkvarnens": "vattenkvarn",
    "vattenkvarns": "vattenkvarn",
    "vattenkylda": "vattenkyld",
    "vattenkyldare": "vattenkyld",
    "vattenkyldares": "vattenkyld",
    "vattenkyldas": "vattenkyld",
    "vattenkyldast": "vattenkyld",
    "vattenkyldaste": "vattenkyld",
    "vattenkyldastes": "vattenkyld",
    "vattenkyldasts": "vattenkyld",
    "vattenkylde": "vattenkyld",
    "vattenkyldes": "vattenkyld",
    "vattenkylds": "vattenkyld",
    "vattenkylt": "vattenkyld",
    "vattenkylts": "vattenkyld",
    "vattenkäll": "vattenkälla",
    "vattenkällan": "vattenkälla",
    "vattenkällans": "vattenkälla",
    "vattenkällas": "vattenkälla",
    "vattenkälle": "vattenkälla",
    "vattenkällor": "vattenkälla",
    "vattenkällorna": "vattenkälla",
    "vattenkällornas": "vattenkälla",
    "vattenkällors": "vattenkälla",
    "vattenkälls": "vattenkälla",
    "vattenkänsliga": "vattenkänslig",
    "vattenkänsligare": "vattenkänslig",
    "vattenkänsligares": "vattenkänslig",
    "vattenkänsligas": "vattenkänslig",
    "vattenkänsligast": "vattenkänslig",
    "vattenkänsligaste": "vattenkänslig",
    "vattenkänsligastes": "vattenkänslig",
    "vattenkänsligasts": "vattenkänslig",
    "vattenkänslige": "vattenkänslig",
    "vattenkänsliges": "vattenkänslig",
    "vattenkänsligheten": "vattenkänslighet",
    "vattenkänslighetens": "vattenkänslighet",
    "vattenkänslighets": "vattenkänslighet",
    "vattenkänsligs": "vattenkänslig",
    "vattenkänsligt": "vattenkänslig",
    "vattenkänsligts": "vattenkänslig",
    "vattenleden": "vattenled",
    "vattenledens": "vattenled",
    "vattenleder": "vattenled",
    "vattenlederna": "vattenled",
    "vattenledernas": "vattenled",
    "vattenleders": "vattenled",
    "vattenledningar": "vattenledning",
    "vattenledningarna": "vattenledning",
    "vattenledningarnas": "vattenledning",
    "vattenledningars": "vattenledning",
    "vattenledningen": "vattenledning",
    "vattenledningens": "vattenledning",
    "vattenlednings": "vattenledning",
    "vattenledningsvattens": "vattenledningsvatten",
    "vattenledningsvattnen": "vattenledningsvatten",
    "vattenledningsvattnens": "vattenledningsvatten",
    "vattenledningsvattnet": "vattenledningsvatten",
    "vattenledningsvattnets": "vattenledningsvatten",
    "vattenleds": "vattenled",
    "vattenlinjen": "vattenlinje",
    "vattenlinjens": "vattenlinje",
    "vattenlinjer": "vattenlinje",
    "vattenlinjerna": "vattenlinje",
    "vattenlinjernas": "vattenlinje",
    "vattenlinjers": "vattenlinje",
    "vattenlinjes": "vattenlinje",
    "vattenlisten": "vattenlist",
    "vattenlistens": "vattenlist",
    "vattenlister": "vattenlist",
    "vattenlisterna": "vattenlist",
    "vattenlisternas": "vattenlist",
    "vattenlisters": "vattenlist",
    "vattenlists": "vattenlist",
    "vattenlopp": "vattenloppa",
    "vattenloppan": "vattenloppa",
    "vattenloppans": "vattenloppa",
    "vattenloppas": "vattenloppa",
    "vattenloppe": "vattenloppa",
    "vattenloppor": "vattenloppa",
    "vattenlopporna": "vattenloppa",
    "vattenloppornas": "vattenloppa",
    "vattenloppors": "vattenloppa",
    "vattenlopps": "vattenloppa",
    "vattenläck": "vattenläcka",
    "vattenläckan": "vattenläcka",
    "vattenläckans": "vattenläcka",
    "vattenläckas": "vattenläcka",
    "vattenläcke": "vattenläcka",
    "vattenläckor": "vattenläcka",
    "vattenläckorna": "vattenläcka",
    "vattenläckornas": "vattenläcka",
    "vattenläckors": "vattenläcka",
    "vattenläcks": "vattenläcka",
    "vattenlåsen": "vattenlås",
    "vattenlåsens": "vattenlås",
    "vattenlåset": "vattenlås",
    "vattenlåsets": "vattenlås",
    "vattenlöpar": "vattenlöpare",
    "vattenlöparen": "vattenlöpare",
    "vattenlöparens": "vattenlöpare",
    "vattenlöpares": "vattenlöpare",
    "vattenlöparna": "vattenlöpare",
    "vattenlöparnas": "vattenlöpare",
    "vattenlösliga": "vattenlöslig",
    "vattenlösligare": "vattenlöslig",
    "vattenlösligares": "vattenlöslig",
    "vattenlösligas": "vattenlöslig",
    "vattenlösligast": "vattenlöslig",
    "vattenlösligaste": "vattenlöslig",
    "vattenlösligastes": "vattenlöslig",
    "vattenlösligasts": "vattenlöslig",
    "vattenlöslige": "vattenlöslig",
    "vattenlösliges": "vattenlöslig",
    "vattenlösligheten": "vattenlöslighet",
    "vattenlöslighetens": "vattenlöslighet",
    "vattenlösligheter": "vattenlöslighet",
    "vattenlösligheterna": "vattenlöslighet",
    "vattenlösligheternas": "vattenlöslighet",
    "vattenlösligheters": "vattenlöslighet",
    "vattenlöslighets": "vattenlöslighet",
    "vattenlösligs": "vattenlöslig",
    "vattenlösligt": "vattenlöslig",
    "vattenlösligts": "vattenlöslig",
    "vattenlösningar": "vattenlösning",
    "vattenlösningarna": "vattenlösning",
    "vattenlösningarnas": "vattenlösning",
    "vattenlösningars": "vattenlösning",
    "vattenlösningen": "vattenlösning",
    "vattenlösningens": "vattenlösning",
    "vattenlösnings": "vattenlösning",
    "vattenmassan": "vattenmassa",
    "vattenmassans": "vattenmassa",
    "vattenmassas": "vattenmassa",
    "vattenmasse": "vattenmassa",
    "vattenmassor": "vattenmassa",
    "vattenmassorna": "vattenmassa",
    "vattenmassornas": "vattenmassa",
    "vattenmassors": "vattenmassa",
    "vattenmelonen": "vattenmelon",
    "vattenmelonens": "vattenmelon",
    "vattenmeloner": "vattenmelon",
    "vattenmelonerna": "vattenmelon",
    "vattenmelonernas": "vattenmelon",
    "vattenmeloners": "vattenmelon",
    "vattenmelons": "vattenmelon",
    "vattenmotståndet": "vattenmotstånd",
    "vattenmotståndets": "vattenmotstånd",
    "vattenmotstånds": "vattenmotstånd",
    "vattenmärken": "vattenmärke",
    "vattenmärkena": "vattenmärke",
    "vattenmärkenas": "vattenmärke",
    "vattenmärkens": "vattenmärke",
    "vattenmärkes": "vattenmärke",
    "vattenmärket": "vattenmärke",
    "vattenmärkets": "vattenmärke",
    "vattennivåer": "vattennivå",
    "vattennivåerna": "vattennivå",
    "vattennivåernas": "vattennivå",
    "vattennivåers": "vattennivå",
    "vattennivån": "vattennivå",
    "vattennivåns": "vattennivå",
    "vattennivås": "vattennivå",
    "vattennymfen": "vattennymf",
    "vattennymfens": "vattennymf",
    "vattennymfer": "vattennymf",
    "vattennymferna": "vattennymf",
    "vattennymfernas": "vattennymf",
    "vattennymfers": "vattennymf",
    "vattennymfs": "vattennymf",
    "vattenorganismen": "vattenorganism",
    "vattenorganismens": "vattenorganism",
    "vattenorganismer": "vattenorganism",
    "vattenorganismerna": "vattenorganism",
    "vattenorganismernas": "vattenorganism",
    "vattenorganismers": "vattenorganism",
    "vattenorganisms": "vattenorganism",
    "vattenpassen": "vattenpass",
    "vattenpassens": "vattenpass",
    "vattenpasset": "vattenpass",
    "vattenpassets": "vattenpass",
    "vattenpelar": "vattenpelare",
    "vattenpelaren": "vattenpelare",
    "vattenpelarens": "vattenpelare",
    "vattenpelares": "vattenpelare",
    "vattenpelarna": "vattenpelare",
    "vattenpelarnas": "vattenpelare",
    "vattenpesten": "vattenpest",
    "vattenpestens": "vattenpest",
    "vattenpests": "vattenpest",
    "vattenpip": "vattenpipa",
    "vattenpipan": "vattenpipa",
    "vattenpipans": "vattenpipa",
    "vattenpipas": "vattenpipa",
    "vattenpipe": "vattenpipa",
    "vattenpipor": "vattenpipa",
    "vattenpiporna": "vattenpipa",
    "vattenpipornas": "vattenpipa",
    "vattenpipors": "vattenpipa",
    "vattenpips": "vattenpipa",
    "vattenpistolen": "vattenpistol",
    "vattenpistolens": "vattenpistol",
    "vattenpistoler": "vattenpistol",
    "vattenpistolerna": "vattenpistol",
    "vattenpistolernas": "vattenpistol",
    "vattenpistolers": "vattenpistol",
    "vattenpistols": "vattenpistol",
    "vattenplaningen": "vattenplaning",
    "vattenplaningens": "vattenplaning",
    "vattenplanings": "vattenplaning",
    "vattenpolon": "vattenpolo",
    "vattenpolons": "vattenpolo",
    "vattenpolos": "vattenpolo",
    "vattenposten": "vattenpost",
    "vattenpostens": "vattenpost",
    "vattenposter": "vattenpost",
    "vattenposterna": "vattenpost",
    "vattenposternas": "vattenpost",
    "vattenposters": "vattenpost",
    "vattenposts": "vattenpost",
    "vattenproven": "vattenprov",
    "vattenprovens": "vattenprov",
    "vattenprover": "vattenprov",
    "vattenproverna": "vattenprov",
    "vattenprovernas": "vattenprov",
    "vattenprovers": "vattenprov",
    "vattenprovet": "vattenprov",
    "vattenprovets": "vattenprov",
    "vattenprovs": "vattenprov",
    "vattenpumpar": "vattenpump",
    "vattenpumparna": "vattenpump",
    "vattenpumparnas": "vattenpump",
    "vattenpumpars": "vattenpump",
    "vattenpumpen": "vattenpump",
    "vattenpumpens": "vattenpump",
    "vattenpumps": "vattenpump",
    "vattenpussar": "vattenpuss",
    "vattenpussarna": "vattenpuss",
    "vattenpussarnas": "vattenpuss",
    "vattenpussars": "vattenpuss",
    "vattenpussen": "vattenpuss",
    "vattenpussens": "vattenpuss",
    "vattenpölar": "vattenpöl",
    "vattenpölarna": "vattenpöl",
    "vattenpölarnas": "vattenpöl",
    "vattenpölars": "vattenpöl",
    "vattenpölen": "vattenpöl",
    "vattenpölens": "vattenpöl",
    "vattenpöls": "vattenpöl",
    "vattenrallar": "vattenrallare",
    "vattenrallaren": "vattenrallare",
    "vattenrallarens": "vattenrallare",
    "vattenrallares": "vattenrallare",
    "vattenrallarna": "vattenrallare",
    "vattenrallarnas": "vattenrallare",
    "vattenregleringar": "vattenreglering",
    "vattenregleringarna": "vattenreglering",
    "vattenregleringarnas": "vattenreglering",
    "vattenregleringars": "vattenreglering",
    "vattenregleringen": "vattenreglering",
    "vattenregleringens": "vattenreglering",
    "vattenreglerings": "vattenreglering",
    "vattenreningar": "vattenrening",
    "vattenreningarna": "vattenrening",
    "vattenreningarnas": "vattenrening",
    "vattenreningars": "vattenrening",
    "vattenreningen": "vattenrening",
    "vattenreningens": "vattenrening",
    "vattenrenings": "vattenrening",
    "vattenreningsverken": "vattenreningsverk",
    "vattenreningsverkens": "vattenreningsverk",
    "vattenreningsverket": "vattenreningsverk",
    "vattenreningsverkets": "vattenreningsverk",
    "vattenreningsverks": "vattenreningsverk",
    "vattenringar": "vattenring",
    "vattenringarna": "vattenring",
    "vattenringarnas": "vattenring",
    "vattenringars": "vattenring",
    "vattenringen": "vattenring",
    "vattenringens": "vattenring",
    "vattenrings": "vattenring",
    "vattenränn": "vattenränna",
    "vattenrännan": "vattenränna",
    "vattenrännans": "vattenränna",
    "vattenrännas": "vattenränna",
    "vattenränne": "vattenränna",
    "vattenrännor": "vattenränna",
    "vattenrännorna": "vattenränna",
    "vattenrännornas": "vattenränna",
    "vattenrännors": "vattenränna",
    "vattenränns": "vattenränna",
    "vattenrätten": "vattenrätt",
    "vattenrättens": "vattenrätt",
    "vattenrätts": "vattenrätt",
    "vattens": "vatten",
    "vattensalamandern": "vattensalamander",
    "vattensalamanderns": "vattensalamander",
    "vattensalamanders": "vattensalamander",
    "vattensalamandrar": "vattensalamander",
    "vattensalamandrarna": "vattensalamander",
    "vattensalamandrarnas": "vattensalamander",
    "vattensalamandrars": "vattensalamander",
    "vattensamlingar": "vattensamling",
    "vattensamlingarna": "vattensamling",
    "vattensamlingarnas": "vattensamling",
    "vattensamlingars": "vattensamling",
    "vattensamlingen": "vattensamling",
    "vattensamlingens": "vattensamling",
    "vattensamlings": "vattensamling",
    "vattensjuka": "vattensjuk",
    "vattensjukare": "vattensjuk",
    "vattensjukares": "vattensjuk",
    "vattensjukas": "vattensjuk",
    "vattensjukast": "vattensjuk",
    "vattensjukaste": "vattensjuk",
    "vattensjukastes": "vattensjuk",
    "vattensjukasts": "vattensjuk",
    "vattensjuke": "vattensjuk",
    "vattensjukes": "vattensjuk",
    "vattensjukheten": "vattensjukhet",
    "vattensjukhetens": "vattensjukhet",
    "vattensjukhets": "vattensjukhet",
    "vattensjuks": "vattensjuk",
    "vattensjukt": "vattensjuk",
    "vattensjukts": "vattensjuk",
    "vattenskall": "vattenskalle",
    "vattenskallar": "vattenskalle",
    "vattenskallarna": "vattenskalle",
    "vattenskallarnas": "vattenskalle",
    "vattenskallars": "vattenskalle",
    "vattenskallen": "vattenskalle",
    "vattenskallens": "vattenskalle",
    "vattenskalles": "vattenskalle",
    "vattenskalls": "vattenskalle",
    "vattenskid": "vattenskida",
    "vattenskidan": "vattenskida",
    "vattenskidans": "vattenskida",
    "vattenskidas": "vattenskida",
    "vattenskide": "vattenskida",
    "vattenskidor": "vattenskida",
    "vattenskidorna": "vattenskida",
    "vattenskidornas": "vattenskida",
    "vattenskidors": "vattenskida",
    "vattenskids": "vattenskida",
    "vattenskinnbagg": "vattenskinnbagge",
    "vattenskinnbaggar": "vattenskinnbagge",
    "vattenskinnbaggarna": "vattenskinnbagge",
    "vattenskinnbaggarnas": "vattenskinnbagge",
    "vattenskinnbaggars": "vattenskinnbagge",
    "vattenskinnbaggen": "vattenskinnbagge",
    "vattenskinnbaggens": "vattenskinnbagge",
    "vattenskinnbagges": "vattenskinnbagge",
    "vattenskinnbaggs": "vattenskinnbagge",
    "vattenskotten": "vattenskott",
    "vattenskottens": "vattenskott",
    "vattenskottet": "vattenskott",
    "vattenskottets": "vattenskott",
    "vattenskotts": "vattenskott",
    "vattenslangar": "vattenslang",
    "vattenslangarna": "vattenslang",
    "vattenslangarnas": "vattenslang",
    "vattenslangars": "vattenslang",
    "vattenslangen": "vattenslang",
    "vattenslangens": "vattenslang",
    "vattenslangs": "vattenslang",
    "vattenspegeln": "vattenspegel",
    "vattenspegelns": "vattenspegel",
    "vattenspegels": "vattenspegel",
    "vattenspindeln": "vattenspindel",
    "vattenspindelns": "vattenspindel",
    "vattenspindels": "vattenspindel",
    "vattenspindlar": "vattenspindel",
    "vattenspindlarna": "vattenspindel",
    "vattenspindlarnas": "vattenspindel",
    "vattenspindlars": "vattenspindel",
    "vattenspridar": "vattenspridare",
    "vattenspridaren": "vattenspridare",
    "vattenspridarens": "vattenspridare",
    "vattenspridares": "vattenspridare",
    "vattenspridarna": "vattenspridare",
    "vattenspridarnas": "vattenspridare",
    "vattensprut": "vattenspruta",
    "vattensprutan": "vattenspruta",
    "vattensprutans": "vattenspruta",
    "vattensprutas": "vattenspruta",
    "vattensprute": "vattenspruta",
    "vattensprutor": "vattenspruta",
    "vattensprutorna": "vattenspruta",
    "vattensprutornas": "vattenspruta",
    "vattensprutors": "vattenspruta",
    "vattenspruts": "vattenspruta",
    "vattenstrål": "vattenstråle",
    "vattenstrålar": "vattenstråle",
    "vattenstrålarna": "vattenstråle",
    "vattenstrålarnas": "vattenstråle",
    "vattenstrålars": "vattenstråle",
    "vattenstrålen": "vattenstråle",
    "vattenstrålens": "vattenstråle",
    "vattenstråles": "vattenstråle",
    "vattenstråls": "vattenstråle",
    "vattenströmmar": "vattenström",
    "vattenströmmarna": "vattenström",
    "vattenströmmarnas": "vattenström",
    "vattenströmmars": "vattenström",
    "vattenströmmen": "vattenström",
    "vattenströmmens": "vattenström",
    "vattenströms": "vattenström",
    "vattenstämpeln": "vattenstämpel",
    "vattenstämpelns": "vattenstämpel",
    "vattenstämpels": "vattenstämpel",
    "vattenstämplar": "vattenstämpel",
    "vattenstämplarna": "vattenstämpel",
    "vattenstämplarnas": "vattenstämpel",
    "vattenstämplars": "vattenstämpel",
    "vattenstänken": "vattenstänk",
    "vattenstänkens": "vattenstänk",
    "vattenstänket": "vattenstänk",
    "vattenstänkets": "vattenstänk",
    "vattenstänks": "vattenstänk",
    "vattenstånden": "vattenstånd",
    "vattenståndens": "vattenstånd",
    "vattenståndet": "vattenstånd",
    "vattenståndets": "vattenstånd",
    "vattenstånds": "vattenstånd",
    "vattenståndsrören": "vattenståndsrör",
    "vattenståndsrörens": "vattenståndsrör",
    "vattenståndsröret": "vattenståndsrör",
    "vattenståndsrörets": "vattenståndsrör",
    "vattenståndsrörs": "vattenståndsrör",
    "vattenståndsvisar": "vattenståndsvisare",
    "vattenståndsvisaren": "vattenståndsvisare",
    "vattenståndsvisarens": "vattenståndsvisare",
    "vattenståndsvisares": "vattenståndsvisare",
    "vattenståndsvisarna": "vattenståndsvisare",
    "vattenståndsvisarnas": "vattenståndsvisare",
    "vattensvinen": "vattensvin",
    "vattensvinens": "vattensvin",
    "vattensvinet": "vattensvin",
    "vattensvinets": "vattensvin",
    "vattensvins": "vattensvin",
    "vattensängar": "vattensäng",
    "vattensängarna": "vattensäng",
    "vattensängarnas": "vattensäng",
    "vattensängars": "vattensäng",
    "vattensängen": "vattensäng",
    "vattensängens": "vattensäng",
    "vattensängs": "vattensäng",
    "vattentemperaturen": "vattentemperatur",
    "vattentemperaturens": "vattentemperatur",
    "vattentemperaturer": "vattentemperatur",
    "vattentemperaturerna": "vattentemperatur",
    "vattentemperaturernas": "vattentemperatur",
    "vattentemperaturers": "vattentemperatur",
    "vattentemperaturs": "vattentemperatur",
    "vattentornen": "vattentorn",
    "vattentornens": "vattentorn",
    "vattentornet": "vattentorn",
    "vattentornets": "vattentorn",
    "vattentorns": "vattentorn",
    "vattentortyren": "vattentortyr",
    "vattentortyrens": "vattentortyr",
    "vattentortyrer": "vattentortyr",
    "vattentortyrerna": "vattentortyr",
    "vattentortyrernas": "vattentortyr",
    "vattentortyrers": "vattentortyr",
    "vattentortyrs": "vattentortyr",
    "vattentrampningar": "vattentrampning",
    "vattentrampningarna": "vattentrampning",
    "vattentrampningarnas": "vattentrampning",
    "vattentrampningars": "vattentrampning",
    "vattentrampningen": "vattentrampning",
    "vattentrampningens": "vattentrampning",
    "vattentrampnings": "vattentrampning",
    "vattentröskeln": "vattentröskel",
    "vattentröskelns": "vattentröskel",
    "vattentröskels": "vattentröskel",
    "vattentrösklar": "vattentröskel",
    "vattentrösklarna": "vattentröskel",
    "vattentrösklarnas": "vattentröskel",
    "vattentrösklars": "vattentröskel",
    "vattentunn": "vattentunna",
    "vattentunnan": "vattentunna",
    "vattentunnans": "vattentunna",
    "vattentunnas": "vattentunna",
    "vattentunne": "vattentunna",
    "vattentunnor": "vattentunna",
    "vattentunnorna": "vattentunna",
    "vattentunnornas": "vattentunna",
    "vattentunnors": "vattentunna",
    "vattentunns": "vattentunna",
    "vattenturbinen": "vattenturbin",
    "vattenturbinens": "vattenturbin",
    "vattenturbiner": "vattenturbin",
    "vattenturbinerna": "vattenturbin",
    "vattenturbinernas": "vattenturbin",
    "vattenturbiners": "vattenturbin",
    "vattenturbins": "vattenturbin",
    "vattentäkten": "vattentäkt",
    "vattentäktens": "vattentäkt",
    "vattentäkter": "vattentäkt",
    "vattentäkterna": "vattentäkt",
    "vattentäkternas": "vattentäkt",
    "vattentäkters": "vattentäkt",
    "vattentäkts": "vattentäkt",
    "vattentäta": "vattentät",
    "vattentätare": "vattentät",
    "vattentätares": "vattentät",
    "vattentätas": "vattentät",
    "vattentätast": "vattentät",
    "vattentätaste": "vattentät",
    "vattentätastes": "vattentät",
    "vattentätasts": "vattentät",
    "vattentäte": "vattentät",
    "vattentätes": "vattentät",
    "vattentäts": "vattentät",
    "vattentätt": "vattentät",
    "vattentätts": "vattentät",
    "vattentåliga": "vattentålig",
    "vattentåligare": "vattentålig",
    "vattentåligares": "vattentålig",
    "vattentåligas": "vattentålig",
    "vattentåligast": "vattentålig",
    "vattentåligaste": "vattentålig",
    "vattentåligastes": "vattentålig",
    "vattentåligasts": "vattentålig",
    "vattentålige": "vattentålig",
    "vattentåliges": "vattentålig",
    "vattentåligheten": "vattentålighet",
    "vattentålighetens": "vattentålighet",
    "vattentålighets": "vattentålighet",
    "vattentåligs": "vattentålig",
    "vattentåligt": "vattentålig",
    "vattentåligts": "vattentålig",
    "vattenuren": "vattenur",
    "vattenurens": "vattenur",
    "vattenuret": "vattenur",
    "vattenurets": "vattenur",
    "vattenurs": "vattenur",
    "vattenverken": "vattenverk",
    "vattenverkens": "vattenverk",
    "vattenverket": "vattenverk",
    "vattenverkets": "vattenverk",
    "vattenverks": "vattenverk",
    "vattenvirveln": "vattenvirvel",
    "vattenvirvelns": "vattenvirvel",
    "vattenvirvels": "vattenvirvel",
    "vattenvirvlar": "vattenvirvel",
    "vattenvirvlarna": "vattenvirvel",
    "vattenvirvlarnas": "vattenvirvel",
    "vattenvirvlars": "vattenvirvel",
    "vattenvägar": "vattenväg",
    "vattenvägarna": "vattenväg",
    "vattenvägarnas": "vattenväg",
    "vattenvägars": "vattenväg",
    "vattenvägen": "vattenväg",
    "vattenvägens": "vattenväg",
    "vattenvägs": "vattenväg",
    "vattenvärden": "vattenvärde",
    "vattenvärdena": "vattenvärde",
    "vattenvärdenas": "vattenvärde",
    "vattenvärdens": "vattenvärde",
    "vattenvärdes": "vattenvärde",
    "vattenvärdet": "vattenvärde",
    "vattenvärdets": "vattenvärde",
    "vattenvärmar": "vattenvärmare",
    "vattenvärmaren": "vattenvärmare",
    "vattenvärmarens": "vattenvärmare",
    "vattenvärmares": "vattenvärmare",
    "vattenvärmarna": "vattenvärmare",
    "vattenvärmarnas": "vattenvärmare",
    "vattenväsenen": "vattenväsen",
    "vattenväsenens": "vattenväsen",
    "vattenväsenet": "vattenväsen",
    "vattenväsenets": "vattenväsen",
    "vattenväsens": "vattenväsen",
    "vattenväsnen": "vattenväsen",
    "vattenväsnens": "vattenväsen",
    "vattenväsnet": "vattenväsen",
    "vattenväsnets": "vattenväsen",
    "vattenväxten": "vattenväxt",
    "vattenväxtens": "vattenväxt",
    "vattenväxter": "vattenväxt",
    "vattenväxterna": "vattenväxt",
    "vattenväxternas": "vattenväxt",
    "vattenväxters": "vattenväxt",
    "vattenväxts": "vattenväxt",
    "vattenytan": "vattenyta",
    "vattenytans": "vattenyta",
    "vattenytas": "vattenyta",
    "vattenyte": "vattenyta",
    "vattenytor": "vattenyta",
    "vattenytorna": "vattenyta",
    "vattenytornas": "vattenyta",
    "vattenytors": "vattenyta",
    "vattenångan": "vattenånga",
    "vattenångans": "vattenånga",
    "vattenångas": "vattenånga",
    "vattenödlan": "vattenödla",
    "vattenödlans": "vattenödla",
    "vattenödlas": "vattenödla",
    "vattenödle": "vattenödla",
    "vattenödlor": "vattenödla",
    "vattenödlorna": "vattenödla",
    "vattenödlornas": "vattenödla",
    "vattenödlors": "vattenödla",
    "vattenösningar": "vattenösning",
    "vattenösningarna": "vattenösning",
    "vattenösningarnas": "vattenösning",
    "vattenösningars": "vattenösning",
    "vattenösningen": "vattenösning",
    "vattenösningens": "vattenösning",
    "vattenösnings": "vattenösning",
    "vattgröten": "vattgröt",
    "vattgrötens": "vattgröt",
    "vattgröts": "vattgröt",
    "vattkopporna": "vattkoppor",
    "vattkoppornas": "vattkoppor",
    "vattkoppors": "vattkoppor",
    "vattkopps": "vattkoppor",
    "vattn": "vattna",
    "vattnad": "vattna",
    "vattnade": "vattna",
    "vattnades": "vattnas",
    "vattnads": "vattna",
    "vattnande": "vattna",
    "vattnanden": "vattnande",
    "vattnandena": "vattnande",
    "vattnandenas": "vattnande",
    "vattnandens": "vattnande",
    "vattnandes": "vattnande",
    "vattnandet": "vattnande",
    "vattnandets": "vattnande",
    "vattnar": "vattnare",
    "vattnaren": "vattnare",
    "vattnarens": "vattnare",
    "vattnares": "vattnare",
    "vattnarna": "vattnare",
    "vattnarnas": "vattnare",
    "vattnas": "vattna",
    "vattnat": "vattna",
    "vattnats": "vattnas",
    "vattnen": "vatten",
    "vattnens": "vatten",
    "vattnet": "vatten",
    "vattnets": "vatten",
    "vattniga": "vattnig",
    "vattnigare": "vattnig",
    "vattnigares": "vattnig",
    "vattnigas": "vattnig",
    "vattnigast": "vattnig",
    "vattnigaste": "vattnig",
    "vattnigastes": "vattnig",
    "vattnigasts": "vattnig",
    "vattnige": "vattnig",
    "vattniges": "vattnig",
    "vattnigheten": "vattnighet",
    "vattnighetens": "vattnighet",
    "vattnighets": "vattnighet",
    "vattnigs": "vattnig",
    "vattnigt": "vattnig",
    "vattnigts": "vattnig",
    "vattrad": "vattra",
    "vattrade": "vattrad",
    "vattrades": "vattrad",
    "vattrads": "vattrad",
    "vattrande": "vattra",
    "vattranden": "vattrande",
    "vattrandena": "vattrande",
    "vattrandenas": "vattrande",
    "vattrandens": "vattrande",
    "vattrandes": "vattrande",
    "vattrandet": "vattrande",
    "vattrandets": "vattrande",
    "vattrar": "vattra",
    "vattras": "vattra",
    "vattrat": "vattrad",
    "vattrats": "vattrad",
    "vattriga": "vattrig",
    "vattrigare": "vattrig",
    "vattrigares": "vattrig",
    "vattrigas": "vattrig",
    "vattrigast": "vattrig",
    "vattrigaste": "vattrig",
    "vattrigastes": "vattrig",
    "vattrigasts": "vattrig",
    "vattrige": "vattrig",
    "vattriges": "vattrig",
    "vattrigheten": "vattrighet",
    "vattrighetens": "vattrighet",
    "vattrighets": "vattrighet",
    "vattrigs": "vattrig",
    "vattrigt": "vattrig",
    "vattrigts": "vattrig",
    "vattringar": "vattring",
    "vattringarna": "vattring",
    "vattringarnas": "vattring",
    "vattringars": "vattring",
    "vattringen": "vattring",
    "vattringens": "vattring",
    "vattrings": "vattring",
    "vattsoten": "vattsot",
    "vattsotens": "vattsot",
    "vattsots": "vattsot",
    "vattupassen": "vattupass",
    "vattupassens": "vattupass",
    "vattupasset": "vattupass",
    "vattupassets": "vattupass",
    "vattuskräcken": "vattuskräck",
    "vattuskräckens": "vattuskräck",
    "vattuskräcks": "vattuskräck",
    "vattusoten": "vattusot",
    "vattusotens": "vattusot",
    "vattusots": "vattusot",
    "vattvällingar": "vattvälling",
    "vattvällingarna": "vattvälling",
    "vattvällingarnas": "vattvälling",
    "vattvällingars": "vattvälling",
    "vattvällingen": "vattvälling",
    "vattvällingens": "vattvälling",
    "vattvällings": "vattvälling",
    "vaudevillen": "vaudeville",
    "vaudevillens": "vaudeville",
    "vaudeviller": "vaudeville",
    "vaudevillerna": "vaudeville",
    "vaudevillernas": "vaudeville",
    "vaudevillers": "vaudeville",
    "vaudevilles": "vaudeville",
    "vax": "vaxa",
    "vaxad": "vaxa",
    "vaxade": "vaxa",
    "vaxades": "vaxa",
    "vaxads": "vaxa",
    "vaxande": "vaxa",
    "vaxanden": "vaxande",
    "vaxandena": "vaxande",
    "vaxandenas": "vaxande",
    "vaxandens": "vaxande",
    "vaxandes": "vaxande",
    "vaxandet": "vaxande",
    "vaxandets": "vaxande",
    "vaxapplikatorer": "vaxapplikator",
    "vaxapplikatorerna": "vaxapplikator",
    "vaxapplikatorernas": "vaxapplikator",
    "vaxapplikatorers": "vaxapplikator",
    "vaxapplikatorn": "vaxapplikator",
    "vaxapplikatorns": "vaxapplikator",
    "vaxapplikators": "vaxapplikator",
    "vaxar": "vaxa",
    "vaxartade": "vaxartad",
    "vaxartades": "vaxartad",
    "vaxartads": "vaxartad",
    "vaxartat": "vaxartad",
    "vaxartats": "vaxartad",
    "vaxas": "vaxa",
    "vaxat": "vaxa",
    "vaxats": "vaxa",
    "vaxavtrycken": "vaxavtryck",
    "vaxavtryckens": "vaxavtryck",
    "vaxavtrycket": "vaxavtryck",
    "vaxavtryckets": "vaxavtryck",
    "vaxavtrycks": "vaxavtryck",
    "vaxbleka": "vaxblek",
    "vaxblekare": "vaxblek",
    "vaxblekares": "vaxblek",
    "vaxblekas": "vaxblek",
    "vaxblekast": "vaxblek",
    "vaxblekaste": "vaxblek",
    "vaxblekastes": "vaxblek",
    "vaxblekasts": "vaxblek",
    "vaxbleke": "vaxblek",
    "vaxblekes": "vaxblek",
    "vaxblekheten": "vaxblekhet",
    "vaxblekhetens": "vaxblekhet",
    "vaxblekhets": "vaxblekhet",
    "vaxbleks": "vaxblek",
    "vaxblekt": "vaxblek",
    "vaxblekts": "vaxblek",
    "vaxblom": "vaxblomma",
    "vaxblomman": "vaxblomma",
    "vaxblommans": "vaxblomma",
    "vaxblommas": "vaxblomma",
    "vaxblomme": "vaxblomma",
    "vaxblommor": "vaxblomma",
    "vaxblommorna": "vaxblomma",
    "vaxblommornas": "vaxblomma",
    "vaxblommors": "vaxblomma",
    "vaxbloms": "vaxblomma",
    "vaxbön": "vaxböna",
    "vaxbönan": "vaxböna",
    "vaxbönans": "vaxböna",
    "vaxbönas": "vaxböna",
    "vaxböne": "vaxböna",
    "vaxbönor": "vaxböna",
    "vaxbönorna": "vaxböna",
    "vaxbönornas": "vaxböna",
    "vaxbönors": "vaxböna",
    "vaxböns": "vaxböna",
    "vaxdock": "vaxdocka",
    "vaxdockan": "vaxdocka",
    "vaxdockans": "vaxdocka",
    "vaxdockas": "vaxdocka",
    "vaxdocke": "vaxdocka",
    "vaxdockor": "vaxdocka",
    "vaxdockorna": "vaxdocka",
    "vaxdockornas": "vaxdocka",
    "vaxdockors": "vaxdocka",
    "vaxdocks": "vaxdocka",
    "vaxdukar": "vaxduk",
    "vaxdukarna": "vaxduk",
    "vaxdukarnas": "vaxduk",
    "vaxdukars": "vaxduk",
    "vaxduken": "vaxduk",
    "vaxdukens": "vaxduk",
    "vaxduks": "vaxduk",
    "vaxer": "vax",
    "vaxerna": "vax",
    "vaxernas": "vax",
    "vaxers": "vax",
    "vaxet": "vax",
    "vaxets": "vax",
    "vaxfiguren": "vaxfigur",
    "vaxfigurens": "vaxfigur",
    "vaxfigurer": "vaxfigur",
    "vaxfigurerna": "vaxfigur",
    "vaxfigurernas": "vaxfigur",
    "vaxfigurers": "vaxfigur",
    "vaxfigurs": "vaxfigur",
    "vaxkabinetten": "vaxkabinett",
    "vaxkabinettens": "vaxkabinett",
    "vaxkabinettet": "vaxkabinett",
    "vaxkabinettets": "vaxkabinett",
    "vaxkabinetts": "vaxkabinett",
    "vaxkak": "vaxkaka",
    "vaxkakan": "vaxkaka",
    "vaxkakans": "vaxkaka",
    "vaxkakas": "vaxkaka",
    "vaxkake": "vaxkaka",
    "vaxkakor": "vaxkaka",
    "vaxkakorna": "vaxkaka",
    "vaxkakornas": "vaxkaka",
    "vaxkakors": "vaxkaka",
    "vaxkaks": "vaxkaka",
    "vaxljusen": "vaxljus",
    "vaxljusens": "vaxljus",
    "vaxljuset": "vaxljus",
    "vaxljusets": "vaxljus",
    "vaxningar": "vaxning",
    "vaxningarna": "vaxning",
    "vaxningarnas": "vaxning",
    "vaxningars": "vaxning",
    "vaxningen": "vaxning",
    "vaxningens": "vaxning",
    "vaxnings": "vaxning",
    "vaxproppar": "vaxpropp",
    "vaxpropparna": "vaxpropp",
    "vaxpropparnas": "vaxpropp",
    "vaxproppars": "vaxpropp",
    "vaxproppen": "vaxpropp",
    "vaxproppens": "vaxpropp",
    "vaxpropps": "vaxpropp",
    "vaxschampon": "vaxschampo",
    "vaxschampona": "vaxschampo",
    "vaxschamponas": "vaxschampo",
    "vaxschampons": "vaxschampo",
    "vaxschampos": "vaxschampo",
    "vaxschampot": "vaxschampo",
    "vaxschampots": "vaxschampo",
    "vaxsigillen": "vaxsigill",
    "vaxsigillens": "vaxsigill",
    "vaxsigillet": "vaxsigill",
    "vaxsigillets": "vaxsigill",
    "vaxsigills": "vaxsigill",
    "vaxskivlingar": "vaxskivling",
    "vaxskivlingarna": "vaxskivling",
    "vaxskivlingarnas": "vaxskivling",
    "vaxskivlingars": "vaxskivling",
    "vaxskivlingen": "vaxskivling",
    "vaxskivlingens": "vaxskivling",
    "vaxskivlings": "vaxskivling",
    "vaxstapeln": "vaxstapel",
    "vaxstapelns": "vaxstapel",
    "vaxstapels": "vaxstapel",
    "vaxstaplar": "vaxstapel",
    "vaxstaplarna": "vaxstapel",
    "vaxstaplarnas": "vaxstapel",
    "vaxstaplars": "vaxstapel",
    "vaxtavel": "vaxtavla",
    "vaxtavlan": "vaxtavla",
    "vaxtavlans": "vaxtavla",
    "vaxtavlas": "vaxtavla",
    "vaxtavle": "vaxtavla",
    "vaxtavlor": "vaxtavla",
    "vaxtavlorna": "vaxtavla",
    "vaxtavlornas": "vaxtavla",
    "vaxtavlors": "vaxtavla",
    "vd-ar": "vd",
    "vd-arna": "vd",
    "vd-arnas": "vd",
    "vd:arnas": "vd",
    "vd:en": "vd",
    "vd:n": "vd",
    "vd:s": "vd",
    "vden": "vd",
    "vdens": "vd",
    "vdn": "vd",
    "vdns": "vd",
    "vds": "vd",
    "veck": "vecka",
    "veckad": "vecka",
    "veckade": "vecka",
    "veckades": "vecka",
    "veckads": "vecka",
    "veckan": "vecka",
    "veckande": "vecka",
    "veckanden": "veckande",
    "veckandena": "veckande",
    "veckandenas": "veckande",
    "veckandens": "veckande",
    "veckandes": "veckande",
    "veckandet": "veckande",
    "veckandets": "veckande",
    "veckans": "vecka",
    "veckar": "vecka",
    "veckas": "vecka",
    "veckat": "vecka",
    "veckats": "vecka",
    "veckbergen": "veckberg",
    "veckbergens": "veckberg",
    "veckberget": "veckberg",
    "veckbergets": "veckberg",
    "veckbergs": "veckberg",
    "vecke": "vecka",
    "vecken": "veck",
    "veckens": "veck",
    "vecket": "veck",
    "veckets": "veck",
    "veckiga": "veckig",
    "veckigare": "veckig",
    "veckigares": "veckig",
    "veckigas": "veckig",
    "veckigast": "veckig",
    "veckigaste": "veckig",
    "veckigastes": "veckig",
    "veckigasts": "veckig",
    "veckige": "veckig",
    "veckiges": "veckig",
    "veckigheten": "veckighet",
    "veckighetens": "veckighet",
    "veckighets": "veckighet",
    "veckigs": "veckig",
    "veckigt": "veckig",
    "veckigts": "veckig",
    "vecklad": "veckla",
    "vecklade": "veckla",
    "vecklades": "veckla",
    "vecklads": "veckla",
    "vecklande": "veckla",
    "vecklanden": "vecklande",
    "vecklandena": "vecklande",
    "vecklandenas": "vecklande",
    "vecklandens": "vecklande",
    "vecklandes": "vecklande",
    "vecklandet": "vecklande",
    "vecklandets": "vecklande",
    "vecklar": "vecklare",
    "vecklaren": "vecklare",
    "vecklarens": "vecklare",
    "vecklares": "vecklare",
    "vecklarna": "vecklare",
    "vecklarnas": "vecklare",
    "vecklas": "veckla",
    "vecklat": "veckla",
    "vecklats": "veckla",
    "veckningar": "veckning",
    "veckningarna": "veckning",
    "veckningarnas": "veckning",
    "veckningars": "veckning",
    "veckningen": "veckning",
    "veckningens": "veckning",
    "vecknings": "veckning",
    "vecko": "vecka",
    "veckoavdelningar": "veckoavdelning",
    "veckoavdelningarna": "veckoavdelning",
    "veckoavdelningarnas": "veckoavdelning",
    "veckoavdelningars": "veckoavdelning",
    "veckoavdelningen": "veckoavdelning",
    "veckoavdelningens": "veckoavdelning",
    "veckoavdelnings": "veckoavdelning",
    "veckobilag": "veckobilaga",
    "veckobilagan": "veckobilaga",
    "veckobilagans": "veckobilaga",
    "veckobilagas": "veckobilaga",
    "veckobilage": "veckobilaga",
    "veckobilagor": "veckobilaga",
    "veckobilagorna": "veckobilaga",
    "veckobilagornas": "veckobilaga",
    "veckobilagors": "veckobilaga",
    "veckobilags": "veckobilaga",
    "veckobiljetten": "veckobiljett",
    "veckobiljettens": "veckobiljett",
    "veckobiljetter": "veckobiljett",
    "veckobiljetterna": "veckobiljett",
    "veckobiljetternas": "veckobiljett",
    "veckobiljetters": "veckobiljett",
    "veckobiljetts": "veckobiljett",
    "veckodagar": "veckodag",
    "veckodagarna": "veckodag",
    "veckodagarnas": "veckodag",
    "veckodagars": "veckodag",
    "veckodagen": "veckodag",
    "veckodagens": "veckodag",
    "veckodags": "veckodag",
    "veckogamla": "veckogammal",
    "veckogamlas": "veckogammal",
    "veckogamle": "veckogammal",
    "veckogamles": "veckogammal",
    "veckogammals": "veckogammal",
    "veckogammalt": "veckogammal",
    "veckogammalts": "veckogammal",
    "veckohandlade": "veckohandla",
    "veckohandlades": "veckohandla",
    "veckohandlande": "veckohandla",
    "veckohandlanden": "veckohandlande",
    "veckohandlandena": "veckohandlande",
    "veckohandlandenas": "veckohandlande",
    "veckohandlandens": "veckohandlande",
    "veckohandlandes": "veckohandlande",
    "veckohandlandet": "veckohandlande",
    "veckohandlandets": "veckohandlande",
    "veckohandlar": "veckohandla",
    "veckohandlas": "veckohandla",
    "veckohandlat": "veckohandla",
    "veckohandlats": "veckohandla",
    "veckohandlingar": "veckohandling",
    "veckohandlingarna": "veckohandling",
    "veckohandlingarnas": "veckohandling",
    "veckohandlingars": "veckohandling",
    "veckohandlingen": "veckohandling",
    "veckohandlingens": "veckohandling",
    "veckohandlings": "veckohandling",
    "veckohelgen": "veckohelg",
    "veckohelgens": "veckohelg",
    "veckohelger": "veckohelg",
    "veckohelgerna": "veckohelg",
    "veckohelgernas": "veckohelg",
    "veckohelgers": "veckohelg",
    "veckohelgs": "veckohelg",
    "veckolånga": "veckolång",
    "veckolångas": "veckolång",
    "veckolånge": "veckolång",
    "veckolånges": "veckolång",
    "veckolångs": "veckolång",
    "veckolångt": "veckolång",
    "veckolångts": "veckolång",
    "veckomagasinen": "veckomagasin",
    "veckomagasinens": "veckomagasin",
    "veckomagasinet": "veckomagasin",
    "veckomagasinets": "veckomagasin",
    "veckomagasins": "veckomagasin",
    "veckonya": "veckony",
    "veckonyare": "veckony",
    "veckonyares": "veckony",
    "veckonyas": "veckony",
    "veckonyast": "veckony",
    "veckonyaste": "veckony",
    "veckonyastes": "veckony",
    "veckonyasts": "veckony",
    "veckonye": "veckony",
    "veckonyes": "veckony",
    "veckonys": "veckony",
    "veckonytt": "veckony",
    "veckonytts": "veckony",
    "veckopendlade": "veckopendla",
    "veckopendlades": "veckopendla",
    "veckopendlande": "veckopendla",
    "veckopendlanden": "veckopendlande",
    "veckopendlandena": "veckopendlande",
    "veckopendlandenas": "veckopendlande",
    "veckopendlandens": "veckopendlande",
    "veckopendlandes": "veckopendlande",
    "veckopendlandet": "veckopendlande",
    "veckopendlandets": "veckopendlande",
    "veckopendlar": "veckopendla",
    "veckopendlas": "veckopendla",
    "veckopendlat": "veckopendla",
    "veckopendlats": "veckopendla",
    "veckopendlingar": "veckopendling",
    "veckopendlingarna": "veckopendling",
    "veckopendlingarnas": "veckopendling",
    "veckopendlingars": "veckopendling",
    "veckopendlingen": "veckopendling",
    "veckopendlingens": "veckopendling",
    "veckopendlings": "veckopendling",
    "veckopengar": "veckopeng",
    "veckopengarna": "veckopeng",
    "veckopengarnas": "veckopeng",
    "veckopengars": "veckopeng",
    "veckopengen": "veckopeng",
    "veckopengens": "veckopeng",
    "veckopengs": "veckopeng",
    "veckopressen": "veckopress",
    "veckopressens": "veckopress",
    "veckor": "vecka",
    "veckorna": "vecka",
    "veckornas": "vecka",
    "veckors": "vecka",
    "veckosluten": "veckoslut",
    "veckoslutens": "veckoslut",
    "veckoslutet": "veckoslut",
    "veckoslutets": "veckoslut",
    "veckosluts": "veckoslut",
    "veckotidningar": "veckotidning",
    "veckotidningarna": "veckotidning",
    "veckotidningarnas": "veckotidning",
    "veckotidningars": "veckotidning",
    "veckotidningen": "veckotidning",
    "veckotidningens": "veckotidning",
    "veckotidnings": "veckotidning",
    "veckotidningsnovellen": "veckotidningsnovell",
    "veckotidningsnovellens": "veckotidningsnovell",
    "veckotidningsnoveller": "veckotidningsnovell",
    "veckotidningsnovellerna": "veckotidningsnovell",
    "veckotidningsnovellernas": "veckotidningsnovell",
    "veckotidningsnovellers": "veckotidningsnovell",
    "veckotidningsnovells": "veckotidningsnovell",
    "veckotim": "veckotimme",
    "veckotimman": "veckotimma",
    "veckotimmans": "veckotimma",
    "veckotimmar": "veckotimme",
    "veckotimmarna": "veckotimme",
    "veckotimmarnas": "veckotimme",
    "veckotimmars": "veckotimme",
    "veckotimmas": "veckotimma",
    "veckotimmen": "veckotimme",
    "veckotimmens": "veckotimme",
    "veckotimmes": "veckotimme",
    "veckotims": "veckotimme",
    "veckovilla": "veckovill",
    "veckovillare": "veckovill",
    "veckovillares": "veckovill",
    "veckovillas": "veckovill",
    "veckovillast": "veckovill",
    "veckovillaste": "veckovill",
    "veckovillastes": "veckovill",
    "veckovillasts": "veckovill",
    "veckoville": "veckovill",
    "veckovilles": "veckovill",
    "veckovillheten": "veckovillhet",
    "veckovillhetens": "veckovillhet",
    "veckovillhets": "veckovillhet",
    "veckovills": "veckovill",
    "veckoänd": "veckoända",
    "veckoändan": "veckoända",
    "veckoändans": "veckoända",
    "veckoändar": "veckoände",
    "veckoändarna": "veckoände",
    "veckoändarnas": "veckoände",
    "veckoändars": "veckoände",
    "veckoändas": "veckoända",
    "veckoände": "veckoända",
    "veckoänden": "veckoände",
    "veckoändens": "veckoände",
    "veckoändes": "veckoände",
    "veckoändor": "veckoända",
    "veckoändorna": "veckoända",
    "veckoändornas": "veckoända",
    "veckoändors": "veckoända",
    "veckoänds": "veckoända",
    "vecks": "vecka",
    "veckänd": "veckända",
    "veckändan": "veckända",
    "veckändans": "veckända",
    "veckändar": "veckände",
    "veckändarna": "veckände",
    "veckändarnas": "veckände",
    "veckändars": "veckände",
    "veckändas": "veckända",
    "veckände": "veckända",
    "veckänden": "veckände",
    "veckändens": "veckände",
    "veckändes": "veckände",
    "veckändor": "veckända",
    "veckändorna": "veckända",
    "veckändornas": "veckända",
    "veckändors": "veckända",
    "veckänds": "veckända",
    "vedartade": "vedartad",
    "vedartades": "vedartad",
    "vedartads": "vedartad",
    "vedartat": "vedartad",
    "vedartats": "vedartad",
    "vedback": "vedbacke",
    "vedbackar": "vedbacke",
    "vedbackarna": "vedbacke",
    "vedbackarnas": "vedbacke",
    "vedbackars": "vedbacke",
    "vedbacken": "vedbacke",
    "vedbackens": "vedbacke",
    "vedbackes": "vedbacke",
    "vedbacks": "vedbacke",
    "vedbodar": "vedbod",
    "vedbodarna": "vedbod",
    "vedbodarnas": "vedbod",
    "vedbodars": "vedbod",
    "vedboden": "vedbod",
    "vedbodens": "vedbod",
    "vedbods": "vedbod",
    "vedborr": "vedborre",
    "vedborrar": "vedborre",
    "vedborrarna": "vedborre",
    "vedborrarnas": "vedborre",
    "vedborrars": "vedborre",
    "vedborren": "vedborre",
    "vedborrens": "vedborre",
    "vedborres": "vedborre",
    "vedborrs": "vedborre",
    "vedbranden": "vedbrand",
    "vedbrandens": "vedbrand",
    "vedbrands": "vedbrand",
    "vedbränder": "vedbrand",
    "vedbränderna": "vedbrand",
    "vedbrändernas": "vedbrand",
    "vedbränders": "vedbrand",
    "vedbärar": "vedbärare",
    "vedbäraren": "vedbärare",
    "vedbärarens": "vedbärare",
    "vedbärares": "vedbärare",
    "vedbärarna": "vedbärare",
    "vedbärarnas": "vedbärare",
    "vedeldade": "vedeldad",
    "vedeldades": "vedeldad",
    "vedeldads": "vedeldad",
    "vedeldat": "vedeldad",
    "vedeldats": "vedeldad",
    "veden": "ved",
    "vedens": "ved",
    "vederbör": "vederböra",
    "vederbörande": "vederböra",
    "vederböranden": "vederbörande",
    "vederbörandena": "vederbörande",
    "vederbörandenas": "vederbörande",
    "vederbörandens": "vederbörande",
    "vederbörandes": "vederbörande",
    "vederbörandet": "vederbörande",
    "vederbörandets": "vederbörande",
    "vederböras": "vederböra",
    "vederbörliga": "vederbörlig",
    "vederbörligare": "vederbörlig",
    "vederbörligares": "vederbörlig",
    "vederbörligas": "vederbörlig",
    "vederbörligast": "vederbörlig",
    "vederbörligaste": "vederbörlig",
    "vederbörligastes": "vederbörlig",
    "vederbörligasts": "vederbörlig",
    "vederbörlige": "vederbörlig",
    "vederbörliges": "vederbörlig",
    "vederbörligs": "vederbörlig",
    "vederbörligt": "vederbörlig",
    "vederbörligts": "vederbörlig",
    "vederdelomannen": "vederdeloman",
    "vederdelomannens": "vederdeloman",
    "vederdelomans": "vederdeloman",
    "vederdelomän": "vederdeloman",
    "vederdelomännen": "vederdeloman",
    "vederdelomännens": "vederdeloman",
    "vederdelomäns": "vederdeloman",
    "vederdöpar": "vederdöpare",
    "vederdöparen": "vederdöpare",
    "vederdöparens": "vederdöpare",
    "vederdöpares": "vederdöpare",
    "vederdöparna": "vederdöpare",
    "vederdöparnas": "vederdöpare",
    "vederfarits": "vederfaras",
    "vederfars": "vederfaras",
    "vederfors": "vederfaras",
    "vederfå": "vederfås",
    "vederfåendes": "vederfående",
    "vederfåendet": "vederfående",
    "vederfåendets": "vederfående",
    "vederfåtts": "vederfås",
    "vedergäll": "vedergälla",
    "vedergällande": "vedergälla",
    "vedergällanden": "vedergällande",
    "vedergällandena": "vedergällande",
    "vedergällandenas": "vedergällande",
    "vedergällandens": "vedergällande",
    "vedergällandes": "vedergällande",
    "vedergällandet": "vedergällande",
    "vedergällandets": "vedergällande",
    "vedergällas": "vedergälla",
    "vedergälld": "vedergälla",
    "vedergällda": "vedergälla",
    "vedergälldas": "vedergälla",
    "vedergällde": "vedergälla",
    "vedergälldes": "vedergälla",
    "vedergällds": "vedergälla",
    "vedergäller": "vedergälla",
    "vedergälles": "vedergälla",
    "vedergällningar": "vedergällning",
    "vedergällningarna": "vedergällning",
    "vedergällningarnas": "vedergällning",
    "vedergällningars": "vedergällning",
    "vedergällningen": "vedergällning",
    "vedergällningens": "vedergällning",
    "vedergällnings": "vedergällning",
    "vedergällningsläran": "vedergällningslära",
    "vedergällningslärans": "vedergällningslära",
    "vedergällningsläras": "vedergällningslära",
    "vedergälls": "vedergälla",
    "vedergällt": "vedergälla",
    "vedergällts": "vedergälla",
    "vederhäftiga": "vederhäftig",
    "vederhäftigare": "vederhäftig",
    "vederhäftigares": "vederhäftig",
    "vederhäftigas": "vederhäftig",
    "vederhäftigast": "vederhäftig",
    "vederhäftigaste": "vederhäftig",
    "vederhäftigastes": "vederhäftig",
    "vederhäftigasts": "vederhäftig",
    "vederhäftige": "vederhäftig",
    "vederhäftiges": "vederhäftig",
    "vederhäftigheten": "vederhäftighet",
    "vederhäftighetens": "vederhäftighet",
    "vederhäftighets": "vederhäftighet",
    "vederhäftigs": "vederhäftig",
    "vederhäftigt": "vederhäftig",
    "vederhäftigts": "vederhäftig",
    "vederkvick": "vederkvicka",
    "vederkvickande": "vederkvicka",
    "vederkvickanden": "vederkvickande",
    "vederkvickandena": "vederkvickande",
    "vederkvickandenas": "vederkvickande",
    "vederkvickandens": "vederkvickande",
    "vederkvickandes": "vederkvickande",
    "vederkvickandet": "vederkvickande",
    "vederkvickandets": "vederkvickande",
    "vederkvickas": "vederkvicka",
    "vederkvickelsen": "vederkvickelse",
    "vederkvickelsens": "vederkvickelse",
    "vederkvickelser": "vederkvickelse",
    "vederkvickelserna": "vederkvickelse",
    "vederkvickelsernas": "vederkvickelse",
    "vederkvickelsers": "vederkvickelse",
    "vederkvickelses": "vederkvickelse",
    "vederkvicker": "vederkvicka",
    "vederkvickes": "vederkvicka",
    "vederkvicks": "vederkvicka",
    "vederkvickt": "vederkvicka",
    "vederkvickta": "vederkvicka",
    "vederkvicktas": "vederkvicka",
    "vederkvickte": "vederkvicka",
    "vederkvicktes": "vederkvicka",
    "vederkvickts": "vederkvicka",
    "vederla": "vederlägga",
    "vederlade": "vederlägga",
    "vederlades": "vederlägga",
    "vederlagd": "vederlägga",
    "vederlagda": "vederlägga",
    "vederlagdas": "vederlägga",
    "vederlagde": "vederlägga",
    "vederlagdes": "vederlägga",
    "vederlagds": "vederlägga",
    "vederlagen": "vederlag",
    "vederlagens": "vederlag",
    "vederlaget": "vederlag",
    "vederlagets": "vederlag",
    "vederlags": "vederlag",
    "vederlagsgodset": "vederlagsgods",
    "vederlagsgodsets": "vederlagsgods",
    "vederlagt": "vederlägga",
    "vederlagts": "vederlägga",
    "vederlas": "vederlägga",
    "vederlik": "vederlike",
    "vederlikar": "vederlike",
    "vederlikarna": "vederlike",
    "vederlikarnas": "vederlike",
    "vederlikars": "vederlike",
    "vederliken": "vederlike",
    "vederlikens": "vederlike",
    "vederlikes": "vederlike",
    "vederliks": "vederlike",
    "vederlägg": "vederlägga",
    "vederläggande": "vederlägga",
    "vederlägganden": "vederläggande",
    "vederläggandena": "vederläggande",
    "vederläggandenas": "vederläggande",
    "vederläggandens": "vederläggande",
    "vederläggandes": "vederläggande",
    "vederläggandet": "vederläggande",
    "vederläggandets": "vederläggande",
    "vederläggas": "vederlägga",
    "vederlägger": "vederlägga",
    "vederlägges": "vederlägga",
    "vederläggs": "vederlägga",
    "vedermälen": "vedermäle",
    "vedermälena": "vedermäle",
    "vedermälenas": "vedermäle",
    "vedermälens": "vedermäle",
    "vedermäles": "vedermäle",
    "vedermälet": "vedermäle",
    "vedermälets": "vedermäle",
    "vedermäls": "vedermäle",
    "vedermödan": "vedermöda",
    "vedermödans": "vedermöda",
    "vedermödas": "vedermöda",
    "vedermöde": "vedermöda",
    "vedermödo": "vedermöda",
    "vedermödor": "vedermöda",
    "vedermödorna": "vedermöda",
    "vedermödornas": "vedermöda",
    "vedermödors": "vedermöda",
    "vedernamnen": "vedernamn",
    "vedernamnens": "vedernamn",
    "vedernamnet": "vedernamn",
    "vedernamnets": "vedernamn",
    "vedernamns": "vedernamn",
    "vederparten": "vederpart",
    "vederpartens": "vederpart",
    "vederparter": "vederpart",
    "vederparterna": "vederpart",
    "vederparternas": "vederpart",
    "vederparters": "vederpart",
    "vederparts": "vederpart",
    "vedersakar": "vedersakare",
    "vedersakaren": "vedersakare",
    "vedersakarens": "vedersakare",
    "vedersakares": "vedersakare",
    "vedersakarna": "vedersakare",
    "vedersakarnas": "vedersakare",
    "vederstyggliga": "vederstygglig",
    "vederstyggligare": "vederstygglig",
    "vederstyggligares": "vederstygglig",
    "vederstyggligas": "vederstygglig",
    "vederstyggligast": "vederstygglig",
    "vederstyggligaste": "vederstygglig",
    "vederstyggligastes": "vederstygglig",
    "vederstyggligasts": "vederstygglig",
    "vederstygglige": "vederstygglig",
    "vederstyggliges": "vederstygglig",
    "vederstyggligheten": "vederstygglighet",
    "vederstygglighetens": "vederstygglighet",
    "vederstyggligheter": "vederstygglighet",
    "vederstyggligheterna": "vederstygglighet",
    "vederstyggligheternas": "vederstygglighet",
    "vederstyggligheters": "vederstygglighet",
    "vederstygglighets": "vederstygglighet",
    "vederstyggligs": "vederstygglig",
    "vederstyggligt": "vederstygglig",
    "vederstyggligts": "vederstygglig",
    "vedertagens": "vedertagen",
    "vedertaget": "vedertagen",
    "vedertagets": "vedertagen",
    "vedertagna": "vedertagen",
    "vedertagnare": "vedertagen",
    "vedertagnares": "vedertagen",
    "vedertagnas": "vedertagen",
    "vedertagnast": "vedertagen",
    "vedertagnaste": "vedertagen",
    "vedertagnastes": "vedertagen",
    "vedertagnasts": "vedertagen",
    "vedertagne": "vedertagen",
    "vedertagnes": "vedertagen",
    "vederviljan": "vedervilja",
    "vederviljans": "vedervilja",
    "vederviljas": "vedervilja",
    "vedervärdiga": "vedervärdig",
    "vedervärdigare": "vedervärdig",
    "vedervärdigares": "vedervärdig",
    "vedervärdigas": "vedervärdig",
    "vedervärdigast": "vedervärdig",
    "vedervärdigaste": "vedervärdig",
    "vedervärdigastes": "vedervärdig",
    "vedervärdigasts": "vedervärdig",
    "vedervärdige": "vedervärdig",
    "vedervärdiges": "vedervärdig",
    "vedervärdigheten": "vedervärdighet",
    "vedervärdighetens": "vedervärdighet",
    "vedervärdigheter": "vedervärdighet",
    "vedervärdigheterna": "vedervärdighet",
    "vedervärdigheternas": "vedervärdighet",
    "vedervärdigheters": "vedervärdighet",
    "vedervärdighets": "vedervärdighet",
    "vedervärdigs": "vedervärdig",
    "vedervärdigt": "vedervärdig",
    "vedervärdigts": "vedervärdig",
    "vedervåg": "vedervåga",
    "vedervågad": "vedervåga",
    "vedervågade": "vedervåga",
    "vedervågades": "vedervåga",
    "vedervågads": "vedervåga",
    "vedervågande": "vedervåga",
    "vedervåganden": "vedervågande",
    "vedervågandena": "vedervågande",
    "vedervågandenas": "vedervågande",
    "vedervågandens": "vedervågande",
    "vedervågandes": "vedervågande",
    "vedervågandet": "vedervågande",
    "vedervågandets": "vedervågande",
    "vedervågar": "vedervåga",
    "vedervågas": "vedervåga",
    "vedervågat": "vedervåga",
    "vedervågats": "vedervåga",
    "vedettbåtar": "vedettbåt",
    "vedettbåtarna": "vedettbåt",
    "vedettbåtarnas": "vedettbåt",
    "vedettbåtars": "vedettbåt",
    "vedettbåten": "vedettbåt",
    "vedettbåtens": "vedettbåt",
    "vedettbåts": "vedettbåt",
    "vedfången": "vedfång",
    "vedfångens": "vedfång",
    "vedfånget": "vedfång",
    "vedfångets": "vedfång",
    "vedfångs": "vedfång",
    "vedhuggar": "vedhuggare",
    "vedhuggaren": "vedhuggare",
    "vedhuggarens": "vedhuggare",
    "vedhuggares": "vedhuggare",
    "vedhuggarna": "vedhuggare",
    "vedhuggarnas": "vedhuggare",
    "vedhuggningar": "vedhuggning",
    "vedhuggningarna": "vedhuggning",
    "vedhuggningarnas": "vedhuggning",
    "vedhuggningars": "vedhuggning",
    "vedhuggningen": "vedhuggning",
    "vedhuggningens": "vedhuggning",
    "vedhuggnings": "vedhuggning",
    "vedhögar": "vedhög",
    "vedhögarna": "vedhög",
    "vedhögarnas": "vedhög",
    "vedhögars": "vedhög",
    "vedhögen": "vedhög",
    "vedhögens": "vedhög",
    "vedhögs": "vedhög",
    "vediska": "vedisk",
    "vediskare": "vedisk",
    "vediskares": "vedisk",
    "vediskas": "vedisk",
    "vediskast": "vedisk",
    "vediskaste": "vedisk",
    "vediskastes": "vedisk",
    "vediskasts": "vedisk",
    "vediske": "vedisk",
    "vediskes": "vedisk",
    "vedisks": "vedisk",
    "vediskt": "vedisk",
    "vediskts": "vedisk",
    "vedkapar": "vedkap",
    "vedkaparna": "vedkap",
    "vedkaparnas": "vedkap",
    "vedkapars": "vedkap",
    "vedkapen": "vedkap",
    "vedkapens": "vedkap",
    "vedkapningar": "vedkapning",
    "vedkapningarna": "vedkapning",
    "vedkapningarnas": "vedkapning",
    "vedkapningars": "vedkapning",
    "vedkapningen": "vedkapning",
    "vedkapningens": "vedkapning",
    "vedkapnings": "vedkapning",
    "vedkaps": "vedkap",
    "vedkapsågar": "vedkapsåg",
    "vedkapsågarna": "vedkapsåg",
    "vedkapsågarnas": "vedkapsåg",
    "vedkapsågars": "vedkapsåg",
    "vedkapsågen": "vedkapsåg",
    "vedkapsågens": "vedkapsåg",
    "vedkapsågs": "vedkapsåg",
    "vedklyvar": "vedklyv",
    "vedklyvarna": "vedklyv",
    "vedklyvarnas": "vedklyv",
    "vedklyvars": "vedklyv",
    "vedklyven": "vedklyv",
    "vedklyvens": "vedklyv",
    "vedklyvs": "vedklyv",
    "vedlårar": "vedlår",
    "vedlårarna": "vedlår",
    "vedlårarnas": "vedlår",
    "vedlårars": "vedlår",
    "vedlåren": "vedlår",
    "vedlårens": "vedlår",
    "vedlårs": "vedlår",
    "vedmåttet": "vedmått",
    "vedmåttets": "vedmått",
    "vedmåtts": "vedmått",
    "vedpinn": "vedpinne",
    "vedpinnar": "vedpinne",
    "vedpinnarna": "vedpinne",
    "vedpinnarnas": "vedpinne",
    "vedpinnars": "vedpinne",
    "vedpinnen": "vedpinne",
    "vedpinnens": "vedpinne",
    "vedpinnes": "vedpinne",
    "vedpinns": "vedpinne",
    "veds": "ved",
    "vedspisar": "vedspis",
    "vedspisarna": "vedspis",
    "vedspisarnas": "vedspis",
    "vedspisars": "vedspis",
    "vedspisen": "vedspis",
    "vedspisens": "vedspis",
    "vedstammar": "vedstam",
    "vedstammarna": "vedstam",
    "vedstammarnas": "vedstam",
    "vedstammars": "vedstam",
    "vedstammen": "vedstam",
    "vedstammens": "vedstam",
    "vedstams": "vedstam",
    "vedsågar": "vedsåg",
    "vedsågarna": "vedsåg",
    "vedsågarnas": "vedsåg",
    "vedsågars": "vedsåg",
    "vedsågen": "vedsåg",
    "vedsågens": "vedsåg",
    "vedsågs": "vedsåg",
    "vedträet": "vedträ",
    "vedträets": "vedträ",
    "vedträn": "vedträ",
    "vedträna": "vedträ",
    "vedtränas": "vedträ",
    "vedträns": "vedträ",
    "vedträs": "vedträ",
    "vedträt": "vedträ",
    "vedträts": "vedträ",
    "vedämnes": "vedämne",
    "vedämnet": "vedämne",
    "vedämnets": "vedämne",
    "vegamöss": "vegamössa",
    "vegamössan": "vegamössa",
    "vegamössans": "vegamössa",
    "vegamössas": "vegamössa",
    "vegamösse": "vegamössa",
    "vegamössor": "vegamössa",
    "vegamössorna": "vegamössa",
    "vegamössornas": "vegamössa",
    "vegamössors": "vegamössa",
    "vegana": "vegan",
    "veganare": "vegan",
    "veganares": "vegan",
    "veganas": "vegan",
    "veganast": "vegan",
    "veganaste": "vegan",
    "veganastes": "vegan",
    "veganasts": "vegan",
    "vegane": "vegan",
    "veganen": "vegan",
    "veganens": "vegan",
    "veganer": "vegan",
    "veganerna": "vegan",
    "veganernas": "vegan",
    "veganers": "vegan",
    "veganes": "vegan",
    "veganismen": "veganism",
    "veganismens": "veganism",
    "veganismer": "veganism",
    "veganismerna": "veganism",
    "veganismernas": "veganism",
    "veganismers": "veganism",
    "veganisms": "veganism",
    "vegans": "vegan",
    "vegant": "vegan",
    "vegants": "vegan",
    "vegetabilie": "vegetabilier",
    "vegetabilierna": "vegetabilier",
    "vegetabiliernas": "vegetabilier",
    "vegetabiliers": "vegetabilier",
    "vegetabiliska": "vegetabilisk",
    "vegetabiliskare": "vegetabilisk",
    "vegetabiliskares": "vegetabilisk",
    "vegetabiliskas": "vegetabilisk",
    "vegetabiliskast": "vegetabilisk",
    "vegetabiliskaste": "vegetabilisk",
    "vegetabiliskastes": "vegetabilisk",
    "vegetabiliskasts": "vegetabilisk",
    "vegetabiliske": "vegetabilisk",
    "vegetabiliskes": "vegetabilisk",
    "vegetabilisks": "vegetabilisk",
    "vegetabiliskt": "vegetabilisk",
    "vegetabiliskts": "vegetabilisk",
    "vegetarianen": "vegetarian",
    "vegetarianens": "vegetarian",
    "vegetarianer": "vegetarian",
    "vegetarianerna": "vegetarian",
    "vegetarianernas": "vegetarian",
    "vegetarianers": "vegetarian",
    "vegetarianismen": "vegetarianism",
    "vegetarianismens": "vegetarianism",
    "vegetarianismer": "vegetarianism",
    "vegetarianismerna": "vegetarianism",
    "vegetarianismernas": "vegetarianism",
    "vegetarianismers": "vegetarianism",
    "vegetarianisms": "vegetarianism",
    "vegetarians": "vegetarian",
    "vegetarianska": "vegetariansk",
    "vegetarianskare": "vegetariansk",
    "vegetarianskares": "vegetariansk",
    "vegetarianskas": "vegetariansk",
    "vegetarianskast": "vegetariansk",
    "vegetarianskaste": "vegetariansk",
    "vegetarianskastes": "vegetariansk",
    "vegetarianskasts": "vegetariansk",
    "vegetarianske": "vegetariansk",
    "vegetarianskes": "vegetariansk",
    "vegetariansks": "vegetariansk",
    "vegetarianskt": "vegetariansk",
    "vegetarianskts": "vegetariansk",
    "vegetariska": "vegetarisk",
    "vegetariskare": "vegetarisk",
    "vegetariskares": "vegetarisk",
    "vegetariskas": "vegetarisk",
    "vegetariskast": "vegetarisk",
    "vegetariskaste": "vegetarisk",
    "vegetariskastes": "vegetarisk",
    "vegetariskasts": "vegetarisk",
    "vegetariske": "vegetarisk",
    "vegetariskes": "vegetarisk",
    "vegetarisks": "vegetarisk",
    "vegetariskt": "vegetarisk",
    "vegetariskts": "vegetarisk",
    "vegetarismen": "vegetarism",
    "vegetarismens": "vegetarism",
    "vegetarismer": "vegetarism",
    "vegetarismerna": "vegetarism",
    "vegetarismernas": "vegetarism",
    "vegetarismers": "vegetarism",
    "vegetarisms": "vegetarism",
    "vegetationen": "vegetation",
    "vegetationens": "vegetation",
    "vegetationer": "vegetation",
    "vegetationerna": "vegetation",
    "vegetationernas": "vegetation",
    "vegetationers": "vegetation",
    "vegetations": "vegetation",
    "vegetationsbälten": "vegetationsbälte",
    "vegetationsbältena": "vegetationsbälte",
    "vegetationsbältenas": "vegetationsbälte",
    "vegetationsbältens": "vegetationsbälte",
    "vegetationsbältes": "vegetationsbälte",
    "vegetationsbältet": "vegetationsbälte",
    "vegetationsbältets": "vegetationsbälte",
    "vegetationsknoppar": "vegetationsknopp",
    "vegetationsknopparna": "vegetationsknopp",
    "vegetationsknopparnas": "vegetationsknopp",
    "vegetationsknoppars": "vegetationsknopp",
    "vegetationsknoppen": "vegetationsknopp",
    "vegetationsknoppens": "vegetationsknopp",
    "vegetationsknopps": "vegetationsknopp",
    "vegetationsperioden": "vegetationsperiod",
    "vegetationsperiodens": "vegetationsperiod",
    "vegetationsperioder": "vegetationsperiod",
    "vegetationsperioderna": "vegetationsperiod",
    "vegetationsperiodernas": "vegetationsperiod",
    "vegetationsperioders": "vegetationsperiod",
    "vegetationsperiods": "vegetationsperiod",
    "vegetationszonen": "vegetationszon",
    "vegetationszonens": "vegetationszon",
    "vegetationszoner": "vegetationszon",
    "vegetationszonerna": "vegetationszon",
    "vegetationszonernas": "vegetationszon",
    "vegetationszoners": "vegetationszon",
    "vegetationszons": "vegetationszon",
    "vegetativa": "vegetativ",
    "vegetativare": "vegetativ",
    "vegetativares": "vegetativ",
    "vegetativas": "vegetativ",
    "vegetativast": "vegetativ",
    "vegetativaste": "vegetativ",
    "vegetativastes": "vegetativ",
    "vegetativasts": "vegetativ",
    "vegetative": "vegetativ",
    "vegetatives": "vegetativ",
    "vegetativs": "vegetativ",
    "vegetativt": "vegetativ",
    "vegetativts": "vegetativ",
    "vegeterade": "vegetera",
    "vegeterades": "vegetera",
    "vegeterande": "vegetera",
    "vegeteranden": "vegeterande",
    "vegeterandena": "vegeterande",
    "vegeterandenas": "vegeterande",
    "vegeterandens": "vegeterande",
    "vegeterandes": "vegeterande",
    "vegeterandet": "vegeterande",
    "vegeterandets": "vegeterande",
    "vegeterar": "vegetera",
    "vegeteras": "vegetera",
    "vegeterat": "vegetera",
    "vegeterats": "vegetera",
    "vegeteringen": "vegetering",
    "vegeteringens": "vegetering",
    "vegeterings": "vegetering",
    "vehikeln": "vehikel",
    "vehikelns": "vehikel",
    "vehikels": "vehikel",
    "vehiklar": "vehikel",
    "vehiklarna": "vehikel",
    "vehiklarnas": "vehikel",
    "vehiklars": "vehikel",
    "vejden": "vejde",
    "vejdens": "vejde",
    "vejdes": "vejde",
    "vek": "vika",
    "veka": "vek",
    "vekar": "veke",
    "vekare": "vek",
    "vekares": "vek",
    "vekarna": "veke",
    "vekarnas": "veke",
    "vekars": "veke",
    "vekas": "vek",
    "vekast": "vek",
    "vekaste": "vek",
    "vekastes": "vek",
    "vekasts": "vek",
    "veke": "vika",
    "veken": "veke",
    "vekens": "veke",
    "vekes": "vika",
    "vekheten": "vekhet",
    "vekhetens": "vekhet",
    "vekhets": "vekhet",
    "veklag": "veklaga",
    "veklagad": "veklaga",
    "veklagade": "veklaga",
    "veklagades": "veklaga",
    "veklagads": "veklaga",
    "veklagande": "veklaga",
    "veklaganden": "veklagande",
    "veklagandena": "veklagande",
    "veklagandenas": "veklagande",
    "veklagandens": "veklagande",
    "veklagandes": "veklagande",
    "veklagandet": "veklagande",
    "veklagandets": "veklagande",
    "veklagans": "veklagan",
    "veklagar": "veklaga",
    "veklagas": "veklaga",
    "veklagat": "veklaga",
    "veklagats": "veklaga",
    "vekliga": "veklig",
    "vekligare": "veklig",
    "vekligares": "veklig",
    "vekligas": "veklig",
    "vekligast": "veklig",
    "vekligaste": "veklig",
    "vekligastes": "veklig",
    "vekligasts": "veklig",
    "veklige": "veklig",
    "vekliges": "veklig",
    "vekligheten": "veklighet",
    "veklighetens": "veklighet",
    "vekligheter": "veklighet",
    "vekligheterna": "veklighet",
    "vekligheternas": "veklighet",
    "vekligheters": "veklighet",
    "veklighets": "veklighet",
    "vekligs": "veklig",
    "vekligt": "veklig",
    "vekligts": "veklig",
    "veklingar": "vekling",
    "veklingarna": "vekling",
    "veklingarnas": "vekling",
    "veklingars": "vekling",
    "veklingen": "vekling",
    "veklingens": "vekling",
    "veklings": "vekling",
    "vekn": "vekna",
    "veknad": "vekna",
    "veknade": "vekna",
    "veknades": "vekna",
    "veknads": "vekna",
    "veknande": "vekna",
    "veknanden": "veknande",
    "veknandena": "veknande",
    "veknandenas": "veknande",
    "veknandens": "veknande",
    "veknandes": "veknande",
    "veknandet": "veknande",
    "veknandets": "veknande",
    "veknar": "vekna",
    "veknas": "vekna",
    "veknat": "vekna",
    "veknats": "vekna",
    "veks": "vika",
    "vekt": "vek",
    "vektorer": "vektor",
    "vektorerna": "vektor",
    "vektorernas": "vektor",
    "vektorers": "vektor",
    "vektorn": "vektor",
    "vektorns": "vektor",
    "vektors": "vektor",
    "vekts": "vek",
    "vel": "vele",
    "velad": "vela",
    "velade": "vela",
    "velades": "vela",
    "velads": "vela",
    "velan": "vela",
    "velande": "vela",
    "velanden": "velande",
    "velandena": "velande",
    "velandenas": "velande",
    "velandens": "velande",
    "velandes": "velande",
    "velandet": "velande",
    "velandets": "velande",
    "velans": "vela",
    "velar": "vele",
    "velara": "velar",
    "velarare": "velar",
    "velarares": "velar",
    "velaras": "velar",
    "velarast": "velar",
    "velaraste": "velar",
    "velarastes": "velar",
    "velarasts": "velar",
    "velare": "velar",
    "velaren": "velar",
    "velarens": "velar",
    "velarer": "velar",
    "velarerna": "velar",
    "velarernas": "velar",
    "velarers": "velar",
    "velares": "velar",
    "velarna": "vele",
    "velarnas": "vele",
    "velars": "vele",
    "velart": "velar",
    "velarts": "velar",
    "velas": "vela",
    "velat": "vilja",
    "velats": "vela",
    "vele": "vela",
    "velen": "vele",
    "velens": "vele",
    "veles": "vele",
    "veliga": "velig",
    "veligare": "velig",
    "veligares": "velig",
    "veligas": "velig",
    "veligast": "velig",
    "veligaste": "velig",
    "veligastes": "velig",
    "veligasts": "velig",
    "velige": "velig",
    "veliges": "velig",
    "veligheten": "velighet",
    "velighetens": "velighet",
    "veligheter": "velighet",
    "veligheterna": "velighet",
    "veligheternas": "velighet",
    "veligheters": "velighet",
    "velighets": "velighet",
    "veligs": "velig",
    "veligt": "velig",
    "veligts": "velig",
    "velingar": "veling",
    "velingarna": "veling",
    "velingarnas": "veling",
    "velingars": "veling",
    "velingen": "veling",
    "velingens": "veling",
    "velings": "veling",
    "velocipeden": "velociped",
    "velocipedens": "velociped",
    "velocipeder": "velociped",
    "velocipederna": "velociped",
    "velocipedernas": "velociped",
    "velocipeders": "velociped",
    "velocipeds": "velociped",
    "velodromen": "velodrom",
    "velodromens": "velodrom",
    "velodromer": "velodrom",
    "velodromerna": "velodrom",
    "velodromernas": "velodrom",
    "velodromers": "velodrom",
    "velodroms": "velodrom",
    "velor": "vela",
    "velorna": "vela",
    "velornas": "vela",
    "velors": "vela",
    "velouren": "velour",
    "velourens": "velour",
    "velouriserad": "velourisera",
    "velouriserade": "velourisera",
    "velouriserades": "velourisera",
    "velouriserads": "velourisera",
    "velouriserande": "velourisera",
    "velouriseranden": "velouriserande",
    "velouriserandena": "velouriserande",
    "velouriserandenas": "velouriserande",
    "velouriserandens": "velouriserande",
    "velouriserandes": "velouriserande",
    "velouriserandet": "velouriserande",
    "velouriserandets": "velouriserande",
    "velouriserar": "velourisera",
    "velouriseras": "velourisera",
    "velouriserat": "velourisera",
    "velouriserats": "velourisera",
    "velouriserbara": "velouriserbar",
    "velouriserbarare": "velouriserbar",
    "velouriserbarares": "velouriserbar",
    "velouriserbaras": "velouriserbar",
    "velouriserbarast": "velouriserbar",
    "velouriserbaraste": "velouriserbar",
    "velouriserbarastes": "velouriserbar",
    "velouriserbarasts": "velouriserbar",
    "velouriserbare": "velouriserbar",
    "velouriserbares": "velouriserbar",
    "velouriserbarheten": "velouriserbarhet",
    "velouriserbarhetens": "velouriserbarhet",
    "velouriserbarhets": "velouriserbarhet",
    "velouriserbars": "velouriserbar",
    "velouriserbart": "velouriserbar",
    "velouriserbarts": "velouriserbar",
    "velouriseringar": "velourisering",
    "velouriseringarna": "velourisering",
    "velouriseringarnas": "velourisering",
    "velouriseringars": "velourisering",
    "velouriseringen": "velourisering",
    "velouriseringens": "velourisering",
    "velouriserings": "velourisering",
    "velourpappan": "velourpappa",
    "velourpappans": "velourpappa",
    "velourpappas": "velourpappa",
    "velourpappor": "velourpappa",
    "velourpapporna": "velourpappa",
    "velourpappornas": "velourpappa",
    "velourpappors": "velourpappa",
    "velours": "velour",
    "vels": "vele",
    "velumet": "velum",
    "velumets": "velum",
    "velums": "velum",
    "velvetinen": "velvetin",
    "velvetinens": "velvetin",
    "velvetinet": "velvetin",
    "velvetinets": "velvetin",
    "velvetins": "velvetin",
    "velängen": "veläng",
    "velängens": "veläng",
    "velängs": "veläng",
    "vemodet": "vemod",
    "vemodets": "vemod",
    "vemodiga": "vemodig",
    "vemodigare": "vemodig",
    "vemodigares": "vemodig",
    "vemodigas": "vemodig",
    "vemodigast": "vemodig",
    "vemodigaste": "vemodig",
    "vemodigastes": "vemodig",
    "vemodigasts": "vemodig",
    "vemodige": "vemodig",
    "vemodiges": "vemodig",
    "vemodigheten": "vemodighet",
    "vemodighetens": "vemodighet",
    "vemodighets": "vemodighet",
    "vemodigs": "vemodig",
    "vemodigt": "vemodig",
    "vemodigts": "vemodig",
    "vemods": "vemod",
    "vems": "vem",
    "ven": "vina",
    "venden": "vend",
    "vendens": "vend",
    "vender": "vend",
    "vendern": "vender",
    "venderna": "vender",
    "vendernas": "vender",
    "venderns": "vender",
    "venders": "vender",
    "vendettan": "vendetta",
    "vendettans": "vendetta",
    "vendettas": "vendetta",
    "vendettor": "vendetta",
    "vendettorna": "vendetta",
    "vendettornas": "vendetta",
    "vendettors": "vendetta",
    "vendiska": "vendisk",
    "vendiskare": "vendisk",
    "vendiskares": "vendisk",
    "vendiskas": "vendisk",
    "vendiskast": "vendisk",
    "vendiskaste": "vendisk",
    "vendiskastes": "vendisk",
    "vendiskasts": "vendisk",
    "vendiske": "vendisk",
    "vendiskes": "vendisk",
    "vendisks": "vendisk",
    "vendiskt": "vendisk",
    "vendiskts": "vendisk",
    "vends": "vend",
    "venen": "ven",
    "venens": "ven",
    "vener": "ven",
    "venerabels": "venerabel",
    "venerabelt": "venerabel",
    "venerabelts": "venerabel",
    "venerabla": "venerabel",
    "venerablare": "venerabel",
    "venerablares": "venerabel",
    "venerablas": "venerabel",
    "venerablast": "venerabel",
    "venerablaste": "venerabel",
    "venerablastes": "venerabel",
    "venerablasts": "venerabel",
    "venerable": "venerabel",
    "venerables": "venerabel",
    "venerationen": "veneration",
    "venerationens": "veneration",
    "venerationer": "veneration",
    "venerationerna": "veneration",
    "venerationernas": "veneration",
    "venerationers": "veneration",
    "venerations": "veneration",
    "venereologen": "venereolog",
    "venereologens": "venereolog",
    "venereologer": "venereolog",
    "venereologerna": "venereolog",
    "venereologernas": "venereolog",
    "venereologers": "venereolog",
    "venereologien": "venereologi",
    "venereologiens": "venereologi",
    "venereologin": "venereologi",
    "venereologins": "venereologi",
    "venereologis": "venereologi",
    "venereologiska": "venereologisk",
    "venereologiskare": "venereologisk",
    "venereologiskares": "venereologisk",
    "venereologiskas": "venereologisk",
    "venereologiskast": "venereologisk",
    "venereologiskaste": "venereologisk",
    "venereologiskastes": "venereologisk",
    "venereologiskasts": "venereologisk",
    "venereologiske": "venereologisk",
    "venereologiskes": "venereologisk",
    "venereologisks": "venereologisk",
    "venereologiskt": "venereologisk",
    "venereologiskts": "venereologisk",
    "venereologs": "venereolog",
    "veneriska": "venerisk",
    "veneriskare": "venerisk",
    "veneriskares": "venerisk",
    "veneriskas": "venerisk",
    "veneriskast": "venerisk",
    "veneriskaste": "venerisk",
    "veneriskastes": "venerisk",
    "veneriskasts": "venerisk",
    "veneriske": "venerisk",
    "veneriskes": "venerisk",
    "venerisks": "venerisk",
    "veneriskt": "venerisk",
    "veneriskts": "venerisk",
    "venerna": "ven",
    "venernas": "ven",
    "veners": "ven",
    "venetianar": "venetianare",
    "venetianaren": "venetianare",
    "venetianarens": "venetianare",
    "venetianares": "venetianare",
    "venetianarna": "venetianare",
    "venetianarnas": "venetianare",
    "venetianen": "venetian",
    "venetianens": "venetian",
    "venetianer": "venetian",
    "venetianerna": "venetian",
    "venetianernas": "venetian",
    "venetianers": "venetian",
    "venetians": "venetian",
    "venetianska": "venetiansk",
    "venetianskare": "venetiansk",
    "venetianskares": "venetiansk",
    "venetianskas": "venetiansk",
    "venetianskast": "venetiansk",
    "venetianskaste": "venetiansk",
    "venetianskastes": "venetiansk",
    "venetianskasts": "venetiansk",
    "venetianske": "venetiansk",
    "venetianskes": "venetiansk",
    "venetiansks": "venetiansk",
    "venetianskt": "venetiansk",
    "venetianskts": "venetiansk",
    "venezolanen": "venezolan",
    "venezolanens": "venezolan",
    "venezolaner": "venezolan",
    "venezolanerna": "venezolan",
    "venezolanernas": "venezolan",
    "venezolaners": "venezolan",
    "venezolans": "venezolan",
    "venezuelanen": "venezuelan",
    "venezuelanens": "venezuelan",
    "venezuelaner": "venezuelan",
    "venezuelanerna": "venezuelan",
    "venezuelanernas": "venezuelan",
    "venezuelaners": "venezuelan",
    "venezuelans": "venezuelan",
    "venias": "venia",
    "vens": "vina",
    "ventilationen": "ventilation",
    "ventilationens": "ventilation",
    "ventilationer": "ventilation",
    "ventilationerna": "ventilation",
    "ventilationernas": "ventilation",
    "ventilationers": "ventilation",
    "ventilations": "ventilation",
    "ventilationsfläktar": "ventilationsfläkt",
    "ventilationsfläktarna": "ventilationsfläkt",
    "ventilationsfläktarnas": "ventilationsfläkt",
    "ventilationsfläktars": "ventilationsfläkt",
    "ventilationsfläkten": "ventilationsfläkt",
    "ventilationsfläktens": "ventilationsfläkt",
    "ventilationsfläkts": "ventilationsfläkt",
    "ventilationssystemen": "ventilationssystem",
    "ventilationssystemens": "ventilationssystem",
    "ventilationssystemet": "ventilationssystem",
    "ventilationssystemets": "ventilationssystem",
    "ventilationssystems": "ventilationssystem",
    "ventilatorer": "ventilator",
    "ventilatorerna": "ventilator",
    "ventilatorernas": "ventilator",
    "ventilatorers": "ventilator",
    "ventilatorn": "ventilator",
    "ventilatorns": "ventilator",
    "ventilators": "ventilator",
    "ventilbasunen": "ventilbasun",
    "ventilbasunens": "ventilbasun",
    "ventilbasuner": "ventilbasun",
    "ventilbasunerna": "ventilbasun",
    "ventilbasunernas": "ventilbasun",
    "ventilbasuners": "ventilbasun",
    "ventilbasuns": "ventilbasun",
    "ventilen": "ventil",
    "ventilens": "ventil",
    "ventiler": "ventil",
    "ventilerad": "ventilera",
    "ventilerade": "ventilera",
    "ventilerades": "ventilera",
    "ventilerads": "ventilera",
    "ventilerande": "ventilera",
    "ventileranden": "ventilerande",
    "ventilerandena": "ventilerande",
    "ventilerandenas": "ventilerande",
    "ventilerandens": "ventilerande",
    "ventilerandes": "ventilerande",
    "ventilerandet": "ventilerande",
    "ventilerandets": "ventilerande",
    "ventilerar": "ventilera",
    "ventileras": "ventilera",
    "ventilerat": "ventilera",
    "ventilerats": "ventilera",
    "ventilerbara": "ventilerbar",
    "ventilerbarare": "ventilerbar",
    "ventilerbarares": "ventilerbar",
    "ventilerbaras": "ventilerbar",
    "ventilerbarast": "ventilerbar",
    "ventilerbaraste": "ventilerbar",
    "ventilerbarastes": "ventilerbar",
    "ventilerbarasts": "ventilerbar",
    "ventilerbare": "ventilerbar",
    "ventilerbares": "ventilerbar",
    "ventilerbarheten": "ventilerbarhet",
    "ventilerbarhetens": "ventilerbarhet",
    "ventilerbarhets": "ventilerbarhet",
    "ventilerbars": "ventilerbar",
    "ventilerbart": "ventilerbar",
    "ventilerbarts": "ventilerbar",
    "ventileringar": "ventilering",
    "ventileringarna": "ventilering",
    "ventileringarnas": "ventilering",
    "ventileringars": "ventilering",
    "ventileringen": "ventilering",
    "ventileringens": "ventilering",
    "ventilerings": "ventilering",
    "ventileringshålen": "ventileringshål",
    "ventileringshålens": "ventileringshål",
    "ventileringshålet": "ventileringshål",
    "ventileringshålets": "ventileringshål",
    "ventileringshåls": "ventileringshål",
    "ventilerna": "ventil",
    "ventilernas": "ventil",
    "ventilers": "ventil",
    "ventilfjädern": "ventilfjäder",
    "ventilfjäderns": "ventilfjäder",
    "ventilfjäders": "ventilfjäder",
    "ventilfjädrar": "ventilfjäder",
    "ventilfjädrarna": "ventilfjäder",
    "ventilfjädrarnas": "ventilfjäder",
    "ventilfjädrars": "ventilfjäder",
    "ventilgummin": "ventilgummi",
    "ventilgummina": "ventilgummi",
    "ventilgumminas": "ventilgummi",
    "ventilgummins": "ventilgummi",
    "ventilgummis": "ventilgummi",
    "ventilgummit": "ventilgummi",
    "ventilgummits": "ventilgummi",
    "ventilhattar": "ventilhatt",
    "ventilhattarna": "ventilhatt",
    "ventilhattarnas": "ventilhatt",
    "ventilhattars": "ventilhatt",
    "ventilhatten": "ventilhatt",
    "ventilhattens": "ventilhatt",
    "ventilhatts": "ventilhatt",
    "ventilhusen": "ventilhus",
    "ventilhusens": "ventilhus",
    "ventilhuset": "ventilhus",
    "ventilhusets": "ventilhus",
    "ventilrutan": "ventilruta",
    "ventilrutans": "ventilruta",
    "ventilrutas": "ventilruta",
    "ventilrute": "ventilruta",
    "ventilrutor": "ventilruta",
    "ventilrutorna": "ventilruta",
    "ventilrutornas": "ventilruta",
    "ventilrutors": "ventilruta",
    "ventils": "ventil",
    "ventilsnör": "ventilsnöre",
    "ventilsnören": "ventilsnöre",
    "ventilsnörena": "ventilsnöre",
    "ventilsnörenas": "ventilsnöre",
    "ventilsnörens": "ventilsnöre",
    "ventilsnöres": "ventilsnöre",
    "ventilsnöret": "ventilsnöre",
    "ventilsnörets": "ventilsnöre",
    "ventilsnörs": "ventilsnöre",
    "ventrikeln": "ventrikel",
    "ventrikelns": "ventrikel",
    "ventrikels": "ventrikel",
    "ventriklar": "ventrikel",
    "ventriklarna": "ventrikel",
    "ventriklarnas": "ventrikel",
    "ventriklars": "ventrikel",
    "venusbergen": "venusberg",
    "venusbergens": "venusberg",
    "venusberget": "venusberg",
    "venusbergets": "venusberg",
    "venusbergs": "venusberg",
    "venushåret": "venushår",
    "venushårets": "venushår",
    "venushårs": "venushår",
    "venösa": "venös",
    "venösare": "venös",
    "venösares": "venös",
    "venösas": "venös",
    "venösast": "venös",
    "venösaste": "venös",
    "venösastes": "venös",
    "venösasts": "venös",
    "venöse": "venös",
    "venöses": "venös",
    "venöst": "venös",
    "venösts": "venös",
    "vep": "vepa",
    "vepan": "vepa",
    "vepans": "vepa",
    "vepas": "vepa",
    "vepe": "vepa",
    "vepor": "vepa",
    "veporna": "vepa",
    "vepornas": "vepa",
    "vepors": "vepa",
    "veps": "vepa",
    "verand": "veranda",
    "verandadörrar": "verandadörr",
    "verandadörrarna": "verandadörr",
    "verandadörrarnas": "verandadörr",
    "verandadörrars": "verandadörr",
    "verandadörren": "verandadörr",
    "verandadörrens": "verandadörr",
    "verandadörrs": "verandadörr",
    "verandan": "veranda",
    "verandans": "veranda",
    "verandaräcken": "verandaräcke",
    "verandaräckena": "verandaräcke",
    "verandaräckenas": "verandaräcke",
    "verandaräckens": "verandaräcke",
    "verandaräckes": "verandaräcke",
    "verandaräcket": "verandaräcke",
    "verandaräckets": "verandaräcke",
    "verandas": "veranda",
    "verandatrapp": "verandatrappa",
    "verandatrappan": "verandatrappa",
    "verandatrappans": "verandatrappa",
    "verandatrappas": "verandatrappa",
    "verandatrappe": "verandatrappa",
    "verandatrappor": "verandatrappa",
    "verandatrapporna": "verandatrappa",
    "verandatrappornas": "verandatrappa",
    "verandatrappors": "verandatrappa",
    "verandatrapps": "verandatrappa",
    "verande": "veranda",
    "verandor": "veranda",
    "verandorna": "veranda",
    "verandornas": "veranda",
    "verandors": "veranda",
    "verands": "veranda",
    "verbala": "verbal",
    "verbalabstrakten": "verbalabstrakt",
    "verbalabstraktens": "verbalabstrakt",
    "verbalabstrakter": "verbalabstrakt",
    "verbalabstrakterna": "verbalabstrakt",
    "verbalabstrakternas": "verbalabstrakt",
    "verbalabstrakters": "verbalabstrakt",
    "verbalabstraktet": "verbalabstrakt",
    "verbalabstraktets": "verbalabstrakt",
    "verbalabstrakts": "verbalabstrakt",
    "verbalare": "verbal",
    "verbalares": "verbal",
    "verbalas": "verbal",
    "verbalast": "verbal",
    "verbalaste": "verbal",
    "verbalastes": "verbal",
    "verbalasts": "verbal",
    "verbale": "verbal",
    "verbales": "verbal",
    "verbalfaktorer": "verbalfaktor",
    "verbalfaktorerna": "verbalfaktor",
    "verbalfaktorernas": "verbalfaktor",
    "verbalfaktorers": "verbalfaktor",
    "verbalfaktorn": "verbalfaktor",
    "verbalfaktorns": "verbalfaktor",
    "verbalfaktors": "verbalfaktor",
    "verbalinspirationen": "verbalinspiration",
    "verbalinspirationens": "verbalinspiration",
    "verbalinspirationer": "verbalinspiration",
    "verbalinspirationerna": "verbalinspiration",
    "verbalinspirationernas": "verbalinspiration",
    "verbalinspirationers": "verbalinspiration",
    "verbalinspirations": "verbalinspiration",
    "verbaliserad": "verbalisera",
    "verbaliserade": "verbalisera",
    "verbaliserades": "verbalisera",
    "verbaliserads": "verbalisera",
    "verbaliserande": "verbalisera",
    "verbaliseranden": "verbaliserande",
    "verbaliserandena": "verbaliserande",
    "verbaliserandenas": "verbaliserande",
    "verbaliserandens": "verbaliserande",
    "verbaliserandes": "verbaliserande",
    "verbaliserandet": "verbaliserande",
    "verbaliserandets": "verbaliserande",
    "verbaliserar": "verbalisera",
    "verbaliseras": "verbalisera",
    "verbaliserat": "verbalisera",
    "verbaliserats": "verbalisera",
    "verbaliserbara": "verbaliserbar",
    "verbaliserbarare": "verbaliserbar",
    "verbaliserbarares": "verbaliserbar",
    "verbaliserbaras": "verbaliserbar",
    "verbaliserbarast": "verbaliserbar",
    "verbaliserbaraste": "verbaliserbar",
    "verbaliserbarastes": "verbaliserbar",
    "verbaliserbarasts": "verbaliserbar",
    "verbaliserbare": "verbaliserbar",
    "verbaliserbares": "verbaliserbar",
    "verbaliserbarheten": "verbaliserbarhet",
    "verbaliserbarhetens": "verbaliserbarhet",
    "verbaliserbarhets": "verbaliserbarhet",
    "verbaliserbars": "verbaliserbar",
    "verbaliserbart": "verbaliserbar",
    "verbaliserbarts": "verbaliserbar",
    "verbaliseringar": "verbalisering",
    "verbaliseringarna": "verbalisering",
    "verbaliseringarnas": "verbalisering",
    "verbaliseringars": "verbalisering",
    "verbaliseringen": "verbalisering",
    "verbaliseringens": "verbalisering",
    "verbaliserings": "verbalisering",
    "verbalismen": "verbalism",
    "verbalismens": "verbalism",
    "verbalismer": "verbalism",
    "verbalismerna": "verbalism",
    "verbalismernas": "verbalism",
    "verbalismers": "verbalism",
    "verbalisms": "verbalism",
    "verbaliteten": "verbalitet",
    "verbalitetens": "verbalitet",
    "verbaliteter": "verbalitet",
    "verbaliteterna": "verbalitet",
    "verbaliteternas": "verbalitet",
    "verbaliteters": "verbalitet",
    "verbalitets": "verbalitet",
    "verbalnoten": "verbalnot",
    "verbalnotens": "verbalnot",
    "verbalnoter": "verbalnot",
    "verbalnoterna": "verbalnot",
    "verbalnoternas": "verbalnot",
    "verbalnoters": "verbalnot",
    "verbalnots": "verbalnot",
    "verbals": "verbal",
    "verbalstammar": "verbalstam",
    "verbalstammarna": "verbalstam",
    "verbalstammarnas": "verbalstam",
    "verbalstammars": "verbalstam",
    "verbalstammen": "verbalstam",
    "verbalstammens": "verbalstam",
    "verbalstams": "verbalstam",
    "verbalsubstantiven": "verbalsubstantiv",
    "verbalsubstantivens": "verbalsubstantiv",
    "verbalsubstantivet": "verbalsubstantiv",
    "verbalsubstantivets": "verbalsubstantiv",
    "verbalsubstantivs": "verbalsubstantiv",
    "verbalt": "verbal",
    "verbalts": "verbal",
    "verben": "verbena",
    "verbenan": "verbena",
    "verbenans": "verbena",
    "verbenas": "verbena",
    "verbene": "verbena",
    "verbenor": "verbena",
    "verbenorna": "verbena",
    "verbenornas": "verbena",
    "verbenors": "verbena",
    "verbens": "verbena",
    "verbet": "verb",
    "verbets": "verb",
    "verbformen": "verbform",
    "verbformens": "verbform",
    "verbformer": "verbform",
    "verbformerna": "verbform",
    "verbformernas": "verbform",
    "verbformers": "verbform",
    "verbforms": "verbform",
    "verbhandlingar": "verbhandling",
    "verbhandlingarna": "verbhandling",
    "verbhandlingarnas": "verbhandling",
    "verbhandlingars": "verbhandling",
    "verbhandlingen": "verbhandling",
    "verbhandlingens": "verbhandling",
    "verbhandlings": "verbhandling",
    "verbs": "verb",
    "verbsammansättningar": "verbsammansättning",
    "verbsammansättningarna": "verbsammansättning",
    "verbsammansättningarnas": "verbsammansättning",
    "verbsammansättningars": "verbsammansättning",
    "verbsammansättningen": "verbsammansättning",
    "verbsammansättningens": "verbsammansättning",
    "verbsammansättnings": "verbsammansättning",
    "verbstammar": "verbstam",
    "verbstammarna": "verbstam",
    "verbstammarnas": "verbstam",
    "verbstammars": "verbstam",
    "verbstammen": "verbstam",
    "verbstammens": "verbstam",
    "verbstams": "verbstam",
    "verbändelsen": "verbändelse",
    "verbändelsens": "verbändelse",
    "verbändelser": "verbändelse",
    "verbändelserna": "verbändelse",
    "verbändelsernas": "verbändelse",
    "verbändelsers": "verbändelse",
    "verbändelses": "verbändelse",
    "verifierad": "verifiera",
    "verifierade": "verifiera",
    "verifierades": "verifiera",
    "verifierads": "verifiera",
    "verifierande": "verifiera",
    "verifieranden": "verifierande",
    "verifierandena": "verifierande",
    "verifierandenas": "verifierande",
    "verifierandens": "verifierande",
    "verifierandes": "verifierande",
    "verifierandet": "verifierande",
    "verifierandets": "verifierande",
    "verifierar": "verifiera",
    "verifieras": "verifiera",
    "verifierat": "verifiera",
    "verifierats": "verifiera",
    "verifierbara": "verifierbar",
    "verifierbarare": "verifierbar",
    "verifierbarares": "verifierbar",
    "verifierbaras": "verifierbar",
    "verifierbarast": "verifierbar",
    "verifierbaraste": "verifierbar",
    "verifierbarastes": "verifierbar",
    "verifierbarasts": "verifierbar",
    "verifierbare": "verifierbar",
    "verifierbares": "verifierbar",
    "verifierbarheten": "verifierbarhet",
    "verifierbarhetens": "verifierbarhet",
    "verifierbarhets": "verifierbarhet",
    "verifierbars": "verifierbar",
    "verifierbart": "verifierbar",
    "verifierbarts": "verifierbar",
    "verifieringar": "verifiering",
    "verifieringarna": "verifiering",
    "verifieringarnas": "verifiering",
    "verifieringars": "verifiering",
    "verifieringen": "verifiering",
    "verifieringens": "verifiering",
    "verifierings": "verifiering",
    "verifikaten": "verifikat",
    "verifikatens": "verifikat",
    "verifikatet": "verifikat",
    "verifikatets": "verifikat",
    "verifikationen": "verifikation",
    "verifikationens": "verifikation",
    "verifikationer": "verifikation",
    "verifikationerna": "verifikation",
    "verifikationernas": "verifikation",
    "verifikationers": "verifikation",
    "verifikations": "verifikation",
    "verifikats": "verifikat",
    "verismen": "verism",
    "verismens": "verism",
    "verismer": "verism",
    "verismerna": "verism",
    "verismernas": "verism",
    "verismers": "verism",
    "verisms": "verism",
    "veristiska": "veristisk",
    "veristiskas": "veristisk",
    "veristiske": "veristisk",
    "veristiskes": "veristisk",
    "veristisks": "veristisk",
    "veristiskt": "veristisk",
    "veristiskts": "veristisk",
    "veritabels": "veritabel",
    "veritabelt": "veritabel",
    "veritabelts": "veritabel",
    "veritabla": "veritabel",
    "veritablare": "veritabel",
    "veritablares": "veritabel",
    "veritablas": "veritabel",
    "veritablast": "veritabel",
    "veritablaste": "veritabel",
    "veritablastes": "veritabel",
    "veritablasts": "veritabel",
    "veritable": "veritabel",
    "veritables": "veritabel",
    "verk": "verka",
    "verkad": "verka",
    "verkade": "verka",
    "verkades": "verka",
    "verkads": "verka",
    "verkande": "verka",
    "verkanden": "verkande",
    "verkandena": "verkande",
    "verkandenas": "verkande",
    "verkandens": "verkande",
    "verkandes": "verkande",
    "verkandet": "verkande",
    "verkandets": "verkande",
    "verkans": "verkan",
    "verkar": "verka",
    "verkas": "verka",
    "verkat": "verka",
    "verkats": "verka",
    "verkblyet": "verkbly",
    "verkblyets": "verkbly",
    "verkblys": "verkbly",
    "verkblyt": "verkbly",
    "verkblyts": "verkbly",
    "verkborden": "verkbord",
    "verkbordens": "verkbord",
    "verkbordet": "verkbord",
    "verkbordets": "verkbord",
    "verkbords": "verkbord",
    "verken": "verk",
    "verkens": "verk",
    "verket": "verk",
    "verkets": "verk",
    "verkheliga": "verkhelig",
    "verkheligare": "verkhelig",
    "verkheligares": "verkhelig",
    "verkheligas": "verkhelig",
    "verkheligast": "verkhelig",
    "verkheligaste": "verkhelig",
    "verkheligastes": "verkhelig",
    "verkheligasts": "verkhelig",
    "verkhelige": "verkhelig",
    "verkheliges": "verkhelig",
    "verkheligheten": "verkhelighet",
    "verkhelighetens": "verkhelighet",
    "verkhelighets": "verkhelighet",
    "verkheligs": "verkhelig",
    "verkheligt": "verkhelig",
    "verkheligts": "verkhelig",
    "verkjärnen": "verkjärn",
    "verkjärnens": "verkjärn",
    "verkjärnet": "verkjärn",
    "verkjärnets": "verkjärn",
    "verkjärns": "verkjärn",
    "verkliga": "verklig",
    "verkligare": "verklig",
    "verkligares": "verklig",
    "verkligas": "verklig",
    "verkligast": "verklig",
    "verkligaste": "verklig",
    "verkligastes": "verklig",
    "verkligasts": "verklig",
    "verklige": "verklig",
    "verkliges": "verklig",
    "verkliggjord": "verkliggöra",
    "verkliggjorda": "verkliggöra",
    "verkliggjordas": "verkliggöra",
    "verkliggjorde": "verkliggöra",
    "verkliggjordes": "verkliggöra",
    "verkliggjords": "verkliggöra",
    "verkliggjort": "verkliggöra",
    "verkliggjorts": "verkliggöra",
    "verkliggör": "verkliggöra",
    "verkliggörande": "verkliggöra",
    "verkliggöranden": "verkliggörande",
    "verkliggörandena": "verkliggörande",
    "verkliggörandenas": "verkliggörande",
    "verkliggörandens": "verkliggörande",
    "verkliggörandes": "verkliggörande",
    "verkliggörandet": "verkliggörande",
    "verkliggörandets": "verkliggörande",
    "verkliggöras": "verkliggöra",
    "verkliggöres": "verkliggöra",
    "verkliggörs": "verkliggöra",
    "verkligheten": "verklighet",
    "verklighetens": "verklighet",
    "verkligheter": "verklighet",
    "verkligheterna": "verklighet",
    "verkligheternas": "verklighet",
    "verkligheters": "verklighet",
    "verklighets": "verklighet",
    "verklighetsbakgrunden": "verklighetsbakgrund",
    "verklighetsbakgrundens": "verklighetsbakgrund",
    "verklighetsbakgrunder": "verklighetsbakgrund",
    "verklighetsbakgrunderna": "verklighetsbakgrund",
    "verklighetsbakgrundernas": "verklighetsbakgrund",
    "verklighetsbakgrunders": "verklighetsbakgrund",
    "verklighetsbakgrunds": "verklighetsbakgrund",
    "verklighetsbaserade": "verklighetsbaserad",
    "verklighetsbaserades": "verklighetsbaserad",
    "verklighetsbaserads": "verklighetsbaserad",
    "verklighetsbaserat": "verklighetsbaserad",
    "verklighetsbaserats": "verklighetsbaserad",
    "verklighetsbetonade": "verklighetsbetonad",
    "verklighetsbetonades": "verklighetsbetonad",
    "verklighetsbetonads": "verklighetsbetonad",
    "verklighetsbetonat": "verklighetsbetonad",
    "verklighetsbetonats": "verklighetsbetonad",
    "verklighetschocken": "verklighetschock",
    "verklighetschockens": "verklighetschock",
    "verklighetschocker": "verklighetschock",
    "verklighetschockerna": "verklighetschock",
    "verklighetschockernas": "verklighetschock",
    "verklighetschockers": "verklighetschock",
    "verklighetschocks": "verklighetschock",
    "verklighetsflykten": "verklighetsflykt",
    "verklighetsflyktens": "verklighetsflykt",
    "verklighetsflykts": "verklighetsflykt",
    "verklighetsförankrad": "verklighetsförankra",
    "verklighetsförankrade": "verklighetsförankra",
    "verklighetsförankrades": "verklighetsförankra",
    "verklighetsförankrads": "verklighetsförankra",
    "verklighetsförankrande": "verklighetsförankra",
    "verklighetsförankranden": "verklighetsförankrande",
    "verklighetsförankrandena": "verklighetsförankrande",
    "verklighetsförankrandenas": "verklighetsförankrande",
    "verklighetsförankrandens": "verklighetsförankrande",
    "verklighetsförankrandes": "verklighetsförankrande",
    "verklighetsförankrandet": "verklighetsförankrande",
    "verklighetsförankrandets": "verklighetsförankrande",
    "verklighetsförankrar": "verklighetsförankra",
    "verklighetsförankras": "verklighetsförankra",
    "verklighetsförankrat": "verklighetsförankra",
    "verklighetsförankrats": "verklighetsförankra",
    "verklighetstrogens": "verklighetstrogen",
    "verklighetstroget": "verklighetstrogen",
    "verklighetstrogets": "verklighetstrogen",
    "verklighetstrogna": "verklighetstrogen",
    "verklighetstrognare": "verklighetstrogen",
    "verklighetstrognares": "verklighetstrogen",
    "verklighetstrognas": "verklighetstrogen",
    "verklighetstrognast": "verklighetstrogen",
    "verklighetstrognaste": "verklighetstrogen",
    "verklighetstrognastes": "verklighetstrogen",
    "verklighetstrognasts": "verklighetstrogen",
    "verklighetstrogne": "verklighetstrogen",
    "verklighetstrognes": "verklighetstrogen",
    "verkligs": "verklig",
    "verkligt": "verklig",
    "verkligts": "verklig",
    "verkmästar": "verkmästare",
    "verkmästaren": "verkmästare",
    "verkmästarens": "verkmästare",
    "verkmästares": "verkmästare",
    "verkmästarna": "verkmästare",
    "verkmästarnas": "verkmästare",
    "verkningar": "verkning",
    "verkningarna": "verkning",
    "verkningarnas": "verkning",
    "verkningars": "verkning",
    "verkningen": "verkning",
    "verkningens": "verkning",
    "verknings": "verkning",
    "verkningselden": "verkningseld",
    "verkningseldens": "verkningseld",
    "verkningselds": "verkningseld",
    "verkningsfulla": "verkningsfull",
    "verkningsfullare": "verkningsfull",
    "verkningsfullares": "verkningsfull",
    "verkningsfullas": "verkningsfull",
    "verkningsfullast": "verkningsfull",
    "verkningsfullaste": "verkningsfull",
    "verkningsfullastes": "verkningsfull",
    "verkningsfullasts": "verkningsfull",
    "verkningsfulle": "verkningsfull",
    "verkningsfulles": "verkningsfull",
    "verkningsfullheten": "verkningsfullhet",
    "verkningsfullhetens": "verkningsfullhet",
    "verkningsfullhets": "verkningsfullhet",
    "verkningsfulls": "verkningsfull",
    "verkningsfullt": "verkningsfull",
    "verkningsfullts": "verkningsfull",
    "verkningsgraden": "verkningsgrad",
    "verkningsgradens": "verkningsgrad",
    "verkningsgrader": "verkningsgrad",
    "verkningsgraderna": "verkningsgrad",
    "verkningsgradernas": "verkningsgrad",
    "verkningsgraders": "verkningsgrad",
    "verkningsgrads": "verkningsgrad",
    "verkningslösa": "verkningslös",
    "verkningslösare": "verkningslös",
    "verkningslösares": "verkningslös",
    "verkningslösas": "verkningslös",
    "verkningslösast": "verkningslös",
    "verkningslösaste": "verkningslös",
    "verkningslösastes": "verkningslös",
    "verkningslösasts": "verkningslös",
    "verkningslöse": "verkningslös",
    "verkningslöses": "verkningslös",
    "verkningslösheten": "verkningslöshet",
    "verkningslöshetens": "verkningslöshet",
    "verkningslöshets": "verkningslöshet",
    "verkningslöst": "verkningslös",
    "verkningslösts": "verkningslös",
    "verks": "verk",
    "verksamheten": "verksamhet",
    "verksamhetens": "verksamhet",
    "verksamheter": "verksamhet",
    "verksamheterna": "verksamhet",
    "verksamheternas": "verksamhet",
    "verksamheters": "verksamhet",
    "verksamhets": "verksamhet",
    "verksamhetsbehoven": "verksamhetsbehov",
    "verksamhetsbehovens": "verksamhetsbehov",
    "verksamhetsbehovet": "verksamhetsbehov",
    "verksamhetsbehovets": "verksamhetsbehov",
    "verksamhetsbehovs": "verksamhetsbehov",
    "verksamhetsberättelsen": "verksamhetsberättelse",
    "verksamhetsberättelsens": "verksamhetsberättelse",
    "verksamhetsberättelser": "verksamhetsberättelse",
    "verksamhetsberättelserna": "verksamhetsberättelse",
    "verksamhetsberättelsernas": "verksamhetsberättelse",
    "verksamhetsberättelsers": "verksamhetsberättelse",
    "verksamhetsberättelses": "verksamhetsberättelse",
    "verksamhetsfälten": "verksamhetsfält",
    "verksamhetsfältens": "verksamhetsfält",
    "verksamhetsfältet": "verksamhetsfält",
    "verksamhetsfältets": "verksamhetsfält",
    "verksamhetsfälts": "verksamhetsfält",
    "verksamhetsmässiga": "verksamhetsmässig",
    "verksamhetsmässigare": "verksamhetsmässig",
    "verksamhetsmässigares": "verksamhetsmässig",
    "verksamhetsmässigas": "verksamhetsmässig",
    "verksamhetsmässigast": "verksamhetsmässig",
    "verksamhetsmässigaste": "verksamhetsmässig",
    "verksamhetsmässigastes": "verksamhetsmässig",
    "verksamhetsmässigasts": "verksamhetsmässig",
    "verksamhetsmässige": "verksamhetsmässig",
    "verksamhetsmässiges": "verksamhetsmässig",
    "verksamhetsmässigs": "verksamhetsmässig",
    "verksamhetsmässigt": "verksamhetsmässig",
    "verksamhetsmässigts": "verksamhetsmässig",
    "verksamhetsområden": "verksamhetsområde",
    "verksamhetsområdena": "verksamhetsområde",
    "verksamhetsområdenas": "verksamhetsområde",
    "verksamhetsområdens": "verksamhetsområde",
    "verksamhetsområdes": "verksamhetsområde",
    "verksamhetsområdet": "verksamhetsområde",
    "verksamhetsområdets": "verksamhetsområde",
    "verksamhetsåren": "verksamhetsår",
    "verksamhetsårens": "verksamhetsår",
    "verksamhetsåret": "verksamhetsår",
    "verksamhetsårets": "verksamhetsår",
    "verksamhetsårs": "verksamhetsår",
    "verksamma": "verksam",
    "verksammare": "verksam",
    "verksammares": "verksam",
    "verksammas": "verksam",
    "verksammast": "verksam",
    "verksammaste": "verksam",
    "verksammastes": "verksam",
    "verksammasts": "verksam",
    "verksamme": "verksam",
    "verksammes": "verksam",
    "verksams": "verksam",
    "verksamt": "verksam",
    "verksamts": "verksam",
    "verkshöjden": "verkshöjd",
    "verkshöjdens": "verkshöjd",
    "verkshöjder": "verkshöjd",
    "verkshöjderna": "verkshöjd",
    "verkshöjdernas": "verkshöjd",
    "verkshöjders": "verkshöjd",
    "verkshöjds": "verkshöjd",
    "verkskyddet": "verkskydd",
    "verkskyddets": "verkskydd",
    "verkskydds": "verkskydd",
    "verksläkar": "verksläkare",
    "verksläkaren": "verksläkare",
    "verksläkarens": "verksläkare",
    "verksläkares": "verksläkare",
    "verksläkarna": "verksläkare",
    "verksläkarnas": "verksläkare",
    "verkstaden": "verkstad",
    "verkstadens": "verkstad",
    "verkstads": "verkstad",
    "verkstadsarbetar": "verkstadsarbetare",
    "verkstadsarbetaren": "verkstadsarbetare",
    "verkstadsarbetarens": "verkstadsarbetare",
    "verkstadsarbetares": "verkstadsarbetare",
    "verkstadsarbetarna": "verkstadsarbetare",
    "verkstadsarbetarnas": "verkstadsarbetare",
    "verkstadsarbeten": "verkstadsarbete",
    "verkstadsarbetena": "verkstadsarbete",
    "verkstadsarbetenas": "verkstadsarbete",
    "verkstadsarbetens": "verkstadsarbete",
    "verkstadsarbetes": "verkstadsarbete",
    "verkstadsarbetet": "verkstadsarbete",
    "verkstadsarbetets": "verkstadsarbete",
    "verkstadsarbets": "verkstadsarbete",
    "verkstadsföreningar": "verkstadsförening",
    "verkstadsföreningarna": "verkstadsförening",
    "verkstadsföreningarnas": "verkstadsförening",
    "verkstadsföreningars": "verkstadsförening",
    "verkstadsföreningen": "verkstadsförening",
    "verkstadsföreningens": "verkstadsförening",
    "verkstadsförenings": "verkstadsförening",
    "verkstadshusen": "verkstadshus",
    "verkstadshusens": "verkstadshus",
    "verkstadshuset": "verkstadshus",
    "verkstadshusets": "verkstadshus",
    "verkstadsindustrien": "verkstadsindustri",
    "verkstadsindustriens": "verkstadsindustri",
    "verkstadsindustrier": "verkstadsindustri",
    "verkstadsindustrierna": "verkstadsindustri",
    "verkstadsindustriernas": "verkstadsindustri",
    "verkstadsindustriers": "verkstadsindustri",
    "verkstadsindustrin": "verkstadsindustri",
    "verkstadsindustrins": "verkstadsindustri",
    "verkstadsindustris": "verkstadsindustri",
    "verkstadsklubbar": "verkstadsklubb",
    "verkstadsklubbarna": "verkstadsklubb",
    "verkstadsklubbarnas": "verkstadsklubb",
    "verkstadsklubbars": "verkstadsklubb",
    "verkstadsklubben": "verkstadsklubb",
    "verkstadsklubbens": "verkstadsklubb",
    "verkstadsklubbs": "verkstadsklubb",
    "verkstadskranar": "verkstadskran",
    "verkstadskranarna": "verkstadskran",
    "verkstadskranarnas": "verkstadskran",
    "verkstadskranars": "verkstadskran",
    "verkstadskranen": "verkstadskran",
    "verkstadskranens": "verkstadskran",
    "verkstadskrans": "verkstadskran",
    "verkstan": "verkstad",
    "verkstans": "verkstad",
    "verkstäder": "verkstad",
    "verkstäderna": "verkstad",
    "verkstädernas": "verkstad",
    "verkstäders": "verkstad",
    "verkställ": "verkställa",
    "verkställande": "verkställa",
    "verkställanden": "verkställande",
    "verkställandena": "verkställande",
    "verkställandenas": "verkställande",
    "verkställandens": "verkställande",
    "verkställandes": "verkställande",
    "verkställandet": "verkställande",
    "verkställandets": "verkställande",
    "verkställas": "verkställa",
    "verkställd": "verkställa",
    "verkställda": "verkställa",
    "verkställdas": "verkställa",
    "verkställde": "verkställa",
    "verkställdes": "verkställa",
    "verkställds": "verkställa",
    "verkställer": "verkställa",
    "verkställes": "verkställa",
    "verkställigheten": "verkställighet",
    "verkställighetens": "verkställighet",
    "verkställigheter": "verkställighet",
    "verkställigheterna": "verkställighet",
    "verkställigheternas": "verkställighet",
    "verkställigheters": "verkställighet",
    "verkställighets": "verkställighet",
    "verkställs": "verkställa",
    "verkställt": "verkställa",
    "verkställts": "verkställa",
    "verksynden": "verksynd",
    "verksyndens": "verksynd",
    "verksynder": "verksynd",
    "verksynderna": "verksynd",
    "verksyndernas": "verksynd",
    "verksynders": "verksynd",
    "verksynds": "verksynd",
    "verktummen": "verktum",
    "verktummens": "verktum",
    "verktums": "verktum",
    "verktygen": "verktyg",
    "verktygens": "verktyg",
    "verktyget": "verktyg",
    "verktygets": "verktyg",
    "verktygs": "verktyg",
    "verktygsbälten": "verktygsbälte",
    "verktygsbältena": "verktygsbälte",
    "verktygsbältenas": "verktygsbälte",
    "verktygsbältens": "verktygsbälte",
    "verktygsbältes": "verktygsbälte",
    "verktygsbältet": "verktygsbälte",
    "verktygsbältets": "verktygsbälte",
    "verktygskrokar": "verktygskrok",
    "verktygskrokarna": "verktygskrok",
    "verktygskrokarnas": "verktygskrok",
    "verktygskrokars": "verktygskrok",
    "verktygskroken": "verktygskrok",
    "verktygskrokens": "verktygskrok",
    "verktygskroks": "verktygskrok",
    "verktygslåd": "verktygslåda",
    "verktygslådan": "verktygslåda",
    "verktygslådans": "verktygslåda",
    "verktygslådas": "verktygslåda",
    "verktygslåde": "verktygslåda",
    "verktygslådor": "verktygslåda",
    "verktygslådorna": "verktygslåda",
    "verktygslådornas": "verktygslåda",
    "verktygslådors": "verktygslåda",
    "verktygslåds": "verktygslåda",
    "verktygsmaskinen": "verktygsmaskin",
    "verktygsmaskinens": "verktygsmaskin",
    "verktygsmaskiner": "verktygsmaskin",
    "verktygsmaskinerna": "verktygsmaskin",
    "verktygsmaskinernas": "verktygsmaskin",
    "verktygsmaskiners": "verktygsmaskin",
    "verktygsmaskins": "verktygsmaskin",
    "verktygssatsen": "verktygssats",
    "verktygssatsens": "verktygssats",
    "verktygssatser": "verktygssats",
    "verktygssatserna": "verktygssats",
    "verktygssatsernas": "verktygssats",
    "verktygssatsers": "verktygssats",
    "verktygsstålet": "verktygsstål",
    "verktygsstålets": "verktygsstål",
    "verktygsståls": "verktygsstål",
    "verktygsväsk": "verktygsväska",
    "verktygsväskan": "verktygsväska",
    "verktygsväskans": "verktygsväska",
    "verktygsväskas": "verktygsväska",
    "verktygsväske": "verktygsväska",
    "verktygsväskor": "verktygsväska",
    "verktygsväskorna": "verktygsväska",
    "verktygsväskornas": "verktygsväska",
    "verktygsväskors": "verktygsväska",
    "vermicell": "vermiceller",
    "vermicellerna": "vermiceller",
    "vermicellernas": "vermiceller",
    "vermicellers": "vermiceller",
    "vermicells": "vermiceller",
    "vermouthen": "vermouth",
    "vermouthens": "vermouth",
    "vermouths": "vermouth",
    "vermuten": "vermut",
    "vermutens": "vermut",
    "vermuts": "vermut",
    "vernaliseringar": "vernalisering",
    "vernaliseringarna": "vernalisering",
    "vernaliseringarnas": "vernalisering",
    "vernaliseringars": "vernalisering",
    "vernaliseringen": "vernalisering",
    "vernaliseringens": "vernalisering",
    "vernaliserings": "vernalisering",
    "vernissagen": "vernissage",
    "vernissagens": "vernissage",
    "vernissager": "vernissage",
    "vernissagerna": "vernissage",
    "vernissagernas": "vernissage",
    "vernissagers": "vernissage",
    "vernissages": "vernissage",
    "versalen": "versal",
    "versalens": "versal",
    "versaler": "versal",
    "versalerna": "versal",
    "versalernas": "versal",
    "versalers": "versal",
    "versals": "versal",
    "versar": "vers",
    "versarna": "vers",
    "versarnas": "vers",
    "versars": "vers",
    "versatila": "versatil",
    "versatilare": "versatil",
    "versatilares": "versatil",
    "versatilas": "versatil",
    "versatilast": "versatil",
    "versatilaste": "versatil",
    "versatilastes": "versatil",
    "versatilasts": "versatil",
    "versatile": "versatil",
    "versatiles": "versatil",
    "versatils": "versatil",
    "versatilt": "versatil",
    "versatilts": "versatil",
    "versberättelsen": "versberättelse",
    "versberättelsens": "versberättelse",
    "versberättelser": "versberättelse",
    "versberättelserna": "versberättelse",
    "versberättelsernas": "versberättelse",
    "versberättelsers": "versberättelse",
    "versberättelses": "versberättelse",
    "versbindningar": "versbindning",
    "versbindningarna": "versbindning",
    "versbindningarnas": "versbindning",
    "versbindningars": "versbindning",
    "versbindningen": "versbindning",
    "versbindningens": "versbindning",
    "versbindnings": "versbindning",
    "versen": "vers",
    "versens": "vers",
    "verser": "vers",
    "verserade": "verserad",
    "verserades": "verserad",
    "verserads": "verserad",
    "verserat": "verserad",
    "verserats": "verserad",
    "verserna": "vers",
    "versernas": "vers",
    "versers": "vers",
    "versfoten": "versfot",
    "versfotens": "versfot",
    "versfots": "versfot",
    "versfötter": "versfot",
    "versfötterna": "versfot",
    "versfötternas": "versfot",
    "versfötters": "versfot",
    "versifierad": "versifiera",
    "versifierade": "versifiera",
    "versifierades": "versifiera",
    "versifierads": "versifiera",
    "versifierande": "versifiera",
    "versifieranden": "versifierande",
    "versifierandena": "versifierande",
    "versifierandenas": "versifierande",
    "versifierandens": "versifierande",
    "versifierandes": "versifierande",
    "versifierandet": "versifierande",
    "versifierandets": "versifierande",
    "versifierar": "versifiera",
    "versifieras": "versifiera",
    "versifierat": "versifiera",
    "versifierats": "versifiera",
    "versifierbara": "versifierbar",
    "versifierbarare": "versifierbar",
    "versifierbarares": "versifierbar",
    "versifierbaras": "versifierbar",
    "versifierbarast": "versifierbar",
    "versifierbaraste": "versifierbar",
    "versifierbarastes": "versifierbar",
    "versifierbarasts": "versifierbar",
    "versifierbare": "versifierbar",
    "versifierbares": "versifierbar",
    "versifierbarheten": "versifierbarhet",
    "versifierbarhetens": "versifierbarhet",
    "versifierbarhets": "versifierbarhet",
    "versifierbars": "versifierbar",
    "versifierbart": "versifierbar",
    "versifierbarts": "versifierbar",
    "versifieringar": "versifiering",
    "versifieringarna": "versifiering",
    "versifieringarnas": "versifiering",
    "versifieringars": "versifiering",
    "versifieringen": "versifiering",
    "versifieringens": "versifiering",
    "versifierings": "versifiering",
    "versifikationen": "versifikation",
    "versifikationens": "versifikation",
    "versifikationer": "versifikation",
    "versifikationerna": "versifikation",
    "versifikationernas": "versifikation",
    "versifikationers": "versifikation",
    "versifikations": "versifikation",
    "versifikatören": "versifikatör",
    "versifikatörens": "versifikatör",
    "versifikatörer": "versifikatör",
    "versifikatörerna": "versifikatör",
    "versifikatörernas": "versifikatör",
    "versifikatörers": "versifikatör",
    "versifikatörs": "versifikatör",
    "versionen": "version",
    "versionens": "version",
    "versioner": "version",
    "versionerna": "version",
    "versionernas": "version",
    "versioners": "version",
    "versions": "version",
    "versläran": "verslära",
    "verslärans": "verslära",
    "versläras": "verslära",
    "versläre": "verslära",
    "versläro": "verslära",
    "versläror": "verslära",
    "verslärorna": "verslära",
    "verslärornas": "verslära",
    "verslärors": "verslära",
    "versmakar": "versmakare",
    "versmakaren": "versmakare",
    "versmakarens": "versmakare",
    "versmakares": "versmakare",
    "versmakarna": "versmakare",
    "versmakarnas": "versmakare",
    "versmåtten": "versmått",
    "versmåttens": "versmått",
    "versmåttet": "versmått",
    "versmåttets": "versmått",
    "versmåtts": "versmått",
    "versraden": "versrad",
    "versradens": "versrad",
    "versrader": "versrad",
    "versraderna": "versrad",
    "versradernas": "versrad",
    "versraders": "versrad",
    "versrads": "versrad",
    "versten": "verst",
    "verstens": "verst",
    "versts": "verst",
    "vertebraten": "vertebrat",
    "vertebratens": "vertebrat",
    "vertebrater": "vertebrat",
    "vertebraterna": "vertebrat",
    "vertebraternas": "vertebrat",
    "vertebraters": "vertebrat",
    "vertebrats": "vertebrat",
    "vertebrerade": "vertebrerad",
    "vertebrerades": "vertebrerad",
    "vertebrerads": "vertebrerad",
    "vertebrerat": "vertebrerad",
    "vertebrerats": "vertebrerad",
    "vertikala": "vertikal",
    "vertikalare": "vertikal",
    "vertikalares": "vertikal",
    "vertikalas": "vertikal",
    "vertikalast": "vertikal",
    "vertikalaste": "vertikal",
    "vertikalastes": "vertikal",
    "vertikalasts": "vertikal",
    "vertikalaxlade": "vertikalaxlad",
    "vertikalaxlades": "vertikalaxlad",
    "vertikalaxlads": "vertikalaxlad",
    "vertikalaxlat": "vertikalaxlad",
    "vertikalaxlats": "vertikalaxlad",
    "vertikalcirkeln": "vertikalcirkel",
    "vertikalcirkelns": "vertikalcirkel",
    "vertikalcirkels": "vertikalcirkel",
    "vertikalcirklar": "vertikalcirkel",
    "vertikalcirklarna": "vertikalcirkel",
    "vertikalcirklarnas": "vertikalcirkel",
    "vertikalcirklars": "vertikalcirkel",
    "vertikale": "vertikal",
    "vertikalen": "vertikal",
    "vertikalens": "vertikal",
    "vertikaler": "vertikal",
    "vertikalerna": "vertikal",
    "vertikalernas": "vertikal",
    "vertikalers": "vertikal",
    "vertikales": "vertikal",
    "vertikallägen": "vertikalläge",
    "vertikallägena": "vertikalläge",
    "vertikallägenas": "vertikalläge",
    "vertikallägens": "vertikalläge",
    "vertikalläges": "vertikalläge",
    "vertikalläget": "vertikalläge",
    "vertikallägets": "vertikalläge",
    "vertikalplanen": "vertikalplan",
    "vertikalplanens": "vertikalplan",
    "vertikalplanet": "vertikalplan",
    "vertikalplanets": "vertikalplan",
    "vertikalplans": "vertikalplan",
    "vertikalprojektionen": "vertikalprojektion",
    "vertikalprojektionens": "vertikalprojektion",
    "vertikalprojektioner": "vertikalprojektion",
    "vertikalprojektionerna": "vertikalprojektion",
    "vertikalprojektionernas": "vertikalprojektion",
    "vertikalprojektioners": "vertikalprojektion",
    "vertikalprojektions": "vertikalprojektion",
    "vertikals": "vertikal",
    "vertikalskärar": "vertikalskärare",
    "vertikalskäraren": "vertikalskärare",
    "vertikalskärarens": "vertikalskärare",
    "vertikalskärares": "vertikalskärare",
    "vertikalskärarna": "vertikalskärare",
    "vertikalskärarnas": "vertikalskärare",
    "vertikalströmmar": "vertikalström",
    "vertikalströmmarna": "vertikalström",
    "vertikalströmmarnas": "vertikalström",
    "vertikalströmmars": "vertikalström",
    "vertikalströmmen": "vertikalström",
    "vertikalströmmens": "vertikalström",
    "vertikalströms": "vertikalström",
    "vertikalt": "vertikal",
    "vertikalts": "vertikal",
    "vertikalvinkeln": "vertikalvinkel",
    "vertikalvinkelns": "vertikalvinkel",
    "vertikalvinkels": "vertikalvinkel",
    "vertikalvinklar": "vertikalvinkel",
    "vertikalvinklarna": "vertikalvinkel",
    "vertikalvinklarnas": "vertikalvinkel",
    "vertikalvinklars": "vertikalvinkel",
    "vertolhelikoptern": "vertolhelikopter",
    "vertolhelikopterns": "vertolhelikopter",
    "vertolhelikopters": "vertolhelikopter",
    "vertolhelikoptrar": "vertolhelikopter",
    "vertolhelikoptrarna": "vertolhelikopter",
    "vertolhelikoptrarnas": "vertolhelikopter",
    "vertolhelikoptrars": "vertolhelikopter",
    "verven": "verv",
    "vervens": "verv",
    "vervs": "verv",
    "ves": "ve",
    "vesiren": "vesir",
    "vesirens": "vesir",
    "vesirer": "vesir",
    "vesirerna": "vesir",
    "vesirernas": "vesir",
    "vesirers": "vesir",
    "vesirs": "vesir",
    "vesp": "vespa",
    "vespan": "vespa",
    "vespans": "vespa",
    "vespas": "vespa",
    "vespe": "vespa",
    "vespern": "vesper",
    "vesperns": "vesper",
    "vespers": "vesper",
    "vespor": "vespa",
    "vesporna": "vespa",
    "vespornas": "vespa",
    "vespors": "vespa",
    "vesprar": "vesper",
    "vesprarna": "vesper",
    "vesprarnas": "vesper",
    "vesprars": "vesper",
    "vessl": "vessla",
    "vesslan": "vessla",
    "vesslans": "vessla",
    "vesslas": "vessla",
    "vessle": "vessla",
    "vesslor": "vessla",
    "vesslorna": "vessla",
    "vesslornas": "vessla",
    "vesslors": "vessla",
    "vestalen": "vestal",
    "vestalens": "vestal",
    "vestaler": "vestal",
    "vestalerna": "vestal",
    "vestalernas": "vestal",
    "vestalers": "vestal",
    "vestaliska": "vestalisk",
    "vestaliskare": "vestalisk",
    "vestaliskares": "vestalisk",
    "vestaliskas": "vestalisk",
    "vestaliskast": "vestalisk",
    "vestaliskaste": "vestalisk",
    "vestaliskastes": "vestalisk",
    "vestaliskasts": "vestalisk",
    "vestaliske": "vestalisk",
    "vestaliskes": "vestalisk",
    "vestalisks": "vestalisk",
    "vestaliskt": "vestalisk",
    "vestaliskts": "vestalisk",
    "vestals": "vestal",
    "vestibulen": "vestibul",
    "vestibulens": "vestibul",
    "vestibuler": "vestibul",
    "vestibulerna": "vestibul",
    "vestibulernas": "vestibul",
    "vestibulers": "vestibul",
    "vestibuliten": "vestibulit",
    "vestibulitens": "vestibulit",
    "vestibuliter": "vestibulit",
    "vestibuliterna": "vestibulit",
    "vestibuliternas": "vestibulit",
    "vestibuliters": "vestibulit",
    "vestibulits": "vestibulit",
    "vestibuls": "vestibul",
    "vesälla": "vesäll",
    "vesällare": "vesäll",
    "vesällares": "vesäll",
    "vesällas": "vesäll",
    "vesällast": "vesäll",
    "vesällaste": "vesäll",
    "vesällastes": "vesäll",
    "vesällasts": "vesäll",
    "vesälle": "vesäll",
    "vesälles": "vesäll",
    "vesälls": "vesäll",
    "vesällt": "vesäll",
    "vesällts": "vesäll",
    "vet": "veta",
    "vetande": "veta",
    "vetandes": "vetande",
    "vetandet": "vetande",
    "vetandets": "vetande",
    "vetar": "vetare",
    "vetaren": "vetare",
    "vetarens": "vetare",
    "vetares": "vetare",
    "vetarna": "vetare",
    "vetarnas": "vetare",
    "vetars": "vetare",
    "vetat": "veta",
    "vetbara": "vetbar",
    "vetbarare": "vetbar",
    "vetbarares": "vetbar",
    "vetbaras": "vetbar",
    "vetbarast": "vetbar",
    "vetbaraste": "vetbar",
    "vetbarastes": "vetbar",
    "vetbarasts": "vetbar",
    "vetbare": "vetbar",
    "vetbares": "vetbar",
    "vetbarheten": "vetbarhet",
    "vetbarhetens": "vetbarhet",
    "vetbarhets": "vetbarhet",
    "vetbars": "vetbar",
    "vetbart": "vetbar",
    "vetbarts": "vetbar",
    "vete": "veta",
    "vetebröden": "vetebröd",
    "vetebrödens": "vetebröd",
    "vetebrödet": "vetebröd",
    "vetebrödets": "vetebröd",
    "vetebröds": "vetebröd",
    "vetebrödslängden": "vetebrödslängd",
    "vetebrödslängdens": "vetebrödslängd",
    "vetebrödslängder": "vetebrödslängd",
    "vetebrödslängderna": "vetebrödslängd",
    "vetebrödslängdernas": "vetebrödslängd",
    "vetebrödslängders": "vetebrödslängd",
    "vetebrödslängds": "vetebrödslängd",
    "vetebull": "vetebulle",
    "vetebullan": "vetebulla",
    "vetebullans": "vetebulla",
    "vetebullar": "vetebulle",
    "vetebullarna": "vetebulle",
    "vetebullarnas": "vetebulle",
    "vetebullars": "vetebulle",
    "vetebullas": "vetebulla",
    "vetebulle": "vetebulla",
    "vetebullen": "vetebulle",
    "vetebullens": "vetebulle",
    "vetebulles": "vetebulle",
    "vetebullor": "vetebulla",
    "vetebullorna": "vetebulla",
    "vetebullornas": "vetebulla",
    "vetebullors": "vetebulla",
    "vetebulls": "vetebulle",
    "veteflät": "vetefläta",
    "veteflätan": "vetefläta",
    "veteflätans": "vetefläta",
    "veteflätas": "vetefläta",
    "vetefläte": "vetefläta",
    "veteflätor": "vetefläta",
    "veteflätorna": "vetefläta",
    "veteflätornas": "vetefläta",
    "veteflätors": "vetefläta",
    "vetefläts": "vetefläta",
    "vetegroddar": "vetegrodd",
    "vetegroddarna": "vetegrodd",
    "vetegroddarnas": "vetegrodd",
    "vetegroddars": "vetegrodd",
    "vetegrodden": "vetegrodd",
    "vetegroddens": "vetegrodd",
    "vetegrodds": "vetegrodd",
    "vetekak": "vetekaka",
    "vetekakan": "vetekaka",
    "vetekakans": "vetekaka",
    "vetekakas": "vetekaka",
    "vetekake": "vetekaka",
    "vetekakor": "vetekaka",
    "vetekakorna": "vetekaka",
    "vetekakornas": "vetekaka",
    "vetekakors": "vetekaka",
    "vetekaks": "vetekaka",
    "vetekliet": "vetekli",
    "vetekliets": "vetekli",
    "veteklis": "vetekli",
    "veteklit": "vetekli",
    "veteklits": "vetekli",
    "vetekornen": "vetekorn",
    "vetekornens": "vetekorn",
    "vetekornet": "vetekorn",
    "vetekornets": "vetekorn",
    "vetekorns": "vetekorn",
    "vetekransar": "vetekrans",
    "vetekransarna": "vetekrans",
    "vetekransarnas": "vetekrans",
    "vetekransars": "vetekrans",
    "vetekransen": "vetekrans",
    "vetekransens": "vetekrans",
    "vetelängden": "vetelängd",
    "vetelängdens": "vetelängd",
    "vetelängder": "vetelängd",
    "vetelängderna": "vetelängd",
    "vetelängdernas": "vetelängd",
    "vetelängders": "vetelängd",
    "vetelängds": "vetelängd",
    "vetemjölet": "vetemjöl",
    "vetemjölets": "vetemjöl",
    "vetemjöls": "vetemjöl",
    "vetemjölsklisters": "vetemjölsklister",
    "vetemjölsklistret": "vetemjölsklister",
    "vetemjölsklistrets": "vetemjölsklister",
    "vetenskap": "vetenskapa",
    "vetenskapad": "vetenskapa",
    "vetenskapade": "vetenskapa",
    "vetenskapades": "vetenskapa",
    "vetenskapads": "vetenskapa",
    "vetenskapande": "vetenskapa",
    "vetenskapanden": "vetenskapande",
    "vetenskapandena": "vetenskapande",
    "vetenskapandenas": "vetenskapande",
    "vetenskapandens": "vetenskapande",
    "vetenskapandes": "vetenskapande",
    "vetenskapandet": "vetenskapande",
    "vetenskapandets": "vetenskapande",
    "vetenskapar": "vetenskapare",
    "vetenskaparen": "vetenskapare",
    "vetenskaparens": "vetenskapare",
    "vetenskapares": "vetenskapare",
    "vetenskaparna": "vetenskapare",
    "vetenskaparnas": "vetenskapare",
    "vetenskapas": "vetenskapa",
    "vetenskapat": "vetenskapa",
    "vetenskapats": "vetenskapa",
    "vetenskapen": "vetenskap",
    "vetenskapens": "vetenskap",
    "vetenskaper": "vetenskap",
    "vetenskaperna": "vetenskap",
    "vetenskapernas": "vetenskap",
    "vetenskapers": "vetenskap",
    "vetenskapliga": "vetenskaplig",
    "vetenskapligare": "vetenskaplig",
    "vetenskapligares": "vetenskaplig",
    "vetenskapligas": "vetenskaplig",
    "vetenskapligast": "vetenskaplig",
    "vetenskapligaste": "vetenskaplig",
    "vetenskapligastes": "vetenskaplig",
    "vetenskapligasts": "vetenskaplig",
    "vetenskaplige": "vetenskaplig",
    "vetenskapliges": "vetenskaplig",
    "vetenskapligheten": "vetenskaplighet",
    "vetenskaplighetens": "vetenskaplighet",
    "vetenskaplighets": "vetenskaplighet",
    "vetenskapligs": "vetenskaplig",
    "vetenskapligt": "vetenskaplig",
    "vetenskapligts": "vetenskaplig",
    "vetenskaps": "vetenskap",
    "vetenskapsakademien": "vetenskapsakademi",
    "vetenskapsakademiens": "vetenskapsakademi",
    "vetenskapsakademier": "vetenskapsakademi",
    "vetenskapsakademierna": "vetenskapsakademi",
    "vetenskapsakademiernas": "vetenskapsakademi",
    "vetenskapsakademiers": "vetenskapsakademi",
    "vetenskapsakademin": "vetenskapsakademi",
    "vetenskapsakademins": "vetenskapsakademi",
    "vetenskapsakademis": "vetenskapsakademi",
    "vetenskapsmannen": "vetenskapsman",
    "vetenskapsmannens": "vetenskapsman",
    "vetenskapsmans": "vetenskapsman",
    "vetenskapsmän": "vetenskapsman",
    "vetenskapsmännen": "vetenskapsman",
    "vetenskapsmännens": "vetenskapsman",
    "vetenskapsmäns": "vetenskapsman",
    "vetenskapsteorien": "vetenskapsteori",
    "vetenskapsteoriens": "vetenskapsteori",
    "vetenskapsteorin": "vetenskapsteori",
    "vetenskapsteorins": "vetenskapsteori",
    "vetenskapsteoris": "vetenskapsteori",
    "veteranbilar": "veteranbil",
    "veteranbilarna": "veteranbil",
    "veteranbilarnas": "veteranbil",
    "veteranbilars": "veteranbil",
    "veteranbilen": "veteranbil",
    "veteranbilens": "veteranbil",
    "veteranbils": "veteranbil",
    "veteranen": "veteran",
    "veteranens": "veteran",
    "veteraner": "veteran",
    "veteranerna": "veteran",
    "veteranernas": "veteran",
    "veteraners": "veteran",
    "veterans": "veteran",
    "veterinärbesiktningar": "veterinärbesiktning",
    "veterinärbesiktningarna": "veterinärbesiktning",
    "veterinärbesiktningarnas": "veterinärbesiktning",
    "veterinärbesiktningars": "veterinärbesiktning",
    "veterinärbesiktningen": "veterinärbesiktning",
    "veterinärbesiktningens": "veterinärbesiktning",
    "veterinärbesiktnings": "veterinärbesiktning",
    "veterinären": "veterinär",
    "veterinärens": "veterinär",
    "veterinärer": "veterinär",
    "veterinärerna": "veterinär",
    "veterinärernas": "veterinär",
    "veterinärers": "veterinär",
    "veterinärmedicinen": "veterinärmedicin",
    "veterinärmedicinens": "veterinärmedicin",
    "veterinärmedicins": "veterinärmedicin",
    "veterinärs": "veterinär",
    "vetes": "vete",
    "veteskivan": "veteskiva",
    "veteskivans": "veteskiva",
    "veteskivas": "veteskiva",
    "veteskive": "veteskiva",
    "veteskivor": "veteskiva",
    "veteskivorna": "veteskiva",
    "veteskivornas": "veteskiva",
    "veteskivors": "veteskiva",
    "vetesorten": "vetesort",
    "vetesortens": "vetesort",
    "vetesorter": "vetesort",
    "vetesorterna": "vetesort",
    "vetesorternas": "vetesort",
    "vetesorters": "vetesort",
    "vetesorts": "vetesort",
    "vetet": "vete",
    "vetets": "vete",
    "vetgiriga": "vetgirig",
    "vetgirigare": "vetgirig",
    "vetgirigares": "vetgirig",
    "vetgirigas": "vetgirig",
    "vetgirigast": "vetgirig",
    "vetgirigaste": "vetgirig",
    "vetgirigastes": "vetgirig",
    "vetgirigasts": "vetgirig",
    "vetgirige": "vetgirig",
    "vetgiriges": "vetgirig",
    "vetgirigheten": "vetgirighet",
    "vetgirighetens": "vetgirighet",
    "vetgirighets": "vetgirighet",
    "vetgirigs": "vetgirig",
    "vetgirigt": "vetgirig",
    "vetgirigts": "vetgirig",
    "veton": "veto",
    "vetona": "veto",
    "vetonas": "veto",
    "vetons": "veto",
    "vetorätten": "vetorätt",
    "vetorättens": "vetorätt",
    "vetorätts": "vetorätt",
    "vetos": "veto",
    "vetot": "veto",
    "vetots": "veto",
    "vetskapen": "vetskap",
    "vetskapens": "vetskap",
    "vetskaps": "vetskap",
    "vett": "vette",
    "vettande": "vetta",
    "vettanden": "vettande",
    "vettandena": "vettande",
    "vettandenas": "vettande",
    "vettandens": "vettande",
    "vettandes": "vettande",
    "vettandet": "vettande",
    "vettandets": "vettande",
    "vettar": "vette",
    "vettarna": "vette",
    "vettarnas": "vette",
    "vettars": "vette",
    "vettas": "vetta",
    "vettat": "vetta",
    "vettats": "vetta",
    "vette": "vetta",
    "vetten": "vette",
    "vettens": "vette",
    "vetter": "vetta",
    "vettes": "vette",
    "vettet": "vett",
    "vettets": "vett",
    "vettiga": "vettig",
    "vettigare": "vettig",
    "vettigares": "vettig",
    "vettigas": "vettig",
    "vettigast": "vettig",
    "vettigaste": "vettig",
    "vettigastes": "vettig",
    "vettigasts": "vettig",
    "vettige": "vettig",
    "vettiges": "vettig",
    "vettigheten": "vettighet",
    "vettighetens": "vettighet",
    "vettigheter": "vettighet",
    "vettigheterna": "vettighet",
    "vettigheternas": "vettighet",
    "vettigheters": "vettighet",
    "vettighets": "vettighet",
    "vettigs": "vettig",
    "vettigt": "vettig",
    "vettigts": "vettig",
    "vettlösa": "vettlös",
    "vettlösare": "vettlös",
    "vettlösares": "vettlös",
    "vettlösas": "vettlös",
    "vettlösast": "vettlös",
    "vettlösaste": "vettlös",
    "vettlösastes": "vettlös",
    "vettlösasts": "vettlös",
    "vettlöse": "vettlös",
    "vettlöses": "vettlös",
    "vettlösheten": "vettlöshet",
    "vettlöshetens": "vettlöshet",
    "vettlösheter": "vettlöshet",
    "vettlösheterna": "vettlöshet",
    "vettlösheternas": "vettlöshet",
    "vettlösheters": "vettlöshet",
    "vettlöshets": "vettlöshet",
    "vettlöst": "vettlös",
    "vettlösts": "vettlös",
    "vetts": "vette",
    "vettskrämda": "vettskrämd",
    "vettskrämdare": "vettskrämd",
    "vettskrämdares": "vettskrämd",
    "vettskrämdas": "vettskrämd",
    "vettskrämdast": "vettskrämd",
    "vettskrämdaste": "vettskrämd",
    "vettskrämdastes": "vettskrämd",
    "vettskrämdasts": "vettskrämd",
    "vettskrämde": "vettskrämd",
    "vettskrämdes": "vettskrämd",
    "vettskrämdheten": "vettskrämdhet",
    "vettskrämdhetens": "vettskrämdhet",
    "vettskrämdhets": "vettskrämdhet",
    "vettskrämds": "vettskrämd",
    "vettskrämt": "vettskrämd",
    "vettskrämts": "vettskrämd",
    "vettvilliga": "vettvillig",
    "vettvilligare": "vettvillig",
    "vettvilligares": "vettvillig",
    "vettvilligas": "vettvillig",
    "vettvilligast": "vettvillig",
    "vettvilligaste": "vettvillig",
    "vettvilligastes": "vettvillig",
    "vettvilligasts": "vettvillig",
    "vettvillige": "vettvillig",
    "vettvilliges": "vettvillig",
    "vettvilligheten": "vettvillighet",
    "vettvillighetens": "vettvillighet",
    "vettvilligheter": "vettvillighet",
    "vettvilligheterna": "vettvillighet",
    "vettvilligheternas": "vettvillighet",
    "vettvilligheters": "vettvillighet",
    "vettvillighets": "vettvillighet",
    "vettvilligs": "vettvillig",
    "vettvilligt": "vettvillig",
    "vettvilligts": "vettvillig",
    "vettvillingar": "vettvilling",
    "vettvillingarna": "vettvilling",
    "vettvillingarnas": "vettvilling",
    "vettvillingars": "vettvilling",
    "vettvillingen": "vettvilling",
    "vettvillingens": "vettvilling",
    "vettvillings": "vettvilling",
    "vev": "veva",
    "vevad": "veva",
    "vevade": "veva",
    "vevades": "veva",
    "vevads": "veva",
    "vevande": "veva",
    "vevanden": "vevande",
    "vevandena": "vevande",
    "vevandenas": "vevande",
    "vevandens": "vevande",
    "vevandes": "vevande",
    "vevandet": "vevande",
    "vevandets": "vevande",
    "vevar": "veva",
    "vevarmar": "vevarm",
    "vevarmarna": "vevarm",
    "vevarmarnas": "vevarm",
    "vevarmars": "vevarm",
    "vevarmen": "vevarm",
    "vevarmens": "vevarm",
    "vevarms": "vevarm",
    "vevarna": "vev",
    "vevarnas": "vev",
    "vevars": "vev",
    "vevas": "veva",
    "vevat": "veva",
    "vevats": "veva",
    "vevaxeln": "vevaxel",
    "vevaxelns": "vevaxel",
    "vevaxels": "vevaxel",
    "vevaxlar": "vevaxel",
    "vevaxlarna": "vevaxel",
    "vevaxlarnas": "vevaxel",
    "vevaxlars": "vevaxel",
    "veven": "vev",
    "vevens": "vev",
    "vevgrammofonen": "vevgrammofon",
    "vevgrammofonens": "vevgrammofon",
    "vevgrammofoner": "vevgrammofon",
    "vevgrammofonerna": "vevgrammofon",
    "vevgrammofonernas": "vevgrammofon",
    "vevgrammofoners": "vevgrammofon",
    "vevgrammofons": "vevgrammofon",
    "vevhusen": "vevhus",
    "vevhusens": "vevhus",
    "vevhuset": "vevhus",
    "vevhusets": "vevhus",
    "vevlad": "vevla",
    "vevlade": "vevla",
    "vevlades": "vevla",
    "vevlads": "vevla",
    "vevlande": "vevla",
    "vevlanden": "vevlande",
    "vevlandena": "vevlande",
    "vevlandenas": "vevlande",
    "vevlandens": "vevlande",
    "vevlandes": "vevlande",
    "vevlandet": "vevlande",
    "vevlandets": "vevlande",
    "vevlar": "vevla",
    "vevlas": "vevla",
    "vevlat": "vevla",
    "vevlats": "vevla",
    "vevlingar": "vevling",
    "vevlingarna": "vevling",
    "vevlingarnas": "vevling",
    "vevlingars": "vevling",
    "vevlingen": "vevling",
    "vevlingens": "vevling",
    "vevlings": "vevling",
    "vevs": "vev",
    "vevstak": "vevstake",
    "vevstakar": "vevstake",
    "vevstakarna": "vevstake",
    "vevstakarnas": "vevstake",
    "vevstakars": "vevstake",
    "vevstaken": "vevstake",
    "vevstakens": "vevstake",
    "vevstakes": "vevstake",
    "vevstaks": "vevstake",
    "vevstänger": "vevstång",
    "vevstängerna": "vevstång",
    "vevstängernas": "vevstång",
    "vevstängers": "vevstång",
    "vevstången": "vevstång",
    "vevstångens": "vevstång",
    "vevstångs": "vevstång",
    "vevtappar": "vevtapp",
    "vevtapparna": "vevtapp",
    "vevtapparnas": "vevtapp",
    "vevtappars": "vevtapp",
    "vevtappen": "vevtapp",
    "vevtappens": "vevtapp",
    "vevtapps": "vevtapp",
    "viadukten": "viadukt",
    "viaduktens": "viadukt",
    "viadukter": "viadukt",
    "viadukterna": "viadukt",
    "viadukternas": "viadukt",
    "viadukters": "viadukt",
    "viadukts": "viadukt",
    "vialen": "vial",
    "vialens": "vial",
    "vialer": "vial",
    "vialerna": "vial",
    "vialernas": "vial",
    "vialers": "vial",
    "vials": "vial",
    "vibrafonen": "vibrafon",
    "vibrafonens": "vibrafon",
    "vibrafoner": "vibrafon",
    "vibrafonerna": "vibrafon",
    "vibrafonernas": "vibrafon",
    "vibrafoners": "vibrafon",
    "vibrafons": "vibrafon",
    "vibranten": "vibrant",
    "vibrantens": "vibrant",
    "vibranter": "vibrant",
    "vibranterna": "vibrant",
    "vibranternas": "vibrant",
    "vibranters": "vibrant",
    "vibrants": "vibrant",
    "vibrationen": "vibration",
    "vibrationens": "vibration",
    "vibrationer": "vibration",
    "vibrationerna": "vibration",
    "vibrationernas": "vibration",
    "vibrationers": "vibration",
    "vibrations": "vibration",
    "vibraton": "vibrato",
    "vibratona": "vibrato",
    "vibratonas": "vibrato",
    "vibratons": "vibrato",
    "vibratorer": "vibrator",
    "vibratorerna": "vibrator",
    "vibratorernas": "vibrator",
    "vibratorers": "vibrator",
    "vibratorn": "vibrator",
    "vibratorns": "vibrator",
    "vibrators": "vibrator",
    "vibratos": "vibrato",
    "vibratot": "vibrato",
    "vibratots": "vibrato",
    "vibrerade": "vibrera",
    "vibrerades": "vibrera",
    "vibrerande": "vibrera",
    "vibreranden": "vibrerande",
    "vibrerandena": "vibrerande",
    "vibrerandenas": "vibrerande",
    "vibrerandens": "vibrerande",
    "vibrerandes": "vibrerande",
    "vibrerandet": "vibrerande",
    "vibrerandets": "vibrerande",
    "vibrerar": "vibrera",
    "vibreras": "vibrera",
    "vibrerat": "vibrera",
    "vibrerats": "vibrera",
    "vibreringar": "vibrering",
    "vibreringarna": "vibrering",
    "vibreringarnas": "vibrering",
    "vibreringars": "vibrering",
    "vibreringen": "vibrering",
    "vibreringens": "vibrering",
    "vibrerings": "vibrering",
    "vibrionen": "vibrion",
    "vibrionens": "vibrion",
    "vibrioner": "vibrion",
    "vibrionerna": "vibrion",
    "vibrionernas": "vibrion",
    "vibrioners": "vibrion",
    "vibrions": "vibrion",
    "viby-i-en": "viby-i",
    "viby-i-ens": "viby-i",
    "viby-i-et": "viby-i",
    "viby-i-ets": "viby-i",
    "viby-i-n": "viby-i",
    "viby-i-na": "viby-i",
    "viby-i-nas": "viby-i",
    "viby-i-ns": "viby-i",
    "viby-i-s": "viby-i",
    "viby-i-t": "viby-i",
    "viby-i-ts": "viby-i",
    "viby-i:en": "viby-i",
    "viby-i:ens": "viby-i",
    "viby-i:et": "viby-i",
    "viby-i:ets": "viby-i",
    "viby-i:n": "viby-i",
    "viby-i:na": "viby-i",
    "viby-i:nas": "viby-i",
    "viby-i:ns": "viby-i",
    "viby-i:s": "viby-i",
    "viby-i:t": "viby-i",
    "viby-i:ts": "viby-i",
    "viby-ien": "viby-i",
    "viby-iens": "viby-i",
    "viby-iet": "viby-i",
    "viby-iets": "viby-i",
    "viby-in": "viby-i",
    "viby-ina": "viby-i",
    "viby-inas": "viby-i",
    "viby-ins": "viby-i",
    "viby-is": "viby-i",
    "viby-it": "viby-i",
    "viby-its": "viby-i",
    "viceamiralen": "viceamiral",
    "viceamiralens": "viceamiral",
    "viceamiraler": "viceamiral",
    "viceamiralerna": "viceamiral",
    "viceamiralernas": "viceamiral",
    "viceamiralers": "viceamiral",
    "viceamirals": "viceamiral",
    "vicekonungar": "vicekonung",
    "vicekonungarna": "vicekonung",
    "vicekonungarnas": "vicekonung",
    "vicekonungars": "vicekonung",
    "vicekonungen": "vicekonung",
    "vicekonungens": "vicekonung",
    "vicekonungs": "vicekonung",
    "vicekorpralen": "vicekorpral",
    "vicekorpralens": "vicekorpral",
    "vicekorpraler": "vicekorpral",
    "vicekorpralerna": "vicekorpral",
    "vicekorpralernas": "vicekorpral",
    "vicekorpralers": "vicekorpral",
    "vicekorprals": "vicekorpral",
    "vicekungar": "vicekung",
    "vicekungarna": "vicekung",
    "vicekungarnas": "vicekung",
    "vicekungars": "vicekung",
    "vicekungen": "vicekung",
    "vicekungens": "vicekung",
    "vicekungs": "vicekung",
    "vicepresidenten": "vicepresident",
    "vicepresidentens": "vicepresident",
    "vicepresidenter": "vicepresident",
    "vicepresidenterna": "vicepresident",
    "vicepresidenternas": "vicepresident",
    "vicepresidenters": "vicepresident",
    "vicepresidentkandidaten": "vicepresidentkandidat",
    "vicepresidentkandidatens": "vicepresidentkandidat",
    "vicepresidentkandidater": "vicepresidentkandidat",
    "vicepresidentkandidaterna": "vicepresidentkandidat",
    "vicepresidentkandidaternas": "vicepresidentkandidat",
    "vicepresidentkandidaters": "vicepresidentkandidat",
    "vicepresidentkandidats": "vicepresidentkandidat",
    "vicepresidents": "vicepresident",
    "vicevärdar": "vicevärd",
    "vicevärdarna": "vicevärd",
    "vicevärdarnas": "vicevärd",
    "vicevärdars": "vicevärd",
    "vicevärden": "vicevärd",
    "vicevärdens": "vicevärd",
    "vicevärds": "vicevärd",
    "vichyvattens": "vichyvatten",
    "vichyvattnen": "vichyvatten",
    "vichyvattnens": "vichyvatten",
    "vichyvattnet": "vichyvatten",
    "vichyvattnets": "vichyvatten",
    "vick": "vicka",
    "vickad": "vicka",
    "vickade": "vicka",
    "vickades": "vicka",
    "vickads": "vicka",
    "vickande": "vicka",
    "vickanden": "vickande",
    "vickandena": "vickande",
    "vickandenas": "vickande",
    "vickandens": "vickande",
    "vickandes": "vickande",
    "vickandet": "vickande",
    "vickandets": "vickande",
    "vickar": "vicka",
    "vickas": "vicka",
    "vickat": "vicka",
    "vickats": "vicka",
    "vickeln": "vickel",
    "vickelns": "vickel",
    "vickels": "vickel",
    "vicken": "vick",
    "vickens": "vick",
    "vickern": "vicker",
    "vickerns": "vicker",
    "vickers": "vicker",
    "vicket": "vick",
    "vickets": "vick",
    "vickiga": "vickig",
    "vickigare": "vickig",
    "vickigares": "vickig",
    "vickigas": "vickig",
    "vickigast": "vickig",
    "vickigaste": "vickig",
    "vickigastes": "vickig",
    "vickigasts": "vickig",
    "vickige": "vickig",
    "vickiges": "vickig",
    "vickigheten": "vickighet",
    "vickighetens": "vickighet",
    "vickighets": "vickighet",
    "vickigs": "vickig",
    "vickigt": "vickig",
    "vickigts": "vickig",
    "vicklar": "vickel",
    "vicklarna": "vickel",
    "vicklarnas": "vickel",
    "vicklars": "vickel",
    "vickningar": "vickning",
    "vickningarna": "vickning",
    "vickningarnas": "vickning",
    "vickningars": "vickning",
    "vickningen": "vickning",
    "vickningens": "vickning",
    "vicknings": "vickning",
    "vicks": "vick",
    "victorianska": "victoriansk",
    "victorianskare": "victoriansk",
    "victorianskares": "victoriansk",
    "victorianskas": "victoriansk",
    "victorianskast": "victoriansk",
    "victorianskaste": "victoriansk",
    "victorianskastes": "victoriansk",
    "victorianskasts": "victoriansk",
    "victorianske": "victoriansk",
    "victorianskes": "victoriansk",
    "victoriansks": "victoriansk",
    "victorianskt": "victoriansk",
    "victorianskts": "victoriansk",
    "vida": "vid",
    "vidare": "vid",
    "vidarebefordrad": "vidarebefordra",
    "vidarebefordrade": "vidarebefordra",
    "vidarebefordrades": "vidarebefordra",
    "vidarebefordrads": "vidarebefordra",
    "vidarebefordrande": "vidarebefordra",
    "vidarebefordranden": "vidarebefordrande",
    "vidarebefordrandena": "vidarebefordrande",
    "vidarebefordrandenas": "vidarebefordrande",
    "vidarebefordrandens": "vidarebefordrande",
    "vidarebefordrandes": "vidarebefordrande",
    "vidarebefordrandet": "vidarebefordrande",
    "vidarebefordrandets": "vidarebefordrande",
    "vidarebefordrar": "vidarebefordra",
    "vidarebefordras": "vidarebefordra",
    "vidarebefordrat": "vidarebefordra",
    "vidarebefordrats": "vidarebefordra",
    "vidares": "vid",
    "vidareutbildad": "vidareutbilda",
    "vidareutbildade": "vidareutbilda",
    "vidareutbildades": "vidareutbilda",
    "vidareutbildads": "vidareutbilda",
    "vidareutbildande": "vidareutbilda",
    "vidareutbildanden": "vidareutbildande",
    "vidareutbildandena": "vidareutbildande",
    "vidareutbildandenas": "vidareutbildande",
    "vidareutbildandens": "vidareutbildande",
    "vidareutbildandes": "vidareutbildande",
    "vidareutbildandet": "vidareutbildande",
    "vidareutbildandets": "vidareutbildande",
    "vidareutbildar": "vidareutbilda",
    "vidareutbildas": "vidareutbilda",
    "vidareutbildat": "vidareutbilda",
    "vidareutbildats": "vidareutbilda",
    "vidareutbildningar": "vidareutbildning",
    "vidareutbildningarna": "vidareutbildning",
    "vidareutbildningarnas": "vidareutbildning",
    "vidareutbildningars": "vidareutbildning",
    "vidareutbildningen": "vidareutbildning",
    "vidareutbildningens": "vidareutbildning",
    "vidareutbildnings": "vidareutbildning",
    "vidareutvecklad": "vidareutveckla",
    "vidareutvecklade": "vidareutveckla",
    "vidareutvecklades": "vidareutveckla",
    "vidareutvecklads": "vidareutveckla",
    "vidareutvecklande": "vidareutveckla",
    "vidareutvecklanden": "vidareutvecklande",
    "vidareutvecklandena": "vidareutvecklande",
    "vidareutvecklandenas": "vidareutvecklande",
    "vidareutvecklandens": "vidareutvecklande",
    "vidareutvecklandes": "vidareutvecklande",
    "vidareutvecklandet": "vidareutvecklande",
    "vidareutvecklandets": "vidareutvecklande",
    "vidareutvecklar": "vidareutveckla",
    "vidareutvecklas": "vidareutveckla",
    "vidareutvecklat": "vidareutveckla",
    "vidareutvecklats": "vidareutveckla",
    "vidareutvecklingar": "vidareutveckling",
    "vidareutvecklingarna": "vidareutveckling",
    "vidareutvecklingarnas": "vidareutveckling",
    "vidareutvecklingars": "vidareutveckling",
    "vidareutvecklingen": "vidareutveckling",
    "vidareutvecklingens": "vidareutveckling",
    "vidareutvecklings": "vidareutveckling",
    "vidas": "vid",
    "vidast": "vid",
    "vidaste": "vid",
    "vidastes": "vid",
    "vidasts": "vid",
    "vidbränd": "vidbränna",
    "vidbrända": "vidbränna",
    "vidbrändare": "vidbränd",
    "vidbrändares": "vidbränd",
    "vidbrändas": "vidbränna",
    "vidbrändast": "vidbränd",
    "vidbrändaste": "vidbränd",
    "vidbrändastes": "vidbränd",
    "vidbrändasts": "vidbränd",
    "vidbrände": "vidbränna",
    "vidbrändes": "vidbränna",
    "vidbrändheten": "vidbrändhet",
    "vidbrändhetens": "vidbrändhet",
    "vidbrändhets": "vidbrändhet",
    "vidbränds": "vidbränna",
    "vidbränn": "vidbränna",
    "vidbrännande": "vidbränna",
    "vidbrännanden": "vidbrännande",
    "vidbrännandena": "vidbrännande",
    "vidbrännandenas": "vidbrännande",
    "vidbrännandens": "vidbrännande",
    "vidbrännandes": "vidbrännande",
    "vidbrännandet": "vidbrännande",
    "vidbrännandets": "vidbrännande",
    "vidbrännas": "vidbränna",
    "vidbränner": "vidbränna",
    "vidbrännes": "vidbränna",
    "vidbränns": "vidbränna",
    "vidbränt": "vidbränna",
    "vidbränts": "vidbränna",
    "vidbrättade": "vidbrättad",
    "vidbrättades": "vidbrättad",
    "vidbrättads": "vidbrättad",
    "vidbrättat": "vidbrättad",
    "vidbrättats": "vidbrättad",
    "vidden": "vidd",
    "viddens": "vidd",
    "vidder": "vidd",
    "vidderna": "vidd",
    "viddernas": "vidd",
    "vidders": "vidd",
    "vidds": "vidd",
    "vide": "vid",
    "viden": "vide",
    "videna": "vide",
    "videnas": "vide",
    "videns": "vide",
    "videoaffären": "videoaffär",
    "videoaffärens": "videoaffär",
    "videoaffärer": "videoaffär",
    "videoaffärerna": "videoaffär",
    "videoaffärernas": "videoaffär",
    "videoaffärers": "videoaffär",
    "videoaffärs": "videoaffär",
    "videobanden": "videoband",
    "videobandens": "videoband",
    "videobandet": "videoband",
    "videobandets": "videoband",
    "videobands": "videoband",
    "videobandspelar": "videobandspelare",
    "videobandspelaren": "videobandspelare",
    "videobandspelarens": "videobandspelare",
    "videobandspelares": "videobandspelare",
    "videobandspelarna": "videobandspelare",
    "videobandspelarnas": "videobandspelare",
    "videobutiken": "videobutik",
    "videobutikens": "videobutik",
    "videobutiker": "videobutik",
    "videobutikerna": "videobutik",
    "videobutikernas": "videobutik",
    "videobutikers": "videobutik",
    "videobutiks": "videobutik",
    "videofilmen": "videofilm",
    "videofilmens": "videofilm",
    "videofilmer": "videofilm",
    "videofilmerna": "videofilm",
    "videofilmernas": "videofilm",
    "videofilmers": "videofilm",
    "videofilms": "videofilm",
    "videoklippen": "videoklipp",
    "videoklippens": "videoklipp",
    "videoklippet": "videoklipp",
    "videoklippets": "videoklipp",
    "videoklipps": "videoklipp",
    "videon": "video",
    "videons": "video",
    "videor": "video",
    "videorna": "video",
    "videornas": "video",
    "videors": "video",
    "videos": "video",
    "videosignalen": "videosignal",
    "videosignalens": "videosignal",
    "videosignaler": "videosignal",
    "videosignalerna": "videosignal",
    "videosignalernas": "videosignal",
    "videosignalers": "videosignal",
    "videosignals": "videosignal",
    "viderboenden": "viderboende",
    "viderboendena": "viderboende",
    "viderboendenas": "viderboende",
    "viderboendens": "viderboende",
    "viderboendes": "viderboende",
    "videregionen": "videregion",
    "videregionens": "videregion",
    "videregioner": "videregion",
    "videregionerna": "videregion",
    "videregionernas": "videregion",
    "videregioners": "videregion",
    "videregions": "videregion",
    "vidertrycken": "vidertryck",
    "vidertryckens": "vidertryck",
    "vidertrycket": "vidertryck",
    "vidertryckets": "vidertryck",
    "vidertrycks": "vidertryck",
    "vides": "vide",
    "videsparvar": "videsparv",
    "videsparvarna": "videsparv",
    "videsparvarnas": "videsparv",
    "videsparvars": "videsparv",
    "videsparven": "videsparv",
    "videsparvens": "videsparv",
    "videsparvs": "videsparv",
    "videt": "vide",
    "videts": "vide",
    "videörten": "videört",
    "videörtens": "videört",
    "videörts": "videört",
    "vidfilmen": "vidfilm",
    "vidfilmens": "vidfilm",
    "vidfilmer": "vidfilm",
    "vidfilmerna": "vidfilm",
    "vidfilmernas": "vidfilm",
    "vidfilmers": "vidfilm",
    "vidfilms": "vidfilm",
    "vidg": "vidga",
    "vidgad": "vidga",
    "vidgade": "vidga",
    "vidgades": "vidga",
    "vidgads": "vidga",
    "vidgande": "vidga",
    "vidganden": "vidgande",
    "vidgandena": "vidgande",
    "vidgandenas": "vidgande",
    "vidgandens": "vidgande",
    "vidgandes": "vidgande",
    "vidgandet": "vidgande",
    "vidgandets": "vidgande",
    "vidgar": "vidga",
    "vidgas": "vidga",
    "vidgat": "vidga",
    "vidgats": "vidga",
    "vidgick": "vidgå",
    "vidgicks": "vidgå",
    "vidginge": "vidgå",
    "vidginges": "vidgå",
    "vidgående": "vidgå",
    "vidgåenden": "vidgående",
    "vidgåendena": "vidgående",
    "vidgåendenas": "vidgående",
    "vidgåendens": "vidgående",
    "vidgåendes": "vidgående",
    "vidgåendet": "vidgående",
    "vidgåendets": "vidgående",
    "vidgår": "vidgå",
    "vidgås": "vidgå",
    "vidgått": "vidgå",
    "vidgåtts": "vidgå",
    "vidheten": "vidhet",
    "vidhetens": "vidhet",
    "vidhets": "vidhet",
    "vidhäft": "vidhäfta",
    "vidhäftad": "vidhäfta",
    "vidhäftade": "vidhäfta",
    "vidhäftades": "vidhäfta",
    "vidhäftads": "vidhäfta",
    "vidhäftande": "vidhäfta",
    "vidhäftanden": "vidhäftande",
    "vidhäftandena": "vidhäftande",
    "vidhäftandenas": "vidhäftande",
    "vidhäftandens": "vidhäftande",
    "vidhäftandes": "vidhäftande",
    "vidhäftandet": "vidhäftande",
    "vidhäftandets": "vidhäftande",
    "vidhäftar": "vidhäfta",
    "vidhäftas": "vidhäfta",
    "vidhäftat": "vidhäfta",
    "vidhäftats": "vidhäfta",
    "vidhäftningar": "vidhäftning",
    "vidhäftningarna": "vidhäftning",
    "vidhäftningarnas": "vidhäftning",
    "vidhäftningars": "vidhäftning",
    "vidhäftningen": "vidhäftning",
    "vidhäftningens": "vidhäftning",
    "vidhäftnings": "vidhäftning",
    "vidhäng": "vidhänga",
    "vidhängande": "vidhänga",
    "vidhänganden": "vidhängande",
    "vidhängandena": "vidhängande",
    "vidhängandenas": "vidhängande",
    "vidhängandens": "vidhängande",
    "vidhängandes": "vidhängande",
    "vidhängandet": "vidhängande",
    "vidhängandets": "vidhängande",
    "vidhängas": "vidhänga",
    "vidhängd": "vidhänga",
    "vidhängda": "vidhänga",
    "vidhängdas": "vidhänga",
    "vidhängde": "vidhänga",
    "vidhängdes": "vidhänga",
    "vidhängds": "vidhänga",
    "vidhänger": "vidhänga",
    "vidhänges": "vidhänga",
    "vidhängs": "vidhänga",
    "vidhängt": "vidhänga",
    "vidhängts": "vidhänga",
    "vidhåll": "vidhålla",
    "vidhållande": "vidhålla",
    "vidhållanden": "vidhållande",
    "vidhållandena": "vidhållande",
    "vidhållandenas": "vidhållande",
    "vidhållandens": "vidhållande",
    "vidhållandes": "vidhållande",
    "vidhållandet": "vidhållande",
    "vidhållandets": "vidhållande",
    "vidhållas": "vidhålla",
    "vidhålle": "vidhålla",
    "vidhållen": "vidhålla",
    "vidhållens": "vidhålla",
    "vidhåller": "vidhålla",
    "vidhålles": "vidhålla",
    "vidhållet": "vidhålla",
    "vidhållets": "vidhålla",
    "vidhållit": "vidhålla",
    "vidhållits": "vidhålla",
    "vidhållna": "vidhålla",
    "vidhållnas": "vidhålla",
    "vidhållne": "vidhålla",
    "vidhållnes": "vidhålla",
    "vidhålls": "vidhålla",
    "vidhöll": "vidhålla",
    "vidhölle": "vidhålla",
    "vidhölles": "vidhålla",
    "vidhölls": "vidhålla",
    "vidimationen": "vidimation",
    "vidimationens": "vidimation",
    "vidimationer": "vidimation",
    "vidimationerna": "vidimation",
    "vidimationernas": "vidimation",
    "vidimationers": "vidimation",
    "vidimations": "vidimation",
    "vidimerad": "vidimera",
    "vidimerade": "vidimera",
    "vidimerades": "vidimera",
    "vidimerads": "vidimera",
    "vidimerande": "vidimera",
    "vidimeranden": "vidimerande",
    "vidimerandena": "vidimerande",
    "vidimerandenas": "vidimerande",
    "vidimerandens": "vidimerande",
    "vidimerandes": "vidimerande",
    "vidimerandet": "vidimerande",
    "vidimerandets": "vidimerande",
    "vidimerar": "vidimera",
    "vidimeras": "vidimera",
    "vidimerat": "vidimera",
    "vidimerats": "vidimera",
    "vidimerbara": "vidimerbar",
    "vidimerbarare": "vidimerbar",
    "vidimerbarares": "vidimerbar",
    "vidimerbaras": "vidimerbar",
    "vidimerbarast": "vidimerbar",
    "vidimerbaraste": "vidimerbar",
    "vidimerbarastes": "vidimerbar",
    "vidimerbarasts": "vidimerbar",
    "vidimerbare": "vidimerbar",
    "vidimerbares": "vidimerbar",
    "vidimerbarheten": "vidimerbarhet",
    "vidimerbarhetens": "vidimerbarhet",
    "vidimerbarhets": "vidimerbarhet",
    "vidimerbars": "vidimerbar",
    "vidimerbart": "vidimerbar",
    "vidimerbarts": "vidimerbar",
    "vidimeringar": "vidimering",
    "vidimeringarna": "vidimering",
    "vidimeringarnas": "vidimering",
    "vidimeringars": "vidimering",
    "vidimeringen": "vidimering",
    "vidimeringens": "vidimering",
    "vidimerings": "vidimering",
    "vidjan": "vidja",
    "vidjans": "vidja",
    "vidjas": "vidja",
    "vidje": "vidja",
    "vidjor": "vidja",
    "vidjorna": "vidja",
    "vidjornas": "vidja",
    "vidjors": "vidja",
    "vidkom": "vidkomma",
    "vidkommande": "vidkomma",
    "vidkommanden": "vidkommande",
    "vidkommandena": "vidkommande",
    "vidkommandenas": "vidkommande",
    "vidkommandens": "vidkommande",
    "vidkommandes": "vidkommande",
    "vidkommandet": "vidkommande",
    "vidkommandets": "vidkommande",
    "vidkommas": "vidkomma",
    "vidkomme": "vidkomma",
    "vidkommer": "vidkomma",
    "vidkommes": "vidkomma",
    "vidkommit": "vidkomma",
    "vidkommits": "vidkomma",
    "vidkoms": "vidkomma",
    "vidkänndes": "vidkännas",
    "vidkänns": "vidkännas",
    "vidkännts": "vidkännas",
    "vidlyftiga": "vidlyftig",
    "vidlyftigare": "vidlyftig",
    "vidlyftigares": "vidlyftig",
    "vidlyftigas": "vidlyftig",
    "vidlyftigast": "vidlyftig",
    "vidlyftigaste": "vidlyftig",
    "vidlyftigastes": "vidlyftig",
    "vidlyftigasts": "vidlyftig",
    "vidlyftige": "vidlyftig",
    "vidlyftiges": "vidlyftig",
    "vidlyftigheten": "vidlyftighet",
    "vidlyftighetens": "vidlyftighet",
    "vidlyftigheter": "vidlyftighet",
    "vidlyftigheterna": "vidlyftighet",
    "vidlyftigheternas": "vidlyftighet",
    "vidlyftigheters": "vidlyftighet",
    "vidlyftighets": "vidlyftighet",
    "vidlyftigs": "vidlyftig",
    "vidlyftigt": "vidlyftig",
    "vidlyftigts": "vidlyftig",
    "vidlåd": "vidlåda",
    "vidlådande": "vidlåda",
    "vidlådanden": "vidlådande",
    "vidlådandena": "vidlådande",
    "vidlådandenas": "vidlådande",
    "vidlådandens": "vidlådande",
    "vidlådandes": "vidlådande",
    "vidlådandet": "vidlådande",
    "vidlådandets": "vidlådande",
    "vidlådas": "vidlåda",
    "vidlådd": "vidlåda",
    "vidlådda": "vidlåda",
    "vidlåddas": "vidlåda",
    "vidlådde": "vidlåda",
    "vidlåddes": "vidlåda",
    "vidlådds": "vidlåda",
    "vidlåder": "vidlåda",
    "vidlådes": "vidlåda",
    "vidlåds": "vidlåda",
    "vidlått": "vidlåda",
    "vidlåtts": "vidlåda",
    "vidmakthåll": "vidmakthålla",
    "vidmakthållande": "vidmakthålla",
    "vidmakthållanden": "vidmakthållande",
    "vidmakthållandena": "vidmakthållande",
    "vidmakthållandenas": "vidmakthållande",
    "vidmakthållandens": "vidmakthållande",
    "vidmakthållandes": "vidmakthållande",
    "vidmakthållandet": "vidmakthållande",
    "vidmakthållandets": "vidmakthållande",
    "vidmakthållas": "vidmakthålla",
    "vidmakthålle": "vidmakthålla",
    "vidmakthållen": "vidmakthålla",
    "vidmakthållens": "vidmakthålla",
    "vidmakthåller": "vidmakthålla",
    "vidmakthålles": "vidmakthålla",
    "vidmakthållet": "vidmakthålla",
    "vidmakthållets": "vidmakthålla",
    "vidmakthållit": "vidmakthålla",
    "vidmakthållits": "vidmakthålla",
    "vidmakthållna": "vidmakthålla",
    "vidmakthållnas": "vidmakthålla",
    "vidmakthållne": "vidmakthålla",
    "vidmakthållnes": "vidmakthålla",
    "vidmakthålls": "vidmakthålla",
    "vidmakthöll": "vidmakthålla",
    "vidmakthölle": "vidmakthålla",
    "vidmakthölles": "vidmakthålla",
    "vidmakthölls": "vidmakthålla",
    "vidriga": "vidrig",
    "vidrigare": "vidrig",
    "vidrigares": "vidrig",
    "vidrigas": "vidrig",
    "vidrigast": "vidrig",
    "vidrigaste": "vidrig",
    "vidrigastes": "vidrig",
    "vidrigasts": "vidrig",
    "vidrige": "vidrig",
    "vidriges": "vidrig",
    "vidrigheten": "vidrighet",
    "vidrighetens": "vidrighet",
    "vidrigheter": "vidrighet",
    "vidrigheterna": "vidrighet",
    "vidrigheternas": "vidrighet",
    "vidrigheters": "vidrighet",
    "vidrighets": "vidrighet",
    "vidrigs": "vidrig",
    "vidrigt": "vidrig",
    "vidrigts": "vidrig",
    "vidräkningar": "vidräkning",
    "vidräkningarna": "vidräkning",
    "vidräkningarnas": "vidräkning",
    "vidräkningars": "vidräkning",
    "vidräkningen": "vidräkning",
    "vidräkningens": "vidräkning",
    "vidräknings": "vidräkning",
    "vidrör": "vidröra",
    "vidrörande": "vidröra",
    "vidröranden": "vidrörande",
    "vidrörandena": "vidrörande",
    "vidrörandenas": "vidrörande",
    "vidrörandens": "vidrörande",
    "vidrörandes": "vidrörande",
    "vidrörandet": "vidrörande",
    "vidrörandets": "vidrörande",
    "vidröras": "vidröra",
    "vidrörd": "vidröra",
    "vidrörda": "vidröra",
    "vidrördas": "vidröra",
    "vidrörde": "vidröra",
    "vidrördes": "vidröra",
    "vidrörds": "vidröra",
    "vidröres": "vidröra",
    "vidrörs": "vidröra",
    "vidrört": "vidröra",
    "vidrörts": "vidröra",
    "vids": "vide",
    "vidskepelsen": "vidskepelse",
    "vidskepelsens": "vidskepelse",
    "vidskepelser": "vidskepelse",
    "vidskepelserna": "vidskepelse",
    "vidskepelsernas": "vidskepelse",
    "vidskepelsers": "vidskepelse",
    "vidskepelses": "vidskepelse",
    "vidskepliga": "vidskeplig",
    "vidskepligare": "vidskeplig",
    "vidskepligares": "vidskeplig",
    "vidskepligas": "vidskeplig",
    "vidskepligast": "vidskeplig",
    "vidskepligaste": "vidskeplig",
    "vidskepligastes": "vidskeplig",
    "vidskepligasts": "vidskeplig",
    "vidskeplige": "vidskeplig",
    "vidskepliges": "vidskeplig",
    "vidskepligheten": "vidskeplighet",
    "vidskeplighetens": "vidskeplighet",
    "vidskepligheter": "vidskeplighet",
    "vidskepligheterna": "vidskeplighet",
    "vidskepligheternas": "vidskeplighet",
    "vidskepligheters": "vidskeplighet",
    "vidskeplighets": "vidskeplighet",
    "vidskepligs": "vidskeplig",
    "vidskepligt": "vidskeplig",
    "vidskepligts": "vidskeplig",
    "vidsträckta": "vidsträckt",
    "vidsträcktare": "vidsträckt",
    "vidsträcktares": "vidsträckt",
    "vidsträcktas": "vidsträckt",
    "vidsträcktast": "vidsträckt",
    "vidsträcktaste": "vidsträckt",
    "vidsträcktastes": "vidsträckt",
    "vidsträcktasts": "vidsträckt",
    "vidsträckte": "vidsträckt",
    "vidsträcktes": "vidsträckt",
    "vidsträcktheten": "vidsträckthet",
    "vidsträckthetens": "vidsträckthet",
    "vidsträckthets": "vidsträckthet",
    "vidsträckts": "vidsträckt",
    "vidsynen": "vidsyn",
    "vidsynens": "vidsyn",
    "vidsyns": "vidsyn",
    "vidsynta": "vidsynt",
    "vidsyntare": "vidsynt",
    "vidsyntares": "vidsynt",
    "vidsyntas": "vidsynt",
    "vidsyntast": "vidsynt",
    "vidsyntaste": "vidsynt",
    "vidsyntastes": "vidsynt",
    "vidsyntasts": "vidsynt",
    "vidsynte": "vidsynt",
    "vidsyntes": "vidsynt",
    "vidsyntheten": "vidsynthet",
    "vidsynthetens": "vidsynthet",
    "vidsyntheter": "vidsynthet",
    "vidsyntheterna": "vidsynthet",
    "vidsyntheternas": "vidsynthet",
    "vidsyntheters": "vidsynthet",
    "vidsynthets": "vidsynthet",
    "vidsynts": "vidsynt",
    "vidtag": "vidta",
    "vidtaga": "vidta",
    "vidtagande": "vidta",
    "vidtaganden": "vidtagande",
    "vidtagandena": "vidtagande",
    "vidtagandenas": "vidtagande",
    "vidtagandens": "vidtagande",
    "vidtagandes": "vidtagande",
    "vidtagandet": "vidtagande",
    "vidtagandets": "vidtagande",
    "vidtagas": "vidta",
    "vidtage": "vidta",
    "vidtagen": "vidta",
    "vidtagens": "vidta",
    "vidtager": "vidta",
    "vidtages": "vidta",
    "vidtaget": "vidta",
    "vidtagets": "vidta",
    "vidtagit": "vidta",
    "vidtagits": "vidta",
    "vidtagna": "vidta",
    "vidtagnas": "vidta",
    "vidtagne": "vidta",
    "vidtagnes": "vidta",
    "vidtags": "vidta",
    "vidtal": "vidtala",
    "vidtalad": "vidtala",
    "vidtalade": "vidtala",
    "vidtalades": "vidtala",
    "vidtalads": "vidtala",
    "vidtalande": "vidtala",
    "vidtalanden": "vidtalande",
    "vidtalandena": "vidtalande",
    "vidtalandenas": "vidtalande",
    "vidtalandens": "vidtalande",
    "vidtalandes": "vidtalande",
    "vidtalandet": "vidtalande",
    "vidtalandets": "vidtalande",
    "vidtalar": "vidtala",
    "vidtalas": "vidtala",
    "vidtalat": "vidtala",
    "vidtalats": "vidtala",
    "vidtar": "vidta",
    "vidtas": "vidta",
    "vidtog": "vidta",
    "vidtoge": "vidta",
    "vidtoges": "vidta",
    "vidtogs": "vidta",
    "vidunderliga": "vidunderlig",
    "vidunderligare": "vidunderlig",
    "vidunderligares": "vidunderlig",
    "vidunderligas": "vidunderlig",
    "vidunderligast": "vidunderlig",
    "vidunderligaste": "vidunderlig",
    "vidunderligastes": "vidunderlig",
    "vidunderligasts": "vidunderlig",
    "vidunderlige": "vidunderlig",
    "vidunderliges": "vidunderlig",
    "vidunderligheten": "vidunderlighet",
    "vidunderlighetens": "vidunderlighet",
    "vidunderligheter": "vidunderlighet",
    "vidunderligheterna": "vidunderlighet",
    "vidunderligheternas": "vidunderlighet",
    "vidunderligheters": "vidunderlighet",
    "vidunderlighets": "vidunderlighet",
    "vidunderligs": "vidunderlig",
    "vidunderligt": "vidunderlig",
    "vidunderligts": "vidunderlig",
    "vidunders": "vidunder",
    "vidundren": "vidunder",
    "vidundrens": "vidunder",
    "vidundret": "vidunder",
    "vidundrets": "vidunder",
    "vidvinkelobjektiven": "vidvinkelobjektiv",
    "vidvinkelobjektivens": "vidvinkelobjektiv",
    "vidvinkelobjektivet": "vidvinkelobjektiv",
    "vidvinkelobjektivets": "vidvinkelobjektiv",
    "vidvinkelobjektivs": "vidvinkelobjektiv",
    "vidöppens": "vidöppen",
    "vidöppet": "vidöppen",
    "vidöppets": "vidöppen",
    "vidöppna": "vidöppen",
    "vidöppnare": "vidöppen",
    "vidöppnares": "vidöppen",
    "vidöppnas": "vidöppen",
    "vidöppnast": "vidöppen",
    "vidöppnaste": "vidöppen",
    "vidöppnastes": "vidöppen",
    "vidöppnasts": "vidöppen",
    "vidöppne": "vidöppen",
    "vidöppnes": "vidöppen",
    "viellen": "vielle",
    "viellens": "vielle",
    "vieller": "vielle",
    "viellerna": "vielle",
    "viellernas": "vielle",
    "viellers": "vielle",
    "vielles": "vielle",
    "viet": "vi",
    "vietnamesen": "vietnames",
    "vietnamesens": "vietnames",
    "vietnameser": "vietnames",
    "vietnameserna": "vietnames",
    "vietnamesernas": "vietnames",
    "vietnamesers": "vietnames",
    "vietnamesisk": "vietnamesiska",
    "vietnamesiska": "vietnamesisk",
    "vietnamesiskan": "vietnamesiska",
    "vietnamesiskans": "vietnamesiska",
    "vietnamesiskare": "vietnamesisk",
    "vietnamesiskares": "vietnamesisk",
    "vietnamesiskas": "vietnamesiska",
    "vietnamesiskast": "vietnamesisk",
    "vietnamesiskaste": "vietnamesisk",
    "vietnamesiskastes": "vietnamesisk",
    "vietnamesiskasts": "vietnamesisk",
    "vietnamesiske": "vietnamesiska",
    "vietnamesiskes": "vietnamesisk",
    "vietnamesiskor": "vietnamesiska",
    "vietnamesiskorna": "vietnamesiska",
    "vietnamesiskornas": "vietnamesiska",
    "vietnamesiskors": "vietnamesiska",
    "vietnamesisks": "vietnamesisk",
    "vietnamesiskt": "vietnamesisk",
    "vietnamesiskts": "vietnamesisk",
    "viets": "vi",
    "vift": "vifta",
    "viftad": "vifta",
    "viftade": "vifta",
    "viftades": "vifta",
    "viftads": "vifta",
    "viftande": "vifta",
    "viftanden": "viftande",
    "viftandena": "viftande",
    "viftandenas": "viftande",
    "viftandens": "viftande",
    "viftandes": "viftande",
    "viftandet": "viftande",
    "viftandets": "viftande",
    "viftar": "vifta",
    "viftas": "vifta",
    "viftat": "vifta",
    "viftats": "vifta",
    "vig": "viga",
    "viga": "vig",
    "vigande": "viga",
    "viganden": "vigande",
    "vigandena": "vigande",
    "vigandenas": "vigande",
    "vigandens": "vigande",
    "vigandes": "vigande",
    "vigandet": "vigande",
    "vigandets": "vigande",
    "vigare": "vig",
    "vigares": "vig",
    "vigas": "viga",
    "vigast": "vig",
    "vigaste": "vig",
    "vigastes": "vig",
    "vigasts": "vig",
    "vigd": "viga",
    "vigda": "viga",
    "vigdas": "viga",
    "vigde": "viga",
    "vigdes": "viga",
    "vigds": "viga",
    "vige": "vig",
    "viger": "viga",
    "viges": "viga",
    "vigg": "vigge",
    "viggad": "vigga",
    "viggade": "vigga",
    "viggades": "vigga",
    "viggads": "vigga",
    "viggande": "vigga",
    "vigganden": "viggande",
    "viggandena": "viggande",
    "viggandenas": "viggande",
    "viggandens": "viggande",
    "viggandes": "viggande",
    "viggandet": "viggande",
    "viggandets": "viggande",
    "viggar": "vigge",
    "viggarna": "vigge",
    "viggarnas": "vigge",
    "viggars": "vigge",
    "viggas": "vigga",
    "viggat": "vigga",
    "viggats": "vigga",
    "viggen": "vigge",
    "viggens": "vigge",
    "vigges": "vigge",
    "viggs": "vigge",
    "vigheten": "vighet",
    "vighetens": "vighet",
    "vighets": "vighet",
    "vigilansen": "vigilans",
    "vigilansens": "vigilans",
    "vigilerade": "vigilera",
    "vigilerades": "vigilera",
    "vigilerande": "vigilera",
    "vigileranden": "vigilerande",
    "vigilerandena": "vigilerande",
    "vigilerandenas": "vigilerande",
    "vigilerandens": "vigilerande",
    "vigilerandes": "vigilerande",
    "vigilerandet": "vigilerande",
    "vigilerandets": "vigilerande",
    "vigilerar": "vigilera",
    "vigileras": "vigilera",
    "vigilerat": "vigilera",
    "vigilerats": "vigilera",
    "vigileringar": "vigilering",
    "vigileringarna": "vigilering",
    "vigileringarnas": "vigilering",
    "vigileringars": "vigilering",
    "vigileringen": "vigilering",
    "vigileringens": "vigilering",
    "vigilerings": "vigilering",
    "vigili": "vigilia",
    "vigilian": "vigilia",
    "vigilians": "vigilia",
    "vigilias": "vigilia",
    "vigilie": "vigilia",
    "vigilior": "vigilia",
    "vigiliorna": "vigilia",
    "vigiliornas": "vigilia",
    "vigiliors": "vigilia",
    "vigilis": "vigilia",
    "vigkvastar": "vigkvast",
    "vigkvastarna": "vigkvast",
    "vigkvastarnas": "vigkvast",
    "vigkvastars": "vigkvast",
    "vigkvasten": "vigkvast",
    "vigkvastens": "vigkvast",
    "vigkvasts": "vigkvast",
    "vigs": "viga",
    "vigselakten": "vigselakt",
    "vigselaktens": "vigselakt",
    "vigselakter": "vigselakt",
    "vigselakterna": "vigselakt",
    "vigselakternas": "vigselakt",
    "vigselakters": "vigselakt",
    "vigselakts": "vigselakt",
    "vigselannonsen": "vigselannons",
    "vigselannonsens": "vigselannons",
    "vigselannonser": "vigselannons",
    "vigselannonserna": "vigselannons",
    "vigselannonsernas": "vigselannons",
    "vigselannonsers": "vigselannons",
    "vigselbevisen": "vigselbevis",
    "vigselbevisens": "vigselbevis",
    "vigselbeviset": "vigselbevis",
    "vigselbevisets": "vigselbevis",
    "vigselformulären": "vigselformulär",
    "vigselformulärens": "vigselformulär",
    "vigselformuläret": "vigselformulär",
    "vigselformulärets": "vigselformulär",
    "vigselformulärs": "vigselformulär",
    "vigseln": "vigsel",
    "vigselns": "vigsel",
    "vigselringar": "vigselring",
    "vigselringarna": "vigselring",
    "vigselringarnas": "vigselring",
    "vigselringars": "vigselring",
    "vigselringen": "vigselring",
    "vigselringens": "vigselring",
    "vigselrings": "vigselring",
    "vigselritualen": "vigselritual",
    "vigselritualens": "vigselritual",
    "vigselritualer": "vigselritual",
    "vigselritualerna": "vigselritual",
    "vigselritualernas": "vigselritual",
    "vigselritualers": "vigselritual",
    "vigselritualet": "vigselritual",
    "vigselritualets": "vigselritual",
    "vigselrituals": "vigselritual",
    "vigselrummen": "vigselrum",
    "vigselrummens": "vigselrum",
    "vigselrummet": "vigselrum",
    "vigselrummets": "vigselrum",
    "vigselrums": "vigselrum",
    "vigsels": "vigsel",
    "vigselvägrans": "vigselvägran",
    "vigslar": "vigsel",
    "vigslarna": "vigsel",
    "vigslarnas": "vigsel",
    "vigslars": "vigsel",
    "vigt": "viga",
    "vigts": "viga",
    "vigvamen": "vigvam",
    "vigvamens": "vigvam",
    "vigvamer": "vigvam",
    "vigvamerna": "vigvam",
    "vigvamernas": "vigvam",
    "vigvamers": "vigvam",
    "vigvams": "vigvam",
    "vigvattens": "vigvatten",
    "vigvattnet": "vigvatten",
    "vigvattnets": "vigvatten",
    "vigören": "vigör",
    "vigörens": "vigör",
    "vigörs": "vigör",
    "vik": "vika",
    "vikande": "vika",
    "vikanden": "vikande",
    "vikandena": "vikande",
    "vikandenas": "vikande",
    "vikandens": "vikande",
    "vikandes": "vikande",
    "vikandet": "vikande",
    "vikandets": "vikande",
    "vikar": "vikare",
    "vikaren": "vikare",
    "vikarens": "vikare",
    "vikares": "vikare",
    "vikariaten": "vikariat",
    "vikariatens": "vikariat",
    "vikariatet": "vikariat",
    "vikariatets": "vikariat",
    "vikariats": "vikariat",
    "vikarien": "vikarie",
    "vikariens": "vikarie",
    "vikarier": "vikarie",
    "vikarierade": "vikariera",
    "vikarierades": "vikariera",
    "vikarierande": "vikariera",
    "vikarieranden": "vikarierande",
    "vikarierandena": "vikarierande",
    "vikarierandenas": "vikarierande",
    "vikarierandens": "vikarierande",
    "vikarierandes": "vikarierande",
    "vikarierandet": "vikarierande",
    "vikarierandets": "vikarierande",
    "vikarierar": "vikariera",
    "vikarieras": "vikariera",
    "vikarierat": "vikariera",
    "vikarierats": "vikariera",
    "vikarieringar": "vikariering",
    "vikarieringarna": "vikariering",
    "vikarieringarnas": "vikariering",
    "vikarieringars": "vikariering",
    "vikarieringen": "vikariering",
    "vikarieringens": "vikariering",
    "vikarierings": "vikariering",
    "vikarierna": "vikarie",
    "vikariernas": "vikarie",
    "vikariers": "vikarie",
    "vikaries": "vikarie",
    "vikarna": "vikare",
    "vikarnas": "vikare",
    "vikars": "vik",
    "vikas": "vika",
    "vikdörrar": "vikdörr",
    "vikdörrarna": "vikdörr",
    "vikdörrarnas": "vikdörr",
    "vikdörrars": "vikdörr",
    "vikdörren": "vikdörr",
    "vikdörrens": "vikdörr",
    "vikdörrs": "vikdörr",
    "vike": "vika",
    "viken": "vika",
    "vikens": "vika",
    "viker": "vika",
    "vikes": "vika",
    "viket": "vika",
    "vikets": "vika",
    "vikingagravar": "vikingagrav",
    "vikingagravarna": "vikingagrav",
    "vikingagravarnas": "vikingagrav",
    "vikingagravars": "vikingagrav",
    "vikingagraven": "vikingagrav",
    "vikingagravens": "vikingagrav",
    "vikingagravs": "vikingagrav",
    "vikingar": "viking",
    "vikingarna": "viking",
    "vikingarnas": "viking",
    "vikingars": "viking",
    "vikingaskeppen": "vikingaskepp",
    "vikingaskeppens": "vikingaskepp",
    "vikingaskeppet": "vikingaskepp",
    "vikingaskeppets": "vikingaskepp",
    "vikingaskepps": "vikingaskepp",
    "vikingatiden": "vikingatid",
    "vikingatidens": "vikingatid",
    "vikingatids": "vikingatid",
    "vikingatågen": "vikingatåg",
    "vikingatågens": "vikingatåg",
    "vikingatåget": "vikingatåg",
    "vikingatågets": "vikingatåg",
    "vikingatågs": "vikingatåg",
    "vikingen": "viking",
    "vikingens": "viking",
    "vikings": "viking",
    "vikit": "vika",
    "vikits": "vika",
    "vikna": "vika",
    "viknas": "vika",
    "vikne": "vika",
    "viknes": "vika",
    "vikningar": "vikning",
    "vikningarna": "vikning",
    "vikningarnas": "vikning",
    "vikningars": "vikning",
    "vikningen": "vikning",
    "vikningens": "vikning",
    "viknings": "vikning",
    "vikonen": "vikon",
    "vikonens": "vikon",
    "vikonet": "vikon",
    "vikonets": "vikon",
    "vikons": "vikon",
    "viks": "vika",
    "vikskärmar": "vikskärm",
    "vikskärmarna": "vikskärm",
    "vikskärmarnas": "vikskärm",
    "vikskärmars": "vikskärm",
    "vikskärmen": "vikskärm",
    "vikskärmens": "vikskärm",
    "vikskärms": "vikskärm",
    "vikt": "vika",
    "viktad": "vikta",
    "viktade": "vikta",
    "viktades": "vikta",
    "viktads": "vikta",
    "viktande": "vikta",
    "viktanden": "viktande",
    "viktandena": "viktande",
    "viktandenas": "viktande",
    "viktandens": "viktande",
    "viktandes": "viktande",
    "viktandet": "viktande",
    "viktandets": "viktande",
    "viktar": "vikta",
    "viktas": "vikta",
    "viktat": "vikta",
    "viktats": "vikta",
    "vikten": "vikt",
    "viktenheten": "viktenhet",
    "viktenhetens": "viktenhet",
    "viktenheter": "viktenhet",
    "viktenheterna": "viktenhet",
    "viktenheternas": "viktenhet",
    "viktenheters": "viktenhet",
    "viktenhets": "viktenhet",
    "viktens": "vikt",
    "vikter": "vikt",
    "vikterna": "vikt",
    "vikternas": "vikt",
    "vikters": "vikt",
    "viktförlusten": "viktförlust",
    "viktförlustens": "viktförlust",
    "viktförluster": "viktförlust",
    "viktförlusterna": "viktförlust",
    "viktförlusternas": "viktförlust",
    "viktförlusters": "viktförlust",
    "viktförlusts": "viktförlust",
    "viktiga": "viktig",
    "viktigare": "viktig",
    "viktigares": "viktig",
    "viktigas": "viktig",
    "viktigast": "viktig",
    "viktigaste": "viktig",
    "viktigastes": "viktig",
    "viktigasts": "viktig",
    "viktige": "viktig",
    "viktiges": "viktig",
    "viktigheten": "viktighet",
    "viktighetens": "viktighet",
    "viktigheter": "viktighet",
    "viktigheterna": "viktighet",
    "viktigheternas": "viktighet",
    "viktigheters": "viktighet",
    "viktighets": "viktighet",
    "viktighetsmakar": "viktighetsmakare",
    "viktighetsmakaren": "viktighetsmakare",
    "viktighetsmakarens": "viktighetsmakare",
    "viktighetsmakares": "viktighetsmakare",
    "viktighetsmakarna": "viktighetsmakare",
    "viktighetsmakarnas": "viktighetsmakare",
    "viktigpettern": "viktigpetter",
    "viktigpetterns": "viktigpetter",
    "viktigpetters": "viktigpetter",
    "viktigpettrar": "viktigpetter",
    "viktigpettrarna": "viktigpetter",
    "viktigpettrarnas": "viktigpetter",
    "viktigpettrars": "viktigpetter",
    "viktigs": "viktig",
    "viktigt": "viktig",
    "viktigts": "viktig",
    "viktjusterar": "viktjusterare",
    "viktjusteraren": "viktjusterare",
    "viktjusterarens": "viktjusterare",
    "viktjusterares": "viktjusterare",
    "viktjusterarna": "viktjusterare",
    "viktjusterarnas": "viktjusterare",
    "viktkastningar": "viktkastning",
    "viktkastningarna": "viktkastning",
    "viktkastningarnas": "viktkastning",
    "viktkastningars": "viktkastning",
    "viktkastningen": "viktkastning",
    "viktkastningens": "viktkastning",
    "viktkastnings": "viktkastning",
    "viktklassen": "viktklass",
    "viktklassens": "viktklass",
    "viktklasser": "viktklass",
    "viktklasserna": "viktklass",
    "viktklassernas": "viktklass",
    "viktklassers": "viktklass",
    "viktklubbar": "viktklubb",
    "viktklubbarna": "viktklubb",
    "viktklubbarnas": "viktklubb",
    "viktklubbars": "viktklubb",
    "viktklubben": "viktklubb",
    "viktklubbens": "viktklubb",
    "viktklubbs": "viktklubb",
    "viktlösa": "viktlös",
    "viktlösare": "viktlös",
    "viktlösares": "viktlös",
    "viktlösas": "viktlös",
    "viktlösast": "viktlös",
    "viktlösaste": "viktlös",
    "viktlösastes": "viktlös",
    "viktlösasts": "viktlös",
    "viktlöse": "viktlös",
    "viktlöses": "viktlös",
    "viktlösheten": "viktlöshet",
    "viktlöshetens": "viktlöshet",
    "viktlöshets": "viktlöshet",
    "viktlöst": "viktlös",
    "viktlösts": "viktlös",
    "viktminskningar": "viktminskning",
    "viktminskningarna": "viktminskning",
    "viktminskningarnas": "viktminskning",
    "viktminskningars": "viktminskning",
    "viktminskningen": "viktminskning",
    "viktminskningens": "viktminskning",
    "viktminsknings": "viktminskning",
    "viktmässiga": "viktmässig",
    "viktmässigare": "viktmässig",
    "viktmässigares": "viktmässig",
    "viktmässigas": "viktmässig",
    "viktmässigast": "viktmässig",
    "viktmässigaste": "viktmässig",
    "viktmässigastes": "viktmässig",
    "viktmässigasts": "viktmässig",
    "viktmässige": "viktmässig",
    "viktmässiges": "viktmässig",
    "viktmässigs": "viktmässig",
    "viktmässigt": "viktmässig",
    "viktmässigts": "viktmässig",
    "viktnedgången": "viktnedgång",
    "viktnedgångens": "viktnedgång",
    "viktnedgångs": "viktnedgång",
    "viktnedgångsåtgärden": "viktnedgångsåtgärd",
    "viktnedgångsåtgärdens": "viktnedgångsåtgärd",
    "viktnedgångsåtgärder": "viktnedgångsåtgärd",
    "viktnedgångsåtgärderna": "viktnedgångsåtgärd",
    "viktnedgångsåtgärdernas": "viktnedgångsåtgärd",
    "viktnedgångsåtgärders": "viktnedgångsåtgärd",
    "viktnedgångsåtgärds": "viktnedgångsåtgärd",
    "viktori": "viktoria",
    "viktorian": "viktoria",
    "viktorianismen": "viktorianism",
    "viktorianismens": "viktorianism",
    "viktorianismer": "viktorianism",
    "viktorianismerna": "viktorianism",
    "viktorianismernas": "viktorianism",
    "viktorianismers": "viktorianism",
    "viktorianisms": "viktorianism",
    "viktorians": "viktoria",
    "viktorianska": "viktoriansk",
    "viktorianskare": "viktoriansk",
    "viktorianskares": "viktoriansk",
    "viktorianskas": "viktoriansk",
    "viktorianskast": "viktoriansk",
    "viktorianskaste": "viktoriansk",
    "viktorianskastes": "viktoriansk",
    "viktorianskasts": "viktoriansk",
    "viktorianske": "viktoriansk",
    "viktorianskes": "viktoriansk",
    "viktoriansks": "viktoriansk",
    "viktorianskt": "viktoriansk",
    "viktorianskts": "viktoriansk",
    "viktorie": "viktoria",
    "viktorior": "viktoria",
    "viktoriornas": "viktoria",
    "viktoris": "viktoria",
    "viktprocenten": "viktprocent",
    "viktprocentens": "viktprocent",
    "viktprocents": "viktprocent",
    "vikts": "vikt",
    "viktskillnaden": "viktskillnad",
    "viktskillnadens": "viktskillnad",
    "viktskillnader": "viktskillnad",
    "viktskillnaderna": "viktskillnad",
    "viktskillnadernas": "viktskillnad",
    "viktskillnaders": "viktskillnad",
    "viktskillnads": "viktskillnad",
    "viktsystemen": "viktsystem",
    "viktsystemens": "viktsystem",
    "viktsystemet": "viktsystem",
    "viktsystemets": "viktsystem",
    "viktsystems": "viktsystem",
    "viktualie": "viktualier",
    "viktualiehandeln": "viktualiehandel",
    "viktualiehandelns": "viktualiehandel",
    "viktualiehandels": "viktualiehandel",
    "viktualiehandlar": "viktualiehandel",
    "viktualiehandlarna": "viktualiehandel",
    "viktualiehandlarnas": "viktualiehandel",
    "viktualiehandlars": "viktualiehandel",
    "viktualierna": "viktualier",
    "viktualiernas": "viktualier",
    "viktualiers": "viktualier",
    "viktualievikten": "viktualievikt",
    "viktualieviktens": "viktualievikt",
    "viktualievikts": "viktualievikt",
    "viktökningar": "viktökning",
    "viktökningarna": "viktökning",
    "viktökningarnas": "viktökning",
    "viktökningars": "viktökning",
    "viktökningen": "viktökning",
    "viktökningens": "viktökning",
    "viktöknings": "viktökning",
    "vikunj": "vikunja",
    "vikunjan": "vikunja",
    "vikunjans": "vikunja",
    "vikunjas": "vikunja",
    "vikunjaullen": "vikunjaull",
    "vikunjaullens": "vikunjaull",
    "vikunjaulls": "vikunjaull",
    "vikunje": "vikunja",
    "vikunjor": "vikunja",
    "vikunjorna": "vikunja",
    "vikunjornas": "vikunja",
    "vikunjors": "vikunja",
    "vikunjs": "vikunja",
    "vil": "vila",
    "vilade": "vila",
    "vilades": "vila",
    "vilan": "vila",
    "vilande": "vila",
    "vilanden": "vilande",
    "vilandena": "vilande",
    "vilandenas": "vilande",
    "vilandens": "vilande",
    "vilandes": "vilande",
    "vilandet": "vilande",
    "vilandets": "vilande",
    "vilans": "vila",
    "vilar": "vila",
    "vilas": "vila",
    "vilat": "vila",
    "vilats": "vila",
    "vild": "vilde",
    "vilda": "vild",
    "vildanden": "vildand",
    "vildandens": "vildand",
    "vildands": "vildand",
    "vildapeln": "vildapel",
    "vildapelns": "vildapel",
    "vildapels": "vildapel",
    "vildaplar": "vildapel",
    "vildaplarna": "vildapel",
    "vildaplarnas": "vildapel",
    "vildaplars": "vildapel",
    "vildar": "vilde",
    "vildare": "vild",
    "vildares": "vild",
    "vildarna": "vilde",
    "vildarnas": "vilde",
    "vildars": "vilde",
    "vildas": "vild",
    "vildast": "vild",
    "vildaste": "vild",
    "vildastes": "vild",
    "vildasts": "vild",
    "vildaveln": "vildavel",
    "vildavelns": "vildavel",
    "vildavels": "vildavel",
    "vildbanan": "vildbana",
    "vildbanans": "vildbana",
    "vildbanas": "vildbana",
    "vildbane": "vildbana",
    "vildbanor": "vildbana",
    "vildbanorna": "vildbana",
    "vildbanornas": "vildbana",
    "vildbanors": "vildbana",
    "vildbasar": "vildbasare",
    "vildbasaren": "vildbasare",
    "vildbasarens": "vildbasare",
    "vildbasares": "vildbasare",
    "vildbasarna": "vildbasare",
    "vildbasarnas": "vildbasare",
    "vilddjuren": "vilddjur",
    "vilddjurens": "vilddjur",
    "vilddjuret": "vilddjur",
    "vilddjurets": "vilddjur",
    "vilddjurs": "vilddjur",
    "vilde": "vild",
    "vilden": "vilde",
    "vildens": "vilde",
    "vildes": "vilde",
    "vildfågeln": "vildfågel",
    "vildfågelns": "vildfågel",
    "vildfågels": "vildfågel",
    "vildfåglar": "vildfågel",
    "vildfåglarna": "vildfågel",
    "vildfåglarnas": "vildfågel",
    "vildfåglars": "vildfågel",
    "vildgräsen": "vildgräs",
    "vildgräsens": "vildgräs",
    "vildgräset": "vildgräs",
    "vildgräsets": "vildgräs",
    "vildgäss": "vildgås",
    "vildgässen": "vildgås",
    "vildgässens": "vildgås",
    "vildgåsen": "vildgås",
    "vildgåsens": "vildgås",
    "vildhavren": "vildhavre",
    "vildhavrens": "vildhavre",
    "vildhavres": "vildhavre",
    "vildheten": "vildhet",
    "vildhetens": "vildhet",
    "vildhets": "vildhet",
    "vildhjärn": "vildhjärna",
    "vildhjärnan": "vildhjärna",
    "vildhjärnans": "vildhjärna",
    "vildhjärnas": "vildhjärna",
    "vildhjärne": "vildhjärna",
    "vildhjärnor": "vildhjärna",
    "vildhjärnorna": "vildhjärna",
    "vildhjärnornas": "vildhjärna",
    "vildhjärnors": "vildhjärna",
    "vildhjärns": "vildhjärna",
    "vildhonungen": "vildhonung",
    "vildhonungens": "vildhonung",
    "vildhonungs": "vildhonung",
    "vildingar": "vilding",
    "vildingarna": "vilding",
    "vildingarnas": "vilding",
    "vildingars": "vilding",
    "vildingen": "vilding",
    "vildingens": "vilding",
    "vildings": "vilding",
    "vildkaninen": "vildkanin",
    "vildkaninens": "vildkanin",
    "vildkaniner": "vildkanin",
    "vildkaninerna": "vildkanin",
    "vildkaninernas": "vildkanin",
    "vildkaniners": "vildkanin",
    "vildkanins": "vildkanin",
    "vildkatten": "vildkatt",
    "vildkattens": "vildkatt",
    "vildkatter": "vildkatt",
    "vildkatterna": "vildkatt",
    "vildkatternas": "vildkatt",
    "vildkatters": "vildkatt",
    "vildkatts": "vildkatt",
    "vildmarken": "vildmark",
    "vildmarkens": "vildmark",
    "vildmarker": "vildmark",
    "vildmarkerna": "vildmark",
    "vildmarkernas": "vildmark",
    "vildmarkers": "vildmark",
    "vildmarks": "vildmark",
    "vildmarksbranden": "vildmarksbrand",
    "vildmarksbrandens": "vildmarksbrand",
    "vildmarksbrands": "vildmarksbrand",
    "vildmarksbränder": "vildmarksbrand",
    "vildmarksbränderna": "vildmarksbrand",
    "vildmarksbrändernas": "vildmarksbrand",
    "vildmarksbränders": "vildmarksbrand",
    "vildnaden": "vildnad",
    "vildnadens": "vildnad",
    "vildnader": "vildnad",
    "vildnaderna": "vildnad",
    "vildnadernas": "vildnad",
    "vildnaders": "vildnad",
    "vildnads": "vildnad",
    "vildpersiljan": "vildpersilja",
    "vildpersiljans": "vildpersilja",
    "vildpersiljas": "vildpersilja",
    "vildrenar": "vildren",
    "vildrenarna": "vildren",
    "vildrenarnas": "vildren",
    "vildrenars": "vildren",
    "vildrenen": "vildren",
    "vildrenens": "vildren",
    "vildrens": "vildren",
    "vildrensjakten": "vildrensjakt",
    "vildrensjaktens": "vildrensjakt",
    "vildrensjakter": "vildrensjakt",
    "vildrensjakterna": "vildrensjakt",
    "vildrensjakternas": "vildrensjakt",
    "vildrensjakters": "vildrensjakt",
    "vildrensjakts": "vildrensjakt",
    "vilds": "vilde",
    "vildsinta": "vildsint",
    "vildsintare": "vildsint",
    "vildsintares": "vildsint",
    "vildsintas": "vildsint",
    "vildsintast": "vildsint",
    "vildsintaste": "vildsint",
    "vildsintastes": "vildsint",
    "vildsintasts": "vildsint",
    "vildsinte": "vildsint",
    "vildsintes": "vildsint",
    "vildsintheten": "vildsinthet",
    "vildsinthetens": "vildsinthet",
    "vildsinthets": "vildsinthet",
    "vildsints": "vildsint",
    "vildskotten": "vildskott",
    "vildskottens": "vildskott",
    "vildskottet": "vildskott",
    "vildskottets": "vildskott",
    "vildskotts": "vildskott",
    "vildstammar": "vildstam",
    "vildstammarna": "vildstam",
    "vildstammarnas": "vildstam",
    "vildstammars": "vildstam",
    "vildstammen": "vildstam",
    "vildstammens": "vildstam",
    "vildstams": "vildstam",
    "vildsvinen": "vildsvin",
    "vildsvinens": "vildsvin",
    "vildsvinet": "vildsvin",
    "vildsvinets": "vildsvin",
    "vildsvins": "vildsvin",
    "vildsvinsjakten": "vildsvinsjakt",
    "vildsvinsjaktens": "vildsvinsjakt",
    "vildsvinsjakts": "vildsvinsjakt",
    "vildvinet": "vildvin",
    "vildvinets": "vildvin",
    "vildvins": "vildvin",
    "vildvuxens": "vildvuxen",
    "vildvuxet": "vildvuxen",
    "vildvuxets": "vildvuxen",
    "vildvuxna": "vildvuxen",
    "vildvuxnare": "vildvuxen",
    "vildvuxnares": "vildvuxen",
    "vildvuxnas": "vildvuxen",
    "vildvuxnast": "vildvuxen",
    "vildvuxnaste": "vildvuxen",
    "vildvuxnastes": "vildvuxen",
    "vildvuxnasts": "vildvuxen",
    "vildvuxne": "vildvuxen",
    "vildvuxnes": "vildvuxen",
    "vildänder": "vildand",
    "vildänderna": "vildand",
    "vildändernas": "vildand",
    "vildänders": "vildand",
    "vile": "vila",
    "vilfåtöljen": "vilfåtölj",
    "vilfåtöljens": "vilfåtölj",
    "vilfåtöljer": "vilfåtölj",
    "vilfåtöljerna": "vilfåtölj",
    "vilfåtöljernas": "vilfåtölj",
    "vilfåtöljers": "vilfåtölj",
    "vilfåtöljs": "vilfåtölj",
    "vilj": "vilja",
    "viljan": "vilja",
    "viljande": "vilja",
    "viljanden": "viljande",
    "viljandena": "viljande",
    "viljandenas": "viljande",
    "viljandens": "viljande",
    "viljandes": "viljande",
    "viljandet": "viljande",
    "viljandets": "viljande",
    "viljans": "vilja",
    "viljas": "vilja",
    "vilje": "vilja",
    "viljeakten": "viljeakt",
    "viljeaktens": "viljeakt",
    "viljeakter": "viljeakt",
    "viljeakterna": "viljeakt",
    "viljeakternas": "viljeakt",
    "viljeakters": "viljeakt",
    "viljeakts": "viljeakt",
    "viljeansträngningar": "viljeansträngning",
    "viljeansträngningarna": "viljeansträngning",
    "viljeansträngningarnas": "viljeansträngning",
    "viljeansträngningars": "viljeansträngning",
    "viljeansträngningen": "viljeansträngning",
    "viljeansträngningens": "viljeansträngning",
    "viljeansträngnings": "viljeansträngning",
    "viljeförklaringar": "viljeförklaring",
    "viljeförklaringarna": "viljeförklaring",
    "viljeförklaringarnas": "viljeförklaring",
    "viljeförklaringars": "viljeförklaring",
    "viljeförklaringen": "viljeförklaring",
    "viljeförklaringens": "viljeförklaring",
    "viljeförklarings": "viljeförklaring",
    "viljeförlamningar": "viljeförlamning",
    "viljeförlamningarna": "viljeförlamning",
    "viljeförlamningarnas": "viljeförlamning",
    "viljeförlamningars": "viljeförlamning",
    "viljeförlamningen": "viljeförlamning",
    "viljeförlamningens": "viljeförlamning",
    "viljeförlamnings": "viljeförlamning",
    "viljehandlingar": "viljehandling",
    "viljehandlingarna": "viljehandling",
    "viljehandlingarnas": "viljehandling",
    "viljehandlingars": "viljehandling",
    "viljehandlingen": "viljehandling",
    "viljehandlingens": "viljehandling",
    "viljehandlings": "viljehandling",
    "viljeinriktningar": "viljeinriktning",
    "viljeinriktningarna": "viljeinriktning",
    "viljeinriktningarnas": "viljeinriktning",
    "viljeinriktningars": "viljeinriktning",
    "viljeinriktningen": "viljeinriktning",
    "viljeinriktningens": "viljeinriktning",
    "viljeinriktnings": "viljeinriktning",
    "viljekraften": "viljekraft",
    "viljekraftens": "viljekraft",
    "viljekrafts": "viljekraft",
    "viljelösa": "viljelös",
    "viljelösare": "viljelös",
    "viljelösares": "viljelös",
    "viljelösas": "viljelös",
    "viljelösast": "viljelös",
    "viljelösaste": "viljelös",
    "viljelösastes": "viljelös",
    "viljelösasts": "viljelös",
    "viljelöse": "viljelös",
    "viljelöses": "viljelös",
    "viljelösheten": "viljelöshet",
    "viljelöshetens": "viljelöshet",
    "viljelöshets": "viljelöshet",
    "viljelöst": "viljelös",
    "viljelösts": "viljelös",
    "viljemänniskan": "viljemänniska",
    "viljemänniskans": "viljemänniska",
    "viljemänniskas": "viljemänniska",
    "viljemännisko": "viljemänniska",
    "viljemänniskor": "viljemänniska",
    "viljemänniskorna": "viljemänniska",
    "viljemänniskornas": "viljemänniska",
    "viljemänniskors": "viljemänniska",
    "viljemässiga": "viljemässig",
    "viljemässigare": "viljemässig",
    "viljemässigares": "viljemässig",
    "viljemässigas": "viljemässig",
    "viljemässigast": "viljemässig",
    "viljemässigaste": "viljemässig",
    "viljemässigastes": "viljemässig",
    "viljemässigasts": "viljemässig",
    "viljemässige": "viljemässig",
    "viljemässiges": "viljemässig",
    "viljemässigheten": "viljemässighet",
    "viljemässighetens": "viljemässighet",
    "viljemässighets": "viljemässighet",
    "viljemässigs": "viljemässig",
    "viljemässigt": "viljemässig",
    "viljemässigts": "viljemässig",
    "viljestarka": "viljestark",
    "viljestarkare": "viljestark",
    "viljestarkares": "viljestark",
    "viljestarkas": "viljestark",
    "viljestarkast": "viljestark",
    "viljestarkaste": "viljestark",
    "viljestarkastes": "viljestark",
    "viljestarkasts": "viljestark",
    "viljestarke": "viljestark",
    "viljestarkes": "viljestark",
    "viljestarkheten": "viljestarkhet",
    "viljestarkhetens": "viljestarkhet",
    "viljestarkhets": "viljestarkhet",
    "viljestarks": "viljestark",
    "viljestarkt": "viljestark",
    "viljestarkts": "viljestark",
    "viljestyrkan": "viljestyrka",
    "viljestyrkans": "viljestyrka",
    "viljestyrkas": "viljestyrka",
    "viljestyrke": "viljestyrka",
    "viljesvaga": "viljesvag",
    "viljesvagare": "viljesvag",
    "viljesvagares": "viljesvag",
    "viljesvagas": "viljesvag",
    "viljesvagast": "viljesvag",
    "viljesvagaste": "viljesvag",
    "viljesvagastes": "viljesvag",
    "viljesvagasts": "viljesvag",
    "viljesvage": "viljesvag",
    "viljesvages": "viljesvag",
    "viljesvagheten": "viljesvaghet",
    "viljesvaghetens": "viljesvaghet",
    "viljesvaghets": "viljesvaghet",
    "viljesvags": "viljesvag",
    "viljesvagt": "viljesvag",
    "viljesvagts": "viljesvag",
    "viljeyttringar": "viljeyttring",
    "viljeyttringarna": "viljeyttring",
    "viljeyttringarnas": "viljeyttring",
    "viljeyttringars": "viljeyttring",
    "viljeyttringen": "viljeyttring",
    "viljeyttringens": "viljeyttring",
    "viljeyttrings": "viljeyttring",
    "viljor": "vilja",
    "viljorna": "vilja",
    "viljornas": "vilja",
    "viljors": "vilja",
    "vilka": "vilken",
    "vilkadera": "vilkendera",
    "vilkaderas": "vilkendera",
    "vilkas": "vilken",
    "vilkenderas": "vilkendera",
    "vilkens": "vilken",
    "vilket": "vilken",
    "vilketdera": "vilkendera",
    "vilketderas": "vilkendera",
    "vilkets": "vilken",
    "vill": "villa",
    "villabranden": "villabrand",
    "villabrandens": "villabrand",
    "villabrands": "villabrand",
    "villabränder": "villabrand",
    "villabränderna": "villabrand",
    "villabrändernas": "villabrand",
    "villabränders": "villabrand",
    "villakvarteren": "villakvarter",
    "villakvarterens": "villakvarter",
    "villakvarteret": "villakvarter",
    "villakvarterets": "villakvarter",
    "villakvarters": "villakvarter",
    "villan": "villa",
    "villanellen": "villanell",
    "villanellens": "villanell",
    "villaneller": "villanell",
    "villanellerna": "villanell",
    "villanellernas": "villanell",
    "villanellers": "villanell",
    "villanells": "villanell",
    "villans": "villa",
    "villaområden": "villaområde",
    "villaområdena": "villaområde",
    "villaområdenas": "villaområde",
    "villaområdens": "villaområde",
    "villaområdes": "villaområde",
    "villaområdet": "villaområde",
    "villaområdets": "villaområde",
    "villaprisen": "villapris",
    "villaprisens": "villapris",
    "villapriser": "villapris",
    "villapriserna": "villapris",
    "villaprisernas": "villapris",
    "villaprisers": "villapris",
    "villapriset": "villapris",
    "villaprisets": "villapris",
    "villas": "villa",
    "villaservituten": "villaservitut",
    "villaservitutens": "villaservitut",
    "villaservitutet": "villaservitut",
    "villaservitutets": "villaservitut",
    "villaservituts": "villaservitut",
    "villatomten": "villatomt",
    "villatomtens": "villatomt",
    "villatomter": "villatomt",
    "villatomterna": "villatomt",
    "villatomternas": "villatomt",
    "villatomters": "villatomt",
    "villatomts": "villatomt",
    "villaägar": "villaägare",
    "villaägaren": "villaägare",
    "villaägarens": "villaägare",
    "villaägares": "villaägare",
    "villaägarna": "villaägare",
    "villaägarnas": "villaägare",
    "ville": "villa",
    "villebråden": "villebråd",
    "villebrådens": "villebråd",
    "villebrådet": "villebråd",
    "villebrådets": "villebråd",
    "villebråds": "villebråd",
    "villervallan": "villervalla",
    "villervallans": "villervalla",
    "villervallas": "villervalla",
    "villfar": "villfara",
    "villfarande": "villfara",
    "villfaranden": "villfarande",
    "villfarandena": "villfarande",
    "villfarandenas": "villfarande",
    "villfarandens": "villfarande",
    "villfarandes": "villfarande",
    "villfarandet": "villfarande",
    "villfarandets": "villfarande",
    "villfaras": "villfara",
    "villfare": "villfara",
    "villfarelsen": "villfarelse",
    "villfarelsens": "villfarelse",
    "villfarelser": "villfarelse",
    "villfarelserna": "villfarelse",
    "villfarelsernas": "villfarelse",
    "villfarelsers": "villfarelse",
    "villfarelses": "villfarelse",
    "villfaren": "villfara",
    "villfarens": "villfara",
    "villfares": "villfara",
    "villfaret": "villfara",
    "villfarets": "villfara",
    "villfarit": "villfara",
    "villfarits": "villfara",
    "villfarna": "villfara",
    "villfarnas": "villfara",
    "villfarne": "villfara",
    "villfarnes": "villfara",
    "villfars": "villfara",
    "villfor": "villfara",
    "villfore": "villfara",
    "villfores": "villfara",
    "villfors": "villfara",
    "villiga": "villig",
    "villigare": "villig",
    "villigares": "villig",
    "villigas": "villig",
    "villigast": "villig",
    "villigaste": "villig",
    "villigastes": "villig",
    "villigasts": "villig",
    "villige": "villig",
    "villiges": "villig",
    "villigheten": "villighet",
    "villighetens": "villighet",
    "villighets": "villighet",
    "villigs": "villig",
    "villigt": "villig",
    "villigts": "villig",
    "villkor": "villkora",
    "villkorad": "villkora",
    "villkorade": "villkora",
    "villkorades": "villkora",
    "villkorads": "villkora",
    "villkorande": "villkora",
    "villkoranden": "villkorande",
    "villkorandena": "villkorande",
    "villkorandenas": "villkorande",
    "villkorandens": "villkorande",
    "villkorandes": "villkorande",
    "villkorandet": "villkorande",
    "villkorandets": "villkorande",
    "villkorar": "villkora",
    "villkoras": "villkora",
    "villkorat": "villkora",
    "villkorats": "villkora",
    "villkoren": "villkor",
    "villkorens": "villkor",
    "villkoret": "villkor",
    "villkorets": "villkor",
    "villkorliga": "villkorlig",
    "villkorligare": "villkorlig",
    "villkorligares": "villkorlig",
    "villkorligas": "villkorlig",
    "villkorligast": "villkorlig",
    "villkorligaste": "villkorlig",
    "villkorligastes": "villkorlig",
    "villkorligasts": "villkorlig",
    "villkorlige": "villkorlig",
    "villkorliges": "villkorlig",
    "villkorligheten": "villkorlighet",
    "villkorlighetens": "villkorlighet",
    "villkorlighets": "villkorlighet",
    "villkorligs": "villkorlig",
    "villkorligt": "villkorlig",
    "villkorligts": "villkorlig",
    "villkors": "villkor",
    "villkorsbisatsen": "villkorsbisats",
    "villkorsbisatsens": "villkorsbisats",
    "villkorsbisatser": "villkorsbisats",
    "villkorsbisatserna": "villkorsbisats",
    "villkorsbisatsernas": "villkorsbisats",
    "villkorsbisatsers": "villkorsbisats",
    "villkorskonjunktionen": "villkorskonjunktion",
    "villkorskonjunktionens": "villkorskonjunktion",
    "villkorskonjunktioner": "villkorskonjunktion",
    "villkorskonjunktionerna": "villkorskonjunktion",
    "villkorskonjunktionernas": "villkorskonjunktion",
    "villkorskonjunktioners": "villkorskonjunktion",
    "villkorskonjunktions": "villkorskonjunktion",
    "villkorslösa": "villkorslös",
    "villkorslösare": "villkorslös",
    "villkorslösares": "villkorslös",
    "villkorslösas": "villkorslös",
    "villkorslösast": "villkorslös",
    "villkorslösaste": "villkorslös",
    "villkorslösastes": "villkorslös",
    "villkorslösasts": "villkorslös",
    "villkorslöse": "villkorslös",
    "villkorslöses": "villkorslös",
    "villkorslösheten": "villkorslöshet",
    "villkorslöshetens": "villkorslöshet",
    "villkorslöshets": "villkorslöshet",
    "villkorslöst": "villkorslös",
    "villkorslösts": "villkorslös",
    "villoläran": "villolära",
    "villolärans": "villolära",
    "villoläras": "villolära",
    "villoläre": "villolära",
    "villoläro": "villolära",
    "villoläror": "villolära",
    "villolärorna": "villolära",
    "villolärornas": "villolära",
    "villolärors": "villolära",
    "villor": "villa",
    "villorna": "villa",
    "villornas": "villa",
    "villors": "villa",
    "villospåren": "villospår",
    "villospårens": "villospår",
    "villospåret": "villospår",
    "villospårets": "villospår",
    "villospårs": "villospår",
    "villovägar": "villoväg",
    "villovägarna": "villoväg",
    "villovägarnas": "villoväg",
    "villovägars": "villoväg",
    "villovägen": "villoväg",
    "villovägens": "villoväg",
    "villovägs": "villoväg",
    "villrådiga": "villrådig",
    "villrådigare": "villrådig",
    "villrådigares": "villrådig",
    "villrådigas": "villrådig",
    "villrådigast": "villrådig",
    "villrådigaste": "villrådig",
    "villrådigastes": "villrådig",
    "villrådigasts": "villrådig",
    "villrådige": "villrådig",
    "villrådiges": "villrådig",
    "villrådigheten": "villrådighet",
    "villrådighetens": "villrådighet",
    "villrådighets": "villrådighet",
    "villrådigs": "villrådig",
    "villrådigt": "villrådig",
    "villrådigts": "villrådig",
    "vills": "villa",
    "villsamheten": "villsamhet",
    "villsamhetens": "villsamhet",
    "villsamhets": "villsamhet",
    "villsamma": "villsam",
    "villsammare": "villsam",
    "villsammares": "villsam",
    "villsammas": "villsam",
    "villsammast": "villsam",
    "villsammaste": "villsam",
    "villsammastes": "villsam",
    "villsammasts": "villsam",
    "villsamme": "villsam",
    "villsammes": "villsam",
    "villsams": "villsam",
    "villsamt": "villsam",
    "villsamts": "villsam",
    "vilo": "vila",
    "vilodagar": "vilodag",
    "vilodagarna": "vilodag",
    "vilodagarnas": "vilodag",
    "vilodagars": "vilodag",
    "vilodagen": "vilodag",
    "vilodagens": "vilodag",
    "vilodags": "vilodag",
    "vilohemmen": "vilohem",
    "vilohemmens": "vilohem",
    "vilohemmet": "vilohem",
    "vilohemmets": "vilohem",
    "vilohems": "vilohem",
    "vilolägen": "viloläge",
    "vilolägena": "viloläge",
    "vilolägenas": "viloläge",
    "vilolägens": "viloläge",
    "vilolägerna": "viloläger",
    "vilolägernas": "viloläger",
    "vilolägers": "viloläger",
    "viloläges": "viloläge",
    "viloläget": "viloläge",
    "vilolägets": "viloläge",
    "vilolägren": "viloläger",
    "vilolägrens": "viloläger",
    "vilolägret": "viloläger",
    "vilolägrets": "viloläger",
    "vilomassan": "vilomassa",
    "vilomassans": "vilomassa",
    "vilomassas": "vilomassa",
    "vilomasse": "vilomassa",
    "vilopausen": "vilopaus",
    "vilopausens": "vilopaus",
    "vilopauser": "vilopaus",
    "vilopauserna": "vilopaus",
    "vilopausernas": "vilopaus",
    "vilopausers": "vilopaus",
    "viloplatsen": "viloplats",
    "viloplatsens": "viloplats",
    "viloplatser": "viloplats",
    "viloplatserna": "viloplats",
    "viloplatsernas": "viloplats",
    "viloplatsers": "viloplats",
    "vilopulsar": "vilopuls",
    "vilopulsarna": "vilopuls",
    "vilopulsarnas": "vilopuls",
    "vilopulsars": "vilopuls",
    "vilopulsen": "vilopuls",
    "vilopulsens": "vilopuls",
    "vilopunkten": "vilopunkt",
    "vilopunktens": "vilopunkt",
    "vilopunkter": "vilopunkt",
    "vilopunkterna": "vilopunkt",
    "vilopunkternas": "vilopunkt",
    "vilopunkters": "vilopunkt",
    "vilopunkts": "vilopunkt",
    "vilor": "vila",
    "vilorna": "vila",
    "vilornas": "vila",
    "vilors": "vila",
    "vilorummen": "vilorum",
    "vilorummens": "vilorum",
    "vilorummet": "vilorum",
    "vilorummets": "vilorum",
    "vilorums": "vilorum",
    "vilostadie": "vilostadium",
    "vilostadier": "vilostadium",
    "vilostadierna": "vilostadium",
    "vilostadiernas": "vilostadium",
    "vilostadiers": "vilostadium",
    "vilostadiet": "vilostadium",
    "vilostadiets": "vilostadium",
    "vilostadiums": "vilostadium",
    "vilrummen": "vilrum",
    "vilrummens": "vilrum",
    "vilrummet": "vilrum",
    "vilrummets": "vilrum",
    "vilrums": "vilrum",
    "vils": "vila",
    "vilsamheten": "vilsamhet",
    "vilsamhetens": "vilsamhet",
    "vilsamhets": "vilsamhet",
    "vilsamma": "vilsam",
    "vilsammare": "vilsam",
    "vilsammares": "vilsam",
    "vilsammas": "vilsam",
    "vilsammast": "vilsam",
    "vilsammaste": "vilsam",
    "vilsammastes": "vilsam",
    "vilsammasts": "vilsam",
    "vilsamme": "vilsam",
    "vilsammes": "vilsam",
    "vilsams": "vilsam",
    "vilsamt": "vilsam",
    "vilsamts": "vilsam",
    "vilseför": "vilseföra",
    "vilseförande": "vilseföra",
    "vilseföranden": "vilseförande",
    "vilseförandena": "vilseförande",
    "vilseförandenas": "vilseförande",
    "vilseförandens": "vilseförande",
    "vilseförandes": "vilseförande",
    "vilseförandet": "vilseförande",
    "vilseförandets": "vilseförande",
    "vilseföras": "vilseföra",
    "vilseförd": "vilseföra",
    "vilseförda": "vilseföra",
    "vilsefördas": "vilseföra",
    "vilseförde": "vilseföra",
    "vilsefördes": "vilseföra",
    "vilseförds": "vilseföra",
    "vilseföres": "vilseföra",
    "vilseförs": "vilseföra",
    "vilsefört": "vilseföra",
    "vilseförts": "vilseföra",
    "vilsegångens": "vilsegången",
    "vilsegånget": "vilsegången",
    "vilsegångets": "vilsegången",
    "vilsegångna": "vilsegången",
    "vilsegångnare": "vilsegången",
    "vilsegångnares": "vilsegången",
    "vilsegångnas": "vilsegången",
    "vilsegångnast": "vilsegången",
    "vilsegångnaste": "vilsegången",
    "vilsegångnastes": "vilsegången",
    "vilsegångnasts": "vilsegången",
    "vilsegångne": "vilsegången",
    "vilsegångnes": "vilsegången",
    "vilsekommens": "vilsekommen",
    "vilsekommet": "vilsekommen",
    "vilsekommets": "vilsekommen",
    "vilsekomna": "vilsekommen",
    "vilsekomnare": "vilsekommen",
    "vilsekomnares": "vilsekommen",
    "vilsekomnas": "vilsekommen",
    "vilsekomnast": "vilsekommen",
    "vilsekomnaste": "vilsekommen",
    "vilsekomnastes": "vilsekommen",
    "vilsekomnasts": "vilsekommen",
    "vilsekomne": "vilsekommen",
    "vilsekomnes": "vilsekommen",
    "vilseled": "vilseleda",
    "vilseledande": "vilseleda",
    "vilseledanden": "vilseledande",
    "vilseledandena": "vilseledande",
    "vilseledandenas": "vilseledande",
    "vilseledandens": "vilseledande",
    "vilseledandes": "vilseledande",
    "vilseledandet": "vilseledande",
    "vilseledandets": "vilseledande",
    "vilseledas": "vilseleda",
    "vilseledd": "vilseleda",
    "vilseledda": "vilseleda",
    "vilseleddas": "vilseleda",
    "vilseledde": "vilseleda",
    "vilseleddes": "vilseleda",
    "vilseledds": "vilseleda",
    "vilseleder": "vilseleda",
    "vilseledes": "vilseleda",
    "vilseleds": "vilseleda",
    "vilselett": "vilseleda",
    "vilseletts": "vilseleda",
    "vilsens": "vilsen",
    "vilset": "vilsen",
    "vilsets": "vilsen",
    "vilsna": "vilsen",
    "vilsnare": "vilsen",
    "vilsnares": "vilsen",
    "vilsnas": "vilsen",
    "vilsnast": "vilsen",
    "vilsnaste": "vilsen",
    "vilsnastes": "vilsen",
    "vilsnasts": "vilsen",
    "vilsne": "vilsen",
    "vilsnes": "vilsen",
    "vilstolar": "vilstol",
    "vilstolarna": "vilstol",
    "vilstolarnas": "vilstol",
    "vilstolars": "vilstol",
    "vilstolen": "vilstol",
    "vilstolens": "vilstol",
    "vilstols": "vilstol",
    "vilt": "vild",
    "viltbanan": "viltbana",
    "viltbanans": "viltbana",
    "viltbanas": "viltbana",
    "viltbane": "viltbana",
    "viltbanor": "viltbana",
    "viltbanorna": "viltbana",
    "viltbanornas": "viltbana",
    "viltbanors": "viltbana",
    "viltdjuren": "viltdjur",
    "viltdjurens": "viltdjur",
    "viltdjuret": "viltdjur",
    "viltdjurets": "viltdjur",
    "viltdjurs": "viltdjur",
    "viltet": "vilt",
    "viltets": "vilt",
    "vilthandlar": "vilthandlare",
    "vilthandlaren": "vilthandlare",
    "vilthandlarens": "vilthandlare",
    "vilthandlares": "vilthandlare",
    "vilthandlarna": "vilthandlare",
    "vilthandlarnas": "vilthandlare",
    "viltmålskyttes": "viltmålskytte",
    "viltmålskyttet": "viltmålskytte",
    "viltmålskyttets": "viltmålskytte",
    "viltplanteringar": "viltplantering",
    "viltplanteringarna": "viltplantering",
    "viltplanteringarnas": "viltplantering",
    "viltplanteringars": "viltplantering",
    "viltplanteringen": "viltplantering",
    "viltplanteringens": "viltplantering",
    "viltplanterings": "viltplantering",
    "vilts": "vilt",
    "viltsmaken": "viltsmak",
    "viltsmakens": "viltsmak",
    "viltsmaks": "viltsmak",
    "viltspegeln": "viltspegel",
    "viltspegelns": "viltspegel",
    "viltspegels": "viltspegel",
    "viltspeglar": "viltspegel",
    "viltspeglarna": "viltspegel",
    "viltspeglarnas": "viltspegel",
    "viltspeglars": "viltspegel",
    "viltstråken": "viltstråk",
    "viltstråkens": "viltstråk",
    "viltstråket": "viltstråk",
    "viltstråkets": "viltstråk",
    "viltstråks": "viltstråk",
    "viltstängsels": "viltstängsel",
    "viltstängslen": "viltstängsel",
    "viltstängslens": "viltstängsel",
    "viltstängslet": "viltstängsel",
    "viltstängslets": "viltstängsel",
    "viltvården": "viltvård",
    "viltvårdens": "viltvård",
    "viltvårds": "viltvård",
    "vim": "vimma",
    "vimb": "vimba",
    "vimban": "vimba",
    "vimbans": "vimba",
    "vimbas": "vimba",
    "vimbe": "vimba",
    "vimbor": "vimba",
    "vimborna": "vimba",
    "vimbornas": "vimba",
    "vimbors": "vimba",
    "vimbs": "vimba",
    "vimlade": "vimla",
    "vimlades": "vimla",
    "vimlande": "vimla",
    "vimlanden": "vimlande",
    "vimlandena": "vimlande",
    "vimlandenas": "vimlande",
    "vimlandens": "vimlande",
    "vimlandes": "vimlande",
    "vimlandet": "vimlande",
    "vimlandets": "vimlande",
    "vimlar": "vimla",
    "vimlas": "vimla",
    "vimlat": "vimla",
    "vimlats": "vimla",
    "vimlet": "vimmel",
    "vimlets": "vimmel",
    "vimman": "vimma",
    "vimmans": "vimma",
    "vimmas": "vimma",
    "vimme": "vimma",
    "vimmel": "vimla",
    "vimmelkantiga": "vimmelkantig",
    "vimmelkantigare": "vimmelkantig",
    "vimmelkantigares": "vimmelkantig",
    "vimmelkantigas": "vimmelkantig",
    "vimmelkantigast": "vimmelkantig",
    "vimmelkantigaste": "vimmelkantig",
    "vimmelkantigastes": "vimmelkantig",
    "vimmelkantigasts": "vimmelkantig",
    "vimmelkantige": "vimmelkantig",
    "vimmelkantiges": "vimmelkantig",
    "vimmelkantigheten": "vimmelkantighet",
    "vimmelkantighetens": "vimmelkantighet",
    "vimmelkantighets": "vimmelkantighet",
    "vimmelkantigs": "vimmelkantig",
    "vimmelkantigt": "vimmelkantig",
    "vimmelkantigts": "vimmelkantig",
    "vimmels": "vimmel",
    "vimmor": "vimma",
    "vimmorna": "vimma",
    "vimmornas": "vimma",
    "vimmors": "vimma",
    "vimpeln": "vimpel",
    "vimpelns": "vimpel",
    "vimpelprydda": "vimpelprydd",
    "vimpelpryddare": "vimpelprydd",
    "vimpelpryddares": "vimpelprydd",
    "vimpelpryddas": "vimpelprydd",
    "vimpelpryddast": "vimpelprydd",
    "vimpelpryddaste": "vimpelprydd",
    "vimpelpryddastes": "vimpelprydd",
    "vimpelpryddasts": "vimpelprydd",
    "vimpelprydde": "vimpelprydd",
    "vimpelpryddes": "vimpelprydd",
    "vimpelprydds": "vimpelprydd",
    "vimpelprytt": "vimpelprydd",
    "vimpelprytts": "vimpelprydd",
    "vimpels": "vimpel",
    "vimpergen": "vimperg",
    "vimpergens": "vimperg",
    "vimperger": "vimperg",
    "vimpergerna": "vimperg",
    "vimpergernas": "vimperg",
    "vimpergers": "vimperg",
    "vimpergs": "vimperg",
    "vimplade": "vimplad",
    "vimplades": "vimplad",
    "vimplads": "vimplad",
    "vimplar": "vimpel",
    "vimplarna": "vimpel",
    "vimplarnas": "vimpel",
    "vimplars": "vimpel",
    "vimplat": "vimplad",
    "vimplats": "vimplad",
    "vims": "vimsa",
    "vimsad": "vimsa",
    "vimsade": "vimsa",
    "vimsades": "vimsa",
    "vimsads": "vimsa",
    "vimsande": "vimsa",
    "vimsanden": "vimsande",
    "vimsandena": "vimsande",
    "vimsandenas": "vimsande",
    "vimsandens": "vimsande",
    "vimsandes": "vimsande",
    "vimsandet": "vimsande",
    "vimsandets": "vimsande",
    "vimsar": "vimsa",
    "vimsas": "vimsa",
    "vimsat": "vimsa",
    "vimsats": "vimsa",
    "vimsiga": "vimsig",
    "vimsigare": "vimsig",
    "vimsigares": "vimsig",
    "vimsigas": "vimsig",
    "vimsigast": "vimsig",
    "vimsigaste": "vimsig",
    "vimsigastes": "vimsig",
    "vimsigasts": "vimsig",
    "vimsige": "vimsig",
    "vimsiges": "vimsig",
    "vimsigheten": "vimsighet",
    "vimsighetens": "vimsighet",
    "vimsighets": "vimsighet",
    "vimsigs": "vimsig",
    "vimsigt": "vimsig",
    "vimsigts": "vimsig",
    "vin": "vina",
    "vinad": "vina",
    "vinade": "vina",
    "vinades": "vina",
    "vinads": "vina",
    "vinan": "vina",
    "vinande": "vina",
    "vinanden": "vinande",
    "vinandena": "vinande",
    "vinandenas": "vinande",
    "vinandens": "vinande",
    "vinandes": "vinande",
    "vinandet": "vinande",
    "vinandets": "vinande",
    "vinans": "vina",
    "vinar": "vinare",
    "vinaren": "vinare",
    "vinarens": "vinare",
    "vinares": "vinare",
    "vinarna": "vinare",
    "vinarnas": "vinare",
    "vinas": "vina",
    "vinat": "vina",
    "vinats": "vina",
    "vinbergssnäck": "vinbergssnäcka",
    "vinbergssnäckan": "vinbergssnäcka",
    "vinbergssnäckans": "vinbergssnäcka",
    "vinbergssnäckas": "vinbergssnäcka",
    "vinbergssnäcke": "vinbergssnäcka",
    "vinbergssnäckor": "vinbergssnäcka",
    "vinbergssnäckorna": "vinbergssnäcka",
    "vinbergssnäckornas": "vinbergssnäcka",
    "vinbergssnäckors": "vinbergssnäcka",
    "vinbergssnäcks": "vinbergssnäcka",
    "vinbladen": "vinblad",
    "vinbladens": "vinblad",
    "vinbladet": "vinblad",
    "vinbladets": "vinblad",
    "vinblads": "vinblad",
    "vinbranschen": "vinbransch",
    "vinbranschens": "vinbransch",
    "vinbranschs": "vinbransch",
    "vinbären": "vinbär",
    "vinbärens": "vinbär",
    "vinbäret": "vinbär",
    "vinbärets": "vinbär",
    "vinbärs": "vinbär",
    "vinbärsbusk": "vinbärsbuske",
    "vinbärsbuskar": "vinbärsbuske",
    "vinbärsbuskarna": "vinbärsbuske",
    "vinbärsbuskarnas": "vinbärsbuske",
    "vinbärsbuskars": "vinbärsbuske",
    "vinbärsbusken": "vinbärsbuske",
    "vinbärsbuskens": "vinbärsbuske",
    "vinbärsbuskes": "vinbärsbuske",
    "vinbärssaften": "vinbärssaft",
    "vinbärssaftens": "vinbärssaft",
    "vinbärssafter": "vinbärssaft",
    "vinbärssafterna": "vinbärssaft",
    "vinbärssafternas": "vinbärssaft",
    "vinbärssafters": "vinbärssaft",
    "vinbärssafts": "vinbärssaft",
    "vinbålar": "vinbål",
    "vinbålarna": "vinbål",
    "vinbålarnas": "vinbål",
    "vinbålars": "vinbål",
    "vinbålen": "vinbål",
    "vinbålens": "vinbål",
    "vinbåls": "vinbål",
    "vind": "vinda",
    "vinda": "vind",
    "vindad": "vinda",
    "vindade": "vinda",
    "vindades": "vinda",
    "vindads": "vinda",
    "vindan": "vinda",
    "vindande": "vinda",
    "vindanden": "vindande",
    "vindandena": "vindande",
    "vindandenas": "vindande",
    "vindandens": "vindande",
    "vindandes": "vindande",
    "vindandet": "vindande",
    "vindandets": "vindande",
    "vindans": "vinda",
    "vindar": "vinda",
    "vindare": "vind",
    "vindares": "vind",
    "vindarna": "vind",
    "vindarnas": "vind",
    "vindars": "vind",
    "vindas": "vinda",
    "vindast": "vind",
    "vindaste": "vind",
    "vindastes": "vind",
    "vindasts": "vind",
    "vindat": "vinda",
    "vindats": "vinda",
    "vindblom": "vindblomma",
    "vindblomman": "vindblomma",
    "vindblommans": "vindblomma",
    "vindblommas": "vindblomma",
    "vindblomme": "vindblomma",
    "vindblommor": "vindblomma",
    "vindblommorna": "vindblomma",
    "vindblommornas": "vindblomma",
    "vindblommors": "vindblomma",
    "vindbloms": "vindblomma",
    "vindbroar": "vindbro",
    "vindbroarna": "vindbro",
    "vindbroarnas": "vindbro",
    "vindbroars": "vindbro",
    "vindbron": "vindbro",
    "vindbrons": "vindbro",
    "vindbros": "vindbro",
    "vindbrygg": "vindbrygga",
    "vindbryggan": "vindbrygga",
    "vindbryggans": "vindbrygga",
    "vindbryggas": "vindbrygga",
    "vindbrygge": "vindbrygga",
    "vindbryggor": "vindbrygga",
    "vindbryggorna": "vindbrygga",
    "vindbryggornas": "vindbrygga",
    "vindbryggors": "vindbrygga",
    "vindbryggs": "vindbrygga",
    "vindbyar": "vindby",
    "vindbyarna": "vindby",
    "vindbyarnas": "vindby",
    "vindbyars": "vindby",
    "vindbyn": "vindby",
    "vindbyns": "vindby",
    "vindbys": "vindby",
    "vindbälten": "vindbälte",
    "vindbältena": "vindbälte",
    "vindbältenas": "vindbälte",
    "vindbältens": "vindbälte",
    "vindbältes": "vindbälte",
    "vindbältet": "vindbälte",
    "vindbältets": "vindbälte",
    "vindböjteln": "vindböjtel",
    "vindböjtelns": "vindböjtel",
    "vindböjtels": "vindböjtel",
    "vindböjtlar": "vindböjtel",
    "vindböjtlarna": "vindböjtel",
    "vindböjtlarnas": "vindböjtel",
    "vindböjtlars": "vindböjtel",
    "vinddrivens": "vinddriven",
    "vinddrivet": "vinddriven",
    "vinddrivets": "vinddriven",
    "vinddrivna": "vinddriven",
    "vinddrivnare": "vinddriven",
    "vinddrivnares": "vinddriven",
    "vinddrivnas": "vinddriven",
    "vinddrivnast": "vinddriven",
    "vinddrivnaste": "vinddriven",
    "vinddrivnastes": "vinddriven",
    "vinddrivnasts": "vinddriven",
    "vinddrivne": "vinddriven",
    "vinddrivnes": "vinddriven",
    "vinde": "vinda",
    "vindel": "vindla",
    "vindeln": "vindel",
    "vindelns": "vindel",
    "vindels": "vindel",
    "vindeltrapp": "vindeltrappa",
    "vindeltrappan": "vindeltrappa",
    "vindeltrappans": "vindeltrappa",
    "vindeltrappas": "vindeltrappa",
    "vindeltrappe": "vindeltrappa",
    "vindeltrappor": "vindeltrappa",
    "vindeltrapporna": "vindeltrappa",
    "vindeltrappornas": "vindeltrappa",
    "vindeltrappors": "vindeltrappa",
    "vindeltrapps": "vindeltrappa",
    "vinden": "vind",
    "vindens": "vind",
    "vindes": "vind",
    "vindfläktar": "vindfläkt",
    "vindfläktarna": "vindfläkt",
    "vindfläktarnas": "vindfläkt",
    "vindfläktars": "vindfläkt",
    "vindfläkten": "vindfläkt",
    "vindfläktens": "vindfläkt",
    "vindfläkts": "vindfläkt",
    "vindflöjeln": "vindflöjel",
    "vindflöjelns": "vindflöjel",
    "vindflöjels": "vindflöjel",
    "vindflöjlar": "vindflöjel",
    "vindflöjlarna": "vindflöjel",
    "vindflöjlarnas": "vindflöjel",
    "vindflöjlars": "vindflöjel",
    "vindfällen": "vindfälle",
    "vindfällena": "vindfälle",
    "vindfällenas": "vindfälle",
    "vindfällens": "vindfälle",
    "vindfälles": "vindfälle",
    "vindfället": "vindfälle",
    "vindfällets": "vindfälle",
    "vindfälls": "vindfälle",
    "vindfången": "vindfång",
    "vindfångens": "vindfång",
    "vindfånget": "vindfång",
    "vindfångets": "vindfång",
    "vindfångs": "vindfång",
    "vindförhållanden": "vindförhållande",
    "vindförhållandena": "vindförhållande",
    "vindförhållandenas": "vindförhållande",
    "vindförhållandens": "vindförhållande",
    "vindförhållandes": "vindförhållande",
    "vindförhållandet": "vindförhållande",
    "vindförhållandets": "vindförhållande",
    "vindhastigheten": "vindhastighet",
    "vindhastighetens": "vindhastighet",
    "vindhastigheter": "vindhastighet",
    "vindhastigheterna": "vindhastighet",
    "vindhastigheternas": "vindhastighet",
    "vindhastigheters": "vindhastighet",
    "vindhastighets": "vindhastighet",
    "vindheten": "vindhet",
    "vindhetens": "vindhet",
    "vindhets": "vindhet",
    "vindicerad": "vindicera",
    "vindicerade": "vindicera",
    "vindicerades": "vindicera",
    "vindicerads": "vindicera",
    "vindicerande": "vindicera",
    "vindiceranden": "vindicerande",
    "vindicerandena": "vindicerande",
    "vindicerandenas": "vindicerande",
    "vindicerandens": "vindicerande",
    "vindicerandes": "vindicerande",
    "vindicerandet": "vindicerande",
    "vindicerandets": "vindicerande",
    "vindicerar": "vindicera",
    "vindiceras": "vindicera",
    "vindicerat": "vindicera",
    "vindicerats": "vindicera",
    "vindicerbara": "vindicerbar",
    "vindicerbarare": "vindicerbar",
    "vindicerbarares": "vindicerbar",
    "vindicerbaras": "vindicerbar",
    "vindicerbarast": "vindicerbar",
    "vindicerbaraste": "vindicerbar",
    "vindicerbarastes": "vindicerbar",
    "vindicerbarasts": "vindicerbar",
    "vindicerbare": "vindicerbar",
    "vindicerbares": "vindicerbar",
    "vindicerbarheten": "vindicerbarhet",
    "vindicerbarhetens": "vindicerbarhet",
    "vindicerbarhets": "vindicerbarhet",
    "vindicerbars": "vindicerbar",
    "vindicerbart": "vindicerbar",
    "vindicerbarts": "vindicerbar",
    "vindiceringar": "vindicering",
    "vindiceringarna": "vindicering",
    "vindiceringarnas": "vindicering",
    "vindiceringars": "vindicering",
    "vindiceringen": "vindicering",
    "vindiceringens": "vindicering",
    "vindicerings": "vindicering",
    "vindikationen": "vindikation",
    "vindikationens": "vindikation",
    "vindikationer": "vindikation",
    "vindikationerna": "vindikation",
    "vindikationernas": "vindikation",
    "vindikationers": "vindikation",
    "vindikations": "vindikation",
    "vindilar": "vindil",
    "vindilarna": "vindil",
    "vindilarnas": "vindil",
    "vindilars": "vindil",
    "vindilen": "vindil",
    "vindilens": "vindil",
    "vindils": "vindil",
    "vindjack": "vindjacka",
    "vindjackan": "vindjacka",
    "vindjackans": "vindjacka",
    "vindjackas": "vindjacka",
    "vindjacke": "vindjacka",
    "vindjackor": "vindjacka",
    "vindjackorna": "vindjacka",
    "vindjackornas": "vindjacka",
    "vindjackors": "vindjacka",
    "vindjacks": "vindjacka",
    "vindkantringar": "vindkantring",
    "vindkantringarna": "vindkantring",
    "vindkantringarnas": "vindkantring",
    "vindkantringars": "vindkantring",
    "vindkantringen": "vindkantring",
    "vindkantringens": "vindkantring",
    "vindkantrings": "vindkantring",
    "vindkraften": "vindkraft",
    "vindkraftens": "vindkraft",
    "vindkrafts": "vindkraft",
    "vindkraftsbolagen": "vindkraftsbolag",
    "vindkraftsbolagens": "vindkraftsbolag",
    "vindkraftsbolaget": "vindkraftsbolag",
    "vindkraftsbolagets": "vindkraftsbolag",
    "vindkraftsbolags": "vindkraftsbolag",
    "vindkraftverken": "vindkraftverk",
    "vindkraftverkens": "vindkraftverk",
    "vindkraftverket": "vindkraftverk",
    "vindkraftverkets": "vindkraftverk",
    "vindkraftverks": "vindkraftverk",
    "vindlade": "vindla",
    "vindlades": "vindla",
    "vindlande": "vindla",
    "vindlanden": "vindlande",
    "vindlandena": "vindlande",
    "vindlandenas": "vindlande",
    "vindlandens": "vindlande",
    "vindlandes": "vindlande",
    "vindlandet": "vindlande",
    "vindlandets": "vindlande",
    "vindlar": "vindla",
    "vindlarna": "vindel",
    "vindlarnas": "vindel",
    "vindlars": "vindel",
    "vindlas": "vindla",
    "vindlat": "vindla",
    "vindlats": "vindla",
    "vindlingar": "vindling",
    "vindlingarna": "vindling",
    "vindlingarnas": "vindling",
    "vindlingars": "vindling",
    "vindlingen": "vindling",
    "vindlingens": "vindling",
    "vindlings": "vindling",
    "vindmätar": "vindmätare",
    "vindmätaren": "vindmätare",
    "vindmätarens": "vindmätare",
    "vindmätares": "vindmätare",
    "vindmätarna": "vindmätare",
    "vindmätarnas": "vindmätare",
    "vindmätningar": "vindmätning",
    "vindmätningarna": "vindmätning",
    "vindmätningarnas": "vindmätning",
    "vindmätningars": "vindmätning",
    "vindmätningen": "vindmätning",
    "vindmätningens": "vindmätning",
    "vindmätnings": "vindmätning",
    "vindmätningsinstrumenten": "vindmätningsinstrument",
    "vindmätningsinstrumentens": "vindmätningsinstrument",
    "vindmätningsinstrumentet": "vindmätningsinstrument",
    "vindmätningsinstrumentets": "vindmätningsinstrument",
    "vindmätningsinstruments": "vindmätningsinstrument",
    "vindor": "vinda",
    "vindorna": "vinda",
    "vindornas": "vinda",
    "vindors": "vinda",
    "vindpinade": "vindpinad",
    "vindpinades": "vindpinad",
    "vindpinads": "vindpinad",
    "vindpinat": "vindpinad",
    "vindpinats": "vindpinad",
    "vindpollinerad": "vindpollinera",
    "vindpollinerade": "vindpollinera",
    "vindpollinerades": "vindpollinera",
    "vindpollinerads": "vindpollinera",
    "vindpollinerande": "vindpollinera",
    "vindpollineranden": "vindpollinerande",
    "vindpollinerandena": "vindpollinerande",
    "vindpollinerandenas": "vindpollinerande",
    "vindpollinerandens": "vindpollinerande",
    "vindpollinerandes": "vindpollinerande",
    "vindpollinerandet": "vindpollinerande",
    "vindpollinerandets": "vindpollinerande",
    "vindpollinerar": "vindpollinera",
    "vindpollineras": "vindpollinera",
    "vindpollinerat": "vindpollinera",
    "vindpollinerats": "vindpollinera",
    "vindpollinerbara": "vindpollinerbar",
    "vindpollinerbarare": "vindpollinerbar",
    "vindpollinerbarares": "vindpollinerbar",
    "vindpollinerbaras": "vindpollinerbar",
    "vindpollinerbarast": "vindpollinerbar",
    "vindpollinerbaraste": "vindpollinerbar",
    "vindpollinerbarastes": "vindpollinerbar",
    "vindpollinerbarasts": "vindpollinerbar",
    "vindpollinerbare": "vindpollinerbar",
    "vindpollinerbares": "vindpollinerbar",
    "vindpollinerbarheten": "vindpollinerbarhet",
    "vindpollinerbarhetens": "vindpollinerbarhet",
    "vindpollinerbarhets": "vindpollinerbarhet",
    "vindpollinerbars": "vindpollinerbar",
    "vindpollinerbart": "vindpollinerbar",
    "vindpollinerbarts": "vindpollinerbar",
    "vindpollineringar": "vindpollinering",
    "vindpollineringarna": "vindpollinering",
    "vindpollineringarnas": "vindpollinering",
    "vindpollineringars": "vindpollinering",
    "vindpollineringen": "vindpollinering",
    "vindpollineringens": "vindpollinering",
    "vindpollinerings": "vindpollinering",
    "vindpustar": "vindpust",
    "vindpustarna": "vindpust",
    "vindpustarnas": "vindpust",
    "vindpustars": "vindpust",
    "vindpusten": "vindpust",
    "vindpustens": "vindpust",
    "vindpusts": "vindpust",
    "vindriktningar": "vindriktning",
    "vindriktningarna": "vindriktning",
    "vindriktningarnas": "vindriktning",
    "vindriktningars": "vindriktning",
    "vindriktningen": "vindriktning",
    "vindriktningens": "vindriktning",
    "vindriktnings": "vindriktning",
    "vindrosen": "vindros",
    "vindrosens": "vindros",
    "vindrosor": "vindros",
    "vindrosorna": "vindros",
    "vindrosornas": "vindros",
    "vindrosors": "vindros",
    "vindrufset": "vindrufs",
    "vindrufsets": "vindrufs",
    "vindrutan": "vindruta",
    "vindrutans": "vindruta",
    "vindrutas": "vindruta",
    "vindrute": "vindruta",
    "vindruteskydden": "vindruteskydd",
    "vindruteskyddens": "vindruteskydd",
    "vindruteskyddet": "vindruteskydd",
    "vindruteskyddets": "vindruteskydd",
    "vindruteskydds": "vindruteskydd",
    "vindrutespolar": "vindrutespolare",
    "vindrutespolaren": "vindrutespolare",
    "vindrutespolarens": "vindrutespolare",
    "vindrutespolares": "vindrutespolare",
    "vindrutespolarna": "vindrutespolare",
    "vindrutespolarnas": "vindrutespolare",
    "vindrutetorkar": "vindrutetorkare",
    "vindrutetorkaren": "vindrutetorkare",
    "vindrutetorkarens": "vindrutetorkare",
    "vindrutetorkares": "vindrutetorkare",
    "vindrutetorkarna": "vindrutetorkare",
    "vindrutetorkarnas": "vindrutetorkare",
    "vindrutor": "vindruta",
    "vindrutorna": "vindruta",
    "vindrutornas": "vindruta",
    "vindrutors": "vindruta",
    "vindruv": "vindruva",
    "vindruvan": "vindruva",
    "vindruvans": "vindruva",
    "vindruvas": "vindruva",
    "vindruve": "vindruva",
    "vindruvor": "vindruva",
    "vindruvorna": "vindruva",
    "vindruvornas": "vindruva",
    "vindruvors": "vindruva",
    "vindruvs": "vindruva",
    "vinds": "vinda",
    "vindsbranden": "vindsbrand",
    "vindsbrandens": "vindsbrand",
    "vindsbrands": "vindsbrand",
    "vindsbränder": "vindsbrand",
    "vindsbränderna": "vindsbrand",
    "vindsbrändernas": "vindsbrand",
    "vindsbränders": "vindsbrand",
    "vindsidan": "vindsida",
    "vindsidans": "vindsida",
    "vindsidas": "vindsida",
    "vindside": "vindsida",
    "vindsides": "vindsida",
    "vindsidor": "vindsida",
    "vindsidorna": "vindsida",
    "vindsidornas": "vindsida",
    "vindsidors": "vindsida",
    "vindskal": "vindskala",
    "vindskalan": "vindskala",
    "vindskalans": "vindskala",
    "vindskalas": "vindskala",
    "vindskale": "vindskala",
    "vindskalor": "vindskala",
    "vindskalorna": "vindskala",
    "vindskalornas": "vindskala",
    "vindskalors": "vindskala",
    "vindskals": "vindskala",
    "vindskammar": "vindskammare",
    "vindskammaren": "vindskammare",
    "vindskammarens": "vindskammare",
    "vindskammares": "vindskammare",
    "vindskamrar": "vindskammare",
    "vindskamrarna": "vindskammare",
    "vindskamrarnas": "vindskammare",
    "vindskamrars": "vindskammare",
    "vindskid": "vindskida",
    "vindskidan": "vindskida",
    "vindskidans": "vindskida",
    "vindskidas": "vindskida",
    "vindskide": "vindskida",
    "vindskidor": "vindskida",
    "vindskidorna": "vindskida",
    "vindskidornas": "vindskida",
    "vindskidors": "vindskida",
    "vindskids": "vindskida",
    "vindskiften": "vindskifte",
    "vindskiftena": "vindskifte",
    "vindskiftenas": "vindskifte",
    "vindskiftens": "vindskifte",
    "vindskiftes": "vindskifte",
    "vindskiftet": "vindskifte",
    "vindskiftets": "vindskifte",
    "vindskivan": "vindskiva",
    "vindskivans": "vindskiva",
    "vindskivas": "vindskiva",
    "vindskive": "vindskiva",
    "vindskivor": "vindskiva",
    "vindskivorna": "vindskiva",
    "vindskivornas": "vindskiva",
    "vindskivors": "vindskiva",
    "vindskontoren": "vindskontor",
    "vindskontorens": "vindskontor",
    "vindskontoret": "vindskontor",
    "vindskontorets": "vindskontor",
    "vindskontors": "vindskontor",
    "vindskup": "vindskupa",
    "vindskupan": "vindskupa",
    "vindskupans": "vindskupa",
    "vindskupas": "vindskupa",
    "vindskupe": "vindskupa",
    "vindskupor": "vindskupa",
    "vindskuporna": "vindskupa",
    "vindskupornas": "vindskupa",
    "vindskupors": "vindskupa",
    "vindskups": "vindskupa",
    "vindskyddade": "vindskyddad",
    "vindskyddades": "vindskyddad",
    "vindskyddads": "vindskyddad",
    "vindskyddat": "vindskyddad",
    "vindskyddats": "vindskyddad",
    "vindskydden": "vindskydd",
    "vindskyddens": "vindskydd",
    "vindskyddet": "vindskydd",
    "vindskyddets": "vindskydd",
    "vindskydds": "vindskydd",
    "vindskärmar": "vindskärm",
    "vindskärmarna": "vindskärm",
    "vindskärmarnas": "vindskärm",
    "vindskärmars": "vindskärm",
    "vindskärmen": "vindskärm",
    "vindskärmens": "vindskärm",
    "vindskärms": "vindskärm",
    "vindsopade": "vindsopad",
    "vindsopades": "vindsopad",
    "vindsopads": "vindsopad",
    "vindsopat": "vindsopad",
    "vindsopats": "vindsopad",
    "vindspelen": "vindspel",
    "vindspelens": "vindspel",
    "vindspelet": "vindspel",
    "vindspelets": "vindspel",
    "vindspels": "vindspel",
    "vindstillan": "vindstilla",
    "vindstillans": "vindstilla",
    "vindstillas": "vindstilla",
    "vindstillor": "vindstilla",
    "vindstillorna": "vindstilla",
    "vindstillornas": "vindstilla",
    "vindstillors": "vindstilla",
    "vindstrapp": "vindstrappa",
    "vindstrappan": "vindstrappa",
    "vindstrappans": "vindstrappa",
    "vindstrappas": "vindstrappa",
    "vindstrappe": "vindstrappa",
    "vindstrappor": "vindstrappa",
    "vindstrapporna": "vindstrappa",
    "vindstrappornas": "vindstrappa",
    "vindstrappors": "vindstrappa",
    "vindstrapps": "vindstrappa",
    "vindstyrkan": "vindstyrka",
    "vindstyrkans": "vindstyrka",
    "vindstyrkas": "vindstyrka",
    "vindstyrke": "vindstyrka",
    "vindstyrkor": "vindstyrka",
    "vindstyrkorna": "vindstyrka",
    "vindstyrkornas": "vindstyrka",
    "vindstyrkors": "vindstyrka",
    "vindstötar": "vindstöt",
    "vindstötarna": "vindstöt",
    "vindstötarnas": "vindstöt",
    "vindstötars": "vindstöt",
    "vindstöten": "vindstöt",
    "vindstötens": "vindstöt",
    "vindstöts": "vindstöt",
    "vindsurf": "vindsurfa",
    "vindsurfad": "vindsurfa",
    "vindsurfade": "vindsurfa",
    "vindsurfades": "vindsurfa",
    "vindsurfads": "vindsurfa",
    "vindsurfande": "vindsurfa",
    "vindsurfanden": "vindsurfande",
    "vindsurfandena": "vindsurfande",
    "vindsurfandenas": "vindsurfande",
    "vindsurfandens": "vindsurfande",
    "vindsurfandes": "vindsurfande",
    "vindsurfandet": "vindsurfande",
    "vindsurfandets": "vindsurfande",
    "vindsurfar": "vindsurfa",
    "vindsurfas": "vindsurfa",
    "vindsurfat": "vindsurfa",
    "vindsurfats": "vindsurfa",
    "vindsutrymmen": "vindsutrymme",
    "vindsutrymmena": "vindsutrymme",
    "vindsutrymmenas": "vindsutrymme",
    "vindsutrymmens": "vindsutrymme",
    "vindsutrymmes": "vindsutrymme",
    "vindsutrymmet": "vindsutrymme",
    "vindsutrymmets": "vindsutrymme",
    "vindtunlar": "vindtunnel",
    "vindtunlarna": "vindtunnel",
    "vindtunlarnas": "vindtunnel",
    "vindtunlars": "vindtunnel",
    "vindtunneln": "vindtunnel",
    "vindtunnelns": "vindtunnel",
    "vindtunnels": "vindtunnel",
    "vindtunnlar": "vindtunnel",
    "vindtunnlarna": "vindtunnel",
    "vindtunnlarnas": "vindtunnel",
    "vindtunnlars": "vindtunnel",
    "vindtyget": "vindtyg",
    "vindtygets": "vindtyg",
    "vindtygs": "vindtyg",
    "vindtygsjack": "vindtygsjacka",
    "vindtygsjackan": "vindtygsjacka",
    "vindtygsjackans": "vindtygsjacka",
    "vindtygsjackas": "vindtygsjacka",
    "vindtygsjacke": "vindtygsjacka",
    "vindtygsjackor": "vindtygsjacka",
    "vindtygsjackorna": "vindtygsjacka",
    "vindtygsjackornas": "vindtygsjacka",
    "vindtygsjackors": "vindtygsjacka",
    "vindtygsjacks": "vindtygsjacka",
    "vindtäta": "vindtät",
    "vindtätare": "vindtät",
    "vindtätares": "vindtät",
    "vindtätas": "vindtät",
    "vindtätast": "vindtät",
    "vindtätaste": "vindtät",
    "vindtätastes": "vindtät",
    "vindtätasts": "vindtät",
    "vindtäte": "vindtät",
    "vindtätes": "vindtät",
    "vindtäts": "vindtät",
    "vindtätt": "vindtät",
    "vindtätts": "vindtät",
    "vindvridningar": "vindvridning",
    "vindvridningarna": "vindvridning",
    "vindvridningarnas": "vindvridning",
    "vindvridningars": "vindvridning",
    "vindvridningen": "vindvridning",
    "vindvridningens": "vindvridning",
    "vindvridnings": "vindvridning",
    "vindäggen": "vindägg",
    "vindäggens": "vindägg",
    "vindägget": "vindägg",
    "vindäggets": "vindägg",
    "vindäggs": "vindägg",
    "vindändringar": "vindändring",
    "vindändringarna": "vindändring",
    "vindändringarnas": "vindändring",
    "vindändringars": "vindändring",
    "vindändringen": "vindändring",
    "vindändringens": "vindändring",
    "vindändrings": "vindändring",
    "vindögas": "vindöga",
    "vindögat": "vindöga",
    "vindögats": "vindöga",
    "vindögda": "vindögd",
    "vindögdare": "vindögd",
    "vindögdares": "vindögd",
    "vindögdas": "vindögd",
    "vindögdast": "vindögd",
    "vindögdaste": "vindögd",
    "vindögdastes": "vindögd",
    "vindögdasts": "vindögd",
    "vindögde": "vindögd",
    "vindögdes": "vindögd",
    "vindögdheten": "vindögdhet",
    "vindögdhetens": "vindögdhet",
    "vindögdhets": "vindögdhet",
    "vindögds": "vindögd",
    "vindögon": "vindöga",
    "vindögonen": "vindöga",
    "vindögonens": "vindöga",
    "vindögons": "vindöga",
    "vindögt": "vindögd",
    "vindögts": "vindögd",
    "vine": "vina",
    "viner": "vina",
    "vinerier": "vineri",
    "vinerierna": "vineri",
    "vineriernas": "vineri",
    "vineriers": "vineri",
    "vineriet": "vineri",
    "vineriets": "vineri",
    "vineris": "vineri",
    "vinerit": "vineri",
    "vinerits": "vineri",
    "vinerna": "vin",
    "vinernas": "vin",
    "viners": "vin",
    "vines": "vina",
    "vinet": "vin",
    "vinets": "vin",
    "vinflask": "vinflaska",
    "vinflaskan": "vinflaska",
    "vinflaskans": "vinflaska",
    "vinflaskas": "vinflaska",
    "vinflaske": "vinflaska",
    "vinflaskor": "vinflaska",
    "vinflaskorna": "vinflaska",
    "vinflaskornas": "vinflaska",
    "vinflaskors": "vinflaska",
    "vinfärgade": "vinfärgad",
    "vinfärgades": "vinfärgad",
    "vinfärgads": "vinfärgad",
    "vinfärgat": "vinfärgad",
    "vinfärgats": "vinfärgad",
    "ving": "vinge",
    "vingade": "vingad",
    "vingades": "vingad",
    "vingads": "vingad",
    "vingar": "vinge",
    "vingarna": "vinge",
    "vingarnas": "vinge",
    "vingars": "vinge",
    "vingat": "vingad",
    "vingats": "vingad",
    "vingbredden": "vingbredd",
    "vingbreddens": "vingbredd",
    "vingbredder": "vingbredd",
    "vingbredderna": "vingbredd",
    "vingbreddernas": "vingbredd",
    "vingbredders": "vingbredd",
    "vingbredds": "vingbredd",
    "vingbruset": "vingbrus",
    "vingbrusets": "vingbrus",
    "vingbrutens": "vingbruten",
    "vingbrutet": "vingbruten",
    "vingbrutets": "vingbruten",
    "vingbrutna": "vingbruten",
    "vingbrutnare": "vingbruten",
    "vingbrutnares": "vingbruten",
    "vingbrutnas": "vingbruten",
    "vingbrutnast": "vingbruten",
    "vingbrutnaste": "vingbruten",
    "vingbrutnastes": "vingbruten",
    "vingbrutnasts": "vingbruten",
    "vingbrutne": "vingbruten",
    "vingbrutnes": "vingbruten",
    "vingel": "vingla",
    "vingelpell": "vingelpelle",
    "vingelpellar": "vingelpelle",
    "vingelpellarna": "vingelpelle",
    "vingelpellarnas": "vingelpelle",
    "vingelpellars": "vingelpelle",
    "vingelpellen": "vingelpelle",
    "vingelpellens": "vingelpelle",
    "vingelpelles": "vingelpelle",
    "vingelpells": "vingelpelle",
    "vingels": "vingel",
    "vingen": "vinge",
    "vingens": "vinge",
    "vinges": "vinge",
    "vingfrukten": "vingfrukt",
    "vingfruktens": "vingfrukt",
    "vingfrukter": "vingfrukt",
    "vingfrukterna": "vingfrukt",
    "vingfrukternas": "vingfrukt",
    "vingfrukters": "vingfrukt",
    "vingfrukts": "vingfrukt",
    "vingglidningar": "vingglidning",
    "vingglidningarna": "vingglidning",
    "vingglidningarnas": "vingglidning",
    "vingglidningars": "vingglidning",
    "vingglidningen": "vingglidning",
    "vingglidningens": "vingglidning",
    "vingglidnings": "vingglidning",
    "vingklaffar": "vingklaff",
    "vingklaffarna": "vingklaff",
    "vingklaffarnas": "vingklaff",
    "vingklaffars": "vingklaff",
    "vingklaffen": "vingklaff",
    "vingklaffens": "vingklaff",
    "vingklaffs": "vingklaff",
    "vingklipp": "vingklippa",
    "vingklippande": "vingklippa",
    "vingklippanden": "vingklippande",
    "vingklippandena": "vingklippande",
    "vingklippandenas": "vingklippande",
    "vingklippandens": "vingklippande",
    "vingklippandes": "vingklippande",
    "vingklippandet": "vingklippande",
    "vingklippandets": "vingklippande",
    "vingklippas": "vingklippa",
    "vingklipper": "vingklippa",
    "vingklippes": "vingklippa",
    "vingklipps": "vingklippa",
    "vingklippt": "vingklippa",
    "vingklippta": "vingklippa",
    "vingklipptas": "vingklippa",
    "vingklippte": "vingklippa",
    "vingklipptes": "vingklippa",
    "vingklippts": "vingklippa",
    "vinglade": "vingla",
    "vinglades": "vingla",
    "vinglande": "vingla",
    "vinglanden": "vinglande",
    "vinglandena": "vinglande",
    "vinglandenas": "vinglande",
    "vinglandens": "vinglande",
    "vinglandes": "vinglande",
    "vinglandet": "vinglande",
    "vinglandets": "vinglande",
    "vinglar": "vingla",
    "vinglas": "vingla",
    "vinglasen": "vinglas",
    "vinglasens": "vinglas",
    "vinglaset": "vinglas",
    "vinglasets": "vinglas",
    "vinglat": "vingla",
    "vinglats": "vingla",
    "vinglet": "vingel",
    "vinglets": "vingel",
    "vingliga": "vinglig",
    "vingligare": "vinglig",
    "vingligares": "vinglig",
    "vingligas": "vinglig",
    "vingligast": "vinglig",
    "vingligaste": "vinglig",
    "vingligastes": "vinglig",
    "vingligasts": "vinglig",
    "vinglige": "vinglig",
    "vingliges": "vinglig",
    "vingligheten": "vinglighet",
    "vinglighetens": "vinglighet",
    "vinglighets": "vinglighet",
    "vingligs": "vinglig",
    "vingligt": "vinglig",
    "vingligts": "vinglig",
    "vinglösa": "vinglös",
    "vinglösare": "vinglös",
    "vinglösares": "vinglös",
    "vinglösas": "vinglös",
    "vinglösast": "vinglös",
    "vinglösaste": "vinglös",
    "vinglösastes": "vinglös",
    "vinglösasts": "vinglös",
    "vinglöse": "vinglös",
    "vinglöses": "vinglös",
    "vinglösheten": "vinglöshet",
    "vinglöshetens": "vinglöshet",
    "vinglöshets": "vinglöshet",
    "vinglöst": "vinglös",
    "vinglösts": "vinglös",
    "vingmannen": "vingman",
    "vingmannens": "vingman",
    "vingmans": "vingman",
    "vingmuttern": "vingmutter",
    "vingmutterns": "vingmutter",
    "vingmutters": "vingmutter",
    "vingmuttrar": "vingmutter",
    "vingmuttrarna": "vingmutter",
    "vingmuttrarnas": "vingmutter",
    "vingmuttrars": "vingmutter",
    "vingmän": "vingman",
    "vingmännen": "vingman",
    "vingmännens": "vingman",
    "vingmäns": "vingman",
    "vingpenn": "vingpenna",
    "vingpennan": "vingpenna",
    "vingpennans": "vingpenna",
    "vingpennas": "vingpenna",
    "vingpenne": "vingpenna",
    "vingpennor": "vingpenna",
    "vingpennorna": "vingpenna",
    "vingpennornas": "vingpenna",
    "vingpennors": "vingpenna",
    "vingpenns": "vingpenna",
    "vingplogar": "vingplog",
    "vingplogarna": "vingplog",
    "vingplogarnas": "vingplog",
    "vingplogars": "vingplog",
    "vingplogen": "vingplog",
    "vingplogens": "vingplog",
    "vingplogs": "vingplog",
    "vings": "vinge",
    "vingslagen": "vingslag",
    "vingslagens": "vingslag",
    "vingslaget": "vingslag",
    "vingslagets": "vingslag",
    "vingslags": "vingslag",
    "vingspegeln": "vingspegel",
    "vingspegelns": "vingspegel",
    "vingspegels": "vingspegel",
    "vingspeglar": "vingspegel",
    "vingspeglarna": "vingspegel",
    "vingspeglarnas": "vingspegel",
    "vingspeglars": "vingspegel",
    "vingspetsar": "vingspets",
    "vingspetsarna": "vingspets",
    "vingspetsarnas": "vingspets",
    "vingspetsars": "vingspets",
    "vingspetsen": "vingspets",
    "vingspetsens": "vingspets",
    "vingteckningar": "vingteckning",
    "vingteckningarna": "vingteckning",
    "vingteckningarnas": "vingteckning",
    "vingteckningars": "vingteckning",
    "vingteckningen": "vingteckning",
    "vingteckningens": "vingteckning",
    "vingtecknings": "vingteckning",
    "vingteckningvävningsmönsterna": "vingteckningvävningsmönster",
    "vingteckningvävningsmönsternas": "vingteckningvävningsmönster",
    "vingteckningvävningsmönsters": "vingteckningvävningsmönster",
    "vingteckningvävningsmönstren": "vingteckningvävningsmönster",
    "vingteckningvävningsmönstrens": "vingteckningvävningsmönster",
    "vingteckningvävningsmönstret": "vingteckningvävningsmönster",
    "vingteckningvävningsmönstrets": "vingteckningvävningsmönster",
    "vingtäckar": "vingtäckare",
    "vingtäckaren": "vingtäckare",
    "vingtäckarens": "vingtäckare",
    "vingtäckares": "vingtäckare",
    "vingtäckarna": "vingtäckare",
    "vingtäckarnas": "vingtäckare",
    "vingudar": "vingud",
    "vingudarna": "vingud",
    "vingudarnas": "vingud",
    "vingudars": "vingud",
    "vinguden": "vingud",
    "vingudens": "vingud",
    "vinguds": "vingud",
    "vingummin": "vingummi",
    "vingummina": "vingummi",
    "vingumminas": "vingummi",
    "vingummins": "vingummi",
    "vingummis": "vingummi",
    "vingummit": "vingummi",
    "vingummits": "vingummi",
    "vingårdar": "vingård",
    "vingårdarna": "vingård",
    "vingårdarnas": "vingård",
    "vingårdars": "vingård",
    "vingården": "vingård",
    "vingårdens": "vingård",
    "vingårds": "vingård",
    "vingårdsarbetar": "vingårdsarbetare",
    "vingårdsarbetaren": "vingårdsarbetare",
    "vingårdsarbetarens": "vingårdsarbetare",
    "vingårdsarbetares": "vingårdsarbetare",
    "vingårdsarbetarna": "vingårdsarbetare",
    "vingårdsarbetarnas": "vingårdsarbetare",
    "vingårdsmannen": "vingårdsman",
    "vingårdsmannens": "vingårdsman",
    "vingårdsmans": "vingårdsman",
    "vingårdsmän": "vingårdsman",
    "vingårdsmännen": "vingårdsman",
    "vingårdsmännens": "vingårdsman",
    "vingårdsmäns": "vingårdsman",
    "vingöras": "vingöra",
    "vingörat": "vingöra",
    "vingörats": "vingöra",
    "vingöron": "vingöra",
    "vingöronen": "vingöra",
    "vingöronens": "vingöra",
    "vingörons": "vingöra",
    "vinit": "vina",
    "vinits": "vina",
    "vinjetten": "vinjett",
    "vinjettens": "vinjett",
    "vinjetter": "vinjett",
    "vinjetterna": "vinjett",
    "vinjetternas": "vinjett",
    "vinjetters": "vinjett",
    "vinjetts": "vinjett",
    "vinjästen": "vinjäst",
    "vinjästens": "vinjäst",
    "vinjästs": "vinjäst",
    "vink": "vinka",
    "vinkad": "vinka",
    "vinkade": "vinka",
    "vinkades": "vinka",
    "vinkads": "vinka",
    "vinkande": "vinka",
    "vinkanden": "vinkande",
    "vinkandena": "vinkande",
    "vinkandenas": "vinkande",
    "vinkandens": "vinkande",
    "vinkandes": "vinkande",
    "vinkandet": "vinkande",
    "vinkandets": "vinkande",
    "vinkar": "vinka",
    "vinkaraffen": "vinkaraff",
    "vinkaraffens": "vinkaraff",
    "vinkaraffer": "vinkaraff",
    "vinkarafferna": "vinkaraff",
    "vinkaraffernas": "vinkaraff",
    "vinkaraffers": "vinkaraff",
    "vinkaraffs": "vinkaraff",
    "vinkarna": "vink",
    "vinkarnas": "vink",
    "vinkars": "vink",
    "vinkas": "vinka",
    "vinkat": "vinka",
    "vinkats": "vinka",
    "vinkel": "vinkla",
    "vinkelaccelerationen": "vinkelacceleration",
    "vinkelaccelerationens": "vinkelacceleration",
    "vinkelaccelerationer": "vinkelacceleration",
    "vinkelaccelerationerna": "vinkelacceleration",
    "vinkelaccelerationernas": "vinkelacceleration",
    "vinkelaccelerationers": "vinkelacceleration",
    "vinkelaccelerations": "vinkelacceleration",
    "vinkelarmar": "vinkelarm",
    "vinkelarmarna": "vinkelarm",
    "vinkelarmarnas": "vinkelarm",
    "vinkelarmars": "vinkelarm",
    "vinkelarmen": "vinkelarm",
    "vinkelarmens": "vinkelarm",
    "vinkelarms": "vinkelarm",
    "vinkelavstånden": "vinkelavstånd",
    "vinkelavståndens": "vinkelavstånd",
    "vinkelavståndet": "vinkelavstånd",
    "vinkelavståndets": "vinkelavstånd",
    "vinkelavstånds": "vinkelavstånd",
    "vinkelbenen": "vinkelben",
    "vinkelbenens": "vinkelben",
    "vinkelbenet": "vinkelben",
    "vinkelbenets": "vinkelben",
    "vinkelbens": "vinkelben",
    "vinkelbeslagen": "vinkelbeslag",
    "vinkelbeslagens": "vinkelbeslag",
    "vinkelbeslaget": "vinkelbeslag",
    "vinkelbeslagets": "vinkelbeslag",
    "vinkelbeslags": "vinkelbeslag",
    "vinkelborrar": "vinkelborr",
    "vinkelborrarna": "vinkelborr",
    "vinkelborrarnas": "vinkelborr",
    "vinkelborrars": "vinkelborr",
    "vinkelborren": "vinkelborr",
    "vinkelborrens": "vinkelborr",
    "vinkelborret": "vinkelborr",
    "vinkelborrets": "vinkelborr",
    "vinkelborrs": "vinkelborr",
    "vinkelformade": "vinkelformad",
    "vinkelformades": "vinkelformad",
    "vinkelformads": "vinkelformad",
    "vinkelformat": "vinkelformad",
    "vinkelformats": "vinkelformad",
    "vinkelhakar": "vinkelhake",
    "vinkelhakarna": "vinkelhake",
    "vinkelhakarnas": "vinkelhake",
    "vinkelhakars": "vinkelhake",
    "vinkelhaken": "vinkelhake",
    "vinkelhakens": "vinkelhake",
    "vinkelhakes": "vinkelhake",
    "vinkelhastigheten": "vinkelhastighet",
    "vinkelhastighetens": "vinkelhastighet",
    "vinkelhastigheter": "vinkelhastighet",
    "vinkelhastigheterna": "vinkelhastighet",
    "vinkelhastigheternas": "vinkelhastighet",
    "vinkelhastigheters": "vinkelhastighet",
    "vinkelhastighets": "vinkelhastighet",
    "vinkelhusen": "vinkelhus",
    "vinkelhusens": "vinkelhus",
    "vinkelhuset": "vinkelhus",
    "vinkelhusets": "vinkelhus",
    "vinkeljärnen": "vinkeljärn",
    "vinkeljärnens": "vinkeljärn",
    "vinkeljärnet": "vinkeljärn",
    "vinkeljärnets": "vinkeljärn",
    "vinkeljärns": "vinkeljärn",
    "vinkelknäet": "vinkelknä",
    "vinkelknäets": "vinkelknä",
    "vinkelknän": "vinkelknä",
    "vinkelknäna": "vinkelknä",
    "vinkelknänas": "vinkelknä",
    "vinkelknäns": "vinkelknä",
    "vinkelknäs": "vinkelknä",
    "vinkelknät": "vinkelknä",
    "vinkelknäts": "vinkelknä",
    "vinkellinjalen": "vinkellinjal",
    "vinkellinjalens": "vinkellinjal",
    "vinkellinjaler": "vinkellinjal",
    "vinkellinjalerna": "vinkellinjal",
    "vinkellinjalernas": "vinkellinjal",
    "vinkellinjalers": "vinkellinjal",
    "vinkellinjals": "vinkellinjal",
    "vinkelmåtten": "vinkelmått",
    "vinkelmåttens": "vinkelmått",
    "vinkelmåttet": "vinkelmått",
    "vinkelmåttets": "vinkelmått",
    "vinkelmåtts": "vinkelmått",
    "vinkeln": "vinkel",
    "vinkelns": "vinkel",
    "vinkelpredikanten": "vinkelpredikant",
    "vinkelpredikantens": "vinkelpredikant",
    "vinkelpredikanter": "vinkelpredikant",
    "vinkelpredikanterna": "vinkelpredikant",
    "vinkelpredikanternas": "vinkelpredikant",
    "vinkelpredikanters": "vinkelpredikant",
    "vinkelpredikants": "vinkelpredikant",
    "vinkelrollern": "vinkelroller",
    "vinkelrollerns": "vinkelroller",
    "vinkelrollers": "vinkelroller",
    "vinkelrollrar": "vinkelroller",
    "vinkelrollrarna": "vinkelroller",
    "vinkelrollrarnas": "vinkelroller",
    "vinkelrollrars": "vinkelroller",
    "vinkelräta": "vinkelrät",
    "vinkelrätare": "vinkelrät",
    "vinkelrätares": "vinkelrät",
    "vinkelrätas": "vinkelrät",
    "vinkelrätast": "vinkelrät",
    "vinkelrätaste": "vinkelrät",
    "vinkelrätastes": "vinkelrät",
    "vinkelrätasts": "vinkelrät",
    "vinkelräte": "vinkelrät",
    "vinkelrätes": "vinkelrät",
    "vinkelräts": "vinkelrät",
    "vinkelrätt": "vinkelrät",
    "vinkelrätts": "vinkelrät",
    "vinkels": "vinkel",
    "vinkelskillnaden": "vinkelskillnad",
    "vinkelskillnadens": "vinkelskillnad",
    "vinkelskillnader": "vinkelskillnad",
    "vinkelskillnaderna": "vinkelskillnad",
    "vinkelskillnadernas": "vinkelskillnad",
    "vinkelskillnaders": "vinkelskillnad",
    "vinkelskillnads": "vinkelskillnad",
    "vinkelslipar": "vinkelslip",
    "vinkelsliparna": "vinkelslip",
    "vinkelsliparnas": "vinkelslip",
    "vinkelslipars": "vinkelslip",
    "vinkelslipen": "vinkelslip",
    "vinkelslipens": "vinkelslip",
    "vinkelslips": "vinkelslip",
    "vinkelspetsar": "vinkelspets",
    "vinkelspetsarna": "vinkelspets",
    "vinkelspetsarnas": "vinkelspets",
    "vinkelspetsars": "vinkelspets",
    "vinkelspetsen": "vinkelspets",
    "vinkelspetsens": "vinkelspets",
    "vinkelsumman": "vinkelsumma",
    "vinkelsummans": "vinkelsumma",
    "vinkelsummas": "vinkelsumma",
    "vinkelsumme": "vinkelsumma",
    "vinkelsummor": "vinkelsumma",
    "vinkelsummorna": "vinkelsumma",
    "vinkelsummornas": "vinkelsumma",
    "vinkelsummors": "vinkelsumma",
    "vinken": "vink",
    "vinkens": "vink",
    "vinklad": "vinkla",
    "vinklade": "vinkla",
    "vinklades": "vinkla",
    "vinklads": "vinkla",
    "vinklande": "vinkla",
    "vinklanden": "vinklande",
    "vinklandena": "vinklande",
    "vinklandenas": "vinklande",
    "vinklandens": "vinklande",
    "vinklandes": "vinklande",
    "vinklandet": "vinklande",
    "vinklandets": "vinklande",
    "vinklar": "vinkla",
    "vinklarna": "vinkel",
    "vinklarnas": "vinkel",
    "vinklars": "vinkel",
    "vinklas": "vinkla",
    "vinklat": "vinkla",
    "vinklats": "vinkla",
    "vinklingar": "vinkling",
    "vinklingarna": "vinkling",
    "vinklingarnas": "vinkling",
    "vinklingars": "vinkling",
    "vinklingen": "vinkling",
    "vinklingens": "vinkling",
    "vinklings": "vinkling",
    "vinkonsumtionen": "vinkonsumtion",
    "vinkonsumtionens": "vinkonsumtion",
    "vinkonsumtions": "vinkonsumtion",
    "vinkorkar": "vinkork",
    "vinkorkarna": "vinkork",
    "vinkorkarnas": "vinkork",
    "vinkorkars": "vinkork",
    "vinkorken": "vinkork",
    "vinkorkens": "vinkork",
    "vinkorks": "vinkork",
    "vinks": "vink",
    "vinkännar": "vinkännare",
    "vinkännaren": "vinkännare",
    "vinkännarens": "vinkännare",
    "vinkännares": "vinkännare",
    "vinkännarna": "vinkännare",
    "vinkännarnas": "vinkännare",
    "vinlandet": "vinland",
    "vinlandets": "vinland",
    "vinlands": "vinland",
    "vinlistan": "vinlista",
    "vinlistans": "vinlista",
    "vinlistas": "vinlista",
    "vinliste": "vinlista",
    "vinlistor": "vinlista",
    "vinlistorna": "vinlista",
    "vinlistornas": "vinlista",
    "vinlistors": "vinlista",
    "vinlusen": "vinlus",
    "vinlusens": "vinlus",
    "vinländer": "vinland",
    "vinländerna": "vinland",
    "vinländernas": "vinland",
    "vinländers": "vinland",
    "vinlöss": "vinlus",
    "vinlössen": "vinlus",
    "vinlössens": "vinlus",
    "vinlöven": "vinlöv",
    "vinlövens": "vinlöv",
    "vinlövet": "vinlöv",
    "vinlövets": "vinlöv",
    "vinlövs": "vinlöv",
    "vinmakar": "vinmakare",
    "vinmakaren": "vinmakare",
    "vinmakarens": "vinmakare",
    "vinmakares": "vinmakare",
    "vinmakarna": "vinmakare",
    "vinmakarnas": "vinmakare",
    "vinmärken": "vinmärke",
    "vinmärkena": "vinmärke",
    "vinmärkenas": "vinmärke",
    "vinmärkens": "vinmärke",
    "vinmärkes": "vinmärke",
    "vinmärket": "vinmärke",
    "vinmärkets": "vinmärke",
    "vinn": "vinna",
    "vinnande": "vinna",
    "vinnanden": "vinnande",
    "vinnandena": "vinnande",
    "vinnandenas": "vinnande",
    "vinnandens": "vinnande",
    "vinnandes": "vinnande",
    "vinnandet": "vinnande",
    "vinnandets": "vinnande",
    "vinnar": "vinnare",
    "vinnaren": "vinnare",
    "vinnarens": "vinnare",
    "vinnares": "vinnare",
    "vinnarhålen": "vinnarhål",
    "vinnarhålens": "vinnarhål",
    "vinnarhålet": "vinnarhål",
    "vinnarhålets": "vinnarhål",
    "vinnarhåls": "vinnarhål",
    "vinnarna": "vinnare",
    "vinnarnas": "vinnare",
    "vinnas": "vinna",
    "vinne": "vinna",
    "vinner": "vinna",
    "vinnes": "vinna",
    "vinningar": "vinning",
    "vinningarna": "vinning",
    "vinningarnas": "vinning",
    "vinningars": "vinning",
    "vinningen": "vinning",
    "vinningens": "vinning",
    "vinnings": "vinning",
    "vinningslystens": "vinningslysten",
    "vinningslystet": "vinningslysten",
    "vinningslystets": "vinningslysten",
    "vinningslystna": "vinningslysten",
    "vinningslystnaden": "vinningslystnad",
    "vinningslystnadens": "vinningslystnad",
    "vinningslystnader": "vinningslystnad",
    "vinningslystnaderna": "vinningslystnad",
    "vinningslystnadernas": "vinningslystnad",
    "vinningslystnaders": "vinningslystnad",
    "vinningslystnads": "vinningslystnad",
    "vinningslystnare": "vinningslysten",
    "vinningslystnares": "vinningslysten",
    "vinningslystnas": "vinningslysten",
    "vinningslystnast": "vinningslysten",
    "vinningslystnaste": "vinningslysten",
    "vinningslystnastes": "vinningslysten",
    "vinningslystnasts": "vinningslysten",
    "vinningslystne": "vinningslysten",
    "vinningslystnes": "vinningslysten",
    "vinns": "vinna",
    "vinodlar": "vinodlare",
    "vinodlaren": "vinodlare",
    "vinodlarens": "vinodlare",
    "vinodlares": "vinodlare",
    "vinodlarna": "vinodlare",
    "vinodlarnas": "vinodlare",
    "vinor": "vina",
    "vinorganisationen": "vinorganisation",
    "vinorganisationens": "vinorganisation",
    "vinorganisationer": "vinorganisation",
    "vinorganisationerna": "vinorganisation",
    "vinorganisationernas": "vinorganisation",
    "vinorganisationers": "vinorganisation",
    "vinorganisations": "vinorganisation",
    "vinorna": "vina",
    "vinornas": "vina",
    "vinors": "vina",
    "vinproducenten": "vinproducent",
    "vinproducentens": "vinproducent",
    "vinproducenter": "vinproducent",
    "vinproducenterna": "vinproducent",
    "vinproducenternas": "vinproducent",
    "vinproducenters": "vinproducent",
    "vinproducents": "vinproducent",
    "vinproduktionen": "vinproduktion",
    "vinproduktionens": "vinproduktion",
    "vinproduktions": "vinproduktion",
    "vinprovningar": "vinprovning",
    "vinprovningarna": "vinprovning",
    "vinprovningarnas": "vinprovning",
    "vinprovningars": "vinprovning",
    "vinprovningen": "vinprovning",
    "vinprovningens": "vinprovning",
    "vinprovnings": "vinprovning",
    "vinrank": "vinranka",
    "vinrankan": "vinranka",
    "vinrankans": "vinranka",
    "vinrankas": "vinranka",
    "vinranke": "vinranka",
    "vinrankor": "vinranka",
    "vinrankorna": "vinranka",
    "vinrankornas": "vinranka",
    "vinrankors": "vinranka",
    "vinranks": "vinranka",
    "vinrutan": "vinruta",
    "vinrutans": "vinruta",
    "vinrutas": "vinruta",
    "vinrute": "vinruta",
    "vinrutor": "vinruta",
    "vinrutorna": "vinruta",
    "vinrutornas": "vinruta",
    "vinrutors": "vinruta",
    "vinrättigheten": "vinrättighet",
    "vinrättighetens": "vinrättighet",
    "vinrättigheter": "vinrättighet",
    "vinrättigheterna": "vinrättighet",
    "vinrättigheternas": "vinrättighet",
    "vinrättigheters": "vinrättighet",
    "vinrättighets": "vinrättighet",
    "vinröda": "vinröd",
    "vinrödare": "vinröd",
    "vinrödares": "vinröd",
    "vinrödas": "vinröd",
    "vinrödast": "vinröd",
    "vinrödaste": "vinröd",
    "vinrödastes": "vinröd",
    "vinrödasts": "vinröd",
    "vinröde": "vinröd",
    "vinrödes": "vinröd",
    "vinröds": "vinröd",
    "vinrött": "vinröd",
    "vinrötts": "vinröd",
    "vins": "vina",
    "vinsch": "vinscha",
    "vinschad": "vinscha",
    "vinschade": "vinscha",
    "vinschades": "vinscha",
    "vinschads": "vinscha",
    "vinschande": "vinscha",
    "vinschanden": "vinschande",
    "vinschandena": "vinschande",
    "vinschandenas": "vinschande",
    "vinschandens": "vinschande",
    "vinschandes": "vinschande",
    "vinschandet": "vinschande",
    "vinschandets": "vinschande",
    "vinschar": "vinscha",
    "vinscharna": "vinsch",
    "vinscharnas": "vinsch",
    "vinschars": "vinsch",
    "vinschas": "vinscha",
    "vinschat": "vinscha",
    "vinschats": "vinscha",
    "vinschen": "vinsch",
    "vinschens": "vinsch",
    "vinscher": "vinsch",
    "vinscherna": "vinsch",
    "vinschernas": "vinsch",
    "vinschers": "vinsch",
    "vinschs": "vinsch",
    "vinserveringar": "vinservering",
    "vinserveringarna": "vinservering",
    "vinserveringarnas": "vinservering",
    "vinserveringars": "vinservering",
    "vinserveringen": "vinservering",
    "vinserveringens": "vinservering",
    "vinserverings": "vinservering",
    "vinskänkar": "vinskänk",
    "vinskänkarna": "vinskänk",
    "vinskänkarnas": "vinskänk",
    "vinskänkars": "vinskänk",
    "vinskänken": "vinskänk",
    "vinskänkens": "vinskänk",
    "vinskänks": "vinskänk",
    "vinskördar": "vinskörd",
    "vinskördarna": "vinskörd",
    "vinskördarnas": "vinskörd",
    "vinskördars": "vinskörd",
    "vinskörden": "vinskörd",
    "vinskördens": "vinskörd",
    "vinskörds": "vinskörd",
    "vinsorten": "vinsort",
    "vinsortens": "vinsort",
    "vinsorter": "vinsort",
    "vinsorterna": "vinsort",
    "vinsorternas": "vinsort",
    "vinsorters": "vinsort",
    "vinsorts": "vinsort",
    "vinstandelar": "vinstandel",
    "vinstandelarna": "vinstandel",
    "vinstandelarnas": "vinstandel",
    "vinstandelars": "vinstandel",
    "vinstandelen": "vinstandel",
    "vinstandelens": "vinstandel",
    "vinstandels": "vinstandel",
    "vinstchansen": "vinstchans",
    "vinstchansens": "vinstchans",
    "vinstchanser": "vinstchans",
    "vinstchanserna": "vinstchans",
    "vinstchansernas": "vinstchans",
    "vinstchansers": "vinstchans",
    "vinstdelningar": "vinstdelning",
    "vinstdelningarna": "vinstdelning",
    "vinstdelningarnas": "vinstdelning",
    "vinstdelningars": "vinstdelning",
    "vinstdelningen": "vinstdelning",
    "vinstdelningens": "vinstdelning",
    "vinstdelnings": "vinstdelning",
    "vinstdelningsskatten": "vinstdelningsskatt",
    "vinstdelningsskattens": "vinstdelningsskatt",
    "vinstdelningsskatter": "vinstdelningsskatt",
    "vinstdelningsskatterna": "vinstdelningsskatt",
    "vinstdelningsskatternas": "vinstdelningsskatt",
    "vinstdelningsskatters": "vinstdelningsskatt",
    "vinstdelningsskatts": "vinstdelningsskatt",
    "vinsten": "vinst",
    "vinstenen": "vinsten",
    "vinstenens": "vinsten",
    "vinstens": "vinsten",
    "vinster": "vinst",
    "vinsterna": "vinst",
    "vinsternas": "vinst",
    "vinsters": "vinst",
    "vinstkalkylen": "vinstkalkyl",
    "vinstkalkylens": "vinstkalkyl",
    "vinstkalkyler": "vinstkalkyl",
    "vinstkalkylerna": "vinstkalkyl",
    "vinstkalkylernas": "vinstkalkyl",
    "vinstkalkylers": "vinstkalkyl",
    "vinstkalkyls": "vinstkalkyl",
    "vinstlistan": "vinstlista",
    "vinstlistans": "vinstlista",
    "vinstlistas": "vinstlista",
    "vinstliste": "vinstlista",
    "vinstlistor": "vinstlista",
    "vinstlistorna": "vinstlista",
    "vinstlistornas": "vinstlista",
    "vinstlistors": "vinstlista",
    "vinstlotten": "vinstlott",
    "vinstlottens": "vinstlott",
    "vinstlotter": "vinstlott",
    "vinstlotterna": "vinstlott",
    "vinstlotternas": "vinstlott",
    "vinstlotters": "vinstlott",
    "vinstlotts": "vinstlott",
    "vinstmarginalen": "vinstmarginal",
    "vinstmarginalens": "vinstmarginal",
    "vinstmarginaler": "vinstmarginal",
    "vinstmarginalerna": "vinstmarginal",
    "vinstmarginalernas": "vinstmarginal",
    "vinstmarginalers": "vinstmarginal",
    "vinstmarginals": "vinstmarginal",
    "vinstmaskinen": "vinstmaskin",
    "vinstmaskinens": "vinstmaskin",
    "vinstmaskiner": "vinstmaskin",
    "vinstmaskinerna": "vinstmaskin",
    "vinstmaskinernas": "vinstmaskin",
    "vinstmaskiners": "vinstmaskin",
    "vinstmaskins": "vinstmaskin",
    "vinstmaximerad": "vinstmaximera",
    "vinstmaximerade": "vinstmaximera",
    "vinstmaximerades": "vinstmaximera",
    "vinstmaximerads": "vinstmaximera",
    "vinstmaximerande": "vinstmaximera",
    "vinstmaximeranden": "vinstmaximerande",
    "vinstmaximerandena": "vinstmaximerande",
    "vinstmaximerandenas": "vinstmaximerande",
    "vinstmaximerandens": "vinstmaximerande",
    "vinstmaximerandes": "vinstmaximerande",
    "vinstmaximerandet": "vinstmaximerande",
    "vinstmaximerandets": "vinstmaximerande",
    "vinstmaximerar": "vinstmaximera",
    "vinstmaximeras": "vinstmaximera",
    "vinstmaximerat": "vinstmaximera",
    "vinstmaximerats": "vinstmaximera",
    "vinstmaximerbara": "vinstmaximerbar",
    "vinstmaximerbarare": "vinstmaximerbar",
    "vinstmaximerbarares": "vinstmaximerbar",
    "vinstmaximerbaras": "vinstmaximerbar",
    "vinstmaximerbarast": "vinstmaximerbar",
    "vinstmaximerbaraste": "vinstmaximerbar",
    "vinstmaximerbarastes": "vinstmaximerbar",
    "vinstmaximerbarasts": "vinstmaximerbar",
    "vinstmaximerbare": "vinstmaximerbar",
    "vinstmaximerbares": "vinstmaximerbar",
    "vinstmaximerbarheten": "vinstmaximerbarhet",
    "vinstmaximerbarhetens": "vinstmaximerbarhet",
    "vinstmaximerbarhets": "vinstmaximerbarhet",
    "vinstmaximerbars": "vinstmaximerbar",
    "vinstmaximerbart": "vinstmaximerbar",
    "vinstmaximerbarts": "vinstmaximerbar",
    "vinstminskningar": "vinstminskning",
    "vinstminskningarna": "vinstminskning",
    "vinstminskningarnas": "vinstminskning",
    "vinstminskningars": "vinstminskning",
    "vinstminskningen": "vinstminskning",
    "vinstminskningens": "vinstminskning",
    "vinstminsknings": "vinstminskning",
    "vinstnummerna": "vinstnummer",
    "vinstnummernas": "vinstnummer",
    "vinstnummers": "vinstnummer",
    "vinstnumren": "vinstnummer",
    "vinstnumrens": "vinstnummer",
    "vinstnumret": "vinstnummer",
    "vinstnumrets": "vinstnummer",
    "vinstockar": "vinstock",
    "vinstockarna": "vinstock",
    "vinstockarnas": "vinstock",
    "vinstockars": "vinstock",
    "vinstocken": "vinstock",
    "vinstockens": "vinstock",
    "vinstocks": "vinstock",
    "vinstplane": "vinstplan",
    "vinstplanen": "vinstplan",
    "vinstplanens": "vinstplan",
    "vinstplaner": "vinstplan",
    "vinstplanerna": "vinstplan",
    "vinstplanernas": "vinstplan",
    "vinstplaners": "vinstplan",
    "vinstplans": "vinstplan",
    "vinstrasen": "vinstras",
    "vinstrasens": "vinstras",
    "vinstraset": "vinstras",
    "vinstrasets": "vinstras",
    "vinsts": "vinst",
    "vinstsyften": "vinstsyfte",
    "vinstsyftena": "vinstsyfte",
    "vinstsyftenas": "vinstsyfte",
    "vinstsyftens": "vinstsyfte",
    "vinstsyftes": "vinstsyfte",
    "vinstsyftet": "vinstsyfte",
    "vinstsyftets": "vinstsyfte",
    "vinstsyfts": "vinstsyfte",
    "vinstugan": "vinstuga",
    "vinstugans": "vinstuga",
    "vinstugas": "vinstuga",
    "vinstuge": "vinstuga",
    "vinstugor": "vinstuga",
    "vinstugorna": "vinstuga",
    "vinstugornas": "vinstuga",
    "vinstugors": "vinstuga",
    "vinstugu": "vinstuga",
    "vinstvarn": "vinstvarna",
    "vinstvarnad": "vinstvarna",
    "vinstvarnade": "vinstvarna",
    "vinstvarnades": "vinstvarna",
    "vinstvarnads": "vinstvarna",
    "vinstvarnande": "vinstvarna",
    "vinstvarnanden": "vinstvarnande",
    "vinstvarnandena": "vinstvarnande",
    "vinstvarnandenas": "vinstvarnande",
    "vinstvarnandens": "vinstvarnande",
    "vinstvarnandes": "vinstvarnande",
    "vinstvarnandet": "vinstvarnande",
    "vinstvarnandets": "vinstvarnande",
    "vinstvarnar": "vinstvarna",
    "vinstvarnas": "vinstvarna",
    "vinstvarnat": "vinstvarna",
    "vinstvarnats": "vinstvarna",
    "vinstvarningar": "vinstvarning",
    "vinstvarningarna": "vinstvarning",
    "vinstvarningarnas": "vinstvarning",
    "vinstvarningars": "vinstvarning",
    "vinstvarningen": "vinstvarning",
    "vinstvarningens": "vinstvarning",
    "vinstvarnings": "vinstvarning",
    "vinsyran": "vinsyra",
    "vinsyrans": "vinsyra",
    "vinsyras": "vinsyra",
    "vinsyre": "vinsyra",
    "vint": "vind",
    "vintageviner": "vintagevin",
    "vintagevinerna": "vintagevin",
    "vintagevinernas": "vintagevin",
    "vintageviners": "vintagevin",
    "vintagevinet": "vintagevin",
    "vintagevinets": "vintagevin",
    "vintagevins": "vintagevin",
    "vinterbadad": "vinterbada",
    "vinterbadade": "vinterbada",
    "vinterbadades": "vinterbada",
    "vinterbadads": "vinterbada",
    "vinterbadande": "vinterbada",
    "vinterbadanden": "vinterbadande",
    "vinterbadandena": "vinterbadande",
    "vinterbadandenas": "vinterbadande",
    "vinterbadandens": "vinterbadande",
    "vinterbadandes": "vinterbadande",
    "vinterbadandet": "vinterbadande",
    "vinterbadandets": "vinterbadande",
    "vinterbadar": "vinterbadare",
    "vinterbadaren": "vinterbadare",
    "vinterbadarens": "vinterbadare",
    "vinterbadares": "vinterbadare",
    "vinterbadarna": "vinterbadare",
    "vinterbadarnas": "vinterbadare",
    "vinterbadas": "vinterbada",
    "vinterbadat": "vinterbada",
    "vinterbadats": "vinterbada",
    "vinterbaden": "vinterbad",
    "vinterbadens": "vinterbad",
    "vinterbadet": "vinterbad",
    "vinterbadets": "vinterbad",
    "vinterbads": "vinterbad",
    "vinterblåa": "vinterblå",
    "vinterblåare": "vinterblå",
    "vinterblåares": "vinterblå",
    "vinterblåas": "vinterblå",
    "vinterblåast": "vinterblå",
    "vinterblåaste": "vinterblå",
    "vinterblåastes": "vinterblå",
    "vinterblåasts": "vinterblå",
    "vinterblåe": "vinterblå",
    "vinterblåes": "vinterblå",
    "vinterblås": "vinterblå",
    "vinterblått": "vinterblå",
    "vinterblåtts": "vinterblå",
    "vinterbon": "vinterbona",
    "vinterbonad": "vinterbona",
    "vinterbonade": "vinterbona",
    "vinterbonades": "vinterbona",
    "vinterbonads": "vinterbona",
    "vinterbonande": "vinterbona",
    "vinterbonanden": "vinterbonande",
    "vinterbonandena": "vinterbonande",
    "vinterbonandenas": "vinterbonande",
    "vinterbonandens": "vinterbonande",
    "vinterbonandes": "vinterbonande",
    "vinterbonandet": "vinterbonande",
    "vinterbonandets": "vinterbonande",
    "vinterbonar": "vinterbona",
    "vinterbonas": "vinterbona",
    "vinterbonat": "vinterbona",
    "vinterbonats": "vinterbona",
    "vinterbostaden": "vinterbostad",
    "vinterbostadens": "vinterbostad",
    "vinterbostads": "vinterbostad",
    "vinterbostan": "vinterbostad",
    "vinterbostans": "vinterbostad",
    "vinterbostäder": "vinterbostad",
    "vinterbostäderna": "vinterbostad",
    "vinterbostädernas": "vinterbostad",
    "vinterbostäders": "vinterbostad",
    "vinterdräkten": "vinterdräkt",
    "vinterdräktens": "vinterdräkt",
    "vinterdräkter": "vinterdräkt",
    "vinterdräkterna": "vinterdräkt",
    "vinterdräkternas": "vinterdräkt",
    "vinterdräkters": "vinterdräkt",
    "vinterdräkts": "vinterdräkt",
    "vinterdvalan": "vinterdvala",
    "vinterdvalans": "vinterdvala",
    "vinterdvalas": "vinterdvala",
    "vinterdäcken": "vinterdäck",
    "vinterdäckens": "vinterdäck",
    "vinterdäcket": "vinterdäck",
    "vinterdäckets": "vinterdäck",
    "vinterdäcks": "vinterdäck",
    "vintereftermiddagar": "vintereftermiddag",
    "vintereftermiddagarna": "vintereftermiddag",
    "vintereftermiddagarnas": "vintereftermiddag",
    "vintereftermiddagars": "vintereftermiddag",
    "vintereftermiddagen": "vintereftermiddag",
    "vintereftermiddagens": "vintereftermiddag",
    "vintereftermiddags": "vintereftermiddag",
    "vinterfarkosten": "vinterfarkost",
    "vinterfarkostens": "vinterfarkost",
    "vinterfarkoster": "vinterfarkost",
    "vinterfarkosterna": "vinterfarkost",
    "vinterfarkosternas": "vinterfarkost",
    "vinterfarkosters": "vinterfarkost",
    "vinterfarkosts": "vinterfarkost",
    "vinterfoderna": "vinterfoder",
    "vinterfodernas": "vinterfoder",
    "vinterfoders": "vinterfoder",
    "vinterfodren": "vinterfoder",
    "vinterfodrens": "vinterfoder",
    "vinterfodret": "vinterfoder",
    "vinterfodrets": "vinterfoder",
    "vinterfrukten": "vinterfrukt",
    "vinterfruktens": "vinterfrukt",
    "vinterfrukter": "vinterfrukt",
    "vinterfrukterna": "vinterfrukt",
    "vinterfrukternas": "vinterfrukt",
    "vinterfrukters": "vinterfrukt",
    "vinterfrukts": "vinterfrukt",
    "vinterförråden": "vinterförråd",
    "vinterförrådens": "vinterförråd",
    "vinterförrådet": "vinterförråd",
    "vinterförrådets": "vinterförråd",
    "vinterförråds": "vinterförråd",
    "vintergrön": "vintergröna",
    "vintergröna": "vintergrön",
    "vintergrönan": "vintergröna",
    "vintergrönans": "vintergröna",
    "vintergrönare": "vintergrön",
    "vintergrönares": "vintergrön",
    "vintergrönas": "vintergröna",
    "vintergrönast": "vintergrön",
    "vintergrönaste": "vintergrön",
    "vintergrönastes": "vintergrön",
    "vintergrönasts": "vintergrön",
    "vintergröne": "vintergröna",
    "vintergrönes": "vintergrön",
    "vintergrönor": "vintergröna",
    "vintergrönorna": "vintergröna",
    "vintergrönornas": "vintergröna",
    "vintergrönors": "vintergröna",
    "vintergröns": "vintergröna",
    "vintergrönt": "vintergrön",
    "vintergrönts": "vintergrönt",
    "vintergäcken": "vintergäck",
    "vintergäckens": "vintergäck",
    "vintergäcks": "vintergäck",
    "vinterhalvåren": "vinterhalvår",
    "vinterhalvårens": "vinterhalvår",
    "vinterhalvåret": "vinterhalvår",
    "vinterhalvårets": "vinterhalvår",
    "vinterhalvårs": "vinterhalvår",
    "vinterhimlar": "vinterhimmel",
    "vinterhimlarna": "vinterhimmel",
    "vinterhimlarnas": "vinterhimmel",
    "vinterhimlars": "vinterhimmel",
    "vinterhimlen": "vinterhimmel",
    "vinterhimlens": "vinterhimmel",
    "vinterhimmelen": "vinterhimmel",
    "vinterhimmelens": "vinterhimmel",
    "vinterhimmeln": "vinterhimmel",
    "vinterhimmelns": "vinterhimmel",
    "vinterhimmels": "vinterhimmel",
    "vinterhärdiga": "vinterhärdig",
    "vinterhärdigare": "vinterhärdig",
    "vinterhärdigares": "vinterhärdig",
    "vinterhärdigas": "vinterhärdig",
    "vinterhärdigast": "vinterhärdig",
    "vinterhärdigaste": "vinterhärdig",
    "vinterhärdigastes": "vinterhärdig",
    "vinterhärdigasts": "vinterhärdig",
    "vinterhärdige": "vinterhärdig",
    "vinterhärdiges": "vinterhärdig",
    "vinterhärdigheten": "vinterhärdighet",
    "vinterhärdighetens": "vinterhärdighet",
    "vinterhärdighets": "vinterhärdighet",
    "vinterhärdigs": "vinterhärdig",
    "vinterhärdigt": "vinterhärdig",
    "vinterhärdigts": "vinterhärdig",
    "vinteridrotten": "vinteridrott",
    "vinteridrottens": "vinteridrott",
    "vinteridrotter": "vinteridrott",
    "vinteridrotterna": "vinteridrott",
    "vinteridrotternas": "vinteridrott",
    "vinteridrotters": "vinteridrott",
    "vinteridrotts": "vinteridrott",
    "vinterkräken": "vinterkräk",
    "vinterkräkens": "vinterkräk",
    "vinterkräket": "vinterkräk",
    "vinterkräkets": "vinterkräk",
    "vinterkräks": "vinterkräk",
    "vinterkräksjuk": "vinterkräksjuka",
    "vinterkräksjukan": "vinterkräksjuka",
    "vinterkräksjukans": "vinterkräksjuka",
    "vinterkräksjukas": "vinterkräksjuka",
    "vinterkräksjuke": "vinterkräksjuka",
    "vinterkräksjukor": "vinterkräksjuka",
    "vinterkräksjukorna": "vinterkräksjuka",
    "vinterkräksjukornas": "vinterkräksjuka",
    "vinterkräksjukors": "vinterkräksjuka",
    "vinterkräksjuks": "vinterkräksjuka",
    "vinterkvällar": "vinterkväll",
    "vinterkvällarna": "vinterkväll",
    "vinterkvällarnas": "vinterkväll",
    "vinterkvällars": "vinterkväll",
    "vinterkvällen": "vinterkväll",
    "vinterkvällens": "vinterkväll",
    "vinterkvälls": "vinterkväll",
    "vinterkylan": "vinterkyla",
    "vinterkylans": "vinterkyla",
    "vinterkylas": "vinterkyla",
    "vinterkyle": "vinterkyla",
    "vinterkölden": "vinterköld",
    "vinterköldens": "vinterköld",
    "vinterkölds": "vinterköld",
    "vinterlandskapen": "vinterlandskap",
    "vinterlandskapens": "vinterlandskap",
    "vinterlandskapet": "vinterlandskap",
    "vinterlandskapets": "vinterlandskap",
    "vinterlandskaps": "vinterlandskap",
    "vinterlekar": "vinterlek",
    "vinterlekarna": "vinterlek",
    "vinterlekarnas": "vinterlek",
    "vinterlekars": "vinterlek",
    "vinterleken": "vinterlek",
    "vinterlekens": "vinterlek",
    "vinterleks": "vinterlek",
    "vinterleksaken": "vinterleksak",
    "vinterleksakens": "vinterleksak",
    "vinterleksaker": "vinterleksak",
    "vinterleksakerna": "vinterleksak",
    "vinterleksakernas": "vinterleksak",
    "vinterleksakers": "vinterleksak",
    "vinterleksaks": "vinterleksak",
    "vinterliga": "vinterlig",
    "vinterligare": "vinterlig",
    "vinterligares": "vinterlig",
    "vinterligas": "vinterlig",
    "vinterligast": "vinterlig",
    "vinterligaste": "vinterlig",
    "vinterligastes": "vinterlig",
    "vinterligasts": "vinterlig",
    "vinterlige": "vinterlig",
    "vinterliges": "vinterlig",
    "vinterliggar": "vinterliggare",
    "vinterliggaren": "vinterliggare",
    "vinterliggarens": "vinterliggare",
    "vinterliggares": "vinterliggare",
    "vinterliggarna": "vinterliggare",
    "vinterliggarnas": "vinterliggare",
    "vinterligheten": "vinterlighet",
    "vinterlighetens": "vinterlighet",
    "vinterlighets": "vinterlighet",
    "vinterligs": "vinterlig",
    "vinterligt": "vinterlig",
    "vinterligts": "vinterlig",
    "vinterloven": "vinterlov",
    "vinterlovens": "vinterlov",
    "vinterlovet": "vinterlov",
    "vinterlovets": "vinterlov",
    "vinterlovs": "vinterlov",
    "vintermysen": "vintermys",
    "vintermysens": "vintermys",
    "vintermyset": "vintermys",
    "vintermysets": "vintermys",
    "vintermånaden": "vintermånad",
    "vintermånadens": "vintermånad",
    "vintermånader": "vintermånad",
    "vintermånaderna": "vintermånad",
    "vintermånadernas": "vintermånad",
    "vintermånaders": "vintermånad",
    "vintermånads": "vintermånad",
    "vintermörkerna": "vintermörker",
    "vintermörkernas": "vintermörker",
    "vintermörkers": "vintermörker",
    "vintermörkren": "vintermörker",
    "vintermörkrens": "vintermörker",
    "vintermörkret": "vintermörker",
    "vintermörkrets": "vintermörker",
    "vintern": "vinter",
    "vinternatn": "vinternatt",
    "vinternatns": "vinternatt",
    "vinternatten": "vinternatt",
    "vinternattens": "vinternatt",
    "vinternatts": "vinternatt",
    "vinterns": "vinter",
    "vinternys": "vinterny",
    "vinternätter": "vinternatt",
    "vinternätterna": "vinternatt",
    "vinternätternas": "vinternatt",
    "vinternätters": "vinternatt",
    "vinterpäronen": "vinterpäron",
    "vinterpäronens": "vinterpäron",
    "vinterpäronet": "vinterpäron",
    "vinterpäronets": "vinterpäron",
    "vinterpärons": "vinterpäron",
    "vinters": "vinter",
    "vinterskinnen": "vinterskinn",
    "vinterskinnens": "vinterskinn",
    "vinterskinnet": "vinterskinn",
    "vinterskinnets": "vinterskinn",
    "vinterskinns": "vinterskinn",
    "vintersolståndet": "vintersolstånd",
    "vintersolståndets": "vintersolstånd",
    "vintersolstånds": "vintersolstånd",
    "vintersporten": "vintersport",
    "vintersportens": "vintersport",
    "vintersporter": "vintersport",
    "vintersporterna": "vintersport",
    "vintersporternas": "vintersport",
    "vintersporters": "vintersport",
    "vintersports": "vintersport",
    "vinterspårvagnar": "vinterspårvagn",
    "vinterspårvagnarna": "vinterspårvagn",
    "vinterspårvagnarnas": "vinterspårvagn",
    "vinterspårvagnars": "vinterspårvagn",
    "vinterspårvagnen": "vinterspårvagn",
    "vinterspårvagnens": "vinterspårvagn",
    "vinterspårvagns": "vinterspårvagn",
    "vinterstjärnan": "vinterstjärna",
    "vinterstjärnans": "vinterstjärna",
    "vinterstjärnas": "vinterstjärna",
    "vinterstjärne": "vinterstjärna",
    "vinterstjärnor": "vinterstjärna",
    "vinterstjärnorna": "vinterstjärna",
    "vinterstjärnornas": "vinterstjärna",
    "vinterstjärnors": "vinterstjärna",
    "vinterstånden": "vinterstånd",
    "vinterståndens": "vinterstånd",
    "vinterståndet": "vinterstånd",
    "vinterståndets": "vinterstånd",
    "vinterstånds": "vinterstånd",
    "vinterstöveln": "vinterstövel",
    "vinterstövelns": "vinterstövel",
    "vinterstövels": "vinterstövel",
    "vinterstövlar": "vinterstövel",
    "vinterstövlarna": "vinterstövel",
    "vinterstövlarnas": "vinterstövel",
    "vinterstövlars": "vinterstövel",
    "vintersäden": "vintersäd",
    "vintersädens": "vintersäd",
    "vintersädes": "vintersäd",
    "vintersäds": "vintersäd",
    "vintersömnen": "vintersömn",
    "vintersömnens": "vintersömn",
    "vintersömns": "vintersömn",
    "vintertiden": "vintertid",
    "vintertidens": "vintertid",
    "vintertids": "vintertid",
    "vinterträdgårdar": "vinterträdgård",
    "vinterträdgårdarna": "vinterträdgård",
    "vinterträdgårdarnas": "vinterträdgård",
    "vinterträdgårdars": "vinterträdgård",
    "vinterträdgården": "vinterträdgård",
    "vinterträdgårdens": "vinterträdgård",
    "vinterträdgårds": "vinterträdgård",
    "vintertröttheten": "vintertrötthet",
    "vintertrötthetens": "vintertrötthet",
    "vintertröttheter": "vintertrötthet",
    "vintertröttheterna": "vintertrötthet",
    "vintertröttheternas": "vintertrötthet",
    "vintertröttheters": "vintertrötthet",
    "vintertrötthets": "vintertrötthet",
    "vintervilan": "vintervila",
    "vintervilans": "vintervila",
    "vintervilas": "vintervila",
    "vintervile": "vintervila",
    "vintervilo": "vintervila",
    "vintervilor": "vintervila",
    "vintervilorna": "vintervila",
    "vintervilornas": "vintervila",
    "vintervilors": "vintervila",
    "vinterväderna": "vinterväder",
    "vintervädernas": "vinterväder",
    "vinterväders": "vinterväder",
    "vintervädren": "vinterväder",
    "vintervädrens": "vinterväder",
    "vintervädret": "vinterväder",
    "vintervädrets": "vinterväder",
    "vintervägar": "vinterväg",
    "vintervägarna": "vinterväg",
    "vintervägarnas": "vinterväg",
    "vintervägars": "vinterväg",
    "vintervägen": "vinterväg",
    "vintervägens": "vinterväg",
    "vinterväghåll": "vinterväghålla",
    "vinterväghållande": "vinterväghålla",
    "vinterväghållandes": "vinterväghålla",
    "vinterväghållas": "vinterväghålla",
    "vinterväghålle": "vinterväghålla",
    "vinterväghållen": "vinterväghålla",
    "vinterväghållens": "vinterväghålla",
    "vinterväghåller": "vinterväghålla",
    "vinterväghålles": "vinterväghålla",
    "vinterväghållet": "vinterväghålla",
    "vinterväghållets": "vinterväghålla",
    "vinterväghållit": "vinterväghålla",
    "vinterväghållits": "vinterväghålla",
    "vinterväghållna": "vinterväghålla",
    "vinterväghållnas": "vinterväghålla",
    "vinterväghållne": "vinterväghålla",
    "vinterväghållnes": "vinterväghålla",
    "vinterväghålls": "vinterväghålla",
    "vinterväghöll": "vinterväghålla",
    "vinterväghölle": "vinterväghålla",
    "vinterväghölles": "vinterväghålla",
    "vinterväghölls": "vinterväghålla",
    "vinterväglagen": "vinterväglag",
    "vinterväglagens": "vinterväglag",
    "vinterväglaget": "vinterväglag",
    "vinterväglagets": "vinterväglag",
    "vinterväglags": "vinterväglag",
    "vintervägs": "vinterväg",
    "vinteräpplen": "vinteräpple",
    "vinteräpplena": "vinteräpple",
    "vinteräpplenas": "vinteräpple",
    "vinteräpplens": "vinteräpple",
    "vinteräpples": "vinteräpple",
    "vinteräpplet": "vinteräpple",
    "vinteräpplets": "vinteräpple",
    "vinteräppls": "vinteräpple",
    "vinthundar": "vinthund",
    "vinthundarna": "vinthund",
    "vinthundarnas": "vinthund",
    "vinthundars": "vinthund",
    "vinthunden": "vinthund",
    "vinthundens": "vinthund",
    "vinthunds": "vinthund",
    "vintrades": "vintras",
    "vintrar": "vinter",
    "vintrarna": "vinter",
    "vintrarnas": "vinter",
    "vintrars": "vinter",
    "vintrats": "vintras",
    "vintriga": "vintrig",
    "vintrigare": "vintrig",
    "vintrigares": "vintrig",
    "vintrigas": "vintrig",
    "vintrigast": "vintrig",
    "vintrigaste": "vintrig",
    "vintrigastes": "vintrig",
    "vintrigasts": "vintrig",
    "vintrige": "vintrig",
    "vintriges": "vintrig",
    "vintrigheten": "vintrighet",
    "vintrighetens": "vintrighet",
    "vintrighets": "vintrighet",
    "vintrigs": "vintrig",
    "vintrigt": "vintrig",
    "vintrigts": "vintrig",
    "vints": "vind",
    "vinylen": "vinyl",
    "vinylens": "vinyl",
    "vinyler": "vinyl",
    "vinylerna": "vinyl",
    "vinylernas": "vinyl",
    "vinylers": "vinyl",
    "vinylglansen": "vinylglans",
    "vinylglansens": "vinylglans",
    "vinylkloriden": "vinylklorid",
    "vinylkloridens": "vinylklorid",
    "vinylklorids": "vinylklorid",
    "vinyls": "vinyl",
    "vinägern": "vinäger",
    "vinägerns": "vinäger",
    "vinägers": "vinäger",
    "vinägretten": "vinägrett",
    "vinägrettens": "vinägrett",
    "vinägretts": "vinägrett",
    "vinättikan": "vinättika",
    "vinättikans": "vinättika",
    "vinättikas": "vinättika",
    "vinåren": "vinår",
    "vinårens": "vinår",
    "vinåret": "vinår",
    "vinårets": "vinår",
    "vinårs": "vinår",
    "viol": "viola",
    "violan": "viola",
    "violans": "viola",
    "violas": "viola",
    "violblåa": "violblå",
    "violblåare": "violblå",
    "violblåares": "violblå",
    "violblåas": "violblå",
    "violblåast": "violblå",
    "violblåaste": "violblå",
    "violblåastes": "violblå",
    "violblåasts": "violblå",
    "violblåe": "violblå",
    "violblåes": "violblå",
    "violblås": "violblå",
    "violblått": "violblå",
    "violblåtts": "violblå",
    "violdoften": "violdoft",
    "violdoftens": "violdoft",
    "violdofts": "violdoft",
    "viole": "viola",
    "violen": "viol",
    "violens": "viol",
    "violer": "viol",
    "violerna": "viol",
    "violernas": "viol",
    "violers": "viol",
    "violetta": "violett",
    "violettare": "violett",
    "violettares": "violett",
    "violettas": "violett",
    "violettast": "violett",
    "violettaste": "violett",
    "violettastes": "violett",
    "violettasts": "violett",
    "violette": "violett",
    "violettes": "violett",
    "violetts": "violett",
    "violinen": "violin",
    "violinens": "violin",
    "violiner": "violin",
    "violinerna": "violin",
    "violinernas": "violin",
    "violiners": "violin",
    "violinisten": "violinist",
    "violinistens": "violinist",
    "violinister": "violinist",
    "violinisterna": "violinist",
    "violinisternas": "violinist",
    "violinisters": "violinist",
    "violinists": "violinist",
    "violinklaven": "violinklav",
    "violinklavens": "violinklav",
    "violinklaver": "violinklav",
    "violinklaverna": "violinklav",
    "violinklavernas": "violinklav",
    "violinklavers": "violinklav",
    "violinklavs": "violinklav",
    "violins": "violin",
    "violoncellen": "violoncell",
    "violoncellens": "violoncell",
    "violonceller": "violoncell",
    "violoncellerna": "violoncell",
    "violoncellernas": "violoncell",
    "violoncellers": "violoncell",
    "violoncells": "violoncell",
    "violor": "viola",
    "violorna": "viola",
    "violornas": "viola",
    "violors": "viola",
    "viols": "viola",
    "vip": "vipa",
    "vipan": "vipa",
    "vipans": "vipa",
    "vipar": "vip",
    "viparna": "vip",
    "viparnas": "vip",
    "vipars": "vip",
    "vipas": "vipa",
    "vipe": "vipa",
    "vipen": "vip",
    "vipens": "vip",
    "vipor": "vipa",
    "viporna": "vipa",
    "vipornas": "vipa",
    "vipors": "vipa",
    "vipp": "vippa",
    "vippad": "vippa",
    "vippade": "vippa",
    "vippades": "vippa",
    "vippads": "vippa",
    "vippan": "vippa",
    "vippande": "vippa",
    "vippanden": "vippande",
    "vippandena": "vippande",
    "vippandenas": "vippande",
    "vippandens": "vippande",
    "vippandes": "vippande",
    "vippandet": "vippande",
    "vippandets": "vippande",
    "vippans": "vippa",
    "vippar": "vippa",
    "vipparmar": "vipparm",
    "vipparmarna": "vipparm",
    "vipparmarnas": "vipparm",
    "vipparmars": "vipparm",
    "vipparmen": "vipparm",
    "vipparmens": "vipparm",
    "vipparms": "vipparm",
    "vipparna": "vipp",
    "vipparnas": "vipp",
    "vippars": "vipp",
    "vippas": "vippa",
    "vippat": "vippa",
    "vippats": "vippa",
    "vippbräd": "vippbräda",
    "vippbrädan": "vippbräda",
    "vippbrädans": "vippbräda",
    "vippbrädas": "vippbräda",
    "vippbräde": "vippbräda",
    "vippbräden": "vippbräde",
    "vippbrädena": "vippbräde",
    "vippbrädenas": "vippbräde",
    "vippbrädens": "vippbräde",
    "vippbrädes": "vippbräde",
    "vippbrädet": "vippbräde",
    "vippbrädets": "vippbräde",
    "vippbrädor": "vippbräda",
    "vippbrädorna": "vippbräda",
    "vippbrädornas": "vippbräda",
    "vippbrädors": "vippbräda",
    "vippbräds": "vippbräda",
    "vippe": "vippa",
    "vippen": "vipp",
    "vippens": "vipp",
    "vippiga": "vippig",
    "vippigare": "vippig",
    "vippigares": "vippig",
    "vippigas": "vippig",
    "vippigast": "vippig",
    "vippigaste": "vippig",
    "vippigastes": "vippig",
    "vippigasts": "vippig",
    "vippige": "vippig",
    "vippiges": "vippig",
    "vippigheten": "vippighet",
    "vippighetens": "vippighet",
    "vippighets": "vippighet",
    "vippigs": "vippig",
    "vippigt": "vippig",
    "vippigts": "vippig",
    "vippkopplingar": "vippkoppling",
    "vippkopplingarna": "vippkoppling",
    "vippkopplingarnas": "vippkoppling",
    "vippkopplingars": "vippkoppling",
    "vippkopplingen": "vippkoppling",
    "vippkopplingens": "vippkoppling",
    "vippkopplings": "vippkoppling",
    "vippor": "vippa",
    "vipporna": "vippa",
    "vippornas": "vippa",
    "vippors": "vippa",
    "vipps": "vippa",
    "vippstjärtar": "vippstjärt",
    "vippstjärtarna": "vippstjärt",
    "vippstjärtarnas": "vippstjärt",
    "vippstjärtars": "vippstjärt",
    "vippstjärten": "vippstjärt",
    "vippstjärtens": "vippstjärt",
    "vippstjärts": "vippstjärt",
    "viprummen": "viprum",
    "viprummens": "viprum",
    "viprummet": "viprum",
    "viprummets": "viprum",
    "viprums": "viprum",
    "vips": "vipa",
    "vir": "vira",
    "virad": "vira",
    "virade": "vira",
    "virades": "vira",
    "virads": "vira",
    "viraken": "virak",
    "virakens": "virak",
    "viraks": "virak",
    "viran": "vira",
    "virande": "vira",
    "viranden": "virande",
    "virandena": "virande",
    "virandenas": "virande",
    "virandens": "virande",
    "virandes": "virande",
    "virandet": "virande",
    "virandets": "virande",
    "virans": "vira",
    "virar": "vira",
    "viras": "vira",
    "virat": "vira",
    "virats": "vira",
    "vire": "vira",
    "virginiahjortar": "virginiahjort",
    "virginiahjortarna": "virginiahjort",
    "virginiahjortarnas": "virginiahjort",
    "virginiahjortars": "virginiahjort",
    "virginiahjorten": "virginiahjort",
    "virginiahjortens": "virginiahjort",
    "virginiahjorts": "virginiahjort",
    "virila": "viril",
    "virilare": "viril",
    "virilares": "viril",
    "virilas": "viril",
    "virilast": "viril",
    "virilaste": "viril",
    "virilastes": "viril",
    "virilasts": "viril",
    "virile": "viril",
    "viriles": "viril",
    "viriliteten": "virilitet",
    "virilitetens": "virilitet",
    "viriliteter": "virilitet",
    "viriliteterna": "virilitet",
    "viriliteternas": "virilitet",
    "viriliteters": "virilitet",
    "virilitets": "virilitet",
    "virils": "viril",
    "virilt": "viril",
    "virilts": "viril",
    "virk": "virka",
    "virkad": "virka",
    "virkade": "virka",
    "virkades": "virka",
    "virkads": "virka",
    "virkande": "virka",
    "virkanden": "virkande",
    "virkandena": "virkande",
    "virkandenas": "virkande",
    "virkandens": "virkande",
    "virkandes": "virkande",
    "virkandet": "virkande",
    "virkandets": "virkande",
    "virkar": "virka",
    "virkas": "virka",
    "virkat": "virka",
    "virkats": "virka",
    "virkes": "virke",
    "virkesfångsten": "virkesfångst",
    "virkesfångstens": "virkesfångst",
    "virkesfångsts": "virkesfångst",
    "virkeskvaliteten": "virkeskvalitet",
    "virkeskvalitetens": "virkeskvalitet",
    "virkeskvaliteter": "virkeskvalitet",
    "virkeskvaliteterna": "virkeskvalitet",
    "virkeskvaliteternas": "virkeskvalitet",
    "virkeskvaliteters": "virkeskvalitet",
    "virkeskvalitets": "virkeskvalitet",
    "virkesmätningar": "virkesmätning",
    "virkesmätningarna": "virkesmätning",
    "virkesmätningarnas": "virkesmätning",
    "virkesmätningars": "virkesmätning",
    "virkesmätningen": "virkesmätning",
    "virkesmätningens": "virkesmätning",
    "virkesmätnings": "virkesmätning",
    "virket": "virke",
    "virkets": "virke",
    "virkgarnen": "virkgarn",
    "virkgarnens": "virkgarn",
    "virkgarner": "virkgarn",
    "virkgarnerna": "virkgarn",
    "virkgarnernas": "virkgarn",
    "virkgarners": "virkgarn",
    "virkgarnet": "virkgarn",
    "virkgarnets": "virkgarn",
    "virkgarns": "virkgarn",
    "virkkrokar": "virkkrok",
    "virkkrokarna": "virkkrok",
    "virkkrokarnas": "virkkrok",
    "virkkrokars": "virkkrok",
    "virkkroken": "virkkrok",
    "virkkrokens": "virkkrok",
    "virkkroks": "virkkrok",
    "virkningar": "virkning",
    "virkningarna": "virkning",
    "virkningarnas": "virkning",
    "virkningars": "virkning",
    "virkningen": "virkning",
    "virkningens": "virkning",
    "virknings": "virkning",
    "virknålar": "virknål",
    "virknålarna": "virknål",
    "virknålarnas": "virknål",
    "virknålars": "virknål",
    "virknålen": "virknål",
    "virknålens": "virknål",
    "virknåls": "virknål",
    "virologen": "virolog",
    "virologens": "virolog",
    "virologer": "virolog",
    "virologerna": "virolog",
    "virologernas": "virolog",
    "virologers": "virolog",
    "virologien": "virologi",
    "virologiens": "virologi",
    "virologin": "virologi",
    "virologins": "virologi",
    "virologis": "virologi",
    "virologs": "virolog",
    "viror": "vira",
    "virorna": "vira",
    "virornas": "vira",
    "virors": "vira",
    "virr": "virra",
    "virrad": "virra",
    "virrade": "virra",
    "virrades": "virra",
    "virrads": "virra",
    "virrande": "virra",
    "virranden": "virrande",
    "virrandena": "virrande",
    "virrandenas": "virrande",
    "virrandens": "virrande",
    "virrandes": "virrande",
    "virrandet": "virrande",
    "virrandets": "virrande",
    "virrar": "virra",
    "virras": "virra",
    "virrat": "virra",
    "virrats": "virra",
    "virrhjärnan": "virrhjärna",
    "virrhjärnans": "virrhjärna",
    "virrhjärnas": "virrhjärna",
    "virrhjärne": "virrhjärna",
    "virrhjärnor": "virrhjärna",
    "virrhjärnorna": "virrhjärna",
    "virrhjärnornas": "virrhjärna",
    "virrhjärnors": "virrhjärna",
    "virriga": "virrig",
    "virrigare": "virrig",
    "virrigares": "virrig",
    "virrigas": "virrig",
    "virrigast": "virrig",
    "virrigaste": "virrig",
    "virrigastes": "virrig",
    "virrigasts": "virrig",
    "virrige": "virrig",
    "virriges": "virrig",
    "virrigheten": "virrighet",
    "virrighetens": "virrighet",
    "virrigheter": "virrighet",
    "virrigheterna": "virrighet",
    "virrigheternas": "virrighet",
    "virrigheters": "virrighet",
    "virrighets": "virrighet",
    "virrigs": "virrig",
    "virrigt": "virrig",
    "virrigts": "virrig",
    "virrpann": "virrpanna",
    "virrpannan": "virrpanna",
    "virrpannans": "virrpanna",
    "virrpannas": "virrpanna",
    "virrpanne": "virrpanna",
    "virrpannor": "virrpanna",
    "virrpannorna": "virrpanna",
    "virrpannornas": "virrpanna",
    "virrpannors": "virrpanna",
    "virrpanns": "virrpanna",
    "virrvarret": "virrvarr",
    "virrvarrets": "virrvarr",
    "virrvarrs": "virrvarr",
    "virs": "vira",
    "virtuella": "virtuell",
    "virtuellare": "virtuell",
    "virtuellares": "virtuell",
    "virtuellas": "virtuell",
    "virtuellast": "virtuell",
    "virtuellaste": "virtuell",
    "virtuellastes": "virtuell",
    "virtuellasts": "virtuell",
    "virtuelle": "virtuell",
    "virtuelles": "virtuell",
    "virtuells": "virtuell",
    "virtuellt": "virtuell",
    "virtuellts": "virtuell",
    "virtuosa": "virtuos",
    "virtuosare": "virtuos",
    "virtuosares": "virtuos",
    "virtuosas": "virtuos",
    "virtuosast": "virtuos",
    "virtuosaste": "virtuos",
    "virtuosastes": "virtuos",
    "virtuosasts": "virtuos",
    "virtuose": "virtuos",
    "virtuosen": "virtuos",
    "virtuosens": "virtuos",
    "virtuoser": "virtuos",
    "virtuoserna": "virtuos",
    "virtuosernas": "virtuos",
    "virtuosers": "virtuos",
    "virtuoses": "virtuos",
    "virtuositeten": "virtuositet",
    "virtuositetens": "virtuositet",
    "virtuositeter": "virtuositet",
    "virtuositeterna": "virtuositet",
    "virtuositeternas": "virtuositet",
    "virtuositeters": "virtuositet",
    "virtuositets": "virtuositet",
    "virtuosmässiga": "virtuosmässig",
    "virtuosmässigare": "virtuosmässig",
    "virtuosmässigares": "virtuosmässig",
    "virtuosmässigas": "virtuosmässig",
    "virtuosmässigast": "virtuosmässig",
    "virtuosmässigaste": "virtuosmässig",
    "virtuosmässigastes": "virtuosmässig",
    "virtuosmässigasts": "virtuosmässig",
    "virtuosmässige": "virtuosmässig",
    "virtuosmässiges": "virtuosmässig",
    "virtuosmässigheten": "virtuosmässighet",
    "virtuosmässighetens": "virtuosmässighet",
    "virtuosmässighets": "virtuosmässighet",
    "virtuosmässigs": "virtuosmässig",
    "virtuosmässigt": "virtuosmässig",
    "virtuosmässigts": "virtuosmässig",
    "virtuosnummerna": "virtuosnummer",
    "virtuosnummernas": "virtuosnummer",
    "virtuosnummers": "virtuosnummer",
    "virtuosnumren": "virtuosnummer",
    "virtuosnumrens": "virtuosnummer",
    "virtuosnumret": "virtuosnummer",
    "virtuosnumrets": "virtuosnummer",
    "virtuost": "virtuos",
    "virtuosts": "virtuos",
    "virulensen": "virulens",
    "virulensens": "virulens",
    "virulenta": "virulent",
    "virulentare": "virulent",
    "virulentares": "virulent",
    "virulentas": "virulent",
    "virulentast": "virulent",
    "virulentaste": "virulent",
    "virulentastes": "virulent",
    "virulentasts": "virulent",
    "virulente": "virulent",
    "virulentes": "virulent",
    "virulents": "virulent",
    "virusen": "virus",
    "virusens": "virus",
    "virusepidemien": "virusepidemi",
    "virusepidemiens": "virusepidemi",
    "virusepidemier": "virusepidemi",
    "virusepidemierna": "virusepidemi",
    "virusepidemiernas": "virusepidemi",
    "virusepidemiers": "virusepidemi",
    "virusepidemin": "virusepidemi",
    "virusepidemins": "virusepidemi",
    "virusepidemis": "virusepidemi",
    "viruset": "virus",
    "virusets": "virus",
    "virusinfektionen": "virusinfektion",
    "virusinfektionens": "virusinfektion",
    "virusinfektioner": "virusinfektion",
    "virusinfektionerna": "virusinfektion",
    "virusinfektionernas": "virusinfektion",
    "virusinfektioners": "virusinfektion",
    "virusinfektions": "virusinfektion",
    "virusrisken": "virusrisk",
    "virusriskens": "virusrisk",
    "virusrisker": "virusrisk",
    "virusriskerna": "virusrisk",
    "virusriskernas": "virusrisk",
    "virusriskers": "virusrisk",
    "virusrisks": "virusrisk",
    "virussjukdomar": "virussjukdom",
    "virussjukdomarna": "virussjukdom",
    "virussjukdomarnas": "virussjukdom",
    "virussjukdomars": "virussjukdom",
    "virussjukdomen": "virussjukdom",
    "virussjukdomens": "virussjukdom",
    "virussjukdoms": "virussjukdom",
    "virvel": "virvla",
    "virveln": "virvel",
    "virvelns": "virvel",
    "virvelrörelsen": "virvelrörelse",
    "virvelrörelsens": "virvelrörelse",
    "virvelrörelser": "virvelrörelse",
    "virvelrörelserna": "virvelrörelse",
    "virvelrörelsernas": "virvelrörelse",
    "virvelrörelsers": "virvelrörelse",
    "virvelrörelses": "virvelrörelse",
    "virvels": "virvel",
    "virvelstormar": "virvelstorm",
    "virvelstormarna": "virvelstorm",
    "virvelstormarnas": "virvelstorm",
    "virvelstormars": "virvelstorm",
    "virvelstormen": "virvelstorm",
    "virvelstormens": "virvelstorm",
    "virvelstorms": "virvelstorm",
    "virvelströmmar": "virvelström",
    "virvelströmmarna": "virvelström",
    "virvelströmmarnas": "virvelström",
    "virvelströmmars": "virvelström",
    "virvelströmmen": "virvelström",
    "virvelströmmens": "virvelström",
    "virvelströms": "virvelström",
    "virvelvindar": "virvelvind",
    "virvelvindarna": "virvelvind",
    "virvelvindarnas": "virvelvind",
    "virvelvindars": "virvelvind",
    "virvelvinden": "virvelvind",
    "virvelvindens": "virvelvind",
    "virvelvinds": "virvelvind",
    "virvlad": "virvla",
    "virvlade": "virvla",
    "virvlades": "virvla",
    "virvlads": "virvla",
    "virvlande": "virvla",
    "virvlanden": "virvlande",
    "virvlandena": "virvlande",
    "virvlandenas": "virvlande",
    "virvlandens": "virvlande",
    "virvlandes": "virvlande",
    "virvlandet": "virvlande",
    "virvlandets": "virvlande",
    "virvlar": "virvla",
    "virvlarna": "virvel",
    "virvlarnas": "virvel",
    "virvlars": "virvel",
    "virvlas": "virvla",
    "virvlat": "virvla",
    "virvlats": "virvla",
    "vis": "vise",
    "visa": "visum",
    "visad": "visa",
    "visade": "visa",
    "visades": "visa",
    "visads": "visa",
    "visaftnar": "visafton",
    "visaftnarna": "visafton",
    "visaftnarnas": "visafton",
    "visaftnars": "visafton",
    "visaftonen": "visafton",
    "visaftonens": "visafton",
    "visaftons": "visafton",
    "visakorten": "visakort",
    "visakortet": "visakort",
    "visakortets": "visakort",
    "visakorts": "visakort",
    "visan": "visa",
    "visana": "visum",
    "visanas": "visum",
    "visande": "visa",
    "visanden": "visande",
    "visandena": "visande",
    "visandenas": "visande",
    "visandens": "visande",
    "visandes": "visande",
    "visandet": "visande",
    "visandets": "visande",
    "visans": "visa",
    "visar": "vise",
    "visare": "vis",
    "visaren": "visare",
    "visarens": "visare",
    "visares": "visare",
    "visarkiven": "visarkiv",
    "visarkivens": "visarkiv",
    "visarkivet": "visarkiv",
    "visarkivets": "visarkiv",
    "visarkivs": "visarkiv",
    "visarna": "vise",
    "visarnas": "vise",
    "visars": "vise",
    "visas": "visum",
    "visast": "vis",
    "visaste": "vis",
    "visastes": "vis",
    "visasts": "vis",
    "visat": "visa",
    "visats": "visa",
    "visboken": "visbok",
    "visbokens": "visbok",
    "visboks": "visbok",
    "visböcker": "visbok",
    "visböckerna": "visbok",
    "visböckernas": "visbok",
    "visböckers": "visbok",
    "visch": "vischa",
    "vischan": "vischa",
    "vischans": "vischa",
    "vischas": "vischa",
    "vische": "vischa",
    "vischor": "vischa",
    "vischorna": "vischa",
    "vischornas": "vischa",
    "vischors": "vischa",
    "viscounten": "viscount",
    "viscountens": "viscount",
    "viscounter": "viscount",
    "viscounterna": "viscount",
    "viscounternas": "viscount",
    "viscounters": "viscount",
    "viscounts": "viscount",
    "visdomar": "visdom",
    "visdomarna": "visdom",
    "visdomarnas": "visdom",
    "visdomars": "visdom",
    "visdomen": "visdom",
    "visdomens": "visdom",
    "visdoms": "visdom",
    "visdomskäll": "visdomskälla",
    "visdomskällan": "visdomskälla",
    "visdomskällans": "visdomskälla",
    "visdomskällas": "visdomskälla",
    "visdomskälle": "visdomskälla",
    "visdomskällor": "visdomskälla",
    "visdomskällorna": "visdomskälla",
    "visdomskällornas": "visdomskälla",
    "visdomskällors": "visdomskälla",
    "visdomskälls": "visdomskälla",
    "visdomsorden": "visdomsord",
    "visdomsordens": "visdomsord",
    "visdomsordet": "visdomsord",
    "visdomsordets": "visdomsord",
    "visdomsords": "visdomsord",
    "visdomstanden": "visdomstand",
    "visdomstandens": "visdomstand",
    "visdomstands": "visdomstand",
    "visdomständer": "visdomstand",
    "visdomständerna": "visdomstand",
    "visdomständernas": "visdomstand",
    "visdomständers": "visdomstand",
    "vise": "visa",
    "visefallen": "visefall",
    "visefallens": "visefall",
    "visefallet": "visefall",
    "visefallets": "visefall",
    "visefalls": "visefall",
    "visen": "vise",
    "visens": "vise",
    "visenten": "visent",
    "visentens": "visent",
    "visenter": "visent",
    "visenterna": "visent",
    "visenternas": "visent",
    "visenters": "visent",
    "visents": "visent",
    "viserad": "visera",
    "viserade": "visera",
    "viserades": "visera",
    "viserads": "visera",
    "viserande": "visera",
    "viseranden": "viserande",
    "viserandena": "viserande",
    "viserandenas": "viserande",
    "viserandens": "viserande",
    "viserandes": "viserande",
    "viserandet": "viserande",
    "viserandets": "viserande",
    "viserar": "visera",
    "viseras": "visera",
    "viserat": "visera",
    "viserats": "visera",
    "viserbara": "viserbar",
    "viserbarare": "viserbar",
    "viserbarares": "viserbar",
    "viserbaras": "viserbar",
    "viserbarast": "viserbar",
    "viserbaraste": "viserbar",
    "viserbarastes": "viserbar",
    "viserbarasts": "viserbar",
    "viserbare": "viserbar",
    "viserbares": "viserbar",
    "viserbarheten": "viserbarhet",
    "viserbarhetens": "viserbarhet",
    "viserbarhets": "viserbarhet",
    "viserbars": "viserbar",
    "viserbart": "viserbar",
    "viserbarts": "viserbar",
    "viseringar": "visering",
    "viseringarna": "visering",
    "viseringarnas": "visering",
    "viseringars": "visering",
    "viseringen": "visering",
    "viseringens": "visering",
    "viserings": "visering",
    "viseringskorten": "viseringskort",
    "viseringskortens": "viseringskort",
    "viseringskortet": "viseringskort",
    "viseringskortets": "viseringskort",
    "viseringskorts": "viseringskort",
    "vises": "vise",
    "viset": "vis",
    "visets": "vis",
    "visheten": "vishet",
    "vishetens": "vishet",
    "visheter": "vishet",
    "visheterna": "vishet",
    "visheternas": "vishet",
    "visheters": "vishet",
    "vishets": "vishet",
    "vishetsläran": "vishetslära",
    "vishetslärans": "vishetslära",
    "vishetsläras": "vishetslära",
    "vishetsläre": "vishetslära",
    "vishetsläro": "vishetslära",
    "vishetsläror": "vishetslära",
    "vishetslärorna": "vishetslära",
    "vishetslärornas": "vishetslära",
    "vishetslärors": "vishetslära",
    "visibels": "visibel",
    "visibelt": "visibel",
    "visibelts": "visibel",
    "visibla": "visibel",
    "visiblare": "visibel",
    "visiblares": "visibel",
    "visiblas": "visibel",
    "visiblast": "visibel",
    "visiblaste": "visibel",
    "visiblastes": "visibel",
    "visiblasts": "visibel",
    "visible": "visibel",
    "visibles": "visibel",
    "visionen": "vision",
    "visionens": "vision",
    "visioner": "vision",
    "visionerna": "vision",
    "visionernas": "vision",
    "visioners": "vision",
    "visions": "vision",
    "visionära": "visionär",
    "visionärare": "visionär",
    "visionärares": "visionär",
    "visionäras": "visionär",
    "visionärast": "visionär",
    "visionäraste": "visionär",
    "visionärastes": "visionär",
    "visionärasts": "visionär",
    "visionäre": "visionär",
    "visionäres": "visionär",
    "visionärs": "visionär",
    "visionärt": "visionär",
    "visionärts": "visionär",
    "visiren": "visir",
    "visirens": "visir",
    "visirer": "visir",
    "visirerna": "visir",
    "visirernas": "visir",
    "visirers": "visir",
    "visiret": "visir",
    "visirets": "visir",
    "visirlinjen": "visirlinje",
    "visirlinjens": "visirlinje",
    "visirlinjes": "visirlinje",
    "visirs": "visir",
    "visirskivan": "visirskiva",
    "visirskivans": "visirskiva",
    "visirskivas": "visirskiva",
    "visirskive": "visirskiva",
    "visirskivor": "visirskiva",
    "visirskivorna": "visirskiva",
    "visirskivornas": "visirskiva",
    "visirskivors": "visirskiva",
    "visitationen": "visitation",
    "visitationens": "visitation",
    "visitationer": "visitation",
    "visitationerna": "visitation",
    "visitationernas": "visitation",
    "visitationers": "visitation",
    "visitations": "visitation",
    "visitatorer": "visitator",
    "visitatorerna": "visitator",
    "visitatorernas": "visitator",
    "visitatorers": "visitator",
    "visitatorn": "visitator",
    "visitatorns": "visitator",
    "visitators": "visitator",
    "visiten": "visit",
    "visitens": "visit",
    "visiter": "visit",
    "visiterad": "visitera",
    "visiterade": "visitera",
    "visiterades": "visitera",
    "visiterads": "visitera",
    "visiterande": "visitera",
    "visiteranden": "visiterande",
    "visiterandena": "visiterande",
    "visiterandenas": "visiterande",
    "visiterandens": "visiterande",
    "visiterandes": "visiterande",
    "visiterandet": "visiterande",
    "visiterandets": "visiterande",
    "visiterar": "visitera",
    "visiteras": "visitera",
    "visiterat": "visitera",
    "visiterats": "visitera",
    "visiterbara": "visiterbar",
    "visiterbarare": "visiterbar",
    "visiterbarares": "visiterbar",
    "visiterbaras": "visiterbar",
    "visiterbarast": "visiterbar",
    "visiterbaraste": "visiterbar",
    "visiterbarastes": "visiterbar",
    "visiterbarasts": "visiterbar",
    "visiterbare": "visiterbar",
    "visiterbares": "visiterbar",
    "visiterbarheten": "visiterbarhet",
    "visiterbarhetens": "visiterbarhet",
    "visiterbarhets": "visiterbarhet",
    "visiterbars": "visiterbar",
    "visiterbart": "visiterbar",
    "visiterbarts": "visiterbar",
    "visiteringar": "visitering",
    "visiteringarna": "visitering",
    "visiteringarnas": "visitering",
    "visiteringars": "visitering",
    "visiteringen": "visitering",
    "visiteringens": "visitering",
    "visiterings": "visitering",
    "visiterna": "visit",
    "visiternas": "visit",
    "visiters": "visit",
    "visitkorten": "visitkort",
    "visitkortens": "visitkort",
    "visitkortet": "visitkort",
    "visitkortets": "visitkort",
    "visitkorts": "visitkort",
    "visits": "visit",
    "visk": "viska",
    "viskad": "viska",
    "viskade": "viska",
    "viskades": "viska",
    "viskads": "viska",
    "viskan": "viska",
    "viskande": "viska",
    "viskanden": "viskande",
    "viskandena": "viskande",
    "viskandenas": "viskande",
    "viskandens": "viskande",
    "viskandes": "viskande",
    "viskandet": "viskande",
    "viskandets": "viskande",
    "viskans": "viska",
    "viskar": "viskare",
    "viskaren": "viskare",
    "viskarens": "viskare",
    "viskares": "viskare",
    "viskarna": "viskare",
    "viskarnas": "viskare",
    "viskas": "viska",
    "viskat": "viska",
    "viskats": "viska",
    "viske": "viska",
    "viskningar": "viskning",
    "viskningarna": "viskning",
    "viskningarnas": "viskning",
    "viskningars": "viskning",
    "viskningen": "viskning",
    "viskningens": "viskning",
    "visknings": "viskning",
    "viskor": "viska",
    "viskorna": "viska",
    "viskornas": "viska",
    "viskors": "viska",
    "viskosen": "viskos",
    "viskosens": "viskos",
    "viskositeten": "viskositet",
    "viskositetens": "viskositet",
    "viskositeter": "viskositet",
    "viskositeterna": "viskositet",
    "viskositeternas": "viskositet",
    "viskositeters": "viskositet",
    "viskositets": "viskositet",
    "viskösa": "viskös",
    "viskösare": "viskös",
    "viskösares": "viskös",
    "viskösas": "viskös",
    "viskösast": "viskös",
    "viskösaste": "viskös",
    "viskösastes": "viskös",
    "viskösasts": "viskös",
    "visköse": "viskös",
    "visköses": "viskös",
    "visköst": "viskös",
    "viskösts": "viskös",
    "visliga": "vislig",
    "visligare": "vislig",
    "visligares": "vislig",
    "visligas": "vislig",
    "visligast": "vislig",
    "visligaste": "vislig",
    "visligastes": "vislig",
    "visligasts": "vislig",
    "vislige": "vislig",
    "visliges": "vislig",
    "visligheten": "vislighet",
    "vislighetens": "vislighet",
    "vislighets": "vislighet",
    "visligs": "vislig",
    "visligt": "vislig",
    "visligts": "vislig",
    "vismannen": "visman",
    "vismannens": "visman",
    "vismans": "visman",
    "vismuten": "vismut",
    "vismutens": "vismut",
    "vismuts": "vismut",
    "vismän": "visman",
    "vismännen": "visman",
    "vismännens": "visman",
    "vismäns": "visman",
    "visningar": "visning",
    "visningarna": "visning",
    "visningarnas": "visning",
    "visningars": "visning",
    "visningen": "visning",
    "visningens": "visning",
    "visnings": "visning",
    "visor": "visa",
    "visorna": "visa",
    "visornas": "visa",
    "visors": "visa",
    "visp": "vispa",
    "vispad": "vispa",
    "vispade": "vispa",
    "vispades": "vispa",
    "vispads": "vispa",
    "vispande": "vispa",
    "vispanden": "vispande",
    "vispandena": "vispande",
    "vispandenas": "vispande",
    "vispandens": "vispande",
    "vispandes": "vispande",
    "vispandet": "vispande",
    "vispandets": "vispande",
    "vispar": "visper",
    "visparna": "visper",
    "visparnas": "visper",
    "vispars": "visper",
    "vispas": "vispa",
    "vispat": "vispa",
    "vispats": "vispa",
    "vispen": "visp",
    "vispens": "visp",
    "vispern": "visper",
    "visperns": "visper",
    "vispers": "visper",
    "vispet": "visp",
    "vispets": "visp",
    "vispgrädden": "vispgrädde",
    "vispgräddens": "vispgrädde",
    "vispgräddes": "vispgrädde",
    "vispiga": "vispig",
    "vispigare": "vispig",
    "vispigares": "vispig",
    "vispigas": "vispig",
    "vispigast": "vispig",
    "vispigaste": "vispig",
    "vispigastes": "vispig",
    "vispigasts": "vispig",
    "vispige": "vispig",
    "vispiges": "vispig",
    "vispigheten": "vispighet",
    "vispighetens": "vispighet",
    "vispighets": "vispighet",
    "vispigs": "vispig",
    "vispigt": "vispig",
    "vispigts": "vispig",
    "visprar": "visper",
    "visprarna": "visper",
    "visprarnas": "visper",
    "visprars": "visper",
    "visps": "visp",
    "vissa": "viss",
    "vissare": "viss",
    "vissares": "viss",
    "vissas": "viss",
    "vissast": "viss",
    "vissaste": "viss",
    "vissastes": "viss",
    "vissasts": "viss",
    "visse": "viss",
    "vissel": "vissla",
    "visselpip": "visselpipa",
    "visselpipan": "visselpipa",
    "visselpipans": "visselpipa",
    "visselpipas": "visselpipa",
    "visselpipe": "visselpipa",
    "visselpipor": "visselpipa",
    "visselpiporna": "visselpipa",
    "visselpipornas": "visselpipa",
    "visselpipors": "visselpipa",
    "visselpips": "visselpipa",
    "vissens": "vissen",
    "visses": "viss",
    "visset": "vissen",
    "vissets": "vissen",
    "vissheten": "visshet",
    "visshetens": "visshet",
    "vissheter": "visshet",
    "vissheterna": "visshet",
    "vissheternas": "visshet",
    "vissheters": "visshet",
    "visshets": "visshet",
    "visslad": "vissla",
    "visslade": "vissla",
    "visslades": "vissla",
    "visslads": "vissla",
    "visslan": "vissla",
    "visslande": "vissla",
    "visslanden": "visslande",
    "visslandena": "visslande",
    "visslandenas": "visslande",
    "visslandens": "visslande",
    "visslandes": "visslande",
    "visslandet": "visslande",
    "visslandets": "visslande",
    "visslans": "vissla",
    "visslar": "vissla",
    "visslas": "vissla",
    "visslat": "vissla",
    "visslats": "vissla",
    "vissle": "vissla",
    "visslingar": "vissling",
    "visslingarna": "vissling",
    "visslingarnas": "vissling",
    "visslingars": "vissling",
    "visslingen": "vissling",
    "visslingens": "vissling",
    "visslings": "vissling",
    "visslor": "vissla",
    "visslorna": "vissla",
    "visslornas": "vissla",
    "visslors": "vissla",
    "vissn": "vissna",
    "vissna": "vissen",
    "vissnad": "vissna",
    "vissnade": "vissna",
    "vissnades": "vissna",
    "vissnads": "vissna",
    "vissnande": "vissna",
    "vissnanden": "vissnande",
    "vissnandena": "vissnande",
    "vissnandenas": "vissnande",
    "vissnandens": "vissnande",
    "vissnandes": "vissnande",
    "vissnandet": "vissnande",
    "vissnandets": "vissnande",
    "vissnar": "vissna",
    "vissnare": "vissen",
    "vissnares": "vissen",
    "vissnas": "vissna",
    "vissnast": "vissen",
    "vissnaste": "vissen",
    "vissnastes": "vissen",
    "vissnasts": "vissen",
    "vissnat": "vissna",
    "vissnats": "vissna",
    "vissne": "vissen",
    "vissnes": "vissen",
    "vissnesjukan": "vissnesjuka",
    "vissnesjukans": "vissnesjuka",
    "vissnesjukas": "vissnesjuka",
    "vissnesjuke": "vissnesjuka",
    "vissnesjuks": "vissnesjuka",
    "visst": "viss",
    "visste": "veta",
    "visstidsanställningar": "visstidsanställning",
    "visstidsanställningarna": "visstidsanställning",
    "visstidsanställningarnas": "visstidsanställning",
    "visstidsanställningars": "visstidsanställning",
    "visstidsanställningen": "visstidsanställning",
    "visstidsanställningens": "visstidsanställning",
    "visstidsanställnings": "visstidsanställning",
    "visstidsförordnanden": "visstidsförordnande",
    "visstidsförordnandena": "visstidsförordnande",
    "visstidsförordnandenas": "visstidsförordnande",
    "visstidsförordnandens": "visstidsförordnande",
    "visstidsförordnandes": "visstidsförordnande",
    "visstidsförordnandet": "visstidsförordnande",
    "visstidsförordnandets": "visstidsförordnande",
    "vissts": "viss",
    "vissången": "vissång",
    "vissångens": "vissång",
    "vissångs": "vissång",
    "vist": "viste",
    "vistades": "vistas",
    "vistandes": "vistande",
    "vistandet": "vistande",
    "vistandets": "vistande",
    "vistats": "vistas",
    "vistelsen": "vistelse",
    "vistelsens": "vistelse",
    "vistelseorten": "vistelseort",
    "vistelseortens": "vistelseort",
    "vistelseorter": "vistelseort",
    "vistelseorterna": "vistelseort",
    "vistelseorternas": "vistelseort",
    "vistelseorters": "vistelseort",
    "vistelseorts": "vistelseort",
    "vistelser": "vistelse",
    "vistelserna": "vistelse",
    "vistelsernas": "vistelse",
    "vistelsers": "vistelse",
    "vistelses": "vistelse",
    "visten": "viste",
    "vistena": "viste",
    "vistenas": "viste",
    "vistens": "viste",
    "vistes": "viste",
    "vistet": "viste",
    "vistets": "viste",
    "visthusbodar": "visthusbod",
    "visthusbodarna": "visthusbod",
    "visthusbodarnas": "visthusbod",
    "visthusbodars": "visthusbod",
    "visthusboden": "visthusbod",
    "visthusbodens": "visthusbod",
    "visthusbods": "visthusbod",
    "visthusen": "visthus",
    "visthusens": "visthus",
    "visthuset": "visthus",
    "visthusets": "visthus",
    "vists": "vis",
    "visualiserad": "visualisera",
    "visualiserade": "visualisera",
    "visualiserades": "visualisera",
    "visualiserads": "visualisera",
    "visualiserande": "visualisera",
    "visualiseranden": "visualiserande",
    "visualiserandena": "visualiserande",
    "visualiserandenas": "visualiserande",
    "visualiserandens": "visualiserande",
    "visualiserandes": "visualiserande",
    "visualiserandet": "visualiserande",
    "visualiserandets": "visualiserande",
    "visualiserar": "visualisera",
    "visualiseras": "visualisera",
    "visualiserat": "visualisera",
    "visualiserats": "visualisera",
    "visualiserbara": "visualiserbar",
    "visualiserbarare": "visualiserbar",
    "visualiserbarares": "visualiserbar",
    "visualiserbaras": "visualiserbar",
    "visualiserbarast": "visualiserbar",
    "visualiserbaraste": "visualiserbar",
    "visualiserbarastes": "visualiserbar",
    "visualiserbarasts": "visualiserbar",
    "visualiserbare": "visualiserbar",
    "visualiserbares": "visualiserbar",
    "visualiserbarheten": "visualiserbarhet",
    "visualiserbarhetens": "visualiserbarhet",
    "visualiserbarhets": "visualiserbarhet",
    "visualiserbars": "visualiserbar",
    "visualiserbart": "visualiserbar",
    "visualiserbarts": "visualiserbar",
    "visualiseringar": "visualisering",
    "visualiseringarna": "visualisering",
    "visualiseringarnas": "visualisering",
    "visualiseringars": "visualisering",
    "visualiseringen": "visualisering",
    "visualiseringens": "visualisering",
    "visualiserings": "visualisering",
    "visuella": "visuell",
    "visuellare": "visuell",
    "visuellares": "visuell",
    "visuellas": "visuell",
    "visuellast": "visuell",
    "visuellaste": "visuell",
    "visuellastes": "visuell",
    "visuellasts": "visuell",
    "visuelle": "visuell",
    "visuelles": "visuell",
    "visuells": "visuell",
    "visuellt": "visuell",
    "visuellts": "visuell",
    "visumbrotten": "visumbrott",
    "visumbrottens": "visumbrott",
    "visumbrottet": "visumbrott",
    "visumbrottets": "visumbrott",
    "visumbrotts": "visumbrott",
    "visumen": "visum",
    "visumens": "visum",
    "visumet": "visum",
    "visumets": "visum",
    "visums": "visum",
    "vit": "vita",
    "vita": "vit",
    "vitaktiga": "vitaktig",
    "vitaktigare": "vitaktig",
    "vitaktigares": "vitaktig",
    "vitaktigas": "vitaktig",
    "vitaktigast": "vitaktig",
    "vitaktigaste": "vitaktig",
    "vitaktigastes": "vitaktig",
    "vitaktigasts": "vitaktig",
    "vitaktige": "vitaktig",
    "vitaktiges": "vitaktig",
    "vitaktigheten": "vitaktighet",
    "vitaktighetens": "vitaktighet",
    "vitaktighets": "vitaktighet",
    "vitaktigs": "vitaktig",
    "vitaktigt": "vitaktig",
    "vitaktigts": "vitaktig",
    "vitala": "vital",
    "vitalare": "vital",
    "vitalares": "vital",
    "vitalas": "vital",
    "vitalast": "vital",
    "vitalaste": "vital",
    "vitalastes": "vital",
    "vitalasts": "vital",
    "vitalbehoven": "vitalbehov",
    "vitalbehovens": "vitalbehov",
    "vitalbehovet": "vitalbehov",
    "vitalbehovets": "vitalbehov",
    "vitalbehovs": "vitalbehov",
    "vitale": "vital",
    "vitales": "vital",
    "vitalfen": "vitalf",
    "vitalfens": "vitalf",
    "vitalfer": "vitalf",
    "vitalferna": "vitalf",
    "vitalfernas": "vitalf",
    "vitalfers": "vitalf",
    "vitalfs": "vitalf",
    "vitalfärgningar": "vitalfärgning",
    "vitalfärgningarna": "vitalfärgning",
    "vitalfärgningarnas": "vitalfärgning",
    "vitalfärgningars": "vitalfärgning",
    "vitalfärgningen": "vitalfärgning",
    "vitalfärgningens": "vitalfärgning",
    "vitalfärgnings": "vitalfärgning",
    "vitalförnimmelsen": "vitalförnimmelse",
    "vitalförnimmelsens": "vitalförnimmelse",
    "vitalförnimmelser": "vitalförnimmelse",
    "vitalförnimmelserna": "vitalförnimmelse",
    "vitalförnimmelsernas": "vitalförnimmelse",
    "vitalförnimmelsers": "vitalförnimmelse",
    "vitalförnimmelses": "vitalförnimmelse",
    "vitaliserad": "vitalisera",
    "vitaliserade": "vitalisera",
    "vitaliserades": "vitalisera",
    "vitaliserads": "vitalisera",
    "vitaliserande": "vitalisera",
    "vitaliseranden": "vitaliserande",
    "vitaliserandena": "vitaliserande",
    "vitaliserandenas": "vitaliserande",
    "vitaliserandens": "vitaliserande",
    "vitaliserandes": "vitaliserande",
    "vitaliserandet": "vitaliserande",
    "vitaliserandets": "vitaliserande",
    "vitaliserar": "vitalisera",
    "vitaliseras": "vitalisera",
    "vitaliserat": "vitalisera",
    "vitaliserats": "vitalisera",
    "vitaliserbara": "vitaliserbar",
    "vitaliserbarare": "vitaliserbar",
    "vitaliserbarares": "vitaliserbar",
    "vitaliserbaras": "vitaliserbar",
    "vitaliserbarast": "vitaliserbar",
    "vitaliserbaraste": "vitaliserbar",
    "vitaliserbarastes": "vitaliserbar",
    "vitaliserbarasts": "vitaliserbar",
    "vitaliserbare": "vitaliserbar",
    "vitaliserbares": "vitaliserbar",
    "vitaliserbarheten": "vitaliserbarhet",
    "vitaliserbarhetens": "vitaliserbarhet",
    "vitaliserbarhets": "vitaliserbarhet",
    "vitaliserbars": "vitaliserbar",
    "vitaliserbart": "vitaliserbar",
    "vitaliserbarts": "vitaliserbar",
    "vitaliseringar": "vitalisering",
    "vitaliseringarna": "vitalisering",
    "vitaliseringarnas": "vitalisering",
    "vitaliseringars": "vitalisering",
    "vitaliseringen": "vitalisering",
    "vitaliseringens": "vitalisering",
    "vitaliserings": "vitalisering",
    "vitalismen": "vitalism",
    "vitalismens": "vitalism",
    "vitalismer": "vitalism",
    "vitalismerna": "vitalism",
    "vitalismernas": "vitalism",
    "vitalismers": "vitalism",
    "vitalisms": "vitalism",
    "vitalistiska": "vitalistisk",
    "vitalistiskas": "vitalistisk",
    "vitalistiske": "vitalistisk",
    "vitalistiskes": "vitalistisk",
    "vitalistisks": "vitalistisk",
    "vitalistiskt": "vitalistisk",
    "vitalistiskts": "vitalistisk",
    "vitaliteten": "vitalitet",
    "vitalitetens": "vitalitet",
    "vitaliteter": "vitalitet",
    "vitaliteterna": "vitalitet",
    "vitaliteternas": "vitalitet",
    "vitaliteters": "vitalitet",
    "vitalitets": "vitalitet",
    "vitalkapaciteten": "vitalkapacitet",
    "vitalkapacitetens": "vitalkapacitet",
    "vitalkapaciteter": "vitalkapacitet",
    "vitalkapaciteterna": "vitalkapacitet",
    "vitalkapaciteternas": "vitalkapacitet",
    "vitalkapaciteters": "vitalkapacitet",
    "vitalkapacitets": "vitalkapacitet",
    "vitalkraften": "vitalkraft",
    "vitalkraftens": "vitalkraft",
    "vitalkrafts": "vitalkraft",
    "vitals": "vital",
    "vitalt": "vital",
    "vitalts": "vital",
    "vitalven": "vitalv",
    "vitalvens": "vitalv",
    "vitalver": "vitalv",
    "vitalverna": "vitalv",
    "vitalvernas": "vitalv",
    "vitalvers": "vitalv",
    "vitalvs": "vitalv",
    "vitaminberikade": "vitaminberikad",
    "vitaminberikades": "vitaminberikad",
    "vitaminberikads": "vitaminberikad",
    "vitaminberikat": "vitaminberikad",
    "vitaminberikats": "vitaminberikad",
    "vitaminen": "vitamin",
    "vitaminens": "vitamin",
    "vitaminer": "vitamin",
    "vitaminerad": "vitaminera",
    "vitaminerade": "vitaminera",
    "vitaminerades": "vitaminera",
    "vitaminerads": "vitaminera",
    "vitaminerande": "vitaminera",
    "vitamineranden": "vitaminerande",
    "vitaminerandena": "vitaminerande",
    "vitaminerandenas": "vitaminerande",
    "vitaminerandens": "vitaminerande",
    "vitaminerandes": "vitaminerande",
    "vitaminerandet": "vitaminerande",
    "vitaminerandets": "vitaminerande",
    "vitaminerar": "vitaminera",
    "vitamineras": "vitaminera",
    "vitaminerat": "vitaminera",
    "vitaminerats": "vitaminera",
    "vitaminerbara": "vitaminerbar",
    "vitaminerbarare": "vitaminerbar",
    "vitaminerbarares": "vitaminerbar",
    "vitaminerbaras": "vitaminerbar",
    "vitaminerbarast": "vitaminerbar",
    "vitaminerbaraste": "vitaminerbar",
    "vitaminerbarastes": "vitaminerbar",
    "vitaminerbarasts": "vitaminerbar",
    "vitaminerbare": "vitaminerbar",
    "vitaminerbares": "vitaminerbar",
    "vitaminerbarheten": "vitaminerbarhet",
    "vitaminerbarhetens": "vitaminerbarhet",
    "vitaminerbarhets": "vitaminerbarhet",
    "vitaminerbars": "vitaminerbar",
    "vitaminerbart": "vitaminerbar",
    "vitaminerbarts": "vitaminerbar",
    "vitamineringar": "vitaminering",
    "vitamineringarna": "vitaminering",
    "vitamineringarnas": "vitaminering",
    "vitamineringars": "vitaminering",
    "vitamineringen": "vitaminering",
    "vitamineringens": "vitaminering",
    "vitaminerings": "vitaminering",
    "vitaminerna": "vitamin",
    "vitaminernas": "vitamin",
    "vitaminers": "vitamin",
    "vitaminet": "vitamin",
    "vitaminets": "vitamin",
    "vitamininjektionen": "vitamininjektion",
    "vitamininjektionens": "vitamininjektion",
    "vitamininjektioner": "vitamininjektion",
    "vitamininjektionerna": "vitamininjektion",
    "vitamininjektionernas": "vitamininjektion",
    "vitamininjektioners": "vitamininjektion",
    "vitamininjektions": "vitamininjektion",
    "vitaminiserad": "vitaminisera",
    "vitaminiserade": "vitaminisera",
    "vitaminiserades": "vitaminisera",
    "vitaminiserads": "vitaminisera",
    "vitaminiserande": "vitaminisera",
    "vitaminiseranden": "vitaminiserande",
    "vitaminiserandena": "vitaminiserande",
    "vitaminiserandenas": "vitaminiserande",
    "vitaminiserandens": "vitaminiserande",
    "vitaminiserandes": "vitaminiserande",
    "vitaminiserandet": "vitaminiserande",
    "vitaminiserandets": "vitaminiserande",
    "vitaminiserar": "vitaminisera",
    "vitaminiseras": "vitaminisera",
    "vitaminiserat": "vitaminisera",
    "vitaminiserats": "vitaminisera",
    "vitaminiserbara": "vitaminiserbar",
    "vitaminiserbarare": "vitaminiserbar",
    "vitaminiserbarares": "vitaminiserbar",
    "vitaminiserbaras": "vitaminiserbar",
    "vitaminiserbarast": "vitaminiserbar",
    "vitaminiserbaraste": "vitaminiserbar",
    "vitaminiserbarastes": "vitaminiserbar",
    "vitaminiserbarasts": "vitaminiserbar",
    "vitaminiserbare": "vitaminiserbar",
    "vitaminiserbares": "vitaminiserbar",
    "vitaminiserbarheten": "vitaminiserbarhet",
    "vitaminiserbarhetens": "vitaminiserbarhet",
    "vitaminiserbarhets": "vitaminiserbarhet",
    "vitaminiserbars": "vitaminiserbar",
    "vitaminiserbart": "vitaminiserbar",
    "vitaminiserbarts": "vitaminiserbar",
    "vitaminiseringar": "vitaminisering",
    "vitaminiseringarna": "vitaminisering",
    "vitaminiseringarnas": "vitaminisering",
    "vitaminiseringars": "vitaminisering",
    "vitaminiseringen": "vitaminisering",
    "vitaminiseringens": "vitaminisering",
    "vitaminiserings": "vitaminisering",
    "vitaminrika": "vitaminrik",
    "vitaminrikare": "vitaminrik",
    "vitaminrikares": "vitaminrik",
    "vitaminrikas": "vitaminrik",
    "vitaminrikast": "vitaminrik",
    "vitaminrikaste": "vitaminrik",
    "vitaminrikastes": "vitaminrik",
    "vitaminrikasts": "vitaminrik",
    "vitaminrike": "vitaminrik",
    "vitaminrikes": "vitaminrik",
    "vitaminrikheten": "vitaminrikhet",
    "vitaminrikhetens": "vitaminrikhet",
    "vitaminrikhets": "vitaminrikhet",
    "vitaminriks": "vitaminrik",
    "vitaminrikt": "vitaminrik",
    "vitaminrikts": "vitaminrik",
    "vitamins": "vitamin",
    "vitan": "vita",
    "vitans": "vita",
    "vitare": "vit",
    "vitares": "vit",
    "vitas": "vita",
    "vitast": "vit",
    "vitaste": "vit",
    "vitastes": "vit",
    "vitasts": "vit",
    "vitaxigheten": "vitaxighet",
    "vitaxighetens": "vitaxighet",
    "vitaxighets": "vitaxighet",
    "vitbet": "vitbeta",
    "vitbetan": "vitbeta",
    "vitbetans": "vitbeta",
    "vitbetas": "vitbeta",
    "vitbete": "vitbeta",
    "vitbetor": "vitbeta",
    "vitbetorna": "vitbeta",
    "vitbetornas": "vitbeta",
    "vitbetors": "vitbeta",
    "vitbets": "vitbeta",
    "vitblecket": "vitbleck",
    "vitbleckets": "vitbleck",
    "vitblecks": "vitbleck",
    "vitblåa": "vitblå",
    "vitblåare": "vitblå",
    "vitblåares": "vitblå",
    "vitblåas": "vitblå",
    "vitblåast": "vitblå",
    "vitblåaste": "vitblå",
    "vitblåastes": "vitblå",
    "vitblåasts": "vitblå",
    "vitblåe": "vitblå",
    "vitblåes": "vitblå",
    "vitblås": "vitblå",
    "vitblått": "vitblå",
    "vitblåtts": "vitblå",
    "vitboken": "vitbok",
    "vitbokens": "vitbok",
    "vitboks": "vitbok",
    "vitbroderier": "vitbroderi",
    "vitbroderierna": "vitbroderi",
    "vitbroderiernas": "vitbroderi",
    "vitbroderiers": "vitbroderi",
    "vitbroderiet": "vitbroderi",
    "vitbroderiets": "vitbroderi",
    "vitbroderis": "vitbroderi",
    "vitbroderit": "vitbroderi",
    "vitbroderits": "vitbroderi",
    "vitböcker": "vitbok",
    "vitböckerna": "vitbok",
    "vitböckernas": "vitbok",
    "vitböckers": "vitbok",
    "vite": "vita",
    "viten": "vite",
    "vitena": "vite",
    "vitenas": "vite",
    "vitens": "vite",
    "viter": "vitra",
    "vites": "vite",
    "vitet": "vite",
    "vitets": "vite",
    "vitfiskar": "vitfisk",
    "vitfiskarna": "vitfisk",
    "vitfiskarnas": "vitfisk",
    "vitfiskars": "vitfisk",
    "vitfisken": "vitfisk",
    "vitfiskens": "vitfisk",
    "vitfisks": "vitfisk",
    "vitglödg": "vitglödga",
    "vitglödgad": "vitglödga",
    "vitglödgade": "vitglödga",
    "vitglödgades": "vitglödga",
    "vitglödgads": "vitglödga",
    "vitglödgande": "vitglödga",
    "vitglödganden": "vitglödgande",
    "vitglödgandena": "vitglödgande",
    "vitglödgandenas": "vitglödgande",
    "vitglödgandens": "vitglödgande",
    "vitglödgandes": "vitglödgande",
    "vitglödgandet": "vitglödgande",
    "vitglödgandets": "vitglödgande",
    "vitglödgar": "vitglödga",
    "vitglödgas": "vitglödga",
    "vitglödgat": "vitglödga",
    "vitglödgats": "vitglödga",
    "vitgråa": "vitgrå",
    "vitgråare": "vitgrå",
    "vitgråares": "vitgrå",
    "vitgråas": "vitgrå",
    "vitgråast": "vitgrå",
    "vitgråaste": "vitgrå",
    "vitgråastes": "vitgrå",
    "vitgråasts": "vitgrå",
    "vitgråe": "vitgrå",
    "vitgråes": "vitgrå",
    "vitgrås": "vitgrå",
    "vitgrått": "vitgrå",
    "vitgråtts": "vitgrå",
    "vitgröna": "vitgrön",
    "vitgrönare": "vitgrön",
    "vitgrönares": "vitgrön",
    "vitgrönas": "vitgrön",
    "vitgrönast": "vitgrön",
    "vitgrönaste": "vitgrön",
    "vitgrönastes": "vitgrön",
    "vitgrönasts": "vitgrön",
    "vitgröne": "vitgrön",
    "vitgrönes": "vitgrön",
    "vitgröns": "vitgrön",
    "vitgrönt": "vitgrön",
    "vitgrönts": "vitgrön",
    "vitheten": "vithet",
    "vithetens": "vithet",
    "vitheter": "vithet",
    "vitheterna": "vithet",
    "vitheternas": "vithet",
    "vitheters": "vithet",
    "vithets": "vithet",
    "vithyllta": "vithyllt",
    "vithylltare": "vithyllt",
    "vithylltares": "vithyllt",
    "vithylltas": "vithyllt",
    "vithylltast": "vithyllt",
    "vithylltaste": "vithyllt",
    "vithylltastes": "vithyllt",
    "vithylltasts": "vithyllt",
    "vithyllte": "vithyllt",
    "vithylltes": "vithyllt",
    "vithylltheten": "vithyllthet",
    "vithyllthetens": "vithyllthet",
    "vithyllthets": "vithyllthet",
    "vithyllts": "vithyllt",
    "vithåriga": "vithårig",
    "vithårigare": "vithårig",
    "vithårigares": "vithårig",
    "vithårigas": "vithårig",
    "vithårigast": "vithårig",
    "vithårigaste": "vithårig",
    "vithårigastes": "vithårig",
    "vithårigasts": "vithårig",
    "vithårige": "vithårig",
    "vithåriges": "vithårig",
    "vithårigheten": "vithårighet",
    "vithårighetens": "vithårighet",
    "vithårighets": "vithårighet",
    "vithårigs": "vithårig",
    "vithårigt": "vithårig",
    "vithårigts": "vithårig",
    "vitiligon": "vitiligo",
    "vitiligons": "vitiligo",
    "vitiligos": "vitiligo",
    "vitkalk": "vitkalka",
    "vitkalkad": "vitkalka",
    "vitkalkade": "vitkalka",
    "vitkalkades": "vitkalka",
    "vitkalkads": "vitkalka",
    "vitkalkande": "vitkalka",
    "vitkalkanden": "vitkalkande",
    "vitkalkandena": "vitkalkande",
    "vitkalkandenas": "vitkalkande",
    "vitkalkandens": "vitkalkande",
    "vitkalkandes": "vitkalkande",
    "vitkalkandet": "vitkalkande",
    "vitkalkandets": "vitkalkande",
    "vitkalkar": "vitkalka",
    "vitkalkas": "vitkalka",
    "vitkalkat": "vitkalka",
    "vitkalkats": "vitkalka",
    "vitklövern": "vitklöver",
    "vitklöverns": "vitklöver",
    "vitklövers": "vitklöver",
    "vitkålen": "vitkål",
    "vitkålens": "vitkål",
    "vitkåls": "vitkål",
    "vitlimmad": "vitlimma",
    "vitlimmade": "vitlimma",
    "vitlimmades": "vitlimma",
    "vitlimmads": "vitlimma",
    "vitlimmande": "vitlimma",
    "vitlimmanden": "vitlimmande",
    "vitlimmandena": "vitlimmande",
    "vitlimmandenas": "vitlimmande",
    "vitlimmandens": "vitlimmande",
    "vitlimmandes": "vitlimmande",
    "vitlimmandet": "vitlimmande",
    "vitlimmandets": "vitlimmande",
    "vitlimmar": "vitlimma",
    "vitlimmas": "vitlimma",
    "vitlimmat": "vitlimma",
    "vitlimmats": "vitlimma",
    "vitlingar": "vitling",
    "vitlingarna": "vitling",
    "vitlingarnas": "vitling",
    "vitlingars": "vitling",
    "vitlingen": "vitling",
    "vitlingens": "vitling",
    "vitlinglyr": "vitlinglyra",
    "vitlinglyran": "vitlinglyra",
    "vitlinglyrans": "vitlinglyra",
    "vitlinglyras": "vitlinglyra",
    "vitlinglyre": "vitlinglyra",
    "vitlinglyror": "vitlinglyra",
    "vitlinglyrorna": "vitlinglyra",
    "vitlinglyrornas": "vitlinglyra",
    "vitlinglyrors": "vitlinglyra",
    "vitlinglyrs": "vitlinglyra",
    "vitlings": "vitling",
    "vitlökar": "vitlök",
    "vitlökarna": "vitlök",
    "vitlökarnas": "vitlök",
    "vitlökars": "vitlök",
    "vitlöken": "vitlök",
    "vitlökens": "vitlök",
    "vitlöks": "vitlök",
    "vitlöksklyft": "vitlöksklyfta",
    "vitlöksklyftan": "vitlöksklyfta",
    "vitlöksklyftans": "vitlöksklyfta",
    "vitlöksklyftas": "vitlöksklyfta",
    "vitlöksklyfte": "vitlöksklyfta",
    "vitlöksklyftor": "vitlöksklyfta",
    "vitlöksklyftorna": "vitlöksklyfta",
    "vitlöksklyftornas": "vitlöksklyfta",
    "vitlöksklyftors": "vitlöksklyfta",
    "vitlöksklyfts": "vitlöksklyfta",
    "vitmen": "vitmena",
    "vitmenad": "vitmena",
    "vitmenade": "vitmena",
    "vitmenades": "vitmena",
    "vitmenads": "vitmena",
    "vitmenande": "vitmena",
    "vitmenanden": "vitmenande",
    "vitmenandena": "vitmenande",
    "vitmenandenas": "vitmenande",
    "vitmenandens": "vitmenande",
    "vitmenandes": "vitmenande",
    "vitmenandet": "vitmenande",
    "vitmenandets": "vitmenande",
    "vitmenar": "vitmena",
    "vitmenas": "vitmena",
    "vitmenat": "vitmena",
    "vitmenats": "vitmena",
    "vitmetallen": "vitmetall",
    "vitmetallens": "vitmetall",
    "vitmetaller": "vitmetall",
    "vitmetallerna": "vitmetall",
    "vitmetallernas": "vitmetall",
    "vitmetallers": "vitmetall",
    "vitmetalls": "vitmetall",
    "vitmossan": "vitmossa",
    "vitmossans": "vitmossa",
    "vitmossas": "vitmossa",
    "vitmässingen": "vitmässing",
    "vitmässingens": "vitmässing",
    "vitmässings": "vitmässing",
    "vitmålade": "vitmålad",
    "vitmålades": "vitmålad",
    "vitmålads": "vitmålad",
    "vitmålat": "vitmålad",
    "vitmålats": "vitmålad",
    "vitmår": "vitmåra",
    "vitmåran": "vitmåra",
    "vitmårans": "vitmåra",
    "vitmåras": "vitmåra",
    "vitmåre": "vitmåra",
    "vitmåror": "vitmåra",
    "vitmårorna": "vitmåra",
    "vitmårornas": "vitmåra",
    "vitmårors": "vitmåra",
    "vitmårs": "vitmåra",
    "vitmögelostar": "vitmögelost",
    "vitmögelostarna": "vitmögelost",
    "vitmögelostarnas": "vitmögelost",
    "vitmögelostars": "vitmögelost",
    "vitmögelosten": "vitmögelost",
    "vitmögelostens": "vitmögelost",
    "vitmögelosts": "vitmögelost",
    "vitnad": "vitna",
    "vitnade": "vitna",
    "vitnaden": "vitnad",
    "vitnadens": "vitnad",
    "vitnader": "vitnad",
    "vitnaderna": "vitnad",
    "vitnadernas": "vitnad",
    "vitnaders": "vitnad",
    "vitnades": "vitna",
    "vitnads": "vitnad",
    "vitnande": "vitna",
    "vitnanden": "vitnande",
    "vitnandena": "vitnande",
    "vitnandenas": "vitnande",
    "vitnandens": "vitnande",
    "vitnandes": "vitnande",
    "vitnandet": "vitnande",
    "vitnandets": "vitnande",
    "vitnar": "vitna",
    "vitnas": "vitna",
    "vitnat": "vitna",
    "vitnats": "vitna",
    "vitnosar": "vitnos",
    "vitnosarna": "vitnos",
    "vitnosarnas": "vitnos",
    "vitnosars": "vitnos",
    "vitnosen": "vitnos",
    "vitnosens": "vitnos",
    "vitor": "vita",
    "vitorna": "vita",
    "vitornas": "vita",
    "vitors": "vita",
    "vitpepparn": "vitpeppar",
    "vitpepparns": "vitpeppar",
    "vitpeppars": "vitpeppar",
    "vitplistern": "vitplister",
    "vitplisterns": "vitplister",
    "vitplisters": "vitplister",
    "vitplistrar": "vitplister",
    "vitplistrarna": "vitplister",
    "vitplistrarnas": "vitplister",
    "vitplistrars": "vitplister",
    "vitputsade": "vitputsad",
    "vitputsades": "vitputsad",
    "vitputsads": "vitputsad",
    "vitputsat": "vitputsad",
    "vitputsats": "vitputsad",
    "vitrad": "vitra",
    "vitrade": "vitra",
    "vitrades": "vitra",
    "vitrads": "vitra",
    "vitrande": "vitra",
    "vitranden": "vitrande",
    "vitrandena": "vitrande",
    "vitrandenas": "vitrande",
    "vitrandens": "vitrande",
    "vitrandes": "vitrande",
    "vitrandet": "vitrande",
    "vitrandets": "vitrande",
    "vitrar": "vitra",
    "vitras": "vitra",
    "vitrat": "vitra",
    "vitrats": "vitra",
    "vitrinen": "vitrin",
    "vitrinens": "vitrin",
    "vitriner": "vitrin",
    "vitrinerna": "vitrin",
    "vitrinernas": "vitrin",
    "vitriners": "vitrin",
    "vitrins": "vitrin",
    "vitrinskåpen": "vitrinskåp",
    "vitrinskåpens": "vitrinskåp",
    "vitrinskåpet": "vitrinskåp",
    "vitrinskåpets": "vitrinskåp",
    "vitrinskåps": "vitrinskåp",
    "vitriolen": "vitriol",
    "vitriolens": "vitriol",
    "vitriolet": "vitriol",
    "vitriolets": "vitriol",
    "vitriololjan": "vitriololja",
    "vitriololjans": "vitriololja",
    "vitriololjas": "vitriololja",
    "vitriololje": "vitriololja",
    "vitriols": "vitriol",
    "vitrockar": "vitrock",
    "vitrockarna": "vitrock",
    "vitrockarnas": "vitrock",
    "vitrockars": "vitrock",
    "vitrocken": "vitrock",
    "vitrockens": "vitrock",
    "vitrocks": "vitrock",
    "vitrysk": "vitryska",
    "vitryska": "vitrysk",
    "vitryskan": "vitryska",
    "vitryskans": "vitryska",
    "vitryskare": "vitrysk",
    "vitryskares": "vitrysk",
    "vitryskas": "vitryska",
    "vitryskast": "vitrysk",
    "vitryskaste": "vitrysk",
    "vitryskastes": "vitrysk",
    "vitryskasts": "vitrysk",
    "vitryske": "vitryska",
    "vitryskes": "vitrysk",
    "vitryskor": "vitryska",
    "vitryskorna": "vitryska",
    "vitryskornas": "vitryska",
    "vitryskors": "vitryska",
    "vitrysks": "vitrysk",
    "vitryskt": "vitrysk",
    "vitryskts": "vitrysk",
    "vitryssar": "vitryss",
    "vitryssarna": "vitryss",
    "vitryssarnas": "vitryss",
    "vitryssars": "vitryss",
    "vitryssen": "vitryss",
    "vitryssens": "vitryss",
    "viträvar": "viträv",
    "viträvarna": "viträv",
    "viträvarnas": "viträv",
    "viträvars": "viträv",
    "viträven": "viträv",
    "viträvens": "viträv",
    "viträvs": "viträv",
    "vits": "vitsa",
    "vitsad": "vitsa",
    "vitsade": "vitsa",
    "vitsades": "vitsa",
    "vitsads": "vitsa",
    "vitsande": "vitsa",
    "vitsanden": "vitsande",
    "vitsandena": "vitsande",
    "vitsandenas": "vitsande",
    "vitsandens": "vitsande",
    "vitsandes": "vitsande",
    "vitsandet": "vitsande",
    "vitsandets": "vitsande",
    "vitsar": "vitsa",
    "vitsarna": "vits",
    "vitsarnas": "vits",
    "vitsars": "vits",
    "vitsas": "vitsa",
    "vitsat": "vitsa",
    "vitsats": "vitsa",
    "vitsen": "vits",
    "vitsens": "vits",
    "vitsiga": "vitsig",
    "vitsigare": "vitsig",
    "vitsigares": "vitsig",
    "vitsigas": "vitsig",
    "vitsigast": "vitsig",
    "vitsigaste": "vitsig",
    "vitsigastes": "vitsig",
    "vitsigasts": "vitsig",
    "vitsige": "vitsig",
    "vitsiges": "vitsig",
    "vitsigheten": "vitsighet",
    "vitsighetens": "vitsighet",
    "vitsigheter": "vitsighet",
    "vitsigheterna": "vitsighet",
    "vitsigheternas": "vitsighet",
    "vitsigheters": "vitsighet",
    "vitsighets": "vitsighet",
    "vitsigs": "vitsig",
    "vitsigt": "vitsig",
    "vitsigts": "vitsig",
    "vitsipp": "vitsippa",
    "vitsippan": "vitsippa",
    "vitsippans": "vitsippa",
    "vitsippas": "vitsippa",
    "vitsippe": "vitsippa",
    "vitsippor": "vitsippa",
    "vitsipporna": "vitsippa",
    "vitsippornas": "vitsippa",
    "vitsippors": "vitsippa",
    "vitsipps": "vitsippa",
    "vitslammade": "vitslammad",
    "vitslammades": "vitslammad",
    "vitslammads": "vitslammad",
    "vitslammat": "vitslammad",
    "vitslammats": "vitslammad",
    "vitsord": "vitsorda",
    "vitsordad": "vitsorda",
    "vitsordade": "vitsorda",
    "vitsordades": "vitsorda",
    "vitsordads": "vitsorda",
    "vitsordande": "vitsorda",
    "vitsordanden": "vitsordande",
    "vitsordandena": "vitsordande",
    "vitsordandenas": "vitsordande",
    "vitsordandens": "vitsordande",
    "vitsordandes": "vitsordande",
    "vitsordandet": "vitsordande",
    "vitsordandets": "vitsordande",
    "vitsordar": "vitsorda",
    "vitsordas": "vitsorda",
    "vitsordat": "vitsorda",
    "vitsordats": "vitsorda",
    "vitsorden": "vitsord",
    "vitsordens": "vitsord",
    "vitsordet": "vitsord",
    "vitsordets": "vitsord",
    "vitsords": "vitsord",
    "vitsvanshjortar": "vitsvanshjort",
    "vitsvanshjortarna": "vitsvanshjort",
    "vitsvanshjortarnas": "vitsvanshjort",
    "vitsvanshjortars": "vitsvanshjort",
    "vitsvanshjorten": "vitsvanshjort",
    "vitsvanshjortens": "vitsvanshjort",
    "vitsvanshjorts": "vitsvanshjort",
    "vitt": "vitta",
    "vittad": "vitta",
    "vittade": "vitta",
    "vittades": "vitta",
    "vittads": "vitta",
    "vittande": "vitta",
    "vittanden": "vittande",
    "vittandena": "vittande",
    "vittandenas": "vittande",
    "vittandens": "vittande",
    "vittandes": "vittande",
    "vittandet": "vittande",
    "vittandets": "vittande",
    "vittar": "vitta",
    "vittas": "vitta",
    "vittat": "vitta",
    "vittats": "vitta",
    "vittbekanta": "vittbekant",
    "vittbekantare": "vittbekant",
    "vittbekantares": "vittbekant",
    "vittbekantas": "vittbekant",
    "vittbekantast": "vittbekant",
    "vittbekantaste": "vittbekant",
    "vittbekantastes": "vittbekant",
    "vittbekantasts": "vittbekant",
    "vittbekante": "vittbekant",
    "vittbekantes": "vittbekant",
    "vittbekants": "vittbekant",
    "vittberesta": "vittberest",
    "vittberestare": "vittberest",
    "vittberestares": "vittberest",
    "vittberestas": "vittberest",
    "vittberestast": "vittberest",
    "vittberestaste": "vittberest",
    "vittberestastes": "vittberest",
    "vittberestasts": "vittberest",
    "vittbereste": "vittberest",
    "vittberestes": "vittberest",
    "vittberestheten": "vittberesthet",
    "vittberesthetens": "vittberesthet",
    "vittberesthets": "vittberesthet",
    "vittberests": "vittberest",
    "vittberömda": "vittberömd",
    "vittberömdare": "vittberömd",
    "vittberömdares": "vittberömd",
    "vittberömdas": "vittberömd",
    "vittberömdast": "vittberömd",
    "vittberömdaste": "vittberömd",
    "vittberömdastes": "vittberömd",
    "vittberömdasts": "vittberömd",
    "vittberömde": "vittberömd",
    "vittberömdes": "vittberömd",
    "vittberömdheten": "vittberömdhet",
    "vittberömdhetens": "vittberömdhet",
    "vittberömdhets": "vittberömdhet",
    "vittberömds": "vittberömd",
    "vittberömt": "vittberömd",
    "vittberömts": "vittberömd",
    "vitterfolket": "vitterfolk",
    "vitterfolkets": "vitterfolk",
    "vitterfolks": "vitterfolk",
    "vitterheten": "vitterhet",
    "vitterhetens": "vitterhet",
    "vitterheter": "vitterhet",
    "vitterheterna": "vitterhet",
    "vitterheternas": "vitterhet",
    "vitterheters": "vitterhet",
    "vitterhets": "vitterhet",
    "vitterlekar": "vitterlek",
    "vitterlekarna": "vitterlek",
    "vitterlekarnas": "vitterlek",
    "vitterlekars": "vitterlek",
    "vitterleken": "vitterlek",
    "vitterlekens": "vitterlek",
    "vitterleks": "vitterlek",
    "vitters": "vitter",
    "vittert": "vitter",
    "vitterts": "vitter",
    "vittförgrenade": "vittförgrenad",
    "vittförgrenades": "vittförgrenad",
    "vittförgrenads": "vittförgrenad",
    "vittförgrenat": "vittförgrenad",
    "vittförgrenats": "vittförgrenad",
    "vittj": "vittja",
    "vittjad": "vittja",
    "vittjade": "vittja",
    "vittjades": "vittja",
    "vittjads": "vittja",
    "vittjande": "vittja",
    "vittjanden": "vittjande",
    "vittjandena": "vittjande",
    "vittjandenas": "vittjande",
    "vittjandens": "vittjande",
    "vittjandes": "vittjande",
    "vittjandet": "vittjande",
    "vittjandets": "vittjande",
    "vittjar": "vittja",
    "vittjas": "vittja",
    "vittjat": "vittja",
    "vittjats": "vittja",
    "vittlingar": "vittling",
    "vittlingarna": "vittling",
    "vittlingarnas": "vittling",
    "vittlingars": "vittling",
    "vittlingen": "vittling",
    "vittlingens": "vittling",
    "vittlinglyr": "vittlinglyra",
    "vittlinglyran": "vittlinglyra",
    "vittlinglyrans": "vittlinglyra",
    "vittlinglyras": "vittlinglyra",
    "vittlinglyre": "vittlinglyra",
    "vittlinglyror": "vittlinglyra",
    "vittlinglyrorna": "vittlinglyra",
    "vittlinglyrornas": "vittlinglyra",
    "vittlinglyrors": "vittlinglyra",
    "vittlinglyrs": "vittlinglyra",
    "vittlings": "vittling",
    "vittnad": "vittna",
    "vittnade": "vittna",
    "vittnades": "vittna",
    "vittnads": "vittna",
    "vittnande": "vittna",
    "vittnanden": "vittnande",
    "vittnandena": "vittnande",
    "vittnandenas": "vittnande",
    "vittnandens": "vittnande",
    "vittnandes": "vittnande",
    "vittnandet": "vittnande",
    "vittnandets": "vittnande",
    "vittnar": "vittna",
    "vittnas": "vittna",
    "vittnat": "vittna",
    "vittnats": "vittna",
    "vittnen": "vittne",
    "vittnena": "vittne",
    "vittnenas": "vittne",
    "vittnens": "vittne",
    "vittnes": "vittne",
    "vittnesbåsen": "vittnesbås",
    "vittnesbåsens": "vittnesbås",
    "vittnesbåset": "vittnesbås",
    "vittnesbåsets": "vittnesbås",
    "vittnesbörden": "vittnesbörd",
    "vittnesbördens": "vittnesbörd",
    "vittnesbördet": "vittnesbörd",
    "vittnesbördets": "vittnesbörd",
    "vittnesbörds": "vittnesbörd",
    "vittneseden": "vittnesed",
    "vittnesedens": "vittnesed",
    "vittneseder": "vittnesed",
    "vittnesederna": "vittnesed",
    "vittnesedernas": "vittnesed",
    "vittneseders": "vittnesed",
    "vittneseds": "vittnesed",
    "vittnesgilla": "vittnesgill",
    "vittnesgillare": "vittnesgill",
    "vittnesgillares": "vittnesgill",
    "vittnesgillas": "vittnesgill",
    "vittnesgillast": "vittnesgill",
    "vittnesgillaste": "vittnesgill",
    "vittnesgillastes": "vittnesgill",
    "vittnesgillasts": "vittnesgill",
    "vittnesgille": "vittnesgill",
    "vittnesgilles": "vittnesgill",
    "vittnesgillheten": "vittnesgillhet",
    "vittnesgillhetens": "vittnesgillhet",
    "vittnesgillhets": "vittnesgillhet",
    "vittnesgills": "vittnesgill",
    "vittnesgillt": "vittnesgill",
    "vittnesgillts": "vittnesgill",
    "vittneskonfrontationen": "vittneskonfrontation",
    "vittneskonfrontationens": "vittneskonfrontation",
    "vittneskonfrontationer": "vittneskonfrontation",
    "vittneskonfrontationerna": "vittneskonfrontation",
    "vittneskonfrontationernas": "vittneskonfrontation",
    "vittneskonfrontationers": "vittneskonfrontation",
    "vittneskonfrontations": "vittneskonfrontation",
    "vittnesmålen": "vittnesmål",
    "vittnesmålens": "vittnesmål",
    "vittnesmålet": "vittnesmål",
    "vittnesmålets": "vittnesmål",
    "vittnesmåls": "vittnesmål",
    "vittnespsykologien": "vittnespsykologi",
    "vittnespsykologiens": "vittnespsykologi",
    "vittnespsykologin": "vittnespsykologi",
    "vittnespsykologins": "vittnespsykologi",
    "vittnespsykologis": "vittnespsykologi",
    "vittnesskranken": "vittnesskrank",
    "vittnesskrankens": "vittnesskrank",
    "vittnesskranket": "vittnesskrank",
    "vittnesskrankets": "vittnesskrank",
    "vittnesskranks": "vittnesskrank",
    "vittnesuppgiften": "vittnesuppgift",
    "vittnesuppgiftens": "vittnesuppgift",
    "vittnesuppgifter": "vittnesuppgift",
    "vittnesuppgifterna": "vittnesuppgift",
    "vittnesuppgifternas": "vittnesuppgift",
    "vittnesuppgifters": "vittnesuppgift",
    "vittnesuppgifts": "vittnesuppgift",
    "vittnesutsagan": "vittnesutsaga",
    "vittnesutsagans": "vittnesutsaga",
    "vittnesutsagas": "vittnesutsaga",
    "vittnesutsage": "vittnesutsaga",
    "vittnesutsago": "vittnesutsaga",
    "vittnesutsagor": "vittnesutsaga",
    "vittnesutsagorna": "vittnesutsaga",
    "vittnesutsagornas": "vittnesutsaga",
    "vittnesutsagors": "vittnesutsaga",
    "vittnet": "vittne",
    "vittnets": "vittne",
    "vittr": "vittra",
    "vittra": "vitter",
    "vittrad": "vittra",
    "vittrade": "vittra",
    "vittrades": "vittra",
    "vittrads": "vittra",
    "vittran": "vittra",
    "vittrande": "vittra",
    "vittranden": "vittrande",
    "vittrandena": "vittrande",
    "vittrandenas": "vittrande",
    "vittrandens": "vittrande",
    "vittrandes": "vittrande",
    "vittrandet": "vittrande",
    "vittrandets": "vittrande",
    "vittrans": "vittra",
    "vittrar": "vittra",
    "vittrare": "vitter",
    "vittrares": "vitter",
    "vittras": "vittra",
    "vittrast": "vitter",
    "vittraste": "vitter",
    "vittrastes": "vitter",
    "vittrasts": "vitter",
    "vittrat": "vittra",
    "vittrats": "vittra",
    "vittre": "vittra",
    "vittres": "vitter",
    "vittringar": "vittring",
    "vittringarna": "vittring",
    "vittringarnas": "vittring",
    "vittringars": "vittring",
    "vittringen": "vittring",
    "vittringens": "vittring",
    "vittrings": "vittring",
    "vittror": "vittra",
    "vittrorna": "vittra",
    "vittrornas": "vittra",
    "vittrors": "vittra",
    "vittrs": "vittra",
    "vitts": "vit",
    "vittviner": "vittvin",
    "vittvinerna": "vittvin",
    "vittvinernas": "vittvin",
    "vittviners": "vittvin",
    "vittvinet": "vittvin",
    "vittvinets": "vittvin",
    "vittvins": "vittvin",
    "vittvätten": "vittvätt",
    "vittvättens": "vittvätt",
    "vittvätts": "vittvätt",
    "vitvar": "vitvara",
    "vitvaran": "vitvara",
    "vitvarans": "vitvara",
    "vitvaras": "vitvara",
    "vitvaror": "vitvara",
    "vitvarorna": "vitvara",
    "vitvarornas": "vitvara",
    "vitvarors": "vitvara",
    "vitvaru": "vitvara",
    "vitveden": "vitved",
    "vitvedens": "vitved",
    "vitveds": "vitved",
    "vitviner": "vitvin",
    "vitvinerna": "vitvin",
    "vitvinernas": "vitvin",
    "vitviners": "vitvin",
    "vitvinet": "vitvin",
    "vitvinets": "vitvin",
    "vitvins": "vitvin",
    "vitögats": "vitögat",
    "viv": "viva",
    "vivaciteten": "vivacitet",
    "vivacitetens": "vivacitet",
    "vivaciteter": "vivacitet",
    "vivaciteterna": "vivacitet",
    "vivaciteternas": "vivacitet",
    "vivaciteters": "vivacitet",
    "vivacitets": "vivacitet",
    "vivan": "viva",
    "vivans": "viva",
    "vivas": "viva",
    "vive": "viva",
    "viveln": "vivel",
    "vivelns": "vivel",
    "vivels": "vivel",
    "viven": "viv",
    "vivens": "viv",
    "vivet": "viv",
    "vivets": "viv",
    "vivianiten": "vivianit",
    "vivianitens": "vivianit",
    "vivianits": "vivianit",
    "vivipara": "vivipar",
    "viviparare": "vivipar",
    "viviparares": "vivipar",
    "viviparas": "vivipar",
    "viviparast": "vivipar",
    "viviparaste": "vivipar",
    "viviparastes": "vivipar",
    "viviparasts": "vivipar",
    "vivipare": "vivipar",
    "vivipares": "vivipar",
    "vivipars": "vivipar",
    "vivipart": "vivipar",
    "viviparts": "vivipar",
    "vivisektionen": "vivisektion",
    "vivisektionens": "vivisektion",
    "vivisektioner": "vivisektion",
    "vivisektionerna": "vivisektion",
    "vivisektionernas": "vivisektion",
    "vivisektioners": "vivisektion",
    "vivisektions": "vivisektion",
    "vivisektören": "vivisektör",
    "vivisektörens": "vivisektör",
    "vivisektörer": "vivisektör",
    "vivisektörerna": "vivisektör",
    "vivisektörernas": "vivisektör",
    "vivisektörers": "vivisektör",
    "vivisektörs": "vivisektör",
    "vivlar": "vivel",
    "vivlarna": "vivel",
    "vivlarnas": "vivel",
    "vivlars": "vivel",
    "vivor": "viva",
    "vivorna": "viva",
    "vivornas": "viva",
    "vivors": "viva",
    "vivs": "viva",
    "vivören": "vivör",
    "vivörens": "vivör",
    "vivörer": "vivör",
    "vivörerna": "vivör",
    "vivörernas": "vivör",
    "vivörers": "vivör",
    "vivörs": "vivör",
    "voallen": "voall",
    "voallens": "voall",
    "voaller": "voall",
    "voallerna": "voall",
    "voallernas": "voall",
    "voallers": "voall",
    "voalls": "voall",
    "vobblern": "vobbler",
    "vobblerna": "vobbler",
    "vobblernas": "vobbler",
    "vobblerns": "vobbler",
    "vobblers": "vobbler",
    "vobblersarna": "vobbler",
    "vobblersarnas": "vobbler",
    "vobblersen": "vobbler",
    "vobblersens": "vobbler",
    "vodkaglasen": "vodkaglas",
    "vodkaglasens": "vodkaglas",
    "vodkaglaset": "vodkaglas",
    "vodkaglasets": "vodkaglas",
    "vodkan": "vodka",
    "vodkans": "vodka",
    "vodkas": "vodka",
    "voffel": "voffla",
    "vofflan": "voffla",
    "vofflans": "voffla",
    "vofflas": "voffla",
    "voffle": "voffla",
    "vofflor": "voffla",
    "vofflorna": "voffla",
    "vofflornas": "voffla",
    "vofflors": "voffla",
    "voidkoefficienten": "voidkoefficient",
    "voidkoefficientens": "voidkoefficient",
    "voidkoefficienter": "voidkoefficient",
    "voidkoefficienterna": "voidkoefficient",
    "voidkoefficienternas": "voidkoefficient",
    "voidkoefficienters": "voidkoefficient",
    "voidkoefficients": "voidkoefficient",
    "voilen": "voile",
    "voilens": "voile",
    "voiles": "voile",
    "vojlockar": "vojlock",
    "vojlockarna": "vojlock",
    "vojlockarnas": "vojlock",
    "vojlockars": "vojlock",
    "vojlocken": "vojlock",
    "vojlockens": "vojlock",
    "vojlocks": "vojlock",
    "vokabeln": "vokabel",
    "vokabelns": "vokabel",
    "vokabels": "vokabel",
    "vokabelsamlingar": "vokabelsamling",
    "vokabelsamlingarna": "vokabelsamling",
    "vokabelsamlingarnas": "vokabelsamling",
    "vokabelsamlingars": "vokabelsamling",
    "vokabelsamlingen": "vokabelsamling",
    "vokabelsamlingens": "vokabelsamling",
    "vokabelsamlings": "vokabelsamling",
    "vokabler": "vokabel",
    "vokablerna": "vokabel",
    "vokablernas": "vokabel",
    "vokablers": "vokabel",
    "vokabulären": "vokabulär",
    "vokabulärens": "vokabulär",
    "vokabulärer": "vokabulär",
    "vokabulärerna": "vokabulär",
    "vokabulärernas": "vokabulär",
    "vokabulärers": "vokabulär",
    "vokabulärs": "vokabulär",
    "vokala": "vokal",
    "vokalare": "vokal",
    "vokalares": "vokal",
    "vokalas": "vokal",
    "vokalast": "vokal",
    "vokalaste": "vokal",
    "vokalastes": "vokal",
    "vokalasts": "vokal",
    "vokalbalansen": "vokalbalans",
    "vokalbalansens": "vokalbalans",
    "vokale": "vokal",
    "vokalen": "vokal",
    "vokalens": "vokal",
    "vokaler": "vokal",
    "vokalerna": "vokal",
    "vokalernas": "vokal",
    "vokalers": "vokal",
    "vokales": "vokal",
    "vokalharmonien": "vokalharmoni",
    "vokalharmoniens": "vokalharmoni",
    "vokalharmonier": "vokalharmoni",
    "vokalharmonierna": "vokalharmoni",
    "vokalharmoniernas": "vokalharmoni",
    "vokalharmoniers": "vokalharmoni",
    "vokalharmonin": "vokalharmoni",
    "vokalharmonins": "vokalharmoni",
    "vokalharmonis": "vokalharmoni",
    "vokalisationen": "vokalisation",
    "vokalisationens": "vokalisation",
    "vokalisationer": "vokalisation",
    "vokalisationerna": "vokalisation",
    "vokalisationernas": "vokalisation",
    "vokalisationers": "vokalisation",
    "vokalisations": "vokalisation",
    "vokalisen": "vokalis",
    "vokalisens": "vokalis",
    "vokaliser": "vokalis",
    "vokaliserad": "vokalisera",
    "vokaliserade": "vokalisera",
    "vokaliserades": "vokalisera",
    "vokaliserads": "vokalisera",
    "vokaliserande": "vokalisera",
    "vokaliseranden": "vokaliserande",
    "vokaliserandena": "vokaliserande",
    "vokaliserandenas": "vokaliserande",
    "vokaliserandens": "vokaliserande",
    "vokaliserandes": "vokaliserande",
    "vokaliserandet": "vokaliserande",
    "vokaliserandets": "vokaliserande",
    "vokaliserar": "vokalisera",
    "vokaliseras": "vokalisera",
    "vokaliserat": "vokalisera",
    "vokaliserats": "vokalisera",
    "vokaliserbara": "vokaliserbar",
    "vokaliserbarare": "vokaliserbar",
    "vokaliserbarares": "vokaliserbar",
    "vokaliserbaras": "vokaliserbar",
    "vokaliserbarast": "vokaliserbar",
    "vokaliserbaraste": "vokaliserbar",
    "vokaliserbarastes": "vokaliserbar",
    "vokaliserbarasts": "vokaliserbar",
    "vokaliserbare": "vokaliserbar",
    "vokaliserbares": "vokaliserbar",
    "vokaliserbarheten": "vokaliserbarhet",
    "vokaliserbarhetens": "vokaliserbarhet",
    "vokaliserbarhets": "vokaliserbarhet",
    "vokaliserbars": "vokaliserbar",
    "vokaliserbart": "vokaliserbar",
    "vokaliserbarts": "vokaliserbar",
    "vokaliseringar": "vokalisering",
    "vokaliseringarna": "vokalisering",
    "vokaliseringarnas": "vokalisering",
    "vokaliseringars": "vokalisering",
    "vokaliseringen": "vokalisering",
    "vokaliseringens": "vokalisering",
    "vokaliserings": "vokalisering",
    "vokaliserna": "vokalis",
    "vokalisernas": "vokalis",
    "vokalisers": "vokalis",
    "vokaliska": "vokalisk",
    "vokaliskare": "vokalisk",
    "vokaliskares": "vokalisk",
    "vokaliskas": "vokalisk",
    "vokaliskast": "vokalisk",
    "vokaliskaste": "vokalisk",
    "vokaliskastes": "vokalisk",
    "vokaliskasts": "vokalisk",
    "vokaliske": "vokalisk",
    "vokaliskes": "vokalisk",
    "vokalisks": "vokalisk",
    "vokaliskt": "vokalisk",
    "vokaliskts": "vokalisk",
    "vokalismen": "vokalism",
    "vokalismens": "vokalism",
    "vokalismer": "vokalism",
    "vokalismerna": "vokalism",
    "vokalismernas": "vokalism",
    "vokalismers": "vokalism",
    "vokalisms": "vokalism",
    "vokaliss": "vokalissa",
    "vokalissan": "vokalissa",
    "vokalissans": "vokalissa",
    "vokalissas": "vokalissa",
    "vokalisse": "vokalissa",
    "vokalissor": "vokalissa",
    "vokalissorna": "vokalissa",
    "vokalissornas": "vokalissa",
    "vokalissors": "vokalissa",
    "vokalisten": "vokalist",
    "vokalistens": "vokalist",
    "vokalister": "vokalist",
    "vokalisterna": "vokalist",
    "vokalisternas": "vokalist",
    "vokalisters": "vokalist",
    "vokalists": "vokalist",
    "vokalkvaliteten": "vokalkvalitet",
    "vokalkvalitetens": "vokalkvalitet",
    "vokalkvaliteter": "vokalkvalitet",
    "vokalkvaliteterna": "vokalkvalitet",
    "vokalkvaliteternas": "vokalkvalitet",
    "vokalkvaliteters": "vokalkvalitet",
    "vokalkvalitets": "vokalkvalitet",
    "vokalkvantiteten": "vokalkvantitet",
    "vokalkvantitetens": "vokalkvantitet",
    "vokalkvantiteter": "vokalkvantitet",
    "vokalkvantiteterna": "vokalkvantitet",
    "vokalkvantiteternas": "vokalkvantitet",
    "vokalkvantiteters": "vokalkvantitet",
    "vokalkvantitets": "vokalkvantitet",
    "vokallängden": "vokallängd",
    "vokallängdens": "vokallängd",
    "vokallängder": "vokallängd",
    "vokallängderna": "vokallängd",
    "vokallängdernas": "vokallängd",
    "vokallängders": "vokallängd",
    "vokallängds": "vokallängd",
    "vokalmumlet": "vokalmummel",
    "vokalmumlets": "vokalmummel",
    "vokalmummels": "vokalmummel",
    "vokalmusiken": "vokalmusik",
    "vokalmusikens": "vokalmusik",
    "vokalmusiks": "vokalmusik",
    "vokalmöten": "vokalmöte",
    "vokalmötena": "vokalmöte",
    "vokalmötenas": "vokalmöte",
    "vokalmötens": "vokalmöte",
    "vokalmötes": "vokalmöte",
    "vokalmötet": "vokalmöte",
    "vokalmötets": "vokalmöte",
    "vokalrimmen": "vokalrim",
    "vokalrimmens": "vokalrim",
    "vokalrimmet": "vokalrim",
    "vokalrimmets": "vokalrim",
    "vokalrims": "vokalrim",
    "vokals": "vokal",
    "vokalt": "vokal",
    "vokalts": "vokal",
    "vokalväxlingar": "vokalväxling",
    "vokalväxlingarna": "vokalväxling",
    "vokalväxlingarnas": "vokalväxling",
    "vokalväxlingars": "vokalväxling",
    "vokalväxlingen": "vokalväxling",
    "vokalväxlingens": "vokalväxling",
    "vokalväxlings": "vokalväxling",
    "vokativen": "vokativ",
    "vokativens": "vokativ",
    "vokativer": "vokativ",
    "vokativerna": "vokativ",
    "vokativernas": "vokativ",
    "vokativers": "vokativ",
    "vokativs": "vokativ",
    "volangen": "volang",
    "volangens": "volang",
    "volanger": "volang",
    "volangerna": "volang",
    "volangernas": "volang",
    "volangers": "volang",
    "volangs": "volang",
    "volapüks": "volapük",
    "volauventen": "volauvent",
    "volauventens": "volauvent",
    "volauventer": "volauvent",
    "volauventerna": "volauvent",
    "volauventernas": "volauvent",
    "volauventers": "volauvent",
    "volauvents": "volauvent",
    "volframen": "volfram",
    "volframens": "volfram",
    "volframet": "volfram",
    "volframets": "volfram",
    "volframnålar": "volframnål",
    "volframnålarna": "volframnål",
    "volframnålarnas": "volframnål",
    "volframnålars": "volframnål",
    "volframnålen": "volframnål",
    "volframnålens": "volframnål",
    "volframnåls": "volframnål",
    "volframs": "volfram",
    "voljären": "voljär",
    "voljärens": "voljär",
    "voljärer": "voljär",
    "voljärerna": "voljär",
    "voljärernas": "voljär",
    "voljärers": "voljär",
    "voljärs": "voljär",
    "volleybollar": "volleyboll",
    "volleybollarna": "volleyboll",
    "volleybollarnas": "volleyboll",
    "volleybollars": "volleyboll",
    "volleybollen": "volleyboll",
    "volleybollens": "volleyboll",
    "volleybolls": "volleyboll",
    "volleyn": "volley",
    "volleyns": "volley",
    "volleys": "volley",
    "volm": "volma",
    "volmad": "volma",
    "volmade": "volma",
    "volmades": "volma",
    "volmads": "volma",
    "volmande": "volma",
    "volmanden": "volmande",
    "volmandena": "volmande",
    "volmandenas": "volmande",
    "volmandens": "volmande",
    "volmandes": "volmande",
    "volmandet": "volmande",
    "volmandets": "volmande",
    "volmar": "volma",
    "volmarna": "volm",
    "volmarnas": "volm",
    "volmars": "volm",
    "volmas": "volma",
    "volmat": "volma",
    "volmats": "volma",
    "volmen": "volm",
    "volmens": "volm",
    "volms": "volm",
    "volontären": "volontär",
    "volontärens": "volontär",
    "volontärer": "volontär",
    "volontärerna": "volontär",
    "volontärernas": "volontär",
    "volontärers": "volontär",
    "volontärs": "volontär",
    "volt": "volta",
    "voltad": "volta",
    "voltade": "volta",
    "voltades": "volta",
    "voltads": "volta",
    "voltan": "volta",
    "voltande": "volta",
    "voltanden": "voltande",
    "voltandena": "voltande",
    "voltandenas": "voltande",
    "voltandens": "voltande",
    "voltandes": "voltande",
    "voltandet": "voltande",
    "voltandets": "voltande",
    "voltanen": "voltan",
    "voltanens": "voltan",
    "voltaner": "voltan",
    "voltanerna": "voltan",
    "voltanernas": "voltan",
    "voltaners": "voltan",
    "voltans": "voltan",
    "voltar": "volta",
    "voltas": "volta",
    "voltat": "volta",
    "voltats": "volta",
    "volten": "volt",
    "voltens": "volt",
    "volter": "volt",
    "volterna": "volt",
    "volternas": "volt",
    "volters": "volt",
    "voltigen": "voltige",
    "voltigens": "voltige",
    "voltiger": "voltige",
    "voltigerade": "voltigera",
    "voltigerades": "voltigera",
    "voltigerande": "voltigera",
    "voltigeranden": "voltigerande",
    "voltigerandena": "voltigerande",
    "voltigerandenas": "voltigerande",
    "voltigerandens": "voltigerande",
    "voltigerandes": "voltigerande",
    "voltigerandet": "voltigerande",
    "voltigerandets": "voltigerande",
    "voltigerar": "voltigera",
    "voltigeras": "voltigera",
    "voltigerat": "voltigera",
    "voltigerats": "voltigera",
    "voltigeringar": "voltigering",
    "voltigeringarna": "voltigering",
    "voltigeringarnas": "voltigering",
    "voltigeringars": "voltigering",
    "voltigeringen": "voltigering",
    "voltigeringens": "voltigering",
    "voltigerings": "voltigering",
    "voltigerna": "voltige",
    "voltigernas": "voltige",
    "voltigers": "voltige",
    "voltiges": "voltige",
    "voltigören": "voltigör",
    "voltigörens": "voltigör",
    "voltigörer": "voltigör",
    "voltigörerna": "voltigör",
    "voltigörernas": "voltigör",
    "voltigörers": "voltigör",
    "voltigörs": "voltigör",
    "voltmetern": "voltmeter",
    "voltmeterns": "voltmeter",
    "voltmeters": "voltmeter",
    "voltmetrar": "voltmeter",
    "voltmetrarna": "voltmeter",
    "voltmetrarnas": "voltmeter",
    "voltmetrars": "voltmeter",
    "voltmätar": "voltmätare",
    "voltmätaren": "voltmätare",
    "voltmätarens": "voltmätare",
    "voltmätares": "voltmätare",
    "voltmätarna": "voltmätare",
    "voltmätarnas": "voltmätare",
    "voltor": "volta",
    "voltorna": "volta",
    "voltornas": "volta",
    "voltors": "volta",
    "volts": "volt",
    "volttalen": "volttal",
    "volttalens": "volttal",
    "volttalet": "volttal",
    "volttalets": "volttal",
    "volttals": "volttal",
    "voluminösa": "voluminös",
    "voluminösare": "voluminös",
    "voluminösares": "voluminös",
    "voluminösas": "voluminös",
    "voluminösast": "voluminös",
    "voluminösaste": "voluminös",
    "voluminösastes": "voluminös",
    "voluminösasts": "voluminös",
    "voluminöse": "voluminös",
    "voluminöses": "voluminös",
    "voluminöst": "voluminös",
    "voluminösts": "voluminös",
    "voluntarismen": "voluntarism",
    "voluntarismens": "voluntarism",
    "voluntarismer": "voluntarism",
    "voluntarismerna": "voluntarism",
    "voluntarismernas": "voluntarism",
    "voluntarismers": "voluntarism",
    "voluntarisms": "voluntarism",
    "voluntaristiska": "voluntaristisk",
    "voluntaristiskas": "voluntaristisk",
    "voluntaristiske": "voluntaristisk",
    "voluntaristiskes": "voluntaristisk",
    "voluntaristisks": "voluntaristisk",
    "voluntaristiskt": "voluntaristisk",
    "voluntaristiskts": "voluntaristisk",
    "voluten": "volut",
    "volutens": "volut",
    "voluter": "volut",
    "voluterna": "volut",
    "voluternas": "volut",
    "voluters": "volut",
    "voluts": "volut",
    "volvons": "volvo",
    "volvos": "volvo",
    "volymen": "volym",
    "volymenheten": "volymenhet",
    "volymenhetens": "volymenhet",
    "volymenheter": "volymenhet",
    "volymenheterna": "volymenhet",
    "volymenheternas": "volymenhet",
    "volymenheters": "volymenhet",
    "volymenhets": "volymenhet",
    "volymens": "volym",
    "volymer": "volym",
    "volymerna": "volym",
    "volymernas": "volym",
    "volymers": "volym",
    "volymmässiga": "volymmässig",
    "volymmässigare": "volymmässig",
    "volymmässigares": "volymmässig",
    "volymmässigas": "volymmässig",
    "volymmässigast": "volymmässig",
    "volymmässigaste": "volymmässig",
    "volymmässigastes": "volymmässig",
    "volymmässigasts": "volymmässig",
    "volymmässige": "volymmässig",
    "volymmässiges": "volymmässig",
    "volymmässigs": "volymmässig",
    "volymmässigt": "volymmässig",
    "volymmässigts": "volymmässig",
    "volymprocenten": "volymprocent",
    "volymprocentens": "volymprocent",
    "volymprocents": "volymprocent",
    "volyms": "volym",
    "volymsenheten": "volymsenhet",
    "volymsenhetens": "volymsenhet",
    "volymsenheter": "volymsenhet",
    "volymsenheterna": "volymsenhet",
    "volymsenheternas": "volymsenhet",
    "volymsenheters": "volymsenhet",
    "volymsenhets": "volymsenhet",
    "volymvikten": "volymvikt",
    "volymviktens": "volymvikt",
    "volymvikts": "volymvikt",
    "vombar": "vomb",
    "vombarna": "vomb",
    "vombarnas": "vomb",
    "vombars": "vomb",
    "vombaten": "vombat",
    "vombatens": "vombat",
    "vombater": "vombat",
    "vombaterna": "vombat",
    "vombaternas": "vombat",
    "vombaters": "vombat",
    "vombats": "vombat",
    "vomben": "vomb",
    "vombens": "vomb",
    "vombs": "vomb",
    "vomerade": "vomera",
    "vomerades": "vomera",
    "vomerande": "vomera",
    "vomeranden": "vomerande",
    "vomerandena": "vomerande",
    "vomerandenas": "vomerande",
    "vomerandens": "vomerande",
    "vomerandes": "vomerande",
    "vomerandet": "vomerande",
    "vomerandets": "vomerande",
    "vomerar": "vomera",
    "vomeras": "vomera",
    "vomerat": "vomera",
    "vomerats": "vomera",
    "vomeringar": "vomering",
    "vomeringarna": "vomering",
    "vomeringarnas": "vomering",
    "vomeringars": "vomering",
    "vomeringen": "vomering",
    "vomeringens": "vomering",
    "vomerings": "vomering",
    "vomitiven": "vomitiv",
    "vomitivens": "vomitiv",
    "vomitivet": "vomitiv",
    "vomitivets": "vomitiv",
    "vomitivs": "vomitiv",
    "vommar": "vom",
    "vommarna": "vom",
    "vommarnas": "vom",
    "vommars": "vom",
    "vommen": "vom",
    "vommens": "vom",
    "voms": "vom",
    "vons": "von",
    "voodoon": "voodoo",
    "voodoons": "voodoo",
    "voodoos": "voodoo",
    "vorden": "varda",
    "vordens": "varda",
    "vordet": "varda",
    "vordets": "varda",
    "vordna": "varda",
    "vordnas": "varda",
    "vordne": "varda",
    "vordnes": "varda",
    "vore": "vara",
    "vores": "vara",
    "vorstehhundar": "vorstehhund",
    "vorstehhundarna": "vorstehhund",
    "vorstehhundarnas": "vorstehhund",
    "vorstehhundars": "vorstehhund",
    "vorstehhunden": "vorstehhund",
    "vorstehhundens": "vorstehhund",
    "vorstehhunds": "vorstehhund",
    "vota": "votum",
    "votas": "votum",
    "voterade": "votera",
    "voterades": "votera",
    "voterande": "votera",
    "voteranden": "voterande",
    "voterandena": "voterande",
    "voterandenas": "voterande",
    "voterandens": "voterande",
    "voterandes": "voterande",
    "voterandet": "voterande",
    "voterandets": "voterande",
    "voterar": "votera",
    "voteras": "votera",
    "voterat": "votera",
    "voterats": "votera",
    "voteringar": "votering",
    "voteringarna": "votering",
    "voteringarnas": "votering",
    "voteringars": "votering",
    "voteringen": "votering",
    "voteringens": "votering",
    "voterings": "votering",
    "voteringsskyltar": "voteringsskylt",
    "voteringsskyltarna": "voteringsskylt",
    "voteringsskyltarnas": "voteringsskylt",
    "voteringsskyltars": "voteringsskylt",
    "voteringsskylten": "voteringsskylt",
    "voteringsskyltens": "voteringsskylt",
    "voteringsskylts": "voteringsskylt",
    "votivgåvan": "votivgåva",
    "votivgåvans": "votivgåva",
    "votivgåvas": "votivgåva",
    "votivgåve": "votivgåva",
    "votivgåvo": "votivgåva",
    "votivgåvor": "votivgåva",
    "votivgåvorna": "votivgåva",
    "votivgåvornas": "votivgåva",
    "votivgåvors": "votivgåva",
    "votivljusen": "votivljus",
    "votivljusens": "votivljus",
    "votivljuset": "votivljus",
    "votivljusets": "votivljus",
    "votivskeppen": "votivskepp",
    "votivskeppens": "votivskepp",
    "votivskeppet": "votivskepp",
    "votivskeppets": "votivskepp",
    "votivskepps": "votivskepp",
    "votumen": "votum",
    "votumens": "votum",
    "votumet": "votum",
    "votumets": "votum",
    "votums": "votum",
    "vouchern": "voucher",
    "voucherna": "voucher",
    "vouchernas": "voucher",
    "voucherns": "voucher",
    "vouchers": "voucher",
    "vouchersarna": "voucher",
    "vouchersarnas": "voucher",
    "vouchersen": "voucher",
    "vouchersens": "voucher",
    "voven": "vov",
    "vovens": "vov",
    "vovet": "vov",
    "vovets": "vov",
    "vovs": "vov",
    "vovvar": "vovve",
    "vovvarna": "vovve",
    "vovvarnas": "vovve",
    "vovvars": "vovve",
    "vovven": "vovve",
    "vovvens": "vovve",
    "vovves": "vovve",
    "voyeuren": "voyeur",
    "voyeurens": "voyeur",
    "voyeurer": "voyeur",
    "voyeurerna": "voyeur",
    "voyeurernas": "voyeur",
    "voyeurers": "voyeur",
    "voyeurs": "voyeur",
    "vpk-s": "vpk",
    "vpk:s": "vpk",
    "vpks": "vpk",
    "vrak": "vraka",
    "vrakad": "vraka",
    "vrakade": "vraka",
    "vrakades": "vraka",
    "vrakads": "vraka",
    "vrakande": "vraka",
    "vrakanden": "vrakande",
    "vrakandena": "vrakande",
    "vrakandenas": "vrakande",
    "vrakandens": "vrakande",
    "vrakandes": "vrakande",
    "vrakandet": "vrakande",
    "vrakandets": "vrakande",
    "vrakar": "vraka",
    "vrakas": "vraka",
    "vrakat": "vraka",
    "vrakats": "vraka",
    "vrakek": "vrakeka",
    "vrakekan": "vrakeka",
    "vrakekans": "vrakeka",
    "vrakekas": "vrakeka",
    "vrakeke": "vrakeka",
    "vrakekor": "vrakeka",
    "vrakekorna": "vrakeka",
    "vrakekornas": "vrakeka",
    "vrakekors": "vrakeka",
    "vrakeks": "vrakeka",
    "vraken": "vrak",
    "vrakens": "vrak",
    "vraket": "vrak",
    "vrakets": "vrak",
    "vrakgodset": "vrakgods",
    "vrakgodsets": "vrakgods",
    "vrakjärnet": "vrakjärn",
    "vrakjärnets": "vrakjärn",
    "vrakjärns": "vrakjärn",
    "vraklaxar": "vraklax",
    "vraklaxarna": "vraklax",
    "vraklaxarnas": "vraklax",
    "vraklaxars": "vraklax",
    "vraklaxen": "vraklax",
    "vraklaxens": "vraklax",
    "vrakprisen": "vrakpris",
    "vrakprisens": "vrakpris",
    "vrakpriser": "vrakpris",
    "vrakpriserna": "vrakpris",
    "vrakprisernas": "vrakpris",
    "vrakprisers": "vrakpris",
    "vrakpriset": "vrakpris",
    "vrakprisets": "vrakpris",
    "vrakresten": "vrakrest",
    "vrakrestens": "vrakrest",
    "vrakrester": "vrakrest",
    "vrakresterna": "vrakrest",
    "vrakresternas": "vrakrest",
    "vrakresters": "vrakrest",
    "vrakrests": "vrakrest",
    "vraks": "vrak",
    "vrakspiller": "vrakspillra",
    "vrakspillran": "vrakspillra",
    "vrakspillrans": "vrakspillra",
    "vrakspillras": "vrakspillra",
    "vrakspillre": "vrakspillra",
    "vrakspillror": "vrakspillra",
    "vrakspillrorna": "vrakspillra",
    "vrakspillrornas": "vrakspillra",
    "vrakspillrors": "vrakspillra",
    "vrakvirkes": "vrakvirke",
    "vrakvirket": "vrakvirke",
    "vrakvirkets": "vrakvirke",
    "vred": "vrida",
    "vreda": "vred",
    "vredare": "vred",
    "vredares": "vred",
    "vredas": "vred",
    "vredast": "vred",
    "vredaste": "vred",
    "vredastes": "vred",
    "vredasts": "vred",
    "vrede": "vred",
    "vreden": "vrede",
    "vredens": "vrede",
    "vredes": "vrede",
    "vredesmodet": "vredesmod",
    "vredesmodets": "vredesmod",
    "vredesmods": "vredesmod",
    "vredet": "vred",
    "vredets": "vred",
    "vredgade": "vredgad",
    "vredgades": "vredgas",
    "vredgads": "vredgad",
    "vredgat": "vredgad",
    "vredgats": "vredgas",
    "vredheten": "vredhet",
    "vredhetens": "vredhet",
    "vredhets": "vredhet",
    "vreds": "vrida",
    "vrenska": "vrensk",
    "vrenskades": "vrenskas",
    "vrenskare": "vrensk",
    "vrenskares": "vrensk",
    "vrenskas": "vrensk",
    "vrenskast": "vrensk",
    "vrenskaste": "vrensk",
    "vrenskastes": "vrensk",
    "vrenskasts": "vrensk",
    "vrenskats": "vrenskas",
    "vrenske": "vrensk",
    "vrenskes": "vrensk",
    "vrenskheten": "vrenskhet",
    "vrenskhetens": "vrenskhet",
    "vrenskhets": "vrenskhet",
    "vrensks": "vrensk",
    "vrenskt": "vrensk",
    "vrenskts": "vrensk",
    "vresiga": "vresig",
    "vresigare": "vresig",
    "vresigares": "vresig",
    "vresigas": "vresig",
    "vresigast": "vresig",
    "vresigaste": "vresig",
    "vresigastes": "vresig",
    "vresigasts": "vresig",
    "vresige": "vresig",
    "vresiges": "vresig",
    "vresigs": "vresig",
    "vresigt": "vresig",
    "vresigts": "vresig",
    "vrestallar": "vrestall",
    "vrestallarna": "vrestall",
    "vrestallarnas": "vrestall",
    "vrestallars": "vrestall",
    "vrestallen": "vrestall",
    "vrestallens": "vrestall",
    "vrestalls": "vrestall",
    "vresveden": "vresved",
    "vresvedens": "vresved",
    "vresveds": "vresved",
    "vretar": "vret",
    "vretarna": "vret",
    "vretarnas": "vret",
    "vretars": "vret",
    "vreten": "vret",
    "vretens": "vret",
    "vrets": "vret",
    "vrick": "vricka",
    "vrickad": "vricka",
    "vrickade": "vrickad",
    "vrickades": "vrickad",
    "vrickads": "vrickad",
    "vrickande": "vricka",
    "vrickanden": "vrickande",
    "vrickandena": "vrickande",
    "vrickandenas": "vrickande",
    "vrickandens": "vrickande",
    "vrickandes": "vrickande",
    "vrickandet": "vrickande",
    "vrickandets": "vrickande",
    "vrickar": "vricka",
    "vrickas": "vricka",
    "vrickat": "vrickad",
    "vrickats": "vrickad",
    "vrickningar": "vrickning",
    "vrickningarna": "vrickning",
    "vrickningarnas": "vrickning",
    "vrickningars": "vrickning",
    "vrickningen": "vrickning",
    "vrickningens": "vrickning",
    "vricknings": "vrickning",
    "vrid": "vrida",
    "vridande": "vrida",
    "vridanden": "vridande",
    "vridandena": "vridande",
    "vridandenas": "vridande",
    "vridandens": "vridande",
    "vridandes": "vridande",
    "vridandet": "vridande",
    "vridandets": "vridande",
    "vridas": "vrida",
    "vridbara": "vridbar",
    "vridbarare": "vridbar",
    "vridbarares": "vridbar",
    "vridbaras": "vridbar",
    "vridbarast": "vridbar",
    "vridbaraste": "vridbar",
    "vridbarastes": "vridbar",
    "vridbarasts": "vridbar",
    "vridbare": "vridbar",
    "vridbares": "vridbar",
    "vridbarheten": "vridbarhet",
    "vridbarhetens": "vridbarhet",
    "vridbarhets": "vridbarhet",
    "vridbars": "vridbar",
    "vridbart": "vridbar",
    "vridbarts": "vridbar",
    "vride": "vrida",
    "vriden": "vrida",
    "vridens": "vriden",
    "vrider": "vrida",
    "vrides": "vrida",
    "vridet": "vriden",
    "vridets": "vriden",
    "vridit": "vrida",
    "vridits": "vrida",
    "vridjärnsinstrumenten": "vridjärnsinstrument",
    "vridjärnsinstrumentens": "vridjärnsinstrument",
    "vridjärnsinstrumentet": "vridjärnsinstrument",
    "vridjärnsinstrumentets": "vridjärnsinstrument",
    "vridjärnsinstruments": "vridjärnsinstrument",
    "vridleden": "vridled",
    "vridledens": "vridled",
    "vridleder": "vridled",
    "vridlederna": "vridled",
    "vridledernas": "vridled",
    "vridleders": "vridled",
    "vridleds": "vridled",
    "vridmomenten": "vridmoment",
    "vridmomentens": "vridmoment",
    "vridmomentet": "vridmoment",
    "vridmomentets": "vridmoment",
    "vridmoments": "vridmoment",
    "vridna": "vriden",
    "vridnare": "vriden",
    "vridnares": "vriden",
    "vridnas": "vriden",
    "vridnast": "vriden",
    "vridnaste": "vriden",
    "vridnastes": "vriden",
    "vridnasts": "vriden",
    "vridne": "vriden",
    "vridnes": "vriden",
    "vridningar": "vridning",
    "vridningarna": "vridning",
    "vridningarnas": "vridning",
    "vridningars": "vridning",
    "vridningen": "vridning",
    "vridningens": "vridning",
    "vridnings": "vridning",
    "vridningsaxeln": "vridningsaxel",
    "vridningsaxelns": "vridningsaxel",
    "vridningsaxels": "vridningsaxel",
    "vridningsaxlar": "vridningsaxel",
    "vridningsaxlarna": "vridningsaxel",
    "vridningsaxlarnas": "vridningsaxel",
    "vridningsaxlars": "vridningsaxel",
    "vrids": "vrida",
    "vridscenen": "vridscen",
    "vridscenens": "vridscen",
    "vridscener": "vridscen",
    "vridscenerna": "vridscen",
    "vridscenernas": "vridscen",
    "vridsceners": "vridscen",
    "vridscens": "vridscen",
    "vridspoleinstrumenten": "vridspoleinstrument",
    "vridspoleinstrumentens": "vridspoleinstrument",
    "vridspoleinstrumentet": "vridspoleinstrument",
    "vridspoleinstrumentets": "vridspoleinstrument",
    "vridspoleinstruments": "vridspoleinstrument",
    "vrilar": "vril",
    "vrilarna": "vril",
    "vrilarnas": "vril",
    "vrilars": "vril",
    "vrilen": "vril",
    "vrilens": "vril",
    "vrils": "vril",
    "vristbenen": "vristben",
    "vristbenens": "vristben",
    "vristbenet": "vristben",
    "vristbenets": "vristben",
    "vristbens": "vristben",
    "vristen": "vrist",
    "vristens": "vrist",
    "vrister": "vrist",
    "vristerna": "vrist",
    "vristernas": "vrist",
    "vristers": "vrist",
    "vrists": "vrist",
    "vräk": "vräka",
    "vräkande": "vräka",
    "vräkanden": "vräkande",
    "vräkandena": "vräkande",
    "vräkandenas": "vräkande",
    "vräkandens": "vräkande",
    "vräkandes": "vräkande",
    "vräkandet": "vräkande",
    "vräkandets": "vräkande",
    "vräkar": "vräkare",
    "vräkaren": "vräkare",
    "vräkarens": "vräkare",
    "vräkares": "vräkare",
    "vräkarna": "vräkare",
    "vräkarnas": "vräkare",
    "vräkas": "vräka",
    "vräker": "vräka",
    "vräkes": "vräka",
    "vräkiga": "vräkig",
    "vräkigare": "vräkig",
    "vräkigares": "vräkig",
    "vräkigas": "vräkig",
    "vräkigast": "vräkig",
    "vräkigaste": "vräkig",
    "vräkigastes": "vräkig",
    "vräkigasts": "vräkig",
    "vräkige": "vräkig",
    "vräkiges": "vräkig",
    "vräkigheten": "vräkighet",
    "vräkighetens": "vräkighet",
    "vräkigheter": "vräkighet",
    "vräkigheterna": "vräkighet",
    "vräkigheternas": "vräkighet",
    "vräkigheters": "vräkighet",
    "vräkighets": "vräkighet",
    "vräkigs": "vräkig",
    "vräkigt": "vräkig",
    "vräkigts": "vräkig",
    "vräkningar": "vräkning",
    "vräkningarna": "vräkning",
    "vräkningarnas": "vräkning",
    "vräkningars": "vräkning",
    "vräkningen": "vräkning",
    "vräkningens": "vräkning",
    "vräknings": "vräkning",
    "vräks": "vräka",
    "vräkt": "vräka",
    "vräkta": "vräka",
    "vräktas": "vräka",
    "vräkte": "vräka",
    "vräktes": "vräka",
    "vräkts": "vräka",
    "vräng": "vränga",
    "vrängande": "vränga",
    "vränganden": "vrängande",
    "vrängandena": "vrängande",
    "vrängandenas": "vrängande",
    "vrängandens": "vrängande",
    "vrängandes": "vrängande",
    "vrängandet": "vrängande",
    "vrängandets": "vrängande",
    "vrängas": "vränga",
    "vrängd": "vränga",
    "vrängda": "vränga",
    "vrängdas": "vränga",
    "vrängde": "vränga",
    "vrängdes": "vränga",
    "vrängds": "vränga",
    "vränger": "vränga",
    "vränges": "vränga",
    "vrängs": "vränga",
    "vrängt": "vränga",
    "vrängts": "vränga",
    "vråkar": "vråk",
    "vråkarna": "vråk",
    "vråkarnas": "vråk",
    "vråkars": "vråk",
    "vråken": "vråk",
    "vråkens": "vråk",
    "vråks": "vråk",
    "vrål": "vråla",
    "vrålade": "vråla",
    "vrålades": "vråla",
    "vrålande": "vråla",
    "vrålanden": "vrålande",
    "vrålandena": "vrålande",
    "vrålandenas": "vrålande",
    "vrålandens": "vrålande",
    "vrålandes": "vrålande",
    "vrålandet": "vrålande",
    "vrålandets": "vrålande",
    "vrålap": "vrålapa",
    "vrålapan": "vrålapa",
    "vrålapans": "vrålapa",
    "vrålapas": "vrålapa",
    "vrålape": "vrålapa",
    "vrålapor": "vrålapa",
    "vrålaporna": "vrålapa",
    "vrålapornas": "vrålapa",
    "vrålapors": "vrålapa",
    "vrålaps": "vrålapa",
    "vrålar": "vråla",
    "vrålas": "vråla",
    "vrålat": "vråla",
    "vrålats": "vråla",
    "vrålen": "vrål",
    "vrålens": "vrål",
    "vrålet": "vrål",
    "vrålets": "vrål",
    "vrålflotta": "vrålflott",
    "vrålflottare": "vrålflott",
    "vrålflottares": "vrålflott",
    "vrålflottas": "vrålflott",
    "vrålflottast": "vrålflott",
    "vrålflottaste": "vrålflott",
    "vrålflottastes": "vrålflott",
    "vrålflottasts": "vrålflott",
    "vrålflotte": "vrålflott",
    "vrålflottes": "vrålflott",
    "vrålflottheten": "vrålflotthet",
    "vrålflotthetens": "vrålflotthet",
    "vrålflotthets": "vrålflotthet",
    "vrålflotts": "vrålflott",
    "vrålplugg": "vrålplugga",
    "vrålpluggad": "vrålplugga",
    "vrålpluggade": "vrålplugga",
    "vrålpluggades": "vrålplugga",
    "vrålpluggads": "vrålplugga",
    "vrålpluggande": "vrålplugga",
    "vrålplugganden": "vrålpluggande",
    "vrålpluggandena": "vrålpluggande",
    "vrålpluggandenas": "vrålpluggande",
    "vrålpluggandens": "vrålpluggande",
    "vrålpluggandes": "vrålpluggande",
    "vrålpluggandet": "vrålpluggande",
    "vrålpluggandets": "vrålpluggande",
    "vrålpluggar": "vrålplugga",
    "vrålpluggas": "vrålplugga",
    "vrålpluggat": "vrålplugga",
    "vrålpluggats": "vrålplugga",
    "vråls": "vrål",
    "vrålåken": "vrålåk",
    "vrålåkens": "vrålåk",
    "vrålåket": "vrålåk",
    "vrålåkets": "vrålåk",
    "vrålåks": "vrålåk",
    "vrån": "vrå",
    "vrånga": "vrång",
    "vrångare": "vrång",
    "vrångares": "vrång",
    "vrångas": "vrång",
    "vrångast": "vrång",
    "vrångaste": "vrång",
    "vrångastes": "vrång",
    "vrångasts": "vrång",
    "vrångbilden": "vrångbild",
    "vrångbildens": "vrångbild",
    "vrångbilder": "vrångbild",
    "vrångbilderna": "vrångbild",
    "vrångbildernas": "vrångbild",
    "vrångbilders": "vrångbild",
    "vrångbilds": "vrångbild",
    "vrånge": "vrång",
    "vrånges": "vrång",
    "vrångheten": "vrånghet",
    "vrånghetens": "vrånghet",
    "vrångheter": "vrånghet",
    "vrångheterna": "vrånghet",
    "vrångheternas": "vrånghet",
    "vrångheters": "vrånghet",
    "vrånghets": "vrånghet",
    "vrångs": "vrång",
    "vrångt": "vrång",
    "vrångts": "vrång",
    "vrångvisa": "vrångvis",
    "vrångvisare": "vrångvis",
    "vrångvisares": "vrångvis",
    "vrångvisas": "vrångvis",
    "vrångvisast": "vrångvis",
    "vrångvisaste": "vrångvis",
    "vrångvisastes": "vrångvis",
    "vrångvisasts": "vrångvis",
    "vrångvise": "vrångvis",
    "vrångvises": "vrångvis",
    "vrångvisheten": "vrångvishet",
    "vrångvishetens": "vrångvishet",
    "vrångvishets": "vrångvishet",
    "vrångvist": "vrångvis",
    "vrångvists": "vrångvis",
    "vråns": "vrå",
    "vrår": "vrå",
    "vrårna": "vrå",
    "vrårnas": "vrå",
    "vrårs": "vrå",
    "vrås": "vrå",
    "vrövel": "vrövla",
    "vrövels": "vrövel",
    "vrövlade": "vrövla",
    "vrövlades": "vrövla",
    "vrövlande": "vrövla",
    "vrövlanden": "vrövlande",
    "vrövlandena": "vrövlande",
    "vrövlandenas": "vrövlande",
    "vrövlandens": "vrövlande",
    "vrövlandes": "vrövlande",
    "vrövlandet": "vrövlande",
    "vrövlandets": "vrövlande",
    "vrövlar": "vrövla",
    "vrövlas": "vrövla",
    "vrövlat": "vrövla",
    "vrövlats": "vrövla",
    "vrövlet": "vrövel",
    "vrövlets": "vrövel",
    "vul": "vula",
    "vulad": "vula",
    "vulade": "vula",
    "vulades": "vula",
    "vulads": "vula",
    "vulande": "vula",
    "vulanden": "vulande",
    "vulandena": "vulande",
    "vulandenas": "vulande",
    "vulandens": "vulande",
    "vulandes": "vulande",
    "vulandet": "vulande",
    "vulandets": "vulande",
    "vular": "vula",
    "vulas": "vula",
    "vulat": "vula",
    "vulats": "vula",
    "vulgariserad": "vulgarisera",
    "vulgariserade": "vulgarisera",
    "vulgariserades": "vulgarisera",
    "vulgariserads": "vulgarisera",
    "vulgariserande": "vulgarisera",
    "vulgariseranden": "vulgariserande",
    "vulgariserandena": "vulgariserande",
    "vulgariserandenas": "vulgariserande",
    "vulgariserandens": "vulgariserande",
    "vulgariserandes": "vulgariserande",
    "vulgariserandet": "vulgariserande",
    "vulgariserandets": "vulgariserande",
    "vulgariserar": "vulgarisera",
    "vulgariseras": "vulgarisera",
    "vulgariserat": "vulgarisera",
    "vulgariserats": "vulgarisera",
    "vulgariserbara": "vulgariserbar",
    "vulgariserbarare": "vulgariserbar",
    "vulgariserbarares": "vulgariserbar",
    "vulgariserbaras": "vulgariserbar",
    "vulgariserbarast": "vulgariserbar",
    "vulgariserbaraste": "vulgariserbar",
    "vulgariserbarastes": "vulgariserbar",
    "vulgariserbarasts": "vulgariserbar",
    "vulgariserbare": "vulgariserbar",
    "vulgariserbares": "vulgariserbar",
    "vulgariserbarheten": "vulgariserbarhet",
    "vulgariserbarhetens": "vulgariserbarhet",
    "vulgariserbarhets": "vulgariserbarhet",
    "vulgariserbars": "vulgariserbar",
    "vulgariserbart": "vulgariserbar",
    "vulgariserbarts": "vulgariserbar",
    "vulgariseringar": "vulgarisering",
    "vulgariseringarna": "vulgarisering",
    "vulgariseringarnas": "vulgarisering",
    "vulgariseringars": "vulgarisering",
    "vulgariseringen": "vulgarisering",
    "vulgariseringens": "vulgarisering",
    "vulgariserings": "vulgarisering",
    "vulgariteten": "vulgaritet",
    "vulgaritetens": "vulgaritet",
    "vulgariteter": "vulgaritet",
    "vulgariteterna": "vulgaritet",
    "vulgariteternas": "vulgaritet",
    "vulgariteters": "vulgaritet",
    "vulgaritets": "vulgaritet",
    "vulgära": "vulgär",
    "vulgärare": "vulgär",
    "vulgärares": "vulgär",
    "vulgäras": "vulgär",
    "vulgärast": "vulgär",
    "vulgäraste": "vulgär",
    "vulgärastes": "vulgär",
    "vulgärasts": "vulgär",
    "vulgäre": "vulgär",
    "vulgäres": "vulgär",
    "vulgärlatinet": "vulgärlatin",
    "vulgärlatinets": "vulgärlatin",
    "vulgärlatins": "vulgärlatin",
    "vulgärs": "vulgär",
    "vulgärt": "vulgär",
    "vulgärts": "vulgär",
    "vulk": "vulka",
    "vulkad": "vulka",
    "vulkade": "vulka",
    "vulkades": "vulka",
    "vulkads": "vulka",
    "vulkanask": "vulkanaska",
    "vulkanaskan": "vulkanaska",
    "vulkanaskans": "vulkanaska",
    "vulkanaskas": "vulkanaska",
    "vulkande": "vulka",
    "vulkanden": "vulkande",
    "vulkandena": "vulkande",
    "vulkandenas": "vulkande",
    "vulkandens": "vulkande",
    "vulkandes": "vulkande",
    "vulkandet": "vulkande",
    "vulkandets": "vulkande",
    "vulkanen": "vulkan",
    "vulkanens": "vulkan",
    "vulkaner": "vulkan",
    "vulkanerna": "vulkan",
    "vulkanernas": "vulkan",
    "vulkaners": "vulkan",
    "vulkanisatorer": "vulkanisator",
    "vulkanisatorerna": "vulkanisator",
    "vulkanisatorernas": "vulkanisator",
    "vulkanisatorers": "vulkanisator",
    "vulkanisatorn": "vulkanisator",
    "vulkanisatorns": "vulkanisator",
    "vulkanisators": "vulkanisator",
    "vulkaniserad": "vulkanisera",
    "vulkaniserade": "vulkanisera",
    "vulkaniserades": "vulkanisera",
    "vulkaniserads": "vulkanisera",
    "vulkaniserande": "vulkanisera",
    "vulkaniseranden": "vulkaniserande",
    "vulkaniserandena": "vulkaniserande",
    "vulkaniserandenas": "vulkaniserande",
    "vulkaniserandens": "vulkaniserande",
    "vulkaniserandes": "vulkaniserande",
    "vulkaniserandet": "vulkaniserande",
    "vulkaniserandets": "vulkaniserande",
    "vulkaniserar": "vulkanisera",
    "vulkaniseras": "vulkanisera",
    "vulkaniserat": "vulkanisera",
    "vulkaniserats": "vulkanisera",
    "vulkaniserbara": "vulkaniserbar",
    "vulkaniserbarare": "vulkaniserbar",
    "vulkaniserbarares": "vulkaniserbar",
    "vulkaniserbaras": "vulkaniserbar",
    "vulkaniserbarast": "vulkaniserbar",
    "vulkaniserbaraste": "vulkaniserbar",
    "vulkaniserbarastes": "vulkaniserbar",
    "vulkaniserbarasts": "vulkaniserbar",
    "vulkaniserbare": "vulkaniserbar",
    "vulkaniserbares": "vulkaniserbar",
    "vulkaniserbarheten": "vulkaniserbarhet",
    "vulkaniserbarhetens": "vulkaniserbarhet",
    "vulkaniserbarhets": "vulkaniserbarhet",
    "vulkaniserbars": "vulkaniserbar",
    "vulkaniserbart": "vulkaniserbar",
    "vulkaniserbarts": "vulkaniserbar",
    "vulkaniseringar": "vulkanisering",
    "vulkaniseringarna": "vulkanisering",
    "vulkaniseringarnas": "vulkanisering",
    "vulkaniseringars": "vulkanisering",
    "vulkaniseringen": "vulkanisering",
    "vulkaniseringens": "vulkanisering",
    "vulkaniserings": "vulkanisering",
    "vulkaniska": "vulkanisk",
    "vulkaniskare": "vulkanisk",
    "vulkaniskares": "vulkanisk",
    "vulkaniskas": "vulkanisk",
    "vulkaniskast": "vulkanisk",
    "vulkaniskaste": "vulkanisk",
    "vulkaniskastes": "vulkanisk",
    "vulkaniskasts": "vulkanisk",
    "vulkaniske": "vulkanisk",
    "vulkaniskes": "vulkanisk",
    "vulkanisks": "vulkanisk",
    "vulkaniskt": "vulkanisk",
    "vulkaniskts": "vulkanisk",
    "vulkanismen": "vulkanism",
    "vulkanismens": "vulkanism",
    "vulkanismer": "vulkanism",
    "vulkanismerna": "vulkanism",
    "vulkanismernas": "vulkanism",
    "vulkanismers": "vulkanism",
    "vulkanisms": "vulkanism",
    "vulkaniten": "vulkanit",
    "vulkanitens": "vulkanit",
    "vulkaniter": "vulkanit",
    "vulkaniterna": "vulkanit",
    "vulkaniternas": "vulkanit",
    "vulkaniters": "vulkanit",
    "vulkanits": "vulkanit",
    "vulkankratern": "vulkankrater",
    "vulkankraterns": "vulkankrater",
    "vulkankraters": "vulkankrater",
    "vulkankratrar": "vulkankrater",
    "vulkankratrarna": "vulkankrater",
    "vulkankratrarnas": "vulkankrater",
    "vulkankratrars": "vulkankrater",
    "vulkans": "vulkan",
    "vulkanutbrotten": "vulkanutbrott",
    "vulkanutbrottens": "vulkanutbrott",
    "vulkanutbrottet": "vulkanutbrott",
    "vulkanutbrottets": "vulkanutbrott",
    "vulkanutbrotts": "vulkanutbrott",
    "vulkanvarningar": "vulkanvarning",
    "vulkanvarningarna": "vulkanvarning",
    "vulkanvarningarnas": "vulkanvarning",
    "vulkanvarningars": "vulkanvarning",
    "vulkanvarningen": "vulkanvarning",
    "vulkanvarningens": "vulkanvarning",
    "vulkanvarnings": "vulkanvarning",
    "vulkanöar": "vulkanö",
    "vulkanöarna": "vulkanö",
    "vulkanöarnas": "vulkanö",
    "vulkanöars": "vulkanö",
    "vulkanön": "vulkanö",
    "vulkanöns": "vulkanö",
    "vulkanös": "vulkanö",
    "vulkapparaten": "vulkapparat",
    "vulkapparatens": "vulkapparat",
    "vulkapparater": "vulkapparat",
    "vulkapparaterna": "vulkapparat",
    "vulkapparaternas": "vulkapparat",
    "vulkapparaters": "vulkapparat",
    "vulkapparats": "vulkapparat",
    "vulkar": "vulka",
    "vulkas": "vulka",
    "vulkat": "vulka",
    "vulkats": "vulka",
    "vulsten": "vulst",
    "vulstens": "vulst",
    "vulster": "vulst",
    "vulsterna": "vulst",
    "vulsternas": "vulst",
    "vulsters": "vulst",
    "vulstiga": "vulstig",
    "vulstigare": "vulstig",
    "vulstigares": "vulstig",
    "vulstigas": "vulstig",
    "vulstigast": "vulstig",
    "vulstigaste": "vulstig",
    "vulstigastes": "vulstig",
    "vulstigasts": "vulstig",
    "vulstige": "vulstig",
    "vulstiges": "vulstig",
    "vulstigheten": "vulstighet",
    "vulstighetens": "vulstighet",
    "vulstighets": "vulstighet",
    "vulstigs": "vulstig",
    "vulstigt": "vulstig",
    "vulstigts": "vulstig",
    "vulsts": "vulst",
    "vulvan": "vulva",
    "vulvans": "vulva",
    "vulvas": "vulva",
    "vulvor": "vulva",
    "vulvorna": "vulva",
    "vulvornas": "vulva",
    "vulvors": "vulva",
    "vunna": "vinna",
    "vunnas": "vinna",
    "vunne": "vinna",
    "vunnen": "vinna",
    "vunnens": "vinna",
    "vunnes": "vinna",
    "vunnet": "vinna",
    "vunnets": "vinna",
    "vunnit": "vinna",
    "vunnits": "vinna",
    "vurm": "vurma",
    "vurmad": "vurma",
    "vurmade": "vurma",
    "vurmades": "vurma",
    "vurmads": "vurma",
    "vurmande": "vurma",
    "vurmanden": "vurmande",
    "vurmandena": "vurmande",
    "vurmandenas": "vurmande",
    "vurmandens": "vurmande",
    "vurmandes": "vurmande",
    "vurmandet": "vurmande",
    "vurmandets": "vurmande",
    "vurmar": "vurma",
    "vurmarna": "vurm",
    "vurmarnas": "vurm",
    "vurmars": "vurm",
    "vurmas": "vurma",
    "vurmat": "vurma",
    "vurmats": "vurma",
    "vurmen": "vurm",
    "vurmens": "vurm",
    "vurms": "vurm",
    "vurp": "vurpa",
    "vurpad": "vurpa",
    "vurpade": "vurpa",
    "vurpades": "vurpa",
    "vurpads": "vurpa",
    "vurpan": "vurpa",
    "vurpande": "vurpa",
    "vurpanden": "vurpande",
    "vurpandena": "vurpande",
    "vurpandenas": "vurpande",
    "vurpandens": "vurpande",
    "vurpandes": "vurpande",
    "vurpandet": "vurpande",
    "vurpandets": "vurpande",
    "vurpans": "vurpa",
    "vurpar": "vurpa",
    "vurpas": "vurpa",
    "vurpat": "vurpa",
    "vurpats": "vurpa",
    "vurpe": "vurpa",
    "vurpor": "vurpa",
    "vurporna": "vurpa",
    "vurpornas": "vurpa",
    "vurpors": "vurpa",
    "vurps": "vurpa",
    "vurstar": "vurst",
    "vurstarna": "vurst",
    "vurstarnas": "vurst",
    "vurstars": "vurst",
    "vursten": "vurst",
    "vurstens": "vurst",
    "vursts": "vurst",
    "vuvuzelan": "vuvuzela",
    "vuvuzelans": "vuvuzela",
    "vuvuzelas": "vuvuzela",
    "vuvuzelor": "vuvuzela",
    "vuvuzelorna": "vuvuzela",
    "vuvuzelornas": "vuvuzela",
    "vuvuzelors": "vuvuzela",
    "vuxe": "växa",
    "vuxen": "växa",
    "vuxendosen": "vuxendos",
    "vuxendosens": "vuxendos",
    "vuxendoser": "vuxendos",
    "vuxendoserna": "vuxendos",
    "vuxendosernas": "vuxendos",
    "vuxendosers": "vuxendos",
    "vuxenliven": "vuxenliv",
    "vuxenlivens": "vuxenliv",
    "vuxenlivet": "vuxenliv",
    "vuxenlivets": "vuxenliv",
    "vuxenlivs": "vuxenliv",
    "vuxens": "vuxen",
    "vuxenvärldar": "vuxenvärld",
    "vuxenvärldarna": "vuxenvärld",
    "vuxenvärldarnas": "vuxenvärld",
    "vuxenvärldars": "vuxenvärld",
    "vuxenvärlden": "vuxenvärld",
    "vuxenvärldens": "vuxenvärld",
    "vuxenvärlds": "vuxenvärld",
    "vuxet": "vuxen",
    "vuxets": "vuxen",
    "vuxit": "växa",
    "vuxna": "vuxen",
    "vuxnare": "vuxen",
    "vuxnares": "vuxen",
    "vuxnas": "vuxen",
    "vuxnast": "vuxen",
    "vuxnaste": "vuxen",
    "vuxnastes": "vuxen",
    "vuxnasts": "vuxen",
    "vuxne": "vuxen",
    "vuxnes": "vuxen",
    "vyer": "vy",
    "vyerna": "vy",
    "vyernas": "vy",
    "vyers": "vy",
    "vykorten": "vykort",
    "vykortens": "vykort",
    "vykortet": "vykort",
    "vykortets": "vykort",
    "vykorts": "vykort",
    "vykortsvyer": "vykortsvy",
    "vykortsvyerna": "vykortsvy",
    "vykortsvyernas": "vykortsvy",
    "vykortsvyers": "vykortsvy",
    "vykortsvyn": "vykortsvy",
    "vykortsvyns": "vykortsvy",
    "vykortsvys": "vykortsvy",
    "vyn": "vy",
    "vyns": "vy",
    "vys": "vy",
    "vyss": "vyssa",
    "vyssad": "vyssa",
    "vyssade": "vyssa",
    "vyssades": "vyssa",
    "vyssads": "vyssa",
    "vyssande": "vyssa",
    "vyssanden": "vyssande",
    "vyssandena": "vyssande",
    "vyssandenas": "vyssande",
    "vyssandens": "vyssande",
    "vyssandes": "vyssande",
    "vyssandet": "vyssande",
    "vyssandets": "vyssande",
    "vyssar": "vyssa",
    "vyssas": "vyssa",
    "vyssat": "vyssa",
    "vyssats": "vyssa",
    "vyssj": "vyssja",
    "vyssjad": "vyssja",
    "vyssjade": "vyssja",
    "vyssjades": "vyssja",
    "vyssjads": "vyssja",
    "vyssjande": "vyssja",
    "vyssjanden": "vyssjande",
    "vyssjandena": "vyssjande",
    "vyssjandenas": "vyssjande",
    "vyssjandens": "vyssjande",
    "vyssjandes": "vyssjande",
    "vyssjandet": "vyssjande",
    "vyssjandets": "vyssjande",
    "vyssjar": "vyssja",
    "vyssjas": "vyssja",
    "vyssjat": "vyssja",
    "vyssjats": "vyssja",
    "väbeln": "väbel",
    "väbelns": "väbel",
    "väbels": "väbel",
    "väblar": "väbel",
    "väblarna": "väbel",
    "väblarnas": "väbel",
    "väblars": "väbel",
    "väck": "väcka",
    "väckan": "väcka",
    "väckande": "väcka",
    "väckanden": "väckande",
    "väckandena": "väckande",
    "väckandenas": "väckande",
    "väckandens": "väckande",
    "väckandes": "väckande",
    "väckandet": "väckande",
    "väckandets": "väckande",
    "väckans": "väcka",
    "väckar": "väckare",
    "väckaren": "väckare",
    "väckarens": "väckare",
    "väckares": "väckare",
    "väckarklock": "väckarklocka",
    "väckarklockan": "väckarklocka",
    "väckarklockans": "väckarklocka",
    "väckarklockas": "väckarklocka",
    "väckarklocke": "väckarklocka",
    "väckarklockor": "väckarklocka",
    "väckarklockorna": "väckarklocka",
    "väckarklockornas": "väckarklocka",
    "väckarklockors": "väckarklocka",
    "väckarklocks": "väckarklocka",
    "väckarna": "väckare",
    "väckarnas": "väckare",
    "väckas": "väcka",
    "väcke": "väcka",
    "väckelsemöten": "väckelsemöte",
    "väckelsemötena": "väckelsemöte",
    "väckelsemötenas": "väckelsemöte",
    "väckelsemötens": "väckelsemöte",
    "väckelsemötes": "väckelsemöte",
    "väckelsemötet": "väckelsemöte",
    "väckelsemötets": "väckelsemöte",
    "väckelsen": "väckelse",
    "väckelsens": "väckelse",
    "väckelsepredikanten": "väckelsepredikant",
    "väckelsepredikantens": "väckelsepredikant",
    "väckelsepredikanter": "väckelsepredikant",
    "väckelsepredikanterna": "väckelsepredikant",
    "väckelsepredikanternas": "väckelsepredikant",
    "väckelsepredikanters": "väckelsepredikant",
    "väckelsepredikants": "väckelsepredikant",
    "väckelser": "väckelse",
    "väckelserna": "väckelse",
    "väckelsernas": "väckelse",
    "väckelsers": "väckelse",
    "väckelserörelsen": "väckelserörelse",
    "väckelserörelsens": "väckelserörelse",
    "väckelserörelser": "väckelserörelse",
    "väckelserörelserna": "väckelserörelse",
    "väckelserörelsernas": "väckelserörelse",
    "väckelserörelsers": "väckelserörelse",
    "väckelserörelses": "väckelserörelse",
    "väckelses": "väckelse",
    "väcker": "väcka",
    "väckes": "väcka",
    "väckningar": "väckning",
    "väckningarna": "väckning",
    "väckningarnas": "väckning",
    "väckningars": "väckning",
    "väckningen": "väckning",
    "väckningens": "väckning",
    "väcknings": "väckning",
    "väckor": "väcka",
    "väckorna": "väcka",
    "väckornas": "väcka",
    "väckors": "väcka",
    "väcks": "väcka",
    "väckt": "väcka",
    "väckta": "väcka",
    "väcktas": "väcka",
    "väckte": "väcka",
    "väcktes": "väcka",
    "väckts": "väcka",
    "vädden": "vädd",
    "väddens": "vädd",
    "vädds": "vädd",
    "väderbeständiga": "väderbeständig",
    "väderbeständigare": "väderbeständig",
    "väderbeständigares": "väderbeständig",
    "väderbeständigas": "väderbeständig",
    "väderbeständigast": "väderbeständig",
    "väderbeständigaste": "väderbeständig",
    "väderbeständigastes": "väderbeständig",
    "väderbeständigasts": "väderbeständig",
    "väderbeständige": "väderbeständig",
    "väderbeständiges": "väderbeständig",
    "väderbeständigheten": "väderbeständighet",
    "väderbeständighetens": "väderbeständighet",
    "väderbeständighets": "väderbeständighet",
    "väderbeständigs": "väderbeständig",
    "väderbeständigt": "väderbeständig",
    "väderbeständigts": "väderbeständig",
    "väderbitens": "väderbiten",
    "väderbitet": "väderbiten",
    "väderbitets": "väderbiten",
    "väderbitna": "väderbiten",
    "väderbitnare": "väderbiten",
    "väderbitnares": "väderbiten",
    "väderbitnas": "väderbiten",
    "väderbitnast": "väderbiten",
    "väderbitnaste": "väderbiten",
    "väderbitnastes": "väderbiten",
    "väderbitnasts": "väderbiten",
    "väderbitne": "väderbiten",
    "väderbitnes": "väderbiten",
    "väderförhållanden": "väderförhållande",
    "väderförhållandena": "väderförhållande",
    "väderförhållandenas": "väderförhållande",
    "väderförhållandens": "väderförhållande",
    "väderförhållandes": "väderförhållande",
    "väderförhållandet": "väderförhållande",
    "väderförhållandets": "väderförhållande",
    "vädergallan": "vädergalla",
    "vädergallans": "vädergalla",
    "vädergallas": "vädergalla",
    "väderilar": "väderil",
    "väderilarna": "väderil",
    "väderilarnas": "väderil",
    "väderilars": "väderil",
    "väderilen": "väderil",
    "väderilens": "väderil",
    "väderils": "väderil",
    "väderkart": "väderkarta",
    "väderkartan": "väderkarta",
    "väderkartans": "väderkarta",
    "väderkartas": "väderkarta",
    "väderkarte": "väderkarta",
    "väderkartor": "väderkarta",
    "väderkartorna": "väderkarta",
    "väderkartornas": "väderkarta",
    "väderkartors": "väderkarta",
    "väderkarts": "väderkarta",
    "väderkornet": "väderkorn",
    "väderkornets": "väderkorn",
    "väderkorns": "väderkorn",
    "väderkvarnar": "väderkvarn",
    "väderkvarnarna": "väderkvarn",
    "väderkvarnarnas": "väderkvarn",
    "väderkvarnars": "väderkvarn",
    "väderkvarnen": "väderkvarn",
    "väderkvarnens": "väderkvarn",
    "väderkvarns": "väderkvarn",
    "väderlekar": "väderlek",
    "väderlekarna": "väderlek",
    "väderlekarnas": "väderlek",
    "väderlekars": "väderlek",
    "väderleken": "väderlek",
    "väderlekens": "väderlek",
    "väderleks": "väderlek",
    "väderleksmässiga": "väderleksmässig",
    "väderleksmässigare": "väderleksmässig",
    "väderleksmässigares": "väderleksmässig",
    "väderleksmässigas": "väderleksmässig",
    "väderleksmässigast": "väderleksmässig",
    "väderleksmässigaste": "väderleksmässig",
    "väderleksmässigastes": "väderleksmässig",
    "väderleksmässigasts": "väderleksmässig",
    "väderleksmässige": "väderleksmässig",
    "väderleksmässiges": "väderleksmässig",
    "väderleksmässigs": "väderleksmässig",
    "väderleksmässigt": "väderleksmässig",
    "väderleksmässigts": "väderleksmässig",
    "väderleksrapporten": "väderleksrapport",
    "väderleksrapportens": "väderleksrapport",
    "väderleksrapporter": "väderleksrapport",
    "väderleksrapporterna": "väderleksrapport",
    "väderleksrapporternas": "väderleksrapport",
    "väderleksrapporters": "väderleksrapport",
    "väderleksrapports": "väderleksrapport",
    "väderlekstjänsten": "väderlekstjänst",
    "väderlekstjänstens": "väderlekstjänst",
    "väderlekstjänsts": "väderlekstjänst",
    "väderlåd": "väderlåda",
    "väderlådan": "väderlåda",
    "väderlådans": "väderlåda",
    "väderlådas": "väderlåda",
    "väderlåde": "väderlåda",
    "väderlådor": "väderlåda",
    "väderlådorna": "väderlåda",
    "väderlådornas": "väderlåda",
    "väderlådors": "väderlåda",
    "väderlåds": "väderlåda",
    "vädermässiga": "vädermässig",
    "vädermässigare": "vädermässig",
    "vädermässigares": "vädermässig",
    "vädermässigas": "vädermässig",
    "vädermässigast": "vädermässig",
    "vädermässigaste": "vädermässig",
    "vädermässigastes": "vädermässig",
    "vädermässigasts": "vädermässig",
    "vädermässige": "vädermässig",
    "vädermässiges": "vädermässig",
    "vädermässigs": "vädermässig",
    "vädermässigt": "vädermässig",
    "vädermässigts": "vädermässig",
    "vädermätningar": "vädermätning",
    "vädermätningarna": "vädermätning",
    "vädermätningarnas": "vädermätning",
    "vädermätningars": "vädermätning",
    "vädermätningen": "vädermätning",
    "vädermätningens": "vädermätning",
    "vädermätnings": "vädermätning",
    "väderomslagen": "väderomslag",
    "väderomslagens": "väderomslag",
    "väderomslaget": "väderomslag",
    "väderomslagets": "väderomslag",
    "väderomslags": "väderomslag",
    "väderprognosen": "väderprognos",
    "väderprognosens": "väderprognos",
    "väderprognoser": "väderprognos",
    "väderprognoserna": "väderprognos",
    "väderprognosernas": "väderprognos",
    "väderprognosers": "väderprognos",
    "väderrapporten": "väderrapport",
    "väderrapportens": "väderrapport",
    "väderrapporter": "väderrapport",
    "väderrapporterna": "väderrapport",
    "väderrapporternas": "väderrapport",
    "väderrapporters": "väderrapport",
    "väderrapports": "väderrapport",
    "väders": "väder",
    "vädersatelliten": "vädersatellit",
    "vädersatellitens": "vädersatellit",
    "vädersatelliter": "vädersatellit",
    "vädersatelliterna": "vädersatellit",
    "vädersatelliternas": "vädersatellit",
    "vädersatelliters": "vädersatellit",
    "vädersatellits": "vädersatellit",
    "vädersegels": "vädersegel",
    "väderseglen": "vädersegel",
    "väderseglens": "vädersegel",
    "väderseglet": "vädersegel",
    "väderseglets": "vädersegel",
    "väderskeppen": "väderskepp",
    "väderskeppens": "väderskepp",
    "väderskeppet": "väderskepp",
    "väderskeppets": "väderskepp",
    "väderskepps": "väderskepp",
    "vädersolar": "vädersol",
    "vädersolarna": "vädersol",
    "vädersolarnas": "vädersol",
    "vädersolars": "vädersol",
    "vädersolen": "vädersol",
    "vädersolens": "vädersol",
    "vädersols": "vädersol",
    "väderspända": "väderspänd",
    "väderspändare": "väderspänd",
    "väderspändares": "väderspänd",
    "väderspändas": "väderspänd",
    "väderspändast": "väderspänd",
    "väderspändaste": "väderspänd",
    "väderspändastes": "väderspänd",
    "väderspändasts": "väderspänd",
    "väderspände": "väderspänd",
    "väderspändes": "väderspänd",
    "väderspändheten": "väderspändhet",
    "väderspändhetens": "väderspändhet",
    "väderspändhets": "väderspändhet",
    "väderspänds": "väderspänd",
    "väderspänningar": "väderspänning",
    "väderspänningarna": "väderspänning",
    "väderspänningarnas": "väderspänning",
    "väderspänningars": "väderspänning",
    "väderspänningen": "väderspänning",
    "väderspänningens": "väderspänning",
    "väderspännings": "väderspänning",
    "väderspänt": "väderspänd",
    "väderspänts": "väderspänd",
    "väderstinna": "väderstinn",
    "väderstinnare": "väderstinn",
    "väderstinnares": "väderstinn",
    "väderstinnas": "väderstinn",
    "väderstinnast": "väderstinn",
    "väderstinnaste": "väderstinn",
    "väderstinnastes": "väderstinn",
    "väderstinnasts": "väderstinn",
    "väderstinne": "väderstinn",
    "väderstinnes": "väderstinn",
    "väderstinnheten": "väderstinnhet",
    "väderstinnhetens": "väderstinnhet",
    "väderstinnhets": "väderstinnhet",
    "väderstinns": "väderstinn",
    "väderstint": "väderstinn",
    "väderstints": "väderstinn",
    "väderstrecken": "väderstreck",
    "väderstreckens": "väderstreck",
    "väderstrecket": "väderstreck",
    "väderstreckets": "väderstreck",
    "väderstrecks": "väderstreck",
    "vädertillstånden": "vädertillstånd",
    "vädertillståndens": "vädertillstånd",
    "vädertillståndet": "vädertillstånd",
    "vädertillståndets": "vädertillstånd",
    "vädertillstånds": "vädertillstånd",
    "vädertjänsten": "vädertjänst",
    "vädertjänstens": "vädertjänst",
    "vädertjänsts": "vädertjänst",
    "vädj": "vädja",
    "vädjad": "vädja",
    "vädjade": "vädja",
    "vädjades": "vädja",
    "vädjads": "vädja",
    "vädjande": "vädja",
    "vädjanden": "vädjande",
    "vädjandena": "vädjande",
    "vädjandenas": "vädjande",
    "vädjandens": "vädjande",
    "vädjandes": "vädjande",
    "vädjandet": "vädjande",
    "vädjandets": "vädjande",
    "vädjans": "vädjan",
    "vädjar": "vädja",
    "vädjas": "vädja",
    "vädjat": "vädja",
    "vädjats": "vädja",
    "vädjo": "vädja",
    "vädjobanan": "vädjobana",
    "vädjobanans": "vädjobana",
    "vädjobanas": "vädjobana",
    "vädjobane": "vädjobana",
    "vädjobanor": "vädjobana",
    "vädjobanorna": "vädjobana",
    "vädjobanornas": "vädjobana",
    "vädjobanors": "vädjobana",
    "vädrad": "vädra",
    "vädrade": "vädra",
    "vädrades": "vädra",
    "vädrads": "vädra",
    "vädrande": "vädra",
    "vädranden": "vädrande",
    "vädrandena": "vädrande",
    "vädrandenas": "vädrande",
    "vädrandens": "vädrande",
    "vädrandes": "vädrande",
    "vädrandet": "vädrande",
    "vädrandets": "vädrande",
    "vädrar": "vädra",
    "vädras": "vädra",
    "vädrat": "vädra",
    "vädrats": "vädra",
    "vädren": "väder",
    "vädrens": "väder",
    "vädret": "väder",
    "vädrets": "väder",
    "vädurar": "vädur",
    "vädurarna": "vädur",
    "vädurarnas": "vädur",
    "vädurars": "vädur",
    "väduren": "vädur",
    "vädurens": "vädur",
    "vädurn": "vädur",
    "vädurns": "vädur",
    "vädurs": "vädur",
    "väften": "väft",
    "väftens": "väft",
    "väfts": "väft",
    "väg": "väga",
    "vägad": "väga",
    "vägade": "väga",
    "vägades": "väga",
    "vägads": "väga",
    "vägande": "väga",
    "väganden": "vägande",
    "vägandena": "vägande",
    "vägandenas": "vägande",
    "vägandens": "vägande",
    "vägandes": "vägande",
    "vägandet": "vägande",
    "vägandets": "vägande",
    "vägar": "vägare",
    "vägarbeten": "vägarbete",
    "vägarbetena": "vägarbete",
    "vägarbetenas": "vägarbete",
    "vägarbetens": "vägarbete",
    "vägarbetes": "vägarbete",
    "vägarbetet": "vägarbete",
    "vägarbetets": "vägarbete",
    "vägarbets": "vägarbete",
    "vägaren": "vägare",
    "vägarens": "vägare",
    "vägares": "vägare",
    "vägarna": "vägare",
    "vägarnas": "vägare",
    "vägars": "väg",
    "vägas": "väga",
    "vägat": "väga",
    "vägats": "väga",
    "vägbanan": "vägbana",
    "vägbanans": "vägbana",
    "vägbanas": "vägbana",
    "vägbane": "vägbana",
    "vägbanor": "vägbana",
    "vägbanorna": "vägbana",
    "vägbanornas": "vägbana",
    "vägbanors": "vägbana",
    "vägbeläggningar": "vägbeläggning",
    "vägbeläggningarna": "vägbeläggning",
    "vägbeläggningarnas": "vägbeläggning",
    "vägbeläggningars": "vägbeläggning",
    "vägbeläggningen": "vägbeläggning",
    "vägbeläggningens": "vägbeläggning",
    "vägbeläggnings": "vägbeläggning",
    "vägbomben": "vägbomb",
    "vägbombens": "vägbomb",
    "vägbomber": "vägbomb",
    "vägbomberna": "vägbomb",
    "vägbombernas": "vägbomb",
    "vägbombers": "vägbomb",
    "vägbombs": "vägbomb",
    "vägbommar": "vägbom",
    "vägbommarna": "vägbom",
    "vägbommarnas": "vägbom",
    "vägbommars": "vägbom",
    "vägbommen": "vägbom",
    "vägbommens": "vägbom",
    "vägboms": "vägbom",
    "vägbroar": "vägbro",
    "vägbroarna": "vägbro",
    "vägbroarnas": "vägbro",
    "vägbroars": "vägbro",
    "vägbron": "vägbro",
    "vägbrons": "vägbro",
    "vägbros": "vägbro",
    "vägbrytar": "vägbrytare",
    "vägbrytaren": "vägbrytare",
    "vägbrytarens": "vägbrytare",
    "vägbrytares": "vägbrytare",
    "vägbrytarna": "vägbrytare",
    "vägbrytarnas": "vägbrytare",
    "vägbul": "vägbula",
    "vägbulan": "vägbula",
    "vägbulans": "vägbula",
    "vägbulas": "vägbula",
    "vägbule": "vägbula",
    "vägbulor": "vägbula",
    "vägbulorna": "vägbula",
    "vägbulornas": "vägbula",
    "vägbulors": "vägbula",
    "vägbuls": "vägbula",
    "vägbyggen": "vägbygge",
    "vägbyggena": "vägbygge",
    "vägbyggenas": "vägbygge",
    "vägbyggens": "vägbygge",
    "vägbygges": "vägbygge",
    "vägbygget": "vägbygge",
    "vägbyggets": "vägbygge",
    "vägd": "väga",
    "vägda": "väga",
    "vägdas": "väga",
    "vägde": "väga",
    "vägdes": "väga",
    "vägdiken": "vägdike",
    "vägdikena": "vägdike",
    "vägdikenas": "vägdike",
    "vägdikens": "vägdike",
    "vägdikes": "vägdike",
    "vägdiket": "vägdike",
    "vägdikets": "vägdike",
    "vägds": "väga",
    "vägdöden": "vägdöd",
    "vägdödens": "vägdöd",
    "vägdöds": "vägdöd",
    "vägegenskapen": "vägegenskap",
    "vägegenskapens": "vägegenskap",
    "vägegenskaper": "vägegenskap",
    "vägegenskaperna": "vägegenskap",
    "vägegenskapernas": "vägegenskap",
    "vägegenskapers": "vägegenskap",
    "vägegenskaps": "vägegenskap",
    "vägen": "väg",
    "vägens": "väg",
    "väger": "väga",
    "väges": "väga",
    "vägfaranden": "vägfarande",
    "vägfarandena": "vägfarande",
    "vägfarandenas": "vägfarande",
    "vägfarandens": "vägfarande",
    "vägfarandes": "vägfarande",
    "vägfärjan": "vägfärja",
    "vägfärjans": "vägfärja",
    "vägfärjas": "vägfärja",
    "vägfärje": "vägfärja",
    "vägfärjor": "vägfärja",
    "vägfärjorna": "vägfärja",
    "vägfärjornas": "vägfärja",
    "vägfärjors": "vägfärja",
    "vägförbindelsen": "vägförbindelse",
    "vägförbindelsens": "vägförbindelse",
    "vägförbindelser": "vägförbindelse",
    "vägförbindelserna": "vägförbindelse",
    "vägförbindelsernas": "vägförbindelse",
    "vägförbindelsers": "vägförbindelse",
    "vägförbindelses": "vägförbindelse",
    "vägföreningar": "vägförening",
    "vägföreningarna": "vägförening",
    "vägföreningarnas": "vägförening",
    "vägföreningars": "vägförening",
    "vägföreningen": "vägförening",
    "vägföreningens": "vägförening",
    "vägförenings": "vägförening",
    "vägförvaltningar": "vägförvaltning",
    "vägförvaltningarna": "vägförvaltning",
    "vägförvaltningarnas": "vägförvaltning",
    "vägförvaltningars": "vägförvaltning",
    "vägförvaltningen": "vägförvaltning",
    "vägförvaltningens": "vägförvaltning",
    "vägförvaltnings": "vägförvaltning",
    "väggar": "vägg",
    "väggarmar": "väggarm",
    "väggarmarna": "väggarm",
    "väggarmarnas": "väggarm",
    "väggarmars": "väggarm",
    "väggarmen": "väggarm",
    "väggarmens": "väggarm",
    "väggarms": "väggarm",
    "väggarna": "vägg",
    "väggarnas": "vägg",
    "väggars": "vägg",
    "väggbanden": "väggband",
    "väggbandens": "väggband",
    "väggbandet": "väggband",
    "väggbandets": "väggband",
    "väggbands": "väggband",
    "väggbonaden": "väggbonad",
    "väggbonadens": "väggbonad",
    "väggbonader": "väggbonad",
    "väggbonaderna": "väggbonad",
    "väggbonadernas": "väggbonad",
    "väggbonaders": "väggbonad",
    "väggbonads": "väggbonad",
    "väggen": "vägg",
    "väggens": "vägg",
    "väggfasta": "väggfast",
    "väggfastare": "väggfast",
    "väggfastares": "väggfast",
    "väggfastas": "väggfast",
    "väggfastast": "väggfast",
    "väggfastaste": "väggfast",
    "väggfastastes": "väggfast",
    "väggfastasts": "väggfast",
    "väggfaste": "väggfast",
    "väggfastes": "väggfast",
    "väggfasts": "väggfast",
    "väggfästen": "väggfäste",
    "väggfästena": "väggfäste",
    "väggfästenas": "väggfäste",
    "väggfästens": "väggfäste",
    "väggfästes": "väggfäste",
    "väggfästet": "väggfäste",
    "väggfästets": "väggfäste",
    "vägghyll": "vägghylla",
    "vägghyllan": "vägghylla",
    "vägghyllans": "vägghylla",
    "vägghyllas": "vägghylla",
    "vägghylle": "vägghylla",
    "vägghyllor": "vägghylla",
    "vägghyllorna": "vägghylla",
    "vägghyllornas": "vägghylla",
    "vägghyllors": "vägghylla",
    "vägghylls": "vägghylla",
    "väggklock": "väggklocka",
    "väggklockan": "väggklocka",
    "väggklockans": "väggklocka",
    "väggklockas": "väggklocka",
    "väggklocke": "väggklocka",
    "väggklockor": "väggklocka",
    "väggklockorna": "väggklocka",
    "väggklockornas": "väggklocka",
    "väggklockors": "väggklocka",
    "väggklocks": "väggklocka",
    "vägglusen": "vägglus",
    "vägglusens": "vägglus",
    "vägglöss": "vägglus",
    "vägglössen": "vägglus",
    "vägglössens": "vägglus",
    "väggmadammen": "väggmadam",
    "väggmadammens": "väggmadam",
    "väggmadammer": "väggmadam",
    "väggmadammerna": "väggmadam",
    "väggmadammernas": "väggmadam",
    "väggmadammers": "väggmadam",
    "väggmadams": "väggmadam",
    "väggmonterad": "väggmontera",
    "väggmonterade": "väggmontera",
    "väggmonterades": "väggmontera",
    "väggmonterads": "väggmontera",
    "väggmonterande": "väggmontera",
    "väggmonteranden": "väggmonterande",
    "väggmonterandena": "väggmonterande",
    "väggmonterandenas": "väggmonterande",
    "väggmonterandens": "väggmonterande",
    "väggmonterandes": "väggmonterande",
    "väggmonterandet": "väggmonterande",
    "väggmonterandets": "väggmonterande",
    "väggmonterar": "väggmontera",
    "väggmonteras": "väggmontera",
    "väggmonterat": "väggmontera",
    "väggmonterats": "väggmontera",
    "väggmonterbara": "väggmonterbar",
    "väggmonterbarare": "väggmonterbar",
    "väggmonterbarares": "väggmonterbar",
    "väggmonterbaras": "väggmonterbar",
    "väggmonterbarast": "väggmonterbar",
    "väggmonterbaraste": "väggmonterbar",
    "väggmonterbarastes": "väggmonterbar",
    "väggmonterbarasts": "väggmonterbar",
    "väggmonterbare": "väggmonterbar",
    "väggmonterbares": "väggmonterbar",
    "väggmonterbarheten": "väggmonterbarhet",
    "väggmonterbarhetens": "väggmonterbarhet",
    "väggmonterbarhets": "väggmonterbarhet",
    "väggmonterbars": "väggmonterbar",
    "väggmonterbart": "väggmonterbar",
    "väggmonterbarts": "väggmonterbar",
    "väggmossan": "väggmossa",
    "väggmossans": "väggmossa",
    "väggmossas": "väggmossa",
    "väggmålningar": "väggmålning",
    "väggmålningarna": "väggmålning",
    "väggmålningarnas": "väggmålning",
    "väggmålningars": "väggmålning",
    "väggmålningen": "väggmålning",
    "väggmålningens": "väggmålning",
    "väggmålnings": "väggmålning",
    "väggpelar": "väggpelare",
    "väggpelaren": "väggpelare",
    "väggpelarens": "väggpelare",
    "väggpelares": "väggpelare",
    "väggpelarna": "väggpelare",
    "väggpelarnas": "väggpelare",
    "väggplatt": "väggplatta",
    "väggplattan": "väggplatta",
    "väggplattans": "väggplatta",
    "väggplattas": "väggplatta",
    "väggplatte": "väggplatta",
    "väggplattor": "väggplatta",
    "väggplattorna": "väggplatta",
    "väggplattornas": "väggplatta",
    "väggplattors": "väggplatta",
    "väggplatts": "väggplatta",
    "väggreppet": "väggrepp",
    "väggreppets": "väggrepp",
    "väggrepps": "väggrepp",
    "väggs": "vägg",
    "väggspelet": "väggspel",
    "väggspelets": "väggspel",
    "väggspels": "väggspel",
    "väggtelefonen": "väggtelefon",
    "väggtelefonens": "väggtelefon",
    "väggtelefoner": "väggtelefon",
    "väggtelefonerna": "väggtelefon",
    "väggtelefonernas": "väggtelefon",
    "väggtelefoners": "väggtelefon",
    "väggtelefons": "väggtelefon",
    "väggtidningar": "väggtidning",
    "väggtidningarna": "väggtidning",
    "väggtidningarnas": "väggtidning",
    "väggtidningars": "väggtidning",
    "väggtidningen": "väggtidning",
    "väggtidningens": "väggtidning",
    "väggtidnings": "väggtidning",
    "vägguren": "väggur",
    "väggurens": "väggur",
    "vägguret": "väggur",
    "väggurets": "väggur",
    "väggurs": "väggur",
    "vägguttagen": "vägguttag",
    "vägguttagens": "vägguttag",
    "vägguttaget": "vägguttag",
    "vägguttagets": "vägguttag",
    "vägguttags": "vägguttag",
    "väggytan": "väggyta",
    "väggytans": "väggyta",
    "väggytas": "väggyta",
    "väggyte": "väggyta",
    "väggytor": "väggyta",
    "väggytorna": "väggyta",
    "väggytornas": "väggyta",
    "väggytors": "väggyta",
    "väghyveln": "väghyvel",
    "väghyvelns": "väghyvel",
    "väghyvels": "väghyvel",
    "väghyvlar": "väghyvel",
    "väghyvlarna": "väghyvel",
    "väghyvlarnas": "väghyvel",
    "väghyvlars": "väghyvel",
    "väghållningar": "väghållning",
    "väghållningarna": "väghållning",
    "väghållningarnas": "väghållning",
    "väghållningars": "väghållning",
    "väghållningen": "väghållning",
    "väghållningens": "väghållning",
    "väghållnings": "väghållning",
    "vägkanten": "vägkant",
    "vägkantens": "vägkant",
    "vägkanter": "vägkant",
    "vägkanterna": "vägkant",
    "vägkanternas": "vägkant",
    "vägkanters": "vägkant",
    "vägkants": "vägkant",
    "vägkorsen": "vägkors",
    "vägkorsens": "vägkors",
    "vägkorset": "vägkors",
    "vägkorsets": "vägkors",
    "vägkorsningar": "vägkorsning",
    "vägkorsningarna": "vägkorsning",
    "vägkorsningarnas": "vägkorsning",
    "vägkorsningars": "vägkorsning",
    "vägkorsningen": "vägkorsning",
    "vägkorsningens": "vägkorsning",
    "vägkorsnings": "vägkorsning",
    "vägkosten": "vägkost",
    "vägkostens": "vägkost",
    "vägkosts": "vägkost",
    "vägkurv": "vägkurva",
    "vägkurvan": "vägkurva",
    "vägkurvans": "vägkurva",
    "vägkurvas": "vägkurva",
    "vägkurve": "vägkurva",
    "vägkurvor": "vägkurva",
    "vägkurvorna": "vägkurva",
    "vägkurvornas": "vägkurva",
    "vägkurvors": "vägkurva",
    "vägkurvs": "vägkurva",
    "väglagar": "väglag",
    "väglagarna": "väglag",
    "väglagarnas": "väglag",
    "väglagars": "väglag",
    "väglagen": "väglag",
    "väglagens": "väglag",
    "väglaget": "väglag",
    "väglagets": "väglag",
    "väglags": "väglag",
    "vägled": "vägleda",
    "vägledande": "vägleda",
    "vägledanden": "vägledande",
    "vägledandena": "vägledande",
    "vägledandenas": "vägledande",
    "vägledandens": "vägledande",
    "vägledandes": "vägledande",
    "vägledandet": "vägledande",
    "vägledandets": "vägledande",
    "vägledas": "vägleda",
    "vägledd": "vägleda",
    "vägledda": "vägleda",
    "vägleddas": "vägleda",
    "vägledde": "vägleda",
    "vägleddes": "vägleda",
    "vägledds": "vägleda",
    "vägleder": "vägleda",
    "vägledes": "vägleda",
    "vägledningar": "vägledning",
    "vägledningarna": "vägledning",
    "vägledningarnas": "vägledning",
    "vägledningars": "vägledning",
    "vägledningen": "vägledning",
    "vägledningens": "vägledning",
    "väglednings": "vägledning",
    "vägleds": "vägleda",
    "väglett": "vägleda",
    "vägletts": "vägleda",
    "väglusen": "väglus",
    "väglusens": "väglus",
    "väglöss": "väglus",
    "väglössen": "väglus",
    "väglössens": "väglus",
    "vägmaskinen": "vägmaskin",
    "vägmaskinens": "vägmaskin",
    "vägmaskiner": "vägmaskin",
    "vägmaskinerna": "vägmaskin",
    "vägmaskinernas": "vägmaskin",
    "vägmaskiners": "vägmaskin",
    "vägmaskins": "vägmaskin",
    "vägmärken": "vägmärke",
    "vägmärkena": "vägmärke",
    "vägmärkenas": "vägmärke",
    "vägmärkens": "vägmärke",
    "vägmärkes": "vägmärke",
    "vägmärket": "vägmärke",
    "vägmärkets": "vägmärke",
    "vägmätar": "vägmätare",
    "vägmätaren": "vägmätare",
    "vägmätarens": "vägmätare",
    "vägmätares": "vägmätare",
    "vägmätarna": "vägmätare",
    "vägmätarnas": "vägmätare",
    "vägningar": "vägning",
    "vägningarna": "vägning",
    "vägningarnas": "vägning",
    "vägningars": "vägning",
    "vägningen": "vägning",
    "vägningens": "vägning",
    "vägnings": "vägning",
    "vägnäten": "vägnät",
    "vägnätens": "vägnät",
    "vägnätet": "vägnät",
    "vägnätets": "vägnät",
    "vägnäts": "vägnät",
    "vägportar": "vägport",
    "vägportarna": "vägport",
    "vägportarnas": "vägport",
    "vägportars": "vägport",
    "vägporten": "vägport",
    "vägportens": "vägport",
    "vägports": "vägport",
    "vägrad": "vägra",
    "vägrade": "vägra",
    "vägrades": "vägra",
    "vägrads": "vägra",
    "vägrande": "vägra",
    "vägranden": "vägrande",
    "vägrandena": "vägrande",
    "vägrandenas": "vägrande",
    "vägrandens": "vägrande",
    "vägrandes": "vägrande",
    "vägrandet": "vägrande",
    "vägrandets": "vägrande",
    "vägrans": "vägran",
    "vägrar": "vägrare",
    "vägraren": "vägrare",
    "vägrarens": "vägrare",
    "vägrares": "vägrare",
    "vägrarna": "vägrare",
    "vägrarnas": "vägrare",
    "vägras": "vägra",
    "vägrat": "vägra",
    "vägrats": "vägra",
    "vägrenar": "vägren",
    "vägrenarna": "vägren",
    "vägrenarnas": "vägren",
    "vägrenars": "vägren",
    "vägrenen": "vägren",
    "vägrenens": "vägren",
    "vägrens": "vägren",
    "vägräcken": "vägräcke",
    "vägräckena": "vägräcke",
    "vägräckenas": "vägräcke",
    "vägräckens": "vägräcke",
    "vägräckes": "vägräcke",
    "vägräcket": "vägräcke",
    "vägräckets": "vägräcke",
    "vägröjar": "vägröjare",
    "vägröjaren": "vägröjare",
    "vägröjarens": "vägröjare",
    "vägröjares": "vägröjare",
    "vägröjarna": "vägröjare",
    "vägröjarnas": "vägröjare",
    "vägs": "väga",
    "vägsaltet": "vägsalt",
    "vägsaltets": "vägsalt",
    "vägsalts": "vägsalt",
    "vägskrapan": "vägskrapa",
    "vägskrapans": "vägskrapa",
    "vägskrapas": "vägskrapa",
    "vägskrape": "vägskrapa",
    "vägskrapor": "vägskrapa",
    "vägskraporna": "vägskrapa",
    "vägskrapornas": "vägskrapa",
    "vägskrapors": "vägskrapa",
    "vägskyltar": "vägskylt",
    "vägskyltarna": "vägskylt",
    "vägskyltarnas": "vägskylt",
    "vägskyltars": "vägskylt",
    "vägskylten": "vägskylt",
    "vägskyltens": "vägskylt",
    "vägskylts": "vägskylt",
    "vägskälen": "vägskäl",
    "vägskälens": "vägskäl",
    "vägskälet": "vägskäl",
    "vägskälets": "vägskäl",
    "vägskäls": "vägskäl",
    "vägsmutset": "vägsmuts",
    "vägsmutsets": "vägsmuts",
    "vägspärrar": "vägspärr",
    "vägspärrarna": "vägspärr",
    "vägspärrarnas": "vägspärr",
    "vägspärrars": "vägspärr",
    "vägspärren": "vägspärr",
    "vägspärrens": "vägspärr",
    "vägspärrs": "vägspärr",
    "vägsträck": "vägsträcka",
    "vägsträckan": "vägsträcka",
    "vägsträckans": "vägsträcka",
    "vägsträckas": "vägsträcka",
    "vägsträcke": "vägsträcka",
    "vägsträckor": "vägsträcka",
    "vägsträckorna": "vägsträcka",
    "vägsträckornas": "vägsträcka",
    "vägsträckors": "vägsträcka",
    "vägsträcks": "vägsträcka",
    "vägt": "väga",
    "vägtisteln": "vägtistel",
    "vägtistelns": "vägtistel",
    "vägtistels": "vägtistel",
    "vägtistlar": "vägtistel",
    "vägtistlarna": "vägtistel",
    "vägtistlarnas": "vägtistel",
    "vägtistlars": "vägtistel",
    "vägtornar": "vägtorn",
    "vägtornarna": "vägtorn",
    "vägtornarnas": "vägtorn",
    "vägtornars": "vägtorn",
    "vägtornen": "vägtorn",
    "vägtornens": "vägtorn",
    "vägtorns": "vägtorn",
    "vägtrafiken": "vägtrafik",
    "vägtrafikens": "vägtrafik",
    "vägtrafiks": "vägtrafik",
    "vägtrum": "vägtrumma",
    "vägtrumman": "vägtrumma",
    "vägtrummans": "vägtrumma",
    "vägtrummas": "vägtrumma",
    "vägtrumme": "vägtrumma",
    "vägtrummor": "vägtrumma",
    "vägtrummorna": "vägtrumma",
    "vägtrummornas": "vägtrumma",
    "vägtrummors": "vägtrumma",
    "vägtrums": "vägtrumma",
    "vägts": "väga",
    "vägtullar": "vägtull",
    "vägtullarna": "vägtull",
    "vägtullarnas": "vägtull",
    "vägtullars": "vägtull",
    "vägtullen": "vägtull",
    "vägtullens": "vägtull",
    "vägtulls": "vägtull",
    "vägtunlar": "vägtunnel",
    "vägtunlarna": "vägtunnel",
    "vägtunlarnas": "vägtunnel",
    "vägtunlars": "vägtunnel",
    "vägtunneln": "vägtunnel",
    "vägtunnelns": "vägtunnel",
    "vägtunnels": "vägtunnel",
    "vägtunnlar": "vägtunnel",
    "vägtunnlarna": "vägtunnel",
    "vägtunnlarnas": "vägtunnel",
    "vägtunnlars": "vägtunnel",
    "vägvalen": "vägval",
    "vägvalens": "vägval",
    "vägvalet": "vägval",
    "vägvalets": "vägval",
    "vägvals": "vägval",
    "vägvilla": "vägvill",
    "vägvillare": "vägvill",
    "vägvillares": "vägvill",
    "vägvillas": "vägvill",
    "vägvillast": "vägvill",
    "vägvillaste": "vägvill",
    "vägvillastes": "vägvill",
    "vägvillasts": "vägvill",
    "vägville": "vägvill",
    "vägvilles": "vägvill",
    "vägvillheten": "vägvillhet",
    "vägvillhetens": "vägvillhet",
    "vägvillhets": "vägvillhet",
    "vägvills": "vägvill",
    "vägvisar": "vägvisare",
    "vägvisaren": "vägvisare",
    "vägvisarens": "vägvisare",
    "vägvisares": "vägvisare",
    "vägvisarna": "vägvisare",
    "vägvisarnas": "vägvisare",
    "vägvård": "vägvårda",
    "vägvårdan": "vägvårda",
    "vägvårdans": "vägvårda",
    "vägvårdas": "vägvårda",
    "vägvårde": "vägvårda",
    "vägvårdor": "vägvårda",
    "vägvårdorna": "vägvårda",
    "vägvårdornas": "vägvårda",
    "vägvårdors": "vägvårda",
    "vägvårds": "vägvårda",
    "väj": "väja",
    "väjande": "väja",
    "väjanden": "väjande",
    "väjandena": "väjande",
    "väjandenas": "väjande",
    "väjandens": "väjande",
    "väjandes": "väjande",
    "väjandet": "väjande",
    "väjandets": "väjande",
    "väjas": "väja",
    "väjd": "väja",
    "väjda": "väja",
    "väjdas": "väja",
    "väjde": "väja",
    "väjdes": "väja",
    "väjds": "väja",
    "väjer": "väja",
    "väjes": "väja",
    "väjningar": "väjning",
    "väjningarna": "väjning",
    "väjningarnas": "väjning",
    "väjningars": "väjning",
    "väjningen": "väjning",
    "väjningens": "väjning",
    "väjnings": "väjning",
    "väjs": "väja",
    "väjt": "väja",
    "väjts": "väja",
    "väktar": "väktare",
    "väktaren": "väktare",
    "väktarens": "väktare",
    "väktares": "väktare",
    "väktarna": "väktare",
    "väktarnas": "väktare",
    "väkten": "väkt",
    "väktens": "väkt",
    "väkter": "väkt",
    "väkterna": "väkt",
    "väkternas": "väkt",
    "väkters": "väkt",
    "väkts": "väkt",
    "välaktade": "välaktad",
    "välaktades": "välaktad",
    "välaktads": "välaktad",
    "välaktat": "välaktad",
    "välaktats": "välaktad",
    "välanpassade": "välanpassad",
    "välanpassades": "välanpassad",
    "välanpassads": "välanpassad",
    "välanpassat": "välanpassad",
    "välanpassats": "välanpassad",
    "välansade": "välansad",
    "välansades": "välansad",
    "välansads": "välansad",
    "välansat": "välansad",
    "välansats": "välansad",
    "välartade": "välartad",
    "välartades": "välartad",
    "välartads": "välartad",
    "välartat": "välartad",
    "välartats": "välartad",
    "välavlönade": "välavlönad",
    "välavlönades": "välavlönad",
    "välavlönads": "välavlönad",
    "välavlönat": "välavlönad",
    "välavlönats": "välavlönad",
    "välavvägda": "välavvägd",
    "välavvägdare": "välavvägd",
    "välavvägdares": "välavvägd",
    "välavvägdas": "välavvägd",
    "välavvägdast": "välavvägd",
    "välavvägdaste": "välavvägd",
    "välavvägdastes": "välavvägd",
    "välavvägdasts": "välavvägd",
    "välavvägde": "välavvägd",
    "välavvägdes": "välavvägd",
    "välavvägdheten": "välavvägdhet",
    "välavvägdhetens": "välavvägdhet",
    "välavvägdhets": "välavvägdhet",
    "välavvägds": "välavvägd",
    "välavvägt": "välavvägd",
    "välavvägts": "välavvägd",
    "välbalanserade": "välbalanserad",
    "välbalanserades": "välbalanserad",
    "välbalanserads": "välbalanserad",
    "välbalanserat": "välbalanserad",
    "välbalanserats": "välbalanserad",
    "välbefinnandes": "välbefinnande",
    "välbefinnandet": "välbefinnande",
    "välbefinnandets": "välbefinnande",
    "välbefogade": "välbefogad",
    "välbefogades": "välbefogad",
    "välbefogads": "välbefogad",
    "välbefogat": "välbefogad",
    "välbefogats": "välbefogad",
    "välbegripliga": "välbegriplig",
    "välbegripligare": "välbegriplig",
    "välbegripligares": "välbegriplig",
    "välbegripligas": "välbegriplig",
    "välbegripligast": "välbegriplig",
    "välbegripligaste": "välbegriplig",
    "välbegripligastes": "välbegriplig",
    "välbegripligasts": "välbegriplig",
    "välbegriplige": "välbegriplig",
    "välbegripliges": "välbegriplig",
    "välbegripligheten": "välbegriplighet",
    "välbegriplighetens": "välbegriplighet",
    "välbegriplighets": "välbegriplighet",
    "välbegripligs": "välbegriplig",
    "välbegripligt": "välbegriplig",
    "välbegripligts": "välbegriplig",
    "välbehaget": "välbehag",
    "välbehagets": "välbehag",
    "välbehags": "välbehag",
    "välbehållens": "välbehållen",
    "välbehållet": "välbehållen",
    "välbehållets": "välbehållen",
    "välbehållna": "välbehållen",
    "välbehållnare": "välbehållen",
    "välbehållnares": "välbehållen",
    "välbehållnas": "välbehållen",
    "välbehållnast": "välbehållen",
    "välbehållnaste": "välbehållen",
    "välbehållnastes": "välbehållen",
    "välbehållnasts": "välbehållen",
    "välbehållne": "välbehållen",
    "välbehållnes": "välbehållen",
    "välbehövliga": "välbehövlig",
    "välbehövligare": "välbehövlig",
    "välbehövligares": "välbehövlig",
    "välbehövligas": "välbehövlig",
    "välbehövligast": "välbehövlig",
    "välbehövligaste": "välbehövlig",
    "välbehövligastes": "välbehövlig",
    "välbehövligasts": "välbehövlig",
    "välbehövlige": "välbehövlig",
    "välbehövliges": "välbehövlig",
    "välbehövligheten": "välbehövlighet",
    "välbehövlighetens": "välbehövlighet",
    "välbehövlighets": "välbehövlighet",
    "välbehövligs": "välbehövlig",
    "välbehövligt": "välbehövlig",
    "välbehövligts": "välbehövlig",
    "välbekanta": "välbekant",
    "välbekantare": "välbekant",
    "välbekantares": "välbekant",
    "välbekantas": "välbekant",
    "välbekantast": "välbekant",
    "välbekantaste": "välbekant",
    "välbekantastes": "välbekant",
    "välbekantasts": "välbekant",
    "välbekante": "välbekant",
    "välbekantes": "välbekant",
    "välbekants": "välbekant",
    "välbelägens": "välbelägen",
    "välbeläget": "välbelägen",
    "välbelägets": "välbelägen",
    "välbelägna": "välbelägen",
    "välbelägnare": "välbelägen",
    "välbelägnares": "välbelägen",
    "välbelägnas": "välbelägen",
    "välbelägnast": "välbelägen",
    "välbelägnaste": "välbelägen",
    "välbelägnastes": "välbelägen",
    "välbelägnasts": "välbelägen",
    "välbelägne": "välbelägen",
    "välbelägnes": "välbelägen",
    "välbemedlade": "välbemedlad",
    "välbemedlades": "välbemedlad",
    "välbemedlads": "välbemedlad",
    "välbemedlat": "välbemedlad",
    "välbemedlats": "välbemedlad",
    "välbeprövade": "välbeprövad",
    "välbeprövades": "välbeprövad",
    "välbeprövads": "välbeprövad",
    "välbeprövat": "välbeprövad",
    "välbeprövats": "välbeprövad",
    "välberäknade": "välberäknad",
    "välberäknades": "välberäknad",
    "välberäknads": "välberäknad",
    "välberäknat": "välberäknad",
    "välberäknats": "välberäknad",
    "välbesatta": "välbesatt",
    "välbesattare": "välbesatt",
    "välbesattares": "välbesatt",
    "välbesattas": "välbesatt",
    "välbesattast": "välbesatt",
    "välbesattaste": "välbesatt",
    "välbesattastes": "välbesatt",
    "välbesattasts": "välbesatt",
    "välbesatte": "välbesatt",
    "välbesattes": "välbesatt",
    "välbesatts": "välbesatt",
    "välbeställda": "välbeställd",
    "välbeställdare": "välbeställd",
    "välbeställdares": "välbeställd",
    "välbeställdas": "välbeställd",
    "välbeställdast": "välbeställd",
    "välbeställdaste": "välbeställd",
    "välbeställdastes": "välbeställd",
    "välbeställdasts": "välbeställd",
    "välbeställde": "välbeställd",
    "välbeställdes": "välbeställd",
    "välbeställdheten": "välbeställdhet",
    "välbeställdhetens": "välbeställdhet",
    "välbeställdhets": "välbeställdhet",
    "välbeställds": "välbeställd",
    "välbeställt": "välbeställd",
    "välbeställts": "välbeställd",
    "välbesökta": "välbesökt",
    "välbesöktare": "välbesökt",
    "välbesöktares": "välbesökt",
    "välbesöktas": "välbesökt",
    "välbesöktast": "välbesökt",
    "välbesöktaste": "välbesökt",
    "välbesöktastes": "välbesökt",
    "välbesöktasts": "välbesökt",
    "välbesökte": "välbesökt",
    "välbesöktes": "välbesökt",
    "välbesöktheten": "välbesökthet",
    "välbesökthetens": "välbesökthet",
    "välbesökthets": "välbesökthet",
    "välbesökts": "välbesökt",
    "välbetalda": "välbetald",
    "välbetaldare": "välbetald",
    "välbetaldares": "välbetald",
    "välbetaldas": "välbetald",
    "välbetaldast": "välbetald",
    "välbetaldaste": "välbetald",
    "välbetaldastes": "välbetald",
    "välbetaldasts": "välbetald",
    "välbetalde": "välbetald",
    "välbetaldes": "välbetald",
    "välbetaldheten": "välbetaldhet",
    "välbetaldhetens": "välbetaldhet",
    "välbetaldhets": "välbetaldhet",
    "välbetalds": "välbetald",
    "välbetalt": "välbetald",
    "välbetalts": "välbetald",
    "välbetänkta": "välbetänkt",
    "välbetänktare": "välbetänkt",
    "välbetänktares": "välbetänkt",
    "välbetänktas": "välbetänkt",
    "välbetänktast": "välbetänkt",
    "välbetänktaste": "välbetänkt",
    "välbetänktastes": "välbetänkt",
    "välbetänktasts": "välbetänkt",
    "välbetänkte": "välbetänkt",
    "välbetänktes": "välbetänkt",
    "välbetänktheten": "välbetänkthet",
    "välbetänkthetens": "välbetänkthet",
    "välbetänkthets": "välbetänkthet",
    "välbetänkts": "välbetänkt",
    "välbevarade": "välbevarad",
    "välbevarades": "välbevarad",
    "välbevarads": "välbevarad",
    "välbevarat": "välbevarad",
    "välbevarats": "välbevarad",
    "välbildade": "välbildad",
    "välbildades": "välbildad",
    "välbildads": "välbildad",
    "välbildat": "välbildad",
    "välbildats": "välbildad",
    "välborens": "välboren",
    "välboret": "välboren",
    "välborets": "välboren",
    "välborna": "välboren",
    "välbornare": "välboren",
    "välbornares": "välboren",
    "välbornas": "välboren",
    "välbornast": "välboren",
    "välbornaste": "välboren",
    "välbornastes": "välboren",
    "välbornasts": "välboren",
    "välborne": "välboren",
    "välbornes": "välboren",
    "välborstade": "välborstad",
    "välborstades": "välborstad",
    "välborstads": "välborstad",
    "välborstat": "välborstad",
    "välborstats": "välborstad",
    "välbyggda": "välbyggd",
    "välbyggdare": "välbyggd",
    "välbyggdares": "välbyggd",
    "välbyggdas": "välbyggd",
    "välbyggdast": "välbyggd",
    "välbyggdaste": "välbyggd",
    "välbyggdastes": "välbyggd",
    "välbyggdasts": "välbyggd",
    "välbyggde": "välbyggd",
    "välbyggdes": "välbyggd",
    "välbyggds": "välbyggd",
    "välbyggt": "välbyggd",
    "välbyggts": "välbyggd",
    "välbärgade": "välbärgad",
    "välbärgades": "välbärgad",
    "välbärgads": "välbärgad",
    "välbärgat": "välbärgad",
    "välbärgats": "välbärgad",
    "väldaterade": "väldaterad",
    "väldaterades": "väldaterad",
    "väldaterads": "väldaterad",
    "väldaterat": "väldaterad",
    "väldaterats": "väldaterad",
    "välden": "välde",
    "väldena": "välde",
    "väldenas": "välde",
    "väldens": "välde",
    "väldes": "välde",
    "väldet": "välde",
    "väldets": "välde",
    "väldiga": "väldig",
    "väldigare": "väldig",
    "väldigares": "väldig",
    "väldigas": "väldig",
    "väldigast": "väldig",
    "väldigaste": "väldig",
    "väldigastes": "väldig",
    "väldigasts": "väldig",
    "väldige": "väldig",
    "väldiges": "väldig",
    "väldigheten": "väldighet",
    "väldighetens": "väldighet",
    "väldigheter": "väldighet",
    "väldigheterna": "väldighet",
    "väldigheternas": "väldighet",
    "väldigheters": "väldighet",
    "väldighets": "väldighet",
    "väldigs": "väldig",
    "väldigt": "väldig",
    "väldigts": "väldig",
    "välds": "väld",
    "välformade": "välformad",
    "välformades": "välformad",
    "välformads": "välformad",
    "välformat": "välformad",
    "välformats": "välformad",
    "välfriserade": "välfriserad",
    "välfriserades": "välfriserad",
    "välfriserads": "välfriserad",
    "välfriserat": "välfriserad",
    "välfriserats": "välfriserad",
    "välfunna": "välfunnen",
    "välfunnare": "välfunnen",
    "välfunnares": "välfunnen",
    "välfunnas": "välfunnen",
    "välfunnast": "välfunnen",
    "välfunnaste": "välfunnen",
    "välfunnastes": "välfunnen",
    "välfunnasts": "välfunnen",
    "välfunne": "välfunnen",
    "välfunnens": "välfunnen",
    "välfunnes": "välfunnen",
    "välfunnet": "välfunnen",
    "välfunnets": "välfunnen",
    "välfyllda": "välfylld",
    "välfylldare": "välfylld",
    "välfylldares": "välfylld",
    "välfylldas": "välfylld",
    "välfylldast": "välfylld",
    "välfylldaste": "välfylld",
    "välfylldastes": "välfylld",
    "välfylldasts": "välfylld",
    "välfyllde": "välfylld",
    "välfylldes": "välfylld",
    "välfyllds": "välfylld",
    "välfyllt": "välfylld",
    "välfyllts": "välfylld",
    "välfägn": "välfägna",
    "välfägnad": "välfägna",
    "välfägnade": "välfägna",
    "välfägnaden": "välfägnad",
    "välfägnadens": "välfägnad",
    "välfägnader": "välfägnad",
    "välfägnaderna": "välfägnad",
    "välfägnadernas": "välfägnad",
    "välfägnaders": "välfägnad",
    "välfägnades": "välfägna",
    "välfägnads": "välfägnad",
    "välfägnande": "välfägna",
    "välfägnanden": "välfägnande",
    "välfägnandena": "välfägnande",
    "välfägnandenas": "välfägnande",
    "välfägnandens": "välfägnande",
    "välfägnandes": "välfägnande",
    "välfägnandet": "välfägnande",
    "välfägnandets": "välfägnande",
    "välfägnar": "välfägna",
    "välfägnas": "välfägna",
    "välfägnat": "välfägna",
    "välfägnats": "välfägna",
    "välfärden": "välfärd",
    "välfärdens": "välfärd",
    "välfärds": "välfärd",
    "välfärdsbyggen": "välfärdsbygge",
    "välfärdsbyggena": "välfärdsbygge",
    "välfärdsbyggenas": "välfärdsbygge",
    "välfärdsbyggens": "välfärdsbygge",
    "välfärdsbygges": "välfärdsbygge",
    "välfärdsbygget": "välfärdsbygge",
    "välfärdsbyggets": "välfärdsbygge",
    "välfärdsideologien": "välfärdsideologi",
    "välfärdsideologiens": "välfärdsideologi",
    "välfärdsideologier": "välfärdsideologi",
    "välfärdsideologierna": "välfärdsideologi",
    "välfärdsideologiernas": "välfärdsideologi",
    "välfärdsideologiers": "välfärdsideologi",
    "välfärdsideologin": "välfärdsideologi",
    "välfärdsideologins": "välfärdsideologi",
    "välfärdsideologis": "välfärdsideologi",
    "välfärdskrisen": "välfärdskris",
    "välfärdskrisens": "välfärdskris",
    "välfärdskriser": "välfärdskris",
    "välfärdskriserna": "välfärdskris",
    "välfärdskrisernas": "välfärdskris",
    "välfärdskrisers": "välfärdskris",
    "välfärdslöften": "välfärdslöfte",
    "välfärdslöftena": "välfärdslöfte",
    "välfärdslöftenas": "välfärdslöfte",
    "välfärdslöftens": "välfärdslöfte",
    "välfärdslöftes": "välfärdslöfte",
    "välfärdslöftet": "välfärdslöfte",
    "välfärdslöftets": "välfärdslöfte",
    "välfärdspolitiken": "välfärdspolitik",
    "välfärdspolitikens": "välfärdspolitik",
    "välfärdspolitiks": "välfärdspolitik",
    "välfärdspolitiska": "välfärdspolitisk",
    "välfärdspolitiskas": "välfärdspolitisk",
    "välfärdspolitiske": "välfärdspolitisk",
    "välfärdspolitiskes": "välfärdspolitisk",
    "välfärdspolitisks": "välfärdspolitisk",
    "välfärdspolitiskt": "välfärdspolitisk",
    "välfärdspolitiskts": "välfärdspolitisk",
    "välfärdssamhällen": "välfärdssamhälle",
    "välfärdssamhällena": "välfärdssamhälle",
    "välfärdssamhällenas": "välfärdssamhälle",
    "välfärdssamhällens": "välfärdssamhälle",
    "välfärdssamhälles": "välfärdssamhälle",
    "välfärdssamhället": "välfärdssamhälle",
    "välfärdssamhällets": "välfärdssamhälle",
    "välfärdssamhälls": "välfärdssamhälle",
    "välfärdsstaten": "välfärdsstat",
    "välfärdsstatens": "välfärdsstat",
    "välfärdsstater": "välfärdsstat",
    "välfärdsstaterna": "välfärdsstat",
    "välfärdsstaternas": "välfärdsstat",
    "välfärdsstaters": "välfärdsstat",
    "välfärdsstats": "välfärdsstat",
    "välfärdssystemen": "välfärdssystem",
    "välfärdssystemens": "välfärdssystem",
    "välfärdssystemet": "välfärdssystem",
    "välfärdssystemets": "välfärdssystem",
    "välfärdssystems": "välfärdssystem",
    "välfödda": "välfödd",
    "välföddare": "välfödd",
    "välföddares": "välfödd",
    "välföddas": "välfödd",
    "välföddast": "välfödd",
    "välföddaste": "välfödd",
    "välföddastes": "välfödd",
    "välföddasts": "välfödd",
    "välfödde": "välfödd",
    "välföddes": "välfödd",
    "välfödds": "välfödd",
    "välförenliga": "välförenlig",
    "välförenligare": "välförenlig",
    "välförenligares": "välförenlig",
    "välförenligas": "välförenlig",
    "välförenligast": "välförenlig",
    "välförenligaste": "välförenlig",
    "välförenligastes": "välförenlig",
    "välförenligasts": "välförenlig",
    "välförenlige": "välförenlig",
    "välförenliges": "välförenlig",
    "välförenligheten": "välförenlighet",
    "välförenlighetens": "välförenlighet",
    "välförenlighets": "välförenlighet",
    "välförenligs": "välförenlig",
    "välförenligt": "välförenlig",
    "välförenligts": "välförenlig",
    "välförklarliga": "välförklarlig",
    "välförklarligare": "välförklarlig",
    "välförklarligares": "välförklarlig",
    "välförklarligas": "välförklarlig",
    "välförklarligast": "välförklarlig",
    "välförklarligaste": "välförklarlig",
    "välförklarligastes": "välförklarlig",
    "välförklarligasts": "välförklarlig",
    "välförklarlige": "välförklarlig",
    "välförklarliges": "välförklarlig",
    "välförklarligheten": "välförklarlighet",
    "välförklarlighetens": "välförklarlighet",
    "välförklarlighets": "välförklarlighet",
    "välförklarligs": "välförklarlig",
    "välförklarligt": "välförklarlig",
    "välförklarligts": "välförklarlig",
    "välförrättade": "välförrättad",
    "välförrättades": "välförrättad",
    "välförrättads": "välförrättad",
    "välförrättat": "välförrättad",
    "välförrättats": "välförrättad",
    "välförsedda": "välförsedd",
    "välförseddare": "välförsedd",
    "välförseddares": "välförsedd",
    "välförseddas": "välförsedd",
    "välförseddast": "välförsedd",
    "välförseddaste": "välförsedd",
    "välförseddastes": "välförsedd",
    "välförseddasts": "välförsedd",
    "välförsedde": "välförsedd",
    "välförseddes": "välförsedd",
    "välförsedds": "välförsedd",
    "välförsett": "välförsedd",
    "välförsetts": "välförsedd",
    "välförstådda": "välförstådd",
    "välförståddare": "välförstådd",
    "välförståddares": "välförstådd",
    "välförståddas": "välförstådd",
    "välförståddast": "välförstådd",
    "välförståddaste": "välförstådd",
    "välförståddastes": "välförstådd",
    "välförståddasts": "välförstådd",
    "välförstådde": "välförstådd",
    "välförståddes": "välförstådd",
    "välförstådds": "välförstådd",
    "välförståeliga": "välförståelig",
    "välförståeligare": "välförståelig",
    "välförståeligares": "välförståelig",
    "välförståeligas": "välförståelig",
    "välförståeligast": "välförståelig",
    "välförståeligaste": "välförståelig",
    "välförståeligastes": "välförståelig",
    "välförståeligasts": "välförståelig",
    "välförståelige": "välförståelig",
    "välförståeliges": "välförståelig",
    "välförståeligheten": "välförståelighet",
    "välförståelighetens": "välförståelighet",
    "välförståelighets": "välförståelighet",
    "välförståeligs": "välförståelig",
    "välförståeligt": "välförståelig",
    "välförståeligts": "välförståelig",
    "välförståndiga": "välförståndig",
    "välförståndigare": "välförståndig",
    "välförståndigares": "välförståndig",
    "välförståndigas": "välförståndig",
    "välförståndigast": "välförståndig",
    "välförståndigaste": "välförståndig",
    "välförståndigastes": "välförståndig",
    "välförståndigasts": "välförståndig",
    "välförståndige": "välförståndig",
    "välförståndiges": "välförståndig",
    "välförståndigheten": "välförståndighet",
    "välförståndighetens": "välförståndighet",
    "välförståndighets": "välförståndighet",
    "välförståndigs": "välförståndig",
    "välförståndigt": "välförståndig",
    "välförståndigts": "välförståndig",
    "välförstått": "välförstådd",
    "välförståtts": "välförstådd",
    "välförtjänta": "välförtjänt",
    "välförtjäntare": "välförtjänt",
    "välförtjäntares": "välförtjänt",
    "välförtjäntas": "välförtjänt",
    "välförtjäntast": "välförtjänt",
    "välförtjäntaste": "välförtjänt",
    "välförtjäntastes": "välförtjänt",
    "välförtjäntasts": "välförtjänt",
    "välförtjänte": "välförtjänt",
    "välförtjäntes": "välförtjänt",
    "välförtjäntheten": "välförtjänthet",
    "välförtjänthetens": "välförtjänthet",
    "välförtjänthets": "välförtjänthet",
    "välförtjänts": "välförtjänt",
    "välfött": "välfödd",
    "välfötts": "välfödd",
    "välgjorda": "välgjord",
    "välgjordare": "välgjord",
    "välgjordares": "välgjord",
    "välgjordas": "välgjord",
    "välgjordast": "välgjord",
    "välgjordaste": "välgjord",
    "välgjordastes": "välgjord",
    "välgjordasts": "välgjord",
    "välgjorde": "välgjord",
    "välgjordes": "välgjord",
    "välgjords": "välgjord",
    "välgjort": "välgjord",
    "välgjorts": "välgjord",
    "välgrundade": "välgrundad",
    "välgrundades": "välgrundad",
    "välgrundads": "välgrundad",
    "välgrundat": "välgrundad",
    "välgrundats": "välgrundad",
    "välgärningar": "välgärning",
    "välgärningarna": "välgärning",
    "välgärningarnas": "välgärning",
    "välgärningars": "välgärning",
    "välgärningen": "välgärning",
    "välgärningens": "välgärning",
    "välgärnings": "välgärning",
    "välgången": "välgång",
    "välgångens": "välgång",
    "välgångs": "välgång",
    "välgödda": "välgödd",
    "välgöddare": "välgödd",
    "välgöddares": "välgödd",
    "välgöddas": "välgödd",
    "välgöddast": "välgödd",
    "välgöddaste": "välgödd",
    "välgöddastes": "välgödd",
    "välgöddasts": "välgödd",
    "välgödde": "välgödd",
    "välgöddes": "välgödd",
    "välgödds": "välgödd",
    "välgörar": "välgörare",
    "välgöraren": "välgörare",
    "välgörarens": "välgörare",
    "välgörares": "välgörare",
    "välgörarna": "välgörare",
    "välgörarnas": "välgörare",
    "välgörenheten": "välgörenhet",
    "välgörenhetens": "välgörenhet",
    "välgörenheter": "välgörenhet",
    "välgörenheterna": "välgörenhet",
    "välgörenheternas": "välgörenhet",
    "välgörenheters": "välgörenhet",
    "välgörenhets": "välgörenhet",
    "välgörenhetsbasaren": "välgörenhetsbasar",
    "välgörenhetsbasarens": "välgörenhetsbasar",
    "välgörenhetsbasarer": "välgörenhetsbasar",
    "välgörenhetsbasarerna": "välgörenhetsbasar",
    "välgörenhetsbasarernas": "välgörenhetsbasar",
    "välgörenhetsbasarers": "välgörenhetsbasar",
    "välgörenhetsbasars": "välgörenhetsbasar",
    "välgörenhetsorganisationen": "välgörenhetsorganisation",
    "välgörenhetsorganisationens": "välgörenhetsorganisation",
    "välgörenhetsorganisationer": "välgörenhetsorganisation",
    "välgörenhetsorganisationerna": "välgörenhetsorganisation",
    "välgörenhetsorganisationernas": "välgörenhetsorganisation",
    "välgörenhetsorganisationers": "välgörenhetsorganisation",
    "välgörenhetsorganisations": "välgörenhetsorganisation",
    "välgött": "välgödd",
    "välgötts": "välgödd",
    "välhängda": "välhängd",
    "välhängdare": "välhängd",
    "välhängdares": "välhängd",
    "välhängdas": "välhängd",
    "välhängdast": "välhängd",
    "välhängdaste": "välhängd",
    "välhängdastes": "välhängd",
    "välhängdasts": "välhängd",
    "välhängde": "välhängd",
    "välhängdes": "välhängd",
    "välhängds": "välhängd",
    "välhängt": "välhängd",
    "välhängts": "välhängd",
    "välhållens": "välhållen",
    "välhållet": "välhållen",
    "välhållets": "välhållen",
    "välhållna": "välhållen",
    "välhållnare": "välhållen",
    "välhållnares": "välhållen",
    "välhållnas": "välhållen",
    "välhållnast": "välhållen",
    "välhållnaste": "välhållen",
    "välhållnastes": "välhållen",
    "välhållnasts": "välhållen",
    "välhållne": "välhållen",
    "välhållnes": "välhållen",
    "välinformerade": "välinformerad",
    "välinformerades": "välinformerad",
    "välinformerads": "välinformerad",
    "välinformerat": "välinformerad",
    "välinformerats": "välinformerad",
    "välisolerade": "välisolerad",
    "välisolerades": "välisolerad",
    "välisolerads": "välisolerad",
    "välisolerat": "välisolerad",
    "välisolerats": "välisolerad",
    "välj": "välja",
    "väljande": "välja",
    "väljanden": "väljande",
    "väljandena": "väljande",
    "väljandenas": "väljande",
    "väljandens": "väljande",
    "väljandes": "väljande",
    "väljandet": "väljande",
    "väljandets": "väljande",
    "väljar": "väljare",
    "väljarandelar": "väljarandel",
    "väljarandelarna": "väljarandel",
    "väljarandelarnas": "väljarandel",
    "väljarandelars": "väljarandel",
    "väljarandelen": "väljarandel",
    "väljarandelens": "väljarandel",
    "väljarandels": "väljarandel",
    "väljarbarometern": "väljarbarometer",
    "väljarbarometerns": "väljarbarometer",
    "väljarbarometers": "väljarbarometer",
    "väljarbarometrar": "väljarbarometer",
    "väljarbarometrarna": "väljarbarometer",
    "väljarbarometrarnas": "väljarbarometer",
    "väljarbarometrars": "väljarbarometer",
    "väljaren": "väljare",
    "väljarens": "väljare",
    "väljares": "väljare",
    "väljarkåren": "väljarkår",
    "väljarkårens": "väljarkår",
    "väljarkårer": "väljarkår",
    "väljarkårerna": "väljarkår",
    "väljarkårernas": "väljarkår",
    "väljarkårers": "väljarkår",
    "väljarkårs": "väljarkår",
    "väljarna": "väljare",
    "väljarnas": "väljare",
    "väljarskar": "väljarskara",
    "väljarskaran": "väljarskara",
    "väljarskarans": "väljarskara",
    "väljarskaras": "väljarskara",
    "väljarskare": "väljarskara",
    "väljarskaror": "väljarskara",
    "väljarskarorna": "väljarskara",
    "väljarskarornas": "väljarskara",
    "väljarskarors": "väljarskara",
    "väljarskars": "väljarskara",
    "väljarstöden": "väljarstöd",
    "väljarstödens": "väljarstöd",
    "väljarstödet": "väljarstöd",
    "väljarstödets": "väljarstöd",
    "väljarstöds": "väljarstöd",
    "väljarundersökningar": "väljarundersökning",
    "väljarundersökningarna": "väljarundersökning",
    "väljarundersökningarnas": "väljarundersökning",
    "väljarundersökningars": "väljarundersökning",
    "väljarundersökningen": "väljarundersökning",
    "väljarundersökningens": "väljarundersökning",
    "väljarundersöknings": "väljarundersökning",
    "väljas": "välja",
    "väljer": "välja",
    "väljes": "välja",
    "väljs": "välja",
    "välkammade": "välkammad",
    "välkammades": "välkammad",
    "välkammads": "välkammad",
    "välkammat": "välkammad",
    "välkammats": "välkammad",
    "välklädda": "välklädd",
    "välkläddare": "välklädd",
    "välkläddares": "välklädd",
    "välkläddas": "välklädd",
    "välkläddast": "välklädd",
    "välkläddaste": "välklädd",
    "välkläddastes": "välklädd",
    "välkläddasts": "välklädd",
    "välklädde": "välklädd",
    "välkläddes": "välklädd",
    "välkläddheten": "välkläddhet",
    "välkläddhetens": "välkläddhet",
    "välkläddhets": "välkläddhet",
    "välklädds": "välklädd",
    "välklätt": "välklädd",
    "välklätts": "välklädd",
    "välkom": "välkomma",
    "välkomman": "välkomma",
    "välkommans": "välkomma",
    "välkommas": "välkomma",
    "välkomme": "välkomma",
    "välkommens": "välkommen",
    "välkommet": "välkommen",
    "välkommets": "välkommen",
    "välkommor": "välkomma",
    "välkommorna": "välkomma",
    "välkommornas": "välkomma",
    "välkommors": "välkomma",
    "välkomna": "välkommen",
    "välkomnad": "välkomna",
    "välkomnade": "välkomna",
    "välkomnades": "välkomna",
    "välkomnads": "välkomna",
    "välkomnande": "välkomna",
    "välkomnandes": "välkomnande",
    "välkomnandet": "välkomnande",
    "välkomnandets": "välkomnande",
    "välkomnar": "välkomna",
    "välkomnare": "välkommen",
    "välkomnares": "välkommen",
    "välkomnas": "välkomna",
    "välkomnast": "välkommen",
    "välkomnaste": "välkommen",
    "välkomnastes": "välkommen",
    "välkomnasts": "välkommen",
    "välkomnat": "välkomna",
    "välkomnats": "välkomna",
    "välkomne": "välkommen",
    "välkomnes": "välkommen",
    "välkoms": "välkomma",
    "välkomstfesten": "välkomstfest",
    "välkomstfestens": "välkomstfest",
    "välkomstfester": "välkomstfest",
    "välkomstfesterna": "välkomstfest",
    "välkomstfesternas": "välkomstfest",
    "välkomstfesters": "välkomstfest",
    "välkomstfests": "välkomstfest",
    "välkomstfrukostar": "välkomstfrukost",
    "välkomstfrukostarna": "välkomstfrukost",
    "välkomstfrukostarnas": "välkomstfrukost",
    "välkomstfrukostars": "välkomstfrukost",
    "välkomstfrukosten": "välkomstfrukost",
    "välkomstfrukostens": "välkomstfrukost",
    "välkomstfrukosts": "välkomstfrukost",
    "välkomstmiddagar": "välkomstmiddag",
    "välkomstmiddagarna": "välkomstmiddag",
    "välkomstmiddagarnas": "välkomstmiddag",
    "välkomstmiddagars": "välkomstmiddag",
    "välkomstmiddagen": "välkomstmiddag",
    "välkomstmiddagens": "välkomstmiddag",
    "välkomstmiddags": "välkomstmiddag",
    "välkomstskålar": "välkomstskål",
    "välkomstskålarna": "välkomstskål",
    "välkomstskålarnas": "välkomstskål",
    "välkomstskålars": "välkomstskål",
    "välkomstskålen": "välkomstskål",
    "välkomstskålens": "välkomstskål",
    "välkomstskåls": "välkomstskål",
    "välkomsttalen": "välkomsttal",
    "välkomsttalens": "välkomsttal",
    "välkomsttalet": "välkomsttal",
    "välkomsttalets": "välkomsttal",
    "välkomsttals": "välkomsttal",
    "välkryddade": "välkryddad",
    "välkryddades": "välkryddad",
    "välkryddads": "välkryddad",
    "välkryddat": "välkryddad",
    "välkryddats": "välkryddad",
    "välkända": "välkänd",
    "välkändare": "välkänd",
    "välkändares": "välkänd",
    "välkändas": "välkänd",
    "välkändast": "välkänd",
    "välkändaste": "välkänd",
    "välkändastes": "välkänd",
    "välkändasts": "välkänd",
    "välkände": "välkänd",
    "välkändes": "välkänd",
    "välkändheten": "välkändhet",
    "välkändhetens": "välkändhet",
    "välkändhets": "välkändhet",
    "välkänds": "välkänd",
    "välkänt": "välkänd",
    "välkänts": "välkänd",
    "väll": "välla",
    "vällagade": "vällagad",
    "vällagades": "vällagad",
    "vällagads": "vällagad",
    "vällagat": "vällagad",
    "vällagats": "vällagad",
    "vällagrade": "vällagrad",
    "vällagrades": "vällagrad",
    "vällagrads": "vällagrad",
    "vällagrat": "vällagrad",
    "vällagrats": "vällagrad",
    "vällande": "välla",
    "vällanden": "vällande",
    "vällandena": "vällande",
    "vällandenas": "vällande",
    "vällandens": "vällande",
    "vällandes": "vällande",
    "vällandet": "vällande",
    "vällandets": "vällande",
    "vällar": "väll",
    "vällarna": "väll",
    "vällarnas": "väll",
    "vällars": "väll",
    "vällas": "välla",
    "välld": "välla",
    "vällda": "välla",
    "välldas": "välla",
    "vällde": "välla",
    "välldes": "välla",
    "vällds": "välla",
    "vällen": "väll",
    "vällens": "väll",
    "väller": "välla",
    "välles": "välla",
    "vällevnaden": "vällevnad",
    "vällevnadens": "vällevnad",
    "vällevnader": "vällevnad",
    "vällevnaderna": "vällevnad",
    "vällevnadernas": "vällevnad",
    "vällevnaders": "vällevnad",
    "vällevnads": "vällevnad",
    "vällingar": "välling",
    "vällingarna": "välling",
    "vällingarnas": "välling",
    "vällingars": "välling",
    "vällingen": "välling",
    "vällingens": "välling",
    "vällingklock": "vällingklocka",
    "vällingklockan": "vällingklocka",
    "vällingklockans": "vällingklocka",
    "vällingklockas": "vällingklocka",
    "vällingklocke": "vällingklocka",
    "vällingklockor": "vällingklocka",
    "vällingklockorna": "vällingklocka",
    "vällingklockornas": "vällingklocka",
    "vällingklockors": "vällingklocka",
    "vällingklocks": "vällingklocka",
    "vällings": "välling",
    "välljudet": "välljud",
    "välljudets": "välljud",
    "välljuds": "välljud",
    "välljärnen": "välljärn",
    "välljärnens": "välljärn",
    "välljärnet": "välljärn",
    "välljärnets": "välljärn",
    "välljärns": "välljärn",
    "vällningar": "vällning",
    "vällningarna": "vällning",
    "vällningarnas": "vällning",
    "vällningars": "vällning",
    "vällningen": "vällning",
    "vällningens": "vällning",
    "vällnings": "vällning",
    "vällovliga": "vällovlig",
    "vällovligare": "vällovlig",
    "vällovligares": "vällovlig",
    "vällovligas": "vällovlig",
    "vällovligast": "vällovlig",
    "vällovligaste": "vällovlig",
    "vällovligastes": "vällovlig",
    "vällovligasts": "vällovlig",
    "vällovlige": "vällovlig",
    "vällovliges": "vällovlig",
    "vällovligheten": "vällovlighet",
    "vällovlighetens": "vällovlighet",
    "vällovlighets": "vällovlighet",
    "vällovligs": "vällovlig",
    "vällovligt": "vällovlig",
    "vällovligts": "vällovlig",
    "välls": "välla",
    "vällstålet": "vällstål",
    "vällstålets": "vällstål",
    "vällståls": "vällstål",
    "vällsvetsningar": "vällsvetsning",
    "vällsvetsningarna": "vällsvetsning",
    "vällsvetsningarnas": "vällsvetsning",
    "vällsvetsningars": "vällsvetsning",
    "vällsvetsningen": "vällsvetsning",
    "vällsvetsningens": "vällsvetsning",
    "vällsvetsnings": "vällsvetsning",
    "vällt": "välla",
    "vällts": "välla",
    "vällukten": "vällukt",
    "välluktens": "vällukt",
    "vällukts": "vällukt",
    "vällusten": "vällust",
    "vällustens": "vällust",
    "vällustiga": "vällustig",
    "vällustigare": "vällustig",
    "vällustigares": "vällustig",
    "vällustigas": "vällustig",
    "vällustigast": "vällustig",
    "vällustigaste": "vällustig",
    "vällustigastes": "vällustig",
    "vällustigasts": "vällustig",
    "vällustige": "vällustig",
    "vällustiges": "vällustig",
    "vällustigheten": "vällustighet",
    "vällustighetens": "vällustighet",
    "vällustighets": "vällustighet",
    "vällustigs": "vällustig",
    "vällustigt": "vällustig",
    "vällustigts": "vällustig",
    "vällustingar": "vällusting",
    "vällustingarna": "vällusting",
    "vällustingarnas": "vällusting",
    "vällustingars": "vällusting",
    "vällustingen": "vällusting",
    "vällustingens": "vällusting",
    "vällustings": "vällusting",
    "vällusts": "vällust",
    "vällyckade": "vällyckad",
    "vällyckades": "vällyckad",
    "vällyckads": "vällyckad",
    "vällyckat": "vällyckad",
    "vällyckats": "vällyckad",
    "välmatade": "välmatad",
    "välmatades": "välmatad",
    "välmatads": "välmatad",
    "välmatat": "välmatad",
    "välmatats": "välmatad",
    "välmeningen": "välmening",
    "välmeningens": "välmening",
    "välmenings": "välmening",
    "välmenta": "välment",
    "välmentare": "välment",
    "välmentares": "välment",
    "välmentas": "välment",
    "välmentast": "välment",
    "välmentaste": "välment",
    "välmentastes": "välment",
    "välmentasts": "välment",
    "välmente": "välment",
    "välmentes": "välment",
    "välmentheten": "välmenthet",
    "välmenthetens": "välmenthet",
    "välmenthets": "välmenthet",
    "välments": "välment",
    "välmeriterade": "välmeriterad",
    "välmeriterades": "välmeriterad",
    "välmeriterads": "välmeriterad",
    "välmeriterat": "välmeriterad",
    "välmeriterats": "välmeriterad",
    "välmågan": "välmåga",
    "välmågans": "välmåga",
    "välmågas": "välmåga",
    "välnärda": "välnärd",
    "välnärdare": "välnärd",
    "välnärdares": "välnärd",
    "välnärdas": "välnärd",
    "välnärdast": "välnärd",
    "välnärdaste": "välnärd",
    "välnärdastes": "välnärd",
    "välnärdasts": "välnärd",
    "välnärde": "välnärd",
    "välnärdes": "välnärd",
    "välnärdheten": "välnärdhet",
    "välnärdhetens": "välnärdhet",
    "välnärdhets": "välnärdhet",
    "välnärds": "välnärd",
    "välnärt": "välnärd",
    "välnärts": "välnärd",
    "välondulerade": "välondulerad",
    "välondulerades": "välondulerad",
    "välondulerads": "välondulerad",
    "välondulerat": "välondulerad",
    "välondulerats": "välondulerad",
    "välordnade": "välordnad",
    "välordnades": "välordnad",
    "välordnads": "välordnad",
    "välordnat": "välordnad",
    "välordnats": "välordnad",
    "välplägade": "välplägad",
    "välplägades": "välplägad",
    "välplägads": "välplägad",
    "välplägat": "välplägad",
    "välplägats": "välplägad",
    "välpressade": "välpressad",
    "välpressades": "välpressad",
    "välpressads": "välpressad",
    "välpressat": "välpressad",
    "välpressats": "välpressad",
    "välrenommerade": "välrenommerad",
    "välrenommerades": "välrenommerad",
    "välrenommerads": "välrenommerad",
    "välrenommerat": "välrenommerad",
    "välrenommerats": "välrenommerad",
    "välriktade": "välriktad",
    "välriktades": "välriktad",
    "välriktads": "välriktad",
    "välriktat": "välriktad",
    "välriktats": "välriktad",
    "välrustade": "välrustad",
    "välrustades": "välrustad",
    "välrustads": "välrustad",
    "välrustat": "välrustad",
    "välrustats": "välrustad",
    "väls": "väl",
    "välsedda": "välsedd",
    "välseddare": "välsedd",
    "välseddares": "välsedd",
    "välseddas": "välsedd",
    "välseddast": "välsedd",
    "välseddaste": "välsedd",
    "välseddastes": "välsedd",
    "välseddasts": "välsedd",
    "välsedde": "välsedd",
    "välseddes": "välsedd",
    "välsedds": "välsedd",
    "välsett": "välsedd",
    "välsetts": "välsedd",
    "välsign": "välsigna",
    "välsignad": "välsigna",
    "välsignade": "välsignad",
    "välsignades": "välsignad",
    "välsignads": "välsignad",
    "välsignande": "välsigna",
    "välsignanden": "välsignande",
    "välsignandena": "välsignande",
    "välsignandenas": "välsignande",
    "välsignandens": "välsignande",
    "välsignandes": "välsignande",
    "välsignandet": "välsignande",
    "välsignandets": "välsignande",
    "välsignar": "välsigna",
    "välsignas": "välsigna",
    "välsignat": "välsignad",
    "välsignats": "välsignad",
    "välsignelsen": "välsignelse",
    "välsignelsens": "välsignelse",
    "välsignelser": "välsignelse",
    "välsignelserna": "välsignelse",
    "välsignelsernas": "välsignelse",
    "välsignelsers": "välsignelse",
    "välsignelses": "välsignelse",
    "välsinnade": "välsinnad",
    "välsinnades": "välsinnad",
    "välsinnads": "välsinnad",
    "välsinnat": "välsinnad",
    "välsinnats": "välsinnad",
    "välsituerade": "välsituerad",
    "välsituerades": "välsituerad",
    "välsituerads": "välsituerad",
    "välsituerat": "välsituerad",
    "välsituerats": "välsituerad",
    "välska": "välsk",
    "välskapade": "välskapad",
    "välskapades": "välskapad",
    "välskapads": "välskapad",
    "välskapat": "välskapad",
    "välskapats": "välskapad",
    "välskapta": "välskapt",
    "välskaptare": "välskapt",
    "välskaptares": "välskapt",
    "välskaptas": "välskapt",
    "välskaptast": "välskapt",
    "välskaptaste": "välskapt",
    "välskaptastes": "välskapt",
    "välskaptasts": "välskapt",
    "välskapte": "välskapt",
    "välskaptes": "välskapt",
    "välskaptheten": "välskapthet",
    "välskapthetens": "välskapthet",
    "välskapthets": "välskapthet",
    "välskapts": "välskapt",
    "välskare": "välsk",
    "välskares": "välsk",
    "välskas": "välsk",
    "välskast": "välsk",
    "välskaste": "välsk",
    "välskastes": "välsk",
    "välskasts": "välsk",
    "välske": "välsk",
    "välskes": "välsk",
    "välskheten": "välskhet",
    "välskhetens": "välskhet",
    "välskhets": "välskhet",
    "välskrivens": "välskriven",
    "välskrivet": "välskriven",
    "välskrivets": "välskriven",
    "välskrivna": "välskriven",
    "välskrivnare": "välskriven",
    "välskrivnares": "välskriven",
    "välskrivnas": "välskriven",
    "välskrivnast": "välskriven",
    "välskrivnaste": "välskriven",
    "välskrivnastes": "välskriven",
    "välskrivnasts": "välskriven",
    "välskrivne": "välskriven",
    "välskrivnes": "välskriven",
    "välskrivningar": "välskrivning",
    "välskrivningarna": "välskrivning",
    "välskrivningarnas": "välskrivning",
    "välskrivningars": "välskrivning",
    "välskrivningen": "välskrivning",
    "välskrivningens": "välskrivning",
    "välskrivnings": "välskrivning",
    "välskrivningsfrökens": "välskrivningsfröken",
    "välskrivningsfröknar": "välskrivningsfröken",
    "välskrivningsfröknarna": "välskrivningsfröken",
    "välskrivningsfröknarnas": "välskrivningsfröken",
    "välskrivningsfröknars": "välskrivningsfröken",
    "välskrivningsfröknen": "välskrivningsfröken",
    "välskrivningsfröknens": "välskrivningsfröken",
    "välskräddade": "välskräddad",
    "välskräddades": "välskräddad",
    "välskräddads": "välskräddad",
    "välskräddat": "välskräddad",
    "välskräddats": "välskräddad",
    "välsks": "välsk",
    "välskt": "välsk",
    "välskts": "välsk",
    "välskurens": "välskuren",
    "välskuret": "välskuren",
    "välskurets": "välskuren",
    "välskurna": "välskuren",
    "välskurnare": "välskuren",
    "välskurnares": "välskuren",
    "välskurnas": "välskuren",
    "välskurnast": "välskuren",
    "välskurnaste": "välskuren",
    "välskurnastes": "välskuren",
    "välskurnasts": "välskuren",
    "välskurne": "välskuren",
    "välskurnes": "välskuren",
    "välskötta": "välskött",
    "välsköttare": "välskött",
    "välsköttares": "välskött",
    "välsköttas": "välskött",
    "välsköttast": "välskött",
    "välsköttaste": "välskött",
    "välsköttastes": "välskött",
    "välsköttasts": "välskött",
    "välskötte": "välskött",
    "välsköttes": "välskött",
    "välsköttheten": "välskötthet",
    "välskötthetens": "välskötthet",
    "välskötthets": "välskötthet",
    "välskötts": "välskött",
    "välsmorda": "välsmord",
    "välsmordare": "välsmord",
    "välsmordares": "välsmord",
    "välsmordas": "välsmord",
    "välsmordast": "välsmord",
    "välsmordaste": "välsmord",
    "välsmordastes": "välsmord",
    "välsmordasts": "välsmord",
    "välsmorde": "välsmord",
    "välsmordes": "välsmord",
    "välsmordheten": "välsmordhet",
    "välsmordhetens": "välsmordhet",
    "välsmordhets": "välsmordhet",
    "välsmords": "välsmord",
    "välsmort": "välsmord",
    "välsmorts": "välsmord",
    "välsorterade": "välsorterad",
    "välsorterades": "välsorterad",
    "välsorterads": "välsorterad",
    "välsorterat": "välsorterad",
    "välsorterats": "välsorterad",
    "välspäckade": "välspäckad",
    "välspäckades": "välspäckad",
    "välspäckads": "välspäckad",
    "välspäckat": "välspäckad",
    "välspäckats": "välspäckad",
    "välstekta": "välstekt",
    "välstektare": "välstekt",
    "välstektares": "välstekt",
    "välstektas": "välstekt",
    "välstektast": "välstekt",
    "välstektaste": "välstekt",
    "välstektastes": "välstekt",
    "välstektasts": "välstekt",
    "välstekte": "välstekt",
    "välstektes": "välstekt",
    "välstekts": "välstekt",
    "välstädade": "välstädad",
    "välstädades": "välstädad",
    "välstädads": "välstädad",
    "välstädat": "välstädad",
    "välstädats": "välstädad",
    "välställda": "välställd",
    "välställdare": "välställd",
    "välställdares": "välställd",
    "välställdas": "välställd",
    "välställdast": "välställd",
    "välställdaste": "välställd",
    "välställdastes": "välställd",
    "välställdasts": "välställd",
    "välställde": "välställd",
    "välställdes": "välställd",
    "välställdheten": "välställdhet",
    "välställdhetens": "välställdhet",
    "välställdhets": "välställdhet",
    "välställds": "välställd",
    "välställt": "välställd",
    "välställts": "välställd",
    "välståndet": "välstånd",
    "välståndets": "välstånd",
    "välstånds": "välstånd",
    "välsvarvade": "välsvarvad",
    "välsvarvades": "välsvarvad",
    "välsvarvads": "välsvarvad",
    "välsvarvat": "välsvarvad",
    "välsvarvats": "välsvarvad",
    "vält": "välta",
    "vältad": "välta",
    "vältade": "välta",
    "vältades": "välta",
    "vältads": "välta",
    "vältagens": "vältagen",
    "vältaget": "vältagen",
    "vältagets": "vältagen",
    "vältagna": "vältagen",
    "vältagnare": "vältagen",
    "vältagnares": "vältagen",
    "vältagnas": "vältagen",
    "vältagnast": "vältagen",
    "vältagnaste": "vältagen",
    "vältagnastes": "vältagen",
    "vältagnasts": "vältagen",
    "vältagne": "vältagen",
    "vältagnes": "vältagen",
    "vältalar": "vältalare",
    "vältalaren": "vältalare",
    "vältalarens": "vältalare",
    "vältalares": "vältalare",
    "vältalarna": "vältalare",
    "vältalarnas": "vältalare",
    "vältaliga": "vältalig",
    "vältaligare": "vältalig",
    "vältaligares": "vältalig",
    "vältaligas": "vältalig",
    "vältaligast": "vältalig",
    "vältaligaste": "vältalig",
    "vältaligastes": "vältalig",
    "vältaligasts": "vältalig",
    "vältalige": "vältalig",
    "vältaliges": "vältalig",
    "vältaligheten": "vältalighet",
    "vältalighetens": "vältalighet",
    "vältaligheter": "vältalighet",
    "vältaligheterna": "vältalighet",
    "vältaligheternas": "vältalighet",
    "vältaligheters": "vältalighet",
    "vältalighets": "vältalighet",
    "vältaligs": "vältalig",
    "vältaligt": "vältalig",
    "vältaligts": "vältalig",
    "vältan": "välta",
    "vältande": "välta",
    "vältanden": "vältande",
    "vältandena": "vältande",
    "vältandenas": "vältande",
    "vältandens": "vältande",
    "vältandes": "vältande",
    "vältandet": "vältande",
    "vältandets": "vältande",
    "vältans": "välta",
    "vältar": "välta",
    "vältarna": "vält",
    "vältarnas": "vält",
    "vältars": "vält",
    "vältas": "välta",
    "vältat": "välta",
    "vältats": "välta",
    "välte": "välta",
    "välten": "vält",
    "vältens": "vält",
    "välter": "välta",
    "vältes": "välta",
    "vältor": "välta",
    "vältorna": "välta",
    "vältornas": "välta",
    "vältors": "välta",
    "vältrad": "vältra",
    "vältrade": "vältra",
    "vältrades": "vältra",
    "vältrads": "vältra",
    "vältrande": "vältra",
    "vältranden": "vältrande",
    "vältrandena": "vältrande",
    "vältrandenas": "vältrande",
    "vältrandens": "vältrande",
    "vältrandes": "vältrande",
    "vältrandet": "vältrande",
    "vältrandets": "vältrande",
    "vältrar": "vältra",
    "vältras": "vältra",
    "vältrat": "vältra",
    "vältrats": "vältra",
    "vältrimmade": "vältrimmad",
    "vältrimmades": "vältrimmad",
    "vältrimmads": "vältrimmad",
    "vältrimmat": "vältrimmad",
    "vältrimmats": "vältrimmad",
    "vältränade": "vältränad",
    "vältränades": "vältränad",
    "vältränads": "vältränad",
    "vältränat": "vältränad",
    "vältränats": "vältränad",
    "välts": "välta",
    "vältuktade": "vältuktad",
    "vältuktades": "vältuktad",
    "vältuktads": "vältuktad",
    "vältuktat": "vältuktad",
    "vältuktats": "vältuktad",
    "välturnerade": "välturnerad",
    "välturnerades": "välturnerad",
    "välturnerads": "välturnerad",
    "välturnerat": "välturnerad",
    "välturnerats": "välturnerad",
    "välunderrättade": "välunderrättad",
    "välunderrättades": "välunderrättad",
    "välunderrättads": "välunderrättad",
    "välunderrättat": "välunderrättad",
    "välunderrättats": "välunderrättad",
    "väluniformerade": "väluniformerad",
    "väluniformerades": "väluniformerad",
    "väluniformerads": "väluniformerad",
    "väluniformerat": "väluniformerad",
    "väluniformerats": "väluniformerad",
    "väluppfostrade": "väluppfostrad",
    "väluppfostrades": "väluppfostrad",
    "väluppfostrads": "väluppfostrad",
    "väluppfostrat": "väluppfostrad",
    "väluppfostrats": "väluppfostrad",
    "välutbildade": "välutbildad",
    "välutbildades": "välutbildad",
    "välutbildads": "välutbildad",
    "välutbildat": "välutbildad",
    "välutbildats": "välutbildad",
    "välutrustade": "välutrustad",
    "välutrustades": "välutrustad",
    "välutrustads": "välutrustad",
    "välutrustat": "välutrustad",
    "välutrustats": "välutrustad",
    "välutvecklade": "välutvecklad",
    "välutvecklades": "välutvecklad",
    "välutvecklads": "välutvecklad",
    "välutvecklat": "välutvecklad",
    "välutvecklats": "välutvecklad",
    "välv": "välva",
    "välvande": "välva",
    "välvanden": "välvande",
    "välvandena": "välvande",
    "välvandenas": "välvande",
    "välvandens": "välvande",
    "välvandes": "välvande",
    "välvandet": "välvande",
    "välvandets": "välvande",
    "välvas": "välva",
    "välvd": "välva",
    "välvda": "välvd",
    "välvdare": "välvd",
    "välvdares": "välvd",
    "välvdas": "välvd",
    "välvdast": "välvd",
    "välvdaste": "välvd",
    "välvdastes": "välvd",
    "välvdasts": "välvd",
    "välvde": "välvd",
    "välvdes": "välvd",
    "välvdheten": "välvdhet",
    "välvdhetens": "välvdhet",
    "välvdhets": "välvdhet",
    "välvds": "välvd",
    "välventilerade": "välventilerad",
    "välventilerades": "välventilerad",
    "välventilerads": "välventilerad",
    "välventilerat": "välventilerad",
    "välventilerats": "välventilerad",
    "välver": "välva",
    "välves": "välva",
    "välviljan": "välvilja",
    "välviljans": "välvilja",
    "välviljas": "välvilja",
    "välvilliga": "välvillig",
    "välvilligare": "välvillig",
    "välvilligares": "välvillig",
    "välvilligas": "välvillig",
    "välvilligast": "välvillig",
    "välvilligaste": "välvillig",
    "välvilligastes": "välvillig",
    "välvilligasts": "välvillig",
    "välvillige": "välvillig",
    "välvilliges": "välvillig",
    "välvilligheten": "välvillighet",
    "välvillighetens": "välvillighet",
    "välvilligheter": "välvillighet",
    "välvilligheterna": "välvillighet",
    "välvilligheternas": "välvillighet",
    "välvilligheters": "välvillighet",
    "välvillighets": "välvillighet",
    "välvilligs": "välvillig",
    "välvilligt": "välvillig",
    "välvilligts": "välvillig",
    "välvisa": "välvis",
    "välvisare": "välvis",
    "välvisares": "välvis",
    "välvisas": "välvis",
    "välvisast": "välvis",
    "välvisaste": "välvis",
    "välvisastes": "välvis",
    "välvisasts": "välvis",
    "välvise": "välvis",
    "välvises": "välvis",
    "välvisheten": "välvishet",
    "välvishetens": "välvishet",
    "välvishets": "välvishet",
    "välvist": "välvis",
    "välvists": "välvis",
    "välvningar": "välvning",
    "välvningarna": "välvning",
    "välvningarnas": "välvning",
    "välvningars": "välvning",
    "välvningen": "välvning",
    "välvningens": "välvning",
    "välvnings": "välvning",
    "välvs": "välva",
    "välvt": "välvd",
    "välvts": "välvd",
    "välvuxens": "välvuxen",
    "välvuxet": "välvuxen",
    "välvuxets": "välvuxen",
    "välvuxna": "välvuxen",
    "välvuxnare": "välvuxen",
    "välvuxnares": "välvuxen",
    "välvuxnas": "välvuxen",
    "välvuxnast": "välvuxen",
    "välvuxnaste": "välvuxen",
    "välvuxnastes": "välvuxen",
    "välvuxnasts": "välvuxen",
    "välvuxne": "välvuxen",
    "välvuxnes": "välvuxen",
    "välväxta": "välväxt",
    "välväxtare": "välväxt",
    "välväxtares": "välväxt",
    "välväxtas": "välväxt",
    "välväxtast": "välväxt",
    "välväxtaste": "välväxt",
    "välväxtastes": "välväxt",
    "välväxtasts": "välväxt",
    "välväxte": "välväxt",
    "välväxtes": "välväxt",
    "välväxtheten": "välväxthet",
    "välväxthetens": "välväxthet",
    "välväxthets": "välväxthet",
    "välväxts": "välväxt",
    "välvårdade": "välvårdad",
    "välvårdades": "välvårdad",
    "välvårdads": "välvårdad",
    "välvårdat": "välvårdad",
    "välvårdats": "välvårdad",
    "vämdes": "vämjas",
    "vämj": "vämja",
    "vämjande": "vämja",
    "vämjanden": "vämjande",
    "vämjandena": "vämjande",
    "vämjandenas": "vämjande",
    "vämjandens": "vämjande",
    "vämjandes": "vämjande",
    "vämjandet": "vämjande",
    "vämjandets": "vämjande",
    "vämjas": "vämja",
    "vämjd": "vämja",
    "vämjda": "vämja",
    "vämjdas": "vämja",
    "vämjde": "vämja",
    "vämjdes": "vämjas",
    "vämjds": "vämja",
    "vämjeliga": "vämjelig",
    "vämjeligare": "vämjelig",
    "vämjeligares": "vämjelig",
    "vämjeligas": "vämjelig",
    "vämjeligast": "vämjelig",
    "vämjeligaste": "vämjelig",
    "vämjeligastes": "vämjelig",
    "vämjeligasts": "vämjelig",
    "vämjelige": "vämjelig",
    "vämjeliges": "vämjelig",
    "vämjeligheten": "vämjelighet",
    "vämjelighetens": "vämjelighet",
    "vämjeligheter": "vämjelighet",
    "vämjeligheterna": "vämjelighet",
    "vämjeligheternas": "vämjelighet",
    "vämjeligheters": "vämjelighet",
    "vämjelighets": "vämjelighet",
    "vämjeligs": "vämjelig",
    "vämjeligt": "vämjelig",
    "vämjeligts": "vämjelig",
    "vämjelsen": "vämjelse",
    "vämjelsens": "vämjelse",
    "vämjelses": "vämjelse",
    "vämjer": "vämja",
    "vämjes": "vämjas",
    "vämjs": "vämjas",
    "vämjt": "vämja",
    "vämjts": "vämjas",
    "vämts": "vämjas",
    "väna": "vän",
    "vänare": "vän",
    "vänares": "vän",
    "vänas": "vän",
    "vänast": "vän",
    "vänaste": "vän",
    "vänastes": "vän",
    "vänasts": "vän",
    "vänd": "vända",
    "vändan": "vända",
    "vändande": "vända",
    "vändanden": "vändande",
    "vändandena": "vändande",
    "vändandenas": "vändande",
    "vändandens": "vändande",
    "vändandes": "vändande",
    "vändandet": "vändande",
    "vändandets": "vändande",
    "vändans": "vända",
    "vändas": "vända",
    "vändbara": "vändbar",
    "vändbarare": "vändbar",
    "vändbarares": "vändbar",
    "vändbaras": "vändbar",
    "vändbarast": "vändbar",
    "vändbaraste": "vändbar",
    "vändbarastes": "vändbar",
    "vändbarasts": "vändbar",
    "vändbare": "vändbar",
    "vändbares": "vändbar",
    "vändbarheten": "vändbarhet",
    "vändbarhetens": "vändbarhet",
    "vändbarhets": "vändbarhet",
    "vändbars": "vändbar",
    "vändbart": "vändbar",
    "vändbarts": "vändbar",
    "vände": "vända",
    "vändelroten": "vändelrot",
    "vändelrotens": "vändelrot",
    "vändelrots": "vändelrot",
    "vändelrötter": "vändelrot",
    "vändelrötterna": "vändelrot",
    "vändelrötternas": "vändelrot",
    "vändelrötters": "vändelrot",
    "vänder": "vända",
    "vändes": "vända",
    "vändkorsen": "vändkors",
    "vändkorsens": "vändkors",
    "vändkorset": "vändkors",
    "vändkorsets": "vändkors",
    "vändkretsar": "vändkrets",
    "vändkretsarna": "vändkrets",
    "vändkretsarnas": "vändkrets",
    "vändkretsars": "vändkrets",
    "vändkretsen": "vändkrets",
    "vändkretsens": "vändkrets",
    "vändningar": "vändning",
    "vändningarna": "vändning",
    "vändningarnas": "vändning",
    "vändningars": "vändning",
    "vändningen": "vändning",
    "vändningens": "vändning",
    "vändnings": "vändning",
    "vändor": "vända",
    "vändorna": "vända",
    "vändornas": "vända",
    "vändors": "vända",
    "vändplatsen": "vändplats",
    "vändplatsens": "vändplats",
    "vändplatser": "vändplats",
    "vändplatserna": "vändplats",
    "vändplatsernas": "vändplats",
    "vändplatsers": "vändplats",
    "vändpunkten": "vändpunkt",
    "vändpunktens": "vändpunkt",
    "vändpunkter": "vändpunkt",
    "vändpunkterna": "vändpunkt",
    "vändpunkternas": "vändpunkt",
    "vändpunkters": "vändpunkt",
    "vändpunkts": "vändpunkt",
    "vändradien": "vändradie",
    "vändradiens": "vändradie",
    "vändradier": "vändradie",
    "vändradierna": "vändradie",
    "vändradiernas": "vändradie",
    "vändradiers": "vändradie",
    "vändradies": "vändradie",
    "vändrostningar": "vändrostning",
    "vändrostningarna": "vändrostning",
    "vändrostningarnas": "vändrostning",
    "vändrostningars": "vändrostning",
    "vändrostningen": "vändrostning",
    "vändrostningens": "vändrostning",
    "vändrostnings": "vändrostning",
    "vänds": "vända",
    "vändskivan": "vändskiva",
    "vändskivans": "vändskiva",
    "vändskivas": "vändskiva",
    "vändskive": "vändskiva",
    "vändskivor": "vändskiva",
    "vändskivorna": "vändskiva",
    "vändskivornas": "vändskiva",
    "vändskivors": "vändskiva",
    "vändstek": "vändsteka",
    "vändstekande": "vändsteka",
    "vändstekandes": "vändsteka",
    "vändstekas": "vändsteka",
    "vändsteker": "vändsteka",
    "vändstekes": "vändsteka",
    "vändsteks": "vändsteka",
    "vändstekt": "vändsteka",
    "vändstekta": "vändsteka",
    "vändstektas": "vändsteka",
    "vändstekte": "vändsteka",
    "vändstektes": "vändsteka",
    "vändstekts": "vändsteka",
    "vändsydda": "vändsydd",
    "vändsyddare": "vändsydd",
    "vändsyddares": "vändsydd",
    "vändsyddas": "vändsydd",
    "vändsyddast": "vändsydd",
    "vändsyddaste": "vändsydd",
    "vändsyddastes": "vändsydd",
    "vändsyddasts": "vändsydd",
    "vändsydde": "vändsydd",
    "vändsyddes": "vändsydd",
    "vändsydds": "vändsydd",
    "vändsytt": "vändsydd",
    "vändsytts": "vändsydd",
    "väne": "vän",
    "vänes": "vän",
    "vänfasta": "vänfast",
    "vänfastare": "vänfast",
    "vänfastares": "vänfast",
    "vänfastas": "vänfast",
    "vänfastast": "vänfast",
    "vänfastaste": "vänfast",
    "vänfastastes": "vänfast",
    "vänfastasts": "vänfast",
    "vänfaste": "vänfast",
    "vänfastes": "vänfast",
    "vänfastheten": "vänfasthet",
    "vänfasthetens": "vänfasthet",
    "vänfasthets": "vänfasthet",
    "vänfasts": "vänfast",
    "vängåvan": "vängåva",
    "vängåvans": "vängåva",
    "vängåvas": "vängåva",
    "vängåve": "vängåva",
    "vängåvo": "vängåva",
    "vängåvor": "vängåva",
    "vängåvorna": "vängåva",
    "vängåvornas": "vängåva",
    "vängåvors": "vängåva",
    "vänheten": "vänhet",
    "vänhetens": "vänhet",
    "vänhets": "vänhet",
    "väninnan": "väninna",
    "väninnans": "väninna",
    "väninnas": "väninna",
    "väninne": "väninna",
    "väninnor": "väninna",
    "väninnorna": "väninna",
    "väninnornas": "väninna",
    "väninnors": "väninna",
    "vänj": "vänja",
    "vänjande": "vänja",
    "vänjanden": "vänjande",
    "vänjandena": "vänjande",
    "vänjandenas": "vänjande",
    "vänjandens": "vänjande",
    "vänjandes": "vänjande",
    "vänjandet": "vänjande",
    "vänjandets": "vänjande",
    "vänjas": "vänja",
    "vänjer": "vänja",
    "vänjes": "vänja",
    "vänjs": "vänja",
    "vänkretsar": "vänkrets",
    "vänkretsarna": "vänkrets",
    "vänkretsarnas": "vänkrets",
    "vänkretsars": "vänkrets",
    "vänkretsen": "vänkrets",
    "vänkretsens": "vänkrets",
    "vänliga": "vänlig",
    "vänligare": "vänlig",
    "vänligares": "vänlig",
    "vänligas": "vänlig",
    "vänligast": "vänlig",
    "vänligaste": "vänlig",
    "vänligastes": "vänlig",
    "vänligasts": "vänlig",
    "vänlige": "vänlig",
    "vänliges": "vänlig",
    "vänligheten": "vänlighet",
    "vänlighetens": "vänlighet",
    "vänligheter": "vänlighet",
    "vänligheterna": "vänlighet",
    "vänligheternas": "vänlighet",
    "vänligheters": "vänlighet",
    "vänlighets": "vänlighet",
    "vänligs": "vänlig",
    "vänligt": "vänlig",
    "vänligts": "vänlig",
    "vännen": "vän",
    "vännens": "vän",
    "vänner": "vän",
    "vännerna": "vän",
    "vännernas": "vän",
    "vänners": "vän",
    "vänorten": "vänort",
    "vänortens": "vänort",
    "vänorter": "vänort",
    "vänorterna": "vänort",
    "vänorternas": "vänort",
    "vänorters": "vänort",
    "vänorts": "vänort",
    "vänprisen": "vänpris",
    "vänprisens": "vänpris",
    "vänpriser": "vänpris",
    "vänpriserna": "vänpris",
    "vänprisernas": "vänpris",
    "vänprisers": "vänpris",
    "vänpriset": "vänpris",
    "vänprisets": "vänpris",
    "väns": "vän",
    "vänskapen": "vänskap",
    "vänskapens": "vänskap",
    "vänskapliga": "vänskaplig",
    "vänskapligare": "vänskaplig",
    "vänskapligares": "vänskaplig",
    "vänskapligas": "vänskaplig",
    "vänskapligast": "vänskaplig",
    "vänskapligaste": "vänskaplig",
    "vänskapligastes": "vänskaplig",
    "vänskapligasts": "vänskaplig",
    "vänskaplige": "vänskaplig",
    "vänskapliges": "vänskaplig",
    "vänskapligheten": "vänskaplighet",
    "vänskaplighetens": "vänskaplighet",
    "vänskapligheter": "vänskaplighet",
    "vänskapligheterna": "vänskaplighet",
    "vänskapligheternas": "vänskaplighet",
    "vänskapligheters": "vänskaplighet",
    "vänskaplighets": "vänskaplighet",
    "vänskapligs": "vänskaplig",
    "vänskapligt": "vänskaplig",
    "vänskapligts": "vänskaplig",
    "vänskaps": "vänskap",
    "vänskapsförbindelsen": "vänskapsförbindelse",
    "vänskapsförbindelsens": "vänskapsförbindelse",
    "vänskapsförbindelser": "vänskapsförbindelse",
    "vänskapsförbindelserna": "vänskapsförbindelse",
    "vänskapsförbindelsernas": "vänskapsförbindelse",
    "vänskapsförbindelsers": "vänskapsförbindelse",
    "vänskapsförbindelses": "vänskapsförbindelse",
    "vänskapsmatchen": "vänskapsmatch",
    "vänskapsmatchens": "vänskapsmatch",
    "vänskapsmatcher": "vänskapsmatch",
    "vänskapsmatcherna": "vänskapsmatch",
    "vänskapsmatchernas": "vänskapsmatch",
    "vänskapsmatchers": "vänskapsmatch",
    "vänskapsmatchs": "vänskapsmatch",
    "vänskapsprisen": "vänskapspris",
    "vänskapsprisens": "vänskapspris",
    "vänskapspriser": "vänskapspris",
    "vänskapspriserna": "vänskapspris",
    "vänskapsprisernas": "vänskapspris",
    "vänskapsprisers": "vänskapspris",
    "vänskapspriset": "vänskapspris",
    "vänskapsprisets": "vänskapspris",
    "vänslades": "vänslas",
    "vänslandes": "vänslande",
    "vänslandet": "vänslande",
    "vänslandets": "vänslande",
    "vänslats": "vänslas",
    "vänsteranhängar": "vänsteranhängare",
    "vänsteranhängaren": "vänsteranhängare",
    "vänsteranhängarens": "vänsteranhängare",
    "vänsteranhängares": "vänsteranhängare",
    "vänsteranhängarna": "vänsteranhängare",
    "vänsteranhängarnas": "vänsteranhängare",
    "vänsterarmar": "vänsterarm",
    "vänsterarmarna": "vänsterarm",
    "vänsterarmarnas": "vänsterarm",
    "vänsterarmars": "vänsterarm",
    "vänsterarmen": "vänsterarm",
    "vänsterarmens": "vänsterarm",
    "vänsterarms": "vänsterarm",
    "vänsterbenen": "vänsterben",
    "vänsterbenens": "vänsterben",
    "vänsterbenet": "vänsterben",
    "vänsterbenets": "vänsterben",
    "vänsterbens": "vänsterben",
    "vänsterflygeln": "vänsterflygel",
    "vänsterflygelns": "vänsterflygel",
    "vänsterflygels": "vänsterflygel",
    "vänsterflyglar": "vänsterflygel",
    "vänsterflyglarna": "vänsterflygel",
    "vänsterflyglarnas": "vänsterflygel",
    "vänsterflyglars": "vänsterflygel",
    "vänsterfoten": "vänsterfot",
    "vänsterfotens": "vänsterfot",
    "vänsterfots": "vänsterfot",
    "vänsterfäst": "vänsterfäste",
    "vänsterfästen": "vänsterfäste",
    "vänsterfästena": "vänsterfäste",
    "vänsterfästenas": "vänsterfäste",
    "vänsterfästens": "vänsterfäste",
    "vänsterfästes": "vänsterfäste",
    "vänsterfästet": "vänsterfäste",
    "vänsterfästets": "vänsterfäste",
    "vänsterfötter": "vänsterfot",
    "vänsterfötterna": "vänsterfot",
    "vänsterfötternas": "vänsterfot",
    "vänsterfötters": "vänsterfot",
    "vänstergirar": "vänstergir",
    "vänstergirarna": "vänstergir",
    "vänstergirarnas": "vänstergir",
    "vänstergirars": "vänstergir",
    "vänstergiren": "vänstergir",
    "vänstergirens": "vänstergir",
    "vänstergirs": "vänstergir",
    "vänsterhanden": "vänsterhand",
    "vänsterhandens": "vänsterhand",
    "vänsterhands": "vänsterhand",
    "vänsterhandsspelar": "vänsterhandsspelare",
    "vänsterhandsspelaren": "vänsterhandsspelare",
    "vänsterhandsspelarens": "vänsterhandsspelare",
    "vänsterhandsspelares": "vänsterhandsspelare",
    "vänsterhandsspelarna": "vänsterhandsspelare",
    "vänsterhandsspelarnas": "vänsterhandsspelare",
    "vänsterhänder": "vänsterhand",
    "vänsterhänderna": "vänsterhand",
    "vänsterhändernas": "vänsterhand",
    "vänsterhänders": "vänsterhand",
    "vänsterhänta": "vänsterhänt",
    "vänsterhäntare": "vänsterhänt",
    "vänsterhäntares": "vänsterhänt",
    "vänsterhäntas": "vänsterhänt",
    "vänsterhäntast": "vänsterhänt",
    "vänsterhäntaste": "vänsterhänt",
    "vänsterhäntastes": "vänsterhänt",
    "vänsterhäntasts": "vänsterhänt",
    "vänsterhänte": "vänsterhänt",
    "vänsterhäntes": "vänsterhänt",
    "vänsterhäntheten": "vänsterhänthet",
    "vänsterhänthetens": "vänsterhänthet",
    "vänsterhänthets": "vänsterhänthet",
    "vänsterhänts": "vänsterhänt",
    "vänsterintellektuella": "vänsterintellektuell",
    "vänsterintellektuellas": "vänsterintellektuell",
    "vänsterintellektuelle": "vänsterintellektuell",
    "vänsterintellektuelles": "vänsterintellektuell",
    "vänsterintellektuells": "vänsterintellektuell",
    "vänsterintellektuellt": "vänsterintellektuell",
    "vänsterintellektuellts": "vänsterintellektuell",
    "vänsterknappar": "vänsterknapp",
    "vänsterknapparna": "vänsterknapp",
    "vänsterknapparnas": "vänsterknapp",
    "vänsterknappars": "vänsterknapp",
    "vänsterknappen": "vänsterknapp",
    "vänsterknappens": "vänsterknapp",
    "vänsterknapps": "vänsterknapp",
    "vänsterknäck": "vänsterknäcka",
    "vänsterknäckande": "vänsterknäcka",
    "vänsterknäckanden": "vänsterknäckande",
    "vänsterknäckandena": "vänsterknäckande",
    "vänsterknäckandenas": "vänsterknäckande",
    "vänsterknäckandens": "vänsterknäckande",
    "vänsterknäckandes": "vänsterknäckande",
    "vänsterknäckandet": "vänsterknäckande",
    "vänsterknäckandets": "vänsterknäckande",
    "vänsterknäckas": "vänsterknäcka",
    "vänsterknäcken": "vänsterknäck",
    "vänsterknäckens": "vänsterknäck",
    "vänsterknäcker": "vänsterknäcka",
    "vänsterknäckes": "vänsterknäcka",
    "vänsterknäcket": "vänsterknäck",
    "vänsterknäckets": "vänsterknäck",
    "vänsterknäcks": "vänsterknäcka",
    "vänsterknäckt": "vänsterknäcka",
    "vänsterknäckta": "vänsterknäcka",
    "vänsterknäcktas": "vänsterknäcka",
    "vänsterknäckte": "vänsterknäcka",
    "vänsterknäcktes": "vänsterknäcka",
    "vänsterknäckts": "vänsterknäcka",
    "vänsterkryssen": "vänsterkryss",
    "vänsterkryssens": "vänsterkryss",
    "vänsterkrysset": "vänsterkryss",
    "vänsterkryssets": "vänsterkryss",
    "vänsterkurv": "vänsterkurva",
    "vänsterkurvan": "vänsterkurva",
    "vänsterkurvans": "vänsterkurva",
    "vänsterkurvas": "vänsterkurva",
    "vänsterkurve": "vänsterkurva",
    "vänsterkurvor": "vänsterkurva",
    "vänsterkurvorna": "vänsterkurva",
    "vänsterkurvornas": "vänsterkurva",
    "vänsterkurvors": "vänsterkurva",
    "vänsterkurvs": "vänsterkurva",
    "vänstermyten": "vänstermyt",
    "vänstermytens": "vänstermyt",
    "vänstermyter": "vänstermyt",
    "vänstermyterna": "vänstermyt",
    "vänstermyternas": "vänstermyt",
    "vänstermyters": "vänstermyt",
    "vänstermyts": "vänstermyt",
    "vänstern": "vänster",
    "vänsterns": "vänster",
    "vänsteroppositionella": "vänsteroppositionell",
    "vänsteroppositionellas": "vänsteroppositionell",
    "vänsteroppositionelle": "vänsteroppositionell",
    "vänsteroppositionelles": "vänsteroppositionell",
    "vänsteroppositionells": "vänsteroppositionell",
    "vänsteroppositionellt": "vänsteroppositionell",
    "vänsteroppositionellts": "vänsteroppositionell",
    "vänsteroppositionen": "vänsteropposition",
    "vänsteroppositionens": "vänsteropposition",
    "vänsteroppositioner": "vänsteropposition",
    "vänsteroppositionerna": "vänsteropposition",
    "vänsteroppositionernas": "vänsteropposition",
    "vänsteroppositioners": "vänsteropposition",
    "vänsteroppositions": "vänsteropposition",
    "vänsterpartier": "vänsterparti",
    "vänsterpartierna": "vänsterparti",
    "vänsterpartiernas": "vänsterparti",
    "vänsterpartiers": "vänsterparti",
    "vänsterpartiet": "vänsterparti",
    "vänsterpartiets": "vänsterparti",
    "vänsterpartis": "vänsterparti",
    "vänsterpartit": "vänsterparti",
    "vänsterpartits": "vänsterparti",
    "vänsterpolitiken": "vänsterpolitik",
    "vänsterpolitikens": "vänsterpolitik",
    "vänsterpolitikern": "vänsterpolitiker",
    "vänsterpolitikerna": "vänsterpolitiker",
    "vänsterpolitikernas": "vänsterpolitiker",
    "vänsterpolitikerns": "vänsterpolitiker",
    "vänsterpolitikers": "vänsterpolitiker",
    "vänsterpolitiks": "vänsterpolitik",
    "vänsterpolitiska": "vänsterpolitisk",
    "vänsterpolitiskas": "vänsterpolitisk",
    "vänsterpolitiske": "vänsterpolitisk",
    "vänsterpolitiskes": "vänsterpolitisk",
    "vänsterpolitisks": "vänsterpolitisk",
    "vänsterpolitiskt": "vänsterpolitisk",
    "vänsterpolitiskts": "vänsterpolitisk",
    "vänsterprassels": "vänsterprassel",
    "vänsterprasslet": "vänsterprassel",
    "vänsterprasslets": "vänsterprassel",
    "vänsterradikala": "vänsterradikal",
    "vänsterradikalare": "vänsterradikal",
    "vänsterradikalares": "vänsterradikal",
    "vänsterradikalas": "vänsterradikal",
    "vänsterradikalast": "vänsterradikal",
    "vänsterradikalaste": "vänsterradikal",
    "vänsterradikalastes": "vänsterradikal",
    "vänsterradikalasts": "vänsterradikal",
    "vänsterradikale": "vänsterradikal",
    "vänsterradikalen": "vänsterradikal",
    "vänsterradikalens": "vänsterradikal",
    "vänsterradikaler": "vänsterradikal",
    "vänsterradikalerna": "vänsterradikal",
    "vänsterradikalernas": "vänsterradikal",
    "vänsterradikalers": "vänsterradikal",
    "vänsterradikales": "vänsterradikal",
    "vänsterradikals": "vänsterradikal",
    "vänsterradikalt": "vänsterradikal",
    "vänsterradikalts": "vänsterradikal",
    "vänsterrebellen": "vänsterrebell",
    "vänsterrebellens": "vänsterrebell",
    "vänsterrebeller": "vänsterrebell",
    "vänsterrebellerna": "vänsterrebell",
    "vänsterrebellernas": "vänsterrebell",
    "vänsterrebellers": "vänsterrebell",
    "vänsterrebells": "vänsterrebell",
    "vänsterregeringar": "vänsterregering",
    "vänsterregeringarna": "vänsterregering",
    "vänsterregeringarnas": "vänsterregering",
    "vänsterregeringars": "vänsterregering",
    "vänsterregeringen": "vänsterregering",
    "vänsterregeringens": "vänsterregering",
    "vänsterregerings": "vänsterregering",
    "vänsters": "vänster",
    "vänstersocialismen": "vänstersocialism",
    "vänstersocialismens": "vänstersocialism",
    "vänstersocialismer": "vänstersocialism",
    "vänstersocialismerna": "vänstersocialism",
    "vänstersocialismernas": "vänstersocialism",
    "vänstersocialismers": "vänstersocialism",
    "vänstersocialisms": "vänstersocialism",
    "vänstersocialistiska": "vänstersocialistisk",
    "vänstersocialistiskas": "vänstersocialistisk",
    "vänstersocialistiske": "vänstersocialistisk",
    "vänstersocialistiskes": "vänstersocialistisk",
    "vänstersocialistisks": "vänstersocialistisk",
    "vänstersocialistiskt": "vänstersocialistisk",
    "vänstersocialistiskts": "vänstersocialistisk",
    "vänstersvängar": "vänstersväng",
    "vänstersvängarna": "vänstersväng",
    "vänstersvängarnas": "vänstersväng",
    "vänstersvängars": "vänstersväng",
    "vänstersvängen": "vänstersväng",
    "vänstersvängens": "vänstersväng",
    "vänstersvängs": "vänstersväng",
    "vänstersympatisören": "vänstersympatisör",
    "vänstersympatisörens": "vänstersympatisör",
    "vänstersympatisörer": "vänstersympatisör",
    "vänstersympatisörerna": "vänstersympatisör",
    "vänstersympatisörernas": "vänstersympatisör",
    "vänstersympatisörers": "vänstersympatisör",
    "vänstersympatisörs": "vänstersympatisör",
    "vänstertidningar": "vänstertidning",
    "vänstertidningarna": "vänstertidning",
    "vänstertidningarnas": "vänstertidning",
    "vänstertidningars": "vänstertidning",
    "vänstertidningen": "vänstertidning",
    "vänstertidningens": "vänstertidning",
    "vänstertidnings": "vänstertidning",
    "vänstervridens": "vänstervriden",
    "vänstervridet": "vänstervriden",
    "vänstervridets": "vänstervriden",
    "vänstervridna": "vänstervriden",
    "vänstervridnare": "vänstervriden",
    "vänstervridnares": "vänstervriden",
    "vänstervridnas": "vänstervriden",
    "vänstervridnast": "vänstervriden",
    "vänstervridnaste": "vänstervriden",
    "vänstervridnastes": "vänstervriden",
    "vänstervridnasts": "vänstervriden",
    "vänstervridne": "vänstervriden",
    "vänstervridnes": "vänstervriden",
    "vänsteråran": "vänsteråra",
    "vänsterårans": "vänsteråra",
    "vänsteråras": "vänsteråra",
    "vänsteråre": "vänsteråra",
    "vänsteråror": "vänsteråra",
    "vänsterårorna": "vänsteråra",
    "vänsterårornas": "vänsteråra",
    "vänsterårors": "vänsteråra",
    "vänsterögas": "vänsteröga",
    "vänsterögat": "vänsteröga",
    "vänsterögats": "vänsteröga",
    "vänsterögon": "vänsteröga",
    "vänsterögonen": "vänsteröga",
    "vänsterögonens": "vänsteröga",
    "vänsterögons": "vänsteröga",
    "vänsteröras": "vänsteröra",
    "vänsterörat": "vänsteröra",
    "vänsterörats": "vänsteröra",
    "vänsteröron": "vänsteröra",
    "vänsteröronen": "vänsteröra",
    "vänsteröronens": "vänsteröra",
    "vänsterörons": "vänsteröra",
    "vänstra": "vänster",
    "vänstrad": "vänstra",
    "vänstrade": "vänstra",
    "vänstrades": "vänstra",
    "vänstrads": "vänstra",
    "vänstrande": "vänstra",
    "vänstranden": "vänstrande",
    "vänstrandena": "vänstrande",
    "vänstrandenas": "vänstrande",
    "vänstrandens": "vänstrande",
    "vänstrandes": "vänstrande",
    "vänstrandet": "vänstrande",
    "vänstrandets": "vänstrande",
    "vänstrans": "vänstran",
    "vänstrar": "vänstra",
    "vänstras": "vänstra",
    "vänstrat": "vänstra",
    "vänstrats": "vänstra",
    "vänsälla": "vänsäll",
    "vänsällare": "vänsäll",
    "vänsällares": "vänsäll",
    "vänsällas": "vänsäll",
    "vänsällast": "vänsäll",
    "vänsällaste": "vänsäll",
    "vänsällastes": "vänsäll",
    "vänsällasts": "vänsäll",
    "vänsälle": "vänsäll",
    "vänsälles": "vänsäll",
    "vänsällheten": "vänsällhet",
    "vänsällhetens": "vänsällhet",
    "vänsällhets": "vänsällhet",
    "vänsälls": "vänsäll",
    "vänsällt": "vänsäll",
    "vänsällts": "vänsäll",
    "vänt": "vänta",
    "väntad": "vänta",
    "väntade": "vänta",
    "väntades": "vänta",
    "väntads": "vänta",
    "väntande": "vänta",
    "väntanden": "väntande",
    "väntandena": "väntande",
    "väntandenas": "väntande",
    "väntandens": "väntande",
    "väntandes": "väntande",
    "väntandet": "väntande",
    "väntandets": "väntande",
    "väntans": "väntan",
    "väntar": "vänta",
    "väntas": "vänta",
    "väntat": "vänta",
    "väntats": "vänta",
    "vänte": "vänta",
    "väntelistan": "väntelista",
    "väntelistans": "väntelista",
    "väntelistas": "väntelista",
    "vänteliste": "väntelista",
    "väntelistor": "väntelista",
    "väntelistorna": "väntelista",
    "väntelistornas": "väntelista",
    "väntelistors": "väntelista",
    "väntetiden": "väntetid",
    "väntetidens": "väntetid",
    "väntetider": "väntetid",
    "väntetiderna": "väntetid",
    "väntetidernas": "väntetid",
    "väntetiders": "väntetid",
    "väntetids": "väntetid",
    "väntevärden": "väntevärde",
    "väntevärdena": "väntevärde",
    "väntevärdenas": "väntevärde",
    "väntevärdens": "väntevärde",
    "väntevärdes": "väntevärde",
    "väntevärdet": "väntevärde",
    "väntevärdets": "väntevärde",
    "vänthallar": "vänthall",
    "vänthallarna": "vänthall",
    "vänthallarnas": "vänthall",
    "vänthallars": "vänthall",
    "vänthallen": "vänthall",
    "vänthallens": "vänthall",
    "vänthalls": "vänthall",
    "väntjänsten": "väntjänst",
    "väntjänstens": "väntjänst",
    "väntjänster": "väntjänst",
    "väntjänsterna": "väntjänst",
    "väntjänsternas": "väntjänst",
    "väntjänsters": "väntjänst",
    "väntjänsts": "väntjänst",
    "väntrummen": "väntrum",
    "väntrummens": "väntrum",
    "väntrummet": "väntrum",
    "väntrummets": "väntrum",
    "väntrums": "väntrum",
    "vänts": "vända",
    "väntsalar": "väntsal",
    "väntsalarna": "väntsal",
    "väntsalarnas": "väntsal",
    "väntsalars": "väntsal",
    "väntsalen": "väntsal",
    "väntsalens": "väntsal",
    "väntsals": "väntsal",
    "väpn": "väpna",
    "väpnad": "väpna",
    "väpnade": "väpnad",
    "väpnades": "väpnad",
    "väpnads": "väpnad",
    "väpnande": "väpna",
    "väpnanden": "väpnande",
    "väpnandena": "väpnande",
    "väpnandenas": "väpnande",
    "väpnandens": "väpnande",
    "väpnandes": "väpnande",
    "väpnandet": "väpnande",
    "väpnandets": "väpnande",
    "väpnar": "väpnare",
    "väpnaren": "väpnare",
    "väpnarens": "väpnare",
    "väpnares": "väpnare",
    "väpnarna": "väpnare",
    "väpnarnas": "väpnare",
    "väpnas": "väpna",
    "väpnat": "väpnad",
    "väpnats": "väpnad",
    "väpplingar": "väppling",
    "väpplingarna": "väppling",
    "väpplingarnas": "väppling",
    "väpplingars": "väppling",
    "väpplingen": "väppling",
    "väpplingens": "väppling",
    "väpplings": "väppling",
    "värda": "värd",
    "värdar": "värd",
    "värdare": "värd",
    "värdares": "värd",
    "värdarna": "värd",
    "värdarnas": "värd",
    "värdars": "värd",
    "värdas": "värd",
    "värdast": "värd",
    "värdaste": "värd",
    "värdastes": "värd",
    "värdasts": "värd",
    "värddjuren": "värddjur",
    "värddjurens": "värddjur",
    "värddjuret": "värddjur",
    "värddjurets": "värddjur",
    "värddjurs": "värddjur",
    "värde": "värd",
    "värdeanalysen": "värdeanalys",
    "värdeanalysens": "värdeanalys",
    "värdeanalyser": "värdeanalys",
    "värdeanalyserna": "värdeanalys",
    "värdeanalysernas": "värdeanalys",
    "värdeanalysers": "värdeanalys",
    "värdebeständiga": "värdebeständig",
    "värdebeständigare": "värdebeständig",
    "värdebeständigares": "värdebeständig",
    "värdebeständigas": "värdebeständig",
    "värdebeständigast": "värdebeständig",
    "värdebeständigaste": "värdebeständig",
    "värdebeständigastes": "värdebeständig",
    "värdebeständigasts": "värdebeständig",
    "värdebeständige": "värdebeständig",
    "värdebeständiges": "värdebeständig",
    "värdebeständigheten": "värdebeständighet",
    "värdebeständighetens": "värdebeständighet",
    "värdebeständighets": "värdebeständighet",
    "värdebeständigs": "värdebeständig",
    "värdebeständigt": "värdebeständig",
    "värdebeständigts": "värdebeständig",
    "värdebreven": "värdebrev",
    "värdebrevens": "värdebrev",
    "värdebrevet": "värdebrev",
    "värdebrevets": "värdebrev",
    "värdebrevs": "värdebrev",
    "värdefasta": "värdefast",
    "värdefastare": "värdefast",
    "värdefastares": "värdefast",
    "värdefastas": "värdefast",
    "värdefastast": "värdefast",
    "värdefastaste": "värdefast",
    "värdefastastes": "värdefast",
    "värdefastasts": "värdefast",
    "värdefaste": "värdefast",
    "värdefastes": "värdefast",
    "värdefastheten": "värdefasthet",
    "värdefasthetens": "värdefasthet",
    "värdefasthets": "värdefasthet",
    "värdefasts": "värdefast",
    "värdefilosofien": "värdefilosofi",
    "värdefilosofiens": "värdefilosofi",
    "värdefilosofin": "värdefilosofi",
    "värdefilosofins": "värdefilosofi",
    "värdefilosofis": "värdefilosofi",
    "värdefulla": "värdefull",
    "värdefullare": "värdefull",
    "värdefullares": "värdefull",
    "värdefullas": "värdefull",
    "värdefullast": "värdefull",
    "värdefullaste": "värdefull",
    "värdefullastes": "värdefull",
    "värdefullasts": "värdefull",
    "värdefulle": "värdefull",
    "värdefulles": "värdefull",
    "värdefullheten": "värdefullhet",
    "värdefullhetens": "värdefullhet",
    "värdefullheter": "värdefullhet",
    "värdefullheterna": "värdefullhet",
    "värdefullheternas": "värdefullhet",
    "värdefullheters": "värdefullhet",
    "värdefullhets": "värdefullhet",
    "värdefulls": "värdefull",
    "värdefullt": "värdefull",
    "värdefullts": "värdefull",
    "värdeföremålen": "värdeföremål",
    "värdeföremålens": "värdeföremål",
    "värdeföremålet": "värdeföremål",
    "värdeföremålets": "värdeföremål",
    "värdeföremåls": "värdeföremål",
    "värdeförsändelsen": "värdeförsändelse",
    "värdeförsändelsens": "värdeförsändelse",
    "värdeförsändelser": "värdeförsändelse",
    "värdeförsändelserna": "värdeförsändelse",
    "värdeförsändelsernas": "värdeförsändelse",
    "värdeförsändelsers": "värdeförsändelse",
    "värdeförsändelses": "värdeförsändelse",
    "värdegemenskapen": "värdegemenskap",
    "värdegemenskapens": "värdegemenskap",
    "värdegemenskaps": "värdegemenskap",
    "värdegrunden": "värdegrund",
    "värdegrundens": "värdegrund",
    "värdegrunder": "värdegrund",
    "värdegrunderna": "värdegrund",
    "värdegrundernas": "värdegrund",
    "värdegrunders": "värdegrund",
    "värdegrunds": "värdegrund",
    "värdehandlingar": "värdehandling",
    "värdehandlingarna": "värdehandling",
    "värdehandlingarnas": "värdehandling",
    "värdehandlingars": "värdehandling",
    "värdehandlingen": "värdehandling",
    "värdehandlingens": "värdehandling",
    "värdehandlings": "värdehandling",
    "värdehierarkien": "värdehierarki",
    "värdehierarkiens": "värdehierarki",
    "värdehierarkier": "värdehierarki",
    "värdehierarkierna": "värdehierarki",
    "värdehierarkiernas": "värdehierarki",
    "värdehierarkiers": "värdehierarki",
    "värdehierarkin": "värdehierarki",
    "värdehierarkins": "värdehierarki",
    "värdehierarkis": "värdehierarki",
    "värdeladdade": "värdeladdad",
    "värdeladdades": "värdeladdad",
    "värdeladdads": "värdeladdad",
    "värdeladdat": "värdeladdad",
    "värdeladdats": "värdeladdad",
    "värdeläran": "värdelära",
    "värdelärans": "värdelära",
    "värdeläras": "värdelära",
    "värdelösa": "värdelös",
    "värdelösare": "värdelös",
    "värdelösares": "värdelös",
    "värdelösas": "värdelös",
    "värdelösast": "värdelös",
    "värdelösaste": "värdelös",
    "värdelösastes": "värdelös",
    "värdelösasts": "värdelös",
    "värdelöse": "värdelös",
    "värdelöses": "värdelös",
    "värdelösheten": "värdelöshet",
    "värdelöshetens": "värdelöshet",
    "värdelöshets": "värdelöshet",
    "värdelöst": "värdelös",
    "värdelösts": "värdelös",
    "värdeminskningar": "värdeminskning",
    "värdeminskningarna": "värdeminskning",
    "värdeminskningarnas": "värdeminskning",
    "värdeminskningars": "värdeminskning",
    "värdeminskningen": "värdeminskning",
    "värdeminskningens": "värdeminskning",
    "värdeminsknings": "värdeminskning",
    "värdemängden": "värdemängd",
    "värdemängdens": "värdemängd",
    "värdemängder": "värdemängd",
    "värdemängderna": "värdemängd",
    "värdemängdernas": "värdemängd",
    "värdemängders": "värdemängd",
    "värdemängds": "värdemängd",
    "värdemässiga": "värdemässig",
    "värdemässigare": "värdemässig",
    "värdemässigares": "värdemässig",
    "värdemässigas": "värdemässig",
    "värdemässigast": "värdemässig",
    "värdemässigaste": "värdemässig",
    "värdemässigastes": "värdemässig",
    "värdemässigasts": "värdemässig",
    "värdemässige": "värdemässig",
    "värdemässiges": "värdemässig",
    "värdemässigheten": "värdemässighet",
    "värdemässighetens": "värdemässighet",
    "värdemässighets": "värdemässighet",
    "värdemässigs": "värdemässig",
    "värdemässigt": "värdemässig",
    "värdemässigts": "värdemässig",
    "värdemätar": "värdemätare",
    "värdemätaren": "värdemätare",
    "värdemätarens": "värdemätare",
    "värdemätares": "värdemätare",
    "värdemätarna": "värdemätare",
    "värdemätarnas": "värdemätare",
    "värden": "värde",
    "värdena": "värde",
    "värdenas": "värde",
    "värdenihilismen": "värdenihilism",
    "värdenihilismens": "värdenihilism",
    "värdenihilismer": "värdenihilism",
    "värdenihilismerna": "värdenihilism",
    "värdenihilismernas": "värdenihilism",
    "värdenihilismers": "värdenihilism",
    "värdenihilisms": "värdenihilism",
    "värdenihilistiska": "värdenihilistisk",
    "värdenihilistiskas": "värdenihilistisk",
    "värdenihilistiske": "värdenihilistisk",
    "värdenihilistiskes": "värdenihilistisk",
    "värdenihilistisks": "värdenihilistisk",
    "värdenihilistiskt": "värdenihilistisk",
    "värdenihilistiskts": "värdenihilistisk",
    "värdens": "värde",
    "värdeomdömen": "värdeomdöme",
    "värdeomdömena": "värdeomdöme",
    "värdeomdömenas": "värdeomdöme",
    "värdeomdömens": "värdeomdöme",
    "värdeomdömes": "värdeomdöme",
    "värdeomdömet": "värdeomdöme",
    "värdeomdömets": "värdeomdöme",
    "värdeorden": "värdeord",
    "värdeordens": "värdeord",
    "värdeordet": "värdeord",
    "värdeordets": "värdeord",
    "värdeords": "värdeord",
    "värdepapperen": "värdepapper",
    "värdepapperens": "värdepapper",
    "värdepapperet": "värdepapper",
    "värdepapperets": "värdepapper",
    "värdepapperna": "värdepapper",
    "värdepappernas": "värdepapper",
    "värdepappers": "värdepapper",
    "värdepappersfonden": "värdepappersfond",
    "värdepappersfondens": "värdepappersfond",
    "värdepappersfonder": "värdepappersfond",
    "värdepappersfonderna": "värdepappersfond",
    "värdepappersfondernas": "värdepappersfond",
    "värdepappersfonders": "värdepappersfond",
    "värdepappersfonds": "värdepappersfond",
    "värdepappersmarknaden": "värdepappersmarknad",
    "värdepappersmarknadens": "värdepappersmarknad",
    "värdepappersmarknader": "värdepappersmarknad",
    "värdepappersmarknaderna": "värdepappersmarknad",
    "värdepappersmarknadernas": "värdepappersmarknad",
    "värdepappersmarknaders": "värdepappersmarknad",
    "värdepappersmarknads": "värdepappersmarknad",
    "värdepappren": "värdepapper",
    "värdepapprens": "värdepapper",
    "värdepappret": "värdepapper",
    "värdepapprets": "värdepapper",
    "värdeposten": "värdepost",
    "värdepostens": "värdepost",
    "värdeposts": "värdepost",
    "värderad": "värdera",
    "värderade": "värdera",
    "värderades": "värdera",
    "värderads": "värdera",
    "värderande": "värdera",
    "värderanden": "värderande",
    "värderandena": "värderande",
    "värderandenas": "värderande",
    "värderandens": "värderande",
    "värderandes": "värderande",
    "värderandet": "värderande",
    "värderandets": "värderande",
    "värderar": "värderare",
    "värderaren": "värderare",
    "värderarens": "värderare",
    "värderares": "värderare",
    "värderarna": "värderare",
    "värderarnas": "värderare",
    "värderas": "värdera",
    "värderat": "värdera",
    "värderats": "värdera",
    "värderbara": "värderbar",
    "värderbarare": "värderbar",
    "värderbarares": "värderbar",
    "värderbaras": "värderbar",
    "värderbarast": "värderbar",
    "värderbaraste": "värderbar",
    "värderbarastes": "värderbar",
    "värderbarasts": "värderbar",
    "värderbare": "värderbar",
    "värderbares": "värderbar",
    "värderbarheten": "värderbarhet",
    "värderbarhetens": "värderbarhet",
    "värderbarhets": "värderbarhet",
    "värderbars": "värderbar",
    "värderbart": "värderbar",
    "värderbarts": "värderbar",
    "värderingar": "värdering",
    "värderingarna": "värdering",
    "värderingarnas": "värdering",
    "värderingars": "värdering",
    "värderingen": "värdering",
    "värderingens": "värdering",
    "värderings": "värdering",
    "värderingsfria": "värderingsfri",
    "värderingsfriare": "värderingsfri",
    "värderingsfriares": "värderingsfri",
    "värderingsfrias": "värderingsfri",
    "värderingsfriast": "värderingsfri",
    "värderingsfriaste": "värderingsfri",
    "värderingsfriastes": "värderingsfri",
    "värderingsfriasts": "värderingsfri",
    "värderingsfrie": "värderingsfri",
    "värderingsfries": "värderingsfri",
    "värderingsfris": "värderingsfri",
    "värderingsfritt": "värderingsfri",
    "värderingsfritts": "värderingsfri",
    "värderingsinstrumenten": "värderingsinstrument",
    "värderingsinstrumentens": "värderingsinstrument",
    "värderingsinstrumentet": "värderingsinstrument",
    "värderingsinstrumentets": "värderingsinstrument",
    "värderingsinstruments": "värderingsinstrument",
    "värderingsmannen": "värderingsman",
    "värderingsmannens": "värderingsman",
    "värderingsmans": "värderingsman",
    "värderingsmän": "värderingsman",
    "värderingsmännen": "värderingsman",
    "värderingsmännens": "värderingsman",
    "värderingsmäns": "värderingsman",
    "värderingsmässiga": "värderingsmässig",
    "värderingsmässigare": "värderingsmässig",
    "värderingsmässigares": "värderingsmässig",
    "värderingsmässigas": "värderingsmässig",
    "värderingsmässigast": "värderingsmässig",
    "värderingsmässigaste": "värderingsmässig",
    "värderingsmässigastes": "värderingsmässig",
    "värderingsmässigasts": "värderingsmässig",
    "värderingsmässige": "värderingsmässig",
    "värderingsmässiges": "värderingsmässig",
    "värderingsmässigs": "värderingsmässig",
    "värderingsmässigt": "värderingsmässig",
    "värderingsmässigts": "värderingsmässig",
    "värderingsnormen": "värderingsnorm",
    "värderingsnormens": "värderingsnorm",
    "värderingsnormer": "värderingsnorm",
    "värderingsnormerna": "värderingsnorm",
    "värderingsnormernas": "värderingsnorm",
    "värderingsnormers": "värderingsnorm",
    "värderingsnorms": "värderingsnorm",
    "värderånen": "värderån",
    "värderånens": "värderån",
    "värderånet": "värderån",
    "värderånets": "värderån",
    "värderåns": "värderån",
    "värdes": "värde",
    "värdesaken": "värdesak",
    "värdesakens": "värdesak",
    "värdesaker": "värdesak",
    "värdesakerna": "värdesak",
    "värdesakernas": "värdesak",
    "värdesakers": "värdesak",
    "värdesaks": "värdesak",
    "värdesatt": "värdesätta",
    "värdesatta": "värdesätta",
    "värdesattas": "värdesätta",
    "värdesatte": "värdesätta",
    "värdesattes": "värdesätta",
    "värdesatts": "värdesätta",
    "värdeskal": "värdeskala",
    "värdeskalan": "värdeskala",
    "värdeskalans": "värdeskala",
    "värdeskalas": "värdeskala",
    "värdeskale": "värdeskala",
    "värdeskalor": "värdeskala",
    "värdeskalorna": "värdeskala",
    "värdeskalornas": "värdeskala",
    "värdeskalors": "värdeskala",
    "värdeskals": "värdeskala",
    "värdestegringar": "värdestegring",
    "värdestegringarna": "värdestegring",
    "värdestegringarnas": "värdestegring",
    "värdestegringars": "värdestegring",
    "värdestegringen": "värdestegring",
    "värdestegringens": "värdestegring",
    "värdestegrings": "värdestegring",
    "värdestrukturen": "värdestruktur",
    "värdestrukturens": "värdestruktur",
    "värdestrukturer": "värdestruktur",
    "värdestrukturerna": "värdestruktur",
    "värdestrukturernas": "värdestruktur",
    "värdestrukturers": "värdestruktur",
    "värdestrukturs": "värdestruktur",
    "värdesäkerheten": "värdesäkerhet",
    "värdesäkerhetens": "värdesäkerhet",
    "värdesäkerhets": "värdesäkerhet",
    "värdesäkers": "värdesäker",
    "värdesäkert": "värdesäker",
    "värdesäkerts": "värdesäker",
    "värdesäkra": "värdesäker",
    "värdesäkrad": "värdesäkra",
    "värdesäkrade": "värdesäkra",
    "värdesäkrades": "värdesäkra",
    "värdesäkrads": "värdesäkra",
    "värdesäkrande": "värdesäkra",
    "värdesäkranden": "värdesäkrande",
    "värdesäkrandena": "värdesäkrande",
    "värdesäkrandenas": "värdesäkrande",
    "värdesäkrandens": "värdesäkrande",
    "värdesäkrandes": "värdesäkrande",
    "värdesäkrandet": "värdesäkrande",
    "värdesäkrandets": "värdesäkrande",
    "värdesäkrar": "värdesäkra",
    "värdesäkrare": "värdesäker",
    "värdesäkrares": "värdesäker",
    "värdesäkras": "värdesäkra",
    "värdesäkrast": "värdesäker",
    "värdesäkraste": "värdesäker",
    "värdesäkrastes": "värdesäker",
    "värdesäkrasts": "värdesäker",
    "värdesäkrat": "värdesäkra",
    "värdesäkrats": "värdesäkra",
    "värdesäkre": "värdesäker",
    "värdesäkres": "värdesäker",
    "värdesätt": "värdesätta",
    "värdesättande": "värdesätta",
    "värdesättanden": "värdesättande",
    "värdesättandena": "värdesättande",
    "värdesättandenas": "värdesättande",
    "värdesättandens": "värdesättande",
    "värdesättandes": "värdesättande",
    "värdesättandet": "värdesättande",
    "värdesättandets": "värdesättande",
    "värdesättas": "värdesätta",
    "värdesätter": "värdesätta",
    "värdesättes": "värdesätta",
    "värdesätts": "värdesätta",
    "värdet": "värde",
    "värdetabellen": "värdetabell",
    "värdetabellens": "värdetabell",
    "värdetabeller": "värdetabell",
    "värdetabellerna": "värdetabell",
    "värdetabellernas": "värdetabell",
    "värdetabellers": "värdetabell",
    "värdetabells": "värdetabell",
    "värdeteorien": "värdeteori",
    "värdeteoriens": "värdeteori",
    "värdeteorin": "värdeteori",
    "värdeteorins": "värdeteori",
    "värdeteoris": "värdeteori",
    "värdetransporten": "värdetransport",
    "värdetransportens": "värdetransport",
    "värdetransporter": "värdetransport",
    "värdetransporterna": "värdetransport",
    "värdetransporternas": "värdetransport",
    "värdetransporters": "värdetransport",
    "värdetransportföretagen": "värdetransportföretag",
    "värdetransportföretagens": "värdetransportföretag",
    "värdetransportföretaget": "värdetransportföretag",
    "värdetransportföretagets": "värdetransportföretag",
    "värdetransportföretags": "värdetransportföretag",
    "värdetransports": "värdetransport",
    "värdets": "värde",
    "värdeökningar": "värdeökning",
    "värdeökningarna": "värdeökning",
    "värdeökningarnas": "värdeökning",
    "värdeökningars": "värdeökning",
    "värdeökningen": "värdeökning",
    "värdeökningens": "värdeökning",
    "värdeöknings": "värdeökning",
    "värdfamiljen": "värdfamilj",
    "värdfamiljens": "värdfamilj",
    "värdfamiljer": "värdfamilj",
    "värdfamiljerna": "värdfamilj",
    "värdfamiljernas": "värdfamilj",
    "värdfamiljers": "värdfamilj",
    "värdfamiljs": "värdfamilj",
    "värdfolken": "värdfolk",
    "värdfolkens": "värdfolk",
    "värdfolket": "värdfolk",
    "värdfolkets": "värdfolk",
    "värdfolks": "värdfolk",
    "värdheten": "värdhet",
    "värdhetens": "värdhet",
    "värdhets": "värdhet",
    "värdiga": "värdig",
    "värdigades": "värdigas",
    "värdigare": "värdig",
    "värdigares": "värdig",
    "värdigas": "värdig",
    "värdigast": "värdig",
    "värdigaste": "värdig",
    "värdigastes": "värdig",
    "värdigasts": "värdig",
    "värdigats": "värdigas",
    "värdige": "värdig",
    "värdiges": "värdig",
    "värdigheten": "värdighet",
    "värdighetens": "värdighet",
    "värdigheter": "värdighet",
    "värdigheterna": "värdighet",
    "värdigheternas": "värdighet",
    "värdigheters": "värdighet",
    "värdighets": "värdighet",
    "värdigs": "värdig",
    "värdigt": "värdig",
    "värdigts": "värdig",
    "värdinnan": "värdinna",
    "värdinnans": "värdinna",
    "värdinnas": "värdinna",
    "värdinne": "värdinna",
    "värdinnor": "värdinna",
    "värdinnorna": "värdinna",
    "värdinnornas": "värdinna",
    "värdinnors": "värdinna",
    "värdmolekylen": "värdmolekyl",
    "värdmolekylens": "värdmolekyl",
    "värdmolekyler": "värdmolekyl",
    "värdmolekylerna": "värdmolekyl",
    "värdmolekylernas": "värdmolekyl",
    "värdmolekylers": "värdmolekyl",
    "värdmolekyls": "värdmolekyl",
    "värdparen": "värdpar",
    "värdparens": "värdpar",
    "värdparet": "värdpar",
    "värdparets": "värdpar",
    "värdpars": "värdpar",
    "värds": "värd",
    "värdshusen": "värdshus",
    "värdshusens": "värdshus",
    "värdshuset": "värdshus",
    "värdshusets": "värdshus",
    "värdskapet": "värdskap",
    "värdskapets": "värdskap",
    "värdskaps": "värdskap",
    "värdväxlingar": "värdväxling",
    "värdväxlingarna": "värdväxling",
    "värdväxlingarnas": "värdväxling",
    "värdväxlingars": "värdväxling",
    "värdväxlingen": "värdväxling",
    "värdväxlingens": "värdväxling",
    "värdväxlings": "värdväxling",
    "värdväxten": "värdväxt",
    "värdväxtens": "värdväxt",
    "värdväxter": "värdväxt",
    "värdväxterna": "värdväxt",
    "värdväxternas": "värdväxt",
    "värdväxters": "värdväxt",
    "värdväxts": "värdväxt",
    "väringar": "väring",
    "väringarna": "väring",
    "väringarnas": "väring",
    "väringars": "väring",
    "väringen": "väring",
    "väringens": "väring",
    "värings": "väring",
    "värj": "värja",
    "värjan": "värja",
    "värjande": "värja",
    "värjanden": "värjande",
    "värjandena": "värjande",
    "värjandenas": "värjande",
    "värjandens": "värjande",
    "värjandes": "värjande",
    "värjandet": "värjande",
    "värjandets": "värjande",
    "värjans": "värja",
    "värjas": "värja",
    "värjd": "värja",
    "värjda": "värja",
    "värjdas": "värja",
    "värjde": "värja",
    "värjdes": "värja",
    "värjds": "värja",
    "värje": "värja",
    "värjemålseden": "värjemålsed",
    "värjemålsedens": "värjemålsed",
    "värjemålseder": "värjemålsed",
    "värjemålsederna": "värjemålsed",
    "värjemålsedernas": "värjemålsed",
    "värjemålseders": "värjemålsed",
    "värjemålseds": "värjemålsed",
    "värjer": "värja",
    "värjes": "värja",
    "värjningsskadan": "värjningsskada",
    "värjningsskadans": "värjningsskada",
    "värjningsskadas": "värjningsskada",
    "värjningsskade": "värjningsskada",
    "värjningsskador": "värjningsskada",
    "värjningsskadorna": "värjningsskada",
    "värjningsskadornas": "värjningsskada",
    "värjningsskadors": "värjningsskada",
    "värjor": "värja",
    "värjorna": "värja",
    "värjornas": "värja",
    "värjors": "värja",
    "värjos": "värjo",
    "värjs": "värja",
    "värjt": "värja",
    "värjts": "värja",
    "värk": "värka",
    "värkande": "värka",
    "värkanden": "värkande",
    "värkandena": "värkande",
    "värkandenas": "värkande",
    "värkandens": "värkande",
    "värkandes": "värkande",
    "värkandet": "värkande",
    "värkandets": "värkande",
    "värkar": "värk",
    "värkarna": "värk",
    "värkarnas": "värk",
    "värkars": "värk",
    "värkas": "värka",
    "värkbrutens": "värkbruten",
    "värkbrutet": "värkbruten",
    "värkbrutets": "värkbruten",
    "värkbrutna": "värkbruten",
    "värkbrutnare": "värkbruten",
    "värkbrutnares": "värkbruten",
    "värkbrutnas": "värkbruten",
    "värkbrutnast": "värkbruten",
    "värkbrutnaste": "värkbruten",
    "värkbrutnastes": "värkbruten",
    "värkbrutnasts": "värkbruten",
    "värkbrutne": "värkbruten",
    "värkbrutnes": "värkbruten",
    "värken": "värk",
    "värkens": "värk",
    "värker": "värka",
    "värkes": "värka",
    "värks": "värka",
    "värkt": "värka",
    "värktabletten": "värktablett",
    "värktablettens": "värktablett",
    "värktabletter": "värktablett",
    "värktabletterna": "värktablett",
    "värktabletternas": "värktablett",
    "värktabletters": "värktablett",
    "värktabletts": "värktablett",
    "värkte": "värka",
    "värktes": "värka",
    "värkts": "värka",
    "världar": "värld",
    "världarna": "värld",
    "världarnas": "värld",
    "världars": "värld",
    "världen": "värld",
    "världens": "värld",
    "världs": "värld",
    "världsalltet": "världsallt",
    "världsalltets": "världsallt",
    "världsallts": "världsallt",
    "världsartisten": "världsartist",
    "världsartistens": "världsartist",
    "världsartister": "världsartist",
    "världsartisterna": "världsartist",
    "världsartisternas": "världsartist",
    "världsartisters": "världsartist",
    "världsartists": "världsartist",
    "världsarven": "världsarv",
    "världsarvens": "världsarv",
    "världsarvet": "världsarv",
    "världsarvets": "världsarv",
    "världsarvs": "världsarv",
    "världsatlasen": "världsatlas",
    "världsatlasens": "världsatlas",
    "världsatlaser": "världsatlas",
    "världsatlaserna": "världsatlas",
    "världsatlasernas": "världsatlas",
    "världsatlasers": "världsatlas",
    "världsaxeln": "världsaxel",
    "världsaxelns": "världsaxel",
    "världsaxels": "världsaxel",
    "världsaxlar": "världsaxel",
    "världsaxlarna": "världsaxel",
    "världsaxlarnas": "världsaxel",
    "världsaxlars": "världsaxel",
    "världsbekanta": "världsbekant",
    "världsbekantare": "världsbekant",
    "världsbekantares": "världsbekant",
    "världsbekantas": "världsbekant",
    "världsbekantast": "världsbekant",
    "världsbekantaste": "världsbekant",
    "världsbekantastes": "världsbekant",
    "världsbekantasts": "världsbekant",
    "världsbekante": "världsbekant",
    "världsbekantes": "världsbekant",
    "världsbekants": "världsbekant",
    "världsberömda": "världsberömd",
    "världsberömdare": "världsberömd",
    "världsberömdares": "världsberömd",
    "världsberömdas": "världsberömd",
    "världsberömdast": "världsberömd",
    "världsberömdaste": "världsberömd",
    "världsberömdastes": "världsberömd",
    "världsberömdasts": "världsberömd",
    "världsberömde": "världsberömd",
    "världsberömdes": "världsberömd",
    "världsberömdheten": "världsberömdhet",
    "världsberömdhetens": "världsberömdhet",
    "världsberömdheter": "världsberömdhet",
    "världsberömdheterna": "världsberömdhet",
    "världsberömdheternas": "världsberömdhet",
    "världsberömdheters": "världsberömdhet",
    "världsberömdhets": "världsberömdhet",
    "världsberömds": "världsberömd",
    "världsberömmelsen": "världsberömmelse",
    "världsberömmelsens": "världsberömmelse",
    "världsberömmelses": "världsberömmelse",
    "världsberömt": "världsberömd",
    "världsberömts": "världsberömd",
    "världsbilden": "världsbild",
    "världsbildens": "världsbild",
    "världsbilder": "världsbild",
    "världsbilderna": "världsbild",
    "världsbildernas": "världsbild",
    "världsbilders": "världsbild",
    "världsbilds": "världsbild",
    "världsborgar": "världsborgare",
    "världsborgaren": "världsborgare",
    "världsborgarens": "världsborgare",
    "världsborgares": "världsborgare",
    "världsborgarna": "världsborgare",
    "världsborgarnas": "världsborgare",
    "världsbranden": "världsbrand",
    "världsbrandens": "världsbrand",
    "världsbrands": "världsbrand",
    "världsbränder": "världsbrand",
    "världsbränderna": "världsbrand",
    "världsbrändernas": "världsbrand",
    "världsbränders": "världsbrand",
    "världsbästa": "världsbäst",
    "världsbästas": "världsbäst",
    "världsbäste": "världsbäst",
    "världsbästes": "världsbäst",
    "världsbästs": "världsbäst",
    "världsdamen": "världsdam",
    "världsdamens": "världsdam",
    "världsdamer": "världsdam",
    "världsdamerna": "världsdam",
    "världsdamernas": "världsdam",
    "världsdamers": "världsdam",
    "världsdams": "världsdam",
    "världsdelar": "världsdel",
    "världsdelarna": "världsdel",
    "världsdelarnas": "världsdel",
    "världsdelars": "världsdel",
    "världsdelen": "världsdel",
    "världsdelens": "världsdel",
    "världsdels": "världsdel",
    "världsett": "världsetta",
    "världsettan": "världsetta",
    "världsettans": "världsetta",
    "världsettas": "världsetta",
    "världsette": "världsetta",
    "världsettor": "världsetta",
    "världsettorna": "världsetta",
    "världsettornas": "världsetta",
    "världsettors": "världsetta",
    "världsetts": "världsetta",
    "världsfederalismen": "världsfederalism",
    "världsfederalismens": "världsfederalism",
    "världsfederalismer": "världsfederalism",
    "världsfederalismerna": "världsfederalism",
    "världsfederalismernas": "världsfederalism",
    "världsfederalismers": "världsfederalism",
    "världsfederalisms": "världsfederalism",
    "världsfientliga": "världsfientlig",
    "världsfientligare": "världsfientlig",
    "världsfientligares": "världsfientlig",
    "världsfientligas": "världsfientlig",
    "världsfientligast": "världsfientlig",
    "världsfientligaste": "världsfientlig",
    "världsfientligastes": "världsfientlig",
    "världsfientligasts": "världsfientlig",
    "världsfientlige": "världsfientlig",
    "världsfientliges": "världsfientlig",
    "världsfientligheten": "världsfientlighet",
    "världsfientlighetens": "världsfientlighet",
    "världsfientlighets": "världsfientlighet",
    "världsfientligs": "världsfientlig",
    "världsfientligt": "världsfientlig",
    "världsfientligts": "världsfientlig",
    "världsformats": "världsformat",
    "världsfreden": "världsfred",
    "världsfredens": "världsfred",
    "världsfreds": "världsfred",
    "världsfrånvända": "världsfrånvänd",
    "världsfrånvändare": "världsfrånvänd",
    "världsfrånvändares": "världsfrånvänd",
    "världsfrånvändas": "världsfrånvänd",
    "världsfrånvändast": "världsfrånvänd",
    "världsfrånvändaste": "världsfrånvänd",
    "världsfrånvändastes": "världsfrånvänd",
    "världsfrånvändasts": "världsfrånvänd",
    "världsfrånvände": "världsfrånvänd",
    "världsfrånvändes": "världsfrånvänd",
    "världsfrånvändheten": "världsfrånvändhet",
    "världsfrånvändhetens": "världsfrånvändhet",
    "världsfrånvändhets": "världsfrånvändhet",
    "världsfrånvänds": "världsfrånvänd",
    "världsfrånvänt": "världsfrånvänd",
    "världsfrånvänts": "världsfrånvänd",
    "världsföraktet": "världsförakt",
    "världsföraktets": "världsförakt",
    "världsförakts": "världsförakt",
    "världsförbättrar": "världsförbättrare",
    "världsförbättraren": "världsförbättrare",
    "världsförbättrarens": "världsförbättrare",
    "världsförbättrares": "världsförbättrare",
    "världsförbättrarna": "världsförbättrare",
    "världsförbättrarnas": "världsförbättrare",
    "världsförsakelsen": "världsförsakelse",
    "världsförsakelsens": "världsförsakelse",
    "världsförsakelser": "världsförsakelse",
    "världsförsakelserna": "världsförsakelse",
    "världsförsakelsernas": "världsförsakelse",
    "världsförsakelsers": "världsförsakelse",
    "världsförsakelses": "världsförsakelse",
    "världsgåt": "världsgåta",
    "världsgåtan": "världsgåta",
    "världsgåtans": "världsgåta",
    "världsgåtas": "världsgåta",
    "världsgåte": "världsgåta",
    "världsgåtor": "världsgåta",
    "världsgåtorna": "världsgåta",
    "världsgåtornas": "världsgåta",
    "världsgåtors": "världsgåta",
    "världsgåts": "världsgåta",
    "världshandeln": "världshandel",
    "världshandelns": "världshandel",
    "världshandels": "världshandel",
    "världshaven": "världshav",
    "världshavens": "världshav",
    "världshavet": "världshav",
    "världshavets": "världshav",
    "världshavs": "världshav",
    "världsherravälden": "världsherravälde",
    "världsherraväldena": "världsherravälde",
    "världsherraväldenas": "världsherravälde",
    "världsherraväldens": "världsherravälde",
    "världsherraväldes": "världsherravälde",
    "världsherraväldet": "världsherravälde",
    "världsherraväldets": "världsherravälde",
    "världshistorian": "världshistoria",
    "världshistorians": "världshistoria",
    "världshistorias": "världshistoria",
    "världshistorien": "världshistoria",
    "världshistoriens": "världshistoria",
    "världshistoriska": "världshistorisk",
    "världshistoriskare": "världshistorisk",
    "världshistoriskares": "världshistorisk",
    "världshistoriskas": "världshistorisk",
    "världshistoriskast": "världshistorisk",
    "världshistoriskaste": "världshistorisk",
    "världshistoriskastes": "världshistorisk",
    "världshistoriskasts": "världshistorisk",
    "världshistoriske": "världshistorisk",
    "världshistoriskes": "världshistorisk",
    "världshistorisks": "världshistorisk",
    "världshistoriskt": "världshistorisk",
    "världshistoriskts": "världshistorisk",
    "världskapitalismen": "världskapitalism",
    "världskapitalismens": "världskapitalism",
    "världskapitalismer": "världskapitalism",
    "världskapitalismerna": "världskapitalism",
    "världskapitalismernas": "världskapitalism",
    "världskapitalismers": "världskapitalism",
    "världskapitalisms": "världskapitalism",
    "världskart": "världskarta",
    "världskartan": "världskarta",
    "världskartans": "världskarta",
    "världskartas": "världskarta",
    "världskarte": "världskarta",
    "världskartor": "världskarta",
    "världskartorna": "världskarta",
    "världskartornas": "världskarta",
    "världskartors": "världskarta",
    "världskarts": "världskarta",
    "världskloka": "världsklok",
    "världsklokare": "världsklok",
    "världsklokares": "världsklok",
    "världsklokas": "världsklok",
    "världsklokast": "världsklok",
    "världsklokaste": "världsklok",
    "världsklokastes": "världsklok",
    "världsklokasts": "världsklok",
    "världskloke": "världsklok",
    "världsklokes": "världsklok",
    "världsklokheten": "världsklokhet",
    "världsklokhetens": "världsklokhet",
    "världsklokhets": "världsklokhet",
    "världskloks": "världsklok",
    "världsklokt": "världsklok",
    "världsklokts": "världsklok",
    "världskrigen": "världskrig",
    "världskrigens": "världskrig",
    "världskriget": "världskrig",
    "världskrigets": "världskrig",
    "världskrigs": "världskrig",
    "världskända": "världskänd",
    "världskändare": "världskänd",
    "världskändares": "världskänd",
    "världskändas": "världskänd",
    "världskändast": "världskänd",
    "världskändaste": "världskänd",
    "världskändastes": "världskänd",
    "världskändasts": "världskänd",
    "världskände": "världskänd",
    "världskändes": "världskänd",
    "världskändheten": "världskändhet",
    "världskändhetens": "världskändhet",
    "världskändhets": "världskändhet",
    "världskänds": "världskänd",
    "världskänt": "världskänd",
    "världskänts": "världskänd",
    "världsliga": "världslig",
    "världsligare": "världslig",
    "världsligares": "världslig",
    "världsligas": "världslig",
    "världsligast": "världslig",
    "världsligaste": "världslig",
    "världsligastes": "världslig",
    "världsligasts": "världslig",
    "världslige": "världslig",
    "världsliges": "världslig",
    "världsligheten": "världslighet",
    "världslighetens": "världslighet",
    "världsligheter": "världslighet",
    "världsligheterna": "världslighet",
    "världsligheternas": "världslighet",
    "världsligheters": "världslighet",
    "världslighets": "världslighet",
    "världsligs": "världslig",
    "världsligt": "världslig",
    "världsligts": "världslig",
    "världslitteraturen": "världslitteratur",
    "världslitteraturens": "världslitteratur",
    "världslitteraturs": "världslitteratur",
    "världsmakten": "världsmakt",
    "världsmaktens": "världsmakt",
    "världsmakter": "världsmakt",
    "världsmakterna": "världsmakt",
    "världsmakternas": "världsmakt",
    "världsmakters": "världsmakt",
    "världsmakts": "världsmakt",
    "världsmannamässiga": "världsmannamässig",
    "världsmannamässigare": "världsmannamässig",
    "världsmannamässigares": "världsmannamässig",
    "världsmannamässigas": "världsmannamässig",
    "världsmannamässigast": "världsmannamässig",
    "världsmannamässigaste": "världsmannamässig",
    "världsmannamässigastes": "världsmannamässig",
    "världsmannamässigasts": "världsmannamässig",
    "världsmannamässige": "världsmannamässig",
    "världsmannamässiges": "världsmannamässig",
    "världsmannamässigs": "världsmannamässig",
    "världsmannamässigt": "världsmannamässig",
    "världsmannamässigts": "världsmannamässig",
    "världsmannen": "världsman",
    "världsmannens": "världsman",
    "världsmans": "världsman",
    "världsmarknaden": "världsmarknad",
    "världsmarknadens": "världsmarknad",
    "världsmarknader": "världsmarknad",
    "världsmarknaderna": "världsmarknad",
    "världsmarknadernas": "världsmarknad",
    "världsmarknaders": "världsmarknad",
    "världsmarknads": "världsmarknad",
    "världsmedborgar": "världsmedborgare",
    "världsmedborgaren": "världsmedborgare",
    "världsmedborgarens": "världsmedborgare",
    "världsmedborgares": "världsmedborgare",
    "världsmedborgarna": "världsmedborgare",
    "världsmedborgarnas": "världsmedborgare",
    "världsmedvetandes": "världsmedvetande",
    "världsmedvetandet": "världsmedvetande",
    "världsmedvetandets": "världsmedvetande",
    "världsmän": "världsman",
    "världsmännen": "världsman",
    "världsmännens": "världsman",
    "världsmäns": "världsman",
    "världsmästar": "världsmästare",
    "världsmästaren": "världsmästare",
    "världsmästarens": "världsmästare",
    "världsmästares": "världsmästare",
    "världsmästarinnan": "världsmästarinna",
    "världsmästarinnans": "världsmästarinna",
    "världsmästarinnas": "världsmästarinna",
    "världsmästarinne": "världsmästarinna",
    "världsmästarinnor": "världsmästarinna",
    "världsmästarinnorna": "världsmästarinna",
    "världsmästarinnornas": "världsmästarinna",
    "världsmästarinnors": "världsmästarinna",
    "världsmästarna": "världsmästare",
    "världsmästarnas": "världsmästare",
    "världsmästerskapen": "världsmästerskap",
    "världsmästerskapens": "världsmästerskap",
    "världsmästerskapet": "världsmästerskap",
    "världsmästerskapets": "världsmästerskap",
    "världsmästerskaps": "världsmästerskap",
    "världsnamnen": "världsnamn",
    "världsnamnens": "världsnamn",
    "världsnamnet": "världsnamn",
    "världsnamnets": "världsnamn",
    "världsnamns": "världsnamn",
    "världsomseglingar": "världsomsegling",
    "världsomseglingarna": "världsomsegling",
    "världsomseglingarnas": "världsomsegling",
    "världsomseglingars": "världsomsegling",
    "världsomseglingen": "världsomsegling",
    "världsomseglingens": "världsomsegling",
    "världsomseglings": "världsomsegling",
    "världsordningar": "världsordning",
    "världsordningarna": "världsordning",
    "världsordningarnas": "världsordning",
    "världsordningars": "världsordning",
    "världsordningen": "världsordning",
    "världsordningens": "världsordning",
    "världsordnings": "världsordning",
    "världsorganisationen": "världsorganisation",
    "världsorganisationens": "världsorganisation",
    "världsorganisationer": "världsorganisation",
    "världsorganisationerna": "världsorganisation",
    "världsorganisationernas": "världsorganisation",
    "världsorganisationers": "världsorganisation",
    "världsorganisations": "världsorganisation",
    "världspolitiken": "världspolitik",
    "världspolitikens": "världspolitik",
    "världspolitiks": "världspolitik",
    "världspolitiska": "världspolitisk",
    "världspolitiskas": "världspolitisk",
    "världspolitiske": "världspolitisk",
    "världspolitiskes": "världspolitisk",
    "världspolitisks": "världspolitisk",
    "världspolitiskt": "världspolitisk",
    "världspolitiskts": "världspolitisk",
    "världspremiären": "världspremiär",
    "världspremiärens": "världspremiär",
    "världspremiärer": "världspremiär",
    "världspremiärerna": "världspremiär",
    "världspremiärernas": "världspremiär",
    "världspremiärers": "världspremiär",
    "världspremiärs": "världspremiär",
    "världspressen": "världspress",
    "världspressens": "världspress",
    "världsrekorden": "världsrekord",
    "världsrekordens": "världsrekord",
    "världsrekordet": "världsrekord",
    "världsrekordets": "världsrekord",
    "världsrekords": "världsrekord",
    "världsreligionen": "världsreligion",
    "världsreligionens": "världsreligion",
    "världsreligioner": "världsreligion",
    "världsreligionerna": "världsreligion",
    "världsreligionernas": "världsreligion",
    "världsreligioners": "världsreligion",
    "världsreligions": "världsreligion",
    "världsrevolutionen": "världsrevolution",
    "världsrevolutionens": "världsrevolution",
    "världsrevolutioner": "världsrevolution",
    "världsrevolutionerna": "världsrevolution",
    "världsrevolutionernas": "världsrevolution",
    "världsrevolutioners": "världsrevolution",
    "världsrevolutions": "världsrevolution",
    "världsryktes": "världsrykte",
    "världsryktet": "världsrykte",
    "världsryktets": "världsrykte",
    "världsrymden": "världsrymd",
    "världsrymdens": "världsrymd",
    "världsrymder": "världsrymd",
    "världsrymderna": "världsrymd",
    "världsrymdernas": "världsrymd",
    "världsrymders": "världsrymd",
    "världsrymds": "världsrymd",
    "världssamfunden": "världssamfund",
    "världssamfundens": "världssamfund",
    "världssamfundet": "världssamfund",
    "världssamfundets": "världssamfund",
    "världssamfunds": "världssamfund",
    "världssamvetes": "världssamvete",
    "världssamvetet": "världssamvete",
    "världssamvetets": "världssamvete",
    "världssjälen": "världssjäl",
    "världssjälens": "världssjäl",
    "världssjäls": "världssjäl",
    "världssmärtan": "världssmärta",
    "världssmärtans": "världssmärta",
    "världssmärtas": "världssmärta",
    "världsspråken": "världsspråk",
    "världsspråkens": "världsspråk",
    "världsspråket": "världsspråk",
    "världsspråkets": "världsspråk",
    "världsspråks": "världsspråk",
    "världsstaden": "världsstad",
    "världsstadens": "världsstad",
    "världsstads": "världsstad",
    "världsstäder": "världsstad",
    "världsstäderna": "världsstad",
    "världsstädernas": "världsstad",
    "världsstäders": "världsstad",
    "världssuccéer": "världssuccé",
    "världssuccéerna": "världssuccé",
    "världssuccéernas": "världssuccé",
    "världssuccéers": "världssuccé",
    "världssuccén": "världssuccé",
    "världssuccéns": "världssuccé",
    "världssuccés": "världssuccé",
    "världstiden": "världstid",
    "världstidens": "världstid",
    "världstider": "världstid",
    "världstiderna": "världstid",
    "världstidernas": "världstid",
    "världstiders": "världstid",
    "världstids": "världstid",
    "världstrean": "världstrea",
    "världstreans": "världstrea",
    "världstreas": "världstrea",
    "världstreor": "världstrea",
    "världstreorna": "världstrea",
    "världstreornas": "världstrea",
    "världstreors": "världstrea",
    "världsutställningar": "världsutställning",
    "världsutställningarna": "världsutställning",
    "världsutställningarnas": "världsutställning",
    "världsutställningars": "världsutställning",
    "världsutställningen": "världsutställning",
    "världsutställningens": "världsutställning",
    "världsutställnings": "världsutställning",
    "världsvana": "världsvan",
    "världsvanan": "världsvana",
    "världsvanans": "världsvana",
    "världsvanare": "världsvan",
    "världsvanares": "världsvan",
    "världsvanas": "världsvana",
    "världsvanast": "världsvan",
    "världsvanaste": "världsvan",
    "världsvanastes": "världsvan",
    "världsvanasts": "världsvan",
    "världsvane": "världsvana",
    "världsvanes": "världsvan",
    "världsvans": "världsvan",
    "världsvant": "världsvan",
    "världsvants": "världsvan",
    "världsvisa": "världsvis",
    "världsvisare": "världsvis",
    "världsvisares": "världsvis",
    "världsvisas": "världsvis",
    "världsvisast": "världsvis",
    "världsvisaste": "världsvis",
    "världsvisastes": "världsvis",
    "världsvisasts": "världsvis",
    "världsvise": "världsvis",
    "världsvises": "världsvis",
    "världsvisheten": "världsvishet",
    "världsvishetens": "världsvishet",
    "världsvishets": "världsvishet",
    "världsvist": "världsvis",
    "världsvists": "världsvis",
    "världsåldern": "världsålder",
    "världsålderns": "världsålder",
    "världsålders": "världsålder",
    "världsåldrar": "världsålder",
    "världsåldrarna": "världsålder",
    "världsåldrarnas": "världsålder",
    "världsåldrars": "världsålder",
    "världsåskådningar": "världsåskådning",
    "världsåskådningarna": "världsåskådning",
    "världsåskådningarnas": "världsåskådning",
    "världsåskådningars": "världsåskådning",
    "världsåskådningen": "världsåskådning",
    "världsåskådningens": "världsåskådning",
    "världsåskådnings": "världsåskådning",
    "värm": "värma",
    "värman": "värma",
    "värmande": "värma",
    "värmanden": "värmande",
    "värmandena": "värmande",
    "värmandenas": "värmande",
    "värmandens": "värmande",
    "värmandes": "värmande",
    "värmandet": "värmande",
    "värmandets": "värmande",
    "värmans": "värma",
    "värmas": "värma",
    "värmd": "värma",
    "värmda": "värma",
    "värmdas": "värma",
    "värmde": "värma",
    "värmdes": "värma",
    "värmds": "värma",
    "värmeanläggningar": "värmeanläggning",
    "värmeanläggningarna": "värmeanläggning",
    "värmeanläggningarnas": "värmeanläggning",
    "värmeanläggningars": "värmeanläggning",
    "värmeanläggningen": "värmeanläggning",
    "värmeanläggningens": "värmeanläggning",
    "värmeanläggnings": "värmeanläggning",
    "värmebehandlad": "värmebehandla",
    "värmebehandlade": "värmebehandla",
    "värmebehandlades": "värmebehandla",
    "värmebehandlads": "värmebehandla",
    "värmebehandlande": "värmebehandla",
    "värmebehandlanden": "värmebehandlande",
    "värmebehandlandena": "värmebehandlande",
    "värmebehandlandenas": "värmebehandlande",
    "värmebehandlandens": "värmebehandlande",
    "värmebehandlandes": "värmebehandlande",
    "värmebehandlandet": "värmebehandlande",
    "värmebehandlandets": "värmebehandlande",
    "värmebehandlar": "värmebehandla",
    "värmebehandlas": "värmebehandla",
    "värmebehandlat": "värmebehandla",
    "värmebehandlats": "värmebehandla",
    "värmebehandlingar": "värmebehandling",
    "värmebehandlingarna": "värmebehandling",
    "värmebehandlingarnas": "värmebehandling",
    "värmebehandlingars": "värmebehandling",
    "värmebehandlingen": "värmebehandling",
    "värmebehandlingens": "värmebehandling",
    "värmebehandlings": "värmebehandling",
    "värmebehoven": "värmebehov",
    "värmebehovens": "värmebehov",
    "värmebehovet": "värmebehov",
    "värmebehovets": "värmebehov",
    "värmebehovs": "värmebehov",
    "värmebeständiga": "värmebeständig",
    "värmebeständigare": "värmebeständig",
    "värmebeständigares": "värmebeständig",
    "värmebeständigas": "värmebeständig",
    "värmebeständigast": "värmebeständig",
    "värmebeständigaste": "värmebeständig",
    "värmebeständigastes": "värmebeständig",
    "värmebeständigasts": "värmebeständig",
    "värmebeständige": "värmebeständig",
    "värmebeständiges": "värmebeständig",
    "värmebeständigheten": "värmebeständighet",
    "värmebeständighetens": "värmebeständighet",
    "värmebeständighets": "värmebeständighet",
    "värmebeständigs": "värmebeständig",
    "värmebeständigt": "värmebeständig",
    "värmebeständigts": "värmebeständig",
    "värmebilden": "värmebild",
    "värmebildens": "värmebild",
    "värmebilder": "värmebild",
    "värmebilderna": "värmebild",
    "värmebildernas": "värmebild",
    "värmebilders": "värmebild",
    "värmebilds": "värmebild",
    "värmebildskameran": "värmebildskamera",
    "värmebildskamerans": "värmebildskamera",
    "värmebildskameras": "värmebildskamera",
    "värmebildskameror": "värmebildskamera",
    "värmebildskamerorna": "värmebildskamera",
    "värmebildskamerornas": "värmebildskamera",
    "värmebildskamerors": "värmebildskamera",
    "värmeböljan": "värmebölja",
    "värmeböljans": "värmebölja",
    "värmeböljas": "värmebölja",
    "värmebölje": "värmebölja",
    "värmeböljor": "värmebölja",
    "värmeböljorna": "värmebölja",
    "värmeböljornas": "värmebölja",
    "värmeböljors": "värmebölja",
    "värmecentralen": "värmecentral",
    "värmecentralens": "värmecentral",
    "värmecentraler": "värmecentral",
    "värmecentralerna": "värmecentral",
    "värmecentralernas": "värmecentral",
    "värmecentralers": "värmecentral",
    "värmecentrals": "värmecentral",
    "värmediset": "värmedis",
    "värmedisets": "värmedis",
    "värmedyn": "värmedyna",
    "värmedynan": "värmedyna",
    "värmedynans": "värmedyna",
    "värmedynas": "värmedyna",
    "värmedyne": "värmedyna",
    "värmedynor": "värmedyna",
    "värmedynorna": "värmedyna",
    "värmedynornas": "värmedyna",
    "värmedynors": "värmedyna",
    "värmedyns": "värmedyna",
    "värmedämpningar": "värmedämpning",
    "värmedämpningarna": "värmedämpning",
    "värmedämpningarnas": "värmedämpning",
    "värmedämpningars": "värmedämpning",
    "värmedämpningen": "värmedämpning",
    "värmedämpningens": "värmedämpning",
    "värmedämpnings": "värmedämpning",
    "värmeeffekten": "värmeeffekt",
    "värmeeffektens": "värmeeffekt",
    "värmeeffekts": "värmeeffekt",
    "värmeekonomien": "värmeekonomi",
    "värmeekonomiens": "värmeekonomi",
    "värmeekonomier": "värmeekonomi",
    "värmeekonomierna": "värmeekonomi",
    "värmeekonomiernas": "värmeekonomi",
    "värmeekonomiers": "värmeekonomi",
    "värmeekonomin": "värmeekonomi",
    "värmeekonomins": "värmeekonomi",
    "värmeekonomis": "värmeekonomi",
    "värmeekvatorn": "värmeekvator",
    "värmeekvatorns": "värmeekvator",
    "värmeekvators": "värmeekvator",
    "värmeekvivalenten": "värmeekvivalent",
    "värmeekvivalentens": "värmeekvivalent",
    "värmeekvivalents": "värmeekvivalent",
    "värmeelementen": "värmeelement",
    "värmeelementens": "värmeelement",
    "värmeelementet": "värmeelement",
    "värmeelementets": "värmeelement",
    "värmeelements": "värmeelement",
    "värmeenergien": "värmeenergi",
    "värmeenergiens": "värmeenergi",
    "värmeenergin": "värmeenergi",
    "värmeenergins": "värmeenergi",
    "värmeenergis": "värmeenergi",
    "värmeenheten": "värmeenhet",
    "värmeenhetens": "värmeenhet",
    "värmeenheter": "värmeenhet",
    "värmeenheterna": "värmeenhet",
    "värmeenheternas": "värmeenhet",
    "värmeenheters": "värmeenhet",
    "värmeenhets": "värmeenhet",
    "värmeexpansionen": "värmeexpansion",
    "värmeexpansionens": "värmeexpansion",
    "värmeexpansioner": "värmeexpansion",
    "värmeexpansionerna": "värmeexpansion",
    "värmeexpansionernas": "värmeexpansion",
    "värmeexpansioners": "värmeexpansion",
    "värmeexpansions": "värmeexpansion",
    "värmeflask": "värmeflaska",
    "värmeflaskan": "värmeflaska",
    "värmeflaskans": "värmeflaska",
    "värmeflaskas": "värmeflaska",
    "värmeflaske": "värmeflaska",
    "värmeflaskor": "värmeflaska",
    "värmeflaskorna": "värmeflaska",
    "värmeflaskornas": "värmeflaska",
    "värmeflaskors": "värmeflaska",
    "värmeflöden": "värmeflöde",
    "värmeflödena": "värmeflöde",
    "värmeflödenas": "värmeflöde",
    "värmeflödens": "värmeflöde",
    "värmeflödes": "värmeflöde",
    "värmeflödet": "värmeflöde",
    "värmeflödets": "värmeflöde",
    "värmefotograferad": "värmefotografera",
    "värmefotograferade": "värmefotografera",
    "värmefotograferades": "värmefotografera",
    "värmefotograferads": "värmefotografera",
    "värmefotograferande": "värmefotografera",
    "värmefotograferanden": "värmefotograferande",
    "värmefotograferandena": "värmefotograferande",
    "värmefotograferandenas": "värmefotograferande",
    "värmefotograferandens": "värmefotograferande",
    "värmefotograferandes": "värmefotograferande",
    "värmefotograferandet": "värmefotograferande",
    "värmefotograferandets": "värmefotograferande",
    "värmefotograferar": "värmefotografera",
    "värmefotograferas": "värmefotografera",
    "värmefotograferat": "värmefotografera",
    "värmefotograferats": "värmefotografera",
    "värmefotograferbara": "värmefotograferbar",
    "värmefotograferbarare": "värmefotograferbar",
    "värmefotograferbarares": "värmefotograferbar",
    "värmefotograferbaras": "värmefotograferbar",
    "värmefotograferbarast": "värmefotograferbar",
    "värmefotograferbaraste": "värmefotograferbar",
    "värmefotograferbarastes": "värmefotograferbar",
    "värmefotograferbarasts": "värmefotograferbar",
    "värmefotograferbare": "värmefotograferbar",
    "värmefotograferbares": "värmefotograferbar",
    "värmefotograferbarheten": "värmefotograferbarhet",
    "värmefotograferbarhetens": "värmefotograferbarhet",
    "värmefotograferbarhets": "värmefotograferbarhet",
    "värmefotograferbars": "värmefotograferbar",
    "värmefotograferbart": "värmefotograferbar",
    "värmefotograferbarts": "värmefotograferbar",
    "värmefotograferingar": "värmefotografering",
    "värmefotograferingarna": "värmefotografering",
    "värmefotograferingarnas": "värmefotografering",
    "värmefotograferingars": "värmefotografering",
    "värmefotograferingen": "värmefotografering",
    "värmefotograferingens": "värmefotografering",
    "värmefotograferings": "värmefotografering",
    "värmeförlusten": "värmeförlust",
    "värmeförlustens": "värmeförlust",
    "värmeförluster": "värmeförlust",
    "värmeförlusterna": "värmeförlust",
    "värmeförlusternas": "värmeförlust",
    "värmeförlusters": "värmeförlust",
    "värmeförlusts": "värmeförlust",
    "värmegenomgången": "värmegenomgång",
    "värmegenomgångens": "värmegenomgång",
    "värmegenomgångs": "värmegenomgång",
    "värmegenomgångstalen": "värmegenomgångstal",
    "värmegenomgångstalens": "värmegenomgångstal",
    "värmegenomgångstalet": "värmegenomgångstal",
    "värmegenomgångstalets": "värmegenomgångstal",
    "värmegenomgångstals": "värmegenomgångstal",
    "värmegraden": "värmegrad",
    "värmegradens": "värmegrad",
    "värmegrader": "värmegrad",
    "värmegraderna": "värmegrad",
    "värmegradernas": "värmegrad",
    "värmegraders": "värmegrad",
    "värmegrads": "värmegrad",
    "värmeisolatorer": "värmeisolator",
    "värmeisolatorerna": "värmeisolator",
    "värmeisolatorernas": "värmeisolator",
    "värmeisolatorers": "värmeisolator",
    "värmeisolatorn": "värmeisolator",
    "värmeisolatorns": "värmeisolator",
    "värmeisolators": "värmeisolator",
    "värmeisolerad": "värmeisolera",
    "värmeisolerade": "värmeisolera",
    "värmeisolerades": "värmeisolera",
    "värmeisolerads": "värmeisolera",
    "värmeisolerande": "värmeisolera",
    "värmeisoleranden": "värmeisolerande",
    "värmeisolerandena": "värmeisolerande",
    "värmeisolerandenas": "värmeisolerande",
    "värmeisolerandens": "värmeisolerande",
    "värmeisolerandes": "värmeisolerande",
    "värmeisolerandet": "värmeisolerande",
    "värmeisolerandets": "värmeisolerande",
    "värmeisolerar": "värmeisolera",
    "värmeisoleras": "värmeisolera",
    "värmeisolerat": "värmeisolera",
    "värmeisolerats": "värmeisolera",
    "värmeisolerbara": "värmeisolerbar",
    "värmeisolerbarare": "värmeisolerbar",
    "värmeisolerbarares": "värmeisolerbar",
    "värmeisolerbaras": "värmeisolerbar",
    "värmeisolerbarast": "värmeisolerbar",
    "värmeisolerbaraste": "värmeisolerbar",
    "värmeisolerbarastes": "värmeisolerbar",
    "värmeisolerbarasts": "värmeisolerbar",
    "värmeisolerbare": "värmeisolerbar",
    "värmeisolerbares": "värmeisolerbar",
    "värmeisolerbarheten": "värmeisolerbarhet",
    "värmeisolerbarhetens": "värmeisolerbarhet",
    "värmeisolerbarhets": "värmeisolerbarhet",
    "värmeisolerbars": "värmeisolerbar",
    "värmeisolerbart": "värmeisolerbar",
    "värmeisolerbarts": "värmeisolerbar",
    "värmeisoleringar": "värmeisolering",
    "värmeisoleringarna": "värmeisolering",
    "värmeisoleringarnas": "värmeisolering",
    "värmeisoleringars": "värmeisolering",
    "värmeisoleringen": "värmeisolering",
    "värmeisoleringens": "värmeisolering",
    "värmeisolerings": "värmeisolering",
    "värmekameran": "värmekamera",
    "värmekamerans": "värmekamera",
    "värmekameras": "värmekamera",
    "värmekameror": "värmekamera",
    "värmekamerorna": "värmekamera",
    "värmekamerornas": "värmekamera",
    "värmekamerors": "värmekamera",
    "värmekapaciteten": "värmekapacitet",
    "värmekapacitetens": "värmekapacitet",
    "värmekapaciteter": "värmekapacitet",
    "värmekapaciteterna": "värmekapacitet",
    "värmekapaciteternas": "värmekapacitet",
    "värmekapaciteters": "värmekapacitet",
    "värmekapacitets": "värmekapacitet",
    "värmekapacitiviteten": "värmekapacitivitet",
    "värmekapacitivitetens": "värmekapacitivitet",
    "värmekapacitiviteter": "värmekapacitivitet",
    "värmekapacitiviteterna": "värmekapacitivitet",
    "värmekapacitiviteternas": "värmekapacitivitet",
    "värmekapacitiviteters": "värmekapacitivitet",
    "värmekapacitivitets": "värmekapacitivitet",
    "värmekonduktiviteten": "värmekonduktivitet",
    "värmekonduktivitetens": "värmekonduktivitet",
    "värmekonduktiviteter": "värmekonduktivitet",
    "värmekonduktiviteterna": "värmekonduktivitet",
    "värmekonduktiviteternas": "värmekonduktivitet",
    "värmekonduktiviteters": "värmekonduktivitet",
    "värmekonduktivitets": "värmekonduktivitet",
    "värmekostnaden": "värmekostnad",
    "värmekostnadens": "värmekostnad",
    "värmekostnader": "värmekostnad",
    "värmekostnaderna": "värmekostnad",
    "värmekostnadernas": "värmekostnad",
    "värmekostnaders": "värmekostnad",
    "värmekostnads": "värmekostnad",
    "värmekraftverken": "värmekraftverk",
    "värmekraftverkens": "värmekraftverk",
    "värmekraftverket": "värmekraftverk",
    "värmekraftverkets": "värmekraftverk",
    "värmekraftverks": "värmekraftverk",
    "värmekrusen": "värmekrus",
    "värmekrusens": "värmekrus",
    "värmekruset": "värmekrus",
    "värmekrusets": "värmekrus",
    "värmekäll": "värmekälla",
    "värmekällan": "värmekälla",
    "värmekällans": "värmekälla",
    "värmekällas": "värmekälla",
    "värmekälle": "värmekälla",
    "värmekällor": "värmekälla",
    "värmekällorna": "värmekälla",
    "värmekällornas": "värmekälla",
    "värmekällors": "värmekälla",
    "värmekälls": "värmekälla",
    "värmelamp": "värmelampa",
    "värmelampan": "värmelampa",
    "värmelampans": "värmelampa",
    "värmelampas": "värmelampa",
    "värmelampe": "värmelampa",
    "värmelampor": "värmelampa",
    "värmelamporna": "värmelampa",
    "värmelampornas": "värmelampa",
    "värmelampors": "värmelampa",
    "värmelamps": "värmelampa",
    "värmeledar": "värmeledare",
    "värmeledaren": "värmeledare",
    "värmeledarens": "värmeledare",
    "värmeledares": "värmeledare",
    "värmeledarna": "värmeledare",
    "värmeledarnas": "värmeledare",
    "värmeledningar": "värmeledning",
    "värmeledningarna": "värmeledning",
    "värmeledningarnas": "värmeledning",
    "värmeledningars": "värmeledning",
    "värmeledningen": "värmeledning",
    "värmeledningens": "värmeledning",
    "värmelednings": "värmeledning",
    "värmeledningspann": "värmeledningspanna",
    "värmeledningspannan": "värmeledningspanna",
    "värmeledningspannans": "värmeledningspanna",
    "värmeledningspannas": "värmeledningspanna",
    "värmeledningspanne": "värmeledningspanna",
    "värmeledningspannor": "värmeledningspanna",
    "värmeledningspannorna": "värmeledningspanna",
    "värmeledningspannornas": "värmeledningspanna",
    "värmeledningspannors": "värmeledningspanna",
    "värmeledningspanns": "värmeledningspanna",
    "värmeledningssystemen": "värmeledningssystem",
    "värmeledningssystemens": "värmeledningssystem",
    "värmeledningssystemet": "värmeledningssystem",
    "värmeledningssystemets": "värmeledningssystem",
    "värmeledningssystems": "värmeledningssystem",
    "värmeljusen": "värmeljus",
    "värmeljusens": "värmeljus",
    "värmeljuset": "värmeljus",
    "värmeljusets": "värmeljus",
    "värmeläran": "värmelära",
    "värmelärans": "värmelära",
    "värmeläras": "värmelära",
    "värmemotorer": "värmemotor",
    "värmemotorerna": "värmemotor",
    "värmemotorernas": "värmemotor",
    "värmemotorers": "värmemotor",
    "värmemotorn": "värmemotor",
    "värmemotorns": "värmemotor",
    "värmemotors": "värmemotor",
    "värmemängden": "värmemängd",
    "värmemängdens": "värmemängd",
    "värmemängder": "värmemängd",
    "värmemängderna": "värmemängd",
    "värmemängdernas": "värmemängd",
    "värmemängders": "värmemängd",
    "värmemängds": "värmemängd",
    "värmemåtten": "värmemått",
    "värmemåttens": "värmemått",
    "värmemåttet": "värmemått",
    "värmemåttets": "värmemått",
    "värmemåtts": "värmemått",
    "värmen": "värme",
    "värmens": "värme",
    "värmepann": "värmepanna",
    "värmepannan": "värmepanna",
    "värmepannans": "värmepanna",
    "värmepannas": "värmepanna",
    "värmepanne": "värmepanna",
    "värmepannor": "värmepanna",
    "värmepannorna": "värmepanna",
    "värmepannornas": "värmepanna",
    "värmepannors": "värmepanna",
    "värmepanns": "värmepanna",
    "värmeplatt": "värmeplatta",
    "värmeplattan": "värmeplatta",
    "värmeplattans": "värmeplatta",
    "värmeplattas": "värmeplatta",
    "värmeplatte": "värmeplatta",
    "värmeplattor": "värmeplatta",
    "värmeplattorna": "värmeplatta",
    "värmeplattornas": "värmeplatta",
    "värmeplattors": "värmeplatta",
    "värmeplatts": "värmeplatta",
    "värmepumpar": "värmepump",
    "värmepumparna": "värmepump",
    "värmepumparnas": "värmepump",
    "värmepumpars": "värmepump",
    "värmepumpen": "värmepump",
    "värmepumpens": "värmepump",
    "värmepumps": "värmepump",
    "värmer": "värma",
    "värmeradiatorer": "värmeradiator",
    "värmeradiatorerna": "värmeradiator",
    "värmeradiatorernas": "värmeradiator",
    "värmeradiatorers": "värmeradiator",
    "värmeradiatorn": "värmeradiator",
    "värmeradiatorns": "värmeradiator",
    "värmeradiators": "värmeradiator",
    "värmerörelsen": "värmerörelse",
    "värmerörelsens": "värmerörelse",
    "värmerörelses": "värmerörelse",
    "värmes": "värme",
    "värmeskåpen": "värmeskåp",
    "värmeskåpens": "värmeskåp",
    "värmeskåpet": "värmeskåp",
    "värmeskåpets": "värmeskåp",
    "värmeskåps": "värmeskåp",
    "värmesköldar": "värmesköld",
    "värmesköldarna": "värmesköld",
    "värmesköldarnas": "värmesköld",
    "värmesköldars": "värmesköld",
    "värmeskölden": "värmesköld",
    "värmesköldens": "värmesköld",
    "värmeskölds": "värmesköld",
    "värmeslaget": "värmeslag",
    "värmeslagets": "värmeslag",
    "värmeslags": "värmeslag",
    "värmesling": "värmeslinga",
    "värmeslingan": "värmeslinga",
    "värmeslingans": "värmeslinga",
    "värmeslingas": "värmeslinga",
    "värmeslinge": "värmeslinga",
    "värmeslingor": "värmeslinga",
    "värmeslingorna": "värmeslinga",
    "värmeslingornas": "värmeslinga",
    "värmeslingors": "värmeslinga",
    "värmeslings": "värmeslinga",
    "värmespridningar": "värmespridning",
    "värmespridningarna": "värmespridning",
    "värmespridningarnas": "värmespridning",
    "värmespridningars": "värmespridning",
    "värmespridningen": "värmespridning",
    "värmespridningens": "värmespridning",
    "värmespridnings": "värmespridning",
    "värmesteriliserad": "värmesterilisera",
    "värmesteriliserade": "värmesterilisera",
    "värmesteriliserades": "värmesterilisera",
    "värmesteriliserads": "värmesterilisera",
    "värmesteriliserande": "värmesterilisera",
    "värmesteriliseranden": "värmesteriliserande",
    "värmesteriliserandena": "värmesteriliserande",
    "värmesteriliserandenas": "värmesteriliserande",
    "värmesteriliserandens": "värmesteriliserande",
    "värmesteriliserandes": "värmesteriliserande",
    "värmesteriliserandet": "värmesteriliserande",
    "värmesteriliserandets": "värmesteriliserande",
    "värmesteriliserar": "värmesterilisera",
    "värmesteriliseras": "värmesterilisera",
    "värmesteriliserat": "värmesterilisera",
    "värmesteriliserats": "värmesterilisera",
    "värmesteriliserbara": "värmesteriliserbar",
    "värmesteriliserbarare": "värmesteriliserbar",
    "värmesteriliserbarares": "värmesteriliserbar",
    "värmesteriliserbaras": "värmesteriliserbar",
    "värmesteriliserbarast": "värmesteriliserbar",
    "värmesteriliserbaraste": "värmesteriliserbar",
    "värmesteriliserbarastes": "värmesteriliserbar",
    "värmesteriliserbarasts": "värmesteriliserbar",
    "värmesteriliserbare": "värmesteriliserbar",
    "värmesteriliserbares": "värmesteriliserbar",
    "värmesteriliserbarheten": "värmesteriliserbarhet",
    "värmesteriliserbarhetens": "värmesteriliserbarhet",
    "värmesteriliserbarhets": "värmesteriliserbarhet",
    "värmesteriliserbars": "värmesteriliserbar",
    "värmesteriliserbart": "värmesteriliserbar",
    "värmesteriliserbarts": "värmesteriliserbar",
    "värmesteriliseringar": "värmesterilisering",
    "värmesteriliseringarna": "värmesterilisering",
    "värmesteriliseringarnas": "värmesterilisering",
    "värmesteriliseringars": "värmesterilisering",
    "värmesteriliseringen": "värmesterilisering",
    "värmesteriliseringens": "värmesterilisering",
    "värmesteriliserings": "värmesterilisering",
    "värmestrålningar": "värmestrålning",
    "värmestrålningarna": "värmestrålning",
    "värmestrålningarnas": "värmestrålning",
    "värmestrålningars": "värmestrålning",
    "värmestrålningen": "värmestrålning",
    "värmestrålningens": "värmestrålning",
    "värmestrålnings": "värmestrålning",
    "värmestugan": "värmestuga",
    "värmestugans": "värmestuga",
    "värmestugas": "värmestuga",
    "värmestuge": "värmestuga",
    "värmestugor": "värmestuga",
    "värmestugorna": "värmestuga",
    "värmestugornas": "värmestuga",
    "värmestugors": "värmestuga",
    "värmestugu": "värmestuga",
    "värmet": "värme",
    "värmeterapien": "värmeterapi",
    "värmeterapiens": "värmeterapi",
    "värmeterapin": "värmeterapi",
    "värmeterapins": "värmeterapi",
    "värmeterapis": "värmeterapi",
    "värmetillförseln": "värmetillförsel",
    "värmetillförselns": "värmetillförsel",
    "värmetillförsels": "värmetillförsel",
    "värmetilläggen": "värmetillägg",
    "värmetilläggens": "värmetillägg",
    "värmetillägget": "värmetillägg",
    "värmetilläggets": "värmetillägg",
    "värmetilläggs": "värmetillägg",
    "värmets": "värme",
    "värmetåliga": "värmetålig",
    "värmetåligare": "värmetålig",
    "värmetåligares": "värmetålig",
    "värmetåligas": "värmetålig",
    "värmetåligast": "värmetålig",
    "värmetåligaste": "värmetålig",
    "värmetåligastes": "värmetålig",
    "värmetåligasts": "värmetålig",
    "värmetålige": "värmetålig",
    "värmetåliges": "värmetålig",
    "värmetåligheten": "värmetålighet",
    "värmetålighetens": "värmetålighet",
    "värmetålighets": "värmetålighet",
    "värmetåligs": "värmetålig",
    "värmetåligt": "värmetålig",
    "värmetåligts": "värmetålig",
    "värmeutbyten": "värmeutbyte",
    "värmeutbytena": "värmeutbyte",
    "värmeutbytenas": "värmeutbyte",
    "värmeutbytens": "värmeutbyte",
    "värmeutbytes": "värmeutbyte",
    "värmeutbytet": "värmeutbyte",
    "värmeutbytets": "värmeutbyte",
    "värmeutvecklingar": "värmeutveckling",
    "värmeutvecklingarna": "värmeutveckling",
    "värmeutvecklingarnas": "värmeutveckling",
    "värmeutvecklingars": "värmeutveckling",
    "värmeutvecklingen": "värmeutveckling",
    "värmeutvecklingens": "värmeutveckling",
    "värmeutvecklings": "värmeutveckling",
    "värmeutvidgningar": "värmeutvidgning",
    "värmeutvidgningarna": "värmeutvidgning",
    "värmeutvidgningarnas": "värmeutvidgning",
    "värmeutvidgningars": "värmeutvidgning",
    "värmeutvidgningen": "värmeutvidgning",
    "värmeutvidgningens": "värmeutvidgning",
    "värmeutvidgnings": "värmeutvidgning",
    "värmeverken": "värmeverk",
    "värmeverkens": "värmeverk",
    "värmeverket": "värmeverk",
    "värmeverkets": "värmeverk",
    "värmeverks": "värmeverk",
    "värmevärdes": "värmevärde",
    "värmevärdet": "värmevärde",
    "värmevärdets": "värmevärde",
    "värmeväxlar": "värmeväxlare",
    "värmeväxlaren": "värmeväxlare",
    "värmeväxlarens": "värmeväxlare",
    "värmeväxlares": "värmeväxlare",
    "värmeväxlarna": "värmeväxlare",
    "värmeväxlarnas": "värmeväxlare",
    "värmeåskväderna": "värmeåskväder",
    "värmeåskvädernas": "värmeåskväder",
    "värmeåskväders": "värmeåskväder",
    "värmeåskvädren": "värmeåskväder",
    "värmeåskvädrens": "värmeåskväder",
    "värmeåskvädret": "värmeåskväder",
    "värmeåskvädrets": "värmeåskväder",
    "värmländsk": "värmländska",
    "värmländska": "värmländsk",
    "värmländskan": "värmländska",
    "värmländskans": "värmländska",
    "värmländskare": "värmländsk",
    "värmländskares": "värmländsk",
    "värmländskas": "värmländska",
    "värmländskast": "värmländsk",
    "värmländskaste": "värmländsk",
    "värmländskastes": "värmländsk",
    "värmländskasts": "värmländsk",
    "värmländske": "värmländska",
    "värmländskes": "värmländsk",
    "värmländskor": "värmländska",
    "värmländskorna": "värmländska",
    "värmländskornas": "värmländska",
    "värmländskors": "värmländska",
    "värmländsks": "värmländsk",
    "värmländskt": "värmländsk",
    "värmländskts": "värmländsk",
    "värmlänningar": "värmlänning",
    "värmlänningarna": "värmlänning",
    "värmlänningarnas": "värmlänning",
    "värmlänningars": "värmlänning",
    "värmlänningen": "värmlänning",
    "värmlänningens": "värmlänning",
    "värmlännings": "värmlänning",
    "värmningsfunktionen": "värmningsfunktion",
    "värmningsfunktionens": "värmningsfunktion",
    "värmningsfunktioner": "värmningsfunktion",
    "värmningsfunktionerna": "värmningsfunktion",
    "värmningsfunktionernas": "värmningsfunktion",
    "värmningsfunktioners": "värmningsfunktion",
    "värmningsfunktions": "värmningsfunktion",
    "värms": "värma",
    "värmt": "värma",
    "värmts": "värma",
    "värn": "värna",
    "värnad": "värna",
    "värnade": "värna",
    "värnades": "värna",
    "värnads": "värna",
    "värnande": "värna",
    "värnanden": "värnande",
    "värnandena": "värnande",
    "värnandenas": "värnande",
    "värnandens": "värnande",
    "värnandes": "värnande",
    "värnandet": "värnande",
    "värnandets": "värnande",
    "värnar": "värna",
    "värnas": "värna",
    "värnat": "värna",
    "värnats": "värna",
    "värnen": "värn",
    "värnens": "värn",
    "värnet": "värn",
    "värnets": "värn",
    "värnfågeln": "värnfågel",
    "värnfågelns": "värnfågel",
    "värnfågels": "värnfågel",
    "värnfåglar": "värnfågel",
    "värnfåglarna": "värnfågel",
    "värnfåglarnas": "värnfågel",
    "värnfåglars": "värnfågel",
    "värnkraften": "värnkraft",
    "värnkraftens": "värnkraft",
    "värnkrafts": "värnkraft",
    "värnlösa": "värnlös",
    "värnlösare": "värnlös",
    "värnlösares": "värnlös",
    "värnlösas": "värnlös",
    "värnlösast": "värnlös",
    "värnlösaste": "värnlös",
    "värnlösastes": "värnlös",
    "värnlösasts": "värnlös",
    "värnlöse": "värnlös",
    "värnlöses": "värnlös",
    "värnlösheten": "värnlöshet",
    "värnlöshetens": "värnlöshet",
    "värnlöshets": "värnlöshet",
    "värnlöst": "värnlös",
    "värnlösts": "värnlös",
    "värnplikten": "värnplikt",
    "värnpliktens": "värnplikt",
    "värnpliktiga": "värnpliktig",
    "värnpliktigare": "värnpliktig",
    "värnpliktigares": "värnpliktig",
    "värnpliktigas": "värnpliktig",
    "värnpliktigast": "värnpliktig",
    "värnpliktigaste": "värnpliktig",
    "värnpliktigastes": "värnpliktig",
    "värnpliktigasts": "värnpliktig",
    "värnpliktige": "värnpliktig",
    "värnpliktiges": "värnpliktig",
    "värnpliktigs": "värnpliktig",
    "värnpliktigt": "värnpliktig",
    "värnpliktigts": "värnpliktig",
    "värnplikts": "värnplikt",
    "värnpliktsarméer": "värnpliktsarmé",
    "värnpliktsarméerna": "värnpliktsarmé",
    "värnpliktsarméernas": "värnpliktsarmé",
    "värnpliktsarméers": "värnpliktsarmé",
    "värnpliktsarmén": "värnpliktsarmé",
    "värnpliktsarméns": "värnpliktsarmé",
    "värnpliktsarmés": "värnpliktsarmé",
    "värnpliktsmyndigheten": "värnpliktsmyndighet",
    "värnpliktsmyndighetens": "värnpliktsmyndighet",
    "värnpliktsmyndigheter": "värnpliktsmyndighet",
    "värnpliktsmyndigheterna": "värnpliktsmyndighet",
    "värnpliktsmyndigheternas": "värnpliktsmyndighet",
    "värnpliktsmyndigheters": "värnpliktsmyndighet",
    "värnpliktsmyndighets": "värnpliktsmyndighet",
    "värnpliktsriksdagar": "värnpliktsriksdag",
    "värnpliktsriksdagarna": "värnpliktsriksdag",
    "värnpliktsriksdagarnas": "värnpliktsriksdag",
    "värnpliktsriksdagars": "värnpliktsriksdag",
    "värnpliktsriksdagen": "värnpliktsriksdag",
    "värnpliktsriksdagens": "värnpliktsriksdag",
    "värnpliktsriksdags": "värnpliktsriksdag",
    "värnpliktstiden": "värnpliktstid",
    "värnpliktstidens": "värnpliktstid",
    "värnpliktstids": "värnpliktstid",
    "värnpliktstjänstgöringar": "värnpliktstjänstgöring",
    "värnpliktstjänstgöringarna": "värnpliktstjänstgöring",
    "värnpliktstjänstgöringarnas": "värnpliktstjänstgöring",
    "värnpliktstjänstgöringars": "värnpliktstjänstgöring",
    "värnpliktstjänstgöringen": "värnpliktstjänstgöring",
    "värnpliktstjänstgöringens": "värnpliktstjänstgöring",
    "värnpliktstjänstgörings": "värnpliktstjänstgöring",
    "värnpliktsvägrans": "värnpliktsvägran",
    "värnpliktsvägrar": "värnpliktsvägrare",
    "värnpliktsvägraren": "värnpliktsvägrare",
    "värnpliktsvägrarens": "värnpliktsvägrare",
    "värnpliktsvägrares": "värnpliktsvägrare",
    "värnpliktsvägrarna": "värnpliktsvägrare",
    "värnpliktsvägrarnas": "värnpliktsvägrare",
    "värns": "värn",
    "värp": "värpa",
    "värpande": "värpa",
    "värpanden": "värpande",
    "värpandena": "värpande",
    "värpandenas": "värpande",
    "värpandens": "värpande",
    "värpandes": "värpande",
    "värpandet": "värpande",
    "värpandets": "värpande",
    "värpas": "värpa",
    "värper": "värpa",
    "värpes": "värpa",
    "värps": "värpa",
    "värpsjuka": "värpsjuk",
    "värpsjukan": "värpsjuka",
    "värpsjukans": "värpsjuka",
    "värpsjukare": "värpsjuk",
    "värpsjukares": "värpsjuk",
    "värpsjukas": "värpsjuka",
    "värpsjukast": "värpsjuk",
    "värpsjukaste": "värpsjuk",
    "värpsjukastes": "värpsjuk",
    "värpsjukasts": "värpsjuk",
    "värpsjuke": "värpsjuka",
    "värpsjukes": "värpsjuk",
    "värpsjukheten": "värpsjukhet",
    "värpsjukhetens": "värpsjukhet",
    "värpsjukhets": "värpsjukhet",
    "värpsjuks": "värpsjuka",
    "värpsjukt": "värpsjuk",
    "värpsjukts": "värpsjuk",
    "värpt": "värpa",
    "värpta": "värpa",
    "värptas": "värpa",
    "värpte": "värpa",
    "värptes": "värpa",
    "värpts": "värpa",
    "värre": "ond",
    "värres": "ond",
    "värst": "ond",
    "värsta": "ond",
    "värstas": "ond",
    "värste": "ond",
    "värstes": "ond",
    "värstingar": "värsting",
    "värstingarna": "värsting",
    "värstingarnas": "värsting",
    "värstingars": "värsting",
    "värstingen": "värsting",
    "värstingens": "värsting",
    "värstings": "värsting",
    "värsts": "ond",
    "värt": "värd",
    "värts": "värd",
    "värv": "värva",
    "värvad": "värva",
    "värvade": "värva",
    "värvades": "värva",
    "värvads": "värva",
    "värvande": "värva",
    "värvanden": "värvande",
    "värvandena": "värvande",
    "värvandenas": "värvande",
    "värvandens": "värvande",
    "värvandes": "värvande",
    "värvandet": "värvande",
    "värvandets": "värvande",
    "värvar": "värva",
    "värvas": "värva",
    "värvat": "värva",
    "värvats": "värva",
    "värven": "värv",
    "värvens": "värv",
    "värvet": "värv",
    "värvets": "värv",
    "värvningar": "värvning",
    "värvningarna": "värvning",
    "värvningarnas": "värvning",
    "värvningars": "värvning",
    "värvningen": "värvning",
    "värvningens": "värvning",
    "värvnings": "värvning",
    "värvningskampanjen": "värvningskampanj",
    "värvningskampanjens": "värvningskampanj",
    "värvningskampanjer": "värvningskampanj",
    "värvningskampanjerna": "värvningskampanj",
    "värvningskampanjernas": "värvningskampanj",
    "värvningskampanjers": "värvningskampanj",
    "värvningskampanjs": "värvningskampanj",
    "värvs": "värv",
    "väs": "väsa",
    "väsande": "väsa",
    "väsandes": "väsande",
    "väsandet": "väsande",
    "väsandets": "väsande",
    "väsas": "väsa",
    "väsenden": "väsende",
    "väsendena": "väsende",
    "väsendenas": "väsende",
    "väsendens": "väsende",
    "väsendes": "väsende",
    "väsendet": "väsende",
    "väsendets": "väsende",
    "väsenen": "väsen",
    "väsenens": "väsen",
    "väsenet": "väsen",
    "väsenets": "väsen",
    "väsens": "väsen",
    "väsentliga": "väsentlig",
    "väsentligare": "väsentlig",
    "väsentligares": "väsentlig",
    "väsentligas": "väsentlig",
    "väsentligast": "väsentlig",
    "väsentligaste": "väsentlig",
    "väsentligastes": "väsentlig",
    "väsentligasts": "väsentlig",
    "väsentlige": "väsentlig",
    "väsentliges": "väsentlig",
    "väsentligheten": "väsentlighet",
    "väsentlighetens": "väsentlighet",
    "väsentligheter": "väsentlighet",
    "väsentligheterna": "väsentlighet",
    "väsentligheternas": "väsentlighet",
    "väsentligheters": "väsentlighet",
    "väsentlighets": "väsentlighet",
    "väsentligs": "väsentlig",
    "väsentligt": "väsentlig",
    "väsentligts": "väsentlig",
    "väser": "väsa",
    "väses": "väsa",
    "väsk": "väska",
    "väskan": "väska",
    "väskans": "väska",
    "väskas": "väska",
    "väske": "väska",
    "väskor": "väska",
    "väskorna": "väska",
    "väskornas": "väska",
    "väskors": "väska",
    "väskryckar": "väskryckare",
    "väskryckaren": "väskryckare",
    "väskryckarens": "väskryckare",
    "väskryckares": "väskryckare",
    "väskryckarna": "väskryckare",
    "väskryckarnas": "väskryckare",
    "väsnades": "väsnas",
    "väsnats": "väsnas",
    "väsnen": "väsen",
    "väsnens": "väsen",
    "väsnet": "väsen",
    "väsnets": "väsen",
    "väsningar": "väsning",
    "väsningarna": "väsning",
    "väsningarnas": "väsning",
    "väsningars": "väsning",
    "väsningen": "väsning",
    "väsningens": "väsning",
    "väsnings": "väsning",
    "väss": "vässa",
    "vässad": "vässa",
    "vässade": "vässa",
    "vässades": "vässa",
    "vässads": "vässa",
    "vässande": "vässa",
    "vässanden": "vässande",
    "vässandena": "vässande",
    "vässandenas": "vässande",
    "vässandens": "vässande",
    "vässandes": "vässande",
    "vässandet": "vässande",
    "vässandets": "vässande",
    "vässar": "vässa",
    "vässas": "vässa",
    "vässat": "vässa",
    "vässats": "vässa",
    "väst": "väsa",
    "västa": "väsa",
    "västanfläktar": "västanfläkt",
    "västanfläktarna": "västanfläkt",
    "västanfläktarnas": "västanfläkt",
    "västanfläktars": "västanfläkt",
    "västanfläkten": "västanfläkt",
    "västanfläktens": "västanfläkt",
    "västanfläkts": "västanfläkt",
    "västans": "västan",
    "västanvinden": "västanvind",
    "västanvindens": "västanvind",
    "västanvinds": "västanvind",
    "västar": "väst",
    "västarna": "väst",
    "västarnas": "väst",
    "västars": "väst",
    "västas": "väsa",
    "västblocket": "västblock",
    "västblockets": "västblock",
    "västblocks": "västblock",
    "väste": "väsa",
    "västen": "väst",
    "västens": "väst",
    "västerbottningar": "västerbottning",
    "västerbottningarna": "västerbottning",
    "västerbottningarnas": "västerbottning",
    "västerbottningars": "västerbottning",
    "västerbottningen": "västerbottning",
    "västerbottningens": "västerbottning",
    "västerbottnings": "västerbottning",
    "västerbottniska": "västerbottnisk",
    "västerbottniskare": "västerbottnisk",
    "västerbottniskares": "västerbottnisk",
    "västerbottniskas": "västerbottnisk",
    "västerbottniskast": "västerbottnisk",
    "västerbottniskaste": "västerbottnisk",
    "västerbottniskastes": "västerbottnisk",
    "västerbottniskasts": "västerbottnisk",
    "västerbottniske": "västerbottnisk",
    "västerbottniskes": "västerbottnisk",
    "västerbottnisks": "västerbottnisk",
    "västerbottniskt": "västerbottnisk",
    "västerbottniskts": "västerbottnisk",
    "västergökar": "västergök",
    "västergökarna": "västergök",
    "västergökarnas": "västergök",
    "västergökars": "västergök",
    "västergöken": "västergök",
    "västergökens": "västergök",
    "västergöks": "västergök",
    "västerhavet": "västerhav",
    "västerhavets": "västerhav",
    "västerhavs": "västerhav",
    "västerlandet": "västerland",
    "västerlandets": "västerland",
    "västerlands": "västerland",
    "västerländska": "västerländsk",
    "västerländskare": "västerländsk",
    "västerländskares": "västerländsk",
    "västerländskas": "västerländsk",
    "västerländskast": "västerländsk",
    "västerländskaste": "västerländsk",
    "västerländskastes": "västerländsk",
    "västerländskasts": "västerländsk",
    "västerländske": "västerländsk",
    "västerländskes": "västerländsk",
    "västerländsks": "västerländsk",
    "västerländskt": "västerländsk",
    "västerländskts": "västerländsk",
    "västerlänningar": "västerlänning",
    "västerlänningarna": "västerlänning",
    "västerlänningarnas": "västerlänning",
    "västerlänningars": "västerlänning",
    "västerlänningen": "västerlänning",
    "västerlänningens": "västerlänning",
    "västerlännings": "västerlänning",
    "västern": "väster",
    "västerns": "väster",
    "västers": "väster",
    "västeråsgurk": "västeråsgurka",
    "västeråsgurkan": "västeråsgurka",
    "västeråsgurkans": "västeråsgurka",
    "västeråsgurkas": "västeråsgurka",
    "västeråsgurke": "västeråsgurka",
    "västeråsgurkor": "västeråsgurka",
    "västeråsgurkorna": "västeråsgurka",
    "västeråsgurkornas": "västeråsgurka",
    "västeråsgurkors": "västeråsgurka",
    "västeråsgurks": "västeråsgurka",
    "västes": "väsa",
    "västeuropeiska": "västeuropeisk",
    "västeuropeiskare": "västeuropeisk",
    "västeuropeiskares": "västeuropeisk",
    "västeuropeiskas": "västeuropeisk",
    "västeuropeiskast": "västeuropeisk",
    "västeuropeiskaste": "västeuropeisk",
    "västeuropeiskastes": "västeuropeisk",
    "västeuropeiskasts": "västeuropeisk",
    "västeuropeiske": "västeuropeisk",
    "västeuropeiskes": "västeuropeisk",
    "västeuropeisks": "västeuropeisk",
    "västeuropeiskt": "västeuropeisk",
    "västeuropeiskts": "västeuropeisk",
    "västficksformatet": "västficksformat",
    "västficksformatets": "västficksformat",
    "västficksformats": "västficksformat",
    "västgoten": "västgot",
    "västgotens": "västgot",
    "västgoter": "västgot",
    "västgoterna": "västgot",
    "västgoternas": "västgot",
    "västgoters": "västgot",
    "västgotisk": "västgotiska",
    "västgotiska": "västgotisk",
    "västgotiskan": "västgotiska",
    "västgotiskans": "västgotiska",
    "västgotiskare": "västgotisk",
    "västgotiskares": "västgotisk",
    "västgotiskas": "västgotiska",
    "västgotiskast": "västgotisk",
    "västgotiskaste": "västgotisk",
    "västgotiskastes": "västgotisk",
    "västgotiskasts": "västgotisk",
    "västgotiske": "västgotisk",
    "västgotiskes": "västgotisk",
    "västgotisks": "västgotisk",
    "västgotiskt": "västgotisk",
    "västgotiskts": "västgotisk",
    "västgots": "västgot",
    "västgöt": "västgöte",
    "västgötaklimaxar": "västgötaklimax",
    "västgötaklimaxarna": "västgötaklimax",
    "västgötaklimaxarnas": "västgötaklimax",
    "västgötaklimaxars": "västgötaklimax",
    "västgötaklimaxen": "västgötaklimax",
    "västgötaklimaxens": "västgötaklimax",
    "västgötar": "västgöte",
    "västgötarna": "västgöte",
    "västgötarnas": "västgöte",
    "västgötars": "västgöte",
    "västgötaspetsar": "västgötaspets",
    "västgötaspetsarna": "västgötaspets",
    "västgötaspetsarnas": "västgötaspets",
    "västgötaspetsars": "västgötaspets",
    "västgötaspetsen": "västgötaspets",
    "västgötaspetsens": "västgötaspets",
    "västgöten": "västgöte",
    "västgötens": "västgöte",
    "västgötes": "västgöte",
    "västgöts": "västgöte",
    "västgötsk": "västgötska",
    "västgötska": "västgötsk",
    "västgötskan": "västgötska",
    "västgötskans": "västgötska",
    "västgötskare": "västgötsk",
    "västgötskares": "västgötsk",
    "västgötskas": "västgötska",
    "västgötskast": "västgötsk",
    "västgötskaste": "västgötsk",
    "västgötskastes": "västgötsk",
    "västgötskasts": "västgötsk",
    "västgötske": "västgötska",
    "västgötskes": "västgötsk",
    "västgötskor": "västgötska",
    "västgötskorna": "västgötska",
    "västgötskornas": "västgötska",
    "västgötskors": "västgötska",
    "västgötsks": "västgötsk",
    "västgötskt": "västgötsk",
    "västgötskts": "västgötsk",
    "västindiefarar": "västindiefarare",
    "västindiefararen": "västindiefarare",
    "västindiefararens": "västindiefarare",
    "västindiefarares": "västindiefarare",
    "västindiefararna": "västindiefarare",
    "västindiefararnas": "västindiefarare",
    "västindiska": "västindisk",
    "västindiskare": "västindisk",
    "västindiskares": "västindisk",
    "västindiskas": "västindisk",
    "västindiskast": "västindisk",
    "västindiskaste": "västindisk",
    "västindiskastes": "västindisk",
    "västindiskasts": "västindisk",
    "västindiske": "västindisk",
    "västindiskes": "västindisk",
    "västindisks": "västindisk",
    "västindiskt": "västindisk",
    "västindiskts": "västindisk",
    "västklänningar": "västklänning",
    "västklänningarna": "västklänning",
    "västklänningarnas": "västklänning",
    "västklänningars": "västklänning",
    "västklänningen": "västklänning",
    "västklänningens": "västklänning",
    "västklännings": "västklänning",
    "västkritiska": "västkritisk",
    "västkritiskare": "västkritisk",
    "västkritiskares": "västkritisk",
    "västkritiskas": "västkritisk",
    "västkritiskast": "västkritisk",
    "västkritiskaste": "västkritisk",
    "västkritiskastes": "västkritisk",
    "västkritiskasts": "västkritisk",
    "västkritiske": "västkritisk",
    "västkritiskes": "västkritisk",
    "västkritisks": "västkritisk",
    "västkritiskt": "västkritisk",
    "västkritiskts": "västkritisk",
    "västkusten": "västkust",
    "västkustens": "västkust",
    "västkuster": "västkust",
    "västkusterna": "västkust",
    "västkusternas": "västkust",
    "västkusters": "västkust",
    "västkusts": "västkust",
    "västkustsalladen": "västkustsallad",
    "västkustsalladens": "västkustsallad",
    "västkustsallader": "västkustsallad",
    "västkustsalladerna": "västkustsallad",
    "västkustsalladernas": "västkustsallad",
    "västkustsalladers": "västkustsallad",
    "västkustsallads": "västkustsallad",
    "västliga": "västlig",
    "västligare": "västlig",
    "västligares": "västlig",
    "västligas": "västlig",
    "västligast": "västlig",
    "västligaste": "västlig",
    "västligastes": "västlig",
    "västligasts": "västlig",
    "västlige": "västlig",
    "västliges": "västlig",
    "västligs": "västlig",
    "västligt": "västlig",
    "västligts": "västlig",
    "västmakten": "västmakt",
    "västmaktens": "västmakt",
    "västmakter": "västmakt",
    "västmakterna": "västmakt",
    "västmakternas": "västmakt",
    "västmakters": "västmakt",
    "västmakts": "västmakt",
    "västmanländsk": "västmanländska",
    "västmanländska": "västmanländsk",
    "västmanländskan": "västmanländska",
    "västmanländskans": "västmanländska",
    "västmanländskare": "västmanländsk",
    "västmanländskares": "västmanländsk",
    "västmanländskas": "västmanländska",
    "västmanländskast": "västmanländsk",
    "västmanländskaste": "västmanländsk",
    "västmanländskastes": "västmanländsk",
    "västmanländskasts": "västmanländsk",
    "västmanländske": "västmanländska",
    "västmanländskes": "västmanländsk",
    "västmanländskor": "västmanländska",
    "västmanländskorna": "västmanländska",
    "västmanländskornas": "västmanländska",
    "västmanländskors": "västmanländska",
    "västmanländsks": "västmanländsk",
    "västmanländskt": "västmanländsk",
    "västmanländskts": "västmanländsk",
    "västmanlänningar": "västmanlänning",
    "västmanlänningarna": "västmanlänning",
    "västmanlänningarnas": "västmanlänning",
    "västmanlänningars": "västmanlänning",
    "västmanlänningen": "västmanlänning",
    "västmanlänningens": "västmanlänning",
    "västmanlännings": "västmanlänning",
    "västs": "väst",
    "västsamoanen": "västsamoan",
    "västsamoanens": "västsamoan",
    "västsamoaner": "västsamoan",
    "västsamoanerna": "västsamoan",
    "västsamoanernas": "västsamoan",
    "västsamoaners": "västsamoan",
    "västsamoans": "västsamoan",
    "västslaviska": "västslavisk",
    "västslaviskare": "västslavisk",
    "västslaviskares": "västslavisk",
    "västslaviskas": "västslavisk",
    "västslaviskast": "västslavisk",
    "västslaviskaste": "västslavisk",
    "västslaviskastes": "västslavisk",
    "västslaviskasts": "västslavisk",
    "västslaviske": "västslavisk",
    "västslaviskes": "västslavisk",
    "västslavisks": "västslavisk",
    "västslaviskt": "västslavisk",
    "västslaviskts": "västslavisk",
    "västsvenska": "västsvensk",
    "västsvenskare": "västsvensk",
    "västsvenskares": "västsvensk",
    "västsvenskas": "västsvensk",
    "västsvenskast": "västsvensk",
    "västsvenskaste": "västsvensk",
    "västsvenskastes": "västsvensk",
    "västsvenskasts": "västsvensk",
    "västsvenske": "västsvensk",
    "västsvenskes": "västsvensk",
    "västsvensks": "västsvensk",
    "västsvenskt": "västsvensk",
    "västsvenskts": "västsvensk",
    "västtyska": "västtysk",
    "västtyskar": "västtysk",
    "västtyskare": "västtysk",
    "västtyskares": "västtysk",
    "västtyskarna": "västtysk",
    "västtyskarnas": "västtysk",
    "västtyskars": "västtysk",
    "västtyskas": "västtysk",
    "västtyskast": "västtysk",
    "västtyskaste": "västtysk",
    "västtyskastes": "västtysk",
    "västtyskasts": "västtysk",
    "västtyske": "västtysk",
    "västtysken": "västtysk",
    "västtyskens": "västtysk",
    "västtyskes": "västtysk",
    "västtysks": "västtysk",
    "västtyskt": "västtysk",
    "västtyskts": "västtysk",
    "västvindar": "västvind",
    "västvindarna": "västvind",
    "västvindarnas": "västvind",
    "västvindars": "västvind",
    "västvinddriften": "västvinddrift",
    "västvinddriftens": "västvinddrift",
    "västvinddrifts": "västvinddrift",
    "västvinden": "västvind",
    "västvindens": "västvind",
    "västvinds": "västvind",
    "västvärlden": "västvärld",
    "västvärldens": "västvärld",
    "västvärlds": "västvärld",
    "vät": "väta",
    "vätan": "väta",
    "vätande": "väta",
    "vätanden": "vätande",
    "vätandena": "vätande",
    "vätandenas": "vätande",
    "vätandens": "vätande",
    "vätandes": "vätande",
    "vätandet": "vätande",
    "vätandets": "vätande",
    "vätans": "väta",
    "vätas": "väta",
    "väteatomen": "väteatom",
    "väteatomens": "väteatom",
    "väteatomer": "väteatom",
    "väteatomerna": "väteatom",
    "väteatomernas": "väteatom",
    "väteatomers": "väteatom",
    "väteatoms": "väteatom",
    "vätebomben": "vätebomb",
    "vätebombens": "vätebomb",
    "vätebomber": "vätebomb",
    "vätebomberna": "vätebomb",
    "vätebombernas": "vätebomb",
    "vätebombers": "vätebomb",
    "vätebombs": "vätebomb",
    "vätegeneratorer": "vätegenerator",
    "vätegeneratorerna": "vätegenerator",
    "vätegeneratorernas": "vätegenerator",
    "vätegeneratorers": "vätegenerator",
    "vätegeneratorn": "vätegenerator",
    "vätegeneratorns": "vätegenerator",
    "vätegenerators": "vätegenerator",
    "vätejonen": "vätejon",
    "vätejonens": "vätejon",
    "vätejoner": "vätejon",
    "vätejonerna": "vätejon",
    "vätejonernas": "vätejon",
    "vätejoners": "vätejon",
    "vätejonkoncentrationen": "vätejonkoncentration",
    "vätejonkoncentrationens": "vätejonkoncentration",
    "vätejonkoncentrationer": "vätejonkoncentration",
    "vätejonkoncentrationerna": "vätejonkoncentration",
    "vätejonkoncentrationernas": "vätejonkoncentration",
    "vätejonkoncentrationers": "vätejonkoncentration",
    "vätejonkoncentrations": "vätejonkoncentration",
    "vätejons": "vätejon",
    "vätekarbonaten": "vätekarbonat",
    "vätekarbonatens": "vätekarbonat",
    "vätekarbonater": "vätekarbonat",
    "vätekarbonaterna": "vätekarbonat",
    "vätekarbonaternas": "vätekarbonat",
    "vätekarbonaters": "vätekarbonat",
    "vätekarbonatet": "vätekarbonat",
    "vätekarbonatets": "vätekarbonat",
    "vätekarbonatjonen": "vätekarbonatjon",
    "vätekarbonatjonens": "vätekarbonatjon",
    "vätekarbonatjoner": "vätekarbonatjon",
    "vätekarbonatjonerna": "vätekarbonatjon",
    "vätekarbonatjonernas": "vätekarbonatjon",
    "vätekarbonatjoners": "vätekarbonatjon",
    "vätekarbonatjons": "vätekarbonatjon",
    "vätekarbonats": "vätekarbonat",
    "vätekraften": "vätekraft",
    "vätekraftens": "vätekraft",
    "vätekrafts": "vätekraft",
    "vätekärn": "vätekärna",
    "vätekärnan": "vätekärna",
    "vätekärnans": "vätekärna",
    "vätekärnas": "vätekärna",
    "vätekärne": "vätekärna",
    "vätekärnor": "vätekärna",
    "vätekärnorna": "vätekärna",
    "vätekärnornas": "vätekärna",
    "vätekärnors": "vätekärna",
    "vätekärns": "vätekärna",
    "väteperoxiden": "väteperoxid",
    "väteperoxidens": "väteperoxid",
    "väteperoxids": "väteperoxid",
    "väter": "väta",
    "vätes": "väte",
    "vätesulfiden": "vätesulfid",
    "vätesulfidens": "vätesulfid",
    "vätesulfids": "vätesulfid",
    "vätesuperoxiden": "vätesuperoxid",
    "vätesuperoxidens": "vätesuperoxid",
    "vätesuperoxids": "vätesuperoxid",
    "vätet": "väte",
    "vätets": "väte",
    "vätevapens": "vätevapen",
    "vätevapnen": "vätevapen",
    "vätevapnens": "vätevapen",
    "vätevapnet": "vätevapen",
    "vätevapnets": "vätevapen",
    "vätgasbilar": "vätgasbil",
    "vätgasbilarna": "vätgasbil",
    "vätgasbilarnas": "vätgasbil",
    "vätgasbilars": "vätgasbil",
    "vätgasbilen": "vätgasbil",
    "vätgasbilens": "vätgasbil",
    "vätgasbils": "vätgasbil",
    "vätgasdriften": "vätgasdrift",
    "vätgasdriftens": "vätgasdrift",
    "vätgasdrifts": "vätgasdrift",
    "vätgasdrivens": "vätgasdriven",
    "vätgasdrivet": "vätgasdriven",
    "vätgasdrivets": "vätgasdriven",
    "vätgasdrivna": "vätgasdriven",
    "vätgasdrivnas": "vätgasdriven",
    "vätgasdrivne": "vätgasdriven",
    "vätgasdrivnes": "vätgasdriven",
    "vätgasen": "vätgas",
    "vätgasens": "vätgas",
    "vätgashybriden": "vätgashybrid",
    "vätgashybridens": "vätgashybrid",
    "vätgashybrider": "vätgashybrid",
    "vätgashybriderna": "vätgashybrid",
    "vätgashybridernas": "vätgashybrid",
    "vätgashybriders": "vätgashybrid",
    "vätgashybrids": "vätgashybrid",
    "vätgasmolekylen": "vätgasmolekyl",
    "vätgasmolekylens": "vätgasmolekyl",
    "vätgasmolekyler": "vätgasmolekyl",
    "vätgasmolekylerna": "vätgasmolekyl",
    "vätgasmolekylernas": "vätgasmolekyl",
    "vätgasmolekylers": "vätgasmolekyl",
    "vätgasmolekyls": "vätgasmolekyl",
    "vätgasrika": "vätgasrik",
    "vätgasrikare": "vätgasrik",
    "vätgasrikares": "vätgasrik",
    "vätgasrikas": "vätgasrik",
    "vätgasrikast": "vätgasrik",
    "vätgasrikaste": "vätgasrik",
    "vätgasrikastes": "vätgasrik",
    "vätgasrikasts": "vätgasrik",
    "vätgasrike": "vätgasrik",
    "vätgasrikes": "vätgasrik",
    "vätgasrikheten": "vätgasrikhet",
    "vätgasrikhetens": "vätgasrikhet",
    "vätgasrikhets": "vätgasrikhet",
    "vätgasriks": "vätgasrik",
    "vätgasrikt": "vätgasrik",
    "vätgasrikts": "vätgasrik",
    "vätmedels": "vätmedel",
    "vätmedlen": "vätmedel",
    "vätmedlens": "vätmedel",
    "vätmedlet": "vätmedel",
    "vätmedlets": "vätmedel",
    "vätningar": "vätning",
    "vätningarna": "vätning",
    "vätningarnas": "vätning",
    "vätningars": "vätning",
    "vätningen": "vätning",
    "vätningens": "vätning",
    "vätnings": "vätning",
    "väts": "väta",
    "vätsk": "vätska",
    "vätskad": "vätska",
    "vätskade": "vätska",
    "vätskades": "vätskas",
    "vätskads": "vätska",
    "vätskan": "vätska",
    "vätskande": "vätska",
    "vätskanden": "vätskande",
    "vätskandena": "vätskande",
    "vätskandenas": "vätskande",
    "vätskandens": "vätskande",
    "vätskandes": "vätskande",
    "vätskandet": "vätskande",
    "vätskandets": "vätskande",
    "vätskans": "vätska",
    "vätskar": "vätska",
    "vätskas": "vätska",
    "vätskat": "vätska",
    "vätskats": "vätskas",
    "vätske": "vätska",
    "vätskeansamlingar": "vätskeansamling",
    "vätskeansamlingarna": "vätskeansamling",
    "vätskeansamlingarnas": "vätskeansamling",
    "vätskeansamlingars": "vätskeansamling",
    "vätskeansamlingen": "vätskeansamling",
    "vätskeansamlingens": "vätskeansamling",
    "vätskeansamlings": "vätskeansamling",
    "vätskebalansen": "vätskebalans",
    "vätskebalansens": "vätskebalans",
    "vätskefjädringar": "vätskefjädring",
    "vätskefjädringarna": "vätskefjädring",
    "vätskefjädringarnas": "vätskefjädring",
    "vätskefjädringars": "vätskefjädring",
    "vätskefjädringen": "vätskefjädring",
    "vätskefjädringens": "vätskefjädring",
    "vätskefjädrings": "vätskefjädring",
    "vätskefyllda": "vätskefylld",
    "vätskefylldare": "vätskefylld",
    "vätskefylldares": "vätskefylld",
    "vätskefylldas": "vätskefylld",
    "vätskefylldast": "vätskefylld",
    "vätskefylldaste": "vätskefylld",
    "vätskefylldastes": "vätskefylld",
    "vätskefylldasts": "vätskefylld",
    "vätskefyllde": "vätskefylld",
    "vätskefylldes": "vätskefylld",
    "vätskefyllds": "vätskefylld",
    "vätskefyllt": "vätskefylld",
    "vätskefyllts": "vätskefylld",
    "vätskeförlusten": "vätskeförlust",
    "vätskeförlustens": "vätskeförlust",
    "vätskeförluster": "vätskeförlust",
    "vätskeförlusterna": "vätskeförlust",
    "vätskeförlusternas": "vätskeförlust",
    "vätskeförlusters": "vätskeförlust",
    "vätskeförlusts": "vätskeförlust",
    "vätskekulturen": "vätskekultur",
    "vätskekulturens": "vätskekultur",
    "vätskekulturs": "vätskekultur",
    "vätskenivåer": "vätskenivå",
    "vätskenivåerna": "vätskenivå",
    "vätskenivåernas": "vätskenivå",
    "vätskenivåers": "vätskenivå",
    "vätskenivån": "vätskenivå",
    "vätskenivåns": "vätskenivå",
    "vätskenivås": "vätskenivå",
    "vätsketermometern": "vätsketermometer",
    "vätsketermometerns": "vätsketermometer",
    "vätsketermometers": "vätsketermometer",
    "vätsketermometrar": "vätsketermometer",
    "vätsketermometrarna": "vätsketermometer",
    "vätsketermometrarnas": "vätsketermometer",
    "vätsketermometrars": "vätsketermometer",
    "vätsketillförseln": "vätsketillförsel",
    "vätsketillförselns": "vätsketillförsel",
    "vätsketillförsels": "vätsketillförsel",
    "vätskiga": "vätskig",
    "vätskigare": "vätskig",
    "vätskigares": "vätskig",
    "vätskigas": "vätskig",
    "vätskigast": "vätskig",
    "vätskigaste": "vätskig",
    "vätskigastes": "vätskig",
    "vätskigasts": "vätskig",
    "vätskige": "vätskig",
    "vätskiges": "vätskig",
    "vätskigheten": "vätskighet",
    "vätskighetens": "vätskighet",
    "vätskighets": "vätskighet",
    "vätskigs": "vätskig",
    "vätskigt": "vätskig",
    "vätskigts": "vätskig",
    "vätskor": "vätska",
    "vätskorna": "vätska",
    "vätskornas": "vätska",
    "vätskors": "vätska",
    "vätt": "vätte",
    "vätta": "väta",
    "vättar": "vätte",
    "vättarna": "vätte",
    "vättarnas": "vätte",
    "vättars": "vätte",
    "vättas": "väta",
    "vätte": "väta",
    "vätteljusen": "vätteljus",
    "vätteljusens": "vätteljus",
    "vätteljuset": "vätteljus",
    "vätteljusets": "vätteljus",
    "vätten": "vätte",
    "vättens": "vätte",
    "vätterosen": "vätteros",
    "vätterosens": "vätteros",
    "vätterosor": "vätteros",
    "vätterosorna": "vätteros",
    "vätterosornas": "vätteros",
    "vätterosors": "vätteros",
    "vätterrödingar": "vätterröding",
    "vätterrödingarna": "vätterröding",
    "vätterrödingarnas": "vätterröding",
    "vätterrödingars": "vätterröding",
    "vätterrödingen": "vätterröding",
    "vätterrödingens": "vätterröding",
    "vätterrödings": "vätterröding",
    "vättes": "vätte",
    "vätts": "vätte",
    "väv": "väva",
    "vävande": "väva",
    "vävanden": "vävande",
    "vävandena": "vävande",
    "vävandenas": "vävande",
    "vävandens": "vävande",
    "vävandes": "vävande",
    "vävandet": "vävande",
    "vävandets": "vävande",
    "vävar": "vävare",
    "vävaren": "vävare",
    "vävarens": "vävare",
    "vävares": "vävare",
    "vävarfinkar": "vävarfink",
    "vävarfinkarna": "vävarfink",
    "vävarfinkarnas": "vävarfink",
    "vävarfinkars": "vävarfink",
    "vävarfinken": "vävarfink",
    "vävarfinkens": "vävarfink",
    "vävarfinks": "vävarfink",
    "vävarfågeln": "vävarfågel",
    "vävarfågelns": "vävarfågel",
    "vävarfågels": "vävarfågel",
    "vävarfåglar": "vävarfågel",
    "vävarfåglarna": "vävarfågel",
    "vävarfåglarnas": "vävarfågel",
    "vävarfåglars": "vävarfågel",
    "vävarna": "vävare",
    "vävarnas": "vävare",
    "vävars": "väv",
    "vävarstar": "vävarstare",
    "vävarstarar": "vävarstare",
    "vävarstararna": "vävarstare",
    "vävarstararnas": "vävarstare",
    "vävarstarars": "vävarstare",
    "vävarstaren": "vävarstare",
    "vävarstarens": "vävarstare",
    "vävarstares": "vävarstare",
    "vävarstars": "vävarstare",
    "vävas": "väva",
    "vävbindningar": "vävbindning",
    "vävbindningarna": "vävbindning",
    "vävbindningarnas": "vävbindning",
    "vävbindningars": "vävbindning",
    "vävbindningen": "vävbindning",
    "vävbindningens": "vävbindning",
    "vävbindnings": "vävbindning",
    "vävburens": "vävburen",
    "vävburet": "vävburen",
    "vävburets": "vävburen",
    "vävburna": "vävburen",
    "vävburnare": "vävburen",
    "vävburnares": "vävburen",
    "vävburnas": "vävburen",
    "vävburnast": "vävburen",
    "vävburnaste": "vävburen",
    "vävburnastes": "vävburen",
    "vävburnasts": "vävburen",
    "vävburne": "vävburen",
    "vävburnes": "vävburen",
    "vävd": "väva",
    "vävda": "väva",
    "vävdas": "väva",
    "vävde": "väva",
    "vävdes": "väva",
    "vävds": "väva",
    "väven": "väv",
    "vävens": "väv",
    "väver": "väva",
    "väverier": "väveri",
    "väverierna": "väveri",
    "väveriernas": "väveri",
    "väveriers": "väveri",
    "väveriet": "väveri",
    "väveriets": "väveri",
    "väveris": "väveri",
    "väverit": "väveri",
    "väverits": "väveri",
    "väverskan": "väverska",
    "väverskans": "väverska",
    "väverskas": "väverska",
    "väverske": "väverska",
    "väverskor": "väverska",
    "väverskorna": "väverska",
    "väverskornas": "väverska",
    "väverskors": "väverska",
    "väves": "väva",
    "vävkammar": "vävkam",
    "vävkammarna": "vävkam",
    "vävkammarnas": "vävkam",
    "vävkammars": "vävkam",
    "vävkammen": "vävkam",
    "vävkammens": "vävkam",
    "vävkams": "vävkam",
    "vävknutar": "vävknut",
    "vävknutarna": "vävknut",
    "vävknutarnas": "vävknut",
    "vävknutars": "vävknut",
    "vävknuten": "vävknut",
    "vävknutens": "vävknut",
    "vävknuts": "vävknut",
    "vävkäppar": "vävkäpp",
    "vävkäpparna": "vävkäpp",
    "vävkäpparnas": "vävkäpp",
    "vävkäppars": "vävkäpp",
    "vävkäppen": "vävkäpp",
    "vävkäppens": "vävkäpp",
    "vävkäpps": "vävkäpp",
    "vävnaden": "vävnad",
    "vävnadens": "vävnad",
    "vävnader": "vävnad",
    "vävnaderna": "vävnad",
    "vävnadernas": "vävnad",
    "vävnaders": "vävnad",
    "vävnads": "vävnad",
    "vävnadsodlingar": "vävnadsodling",
    "vävnadsodlingarna": "vävnadsodling",
    "vävnadsodlingarnas": "vävnadsodling",
    "vävnadsodlingars": "vävnadsodling",
    "vävnadsodlingen": "vävnadsodling",
    "vävnadsodlingens": "vävnadsodling",
    "vävnadsodlings": "vävnadsodling",
    "vävnadsproven": "vävnadsprov",
    "vävnadsprovens": "vävnadsprov",
    "vävnadsprover": "vävnadsprov",
    "vävnadsproverna": "vävnadsprov",
    "vävnadsprovernas": "vävnadsprov",
    "vävnadsprovers": "vävnadsprov",
    "vävnadsprovet": "vävnadsprov",
    "vävnadsprovets": "vävnadsprov",
    "vävnadsprovs": "vävnadsprov",
    "vävnadsvätskan": "vävnadsvätska",
    "vävnadsvätskans": "vävnadsvätska",
    "vävnadsvätskas": "vävnadsvätska",
    "vävnadsvätske": "vävnadsvätska",
    "vävningar": "vävning",
    "vävningarna": "vävning",
    "vävningarnas": "vävning",
    "vävningars": "vävning",
    "vävningen": "vävning",
    "vävningens": "vävning",
    "vävnings": "vävning",
    "vävningsmönsterna": "vävningsmönster",
    "vävningsmönsternas": "vävningsmönster",
    "vävningsmönsters": "vävningsmönster",
    "vävningsmönstren": "vävningsmönster",
    "vävningsmönstrens": "vävningsmönster",
    "vävningsmönstret": "vävningsmönster",
    "vävningsmönstrets": "vävningsmönster",
    "vävplasten": "vävplast",
    "vävplastens": "vävplast",
    "vävplaster": "vävplast",
    "vävplasterna": "vävplast",
    "vävplasternas": "vävplast",
    "vävplasters": "vävplast",
    "vävplasts": "vävplast",
    "vävs": "väva",
    "vävskaften": "vävskaft",
    "vävskaftens": "vävskaft",
    "vävskaftet": "vävskaft",
    "vävskaftets": "vävskaft",
    "vävskafts": "vävskaft",
    "vävskedar": "vävsked",
    "vävskedarna": "vävsked",
    "vävskedarnas": "vävsked",
    "vävskedars": "vävsked",
    "vävskeden": "vävsked",
    "vävskedens": "vävsked",
    "vävskeds": "vävsked",
    "vävskytteln": "vävskyttel",
    "vävskyttelns": "vävskyttel",
    "vävskyttels": "vävskyttel",
    "vävskyttlar": "vävskyttel",
    "vävskyttlarna": "vävskyttel",
    "vävskyttlarnas": "vävskyttel",
    "vävskyttlars": "vävskyttel",
    "vävskälen": "vävskäl",
    "vävskälens": "vävskäl",
    "vävskälet": "vävskäl",
    "vävskälets": "vävskäl",
    "vävskäls": "vävskäl",
    "vävsolven": "vävsolv",
    "vävsolvens": "vävsolv",
    "vävsolvet": "vävsolv",
    "vävsolvets": "vävsolv",
    "vävsolvs": "vävsolv",
    "vävspännar": "vävspännare",
    "vävspännaren": "vävspännare",
    "vävspännarens": "vävspännare",
    "vävspännares": "vävspännare",
    "vävspännarna": "vävspännare",
    "vävspännarnas": "vävspännare",
    "vävstolar": "vävstol",
    "vävstolarna": "vävstol",
    "vävstolarnas": "vävstol",
    "vävstolars": "vävstol",
    "vävstolen": "vävstol",
    "vävstolens": "vävstol",
    "vävstols": "vävstol",
    "vävt": "väva",
    "vävts": "väva",
    "vävtyngden": "vävtyngd",
    "vävtyngdens": "vävtyngd",
    "vävtyngder": "vävtyngd",
    "vävtyngderna": "vävtyngd",
    "vävtyngdernas": "vävtyngd",
    "vävtyngders": "vävtyngd",
    "vävtyngds": "vävtyngd",
    "väx": "växa",
    "växande": "växa",
    "växanden": "växande",
    "växandena": "växande",
    "växandenas": "växande",
    "växandens": "växande",
    "växandes": "växande",
    "växandet": "växande",
    "växandets": "växande",
    "växe": "växa",
    "växel": "växla",
    "växelaccepten": "växelaccept",
    "växelacceptens": "växelaccept",
    "växelaccepter": "växelaccept",
    "växelaccepterna": "växelaccept",
    "växelaccepternas": "växelaccept",
    "växelaccepters": "växelaccept",
    "växelaccepts": "växelaccept",
    "växelaffären": "växelaffär",
    "växelaffärens": "växelaffär",
    "växelaffärer": "växelaffär",
    "växelaffärerna": "växelaffär",
    "växelaffärernas": "växelaffär",
    "växelaffärers": "växelaffär",
    "växelaffärs": "växelaffär",
    "växelborden": "växelbord",
    "växelbordens": "växelbord",
    "växelbordet": "växelbord",
    "växelbordets": "växelbord",
    "växelbords": "växelbord",
    "växelborgens": "växelborgen",
    "växelbruket": "växelbruk",
    "växelbrukets": "växelbruk",
    "växelbruks": "växelbruk",
    "växeldiskonten": "växeldiskont",
    "växeldiskontens": "växeldiskont",
    "växeldiskonter": "växeldiskont",
    "växeldiskonterna": "växeldiskont",
    "växeldiskonternas": "växeldiskont",
    "växeldiskonters": "växeldiskont",
    "växeldiskonton": "växeldiskonto",
    "växeldiskontona": "växeldiskonto",
    "växeldiskontonas": "växeldiskonto",
    "växeldiskontons": "växeldiskonto",
    "växeldiskontos": "växeldiskonto",
    "växeldiskontot": "växeldiskonto",
    "växeldiskontots": "växeldiskonto",
    "växeldiskonts": "växeldiskont",
    "växelfordrans": "växelfordran",
    "växelfordringar": "växelfordran",
    "växelfordringarna": "växelfordran",
    "växelfordringarnas": "växelfordran",
    "växelfordringars": "växelfordran",
    "växelförreglingar": "växelförregling",
    "växelförreglingarna": "växelförregling",
    "växelförreglingarnas": "växelförregling",
    "växelförreglingars": "växelförregling",
    "växelförreglingen": "växelförregling",
    "växelförreglingens": "växelförregling",
    "växelförreglings": "växelförregling",
    "växelgivar": "växelgivare",
    "växelgivaren": "växelgivare",
    "växelgivarens": "växelgivare",
    "växelgivares": "växelgivare",
    "växelgivarna": "växelgivare",
    "växelgivarnas": "växelgivare",
    "växelgäldenären": "växelgäldenär",
    "växelgäldenärens": "växelgäldenär",
    "växelgäldenärer": "växelgäldenär",
    "växelgäldenärerna": "växelgäldenär",
    "växelgäldenärernas": "växelgäldenär",
    "växelgäldenärers": "växelgäldenär",
    "växelgäldenärs": "växelgäldenär",
    "växelkassan": "växelkassa",
    "växelkassans": "växelkassa",
    "växelkassas": "växelkassa",
    "växelkasse": "växelkassa",
    "växelkassor": "växelkassa",
    "växelkassorna": "växelkassa",
    "växelkassornas": "växelkassa",
    "växelkassors": "växelkassa",
    "växelkontoren": "växelkontor",
    "växelkontorens": "växelkontor",
    "växelkontoret": "växelkontor",
    "växelkontorets": "växelkontor",
    "växelkontors": "växelkontor",
    "växelkrediten": "växelkredit",
    "växelkreditens": "växelkredit",
    "växelkrediter": "växelkredit",
    "växelkrediterna": "växelkredit",
    "växelkrediternas": "växelkredit",
    "växelkrediters": "växelkredit",
    "växelkredits": "växelkredit",
    "växelkursen": "växelkurs",
    "växelkursens": "växelkurs",
    "växelkurser": "växelkurs",
    "växelkurserna": "växelkurs",
    "växelkursernas": "växelkurs",
    "växelkursers": "växelkurs",
    "växelloken": "växellok",
    "växellokens": "växellok",
    "växelloket": "växellok",
    "växellokets": "växellok",
    "växelloks": "växellok",
    "växelläsningar": "växelläsning",
    "växelläsningarna": "växelläsning",
    "växelläsningarnas": "växelläsning",
    "växelläsningars": "växelläsning",
    "växelläsningen": "växelläsning",
    "växelläsningens": "växelläsning",
    "växelläsnings": "växelläsning",
    "växellåd": "växellåda",
    "växellådan": "växellåda",
    "växellådans": "växellåda",
    "växellådas": "växellåda",
    "växellåde": "växellåda",
    "växellådor": "växellåda",
    "växellådorna": "växellåda",
    "växellådornas": "växellåda",
    "växellådors": "växellåda",
    "växellåds": "växellåda",
    "växellådslyftar": "växellådslyft",
    "växellådslyftarna": "växellådslyft",
    "växellådslyftarnas": "växellådslyft",
    "växellådslyftars": "växellådslyft",
    "växellådslyften": "växellådslyft",
    "växellådslyftens": "växellådslyft",
    "växellådslyfts": "växellådslyft",
    "växelmynten": "växelmynt",
    "växelmyntens": "växelmynt",
    "växelmyntet": "växelmynt",
    "växelmyntets": "växelmynt",
    "växelmynts": "växelmynt",
    "växeln": "växel",
    "växelns": "växel",
    "växelomsättningar": "växelomsättning",
    "växelomsättningarna": "växelomsättning",
    "växelomsättningarnas": "växelomsättning",
    "växelomsättningars": "växelomsättning",
    "växelomsättningen": "växelomsättning",
    "växelomsättningens": "växelomsättning",
    "växelomsättnings": "växelomsättning",
    "växelryttar": "växelryttare",
    "växelryttaren": "växelryttare",
    "växelryttarens": "växelryttare",
    "växelryttares": "växelryttare",
    "växelryttarna": "växelryttare",
    "växelryttarnas": "växelryttare",
    "växelrytteriet": "växelrytteri",
    "växelrytteriets": "växelrytteri",
    "växelrytteris": "växelrytteri",
    "växelrytterit": "växelrytteri",
    "växelrytterits": "växelrytteri",
    "växels": "växel",
    "växelspakar": "växelspak",
    "växelspakarna": "växelspak",
    "växelspakarnas": "växelspak",
    "växelspakars": "växelspak",
    "växelspaken": "växelspak",
    "växelspakens": "växelspak",
    "växelspaks": "växelspak",
    "växelspelen": "växelspel",
    "växelspelens": "växelspel",
    "växelspelet": "växelspel",
    "växelspelets": "växelspel",
    "växelspels": "växelspel",
    "växelspänningar": "växelspänning",
    "växelspänningarna": "växelspänning",
    "växelspänningarnas": "växelspänning",
    "växelspänningars": "växelspänning",
    "växelspänningen": "växelspänning",
    "växelspänningens": "växelspänning",
    "växelspännings": "växelspänning",
    "växelspåren": "växelspår",
    "växelspårens": "växelspår",
    "växelspåret": "växelspår",
    "växelspårets": "växelspår",
    "växelspårs": "växelspår",
    "växelströmmar": "växelström",
    "växelströmmarna": "växelström",
    "växelströmmarnas": "växelström",
    "växelströmmars": "växelström",
    "växelströmmen": "växelström",
    "växelströmmens": "växelström",
    "växelströms": "växelström",
    "växelställen": "växelställ",
    "växelställens": "växelställ",
    "växelstället": "växelställ",
    "växelställets": "växelställ",
    "växelställs": "växelställ",
    "växelställverken": "växelställverk",
    "växelställverkens": "växelställverk",
    "växelställverket": "växelställverk",
    "växelställverkets": "växelställverk",
    "växelställverks": "växelställverk",
    "växelsången": "växelsång",
    "växelsångens": "växelsång",
    "växelsånger": "växelsång",
    "växelsångerna": "växelsång",
    "växelsångernas": "växelsång",
    "växelsångers": "växelsång",
    "växelsångs": "växelsång",
    "växeltrassaten": "växeltrassat",
    "växeltrassatens": "växeltrassat",
    "växeltrassater": "växeltrassat",
    "växeltrassaterna": "växeltrassat",
    "växeltrassaternas": "växeltrassat",
    "växeltrassaters": "växeltrassat",
    "växeltrassats": "växeltrassat",
    "växeltrassenten": "växeltrassent",
    "växeltrassentens": "växeltrassent",
    "växeltrassenter": "växeltrassent",
    "växeltrassenterna": "växeltrassent",
    "växeltrassenternas": "växeltrassent",
    "växeltrassenters": "växeltrassent",
    "växeltrassents": "växeltrassent",
    "växeltungan": "växeltunga",
    "växeltungans": "växeltunga",
    "växeltungas": "växeltunga",
    "växeltunge": "växeltunga",
    "växeltungo": "växeltunga",
    "växeltungor": "växeltunga",
    "växeltungorna": "växeltunga",
    "växeltungornas": "växeltunga",
    "växeltungors": "växeltunga",
    "växelundervisningar": "växelundervisning",
    "växelundervisningarna": "växelundervisning",
    "växelundervisningarnas": "växelundervisning",
    "växelundervisningars": "växelundervisning",
    "växelundervisningen": "växelundervisning",
    "växelundervisningens": "växelundervisning",
    "växelundervisnings": "växelundervisning",
    "växelutställar": "växelutställare",
    "växelutställaren": "växelutställare",
    "växelutställarens": "växelutställare",
    "växelutställares": "växelutställare",
    "växelutställarna": "växelutställare",
    "växelutställarnas": "växelutställare",
    "växelvarma": "växelvarm",
    "växelvarmare": "växelvarm",
    "växelvarmares": "växelvarm",
    "växelvarmas": "växelvarm",
    "växelvarmast": "växelvarm",
    "växelvarmaste": "växelvarm",
    "växelvarmastes": "växelvarm",
    "växelvarmasts": "växelvarm",
    "växelvarme": "växelvarm",
    "växelvarmes": "växelvarm",
    "växelvarms": "växelvarm",
    "växelvarmt": "växelvarm",
    "växelvarmts": "växelvarm",
    "växelverk": "växelverka",
    "växelverkad": "växelverka",
    "växelverkade": "växelverka",
    "växelverkades": "växelverka",
    "växelverkads": "växelverka",
    "växelverkande": "växelverka",
    "växelverkanden": "växelverkande",
    "växelverkandena": "växelverkande",
    "växelverkandenas": "växelverkande",
    "växelverkandens": "växelverkande",
    "växelverkandes": "växelverkande",
    "växelverkandet": "växelverkande",
    "växelverkandets": "växelverkande",
    "växelverkans": "växelverkan",
    "växelverkar": "växelverka",
    "växelverkas": "växelverka",
    "växelverkat": "växelverka",
    "växelverkats": "växelverka",
    "växer": "växa",
    "växkraften": "växkraft",
    "växkraftens": "växkraft",
    "växkrafts": "växkraft",
    "växlad": "växla",
    "växlade": "växla",
    "växlades": "växla",
    "växlads": "växla",
    "växlande": "växla",
    "växlanden": "växlande",
    "växlandena": "växlande",
    "växlandenas": "växlande",
    "växlandens": "växlande",
    "växlandes": "växlande",
    "växlandet": "växlande",
    "växlandets": "växlande",
    "växlar": "växlare",
    "växlaren": "växlare",
    "växlarens": "växlare",
    "växlares": "växlare",
    "växlarna": "växlare",
    "växlarnas": "växlare",
    "växlars": "växel",
    "växlas": "växla",
    "växlat": "växla",
    "växlats": "växla",
    "växlingar": "växling",
    "växlingarna": "växling",
    "växlingarnas": "växling",
    "växlingars": "växling",
    "växlingen": "växling",
    "växlingens": "växling",
    "växlings": "växling",
    "växlingsloken": "växlingslok",
    "växlingslokens": "växlingslok",
    "växlingsloket": "växlingslok",
    "växlingslokets": "växlingslok",
    "växlingsloks": "växlingslok",
    "växlingsrika": "växlingsrik",
    "växlingsrikare": "växlingsrik",
    "växlingsrikares": "växlingsrik",
    "växlingsrikas": "växlingsrik",
    "växlingsrikast": "växlingsrik",
    "växlingsrikaste": "växlingsrik",
    "växlingsrikastes": "växlingsrik",
    "växlingsrikasts": "växlingsrik",
    "växlingsrike": "växlingsrik",
    "växlingsrikes": "växlingsrik",
    "växlingsrikheten": "växlingsrikhet",
    "växlingsrikhetens": "växlingsrikhet",
    "växlingsrikhets": "växlingsrikhet",
    "växlingsriks": "växlingsrik",
    "växlingsrikt": "växlingsrik",
    "växlingsrikts": "växlingsrik",
    "växt": "växa",
    "växtarten": "växtart",
    "växtartens": "växtart",
    "växtarter": "växtart",
    "växtarterna": "växtart",
    "växtarternas": "växtart",
    "växtarters": "växtart",
    "växtarts": "växtart",
    "växtbasen": "växtbas",
    "växtbasens": "växtbas",
    "växtbaser": "växtbas",
    "växtbaserna": "växtbas",
    "växtbasernas": "växtbas",
    "växtbasers": "växtbas",
    "växtcellen": "växtcell",
    "växtcellens": "växtcell",
    "växtceller": "växtcell",
    "växtcellerna": "växtcell",
    "växtcellernas": "växtcell",
    "växtcellers": "växtcell",
    "växtcells": "växtcell",
    "växtdelar": "växtdel",
    "växtdelarna": "växtdel",
    "växtdelarnas": "växtdel",
    "växtdelars": "växtdel",
    "växtdelen": "växtdel",
    "växtdelens": "växtdel",
    "växtdels": "växtdel",
    "växte": "växa",
    "växten": "växt",
    "växtens": "växt",
    "växter": "växt",
    "växterna": "växt",
    "växternas": "växt",
    "växters": "växt",
    "växtfamiljen": "växtfamilj",
    "växtfamiljens": "växtfamilj",
    "växtfamiljer": "växtfamilj",
    "växtfamiljerna": "växtfamilj",
    "växtfamiljernas": "växtfamilj",
    "växtfamiljers": "växtfamilj",
    "växtfamiljs": "växtfamilj",
    "växtfetter": "växtfett",
    "växtfetterna": "växtfett",
    "växtfetternas": "växtfett",
    "växtfetters": "växtfett",
    "växtfettet": "växtfett",
    "växtfettets": "växtfett",
    "växtfetts": "växtfett",
    "växtfibern": "växtfiber",
    "växtfiberns": "växtfiber",
    "växtfibers": "växtfiber",
    "växtfibrer": "växtfiber",
    "växtfibrerna": "växtfiber",
    "växtfibrernas": "växtfiber",
    "växtfibrers": "växtfiber",
    "växtfärgen": "växtfärg",
    "växtfärgens": "växtfärg",
    "växtfärger": "växtfärg",
    "växtfärgerna": "växtfärg",
    "växtfärgernas": "växtfärg",
    "växtfärgers": "växtfärg",
    "växtfärgningar": "växtfärgning",
    "växtfärgningarna": "växtfärgning",
    "växtfärgningarnas": "växtfärgning",
    "växtfärgningars": "växtfärgning",
    "växtfärgningen": "växtfärgning",
    "växtfärgningens": "växtfärgning",
    "växtfärgnings": "växtfärgning",
    "växtfärgs": "växtfärg",
    "växtföljden": "växtföljd",
    "växtföljdens": "växtföljd",
    "växtföljder": "växtföljd",
    "växtföljderna": "växtföljd",
    "växtföljdernas": "växtföljd",
    "växtföljders": "växtföljd",
    "växtföljds": "växtföljd",
    "växtförädlingar": "växtförädling",
    "växtförädlingarna": "växtförädling",
    "växtförädlingarnas": "växtförädling",
    "växtförädlingars": "växtförädling",
    "växtförädlingen": "växtförädling",
    "växtförädlingens": "växtförädling",
    "växtförädlings": "växtförädling",
    "växtgeografien": "växtgeografi",
    "växtgeografiens": "växtgeografi",
    "växtgeografin": "växtgeografi",
    "växtgeografins": "växtgeografi",
    "växtgeografis": "växtgeografi",
    "växtgifter": "växtgift",
    "växtgifterna": "växtgift",
    "växtgifternas": "växtgift",
    "växtgifters": "växtgift",
    "växtgiftet": "växtgift",
    "växtgiftets": "växtgift",
    "växtgifts": "växtgift",
    "växtgränsen": "växtgräns",
    "växtgränsens": "växtgräns",
    "växtgränser": "växtgräns",
    "växtgränserna": "växtgräns",
    "växtgränsernas": "växtgräns",
    "växtgränsers": "växtgräns",
    "växtgummis": "växtgummi",
    "växtgummit": "växtgummi",
    "växtgummits": "växtgummi",
    "växthormonen": "växthormon",
    "växthormonens": "växthormon",
    "växthormoner": "växthormon",
    "växthormonerna": "växthormon",
    "växthormonernas": "växthormon",
    "växthormoners": "växthormon",
    "växthormonet": "växthormon",
    "växthormonets": "växthormon",
    "växthormons": "växthormon",
    "växthuseffekten": "växthuseffekt",
    "växthuseffektens": "växthuseffekt",
    "växthuseffekts": "växthuseffekt",
    "växthusen": "växthus",
    "växthusens": "växthus",
    "växthuset": "växthus",
    "växthusets": "växthus",
    "växthusgasen": "växthusgas",
    "växthusgasens": "växthusgas",
    "växthusgaser": "växthusgas",
    "växthusgaserna": "växthusgas",
    "växthusgasernas": "växthusgas",
    "växthusgasers": "växthusgas",
    "växthusodlingar": "växthusodling",
    "växthusodlingarna": "växthusodling",
    "växthusodlingarnas": "växthusodling",
    "växthusodlingars": "växthusodling",
    "växthusodlingen": "växthusodling",
    "växthusodlingens": "växthusodling",
    "växthusodlings": "växthusodling",
    "växthustaken": "växthustak",
    "växthustakens": "växthustak",
    "växthustaket": "växthustak",
    "växthustakets": "växthustak",
    "växthustaks": "växthustak",
    "växtkraften": "växtkraft",
    "växtkraftens": "växtkraft",
    "växtkraftiga": "växtkraftig",
    "växtkraftigare": "växtkraftig",
    "växtkraftigares": "växtkraftig",
    "växtkraftigas": "växtkraftig",
    "växtkraftigast": "växtkraftig",
    "växtkraftigaste": "växtkraftig",
    "växtkraftigastes": "växtkraftig",
    "växtkraftigasts": "växtkraftig",
    "växtkraftige": "växtkraftig",
    "växtkraftiges": "växtkraftig",
    "växtkraftigheten": "växtkraftighet",
    "växtkraftighetens": "växtkraftighet",
    "växtkraftighets": "växtkraftighet",
    "växtkraftigs": "växtkraftig",
    "växtkraftigt": "växtkraftig",
    "växtkraftigts": "växtkraftig",
    "växtkrafts": "växtkraft",
    "växtliga": "växtlig",
    "växtligare": "växtlig",
    "växtligares": "växtlig",
    "växtligas": "växtlig",
    "växtligast": "växtlig",
    "växtligaste": "växtlig",
    "växtligastes": "växtlig",
    "växtligasts": "växtlig",
    "växtlige": "växtlig",
    "växtliges": "växtlig",
    "växtligheten": "växtlighet",
    "växtlighetens": "växtlighet",
    "växtligheter": "växtlighet",
    "växtligheterna": "växtlighet",
    "växtligheternas": "växtlighet",
    "växtligheters": "växtlighet",
    "växtlighets": "växtlighet",
    "växtligs": "växtlig",
    "växtligt": "växtlig",
    "växtligts": "växtlig",
    "växtlimmen": "växtlim",
    "växtlimmens": "växtlim",
    "växtlimmer": "växtlim",
    "växtlimmerna": "växtlim",
    "växtlimmernas": "växtlim",
    "växtlimmers": "växtlim",
    "växtlimmet": "växtlim",
    "växtlimmets": "växtlim",
    "växtlims": "växtlim",
    "växtlivet": "växtliv",
    "växtlivets": "växtliv",
    "växtlivs": "växtliv",
    "växtlokalen": "växtlokal",
    "växtlokalens": "växtlokal",
    "växtlokaler": "växtlokal",
    "växtlokalerna": "växtlokal",
    "växtlokalernas": "växtlokal",
    "växtlokalers": "växtlokal",
    "växtlokals": "växtlokal",
    "växtmargarinen": "växtmargarin",
    "växtmargarinens": "växtmargarin",
    "växtmargariner": "växtmargarin",
    "växtmargarinerna": "växtmargarin",
    "växtmargarinernas": "växtmargarin",
    "växtmargariners": "växtmargarin",
    "växtmargarinet": "växtmargarin",
    "växtmargarinets": "växtmargarin",
    "växtmargarins": "växtmargarin",
    "växtnäringar": "växtnäring",
    "växtnäringarna": "växtnäring",
    "växtnäringarnas": "växtnäring",
    "växtnäringars": "växtnäring",
    "växtnäringen": "växtnäring",
    "växtnäringens": "växtnäring",
    "växtnärings": "växtnäring",
    "växtperioden": "växtperiod",
    "växtperiodens": "växtperiod",
    "växtperioder": "växtperiod",
    "växtperioderna": "växtperiod",
    "växtperiodernas": "växtperiod",
    "växtperioders": "växtperiod",
    "växtperiods": "växtperiod",
    "växtplanktonen": "växtplankton",
    "växtplanktonens": "växtplankton",
    "växtplanktonet": "växtplankton",
    "växtplanktonets": "växtplankton",
    "växtplanktons": "växtplankton",
    "växtplatsen": "växtplats",
    "växtplatsens": "växtplats",
    "växtplatser": "växtplats",
    "växtplatserna": "växtplats",
    "växtplatsernas": "växtplats",
    "växtplatsers": "växtplats",
    "växtpressar": "växtpress",
    "växtpressarna": "växtpress",
    "växtpressarnas": "växtpress",
    "växtpressars": "växtpress",
    "växtpressen": "växtpress",
    "växtpressens": "växtpress",
    "växtrikes": "växtrike",
    "växtriket": "växtrike",
    "växtrikets": "växtrike",
    "växtrörelsen": "växtrörelse",
    "växtrörelsens": "växtrörelse",
    "växtrörelses": "växtrörelse",
    "växts": "växt",
    "växtsaften": "växtsaft",
    "växtsaftens": "växtsaft",
    "växtsafter": "växtsaft",
    "växtsafterna": "växtsaft",
    "växtsafternas": "växtsaft",
    "växtsafters": "växtsaft",
    "växtsafts": "växtsaft",
    "växtsamhällen": "växtsamhälle",
    "växtsamhällena": "växtsamhälle",
    "växtsamhällenas": "växtsamhälle",
    "växtsamhällens": "växtsamhälle",
    "växtsamhälles": "växtsamhälle",
    "växtsamhället": "växtsamhälle",
    "växtsamhällets": "växtsamhälle",
    "växtsamhälls": "växtsamhälle",
    "växtsamlar": "växtsamlare",
    "växtsamlaren": "växtsamlare",
    "växtsamlarens": "växtsamlare",
    "växtsamlares": "växtsamlare",
    "växtsamlarna": "växtsamlare",
    "växtsamlarnas": "växtsamlare",
    "växtsilkes": "växtsilke",
    "växtsilket": "växtsilke",
    "växtsilkets": "växtsilke",
    "växtsjukdomar": "växtsjukdom",
    "växtsjukdomarna": "växtsjukdom",
    "växtsjukdomarnas": "växtsjukdom",
    "växtsjukdomars": "växtsjukdom",
    "växtsjukdomen": "växtsjukdom",
    "växtsjukdomens": "växtsjukdom",
    "växtsjukdoms": "växtsjukdom",
    "växtskotten": "växtskott",
    "växtskottens": "växtskott",
    "växtskottet": "växtskott",
    "växtskottets": "växtskott",
    "växtskotts": "växtskott",
    "växtskyddet": "växtskydd",
    "växtskyddets": "växtskydd",
    "växtskydds": "växtskydd",
    "växtskyddsmedels": "växtskyddsmedel",
    "växtskyddsmedlen": "växtskyddsmedel",
    "växtskyddsmedlens": "växtskyddsmedel",
    "växtskyddsmedlet": "växtskyddsmedel",
    "växtskyddsmedlets": "växtskyddsmedel",
    "växtslemmet": "växtslem",
    "växtslemmets": "växtslem",
    "växtslems": "växtslem",
    "växtsläkten": "växtsläkte",
    "växtsläktena": "växtsläkte",
    "växtsläktenas": "växtsläkte",
    "växtsläktens": "växtsläkte",
    "växtsläktes": "växtsläkte",
    "växtsläktet": "växtsläkte",
    "växtsläktets": "växtsläkte",
    "växtsläkts": "växtsläkte",
    "växtstammar": "växtstam",
    "växtstammarna": "växtstam",
    "växtstammarnas": "växtstam",
    "växtstammars": "växtstam",
    "växtstammen": "växtstam",
    "växtstammens": "växtstam",
    "växtstams": "växtstam",
    "växtstekeln": "växtstekel",
    "växtstekelns": "växtstekel",
    "växtstekels": "växtstekel",
    "växtsteklar": "växtstekel",
    "växtsteklarna": "växtstekel",
    "växtsteklarnas": "växtstekel",
    "växtsteklars": "växtstekel",
    "växtsäsongen": "växtsäsong",
    "växtsäsongens": "växtsäsong",
    "växtsäsonger": "växtsäsong",
    "växtsäsongerna": "växtsäsong",
    "växtsäsongernas": "växtsäsong",
    "växtsäsongers": "växtsäsong",
    "växtsäsongs": "växtsäsong",
    "växttrådar": "växttråd",
    "växttrådarna": "växttråd",
    "växttrådarnas": "växttråd",
    "växttrådars": "växttråd",
    "växttråden": "växttråd",
    "växttrådens": "växttråd",
    "växttråds": "växttråd",
    "växtvärken": "växtvärk",
    "växtvärkens": "växtvärk",
    "växtvärks": "växtvärk",
    "växtvävnaden": "växtvävnad",
    "växtvävnadens": "växtvävnad",
    "växtvävnader": "växtvävnad",
    "växtvävnaderna": "växtvävnad",
    "växtvävnadernas": "växtvävnad",
    "växtvävnaders": "växtvävnad",
    "växtvävnads": "växtvävnad",
    "växtämnen": "växtämne",
    "växtämnena": "växtämne",
    "växtämnenas": "växtämne",
    "växtämnens": "växtämne",
    "växtämnes": "växtämne",
    "växtämnet": "växtämne",
    "växtämnets": "växtämne",
    "växtätar": "växtätare",
    "växtätaren": "växtätare",
    "växtätarens": "växtätare",
    "växtätares": "växtätare",
    "växtätarna": "växtätare",
    "växtätarnas": "växtätare",
    "växvärken": "växvärk",
    "växvärkens": "växvärk",
    "växvärks": "växvärk",
    "vådan": "våda",
    "vådans": "våda",
    "vådas": "våda",
    "vådeldar": "vådeld",
    "vådeldarna": "vådeld",
    "vådeldarnas": "vådeld",
    "vådeldars": "vådeld",
    "vådelden": "vådeld",
    "vådeldens": "vådeld",
    "vådelds": "vådeld",
    "våden": "våd",
    "vådens": "våd",
    "våder": "våd",
    "våderna": "våd",
    "vådernas": "våd",
    "våders": "våd",
    "vådevillen": "vådevill",
    "vådevillens": "vådevill",
    "vådeviller": "vådevill",
    "vådevillerna": "vådevill",
    "vådevillernas": "vådevill",
    "vådevillers": "vådevill",
    "vådevills": "vådevill",
    "vådliga": "vådlig",
    "vådligare": "vådlig",
    "vådligares": "vådlig",
    "vådligas": "vådlig",
    "vådligast": "vådlig",
    "vådligaste": "vådlig",
    "vådligastes": "vådlig",
    "vådligasts": "vådlig",
    "vådlige": "vådlig",
    "vådliges": "vådlig",
    "vådligheten": "vådlighet",
    "vådlighetens": "vådlighet",
    "vådlighets": "vådlighet",
    "vådligs": "vådlig",
    "vådligt": "vådlig",
    "vådligts": "vådlig",
    "vådor": "våda",
    "vådorna": "våda",
    "vådornas": "våda",
    "vådors": "våda",
    "våds": "våd",
    "våffel": "våffla",
    "våffelbindningar": "våffelbindning",
    "våffelbindningarna": "våffelbindning",
    "våffelbindningarnas": "våffelbindning",
    "våffelbindningars": "våffelbindning",
    "våffelbindningen": "våffelbindning",
    "våffelbindningens": "våffelbindning",
    "våffelbindnings": "våffelbindning",
    "våffeldagen": "våffeldag",
    "våffeldagens": "våffeldag",
    "våffeldags": "våffeldag",
    "våffeljärnen": "våffeljärn",
    "våffeljärnens": "våffeljärn",
    "våffeljärnet": "våffeljärn",
    "våffeljärnets": "våffeljärn",
    "våffeljärns": "våffeljärn",
    "våffelmönstrade": "våffelmönstrad",
    "våffelmönstrades": "våffelmönstrad",
    "våffelmönstrads": "våffelmönstrad",
    "våffelmönstrat": "våffelmönstrad",
    "våffelmönstrats": "våffelmönstrad",
    "våfflan": "våffla",
    "våfflans": "våffla",
    "våfflas": "våffla",
    "våffle": "våffla",
    "våfflor": "våffla",
    "våfflorna": "våffla",
    "våfflornas": "våffla",
    "våfflors": "våffla",
    "våg": "våga",
    "vågad": "våga",
    "vågade": "vågad",
    "vågades": "vågad",
    "vågads": "vågad",
    "vågande": "våga",
    "våganden": "vågande",
    "vågandena": "vågande",
    "vågandenas": "vågande",
    "vågandens": "vågande",
    "vågandes": "vågande",
    "vågandet": "vågande",
    "vågandets": "vågande",
    "vågar": "våga",
    "vågarna": "våg",
    "vågarnas": "våg",
    "vågars": "våg",
    "vågas": "våga",
    "vågat": "vågad",
    "vågats": "vågad",
    "vågbalansen": "vågbalans",
    "vågbalansens": "vågbalans",
    "vågbalanser": "vågbalans",
    "vågbalanserna": "vågbalans",
    "vågbalansernas": "vågbalans",
    "vågbalansers": "vågbalans",
    "vågbrytar": "vågbrytare",
    "vågbrytaren": "vågbrytare",
    "vågbrytarens": "vågbrytare",
    "vågbrytares": "vågbrytare",
    "vågbrytarna": "vågbrytare",
    "vågbrytarnas": "vågbrytare",
    "vågdalar": "vågdal",
    "vågdalarna": "vågdal",
    "vågdalarnas": "vågdal",
    "vågdalars": "vågdal",
    "vågdalen": "vågdal",
    "vågdalens": "vågdal",
    "vågdals": "vågdal",
    "vågen": "våg",
    "vågens": "våg",
    "vågformade": "vågformad",
    "vågformades": "vågformad",
    "vågformads": "vågformad",
    "vågformat": "vågformad",
    "vågformats": "vågformad",
    "vågformen": "vågform",
    "vågformens": "vågform",
    "vågformer": "vågform",
    "vågformerna": "vågform",
    "vågformernas": "vågform",
    "vågformers": "vågform",
    "vågformiga": "vågformig",
    "vågformigare": "vågformig",
    "vågformigares": "vågformig",
    "vågformigas": "vågformig",
    "vågformigast": "vågformig",
    "vågformigaste": "vågformig",
    "vågformigastes": "vågformig",
    "vågformigasts": "vågformig",
    "vågformige": "vågformig",
    "vågformiges": "vågformig",
    "vågformigheten": "vågformighet",
    "vågformighetens": "vågformighet",
    "vågformighets": "vågformighet",
    "vågformigs": "vågformig",
    "vågformigt": "vågformig",
    "vågformigts": "vågformig",
    "vågforms": "vågform",
    "vågfronten": "vågfront",
    "vågfrontens": "vågfront",
    "vågfronter": "vågfront",
    "vågfronterna": "vågfront",
    "vågfronternas": "vågfront",
    "vågfronters": "vågfront",
    "vågfronts": "vågfront",
    "vågför": "vågföra",
    "vågförande": "vågföra",
    "vågföranden": "vågförande",
    "vågförandena": "vågförande",
    "vågförandenas": "vågförande",
    "vågförandens": "vågförande",
    "vågförandes": "vågförande",
    "vågförandet": "vågförande",
    "vågförandets": "vågförande",
    "vågföras": "vågföra",
    "vågförd": "vågföra",
    "vågförda": "vågföra",
    "vågfördas": "vågföra",
    "vågförde": "vågföra",
    "vågfördes": "vågföra",
    "vågförds": "vågföra",
    "vågföres": "vågföra",
    "vågförs": "vågföra",
    "vågfört": "vågföra",
    "vågförts": "vågföra",
    "våghalsar": "våghals",
    "våghalsarna": "våghals",
    "våghalsarnas": "våghals",
    "våghalsars": "våghals",
    "våghalsen": "våghals",
    "våghalsens": "våghals",
    "våghalsiga": "våghalsig",
    "våghalsigare": "våghalsig",
    "våghalsigares": "våghalsig",
    "våghalsigas": "våghalsig",
    "våghalsigast": "våghalsig",
    "våghalsigaste": "våghalsig",
    "våghalsigastes": "våghalsig",
    "våghalsigasts": "våghalsig",
    "våghalsige": "våghalsig",
    "våghalsiges": "våghalsig",
    "våghalsigheten": "våghalsighet",
    "våghalsighetens": "våghalsighet",
    "våghalsigheter": "våghalsighet",
    "våghalsigheterna": "våghalsighet",
    "våghalsigheternas": "våghalsighet",
    "våghalsigheters": "våghalsighet",
    "våghalsighets": "våghalsighet",
    "våghalsigs": "våghalsig",
    "våghalsigt": "våghalsig",
    "våghalsigts": "våghalsig",
    "våghålen": "våghål",
    "våghålens": "våghål",
    "våghålet": "våghål",
    "våghålets": "våghål",
    "våghåls": "våghål",
    "våghöjden": "våghöjd",
    "våghöjdens": "våghöjd",
    "våghöjder": "våghöjd",
    "våghöjderna": "våghöjd",
    "våghöjdernas": "våghöjd",
    "våghöjders": "våghöjd",
    "våghöjds": "våghöjd",
    "vågiga": "vågig",
    "vågigare": "vågig",
    "vågigares": "vågig",
    "vågigas": "vågig",
    "vågigast": "vågig",
    "vågigaste": "vågig",
    "vågigastes": "vågig",
    "vågigasts": "vågig",
    "vågige": "vågig",
    "vågiges": "vågig",
    "vågigs": "vågig",
    "vågigt": "vågig",
    "vågigts": "vågig",
    "vågkammar": "vågkam",
    "vågkammarna": "vågkam",
    "vågkammarnas": "vågkam",
    "vågkammars": "vågkam",
    "vågkammen": "vågkam",
    "vågkammens": "vågkam",
    "vågkams": "vågkam",
    "vågkraften": "vågkraft",
    "vågkraftens": "vågkraft",
    "vågkrafts": "vågkraft",
    "våglinjen": "våglinje",
    "våglinjens": "våglinje",
    "våglinjer": "våglinje",
    "våglinjerna": "våglinje",
    "våglinjernas": "våglinje",
    "våglinjers": "våglinje",
    "våglinjes": "våglinje",
    "våglängden": "våglängd",
    "våglängdens": "våglängd",
    "våglängder": "våglängd",
    "våglängderna": "våglängd",
    "våglängdernas": "våglängd",
    "våglängders": "våglängd",
    "våglängds": "våglängd",
    "vågmekaniken": "vågmekanik",
    "vågmekanikens": "vågmekanik",
    "vågmekaniks": "vågmekanik",
    "vågmästar": "vågmästare",
    "vågmästaren": "vågmästare",
    "vågmästarens": "vågmästare",
    "vågmästares": "vågmästare",
    "vågmästarna": "vågmästare",
    "vågmästarnas": "vågmästare",
    "vågmästarpolitiken": "vågmästarpolitik",
    "vågmästarpolitikens": "vågmästarpolitik",
    "vågmästarpolitiks": "vågmästarpolitik",
    "vågmästarrollen": "vågmästarroll",
    "vågmästarrollens": "vågmästarroll",
    "vågmästarroller": "vågmästarroll",
    "vågmästarrollerna": "vågmästarroll",
    "vågmästarrollernas": "vågmästarroll",
    "vågmästarrollers": "vågmästarroll",
    "vågmästarrolls": "vågmästarroll",
    "vågmästeriet": "vågmästeri",
    "vågmästeriets": "vågmästeri",
    "vågmästeris": "vågmästeri",
    "vågmästerit": "vågmästeri",
    "vågmästerits": "vågmästeri",
    "vågnaturen": "vågnatur",
    "vågnaturens": "vågnatur",
    "vågnaturer": "vågnatur",
    "vågnaturerna": "vågnatur",
    "vågnaturernas": "vågnatur",
    "vågnaturers": "vågnatur",
    "vågnaturs": "vågnatur",
    "vågor": "våg",
    "vågorna": "våg",
    "vågornas": "våg",
    "vågors": "våg",
    "vågpappen": "vågpapp",
    "vågpappens": "vågpapp",
    "vågpappet": "vågpapp",
    "vågpappets": "vågpapp",
    "vågpapps": "vågpapp",
    "vågplanen": "vågplan",
    "vågplanens": "vågplan",
    "vågplanet": "vågplan",
    "vågplanets": "vågplan",
    "vågplans": "vågplan",
    "vågräta": "vågrät",
    "vågrätare": "vågrät",
    "vågrätares": "vågrät",
    "vågrätas": "vågrät",
    "vågrätast": "vågrät",
    "vågrätaste": "vågrät",
    "vågrätastes": "vågrät",
    "vågrätasts": "vågrät",
    "vågräte": "vågrät",
    "vågrätes": "vågrät",
    "vågräts": "vågrät",
    "vågrätt": "vågrät",
    "vågrätts": "vågrät",
    "vågrörelsen": "vågrörelse",
    "vågrörelsens": "vågrörelse",
    "vågrörelser": "vågrörelse",
    "vågrörelserna": "vågrörelse",
    "vågrörelsernas": "vågrörelse",
    "vågrörelsers": "vågrörelse",
    "vågrörelses": "vågrörelse",
    "vågs": "våg",
    "vågsamheten": "vågsamhet",
    "vågsamhetens": "vågsamhet",
    "vågsamhets": "vågsamhet",
    "vågsamma": "vågsam",
    "vågsammare": "vågsam",
    "vågsammares": "vågsam",
    "vågsammas": "vågsam",
    "vågsammast": "vågsam",
    "vågsammaste": "vågsam",
    "vågsammastes": "vågsam",
    "vågsammasts": "vågsam",
    "vågsamme": "vågsam",
    "vågsammes": "vågsam",
    "vågsams": "vågsam",
    "vågsamt": "vågsam",
    "vågsamts": "vågsam",
    "vågskålar": "vågskål",
    "vågskålarna": "vågskål",
    "vågskålarnas": "vågskål",
    "vågskålars": "vågskål",
    "vågskålen": "vågskål",
    "vågskålens": "vågskål",
    "vågskåls": "vågskål",
    "vågspelen": "vågspel",
    "vågspelens": "vågspel",
    "vågspelet": "vågspel",
    "vågspelets": "vågspel",
    "vågspels": "vågspel",
    "vågstycken": "vågstycke",
    "vågstyckena": "vågstycke",
    "vågstyckenas": "vågstycke",
    "vågstyckens": "vågstycke",
    "vågstyckes": "vågstycke",
    "vågstycket": "vågstycke",
    "vågstyckets": "vågstycke",
    "vågstycks": "vågstycke",
    "vågsvallen": "vågsvall",
    "vågsvallens": "vågsvall",
    "vågsvallet": "vågsvall",
    "vågsvallets": "vågsvall",
    "vågsvalls": "vågsvall",
    "vågtoppar": "vågtopp",
    "vågtopparna": "vågtopp",
    "vågtopparnas": "vågtopp",
    "vågtoppars": "vågtopp",
    "vågtoppen": "vågtopp",
    "vågtoppens": "vågtopp",
    "vågtopps": "vågtopp",
    "vål": "våle",
    "vålar": "våle",
    "vålarna": "våle",
    "vålarnas": "våle",
    "vålars": "våle",
    "våldet": "våld",
    "våldets": "våld",
    "våldför": "våldföra",
    "våldförande": "våldföra",
    "våldförandes": "våldförande",
    "våldförandet": "våldförande",
    "våldförandets": "våldförande",
    "våldföras": "våldföra",
    "våldförd": "våldföra",
    "våldförda": "våldföra",
    "våldfördas": "våldföra",
    "våldförde": "våldföra",
    "våldfördes": "våldföra",
    "våldförds": "våldföra",
    "våldföres": "våldföra",
    "våldförs": "våldföra",
    "våldfört": "våldföra",
    "våldförts": "våldföra",
    "våldgäst": "våldgästa",
    "våldgästad": "våldgästa",
    "våldgästade": "våldgästa",
    "våldgästades": "våldgästa",
    "våldgästads": "våldgästa",
    "våldgästande": "våldgästa",
    "våldgästanden": "våldgästande",
    "våldgästandena": "våldgästande",
    "våldgästandenas": "våldgästande",
    "våldgästandens": "våldgästande",
    "våldgästandes": "våldgästande",
    "våldgästandet": "våldgästande",
    "våldgästandets": "våldgästande",
    "våldgästar": "våldgästa",
    "våldgästas": "våldgästa",
    "våldgästat": "våldgästa",
    "våldgästats": "våldgästa",
    "vålds": "våld",
    "våldsamheten": "våldsamhet",
    "våldsamhetens": "våldsamhet",
    "våldsamheter": "våldsamhet",
    "våldsamheterna": "våldsamhet",
    "våldsamheternas": "våldsamhet",
    "våldsamheters": "våldsamhet",
    "våldsamhets": "våldsamhet",
    "våldsamma": "våldsam",
    "våldsammare": "våldsam",
    "våldsammares": "våldsam",
    "våldsammas": "våldsam",
    "våldsammast": "våldsam",
    "våldsammaste": "våldsam",
    "våldsammastes": "våldsam",
    "våldsammasts": "våldsam",
    "våldsamme": "våldsam",
    "våldsammes": "våldsam",
    "våldsams": "våldsam",
    "våldsamt": "våldsam",
    "våldsamts": "våldsam",
    "våldsbrotten": "våldsbrott",
    "våldsbrottens": "våldsbrott",
    "våldsbrottet": "våldsbrott",
    "våldsbrottets": "våldsbrott",
    "våldsbrotts": "våldsbrott",
    "våldsbrottslingar": "våldsbrottsling",
    "våldsbrottslingarna": "våldsbrottsling",
    "våldsbrottslingarnas": "våldsbrottsling",
    "våldsbrottslingars": "våldsbrottsling",
    "våldsbrottslingen": "våldsbrottsling",
    "våldsbrottslingens": "våldsbrottsling",
    "våldsbrottslings": "våldsbrottsling",
    "våldsförhärligandes": "våldsförhärligande",
    "våldsförhärligandet": "våldsförhärligande",
    "våldsförhärligandets": "våldsförhärligande",
    "våldshandlingar": "våldshandling",
    "våldshandlingarna": "våldshandling",
    "våldshandlingarnas": "våldshandling",
    "våldshandlingars": "våldshandling",
    "våldshandlingen": "våldshandling",
    "våldshandlingens": "våldshandling",
    "våldshandlings": "våldshandling",
    "våldsmannen": "våldsman",
    "våldsmannens": "våldsman",
    "våldsmans": "våldsman",
    "våldsmentaliteten": "våldsmentalitet",
    "våldsmentalitetens": "våldsmentalitet",
    "våldsmentaliteter": "våldsmentalitet",
    "våldsmentaliteterna": "våldsmentalitet",
    "våldsmentaliteternas": "våldsmentalitet",
    "våldsmentaliteters": "våldsmentalitet",
    "våldsmentalitets": "våldsmentalitet",
    "våldsmän": "våldsman",
    "våldsmännen": "våldsman",
    "våldsmännens": "våldsman",
    "våldsmäns": "våldsman",
    "våldsplågade": "våldsplågad",
    "våldsplågades": "våldsplågad",
    "våldsplågads": "våldsplågad",
    "våldsplågat": "våldsplågad",
    "våldsplågats": "våldsplågad",
    "våldspornografien": "våldspornografi",
    "våldspornografiens": "våldspornografi",
    "våldspornografin": "våldspornografi",
    "våldspornografins": "våldspornografi",
    "våldspornografis": "våldspornografi",
    "våldsporren": "våldsporr",
    "våldsporrens": "våldsporr",
    "våldsporret": "våldsporr",
    "våldsporrets": "våldsporr",
    "våldsporrs": "våldsporr",
    "våldsroteln": "våldsrotel",
    "våldsrotelns": "våldsrotel",
    "våldsrotels": "våldsrotel",
    "våldsrotlar": "våldsrotel",
    "våldsrotlarna": "våldsrotel",
    "våldsrotlarnas": "våldsrotel",
    "våldsrotlars": "våldsrotel",
    "våldsscenen": "våldsscen",
    "våldsscenens": "våldsscen",
    "våldsscener": "våldsscen",
    "våldsscenerna": "våldsscen",
    "våldsscenernas": "våldsscen",
    "våldssceners": "våldsscen",
    "våldsscens": "våldsscen",
    "våldsskildringar": "våldsskildring",
    "våldsskildringarna": "våldsskildring",
    "våldsskildringarnas": "våldsskildring",
    "våldsskildringars": "våldsskildring",
    "våldsskildringen": "våldsskildring",
    "våldsskildringens": "våldsskildring",
    "våldsskildrings": "våldsskildring",
    "våldsutsatta": "våldsutsatt",
    "våldsutsattas": "våldsutsatt",
    "våldsutsatte": "våldsutsatt",
    "våldsutsattes": "våldsutsatt",
    "våldsutsattheten": "våldsutsatthet",
    "våldsutsatthetens": "våldsutsatthet",
    "våldsutsatthets": "våldsutsatthet",
    "våldsutsatts": "våldsutsatt",
    "våldsverkar": "våldsverkare",
    "våldsverkaren": "våldsverkare",
    "våldsverkarens": "våldsverkare",
    "våldsverkares": "våldsverkare",
    "våldsverkarna": "våldsverkare",
    "våldsverkarnas": "våldsverkare",
    "våldsvågen": "våldsvåg",
    "våldsvågens": "våldsvåg",
    "våldsvågor": "våldsvåg",
    "våldsvågorna": "våldsvåg",
    "våldsvågornas": "våldsvåg",
    "våldsvågors": "våldsvåg",
    "våldsvågs": "våldsvåg",
    "våldtag": "våldta",
    "våldtaga": "våldta",
    "våldtagande": "våldta",
    "våldtaganden": "våldtagande",
    "våldtagandena": "våldtagande",
    "våldtagandenas": "våldtagande",
    "våldtagandens": "våldtagande",
    "våldtagandes": "våldtagande",
    "våldtagandet": "våldtagande",
    "våldtagandets": "våldtagande",
    "våldtagas": "våldta",
    "våldtage": "våldta",
    "våldtagen": "våldta",
    "våldtagens": "våldta",
    "våldtager": "våldta",
    "våldtages": "våldta",
    "våldtaget": "våldta",
    "våldtagets": "våldta",
    "våldtagit": "våldta",
    "våldtagits": "våldta",
    "våldtagna": "våldta",
    "våldtagnas": "våldta",
    "våldtagne": "våldta",
    "våldtagnes": "våldta",
    "våldtags": "våldta",
    "våldtar": "våldta",
    "våldtas": "våldta",
    "våldtog": "våldta",
    "våldtoge": "våldta",
    "våldtoges": "våldta",
    "våldtogs": "våldta",
    "våldtäkten": "våldtäkt",
    "våldtäktens": "våldtäkt",
    "våldtäkter": "våldtäkt",
    "våldtäkterna": "våldtäkt",
    "våldtäkternas": "våldtäkt",
    "våldtäkters": "våldtäkt",
    "våldtäkts": "våldtäkt",
    "våldtäktsförsöken": "våldtäktsförsök",
    "våldtäktsförsökens": "våldtäktsförsök",
    "våldtäktsförsöket": "våldtäktsförsök",
    "våldtäktsförsökets": "våldtäktsförsök",
    "våldtäktsförsöks": "våldtäktsförsök",
    "våldtäktsmannen": "våldtäktsman",
    "våldtäktsmannens": "våldtäktsman",
    "våldtäktsmans": "våldtäktsman",
    "våldtäktsmisstänkta": "våldtäktsmisstänkt",
    "våldtäktsmisstänktas": "våldtäktsmisstänkt",
    "våldtäktsmisstänkte": "våldtäktsmisstänkt",
    "våldtäktsmisstänktes": "våldtäktsmisstänkt",
    "våldtäktsmisstänkts": "våldtäktsmisstänkt",
    "våldtäktsmän": "våldtäktsman",
    "våldtäktsmännen": "våldtäktsman",
    "våldtäktsmännens": "våldtäktsman",
    "våldtäktsmäns": "våldtäktsman",
    "vålen": "våle",
    "vålens": "våle",
    "våles": "våle",
    "våll": "vålla",
    "vållad": "vålla",
    "vållade": "vålla",
    "vållades": "vålla",
    "vållads": "vålla",
    "vållande": "vålla",
    "vållandes": "vållande",
    "vållandet": "vållande",
    "vållandets": "vållande",
    "vållar": "vålla",
    "vållas": "vålla",
    "vållat": "vålla",
    "vållats": "vålla",
    "vålm": "vålma",
    "vålmad": "vålma",
    "vålmade": "vålma",
    "vålmades": "vålma",
    "vålmads": "vålma",
    "vålmande": "vålma",
    "vålmanden": "vålmande",
    "vålmandena": "vålmande",
    "vålmandenas": "vålmande",
    "vålmandens": "vålmande",
    "vålmandes": "vålmande",
    "vålmandet": "vålmande",
    "vålmandets": "vålmande",
    "vålmar": "vålma",
    "vålmarna": "vålm",
    "vålmarnas": "vålm",
    "vålmars": "vålm",
    "vålmas": "vålma",
    "vålmat": "vålma",
    "vålmats": "vålma",
    "vålmen": "vålm",
    "vålmens": "vålm",
    "vålms": "vålm",
    "vålnaden": "vålnad",
    "vålnadens": "vålnad",
    "vålnader": "vålnad",
    "vålnaderna": "vålnad",
    "vålnadernas": "vålnad",
    "vålnaders": "vålnad",
    "vålnads": "vålnad",
    "våls": "våle",
    "våmmar": "våm",
    "våmmarna": "våm",
    "våmmarnas": "våm",
    "våmmars": "våm",
    "våmmen": "våm",
    "våmmens": "våm",
    "våms": "våm",
    "vånd": "vånda",
    "våndades": "våndas",
    "våndan": "vånda",
    "våndans": "vånda",
    "våndas": "vånda",
    "våndats": "våndas",
    "vånde": "vånda",
    "våndor": "vånda",
    "våndorna": "vånda",
    "våndornas": "vånda",
    "våndors": "vånda",
    "vånds": "vånda",
    "vångar": "vång",
    "vångarna": "vång",
    "vångarnas": "vång",
    "vångars": "vång",
    "vången": "vång",
    "vångens": "vång",
    "vångs": "vång",
    "våningar": "våning",
    "våningarna": "våning",
    "våningarnas": "våning",
    "våningars": "våning",
    "våningen": "våning",
    "våningens": "våning",
    "vånings": "våning",
    "våningsplanen": "våningsplan",
    "våningsplanens": "våningsplan",
    "våningsplanet": "våningsplan",
    "våningsplanets": "våningsplan",
    "våningsplans": "våningsplan",
    "våningssängar": "våningssäng",
    "våningssängarna": "våningssäng",
    "våningssängarnas": "våningssäng",
    "våningssängars": "våningssäng",
    "våningssängen": "våningssäng",
    "våningssängens": "våningssäng",
    "våningssängs": "våningssäng",
    "vånn": "vånna",
    "vånnade": "vånna",
    "vånnades": "vånna",
    "vånnande": "vånna",
    "vånnanden": "vånnande",
    "vånnandena": "vånnande",
    "vånnandenas": "vånnande",
    "vånnandens": "vånnande",
    "vånnandes": "vånnande",
    "vånnandet": "vånnande",
    "vånnandets": "vånnande",
    "vånnar": "vånna",
    "vånnas": "vånna",
    "vånnat": "vånna",
    "vånnats": "vånna",
    "vånne": "vånna",
    "vånnes": "vånna",
    "våns": "vån",
    "våpen": "våp",
    "våpens": "våp",
    "våpet": "våp",
    "våpets": "våp",
    "våpiga": "våpig",
    "våpigare": "våpig",
    "våpigares": "våpig",
    "våpigas": "våpig",
    "våpigast": "våpig",
    "våpigaste": "våpig",
    "våpigastes": "våpig",
    "våpigasts": "våpig",
    "våpige": "våpig",
    "våpiges": "våpig",
    "våpigs": "våpig",
    "våpigt": "våpig",
    "våpigts": "våpig",
    "våps": "våp",
    "vår": "vi",
    "våra": "vi",
    "vårad": "våra",
    "vårade": "våra",
    "vårades": "våras",
    "våradonisar": "våradonis",
    "våradonisarna": "våradonis",
    "våradonisarnas": "våradonis",
    "våradonisars": "våradonis",
    "våradonisen": "våradonis",
    "våradonisens": "våradonis",
    "vårads": "våra",
    "våran": "vi",
    "vårande": "våra",
    "våranden": "vårande",
    "vårandena": "vårande",
    "vårandenas": "vårande",
    "vårandens": "vårande",
    "vårandes": "vårande",
    "vårandet": "vårande",
    "vårandets": "vårande",
    "vårar": "våra",
    "vårarna": "vår",
    "vårarnas": "vår",
    "vårars": "vår",
    "våras": "våra",
    "vårat": "vi",
    "vårats": "våras",
    "vårbeten": "vårbete",
    "vårbetena": "vårbete",
    "vårbetenas": "vårbete",
    "vårbetens": "vårbete",
    "vårbetes": "vårbete",
    "vårbetet": "vårbete",
    "vårbetets": "vårbete",
    "vårblom": "vårblomma",
    "vårblomman": "vårblomma",
    "vårblommans": "vårblomma",
    "vårblommas": "vårblomma",
    "vårblomme": "vårblomma",
    "vårblommor": "vårblomma",
    "vårblommorna": "vårblomma",
    "vårblommornas": "vårblomma",
    "vårblommors": "vårblomma",
    "vårbloms": "vårblomma",
    "vårbrodden": "vårbrodd",
    "vårbroddens": "vårbrodd",
    "vårbrodds": "vårbrodd",
    "vårbruket": "vårbruk",
    "vårbrukets": "vårbruk",
    "vårbruks": "vårbruk",
    "vårbrytningar": "vårbrytning",
    "vårbrytningarna": "vårbrytning",
    "vårbrytningarnas": "vårbrytning",
    "vårbrytningars": "vårbrytning",
    "vårbrytningen": "vårbrytning",
    "vårbrytningens": "vårbrytning",
    "vårbrytnings": "vårbrytning",
    "vård": "vårda",
    "vårdad": "vårda",
    "vårdade": "vårdad",
    "vårdades": "vårdad",
    "vårdads": "vårdad",
    "vårdagjämningar": "vårdagjämning",
    "vårdagjämningarna": "vårdagjämning",
    "vårdagjämningarnas": "vårdagjämning",
    "vårdagjämningars": "vårdagjämning",
    "vårdagjämningen": "vårdagjämning",
    "vårdagjämningens": "vårdagjämning",
    "vårdagjämnings": "vårdagjämning",
    "vårdagjämningspunkten": "vårdagjämningspunkt",
    "vårdagjämningspunktens": "vårdagjämningspunkt",
    "vårdagjämningspunkts": "vårdagjämningspunkt",
    "vårdande": "vårda",
    "vårdanden": "vårdande",
    "vårdandena": "vårdande",
    "vårdandenas": "vårdande",
    "vårdandens": "vårdande",
    "vårdandes": "vårdande",
    "vårdandet": "vårdande",
    "vårdandets": "vårdande",
    "vårdanstalten": "vårdanstalt",
    "vårdanstaltens": "vårdanstalt",
    "vårdanstalter": "vårdanstalt",
    "vårdanstalterna": "vårdanstalt",
    "vårdanstalternas": "vårdanstalt",
    "vårdanstalters": "vårdanstalt",
    "vårdanstalts": "vårdanstalt",
    "vårdar": "vårdare",
    "vårdaren": "vårdare",
    "vårdarens": "vårdare",
    "vårdares": "vårdare",
    "vårdarinnan": "vårdarinna",
    "vårdarinnans": "vårdarinna",
    "vårdarinnas": "vårdarinna",
    "vårdarinne": "vårdarinna",
    "vårdarinnor": "vårdarinna",
    "vårdarinnorna": "vårdarinna",
    "vårdarinnornas": "vårdarinna",
    "vårdarinnors": "vårdarinna",
    "vårdarna": "vårdare",
    "vårdarnas": "vårdare",
    "vårdars": "vård",
    "vårdas": "vårda",
    "vårdat": "vårdad",
    "vårdats": "vårdad",
    "vårdavdelningar": "vårdavdelning",
    "vårdavdelningarna": "vårdavdelning",
    "vårdavdelningarnas": "vårdavdelning",
    "vårdavdelningars": "vårdavdelning",
    "vårdavdelningen": "vårdavdelning",
    "vårdavdelningens": "vårdavdelning",
    "vårdavdelnings": "vårdavdelning",
    "vårdbidragen": "vårdbidrag",
    "vårdbidragens": "vårdbidrag",
    "vårdbidraget": "vårdbidrag",
    "vårdbidragets": "vårdbidrag",
    "vårdbidrags": "vårdbidrag",
    "vårdcentralen": "vårdcentral",
    "vårdcentralens": "vårdcentral",
    "vårdcentraler": "vårdcentral",
    "vårdcentralerna": "vårdcentral",
    "vårdcentralernas": "vårdcentral",
    "vårdcentralers": "vårdcentral",
    "vårdcentrals": "vårdcentral",
    "vården": "vård",
    "vårdens": "vård",
    "vårder": "vård",
    "vårderna": "vård",
    "vårdernas": "vård",
    "vårders": "vård",
    "vårdgarantien": "vårdgaranti",
    "vårdgarantiens": "vårdgaranti",
    "vårdgarantier": "vårdgaranti",
    "vårdgarantierna": "vårdgaranti",
    "vårdgarantiernas": "vårdgaranti",
    "vårdgarantiers": "vårdgaranti",
    "vårdgarantin": "vårdgaranti",
    "vårdgarantins": "vårdgaranti",
    "vårdgarantis": "vårdgaranti",
    "vårdhemmen": "vårdhem",
    "vårdhemmens": "vårdhem",
    "vårdhemmet": "vårdhem",
    "vårdhemmets": "vårdhem",
    "vårdhems": "vårdhem",
    "vårdintygen": "vårdintyg",
    "vårdintygens": "vårdintyg",
    "vårdintyget": "vårdintyg",
    "vårdintygets": "vårdintyg",
    "vårdintygs": "vårdintyg",
    "vårdintygsmässiga": "vårdintygsmässig",
    "vårdintygsmässigare": "vårdintygsmässig",
    "vårdintygsmässigares": "vårdintygsmässig",
    "vårdintygsmässigas": "vårdintygsmässig",
    "vårdintygsmässigast": "vårdintygsmässig",
    "vårdintygsmässigaste": "vårdintygsmässig",
    "vårdintygsmässigastes": "vårdintygsmässig",
    "vårdintygsmässigasts": "vårdintygsmässig",
    "vårdintygsmässige": "vårdintygsmässig",
    "vårdintygsmässiges": "vårdintygsmässig",
    "vårdintygsmässigs": "vårdintygsmässig",
    "vårdintygsmässigt": "vårdintygsmässig",
    "vårdintygsmässigts": "vårdintygsmässig",
    "vårdkas": "vårdkase",
    "vårdkasar": "vårdkase",
    "vårdkasarna": "vårdkase",
    "vårdkasarnas": "vårdkase",
    "vårdkasars": "vårdkase",
    "vårdkasen": "vårdkase",
    "vårdkasens": "vårdkase",
    "vårdkases": "vårdkase",
    "vårdkliniken": "vårdklinik",
    "vårdklinikens": "vårdklinik",
    "vårdkliniker": "vårdklinik",
    "vårdklinikerna": "vårdklinik",
    "vårdklinikernas": "vårdklinik",
    "vårdklinikers": "vårdklinik",
    "vårdkliniks": "vårdklinik",
    "vårdlinjen": "vårdlinje",
    "vårdlinjens": "vårdlinje",
    "vårdlinjer": "vårdlinje",
    "vårdlinjerna": "vårdlinje",
    "vårdlinjernas": "vårdlinje",
    "vårdlinjers": "vårdlinje",
    "vårdlinjes": "vårdlinje",
    "vårdmässiga": "vårdmässig",
    "vårdmässigare": "vårdmässig",
    "vårdmässigares": "vårdmässig",
    "vårdmässigas": "vårdmässig",
    "vårdmässigast": "vårdmässig",
    "vårdmässigaste": "vårdmässig",
    "vårdmässigastes": "vårdmässig",
    "vårdmässigasts": "vårdmässig",
    "vårdmässige": "vårdmässig",
    "vårdmässiges": "vårdmässig",
    "vårdmässigs": "vårdmässig",
    "vårdmässigt": "vårdmässig",
    "vårdmässigts": "vårdmässig",
    "vårdnaden": "vårdnad",
    "vårdnadens": "vårdnad",
    "vårdnader": "vårdnad",
    "vårdnaderna": "vårdnad",
    "vårdnadernas": "vårdnad",
    "vårdnaders": "vårdnad",
    "vårdnads": "vårdnad",
    "vårdnadsbidragen": "vårdnadsbidrag",
    "vårdnadsbidragens": "vårdnadsbidrag",
    "vårdnadsbidraget": "vårdnadsbidrag",
    "vårdnadsbidragets": "vårdnadsbidrag",
    "vårdnadsbidrags": "vårdnadsbidrag",
    "vårdnadshavar": "vårdnadshavare",
    "vårdnadshavaren": "vårdnadshavare",
    "vårdnadshavarens": "vårdnadshavare",
    "vårdnadshavares": "vårdnadshavare",
    "vårdnadshavarna": "vårdnadshavare",
    "vårdnadshavarnas": "vårdnadshavare",
    "vårdpersonalen": "vårdpersonal",
    "vårdpersonalens": "vårdpersonal",
    "vårdpersonaler": "vårdpersonal",
    "vårdpersonalerna": "vårdpersonal",
    "vårdpersonalernas": "vårdpersonal",
    "vårdpersonalers": "vårdpersonal",
    "vårdpersonals": "vårdpersonal",
    "vårdplatsen": "vårdplats",
    "vårdplatsens": "vårdplats",
    "vårdplatser": "vårdplats",
    "vårdplatserna": "vårdplats",
    "vårdplatsernas": "vårdplats",
    "vårdplatsers": "vårdplats",
    "vårds": "vård",
    "vårdsamheten": "vårdsamhet",
    "vårdsamhetens": "vårdsamhet",
    "vårdsamhets": "vårdsamhet",
    "vårdsamma": "vårdsam",
    "vårdsammare": "vårdsam",
    "vårdsammares": "vårdsam",
    "vårdsammas": "vårdsam",
    "vårdsammast": "vårdsam",
    "vårdsammaste": "vårdsam",
    "vårdsammastes": "vårdsam",
    "vårdsammasts": "vårdsam",
    "vårdsamme": "vårdsam",
    "vårdsammes": "vårdsam",
    "vårdsams": "vårdsam",
    "vårdsamt": "vårdsam",
    "vårdsamts": "vårdsam",
    "vårdskadade": "vårdskadad",
    "vårdskadades": "vårdskadad",
    "vårdskadads": "vårdskadad",
    "vårdskadan": "vårdskada",
    "vårdskadans": "vårdskada",
    "vårdskadas": "vårdskada",
    "vårdskadat": "vårdskadad",
    "vårdskadats": "vårdskadad",
    "vårdskade": "vårdskada",
    "vårdskador": "vårdskada",
    "vårdskadorna": "vårdskada",
    "vårdskadornas": "vårdskada",
    "vårdskadors": "vårdskada",
    "vårdslös": "vårdslösa",
    "vårdslösa": "vårdslös",
    "vårdslösad": "vårdslösa",
    "vårdslösade": "vårdslösa",
    "vårdslösades": "vårdslösa",
    "vårdslösads": "vårdslösa",
    "vårdslösande": "vårdslösa",
    "vårdslösanden": "vårdslösande",
    "vårdslösandena": "vårdslösande",
    "vårdslösandenas": "vårdslösande",
    "vårdslösandens": "vårdslösande",
    "vårdslösandes": "vårdslösande",
    "vårdslösandet": "vårdslösande",
    "vårdslösandets": "vårdslösande",
    "vårdslösar": "vårdslösa",
    "vårdslösare": "vårdslös",
    "vårdslösares": "vårdslös",
    "vårdslösas": "vårdslösa",
    "vårdslösast": "vårdslös",
    "vårdslösaste": "vårdslös",
    "vårdslösastes": "vårdslös",
    "vårdslösasts": "vårdslös",
    "vårdslösat": "vårdslösa",
    "vårdslösats": "vårdslösa",
    "vårdslöse": "vårdslös",
    "vårdslöses": "vårdslös",
    "vårdslösheten": "vårdslöshet",
    "vårdslöshetens": "vårdslöshet",
    "vårdslösheter": "vårdslöshet",
    "vårdslösheterna": "vårdslöshet",
    "vårdslösheternas": "vårdslöshet",
    "vårdslösheters": "vårdslöshet",
    "vårdslöshets": "vårdslöshet",
    "vårdslöst": "vårdslös",
    "vårdslösts": "vårdslös",
    "vårdtagar": "vårdtagare",
    "vårdtagaren": "vårdtagare",
    "vårdtagarens": "vårdtagare",
    "vårdtagares": "vårdtagare",
    "vårdtagarna": "vårdtagare",
    "vårdtagarnas": "vårdtagare",
    "vårdteckens": "vårdtecken",
    "vårdtecknen": "vårdtecken",
    "vårdtecknens": "vårdtecken",
    "vårdtecknet": "vårdtecken",
    "vårdtecknets": "vårdtecken",
    "vårdträden": "vårdträd",
    "vårdträdens": "vårdträd",
    "vårdträdet": "vårdträd",
    "vårdträdets": "vårdträd",
    "vårdträds": "vårdträd",
    "vårdvalen": "vårdval",
    "vårdvalens": "vårdval",
    "vårdvalet": "vårdval",
    "vårdvalets": "vårdval",
    "vårdvals": "vårdval",
    "vårdyrken": "vårdyrke",
    "vårdyrkena": "vårdyrke",
    "vårdyrkenas": "vårdyrke",
    "vårdyrkens": "vårdyrke",
    "vårdyrkes": "vårdyrke",
    "vårdyrket": "vårdyrke",
    "vårdyrkets": "vårdyrke",
    "våren": "vår",
    "vårens": "vår",
    "vårfloden": "vårflod",
    "vårflodens": "vårflod",
    "vårflods": "vårflod",
    "vårfrosten": "vårfrost",
    "vårfrostens": "vårfrost",
    "vårfrosts": "vårfrost",
    "vårfrudagen": "vårfrudag",
    "vårfrudagens": "vårfrudag",
    "vårfrudags": "vårfrudag",
    "vårgröna": "vårgrön",
    "vårgrönare": "vårgrön",
    "vårgrönares": "vårgrön",
    "vårgrönas": "vårgrön",
    "vårgrönast": "vårgrön",
    "vårgrönaste": "vårgrön",
    "vårgrönastes": "vårgrön",
    "vårgrönasts": "vårgrön",
    "vårgröne": "vårgrön",
    "vårgrönes": "vårgrön",
    "vårgröns": "vårgrön",
    "vårgrönt": "vårgrön",
    "vårgrönts": "vårgrön",
    "vårkänsl": "vårkänsla",
    "vårkänslan": "vårkänsla",
    "vårkänslans": "vårkänsla",
    "vårkänslas": "vårkänsla",
    "vårkänsle": "vårkänsla",
    "vårkänslo": "vårkänsla",
    "vårkänslor": "vårkänsla",
    "vårkänslorna": "vårkänsla",
    "vårkänslornas": "vårkänsla",
    "vårkänslors": "vårkänsla",
    "vårliga": "vårlig",
    "vårligare": "vårlig",
    "vårligares": "vårlig",
    "vårligas": "vårlig",
    "vårligast": "vårlig",
    "vårligaste": "vårlig",
    "vårligastes": "vårlig",
    "vårligasts": "vårlig",
    "vårlige": "vårlig",
    "vårliges": "vårlig",
    "vårligs": "vårlig",
    "vårligt": "vårlig",
    "vårligts": "vårlig",
    "vårluften": "vårluft",
    "vårluftens": "vårluft",
    "vårlufts": "vårluft",
    "vårlökar": "vårlök",
    "vårlökarna": "vårlök",
    "vårlökarnas": "vårlök",
    "vårlökars": "vårlök",
    "vårlöken": "vårlök",
    "vårlökens": "vårlök",
    "vårlöks": "vårlök",
    "vårmolnen": "vårmoln",
    "vårmolnens": "vårmoln",
    "vårmolnet": "vårmoln",
    "vårmolnets": "vårmoln",
    "vårmolns": "vårmoln",
    "vårmånaden": "vårmånad",
    "vårmånadens": "vårmånad",
    "vårmånader": "vårmånad",
    "vårmånaderna": "vårmånad",
    "vårmånadernas": "vårmånad",
    "vårmånaders": "vårmånad",
    "vårmånads": "vårmånad",
    "vårs": "vår",
    "vårsolar": "vårsol",
    "vårsolarna": "vårsol",
    "vårsolarnas": "vårsol",
    "vårsolars": "vårsol",
    "vårsolen": "vårsol",
    "vårsolens": "vårsol",
    "vårsols": "vårsol",
    "vårsoppan": "vårsoppa",
    "vårsoppans": "vårsoppa",
    "vårsoppas": "vårsoppa",
    "vårsäden": "vårsäd",
    "vårsädens": "vårsäd",
    "vårsädes": "vårsäd",
    "vårsäds": "vårsäd",
    "vårt": "vi",
    "vårtan": "vårta",
    "vårtans": "vårta",
    "vårtas": "vårta",
    "vårtbitar": "vårtbitare",
    "vårtbitaren": "vårtbitare",
    "vårtbitarens": "vårtbitare",
    "vårtbitares": "vårtbitare",
    "vårtbitarna": "vårtbitare",
    "vårtbitarnas": "vårtbitare",
    "vårte": "vårta",
    "vårteckens": "vårtecken",
    "vårtecknen": "vårtecken",
    "vårtecknens": "vårtecken",
    "vårtecknet": "vårtecken",
    "vårtecknets": "vårtecken",
    "vårterminen": "vårtermin",
    "vårterminens": "vårtermin",
    "vårterminer": "vårtermin",
    "vårterminerna": "vårtermin",
    "vårterminernas": "vårtermin",
    "vårterminers": "vårtermin",
    "vårtermins": "vårtermin",
    "vårtgårdar": "vårtgård",
    "vårtgårdarna": "vårtgård",
    "vårtgårdarnas": "vårtgård",
    "vårtgårdars": "vårtgård",
    "vårtgården": "vårtgård",
    "vårtgårdens": "vårtgård",
    "vårtgårds": "vårtgård",
    "vårtiga": "vårtig",
    "vårtigare": "vårtig",
    "vårtigares": "vårtig",
    "vårtigas": "vårtig",
    "vårtigast": "vårtig",
    "vårtigaste": "vårtig",
    "vårtigastes": "vårtig",
    "vårtigasts": "vårtig",
    "vårtige": "vårtig",
    "vårtiges": "vårtig",
    "vårtigheten": "vårtighet",
    "vårtighetens": "vårtighet",
    "vårtighets": "vårtighet",
    "vårtigs": "vårtig",
    "vårtigt": "vårtig",
    "vårtigts": "vårtig",
    "vårtkaktusar": "vårtkaktus",
    "vårtkaktusarna": "vårtkaktus",
    "vårtkaktusarnas": "vårtkaktus",
    "vårtkaktusars": "vårtkaktus",
    "vårtkaktusen": "vårtkaktus",
    "vårtkaktusens": "vårtkaktus",
    "vårtmedels": "vårtmedel",
    "vårtmedlen": "vårtmedel",
    "vårtmedlens": "vårtmedel",
    "vårtmedlet": "vårtmedel",
    "vårtmedlets": "vårtmedel",
    "vårtor": "vårta",
    "vårtorna": "vårta",
    "vårtornas": "vårta",
    "vårtors": "vårta",
    "vårtrötta": "vårtrött",
    "vårtröttare": "vårtrött",
    "vårtröttares": "vårtrött",
    "vårtröttas": "vårtrött",
    "vårtröttast": "vårtrött",
    "vårtröttaste": "vårtrött",
    "vårtröttastes": "vårtrött",
    "vårtröttasts": "vårtrött",
    "vårtrötte": "vårtrött",
    "vårtröttes": "vårtrött",
    "vårtröttheten": "vårtrötthet",
    "vårtrötthetens": "vårtrötthet",
    "vårtröttheter": "vårtrötthet",
    "vårtröttheterna": "vårtrötthet",
    "vårtröttheternas": "vårtrötthet",
    "vårtröttheters": "vårtrötthet",
    "vårtrötthets": "vårtrötthet",
    "vårtrötts": "vårtrött",
    "vårts": "vårta",
    "vårtsvetsar": "vårtsvets",
    "vårtsvetsarna": "vårtsvets",
    "vårtsvetsarnas": "vårtsvets",
    "vårtsvetsars": "vårtsvets",
    "vårtsvetsen": "vårtsvets",
    "vårtsvetsens": "vårtsvets",
    "vårtsvinen": "vårtsvin",
    "vårtsvinens": "vårtsvin",
    "vårtsvinet": "vårtsvin",
    "vårtsvinets": "vårtsvin",
    "vårtsvins": "vårtsvin",
    "vårvetes": "vårvete",
    "vårvetet": "vårvete",
    "vårvetets": "vårvete",
    "vårvialen": "vårvial",
    "vårvialens": "vårvial",
    "vårvialer": "vårvial",
    "vårvialerna": "vårvial",
    "vårvialernas": "vårvial",
    "vårvialers": "vårvial",
    "vårvials": "vårvial",
    "vårvintern": "vårvinter",
    "vårvinterns": "vårvinter",
    "vårvinters": "vårvinter",
    "vårvinterveck": "vårvintervecka",
    "vårvinterveckan": "vårvintervecka",
    "vårvinterveckans": "vårvintervecka",
    "vårvinterveckas": "vårvintervecka",
    "vårvintervecke": "vårvintervecka",
    "vårvintervecko": "vårvintervecka",
    "vårvinterveckor": "vårvintervecka",
    "vårvinterveckorna": "vårvintervecka",
    "vårvinterveckornas": "vårvintervecka",
    "vårvinterveckors": "vårvintervecka",
    "vårvintervecks": "vårvintervecka",
    "vårvintrar": "vårvinter",
    "vårvintrarna": "vårvinter",
    "vårvintrarnas": "vårvinter",
    "vårvintrars": "vårvinter",
    "vårväxten": "vårväxt",
    "vårväxtens": "vårväxt",
    "vårväxter": "vårväxt",
    "vårväxterna": "vårväxt",
    "vårväxternas": "vårväxt",
    "vårväxters": "vårväxt",
    "vårväxts": "vårväxt",
    "våta": "våt",
    "våtare": "våt",
    "våtares": "våt",
    "våtarv": "våtarve",
    "våtarvar": "våtarve",
    "våtarvarna": "våtarve",
    "våtarvarnas": "våtarve",
    "våtarvars": "våtarve",
    "våtarven": "våtarve",
    "våtarvens": "våtarve",
    "våtarves": "våtarve",
    "våtarvs": "våtarve",
    "våtas": "våt",
    "våtast": "våt",
    "våtaste": "våt",
    "våtastes": "våt",
    "våtasts": "våt",
    "våte": "våt",
    "våtelementen": "våtelement",
    "våtelementens": "våtelement",
    "våtelementet": "våtelement",
    "våtelementets": "våtelement",
    "våtelements": "våtelement",
    "våtes": "våt",
    "våtheten": "våthet",
    "våthetens": "våthet",
    "våthets": "våthet",
    "våtkol": "våtkola",
    "våtkolad": "våtkola",
    "våtkolade": "våtkola",
    "våtkolades": "våtkola",
    "våtkolads": "våtkola",
    "våtkolande": "våtkola",
    "våtkolanden": "våtkolande",
    "våtkolandena": "våtkolande",
    "våtkolandenas": "våtkolande",
    "våtkolandens": "våtkolande",
    "våtkolandes": "våtkolande",
    "våtkolandet": "våtkolande",
    "våtkolandets": "våtkolande",
    "våtkolar": "våtkola",
    "våtkolas": "våtkola",
    "våtkolat": "våtkola",
    "våtkolats": "våtkola",
    "våtmarken": "våtmark",
    "våtmarkens": "våtmark",
    "våtmarker": "våtmark",
    "våtmarkerna": "våtmark",
    "våtmarkernas": "våtmark",
    "våtmarkers": "våtmark",
    "våtmarks": "våtmark",
    "våtmassan": "våtmassa",
    "våtmassans": "våtmassa",
    "våtmassas": "våtmassa",
    "våtmasse": "våtmassa",
    "våtpress": "våtpressa",
    "våtpressad": "våtpressa",
    "våtpressade": "våtpressa",
    "våtpressades": "våtpressa",
    "våtpressads": "våtpressa",
    "våtpressande": "våtpressa",
    "våtpressanden": "våtpressande",
    "våtpressandena": "våtpressande",
    "våtpressandenas": "våtpressande",
    "våtpressandens": "våtpressande",
    "våtpressandes": "våtpressande",
    "våtpressandet": "våtpressande",
    "våtpressandets": "våtpressande",
    "våtpressar": "våtpressa",
    "våtpressas": "våtpressa",
    "våtpressat": "våtpressa",
    "våtpressats": "våtpressa",
    "våtrummen": "våtrum",
    "våtrummens": "våtrum",
    "våtrummet": "våtrum",
    "våtrummets": "våtrum",
    "våtrums": "våtrum",
    "våtrumssilikonet": "våtrumssilikon",
    "våtrumssilikonets": "våtrumssilikon",
    "våtrumssilikons": "våtrumssilikon",
    "våts": "våt",
    "våtservetten": "våtservett",
    "våtservettens": "våtservett",
    "våtservetter": "våtservett",
    "våtservetterna": "våtservett",
    "våtservetternas": "våtservett",
    "våtservetters": "våtservett",
    "våtservetts": "våtservett",
    "våtskrapan": "våtskrapa",
    "våtskrapans": "våtskrapa",
    "våtskrapas": "våtskrapa",
    "våtskrape": "våtskrapa",
    "våtskrapor": "våtskrapa",
    "våtskraporna": "våtskrapa",
    "våtskrapornas": "våtskrapa",
    "våtskrapors": "våtskrapa",
    "våtstarka": "våtstark",
    "våtstarkare": "våtstark",
    "våtstarkares": "våtstark",
    "våtstarkas": "våtstark",
    "våtstarkast": "våtstark",
    "våtstarkaste": "våtstark",
    "våtstarkastes": "våtstark",
    "våtstarkasts": "våtstark",
    "våtstarke": "våtstark",
    "våtstarkes": "våtstark",
    "våtstarkheten": "våtstarkhet",
    "våtstarkhetens": "våtstarkhet",
    "våtstarkhets": "våtstarkhet",
    "våtstarks": "våtstark",
    "våtstarkt": "våtstark",
    "våtstarkts": "våtstark",
    "våtsugningar": "våtsugning",
    "våtsugningarna": "våtsugning",
    "våtsugningarnas": "våtsugning",
    "våtsugningars": "våtsugning",
    "våtsugningen": "våtsugning",
    "våtsugningens": "våtsugning",
    "våtsugnings": "våtsugning",
    "vått": "våt",
    "våtts": "våt",
    "våtutrymmen": "våtutrymme",
    "våtutrymmena": "våtutrymme",
    "våtutrymmenas": "våtutrymme",
    "våtutrymmens": "våtutrymme",
    "våtutrymmes": "våtutrymme",
    "våtutrymmet": "våtutrymme",
    "våtutrymmets": "våtutrymme",
    "våtvar": "våtvara",
    "våtvaran": "våtvara",
    "våtvarans": "våtvara",
    "våtvaras": "våtvara",
    "våtvarma": "våtvarm",
    "våtvarmare": "våtvarm",
    "våtvarmares": "våtvarm",
    "våtvarmas": "våtvarm",
    "våtvarmast": "våtvarm",
    "våtvarmaste": "våtvarm",
    "våtvarmastes": "våtvarm",
    "våtvarmasts": "våtvarm",
    "våtvarme": "våtvarm",
    "våtvarmes": "våtvarm",
    "våtvarmheten": "våtvarmhet",
    "våtvarmhetens": "våtvarmhet",
    "våtvarmhets": "våtvarmhet",
    "våtvarms": "våtvarm",
    "våtvarmt": "våtvarm",
    "våtvarmts": "våtvarm",
    "våtvaror": "våtvara",
    "våtvarorna": "våtvara",
    "våtvarornas": "våtvara",
    "våtvarors": "våtvara",
    "våtvaru": "våtvara",
    "vörd": "vörda",
    "vördad": "vörda",
    "vördade": "vörda",
    "vördades": "vörda",
    "vördads": "vörda",
    "vördande": "vörda",
    "vördanden": "vördande",
    "vördandena": "vördande",
    "vördandenas": "vördande",
    "vördandens": "vördande",
    "vördandes": "vördande",
    "vördandet": "vördande",
    "vördandets": "vördande",
    "vördar": "vörda",
    "vördas": "vörda",
    "vördat": "vörda",
    "vördats": "vörda",
    "vördiga": "vördig",
    "vördigare": "vördig",
    "vördigares": "vördig",
    "vördigas": "vördig",
    "vördigast": "vördig",
    "vördigaste": "vördig",
    "vördigastes": "vördig",
    "vördigasts": "vördig",
    "vördige": "vördig",
    "vördiges": "vördig",
    "vördigheten": "vördighet",
    "vördighetens": "vördighet",
    "vördighets": "vördighet",
    "vördigs": "vördig",
    "vördigt": "vördig",
    "vördigts": "vördig",
    "vördnaden": "vördnad",
    "vördnadens": "vördnad",
    "vördnader": "vördnad",
    "vördnaderna": "vördnad",
    "vördnadernas": "vördnad",
    "vördnaders": "vördnad",
    "vördnads": "vördnad",
    "vördnadsbetygelsen": "vördnadsbetygelse",
    "vördnadsbetygelsens": "vördnadsbetygelse",
    "vördnadsbetygelser": "vördnadsbetygelse",
    "vördnadsbetygelserna": "vördnadsbetygelse",
    "vördnadsbetygelsernas": "vördnadsbetygelse",
    "vördnadsbetygelsers": "vördnadsbetygelse",
    "vördnadsbetygelses": "vördnadsbetygelse",
    "vördnadsfulla": "vördnadsfull",
    "vördnadsfullare": "vördnadsfull",
    "vördnadsfullares": "vördnadsfull",
    "vördnadsfullas": "vördnadsfull",
    "vördnadsfullast": "vördnadsfull",
    "vördnadsfullaste": "vördnadsfull",
    "vördnadsfullastes": "vördnadsfull",
    "vördnadsfullasts": "vördnadsfull",
    "vördnadsfulle": "vördnadsfull",
    "vördnadsfulles": "vördnadsfull",
    "vördnadsfullheten": "vördnadsfullhet",
    "vördnadsfullhetens": "vördnadsfullhet",
    "vördnadsfullhets": "vördnadsfullhet",
    "vördnadsfulls": "vördnadsfull",
    "vördnadsfullt": "vördnadsfull",
    "vördnadsfullts": "vördnadsfull",
    "vördnadsvärda": "vördnadsvärd",
    "vördnadsvärdare": "vördnadsvärd",
    "vördnadsvärdares": "vördnadsvärd",
    "vördnadsvärdas": "vördnadsvärd",
    "vördnadsvärdast": "vördnadsvärd",
    "vördnadsvärdaste": "vördnadsvärd",
    "vördnadsvärdastes": "vördnadsvärd",
    "vördnadsvärdasts": "vördnadsvärd",
    "vördnadsvärde": "vördnadsvärd",
    "vördnadsvärdes": "vördnadsvärd",
    "vördnadsvärdheten": "vördnadsvärdhet",
    "vördnadsvärdhetens": "vördnadsvärdhet",
    "vördnadsvärdhets": "vördnadsvärdhet",
    "vördnadsvärds": "vördnadsvärd",
    "vördnadsvärt": "vördnadsvärd",
    "vördnadsvärts": "vördnadsvärd",
    "vördsamheten": "vördsamhet",
    "vördsamhetens": "vördsamhet",
    "vördsamhets": "vördsamhet",
    "vördsamma": "vördsam",
    "vördsammare": "vördsam",
    "vördsammares": "vördsam",
    "vördsammas": "vördsam",
    "vördsammast": "vördsam",
    "vördsammaste": "vördsam",
    "vördsammastes": "vördsam",
    "vördsammasts": "vördsam",
    "vördsamme": "vördsam",
    "vördsammes": "vördsam",
    "vördsams": "vördsam",
    "vördsamt": "vördsam",
    "vördsamts": "vördsam",
    "vörtbröden": "vörtbröd",
    "vörtbrödens": "vörtbröd",
    "vörtbrödet": "vörtbröd",
    "vörtbrödets": "vörtbröd",
    "vörtbröds": "vörtbröd",
    "vörten": "vört",
    "vörtens": "vört",
    "vörts": "vört",
    "vörtstyrkan": "vörtstyrka",
    "vörtstyrkans": "vörtstyrka",
    "vörtstyrkas": "vörtstyrka",
    "vörtstyrke": "vörtstyrka",
    "vörtstyrkor": "vörtstyrka",
    "vörtstyrkorna": "vörtstyrka",
    "vörtstyrkornas": "vörtstyrka",
    "vörtstyrkors": "vörtstyrka",
    "w-et": "w",
    "w-ets": "w",
    "w-n": "w",
    "w-na": "w",
    "w-nas": "w",
    "w-ns": "w",
    "w-t": "w",
    "w-ts": "w",
    "w:et": "w",
    "w:ets": "w",
    "w:n": "w",
    "w:na": "w",
    "w:nas": "w",
    "w:ns": "w",
    "w:s": "w",
    "w:t": "w",
    "w:ts": "w",
    "wafern": "wafer",
    "waferns": "wafer",
    "wafers": "wafer",
    "wafersarna": "wafer",
    "wafersarnas": "wafer",
    "wafersen": "wafer",
    "wafersens": "wafer",
    "wagonen": "wagon",
    "wagonens": "wagon",
    "wagoner": "wagon",
    "wagonerna": "wagon",
    "wagonernas": "wagon",
    "wagoners": "wagon",
    "wagons": "wagon",
    "wajangen": "wajang",
    "wajangens": "wajang",
    "wajangs": "wajang",
    "waldorfpedagogiken": "waldorfpedagogik",
    "waldorfpedagogikens": "waldorfpedagogik",
    "waldorfpedagogiks": "waldorfpedagogik",
    "walesar": "walesare",
    "walesaren": "walesare",
    "walesarens": "walesare",
    "walesares": "walesare",
    "walesarna": "walesare",
    "walesarnas": "walesare",
    "walesisk": "walesiska",
    "walesiska": "walesisk",
    "walesiskan": "walesiska",
    "walesiskans": "walesiska",
    "walesiskare": "walesisk",
    "walesiskares": "walesisk",
    "walesiskas": "walesiska",
    "walesiskast": "walesisk",
    "walesiskaste": "walesisk",
    "walesiskastes": "walesisk",
    "walesiskasts": "walesisk",
    "walesiske": "walesiska",
    "walesiskes": "walesisk",
    "walesiskor": "walesiska",
    "walesiskorna": "walesiska",
    "walesiskornas": "walesiska",
    "walesiskors": "walesiska",
    "walesisks": "walesisk",
    "walesiskt": "walesisk",
    "walesiskts": "walesisk",
    "walkie-talkien": "walkie-talkie",
    "walkie-talkiens": "walkie-talkie",
    "walkie-talkies": "walkie-talkie",
    "walkie-talkiesarna": "walkie-talkie",
    "walkie-talkiesarnas": "walkie-talkie",
    "walkie-talkiesen": "walkie-talkie",
    "walkie-talkiesens": "walkie-talkie",
    "walkovern": "walkover",
    "walkoverns": "walkover",
    "walkovers": "walkover",
    "wallraffad": "wallraffa",
    "wallraffade": "wallraffa",
    "wallraffades": "wallraffa",
    "wallraffads": "wallraffa",
    "wallraffande": "wallraffa",
    "wallraffanden": "wallraffande",
    "wallraffandena": "wallraffande",
    "wallraffandenas": "wallraffande",
    "wallraffandens": "wallraffande",
    "wallraffandes": "wallraffande",
    "wallraffandet": "wallraffande",
    "wallraffandets": "wallraffande",
    "wallraffar": "wallraffa",
    "wallraffas": "wallraffa",
    "wallraffat": "wallraffa",
    "wallraffats": "wallraffa",
    "wallraffningen": "wallraffning",
    "wallraffningens": "wallraffning",
    "wallraffnings": "wallraffning",
    "wankelmotorer": "wankelmotor",
    "wankelmotorerna": "wankelmotor",
    "wankelmotorernas": "wankelmotor",
    "wankelmotorers": "wankelmotor",
    "wankelmotorn": "wankelmotor",
    "wankelmotorns": "wankelmotor",
    "wankelmotors": "wankelmotor",
    "wasabin": "wasabi",
    "wasabins": "wasabi",
    "wasabis": "wasabi",
    "waterloos": "waterloo",
    "watten": "watt",
    "wattens": "watt",
    "watts": "watt",
    "wattsekunden": "wattsekund",
    "wattsekundens": "wattsekund",
    "wattsekunder": "wattsekund",
    "wattsekunderna": "wattsekund",
    "wattsekundernas": "wattsekund",
    "wattsekunders": "wattsekund",
    "wattsekunds": "wattsekund",
    "watusin": "watusi",
    "watusina": "watusi",
    "watusinas": "watusi",
    "watusins": "watusi",
    "watusis": "watusi",
    "watussin": "watussi",
    "watussina": "watussi",
    "watussinas": "watussi",
    "watussins": "watussi",
    "watussis": "watussi",
    "wc-ts": "wc",
    "wc:en": "wc",
    "wc:n": "wc",
    "wc:nas": "wc",
    "wc:s": "wc",
    "wc:t": "wc",
    "wcen": "wc",
    "wcens": "wc",
    "wcn": "wc",
    "wcna": "wc",
    "wcnas": "wc",
    "wcns": "wc",
    "wcs": "wc",
    "wct": "wc",
    "webb-TV-s": "webb-TV",
    "webb-TV:s": "webb-TV",
    "webb-TVs": "webb-TV",
    "webbdomänen": "webbdomän",
    "webbdomänens": "webbdomän",
    "webbdomäner": "webbdomän",
    "webbdomänerna": "webbdomän",
    "webbdomänernas": "webbdomän",
    "webbdomäners": "webbdomän",
    "webbdomäns": "webbdomän",
    "webben": "webb",
    "webbens": "webb",
    "webbkameran": "webbkamera",
    "webbkamerans": "webbkamera",
    "webbkameras": "webbkamera",
    "webbkameror": "webbkamera",
    "webbkamerorna": "webbkamera",
    "webbkamerornas": "webbkamera",
    "webbkamerors": "webbkamera",
    "webblänkar": "webblänk",
    "webblänkarna": "webblänk",
    "webblänkarnas": "webblänk",
    "webblänkars": "webblänk",
    "webblänken": "webblänk",
    "webblänkens": "webblänk",
    "webblänks": "webblänk",
    "webbläsar": "webbläsare",
    "webbläsaren": "webbläsare",
    "webbläsarens": "webbläsare",
    "webbläsares": "webbläsare",
    "webbläsarna": "webbläsare",
    "webbläsarnas": "webbläsare",
    "webbplatsen": "webbplats",
    "webbplatsens": "webbplats",
    "webbplatser": "webbplats",
    "webbplatserna": "webbplats",
    "webbplatsernas": "webbplats",
    "webbplatsers": "webbplats",
    "webbs": "webb",
    "webbsidan": "webbsida",
    "webbsidans": "webbsida",
    "webbsidas": "webbsida",
    "webbside": "webbsida",
    "webbsides": "webbsida",
    "webbsidor": "webbsida",
    "webbsidorna": "webbsida",
    "webbsidornas": "webbsida",
    "webbsidors": "webbsida",
    "webbsupporten": "webbsupport",
    "webbsupportens": "webbsupport",
    "webbsupports": "webbsupport",
    "webbtelevisionen": "webbtelevision",
    "webbtelevisionens": "webbtelevision",
    "webbtelevisions": "webbtelevision",
    "webbtesten": "webbtest",
    "webbtestens": "webbtest",
    "webbtester": "webbtest",
    "webbtesterna": "webbtest",
    "webbtesternas": "webbtest",
    "webbtesters": "webbtest",
    "webbtestet": "webbtest",
    "webbtestets": "webbtest",
    "webbtests": "webbtest",
    "webbteves": "webbteve",
    "webbtjänsten": "webbtjänst",
    "webbtjänstens": "webbtjänst",
    "webbtjänster": "webbtjänst",
    "webbtjänsterna": "webbtjänst",
    "webbtjänsternas": "webbtjänst",
    "webbtjänsters": "webbtjänst",
    "webbtjänsts": "webbtjänst",
    "weben": "web",
    "webens": "web",
    "webs": "web",
    "weekenden": "weekend",
    "weekendens": "weekend",
    "weekends": "weekend",
    "weekendsarna": "weekend",
    "weekendsarnas": "weekend",
    "weekendsen": "weekend",
    "weekendsens": "weekend",
    "wellpappen": "wellpapp",
    "wellpappens": "wellpapp",
    "wellpapps": "wellpapp",
    "weltervikten": "weltervikt",
    "welterviktens": "weltervikt",
    "weltervikts": "weltervikt",
    "weltschmerzen": "weltschmerz",
    "weltschmerzens": "weltschmerz",
    "westerna": "western",
    "westernas": "western",
    "westernfilmen": "westernfilm",
    "westernfilmens": "westernfilm",
    "westernfilmer": "westernfilm",
    "westernfilmerna": "westernfilm",
    "westernfilmernas": "westernfilm",
    "westernfilmers": "westernfilm",
    "westernfilms": "westernfilm",
    "westerns": "western",
    "whigen": "whig",
    "whigens": "whig",
    "whigs": "whig",
    "whigsarna": "whig",
    "whigsarnas": "whig",
    "whigsen": "whig",
    "whigsens": "whig",
    "whippetar": "whippet",
    "whippetarna": "whippet",
    "whippetarnas": "whippet",
    "whippetars": "whippet",
    "whippeten": "whippet",
    "whippetens": "whippet",
    "whippets": "whippet",
    "whiskybuteljen": "whiskybutelj",
    "whiskybuteljens": "whiskybutelj",
    "whiskybuteljer": "whiskybutelj",
    "whiskybuteljerna": "whiskybutelj",
    "whiskybuteljernas": "whiskybutelj",
    "whiskybuteljers": "whiskybutelj",
    "whiskybuteljs": "whiskybutelj",
    "whiskyn": "whisky",
    "whiskyns": "whisky",
    "whiskys": "whisky",
    "whiskysorten": "whiskysort",
    "whiskysortens": "whiskysort",
    "whiskysorter": "whiskysort",
    "whiskysorterna": "whiskysort",
    "whiskysorternas": "whiskysort",
    "whiskysorters": "whiskysort",
    "whiskysorts": "whiskysort",
    "whiskyspruckens": "whiskysprucken",
    "whiskysprucket": "whiskysprucken",
    "whiskyspruckets": "whiskysprucken",
    "whiskyspruckna": "whiskysprucken",
    "whiskysprucknare": "whiskysprucken",
    "whiskysprucknares": "whiskysprucken",
    "whiskysprucknas": "whiskysprucken",
    "whiskysprucknast": "whiskysprucken",
    "whiskysprucknaste": "whiskysprucken",
    "whiskysprucknastes": "whiskysprucken",
    "whiskysprucknasts": "whiskysprucken",
    "whiskyspruckne": "whiskysprucken",
    "whiskysprucknes": "whiskysprucken",
    "whisten": "whist",
    "whistens": "whist",
    "whists": "whist",
    "wienerbröden": "wienerbröd",
    "wienerbrödens": "wienerbröd",
    "wienerbrödet": "wienerbröd",
    "wienerbrödets": "wienerbröd",
    "wienerbröds": "wienerbröd",
    "wienerkorvar": "wienerkorv",
    "wienerkorvarna": "wienerkorv",
    "wienerkorvarnas": "wienerkorv",
    "wienerkorvars": "wienerkorv",
    "wienerkorven": "wienerkorv",
    "wienerkorvens": "wienerkorv",
    "wienerkorvs": "wienerkorv",
    "wienerschnitzeln": "wienerschnitzel",
    "wienerschnitzelns": "wienerschnitzel",
    "wienerschnitzels": "wienerschnitzel",
    "wienerschnitzlar": "wienerschnitzel",
    "wienerschnitzlarna": "wienerschnitzel",
    "wienerschnitzlarnas": "wienerschnitzel",
    "wienerschnitzlars": "wienerschnitzel",
    "wienervalsen": "wienervals",
    "wienervalsens": "wienervals",
    "wienervalser": "wienervals",
    "wienervalserna": "wienervals",
    "wienervalsernas": "wienervals",
    "wienervalsers": "wienervals",
    "wienklassicismen": "wienklassicism",
    "wienklassicismens": "wienklassicism",
    "wienklassicismer": "wienklassicism",
    "wienklassicismerna": "wienklassicism",
    "wienklassicismernas": "wienklassicism",
    "wienklassicismers": "wienklassicism",
    "wienklassicisms": "wienklassicism",
    "wienklassicistiska": "wienklassicistisk",
    "wienklassicistiskas": "wienklassicistisk",
    "wienklassicistiske": "wienklassicistisk",
    "wienklassicistiskes": "wienklassicistisk",
    "wienklassicistisks": "wienklassicistisk",
    "wienklassicistiskt": "wienklassicistisk",
    "wienklassicistiskts": "wienklassicistisk",
    "wigwamen": "wigwam",
    "wigwamens": "wigwam",
    "wigwamer": "wigwam",
    "wigwamerna": "wigwam",
    "wigwamernas": "wigwam",
    "wigwamers": "wigwam",
    "wigwams": "wigwam",
    "wikier": "wiki",
    "wikierna": "wiki",
    "wikiernas": "wiki",
    "wikiers": "wiki",
    "wikin": "wiki",
    "wikins": "wiki",
    "wikis": "wiki",
    "wikisarna": "wiki",
    "wikisarnas": "wiki",
    "wiltonmatt": "wiltonmatta",
    "wiltonmattan": "wiltonmatta",
    "wiltonmattans": "wiltonmatta",
    "wiltonmattas": "wiltonmatta",
    "wiltonmatte": "wiltonmatta",
    "wiltonmattor": "wiltonmatta",
    "wiltonmattorna": "wiltonmatta",
    "wiltonmattornas": "wiltonmatta",
    "wiltonmattors": "wiltonmatta",
    "wiltonmatts": "wiltonmatta",
    "wir": "wire",
    "wirar": "wire",
    "wirarna": "wire",
    "wirarnas": "wire",
    "wirars": "wire",
    "wiren": "wire",
    "wirens": "wire",
    "wires": "wire",
    "wirs": "wire",
    "wobblern": "wobbler",
    "wobblerna": "wobbler",
    "wobblernas": "wobbler",
    "wobblerns": "wobbler",
    "wobblers": "wobbler",
    "wobblersarna": "wobbler",
    "wobblersarnas": "wobbler",
    "wobblersen": "wobbler",
    "wobblersens": "wobbler",
    "wokar": "wok",
    "wokarna": "wok",
    "wokarnas": "wok",
    "wokars": "wok",
    "woken": "wok",
    "wokens": "wok",
    "woks": "wok",
    "wolframen": "wolfram",
    "wolframens": "wolfram",
    "wolframet": "wolfram",
    "wolframets": "wolfram",
    "wolframs": "wolfram",
    "worcestersåsen": "worcestersås",
    "worcestersåsens": "worcestersås",
    "worcestersåser": "worcestersås",
    "worcestersåserna": "worcestersås",
    "worcestersåsernas": "worcestersås",
    "worcestersåsers": "worcestersås",
    "workshopar": "workshop",
    "workshoparna": "workshop",
    "workshoparnas": "workshop",
    "workshopars": "workshop",
    "workshopen": "workshop",
    "workshopens": "workshop",
    "workshoper": "workshop",
    "workshoperna": "workshop",
    "workshopernas": "workshop",
    "workshopers": "workshop",
    "workshopn": "workshop",
    "workshopns": "workshop",
    "workshops": "workshop",
    "workshopsar": "workshop",
    "workshopsarna": "workshop",
    "workshopsarnas": "workshop",
    "workshopsars": "workshop",
    "www-s": "www",
    "x-ad": "x-a",
    "x-ade": "x-a",
    "x-ades": "x-a",
    "x-ads": "x-a",
    "x-ande": "x-a",
    "x-anden": "x-ande",
    "x-andena": "x-ande",
    "x-andenas": "x-ande",
    "x-andens": "x-ande",
    "x-andes": "x-ande",
    "x-andet": "x-ande",
    "x-andets": "x-ande",
    "x-ar": "x-a",
    "x-as": "x-a",
    "x-at": "x-a",
    "x-ats": "x-a",
    "x-axeln": "x-axel",
    "x-axelns": "x-axel",
    "x-axels": "x-axel",
    "x-axlar": "x-axel",
    "x-axlarna": "x-axel",
    "x-axlarnas": "x-axel",
    "x-axlars": "x-axel",
    "x-en": "x",
    "x-ens": "x",
    "x-et": "x",
    "x-ets": "x",
    "x-koordinaten": "x-koordinat",
    "x-koordinatens": "x-koordinat",
    "x-koordinater": "x-koordinat",
    "x-koordinaterna": "x-koordinat",
    "x-koordinaternas": "x-koordinat",
    "x-koordinaters": "x-koordinat",
    "x-koordinats": "x-koordinat",
    "x-kromosomens": "x-kromosom",
    "x-kromosomernas": "x-kromosom",
    "x-kromosomers": "x-kromosom",
    "x-kromosoms": "x-kromosom",
    "x-s": "x",
    "x:ad": "x:a",
    "x:ade": "x:a",
    "x:ades": "x:a",
    "x:ads": "x:a",
    "x:ande": "x:a",
    "x:anden": "x:ande",
    "x:andena": "x:ande",
    "x:andenas": "x:ande",
    "x:andens": "x:ande",
    "x:andes": "x:ande",
    "x:andet": "x:ande",
    "x:andets": "x:ande",
    "x:ar": "x:a",
    "x:as": "x:a",
    "x:at": "x:a",
    "x:ats": "x:a",
    "x:en": "x",
    "x:ens": "x",
    "x:et": "x",
    "x:ets": "x",
    "x:s": "x",
    "xantipp": "xantippa",
    "xantippan": "xantippa",
    "xantippans": "xantippa",
    "xantippas": "xantippa",
    "xantippe": "xantippa",
    "xantippor": "xantippa",
    "xantipporna": "xantippa",
    "xantippornas": "xantippa",
    "xantippors": "xantippa",
    "xantipps": "xantippa",
    "xantofyllet": "xantofyll",
    "xantofyllets": "xantofyll",
    "xantofylls": "xantofyll",
    "xen": "x",
    "xenofobien": "xenofobi",
    "xenofobiens": "xenofobi",
    "xenofobin": "xenofobi",
    "xenofobins": "xenofobi",
    "xenofobis": "xenofobi",
    "xenonet": "xenon",
    "xenonets": "xenon",
    "xenons": "xenon",
    "xens": "x",
    "xerografien": "xerografi",
    "xerografiens": "xerografi",
    "xerografin": "xerografi",
    "xerografins": "xerografi",
    "xerografis": "xerografi",
    "xerotinen": "xerotin",
    "xerotinens": "xerotin",
    "xerotinet": "xerotin",
    "xerotinets": "xerotin",
    "xerotins": "xerotin",
    "xet": "x",
    "xets": "x",
    "xien": "xi",
    "xiens": "xi",
    "xiet": "xi",
    "xiets": "xi",
    "xin": "xi",
    "xina": "xi",
    "xinas": "xi",
    "xins": "xi",
    "xis": "xi",
    "xit": "xi",
    "xits": "xi",
    "xs": "x",
    "xylofonen": "xylofon",
    "xylofonens": "xylofon",
    "xylofoner": "xylofon",
    "xylofonerna": "xylofon",
    "xylofonernas": "xylofon",
    "xylofoners": "xylofon",
    "xylofons": "xylofon",
    "xylografien": "xylografi",
    "xylografiens": "xylografi",
    "xylografier": "xylografi",
    "xylografierna": "xylografi",
    "xylografiernas": "xylografi",
    "xylografiers": "xylografi",
    "xylografin": "xylografi",
    "xylografins": "xylografi",
    "xylografis": "xylografi",
    "y-axeln": "y-axel",
    "y-axelns": "y-axel",
    "y-axels": "y-axel",
    "y-axlar": "y-axel",
    "y-axlarna": "y-axel",
    "y-axlarnas": "y-axel",
    "y-axlars": "y-axel",
    "y-et": "y",
    "y-ets": "y",
    "y-koordinaten": "y-koordinat",
    "y-koordinatens": "y-koordinat",
    "y-koordinater": "y-koordinat",
    "y-koordinaterna": "y-koordinat",
    "y-koordinaternas": "y-koordinat",
    "y-koordinaters": "y-koordinat",
    "y-koordinats": "y-koordinat",
    "y-kromosomens": "y-kromosom",
    "y-kromosomernas": "y-kromosom",
    "y-kromosomers": "y-kromosom",
    "y-kromosoms": "y-kromosom",
    "y-n": "y",
    "y-na": "y",
    "y-nas": "y",
    "y-ns": "y",
    "y-t": "y",
    "y-ts": "y",
    "y:et": "y",
    "y:ets": "y",
    "y:n": "y",
    "y:na": "y",
    "y:nas": "y",
    "y:ns": "y",
    "y:s": "y",
    "y:t": "y",
    "y:ts": "y",
    "yachten": "yacht",
    "yachtens": "yacht",
    "yachter": "yacht",
    "yachterna": "yacht",
    "yachternas": "yacht",
    "yachters": "yacht",
    "yachts": "yacht",
    "yakuzan": "yakuza",
    "yakuzans": "yakuza",
    "yakuzas": "yakuza",
    "yakuzor": "yakuza",
    "yakuzorna": "yakuza",
    "yakuzornas": "yakuza",
    "yakuzors": "yakuza",
    "yalelåsen": "yalelås",
    "yalelåset": "yalelås",
    "yankeejibbar": "yankeejib",
    "yankeejibbarna": "yankeejib",
    "yankeejibbarnas": "yankeejib",
    "yankeejibbars": "yankeejib",
    "yankeejibben": "yankeejib",
    "yankeejibbens": "yankeejib",
    "yankeejibs": "yankeejib",
    "yankeen": "yankee",
    "yankeens": "yankee",
    "yankeer": "yankee",
    "yankeerna": "yankee",
    "yankeernas": "yankee",
    "yankeers": "yankee",
    "yankees": "yankee",
    "yankeesen": "yankee",
    "yankeesens": "yankee",
    "yarden": "yard",
    "yardens": "yard",
    "yards": "yard",
    "yardsen": "yard",
    "yardsens": "yard",
    "yawlen": "yawl",
    "yawlens": "yawl",
    "yawler": "yawl",
    "yawlerna": "yawl",
    "yawlernas": "yawl",
    "yawlers": "yawl",
    "yawls": "yawl",
    "yenen": "yen",
    "yenens": "yen",
    "yens": "yen",
    "yl": "yla",
    "ylad": "yla",
    "ylade": "yla",
    "ylades": "yla",
    "ylads": "yla",
    "ylande": "yla",
    "ylanden": "ylande",
    "ylandena": "ylande",
    "ylandenas": "ylande",
    "ylandens": "ylande",
    "ylandes": "ylande",
    "ylandet": "ylande",
    "ylandets": "ylande",
    "ylar": "yla",
    "ylas": "yla",
    "ylat": "yla",
    "ylats": "yla",
    "ylet": "yl",
    "ylets": "yl",
    "yllelumpen": "yllelump",
    "yllelumpens": "yllelump",
    "yllelumpor": "yllelump",
    "yllelumporna": "yllelump",
    "yllelumpornas": "yllelump",
    "yllelumpors": "yllelump",
    "yllelumps": "yllelump",
    "yllens": "yllen",
    "ylles": "ylle",
    "yllestrump": "yllestrumpa",
    "yllestrumpan": "yllestrumpa",
    "yllestrumpans": "yllestrumpa",
    "yllestrumpas": "yllestrumpa",
    "yllestrumpe": "yllestrumpa",
    "yllestrumpor": "yllestrumpa",
    "yllestrumporna": "yllestrumpa",
    "yllestrumpornas": "yllestrumpa",
    "yllestrumpors": "yllestrumpa",
    "yllestrumps": "yllestrumpa",
    "yllet": "yllen",
    "yllets": "yllen",
    "ylletygen": "ylletyg",
    "ylletygens": "ylletyg",
    "ylletyger": "ylletyg",
    "ylletygerna": "ylletyg",
    "ylletygernas": "ylletyg",
    "ylletygers": "ylletyg",
    "ylletyget": "ylletyg",
    "ylletygets": "ylletyg",
    "ylletygs": "ylletyg",
    "yllevävnaden": "yllevävnad",
    "yllevävnadens": "yllevävnad",
    "yllevävnader": "yllevävnad",
    "yllevävnaderna": "yllevävnad",
    "yllevävnadernas": "yllevävnad",
    "yllevävnaders": "yllevävnad",
    "yllevävnads": "yllevävnad",
    "yllna": "yllen",
    "yllnare": "yllen",
    "yllnares": "yllen",
    "yllnas": "yllen",
    "yllnast": "yllen",
    "yllnaste": "yllen",
    "yllnastes": "yllen",
    "yllnasts": "yllen",
    "yllne": "yllen",
    "yllnes": "yllen",
    "yls": "yl",
    "ymniga": "ymnig",
    "ymnigare": "ymnig",
    "ymnigares": "ymnig",
    "ymnigas": "ymnig",
    "ymnigast": "ymnig",
    "ymnigaste": "ymnig",
    "ymnigastes": "ymnig",
    "ymnigasts": "ymnig",
    "ymnige": "ymnig",
    "ymniges": "ymnig",
    "ymnigheten": "ymnighet",
    "ymnighetens": "ymnighet",
    "ymnighets": "ymnighet",
    "ymnighetshornen": "ymnighetshorn",
    "ymnighetshornens": "ymnighetshorn",
    "ymnighetshornet": "ymnighetshorn",
    "ymnighetshornets": "ymnighetshorn",
    "ymnighetshorns": "ymnighetshorn",
    "ymnigs": "ymnig",
    "ymnigt": "ymnig",
    "ymnigts": "ymnig",
    "ymp": "ympa",
    "ympad": "ympa",
    "ympade": "ympa",
    "ympades": "ympa",
    "ympads": "ympa",
    "ympande": "ympa",
    "ympanden": "ympande",
    "ympandena": "ympande",
    "ympandenas": "ympande",
    "ympandens": "ympande",
    "ympandes": "ympande",
    "ympandet": "ympande",
    "ympandets": "ympande",
    "ympar": "ympa",
    "ymparna": "ymp",
    "ymparnas": "ymp",
    "ympars": "ymp",
    "ympas": "ympa",
    "ympat": "ympa",
    "ympats": "ympa",
    "ympen": "ymp",
    "ympens": "ymp",
    "ympkvistar": "ympkvist",
    "ympkvistarna": "ympkvist",
    "ympkvistarnas": "ympkvist",
    "ympkvistars": "ympkvist",
    "ympkvisten": "ympkvist",
    "ympkvistens": "ympkvist",
    "ympkvists": "ympkvist",
    "ympningar": "ympning",
    "ympningarna": "ympning",
    "ympningarnas": "ympning",
    "ympningars": "ympning",
    "ympningen": "ympning",
    "ympningens": "ympning",
    "ympnings": "ympning",
    "ympningsplikten": "ympningsplikt",
    "ympningspliktens": "ympningsplikt",
    "ympningsplikts": "ympningsplikt",
    "ymps": "ymp",
    "ympsnitten": "ympsnitt",
    "ympsnittens": "ympsnitt",
    "ympsnittet": "ympsnitt",
    "ympsnittets": "ympsnitt",
    "ympsnitts": "ympsnitt",
    "ympstammar": "ympstam",
    "ympstammarna": "ympstam",
    "ympstammarnas": "ympstam",
    "ympstammars": "ympstam",
    "ympstammen": "ympstam",
    "ympstammens": "ympstam",
    "ympstams": "ympstam",
    "ympsåren": "ympsår",
    "ympsårens": "ympsår",
    "ympsåret": "ympsår",
    "ympsårets": "ympsår",
    "ympsårs": "ympsår",
    "ymptvången": "ymptvång",
    "ymptvångens": "ymptvång",
    "ymptvånget": "ymptvång",
    "ymptvångets": "ymptvång",
    "ymptvångs": "ymptvång",
    "yngel": "yngla",
    "yngelcellen": "yngelcell",
    "yngelcellens": "yngelcell",
    "yngelceller": "yngelcell",
    "yngelcellerna": "yngelcell",
    "yngelcellernas": "yngelcell",
    "yngelcellers": "yngelcell",
    "yngelcells": "yngelcell",
    "yngeldammar": "yngeldamm",
    "yngeldammarna": "yngeldamm",
    "yngeldammarnas": "yngeldamm",
    "yngeldammars": "yngeldamm",
    "yngeldammen": "yngeldamm",
    "yngeldammens": "yngeldamm",
    "yngeldamms": "yngeldamm",
    "yngelkak": "yngelkaka",
    "yngelkakan": "yngelkaka",
    "yngelkakans": "yngelkaka",
    "yngelkakas": "yngelkaka",
    "yngelkake": "yngelkaka",
    "yngelkakor": "yngelkaka",
    "yngelkakorna": "yngelkaka",
    "yngelkakornas": "yngelkaka",
    "yngelkakors": "yngelkaka",
    "yngelkaks": "yngelkaka",
    "yngelrötan": "yngelröta",
    "yngelrötans": "yngelröta",
    "yngelrötas": "yngelröta",
    "yngelröte": "yngelröta",
    "yngels": "yngel",
    "yngelstadie": "yngelstadium",
    "yngelstadier": "yngelstadium",
    "yngelstadierna": "yngelstadium",
    "yngelstadiernas": "yngelstadium",
    "yngelstadiers": "yngelstadium",
    "yngelstadiet": "yngelstadium",
    "yngelstadiets": "yngelstadium",
    "yngelstadiums": "yngelstadium",
    "yngeltrågen": "yngeltråg",
    "yngeltrågens": "yngeltråg",
    "yngeltråget": "yngeltråg",
    "yngeltrågets": "yngeltråg",
    "yngeltrågs": "yngeltråg",
    "ynglade": "yngla",
    "ynglades": "yngla",
    "ynglande": "yngla",
    "ynglanden": "ynglande",
    "ynglandena": "ynglande",
    "ynglandenas": "ynglande",
    "ynglandens": "ynglande",
    "ynglandes": "ynglande",
    "ynglandet": "ynglande",
    "ynglandets": "ynglande",
    "ynglar": "yngla",
    "ynglas": "yngla",
    "ynglat": "yngla",
    "ynglats": "yngla",
    "ynglen": "yngel",
    "ynglens": "yngel",
    "ynglet": "yngel",
    "ynglets": "yngel",
    "ynglingalynnen": "ynglingalynne",
    "ynglingalynnena": "ynglingalynne",
    "ynglingalynnenas": "ynglingalynne",
    "ynglingalynnens": "ynglingalynne",
    "ynglingalynnes": "ynglingalynne",
    "ynglingalynnet": "ynglingalynne",
    "ynglingalynnets": "ynglingalynne",
    "ynglingalynns": "ynglingalynne",
    "ynglingar": "yngling",
    "ynglingarna": "yngling",
    "ynglingarnas": "yngling",
    "ynglingars": "yngling",
    "ynglingasinnen": "ynglingasinne",
    "ynglingasinnena": "ynglingasinne",
    "ynglingasinnenas": "ynglingasinne",
    "ynglingasinnens": "ynglingasinne",
    "ynglingasinnes": "ynglingasinne",
    "ynglingasinnet": "ynglingasinne",
    "ynglingasinnets": "ynglingasinne",
    "ynglingen": "yngling",
    "ynglingens": "yngling",
    "ynglings": "yngling",
    "yngre": "ung",
    "yngres": "ung",
    "yngst": "ung",
    "yngsta": "ung",
    "yngstas": "ung",
    "yngste": "ung",
    "yngstes": "ung",
    "yngsts": "ung",
    "ynk": "ynka",
    "ynkad": "ynka",
    "ynkade": "ynka",
    "ynkades": "ynka",
    "ynkads": "ynka",
    "ynkande": "ynka",
    "ynkanden": "ynkande",
    "ynkandena": "ynkande",
    "ynkandenas": "ynkande",
    "ynkandens": "ynkande",
    "ynkandes": "ynkande",
    "ynkandet": "ynkande",
    "ynkandets": "ynkande",
    "ynkansvärda": "ynkansvärd",
    "ynkansvärdare": "ynkansvärd",
    "ynkansvärdares": "ynkansvärd",
    "ynkansvärdas": "ynkansvärd",
    "ynkansvärdast": "ynkansvärd",
    "ynkansvärdaste": "ynkansvärd",
    "ynkansvärdastes": "ynkansvärd",
    "ynkansvärdasts": "ynkansvärd",
    "ynkansvärde": "ynkansvärd",
    "ynkansvärdes": "ynkansvärd",
    "ynkansvärdheten": "ynkansvärdhet",
    "ynkansvärdhetens": "ynkansvärdhet",
    "ynkansvärdhets": "ynkansvärdhet",
    "ynkansvärds": "ynkansvärd",
    "ynkansvärt": "ynkansvärd",
    "ynkansvärts": "ynkansvärd",
    "ynkar": "ynka",
    "ynkas": "ynka",
    "ynkat": "ynka",
    "ynkats": "ynka",
    "ynkedomar": "ynkedom",
    "ynkedomarna": "ynkedom",
    "ynkedomarnas": "ynkedom",
    "ynkedomars": "ynkedom",
    "ynkedomen": "ynkedom",
    "ynkedomens": "ynkedom",
    "ynkedoms": "ynkedom",
    "ynken": "ynk",
    "ynkens": "ynk",
    "ynket": "ynk",
    "ynkets": "ynk",
    "ynkliga": "ynklig",
    "ynkligare": "ynklig",
    "ynkligares": "ynklig",
    "ynkligas": "ynklig",
    "ynkligast": "ynklig",
    "ynkligaste": "ynklig",
    "ynkligastes": "ynklig",
    "ynkligasts": "ynklig",
    "ynklige": "ynklig",
    "ynkliges": "ynklig",
    "ynkligheten": "ynklighet",
    "ynklighetens": "ynklighet",
    "ynklighets": "ynklighet",
    "ynkligs": "ynklig",
    "ynkligt": "ynklig",
    "ynkligts": "ynklig",
    "ynkryggar": "ynkrygg",
    "ynkryggarna": "ynkrygg",
    "ynkryggarnas": "ynkrygg",
    "ynkryggars": "ynkrygg",
    "ynkryggen": "ynkrygg",
    "ynkryggens": "ynkrygg",
    "ynkryggs": "ynkrygg",
    "ynks": "ynk",
    "ynnestbetygelsen": "ynnestbetygelse",
    "ynnestbetygelsens": "ynnestbetygelse",
    "ynnestbetygelser": "ynnestbetygelse",
    "ynnestbetygelserna": "ynnestbetygelse",
    "ynnestbetygelsernas": "ynnestbetygelse",
    "ynnestbetygelsers": "ynnestbetygelse",
    "ynnestbetygelses": "ynnestbetygelse",
    "ynnestbevisen": "ynnestbevis",
    "ynnestbevisens": "ynnestbevis",
    "ynnestbeviset": "ynnestbevis",
    "ynnestbevisets": "ynnestbevis",
    "ynnesten": "ynnest",
    "ynnestens": "ynnest",
    "ynnestproven": "ynnestprov",
    "ynnestprovens": "ynnestprov",
    "ynnestprovet": "ynnestprov",
    "ynnestprovets": "ynnestprov",
    "ynnestprovs": "ynnestprov",
    "ynnests": "ynnest",
    "yogainstituten": "yogainstitut",
    "yogainstitutens": "yogainstitut",
    "yogainstitutet": "yogainstitut",
    "yogainstitutets": "yogainstitut",
    "yogainstituts": "yogainstitut",
    "yogan": "yoga",
    "yogans": "yoga",
    "yogas": "yoga",
    "yoghurten": "yoghurt",
    "yoghurtens": "yoghurt",
    "yoghurts": "yoghurt",
    "yogier": "yogi",
    "yogierna": "yogi",
    "yogiernas": "yogi",
    "yogiers": "yogi",
    "yogin": "yogi",
    "yogins": "yogi",
    "yogis": "yogi",
    "ypp": "yppa",
    "yppad": "yppa",
    "yppade": "yppa",
    "yppades": "yppa",
    "yppads": "yppa",
    "yppande": "yppa",
    "yppanden": "yppande",
    "yppandena": "yppande",
    "yppandenas": "yppande",
    "yppandens": "yppande",
    "yppandes": "yppande",
    "yppandet": "yppande",
    "yppandets": "yppande",
    "yppar": "yppa",
    "yppas": "yppa",
    "yppat": "yppa",
    "yppats": "yppa",
    "ypperliga": "ypperlig",
    "ypperligare": "ypperlig",
    "ypperligares": "ypperlig",
    "ypperligas": "ypperlig",
    "ypperligast": "ypperlig",
    "ypperligaste": "ypperlig",
    "ypperligastes": "ypperlig",
    "ypperligasts": "ypperlig",
    "ypperlige": "ypperlig",
    "ypperliges": "ypperlig",
    "ypperligheten": "ypperlighet",
    "ypperlighetens": "ypperlighet",
    "ypperligheter": "ypperlighet",
    "ypperligheterna": "ypperlighet",
    "ypperligheternas": "ypperlighet",
    "ypperligheters": "ypperlighet",
    "ypperlighets": "ypperlighet",
    "ypperligs": "ypperlig",
    "ypperligt": "ypperlig",
    "ypperligts": "ypperlig",
    "yppersta": "ypperst",
    "ypperstas": "ypperst",
    "ypperste": "ypperst",
    "ypperstes": "ypperst",
    "yppersts": "ypperst",
    "yppiga": "yppig",
    "yppigare": "yppig",
    "yppigares": "yppig",
    "yppigas": "yppig",
    "yppigast": "yppig",
    "yppigaste": "yppig",
    "yppigastes": "yppig",
    "yppigasts": "yppig",
    "yppige": "yppig",
    "yppiges": "yppig",
    "yppigheten": "yppighet",
    "yppighetens": "yppighet",
    "yppighets": "yppighet",
    "yppigs": "yppig",
    "yppigt": "yppig",
    "yppigts": "yppig",
    "ypsilonen": "ypsilon",
    "ypsilonens": "ypsilon",
    "ypsilonet": "ypsilon",
    "ypsilonets": "ypsilon",
    "ypsilons": "ypsilon",
    "yr": "yra",
    "yra": "yr",
    "yrade": "yra",
    "yrades": "yra",
    "yran": "yra",
    "yrande": "yra",
    "yranden": "yrande",
    "yrandena": "yrande",
    "yrandenas": "yrande",
    "yrandens": "yrande",
    "yrandes": "yrande",
    "yrandet": "yrande",
    "yrandets": "yrande",
    "yrans": "yra",
    "yrar": "yra",
    "yrare": "yr",
    "yrares": "yr",
    "yras": "yra",
    "yrast": "yr",
    "yraste": "yr",
    "yrastes": "yr",
    "yrasts": "yr",
    "yrat": "yra",
    "yrats": "yra",
    "yrd": "yra",
    "yrda": "yra",
    "yrdas": "yra",
    "yrde": "yra",
    "yrdes": "yra",
    "yrds": "yra",
    "yre": "yr",
    "yres": "yra",
    "yrheten": "yrhet",
    "yrhetens": "yrhet",
    "yrhets": "yrhet",
    "yrhätt": "yrhätta",
    "yrhättan": "yrhätta",
    "yrhättans": "yrhätta",
    "yrhättas": "yrhätta",
    "yrhätte": "yrhätta",
    "yrhättor": "yrhätta",
    "yrhättorna": "yrhätta",
    "yrhättornas": "yrhätta",
    "yrhättors": "yrhätta",
    "yrhätts": "yrhätta",
    "yrk": "yrka",
    "yrkad": "yrka",
    "yrkade": "yrka",
    "yrkades": "yrka",
    "yrkads": "yrka",
    "yrkande": "yrka",
    "yrkanden": "yrkande",
    "yrkandena": "yrkande",
    "yrkandenas": "yrkande",
    "yrkandens": "yrkande",
    "yrkandes": "yrkande",
    "yrkandet": "yrkande",
    "yrkandets": "yrkande",
    "yrkans": "yrkan",
    "yrkar": "yrka",
    "yrkas": "yrka",
    "yrkat": "yrka",
    "yrkats": "yrka",
    "yrken": "yrke",
    "yrkena": "yrke",
    "yrkenas": "yrke",
    "yrkens": "yrke",
    "yrkes": "yrke",
    "yrkesarbetar": "yrkesarbetare",
    "yrkesarbetaren": "yrkesarbetare",
    "yrkesarbetarens": "yrkesarbetare",
    "yrkesarbetares": "yrkesarbetare",
    "yrkesarbetarna": "yrkesarbetare",
    "yrkesarbetarnas": "yrkesarbetare",
    "yrkesarbeten": "yrkesarbete",
    "yrkesarbetena": "yrkesarbete",
    "yrkesarbetenas": "yrkesarbete",
    "yrkesarbetens": "yrkesarbete",
    "yrkesarbetes": "yrkesarbete",
    "yrkesarbetet": "yrkesarbete",
    "yrkesarbetets": "yrkesarbete",
    "yrkesarbets": "yrkesarbete",
    "yrkesarméer": "yrkesarmé",
    "yrkesarméerna": "yrkesarmé",
    "yrkesarméernas": "yrkesarmé",
    "yrkesarméers": "yrkesarmé",
    "yrkesarmén": "yrkesarmé",
    "yrkesarméns": "yrkesarmé",
    "yrkesarmés": "yrkesarmé",
    "yrkesetiken": "yrkesetik",
    "yrkesetikens": "yrkesetik",
    "yrkesetiker": "yrkesetik",
    "yrkesetikerna": "yrkesetik",
    "yrkesetikernas": "yrkesetik",
    "yrkesetikers": "yrkesetik",
    "yrkesetiks": "yrkesetik",
    "yrkesetiska": "yrkesetisk",
    "yrkesetiskare": "yrkesetisk",
    "yrkesetiskares": "yrkesetisk",
    "yrkesetiskas": "yrkesetisk",
    "yrkesetiskast": "yrkesetisk",
    "yrkesetiskaste": "yrkesetisk",
    "yrkesetiskastes": "yrkesetisk",
    "yrkesetiskasts": "yrkesetisk",
    "yrkesetiske": "yrkesetisk",
    "yrkesetiskes": "yrkesetisk",
    "yrkesetisks": "yrkesetisk",
    "yrkesetiskt": "yrkesetisk",
    "yrkesetiskts": "yrkesetisk",
    "yrkesfiskes": "yrkesfiske",
    "yrkesfisket": "yrkesfiske",
    "yrkesfiskets": "yrkesfiske",
    "yrkesfysikern": "yrkesfysiker",
    "yrkesfysikerna": "yrkesfysiker",
    "yrkesfysikernas": "yrkesfysiker",
    "yrkesfysikerns": "yrkesfysiker",
    "yrkesfysikers": "yrkesfysiker",
    "yrkesförbuden": "yrkesförbud",
    "yrkesförbudens": "yrkesförbud",
    "yrkesförbudet": "yrkesförbud",
    "yrkesförbudets": "yrkesförbud",
    "yrkesförbuds": "yrkesförbud",
    "yrkesgruppen": "yrkesgrupp",
    "yrkesgruppens": "yrkesgrupp",
    "yrkesgrupper": "yrkesgrupp",
    "yrkesgrupperna": "yrkesgrupp",
    "yrkesgruppernas": "yrkesgrupp",
    "yrkesgruppers": "yrkesgrupp",
    "yrkesgrupps": "yrkesgrupp",
    "yrkeshedern": "yrkesheder",
    "yrkeshederns": "yrkesheder",
    "yrkesheders": "yrkesheder",
    "yrkeshemligheten": "yrkeshemlighet",
    "yrkeshemlighetens": "yrkeshemlighet",
    "yrkeshemligheter": "yrkeshemlighet",
    "yrkeshemligheterna": "yrkeshemlighet",
    "yrkeshemligheternas": "yrkeshemlighet",
    "yrkeshemligheters": "yrkeshemlighet",
    "yrkeshemlighets": "yrkeshemlighet",
    "yrkeshygienen": "yrkeshygien",
    "yrkeshygienens": "yrkeshygien",
    "yrkeshygiens": "yrkeshygien",
    "yrkesinspektionen": "yrkesinspektion",
    "yrkesinspektionens": "yrkesinspektion",
    "yrkesinspektioner": "yrkesinspektion",
    "yrkesinspektionerna": "yrkesinspektion",
    "yrkesinspektionernas": "yrkesinspektion",
    "yrkesinspektioners": "yrkesinspektion",
    "yrkesinspektions": "yrkesinspektion",
    "yrkeskodexar": "yrkeskodex",
    "yrkeskodexarna": "yrkeskodex",
    "yrkeskodexarnas": "yrkeskodex",
    "yrkeskodexars": "yrkeskodex",
    "yrkeskodexen": "yrkeskodex",
    "yrkeskodexens": "yrkeskodex",
    "yrkeskollegan": "yrkeskollega",
    "yrkeskollegans": "yrkeskollega",
    "yrkeskollegas": "yrkeskollega",
    "yrkeskolleger": "yrkeskollega",
    "yrkeskollegerna": "yrkeskollega",
    "yrkeskollegernas": "yrkeskollega",
    "yrkeskollegers": "yrkeskollega",
    "yrkeskollegor": "yrkeskollega",
    "yrkeskollegorna": "yrkeskollega",
    "yrkeskollegornas": "yrkeskollega",
    "yrkeskollegors": "yrkeskollega",
    "yrkeskvinnan": "yrkeskvinna",
    "yrkeskvinnans": "yrkeskvinna",
    "yrkeskvinnas": "yrkeskvinna",
    "yrkeskvinne": "yrkeskvinna",
    "yrkeskvinno": "yrkeskvinna",
    "yrkeskvinnor": "yrkeskvinna",
    "yrkeskvinnorna": "yrkeskvinna",
    "yrkeskvinnornas": "yrkeskvinna",
    "yrkeskvinnors": "yrkeskvinna",
    "yrkeskåren": "yrkeskår",
    "yrkeskårens": "yrkeskår",
    "yrkeskårer": "yrkeskår",
    "yrkeskårerna": "yrkeskår",
    "yrkeskårernas": "yrkeskår",
    "yrkeskårers": "yrkeskår",
    "yrkeskårs": "yrkeskår",
    "yrkesliven": "yrkesliv",
    "yrkeslivens": "yrkesliv",
    "yrkeslivet": "yrkesliv",
    "yrkeslivets": "yrkesliv",
    "yrkeslivs": "yrkesliv",
    "yrkeslärar": "yrkeslärare",
    "yrkesläraren": "yrkeslärare",
    "yrkeslärarens": "yrkeslärare",
    "yrkeslärares": "yrkeslärare",
    "yrkeslärarna": "yrkeslärare",
    "yrkeslärarnas": "yrkeslärare",
    "yrkesmannen": "yrkesman",
    "yrkesmannens": "yrkesman",
    "yrkesmans": "yrkesman",
    "yrkesmän": "yrkesman",
    "yrkesmännen": "yrkesman",
    "yrkesmännens": "yrkesman",
    "yrkesmäns": "yrkesman",
    "yrkesmässiga": "yrkesmässig",
    "yrkesmässigare": "yrkesmässig",
    "yrkesmässigares": "yrkesmässig",
    "yrkesmässigas": "yrkesmässig",
    "yrkesmässigast": "yrkesmässig",
    "yrkesmässigaste": "yrkesmässig",
    "yrkesmässigastes": "yrkesmässig",
    "yrkesmässigasts": "yrkesmässig",
    "yrkesmässige": "yrkesmässig",
    "yrkesmässiges": "yrkesmässig",
    "yrkesmässigheten": "yrkesmässighet",
    "yrkesmässighetens": "yrkesmässighet",
    "yrkesmässighets": "yrkesmässighet",
    "yrkesmässigs": "yrkesmässig",
    "yrkesmässigt": "yrkesmässig",
    "yrkesmässigts": "yrkesmässig",
    "yrkesorienteringar": "yrkesorientering",
    "yrkesorienteringarna": "yrkesorientering",
    "yrkesorienteringarnas": "yrkesorientering",
    "yrkesorienteringars": "yrkesorientering",
    "yrkesorienteringen": "yrkesorientering",
    "yrkesorienteringens": "yrkesorientering",
    "yrkesorienterings": "yrkesorientering",
    "yrkespraktiken": "yrkespraktik",
    "yrkespraktikens": "yrkespraktik",
    "yrkespraktiker": "yrkespraktik",
    "yrkespraktikerna": "yrkespraktik",
    "yrkespraktikernas": "yrkespraktik",
    "yrkespraktikers": "yrkespraktik",
    "yrkespraktiks": "yrkespraktik",
    "yrkesregisterna": "yrkesregister",
    "yrkesregisternas": "yrkesregister",
    "yrkesregisters": "yrkesregister",
    "yrkesregistren": "yrkesregister",
    "yrkesregistrens": "yrkesregister",
    "yrkesregistret": "yrkesregister",
    "yrkesregistrets": "yrkesregister",
    "yrkessjukdomar": "yrkessjukdom",
    "yrkessjukdomarna": "yrkessjukdom",
    "yrkessjukdomarnas": "yrkessjukdom",
    "yrkessjukdomars": "yrkessjukdom",
    "yrkessjukdomen": "yrkessjukdom",
    "yrkessjukdomens": "yrkessjukdom",
    "yrkessjukdoms": "yrkessjukdom",
    "yrkesskadan": "yrkesskada",
    "yrkesskadans": "yrkesskada",
    "yrkesskadas": "yrkesskada",
    "yrkesskade": "yrkesskada",
    "yrkesskador": "yrkesskada",
    "yrkesskadorna": "yrkesskada",
    "yrkesskadornas": "yrkesskada",
    "yrkesskadors": "yrkesskada",
    "yrkesskickliga": "yrkesskicklig",
    "yrkesskickligare": "yrkesskicklig",
    "yrkesskickligares": "yrkesskicklig",
    "yrkesskickligas": "yrkesskicklig",
    "yrkesskickligast": "yrkesskicklig",
    "yrkesskickligaste": "yrkesskicklig",
    "yrkesskickligastes": "yrkesskicklig",
    "yrkesskickligasts": "yrkesskicklig",
    "yrkesskicklige": "yrkesskicklig",
    "yrkesskickliges": "yrkesskicklig",
    "yrkesskickligheten": "yrkesskicklighet",
    "yrkesskicklighetens": "yrkesskicklighet",
    "yrkesskicklighets": "yrkesskicklighet",
    "yrkesskickligs": "yrkesskicklig",
    "yrkesskickligt": "yrkesskicklig",
    "yrkesskickligts": "yrkesskicklig",
    "yrkesskolan": "yrkesskola",
    "yrkesskolans": "yrkesskola",
    "yrkesskolas": "yrkesskola",
    "yrkesskole": "yrkesskola",
    "yrkesskolor": "yrkesskola",
    "yrkesskolorna": "yrkesskola",
    "yrkesskolornas": "yrkesskola",
    "yrkesskolors": "yrkesskola",
    "yrkestiteln": "yrkestitel",
    "yrkestitelns": "yrkestitel",
    "yrkestitels": "yrkestitel",
    "yrkestitlar": "yrkestitel",
    "yrkestitlarna": "yrkestitel",
    "yrkestitlarnas": "yrkestitel",
    "yrkestitlars": "yrkestitel",
    "yrkestrafiken": "yrkestrafik",
    "yrkestrafikens": "yrkestrafik",
    "yrkestrafiks": "yrkestrafik",
    "yrkesutbildade": "yrkesutbildad",
    "yrkesutbildades": "yrkesutbildad",
    "yrkesutbildads": "yrkesutbildad",
    "yrkesutbildat": "yrkesutbildad",
    "yrkesutbildats": "yrkesutbildad",
    "yrkesutbildningar": "yrkesutbildning",
    "yrkesutbildningarna": "yrkesutbildning",
    "yrkesutbildningarnas": "yrkesutbildning",
    "yrkesutbildningars": "yrkesutbildning",
    "yrkesutbildningen": "yrkesutbildning",
    "yrkesutbildningens": "yrkesutbildning",
    "yrkesutbildnings": "yrkesutbildning",
    "yrkesvalen": "yrkesval",
    "yrkesvalens": "yrkesval",
    "yrkesvalet": "yrkesval",
    "yrkesvalets": "yrkesval",
    "yrkesvals": "yrkesval",
    "yrkesverksamheten": "yrkesverksamhet",
    "yrkesverksamhetens": "yrkesverksamhet",
    "yrkesverksamhets": "yrkesverksamhet",
    "yrkesverksamma": "yrkesverksam",
    "yrkesverksammare": "yrkesverksam",
    "yrkesverksammares": "yrkesverksam",
    "yrkesverksammas": "yrkesverksam",
    "yrkesverksammast": "yrkesverksam",
    "yrkesverksammaste": "yrkesverksam",
    "yrkesverksammastes": "yrkesverksam",
    "yrkesverksammasts": "yrkesverksam",
    "yrkesverksamme": "yrkesverksam",
    "yrkesverksammes": "yrkesverksam",
    "yrkesverksams": "yrkesverksam",
    "yrkesverksamt": "yrkesverksam",
    "yrkesverksamts": "yrkesverksam",
    "yrkesvägledar": "yrkesvägledare",
    "yrkesvägledaren": "yrkesvägledare",
    "yrkesvägledarens": "yrkesvägledare",
    "yrkesvägledares": "yrkesvägledare",
    "yrkesvägledarna": "yrkesvägledare",
    "yrkesvägledarnas": "yrkesvägledare",
    "yrkesvägledningar": "yrkesvägledning",
    "yrkesvägledningarna": "yrkesvägledning",
    "yrkesvägledningarnas": "yrkesvägledning",
    "yrkesvägledningars": "yrkesvägledning",
    "yrkesvägledningen": "yrkesvägledning",
    "yrkesvägledningens": "yrkesvägledning",
    "yrkesväglednings": "yrkesvägledning",
    "yrket": "yrke",
    "yrkets": "yrke",
    "yrs": "yra",
    "yrseln": "yrsel",
    "yrselns": "yrsel",
    "yrsels": "yrsel",
    "yrsnön": "yrsnö",
    "yrsnöns": "yrsnö",
    "yrsnös": "yrsnö",
    "yrt": "yra",
    "yrts": "yra",
    "yrvakens": "yrvaken",
    "yrvaket": "yrvaken",
    "yrvakets": "yrvaken",
    "yrvakna": "yrvaken",
    "yrvaknare": "yrvaken",
    "yrvaknares": "yrvaken",
    "yrvaknas": "yrvaken",
    "yrvaknast": "yrvaken",
    "yrvaknaste": "yrvaken",
    "yrvaknastes": "yrvaken",
    "yrvaknasts": "yrvaken",
    "yrvakne": "yrvaken",
    "yrvaknes": "yrvaken",
    "yrväderna": "yrväder",
    "yrvädernas": "yrväder",
    "yrväders": "yrväder",
    "yrvädren": "yrväder",
    "yrvädrens": "yrväder",
    "yrvädret": "yrväder",
    "yrvädrets": "yrväder",
    "yst": "yste",
    "ystad": "ysta",
    "ystade": "ysta",
    "ystades": "ysta",
    "ystads": "ysta",
    "ystande": "ysta",
    "ystanden": "ystande",
    "ystandena": "ystande",
    "ystandenas": "ystande",
    "ystandens": "ystande",
    "ystandes": "ystande",
    "ystandet": "ystande",
    "ystandets": "ystande",
    "ystar": "ysta",
    "ystas": "ysta",
    "ystat": "ysta",
    "ystats": "ysta",
    "ysten": "yste",
    "ystena": "yste",
    "ystenas": "yste",
    "ystens": "yste",
    "ysterheten": "ysterhet",
    "ysterhetens": "ysterhet",
    "ysterhets": "ysterhet",
    "ysters": "yster",
    "ystert": "yster",
    "ysterts": "yster",
    "ystes": "yste",
    "ystet": "yste",
    "ystets": "yste",
    "ystra": "yster",
    "ystrare": "yster",
    "ystrares": "yster",
    "ystras": "yster",
    "ystrast": "yster",
    "ystraste": "yster",
    "ystrastes": "yster",
    "ystrasts": "yster",
    "ystre": "yster",
    "ystres": "yster",
    "yt": "yta",
    "ytaktiva": "ytaktiv",
    "ytaktivare": "ytaktiv",
    "ytaktivares": "ytaktiv",
    "ytaktivas": "ytaktiv",
    "ytaktivast": "ytaktiv",
    "ytaktivaste": "ytaktiv",
    "ytaktivastes": "ytaktiv",
    "ytaktivasts": "ytaktiv",
    "ytaktive": "ytaktiv",
    "ytaktives": "ytaktiv",
    "ytaktivs": "ytaktiv",
    "ytaktivt": "ytaktiv",
    "ytaktivts": "ytaktiv",
    "ytan": "yta",
    "ytans": "yta",
    "ytas": "yta",
    "ytavvägningar": "ytavvägning",
    "ytavvägningarna": "ytavvägning",
    "ytavvägningarnas": "ytavvägning",
    "ytavvägningars": "ytavvägning",
    "ytavvägningen": "ytavvägning",
    "ytavvägningens": "ytavvägning",
    "ytavvägnings": "ytavvägning",
    "ytbehandlad": "ytbehandla",
    "ytbehandlade": "ytbehandla",
    "ytbehandlades": "ytbehandla",
    "ytbehandlads": "ytbehandla",
    "ytbehandlande": "ytbehandla",
    "ytbehandlanden": "ytbehandlande",
    "ytbehandlandena": "ytbehandlande",
    "ytbehandlandenas": "ytbehandlande",
    "ytbehandlandens": "ytbehandlande",
    "ytbehandlandes": "ytbehandlande",
    "ytbehandlandet": "ytbehandlande",
    "ytbehandlandets": "ytbehandlande",
    "ytbehandlar": "ytbehandla",
    "ytbehandlas": "ytbehandla",
    "ytbehandlat": "ytbehandla",
    "ytbehandlats": "ytbehandla",
    "ytbergarten": "ytbergart",
    "ytbergartens": "ytbergart",
    "ytbergarter": "ytbergart",
    "ytbergarterna": "ytbergart",
    "ytbergarternas": "ytbergart",
    "ytbergarters": "ytbergart",
    "ytbergarts": "ytbergart",
    "yte": "yta",
    "yteffekten": "yteffekt",
    "yteffektens": "yteffekt",
    "yteffekter": "yteffekt",
    "yteffekterna": "yteffekt",
    "yteffekternas": "yteffekt",
    "yteffekters": "yteffekt",
    "yteffekts": "yteffekt",
    "ytelden": "yteld",
    "yteldens": "yteld",
    "ytelds": "yteld",
    "ytenheten": "ytenhet",
    "ytenhetens": "ytenhet",
    "ytenheter": "ytenhet",
    "ytenheterna": "ytenhet",
    "ytenheternas": "ytenhet",
    "ytenheters": "ytenhet",
    "ytenhets": "ytenhet",
    "ytformen": "ytform",
    "ytformens": "ytform",
    "ytformer": "ytform",
    "ytformerna": "ytform",
    "ytformernas": "ytform",
    "ytformers": "ytform",
    "ytforms": "ytform",
    "ytlagerna": "ytlager",
    "ytlagernas": "ytlager",
    "ytlagers": "ytlager",
    "ytlagren": "ytlager",
    "ytlagrens": "ytlager",
    "ytlagret": "ytlager",
    "ytlagrets": "ytlager",
    "ytliga": "ytlig",
    "ytligare": "ytlig",
    "ytligares": "ytlig",
    "ytligas": "ytlig",
    "ytligast": "ytlig",
    "ytligaste": "ytlig",
    "ytligastes": "ytlig",
    "ytligasts": "ytlig",
    "ytlige": "ytlig",
    "ytliges": "ytlig",
    "ytligheten": "ytlighet",
    "ytlighetens": "ytlighet",
    "ytligheter": "ytlighet",
    "ytligheterna": "ytlighet",
    "ytligheternas": "ytlighet",
    "ytligheters": "ytlighet",
    "ytlighets": "ytlighet",
    "ytligs": "ytlig",
    "ytligt": "ytlig",
    "ytligts": "ytlig",
    "ytmoränen": "ytmorän",
    "ytmoränens": "ytmorän",
    "ytmoräner": "ytmorän",
    "ytmoränerna": "ytmorän",
    "ytmoränernas": "ytmorän",
    "ytmoräners": "ytmorän",
    "ytmoräns": "ytmorän",
    "ytmässiga": "ytmässig",
    "ytmässigare": "ytmässig",
    "ytmässigares": "ytmässig",
    "ytmässigas": "ytmässig",
    "ytmässigast": "ytmässig",
    "ytmässigaste": "ytmässig",
    "ytmässigastes": "ytmässig",
    "ytmässigasts": "ytmässig",
    "ytmässige": "ytmässig",
    "ytmässiges": "ytmässig",
    "ytmässigs": "ytmässig",
    "ytmässigt": "ytmässig",
    "ytmässigts": "ytmässig",
    "ytmåtten": "ytmått",
    "ytmåttens": "ytmått",
    "ytmåttet": "ytmått",
    "ytmåttets": "ytmått",
    "ytmåtts": "ytmått",
    "ytor": "yta",
    "ytorna": "yta",
    "ytornas": "yta",
    "ytors": "yta",
    "yts": "yta",
    "ytskikten": "ytskikt",
    "ytskiktens": "ytskikt",
    "ytskiktet": "ytskikt",
    "ytskiktets": "ytskikt",
    "ytskikts": "ytskikt",
    "ytspänningar": "ytspänning",
    "ytspänningarna": "ytspänning",
    "ytspänningarnas": "ytspänning",
    "ytspänningars": "ytspänning",
    "ytspänningen": "ytspänning",
    "ytspänningens": "ytspänning",
    "ytspännings": "ytspänning",
    "ytstrukturen": "ytstruktur",
    "ytstrukturens": "ytstruktur",
    "ytstrukturer": "ytstruktur",
    "ytstrukturerna": "ytstruktur",
    "ytstrukturernas": "ytstruktur",
    "ytstrukturers": "ytstruktur",
    "ytstrukturs": "ytstruktur",
    "ytterbanan": "ytterbana",
    "ytterbanans": "ytterbana",
    "ytterbanas": "ytterbana",
    "ytterbane": "ytterbana",
    "ytterbanor": "ytterbana",
    "ytterbanorna": "ytterbana",
    "ytterbanornas": "ytterbana",
    "ytterbanors": "ytterbana",
    "ytterbiet": "ytterbium",
    "ytterbiets": "ytterbium",
    "ytterbiumet": "ytterbium",
    "ytterbiumets": "ytterbium",
    "ytterbiums": "ytterbium",
    "ytterdelar": "ytterdel",
    "ytterdelarna": "ytterdel",
    "ytterdelarnas": "ytterdel",
    "ytterdelars": "ytterdel",
    "ytterdelen": "ytterdel",
    "ytterdelens": "ytterdel",
    "ytterdels": "ytterdel",
    "ytterdörrar": "ytterdörr",
    "ytterdörrarna": "ytterdörr",
    "ytterdörrarnas": "ytterdörr",
    "ytterdörrars": "ytterdörr",
    "ytterdörren": "ytterdörr",
    "ytterdörrens": "ytterdörr",
    "ytterdörrhandtagen": "ytterdörrhandtag",
    "ytterdörrhandtagens": "ytterdörrhandtag",
    "ytterdörrhandtaget": "ytterdörrhandtag",
    "ytterdörrhandtagets": "ytterdörrhandtag",
    "ytterdörrhandtags": "ytterdörrhandtag",
    "ytterdörrs": "ytterdörr",
    "ytterfacken": "ytterfack",
    "ytterfackens": "ytterfack",
    "ytterfacket": "ytterfack",
    "ytterfackets": "ytterfack",
    "ytterfacks": "ytterfack",
    "ytterfick": "ytterficka",
    "ytterfickan": "ytterficka",
    "ytterfickans": "ytterficka",
    "ytterfickas": "ytterficka",
    "ytterficke": "ytterficka",
    "ytterfickor": "ytterficka",
    "ytterfickorna": "ytterficka",
    "ytterfickornas": "ytterficka",
    "ytterfickors": "ytterficka",
    "ytterficks": "ytterficka",
    "ytterfoderna": "ytterfoder",
    "ytterfodernas": "ytterfoder",
    "ytterfoders": "ytterfoder",
    "ytterfodren": "ytterfoder",
    "ytterfodrens": "ytterfoder",
    "ytterfodret": "ytterfoder",
    "ytterfodrets": "ytterfoder",
    "ytterhuden": "ytterhud",
    "ytterhudens": "ytterhud",
    "ytterhuds": "ytterhud",
    "ytterhöljen": "ytterhölje",
    "ytterhöljena": "ytterhölje",
    "ytterhöljenas": "ytterhölje",
    "ytterhöljens": "ytterhölje",
    "ytterhöljes": "ytterhölje",
    "ytterhöljet": "ytterhölje",
    "ytterhöljets": "ytterhölje",
    "ytterhöljs": "ytterhölje",
    "ytterkanten": "ytterkant",
    "ytterkantens": "ytterkant",
    "ytterkanter": "ytterkant",
    "ytterkanterna": "ytterkant",
    "ytterkanternas": "ytterkant",
    "ytterkanters": "ytterkant",
    "ytterkants": "ytterkant",
    "ytterkläderna": "ytterkläder",
    "ytterklädernas": "ytterkläder",
    "ytterkläders": "ytterkläder",
    "ytterklädes": "ytterkläder",
    "ytterkläds": "ytterkläder",
    "ytterkurv": "ytterkurva",
    "ytterkurvan": "ytterkurva",
    "ytterkurvans": "ytterkurva",
    "ytterkurvas": "ytterkurva",
    "ytterkurve": "ytterkurva",
    "ytterkurvor": "ytterkurva",
    "ytterkurvorna": "ytterkurva",
    "ytterkurvornas": "ytterkurva",
    "ytterkurvors": "ytterkurva",
    "ytterkurvs": "ytterkurva",
    "ytterliga": "ytterlig",
    "ytterligare": "ytterlig",
    "ytterligares": "ytterlig",
    "ytterligas": "ytterlig",
    "ytterligast": "ytterlig",
    "ytterligaste": "ytterlig",
    "ytterligastes": "ytterlig",
    "ytterligasts": "ytterlig",
    "ytterlige": "ytterlig",
    "ytterliges": "ytterlig",
    "ytterligheten": "ytterlighet",
    "ytterlighetens": "ytterlighet",
    "ytterligheter": "ytterlighet",
    "ytterligheterna": "ytterlighet",
    "ytterligheternas": "ytterlighet",
    "ytterligheters": "ytterlighet",
    "ytterlighets": "ytterlighet",
    "ytterlighetsriktningar": "ytterlighetsriktning",
    "ytterlighetsriktningarna": "ytterlighetsriktning",
    "ytterlighetsriktningarnas": "ytterlighetsriktning",
    "ytterlighetsriktningars": "ytterlighetsriktning",
    "ytterlighetsriktningen": "ytterlighetsriktning",
    "ytterlighetsriktningens": "ytterlighetsriktning",
    "ytterlighetsriktnings": "ytterlighetsriktning",
    "ytterligs": "ytterlig",
    "ytterligt": "ytterlig",
    "ytterligts": "ytterlig",
    "yttermarginalen": "yttermarginal",
    "yttermarginalens": "yttermarginal",
    "yttermarginaler": "yttermarginal",
    "yttermarginalerna": "yttermarginal",
    "yttermarginalernas": "yttermarginal",
    "yttermarginalers": "yttermarginal",
    "yttermarginals": "yttermarginal",
    "yttern": "ytter",
    "ytterns": "ytter",
    "ytterområden": "ytterområde",
    "ytterområdena": "ytterområde",
    "ytterområdenas": "ytterområde",
    "ytterområdens": "ytterområde",
    "ytterområdes": "ytterområde",
    "ytterområdet": "ytterområde",
    "ytterområdets": "ytterområde",
    "ytterplaggen": "ytterplagg",
    "ytterplaggens": "ytterplagg",
    "ytterplagget": "ytterplagg",
    "ytterplaggets": "ytterplagg",
    "ytterplaggs": "ytterplagg",
    "ytterrockar": "ytterrock",
    "ytterrockarna": "ytterrock",
    "ytterrockarnas": "ytterrock",
    "ytterrockars": "ytterrock",
    "ytterrocken": "ytterrock",
    "ytterrockens": "ytterrock",
    "ytterrocks": "ytterrock",
    "ytters": "ytter",
    "ytterskären": "ytterskär",
    "ytterskärens": "ytterskär",
    "ytterskäret": "ytterskär",
    "ytterskärets": "ytterskär",
    "ytterskärs": "ytterskär",
    "ytterspåret": "ytterspår",
    "ytterspårets": "ytterspår",
    "ytterspårs": "ytterspår",
    "yttersta": "yttre",
    "ytterstas": "yttre",
    "ytterste": "yttre",
    "ytterstes": "yttre",
    "yttersul": "yttersula",
    "yttersulan": "yttersula",
    "yttersulans": "yttersula",
    "yttersulas": "yttersula",
    "yttersule": "yttersula",
    "yttersulor": "yttersula",
    "yttersulorna": "yttersula",
    "yttersulornas": "yttersula",
    "yttersulors": "yttersula",
    "yttersuls": "yttersula",
    "yttertaken": "yttertak",
    "yttertakens": "yttertak",
    "yttertaket": "yttertak",
    "yttertakets": "yttertak",
    "yttertaks": "yttertak",
    "yttervinkeln": "yttervinkel",
    "yttervinkelns": "yttervinkel",
    "yttervinkels": "yttervinkel",
    "yttervinklar": "yttervinkel",
    "yttervinklarna": "yttervinkel",
    "yttervinklarnas": "yttervinkel",
    "yttervinklars": "yttervinkel",
    "yttervärldar": "yttervärld",
    "yttervärldarna": "yttervärld",
    "yttervärldarnas": "yttervärld",
    "yttervärldars": "yttervärld",
    "yttervärlden": "yttervärld",
    "yttervärldens": "yttervärld",
    "yttervärlds": "yttervärld",
    "ytteröras": "ytteröra",
    "ytterörat": "ytteröra",
    "ytterörats": "ytteröra",
    "ytteröron": "ytteröra",
    "ytteröronen": "ytteröra",
    "ytteröronens": "ytteröra",
    "ytterörons": "ytteröra",
    "yttrad": "yttra",
    "yttrade": "yttra",
    "yttrades": "yttra",
    "yttrads": "yttra",
    "yttrande": "yttra",
    "yttrandefriheten": "yttrandefrihet",
    "yttrandefrihetens": "yttrandefrihet",
    "yttrandefriheter": "yttrandefrihet",
    "yttrandefriheterna": "yttrandefrihet",
    "yttrandefriheternas": "yttrandefrihet",
    "yttrandefriheters": "yttrandefrihet",
    "yttrandefrihets": "yttrandefrihet",
    "yttrandefrihetsfrågan": "yttrandefrihetsfråga",
    "yttrandefrihetsfrågans": "yttrandefrihetsfråga",
    "yttrandefrihetsfrågas": "yttrandefrihetsfråga",
    "yttrandefrihetsfråge": "yttrandefrihetsfråga",
    "yttrandefrihetsfrågor": "yttrandefrihetsfråga",
    "yttrandefrihetsfrågorna": "yttrandefrihetsfråga",
    "yttrandefrihetsfrågornas": "yttrandefrihetsfråga",
    "yttrandefrihetsfrågors": "yttrandefrihetsfråga",
    "yttranden": "yttrande",
    "yttrandena": "yttrande",
    "yttrandenas": "yttrande",
    "yttrandens": "yttrande",
    "yttrandes": "yttrande",
    "yttrandet": "yttrande",
    "yttrandets": "yttrande",
    "yttrar": "yttra",
    "yttrarna": "ytter",
    "yttrarnas": "ytter",
    "yttrars": "ytter",
    "yttras": "yttra",
    "yttrat": "yttra",
    "yttrats": "yttra",
    "yttres": "yttre",
    "yttriet": "yttrium",
    "yttriets": "yttrium",
    "yttringar": "yttring",
    "yttringarna": "yttring",
    "yttringarnas": "yttring",
    "yttringars": "yttring",
    "yttringen": "yttring",
    "yttringens": "yttring",
    "yttrings": "yttring",
    "yttriumet": "yttrium",
    "yttriumets": "yttrium",
    "yttriumoxiden": "yttriumoxid",
    "yttriumoxidens": "yttriumoxid",
    "yttriumoxider": "yttriumoxid",
    "yttriumoxiderna": "yttriumoxid",
    "yttriumoxidernas": "yttriumoxid",
    "yttriumoxiders": "yttriumoxid",
    "yttriumoxids": "yttriumoxid",
    "yttriums": "yttrium",
    "yttrycken": "yttryck",
    "yttryckens": "yttryck",
    "yttrycket": "yttryck",
    "yttryckets": "yttryck",
    "yttrycks": "yttryck",
    "ytvattens": "ytvatten",
    "ytvattenskikten": "ytvattenskikt",
    "ytvattenskiktens": "ytvattenskikt",
    "ytvattenskiktet": "ytvattenskikt",
    "ytvattenskiktets": "ytvattenskikt",
    "ytvattenskikts": "ytvattenskikt",
    "ytvattnen": "ytvatten",
    "ytvattnens": "ytvatten",
    "ytvattnet": "ytvatten",
    "ytvattnets": "ytvatten",
    "ytveden": "ytved",
    "ytvedens": "ytved",
    "ytveds": "ytved",
    "ytvidden": "ytvidd",
    "ytviddens": "ytvidd",
    "ytvidder": "ytvidd",
    "ytvidderna": "ytvidd",
    "ytviddernas": "ytvidd",
    "ytvidders": "ytvidd",
    "ytvidds": "ytvidd",
    "yvdes": "yvas",
    "yverborens": "yverboren",
    "yverboret": "yverboren",
    "yverborets": "yverboren",
    "yverborna": "yverboren",
    "yverbornare": "yverboren",
    "yverbornares": "yverboren",
    "yverbornas": "yverboren",
    "yverbornast": "yverboren",
    "yverbornaste": "yverboren",
    "yverbornastes": "yverboren",
    "yverbornasts": "yverboren",
    "yverborne": "yverboren",
    "yverbornes": "yverboren",
    "yves": "yvas",
    "yviga": "yvig",
    "yvigare": "yvig",
    "yvigares": "yvig",
    "yvigas": "yvig",
    "yvigast": "yvig",
    "yvigaste": "yvig",
    "yvigastes": "yvig",
    "yvigasts": "yvig",
    "yvige": "yvig",
    "yviges": "yvig",
    "yvigheten": "yvighet",
    "yvighetens": "yvighet",
    "yvigheter": "yvighet",
    "yvigheterna": "yvighet",
    "yvigheternas": "yvighet",
    "yvigheters": "yvighet",
    "yvighets": "yvighet",
    "yvigs": "yvig",
    "yvigt": "yvig",
    "yvigts": "yvig",
    "yvs": "yvas",
    "yvts": "yvas",
    "yx": "yxa",
    "yxan": "yxa",
    "yxans": "yxa",
    "yxas": "yxa",
    "yxbladen": "yxblad",
    "yxbladens": "yxblad",
    "yxbladet": "yxblad",
    "yxbladets": "yxblad",
    "yxblads": "yxblad",
    "yxe": "yxa",
    "yxhammar": "yxhammare",
    "yxhammaren": "yxhammare",
    "yxhammarens": "yxhammare",
    "yxhammares": "yxhammare",
    "yxhamrar": "yxhammare",
    "yxhamrarna": "yxhammare",
    "yxhamrarnas": "yxhammare",
    "yxhamrars": "yxhammare",
    "yxhuvuden": "yxhuvud",
    "yxhuvudena": "yxhuvud",
    "yxhuvudenas": "yxhuvud",
    "yxhuvudens": "yxhuvud",
    "yxhuvudet": "yxhuvud",
    "yxhuvudets": "yxhuvud",
    "yxhuvuds": "yxhuvud",
    "yxläggen": "yxlägg",
    "yxläggens": "yxlägg",
    "yxläggs": "yxlägg",
    "yxmorden": "yxmord",
    "yxmordens": "yxmord",
    "yxmordet": "yxmord",
    "yxmordets": "yxmord",
    "yxmords": "yxmord",
    "yxnes": "yxne",
    "yxnet": "yxne",
    "yxnets": "yxne",
    "yxor": "yxa",
    "yxorna": "yxa",
    "yxornas": "yxa",
    "yxors": "yxa",
    "yxskaften": "yxskaft",
    "yxskaftens": "yxskaft",
    "yxskaftet": "yxskaft",
    "yxskaftets": "yxskaft",
    "yxskafts": "yxskaft",
    "yxämnen": "yxämne",
    "yxämnena": "yxämne",
    "yxämnenas": "yxämne",
    "yxämnens": "yxämne",
    "yxämnes": "yxämne",
    "yxämnet": "yxämne",
    "yxämnets": "yxämne",
    "z-n": "z",
    "z-na": "z",
    "z-nas": "z",
    "z-ns": "z",
    "z-s": "z",
    "z-t": "z",
    "z-ts": "z",
    "z:n": "z",
    "z:na": "z",
    "z:nas": "z",
    "z:ns": "z",
    "z:s": "z",
    "z:t": "z",
    "z:ts": "z",
    "zairiern": "zairier",
    "zairierna": "zairier",
    "zairiernas": "zairier",
    "zairierns": "zairier",
    "zairiers": "zairier",
    "zairiska": "zairisk",
    "zairiskare": "zairisk",
    "zairiskares": "zairisk",
    "zairiskas": "zairisk",
    "zairiskast": "zairisk",
    "zairiskaste": "zairisk",
    "zairiskastes": "zairisk",
    "zairiskasts": "zairisk",
    "zairiske": "zairisk",
    "zairiskes": "zairisk",
    "zairisks": "zairisk",
    "zairiskt": "zairisk",
    "zairiskts": "zairisk",
    "zambiern": "zambier",
    "zambierna": "zambier",
    "zambiernas": "zambier",
    "zambierns": "zambier",
    "zambiers": "zambier",
    "zambiska": "zambisk",
    "zambiskare": "zambisk",
    "zambiskares": "zambisk",
    "zambiskas": "zambisk",
    "zambiskast": "zambisk",
    "zambiskaste": "zambisk",
    "zambiskastes": "zambisk",
    "zambiskasts": "zambisk",
    "zambiske": "zambisk",
    "zambiskes": "zambisk",
    "zambisks": "zambisk",
    "zambiskt": "zambisk",
    "zambiskts": "zambisk",
    "zebran": "zebra",
    "zebrans": "zebra",
    "zebras": "zebra",
    "zebror": "zebra",
    "zebrorna": "zebra",
    "zebrornas": "zebra",
    "zebrors": "zebra",
    "zefyren": "zefyr",
    "zefyrens": "zefyr",
    "zefyrer": "zefyr",
    "zefyrerna": "zefyr",
    "zefyrernas": "zefyr",
    "zefyrers": "zefyr",
    "zefyrs": "zefyr",
    "zeloten": "zelot",
    "zelotens": "zelot",
    "zeloter": "zelot",
    "zeloterna": "zelot",
    "zeloternas": "zelot",
    "zeloters": "zelot",
    "zelots": "zelot",
    "zenitdistansen": "zenitdistans",
    "zenitdistansens": "zenitdistans",
    "zenitdistanser": "zenitdistans",
    "zenitdistanserna": "zenitdistans",
    "zenitdistansernas": "zenitdistans",
    "zenitdistansers": "zenitdistans",
    "zenits": "zenit",
    "zeoliten": "zeolit",
    "zeolitens": "zeolit",
    "zeolits": "zeolit",
    "zeppelinar": "zeppelinare",
    "zeppelinaren": "zeppelinare",
    "zeppelinarens": "zeppelinare",
    "zeppelinares": "zeppelinare",
    "zeppelinarhangarer": "zeppelinarhangar",
    "zeppelinarhangarerna": "zeppelinarhangar",
    "zeppelinarhangarernas": "zeppelinarhangar",
    "zeppelinarhangarers": "zeppelinarhangar",
    "zeppelinarhangarn": "zeppelinarhangar",
    "zeppelinarhangarns": "zeppelinarhangar",
    "zeppelinarhangars": "zeppelinarhangar",
    "zeppelinarna": "zeppelinare",
    "zeppelinarnas": "zeppelinare",
    "zeppelinarpiloten": "zeppelinarpilot",
    "zeppelinarpilotens": "zeppelinarpilot",
    "zeppelinarpiloter": "zeppelinarpilot",
    "zeppelinarpiloterna": "zeppelinarpilot",
    "zeppelinarpiloternas": "zeppelinarpilot",
    "zeppelinarpiloters": "zeppelinarpilot",
    "zeppelinarpilots": "zeppelinarpilot",
    "zetan": "zeta",
    "zetana": "zeta",
    "zetanas": "zeta",
    "zetans": "zeta",
    "zetas": "zeta",
    "zetat": "zeta",
    "zetats": "zeta",
    "zeugman": "zeugma",
    "zeugmana": "zeugma",
    "zeugmanas": "zeugma",
    "zeugmans": "zeugma",
    "zeugmas": "zeugma",
    "zeugmat": "zeugma",
    "zeugmats": "zeugma",
    "zigenar": "zigenare",
    "zigenaren": "zigenare",
    "zigenarens": "zigenare",
    "zigenares": "zigenare",
    "zigenarflick": "zigenarflicka",
    "zigenarflickan": "zigenarflicka",
    "zigenarflickans": "zigenarflicka",
    "zigenarflickas": "zigenarflicka",
    "zigenarflicke": "zigenarflicka",
    "zigenarflickor": "zigenarflicka",
    "zigenarflickorna": "zigenarflicka",
    "zigenarflickornas": "zigenarflicka",
    "zigenarflickors": "zigenarflicka",
    "zigenarflicks": "zigenarflicka",
    "zigenarhövdingar": "zigenarhövding",
    "zigenarhövdingarna": "zigenarhövding",
    "zigenarhövdingarnas": "zigenarhövding",
    "zigenarhövdingars": "zigenarhövding",
    "zigenarhövdingen": "zigenarhövding",
    "zigenarhövdingens": "zigenarhövding",
    "zigenarhövdings": "zigenarhövding",
    "zigenarkapellen": "zigenarkapell",
    "zigenarkapellens": "zigenarkapell",
    "zigenarkapellet": "zigenarkapell",
    "zigenarkapellets": "zigenarkapell",
    "zigenarkapells": "zigenarkapell",
    "zigenarliven": "zigenarliv",
    "zigenarlivens": "zigenarliv",
    "zigenarlivet": "zigenarliv",
    "zigenarlivets": "zigenarliv",
    "zigenarlivs": "zigenarliv",
    "zigenarmusiken": "zigenarmusik",
    "zigenarmusikens": "zigenarmusik",
    "zigenarmusiks": "zigenarmusik",
    "zigenarna": "zigenare",
    "zigenarnas": "zigenare",
    "zigenarspråken": "zigenarspråk",
    "zigenarspråkens": "zigenarspråk",
    "zigenarspråket": "zigenarspråk",
    "zigenarspråkets": "zigenarspråk",
    "zigenarspråks": "zigenarspråk",
    "zigensk": "zigenska",
    "zigenska": "zigensk",
    "zigenskan": "zigenska",
    "zigenskans": "zigenska",
    "zigenskare": "zigensk",
    "zigenskares": "zigensk",
    "zigenskas": "zigenska",
    "zigenskast": "zigensk",
    "zigenskaste": "zigensk",
    "zigenskastes": "zigensk",
    "zigenskasts": "zigensk",
    "zigenske": "zigensk",
    "zigenskes": "zigensk",
    "zigensks": "zigensk",
    "zigenskt": "zigensk",
    "zigenskts": "zigensk",
    "zigguraten": "ziggurat",
    "zigguratens": "ziggurat",
    "ziggurater": "ziggurat",
    "zigguraterna": "ziggurat",
    "zigguraternas": "ziggurat",
    "zigguraters": "ziggurat",
    "zigguratet": "ziggurat",
    "zigguratets": "ziggurat",
    "ziggurats": "ziggurat",
    "zikkuraten": "zikkurat",
    "zikkuratens": "zikkurat",
    "zikkurater": "zikkurat",
    "zikkuraterna": "zikkurat",
    "zikkuraternas": "zikkurat",
    "zikkuraters": "zikkurat",
    "zikkuratet": "zikkurat",
    "zikkuratets": "zikkurat",
    "zikkurats": "zikkurat",
    "zimbabwiern": "zimbabwier",
    "zimbabwierna": "zimbabwier",
    "zimbabwiernas": "zimbabwier",
    "zimbabwierns": "zimbabwier",
    "zimbabwiers": "zimbabwier",
    "zimbabwiska": "zimbabwisk",
    "zimbabwiskare": "zimbabwisk",
    "zimbabwiskares": "zimbabwisk",
    "zimbabwiskas": "zimbabwisk",
    "zimbabwiskast": "zimbabwisk",
    "zimbabwiskaste": "zimbabwisk",
    "zimbabwiskastes": "zimbabwisk",
    "zimbabwiskasts": "zimbabwisk",
    "zimbabwiske": "zimbabwisk",
    "zimbabwiskes": "zimbabwisk",
    "zimbabwisks": "zimbabwisk",
    "zimbabwiskt": "zimbabwisk",
    "zimbabwiskts": "zimbabwisk",
    "zinkbländes": "zinkblände",
    "zinkbländet": "zinkblände",
    "zinkbländets": "zinkblände",
    "zinken": "zink",
    "zinkens": "zink",
    "zinkfebern": "zinkfeber",
    "zinkfeberns": "zinkfeber",
    "zinkfebers": "zinkfeber",
    "zinkgults": "zinkgult",
    "zinkmalmen": "zinkmalm",
    "zinkmalmens": "zinkmalm",
    "zinkmalmer": "zinkmalm",
    "zinkmalmerna": "zinkmalm",
    "zinkmalmernas": "zinkmalm",
    "zinkmalmers": "zinkmalm",
    "zinkmalms": "zinkmalm",
    "zinks": "zink",
    "zinksalvan": "zinksalva",
    "zinksalvans": "zinksalva",
    "zinksalvas": "zinksalva",
    "zinkspaten": "zinkspat",
    "zinkspatens": "zinkspat",
    "zinkspats": "zinkspat",
    "zinkvitts": "zinkvitt",
    "zinkång": "zinkånga",
    "zinkångan": "zinkånga",
    "zinkångans": "zinkånga",
    "zinkångas": "zinkånga",
    "zinkånge": "zinkånga",
    "zinkångor": "zinkånga",
    "zinkångorna": "zinkånga",
    "zinkångornas": "zinkånga",
    "zinkångors": "zinkånga",
    "zinkångs": "zinkånga",
    "zinni": "zinnia",
    "zinnian": "zinnia",
    "zinnians": "zinnia",
    "zinnias": "zinnia",
    "zinnie": "zinnia",
    "zinnior": "zinnia",
    "zinniorna": "zinnia",
    "zinniornas": "zinnia",
    "zinniors": "zinnia",
    "zinnis": "zinnia",
    "ziqquraten": "ziqqurat",
    "ziqquratens": "ziqqurat",
    "ziqqurater": "ziqqurat",
    "ziqquraterna": "ziqqurat",
    "ziqquraternas": "ziqqurat",
    "ziqquraters": "ziqqurat",
    "ziqquratet": "ziqqurat",
    "ziqquratets": "ziqqurat",
    "ziqqurats": "ziqqurat",
    "zirkonen": "zirkon",
    "zirkonens": "zirkon",
    "zirkoner": "zirkon",
    "zirkonerna": "zirkon",
    "zirkonernas": "zirkon",
    "zirkoners": "zirkon",
    "zirkoniet": "zirkonium",
    "zirkoniets": "zirkonium",
    "zirkoniumet": "zirkonium",
    "zirkoniumets": "zirkonium",
    "zirkoniumoxiden": "zirkoniumoxid",
    "zirkoniumoxidens": "zirkoniumoxid",
    "zirkoniumoxider": "zirkoniumoxid",
    "zirkoniumoxiderna": "zirkoniumoxid",
    "zirkoniumoxidernas": "zirkoniumoxid",
    "zirkoniumoxiders": "zirkoniumoxid",
    "zirkoniumoxids": "zirkoniumoxid",
    "zirkoniums": "zirkonium",
    "zirkons": "zirkon",
    "zlotyn": "zloty",
    "zlotyna": "zloty",
    "zlotynas": "zloty",
    "zlotyns": "zloty",
    "zlotys": "zloty",
    "zn": "z",
    "zna": "z",
    "znas": "z",
    "zns": "z",
    "zodiakalljuset": "zodiakalljus",
    "zodiakalljusets": "zodiakalljus",
    "zodiaken": "zodiak",
    "zodiakens": "zodiak",
    "zodiaks": "zodiak",
    "zombien": "zombie",
    "zombiens": "zombie",
    "zombier": "zombie",
    "zombierna": "zombie",
    "zombiernas": "zombie",
    "zombiers": "zombie",
    "zombies": "zombie",
    "zombiesen": "zombie",
    "zombiesens": "zombie",
    "zonen": "zon",
    "zonens": "zon",
    "zoner": "zon",
    "zonerna": "zon",
    "zonernas": "zon",
    "zoners": "zon",
    "zonrören": "zonrör",
    "zonrörens": "zonrör",
    "zonröret": "zonrör",
    "zonrörets": "zonrör",
    "zonrörs": "zonrör",
    "zons": "zon",
    "zontariffen": "zontariff",
    "zontariffens": "zontariff",
    "zontariffer": "zontariff",
    "zontarifferna": "zontariff",
    "zontariffernas": "zontariff",
    "zontariffers": "zontariff",
    "zontariffs": "zontariff",
    "zontax": "zontaxa",
    "zontaxan": "zontaxa",
    "zontaxans": "zontaxa",
    "zontaxas": "zontaxa",
    "zontaxe": "zontaxa",
    "zontaxor": "zontaxa",
    "zontaxorna": "zontaxa",
    "zontaxornas": "zontaxa",
    "zontaxors": "zontaxa",
    "zontiden": "zontid",
    "zontidens": "zontid",
    "zontids": "zontid",
    "zoofysiologien": "zoofysiologi",
    "zoofysiologiens": "zoofysiologi",
    "zoofysiologin": "zoofysiologi",
    "zoofysiologins": "zoofysiologi",
    "zoofysiologis": "zoofysiologi",
    "zoologen": "zoolog",
    "zoologens": "zoolog",
    "zoologer": "zoolog",
    "zoologerna": "zoolog",
    "zoologernas": "zoolog",
    "zoologers": "zoolog",
    "zoologien": "zoologi",
    "zoologiens": "zoologi",
    "zoologin": "zoologi",
    "zoologins": "zoologi",
    "zoologis": "zoologi",
    "zoologiska": "zoologisk",
    "zoologiskare": "zoologisk",
    "zoologiskares": "zoologisk",
    "zoologiskas": "zoologisk",
    "zoologiskast": "zoologisk",
    "zoologiskaste": "zoologisk",
    "zoologiskastes": "zoologisk",
    "zoologiskasts": "zoologisk",
    "zoologiske": "zoologisk",
    "zoologiskes": "zoologisk",
    "zoologisks": "zoologisk",
    "zoologiskt": "zoologisk",
    "zoologiskts": "zoologisk",
    "zoologs": "zoolog",
    "zoom": "zooma",
    "zoomad": "zooma",
    "zoomade": "zooma",
    "zoomades": "zooma",
    "zoomads": "zooma",
    "zoomande": "zooma",
    "zoomanden": "zoomande",
    "zoomandena": "zoomande",
    "zoomandenas": "zoomande",
    "zoomandens": "zoomande",
    "zoomandes": "zoomande",
    "zoomandet": "zoomande",
    "zoomandets": "zoomande",
    "zoomar": "zooma",
    "zoomas": "zooma",
    "zoomat": "zooma",
    "zoomats": "zooma",
    "zoomen": "zoom",
    "zoomens": "zoom",
    "zoomobjektiven": "zoomobjektiv",
    "zoomobjektivens": "zoomobjektiv",
    "zoomobjektivet": "zoomobjektiv",
    "zoomobjektivets": "zoomobjektiv",
    "zoomobjektivs": "zoomobjektiv",
    "zooms": "zoom",
    "zoon": "zoo",
    "zoona": "zoo",
    "zoonas": "zoo",
    "zoons": "zoo",
    "zoos": "zoo",
    "zoot": "zoo",
    "zootomien": "zootomi",
    "zootomiens": "zootomi",
    "zootomin": "zootomi",
    "zootomins": "zootomi",
    "zootomis": "zootomi",
    "zoots": "zoo",
    "zs": "z",
    "zt": "z",
    "zts": "z",
    "zuluer": "zulu",
    "zuluerna": "zulu",
    "zuluernas": "zulu",
    "zuluers": "zulu",
    "zulun": "zulu",
    "zuluns": "zulu",
    "zulus": "zulu",
    "zygoten": "zygot",
    "zygotens": "zygot",
    "zygoter": "zygot",
    "zygoterna": "zygot",
    "zygoternas": "zygot",
    "zygoters": "zygot",
    "zygots": "zygot",
    "zätan": "zäta",
    "zätana": "zäta",
    "zätanas": "zäta",
    "zätans": "zäta",
    "zätas": "zäta",
    "zätat": "zäta",
    "zätats": "zäta",
    "Ägirs": "Ägir",
    "Älvdalens": "Älvdalen",
    "Ätrans": "Ätran",
    "Åbys": "Åby",
    "Åkar": "Åke",
    "Åkarna": "Åke",
    "Åkarnas": "Åke",
    "Åkars": "Åke",
    "Åkes": "Åke",
    "Åkessonen": "Åkesson",
    "Åkessonens": "Åkesson",
    "Åkessons": "Åkesson",
    "Åkessöner": "Åkesson",
    "Åkessönerna": "Åkesson",
    "Åkessönernas": "Åkesson",
    "Åkessöners": "Åkesson",
    "Ålands": "Åland",
    "Ångermanlands": "Ångermanland",
    "Åsa-Nisses": "Åsa-Nisse",
    "Åtvidabergs": "Åtvidaberg",
    "ÖB-s": "ÖB",
    "ÖB:s": "ÖB",
    "ÖBs": "ÖB",
    "Öbergs": "Öberg",
    "Ölands": "Öland",
    "Ölandsbrons": "Ölandsbron",
    "Örebromissionens": "Örebromissionen",
    "Örebros": "Örebro",
    "Öresunds": "Öresund",
    "Öresundsbrons": "Öresundsbron",
    "Örnens": "Örnen",
    "Örsteds": "Örsted",
    "Östafrikas": "Östafrika",
    "Östberlins": "Östberlin",
    "Österbottens": "Österbotten",
    "Östergötlands": "Östergötland",
    "Österlens": "Österlen",
    "Österlings": "Österling",
    "Österrikes": "Österrike",
    "Östersjöns": "Östersjön",
    "Östersjösamarbeten": "Östersjösamarbete",
    "Östersjösamarbetena": "Östersjösamarbete",
    "Östersjösamarbetenas": "Östersjösamarbete",
    "Östersjösamarbetens": "Östersjösamarbete",
    "Östersjösamarbetes": "Östersjösamarbete",
    "Östersjösamarbetet": "Östersjösamarbete",
    "Östersjösamarbetets": "Östersjösamarbete",
    "Östersjösamarbets": "Östersjösamarbete",
    "Östersunds": "Östersund",
    "Östeuropas": "Östeuropa",
    "Östfolds": "Östfold",
    "Östroms": "Östrom",
    "Östtysklands": "Östtyskland",
    "ä-et": "ä",
    "ä-ets": "ä",
    "ä-n": "ä",
    "ä-na": "ä",
    "ä-nas": "ä",
    "ä-ns": "ä",
    "ä-s": "ä",
    "ä-t": "ä",
    "ä-ts": "ä",
    "ä:et": "ä",
    "ä:ets": "ä",
    "ä:n": "ä",
    "ä:na": "ä",
    "ä:nas": "ä",
    "ä:ns": "ä",
    "ä:s": "ä",
    "ä:t": "ä",
    "ä:ts": "ä",
    "äckel": "äckla",
    "äckels": "äckel",
    "äcklad": "äckla",
    "äcklade": "äckla",
    "äcklades": "äckla",
    "äcklads": "äckla",
    "äcklande": "äckla",
    "äcklanden": "äcklande",
    "äcklandena": "äcklande",
    "äcklandenas": "äcklande",
    "äcklandens": "äcklande",
    "äcklandes": "äcklande",
    "äcklandet": "äcklande",
    "äcklandets": "äcklande",
    "äcklar": "äckla",
    "äcklas": "äckla",
    "äcklat": "äckla",
    "äcklats": "äckla",
    "äcklen": "äckel",
    "äcklens": "äckel",
    "äcklet": "äckel",
    "äcklets": "äckel",
    "äckliga": "äcklig",
    "äckligare": "äcklig",
    "äckligares": "äcklig",
    "äckligas": "äcklig",
    "äckligast": "äcklig",
    "äckligaste": "äcklig",
    "äckligastes": "äcklig",
    "äckligasts": "äcklig",
    "äcklige": "äcklig",
    "äckliges": "äcklig",
    "äckligheten": "äcklighet",
    "äcklighetens": "äcklighet",
    "äckligheter": "äcklighet",
    "äckligheterna": "äcklighet",
    "äckligheternas": "äcklighet",
    "äckligheters": "äcklighet",
    "äcklighets": "äcklighet",
    "äckligs": "äcklig",
    "äckligt": "äcklig",
    "äckligts": "äcklig",
    "äcklon": "äcklo",
    "äcklona": "äcklo",
    "äcklonas": "äcklo",
    "äcklons": "äcklo",
    "äcklos": "äcklo",
    "äcklot": "äcklo",
    "äcklots": "äcklo",
    "ädelfasanen": "ädelfasan",
    "ädelfasanens": "ädelfasan",
    "ädelfasaner": "ädelfasan",
    "ädelfasanerna": "ädelfasan",
    "ädelfasanernas": "ädelfasan",
    "ädelfasaners": "ädelfasan",
    "ädelfasans": "ädelfasan",
    "ädelfisken": "ädelfisk",
    "ädelfiskens": "ädelfisk",
    "ädelfisks": "ädelfisk",
    "ädelgasen": "ädelgas",
    "ädelgasens": "ädelgas",
    "ädelgaser": "ädelgas",
    "ädelgaserna": "ädelgas",
    "ädelgasernas": "ädelgas",
    "ädelgasers": "ädelgas",
    "ädelgranar": "ädelgran",
    "ädelgranarna": "ädelgran",
    "ädelgranarnas": "ädelgran",
    "ädelgranars": "ädelgran",
    "ädelgranen": "ädelgran",
    "ädelgranens": "ädelgran",
    "ädelgrans": "ädelgran",
    "ädelkorallen": "ädelkorall",
    "ädelkorallens": "ädelkorall",
    "ädelkoralls": "ädelkorall",
    "ädellövträden": "ädellövträd",
    "ädellövträdens": "ädellövträd",
    "ädellövträdet": "ädellövträd",
    "ädellövträdets": "ädellövträd",
    "ädellövträds": "ädellövträd",
    "ädelmetallen": "ädelmetall",
    "ädelmetallens": "ädelmetall",
    "ädelmetaller": "ädelmetall",
    "ädelmetallerna": "ädelmetall",
    "ädelmetallernas": "ädelmetall",
    "ädelmetallers": "ädelmetall",
    "ädelmetalls": "ädelmetall",
    "ädelmodet": "ädelmod",
    "ädelmodets": "ädelmod",
    "ädelmodiga": "ädelmodig",
    "ädelmodigare": "ädelmodig",
    "ädelmodigares": "ädelmodig",
    "ädelmodigas": "ädelmodig",
    "ädelmodigast": "ädelmodig",
    "ädelmodigaste": "ädelmodig",
    "ädelmodigastes": "ädelmodig",
    "ädelmodigasts": "ädelmodig",
    "ädelmodige": "ädelmodig",
    "ädelmodiges": "ädelmodig",
    "ädelmodigheten": "ädelmodighet",
    "ädelmodighetens": "ädelmodighet",
    "ädelmodighets": "ädelmodighet",
    "ädelmodigs": "ädelmodig",
    "ädelmodigt": "ädelmodig",
    "ädelmodigts": "ädelmodig",
    "ädelmods": "ädelmod",
    "ädelostar": "ädelost",
    "ädelostarna": "ädelost",
    "ädelostarnas": "ädelost",
    "ädelostars": "ädelost",
    "ädelosten": "ädelost",
    "ädelostens": "ädelost",
    "ädelosts": "ädelost",
    "ädelpekoralen": "ädelpekoral",
    "ädelpekoralens": "ädelpekoral",
    "ädelpekoralet": "ädelpekoral",
    "ädelpekoralets": "ädelpekoral",
    "ädelpekorals": "ädelpekoral",
    "ädels": "ädel",
    "ädelskånsk": "ädelskånska",
    "ädelskånskan": "ädelskånska",
    "ädelskånskans": "ädelskånska",
    "ädelskånskas": "ädelskånska",
    "ädelsmeden": "ädelsmed",
    "ädelsmedens": "ädelsmed",
    "ädelsmeder": "ädelsmed",
    "ädelsmederna": "ädelsmed",
    "ädelsmedernas": "ädelsmed",
    "ädelsmeders": "ädelsmed",
    "ädelsmeds": "ädelsmed",
    "ädelstenar": "ädelsten",
    "ädelstenarna": "ädelsten",
    "ädelstenarnas": "ädelsten",
    "ädelstenars": "ädelsten",
    "ädelstenen": "ädelsten",
    "ädelstenens": "ädelsten",
    "ädelstens": "ädelsten",
    "ädelt": "ädel",
    "ädelträet": "ädelträ",
    "ädelträets": "ädelträ",
    "ädelträs": "ädelträ",
    "ädelträt": "ädelträ",
    "ädelträts": "ädelträ",
    "ädelts": "ädel",
    "ädelärgen": "ädelärg",
    "ädelärgens": "ädelärg",
    "ädelärgs": "ädelärg",
    "ädla": "ädel",
    "ädlare": "ädel",
    "ädlares": "ädel",
    "ädlas": "ädel",
    "ädlast": "ädel",
    "ädlaste": "ädel",
    "ädlastes": "ädel",
    "ädlasts": "ädel",
    "ädle": "ädel",
    "ädles": "ädel",
    "ädlingar": "ädling",
    "ädlingarna": "ädling",
    "ädlingarnas": "ädling",
    "ädlingars": "ädling",
    "ädlingen": "ädling",
    "ädlingens": "ädling",
    "ädlings": "ädling",
    "äfsingar": "äfsing",
    "äfsingarna": "äfsing",
    "äfsingarnas": "äfsing",
    "äfsingars": "äfsing",
    "äfsingen": "äfsing",
    "äfsingens": "äfsing",
    "äfsings": "äfsing",
    "äg": "äga",
    "ägan": "äga",
    "ägande": "äga",
    "ägandeförhållanden": "ägandeförhållande",
    "ägandeförhållandena": "ägandeförhållande",
    "ägandeförhållandenas": "ägandeförhållande",
    "ägandeförhållandens": "ägandeförhållande",
    "ägandeförhållandes": "ägandeförhållande",
    "ägandeförhållandet": "ägandeförhållande",
    "ägandeförhållandets": "ägandeförhållande",
    "äganden": "ägande",
    "ägandena": "ägande",
    "ägandenas": "ägande",
    "ägandens": "ägande",
    "äganderätten": "äganderätt",
    "äganderättens": "äganderätt",
    "äganderätts": "äganderätt",
    "ägandes": "ägande",
    "ägandet": "ägande",
    "ägandets": "ägande",
    "ägans": "äga",
    "ägar": "ägare",
    "ägarandelar": "ägarandel",
    "ägarandelarna": "ägarandel",
    "ägarandelarnas": "ägarandel",
    "ägarandelars": "ägarandel",
    "ägarandelen": "ägarandel",
    "ägarandelens": "ägarandel",
    "ägarandels": "ägarandel",
    "ägardemokratien": "ägardemokrati",
    "ägardemokratiens": "ägardemokrati",
    "ägardemokratin": "ägardemokrati",
    "ägardemokratins": "ägardemokrati",
    "ägardemokratis": "ägardemokrati",
    "ägardirektiven": "ägardirektiv",
    "ägardirektivens": "ägardirektiv",
    "ägardirektivet": "ägardirektiv",
    "ägardirektivets": "ägardirektiv",
    "ägardirektivs": "ägardirektiv",
    "ägaren": "ägare",
    "ägarens": "ägare",
    "ägares": "ägare",
    "ägarformen": "ägarform",
    "ägarformens": "ägarform",
    "ägarformer": "ägarform",
    "ägarformerna": "ägarform",
    "ägarformernas": "ägarform",
    "ägarformers": "ägarform",
    "ägarforms": "ägarform",
    "ägarkraven": "ägarkrav",
    "ägarkravens": "ägarkrav",
    "ägarkravet": "ägarkrav",
    "ägarkravets": "ägarkrav",
    "ägarkravs": "ägarkrav",
    "ägarmässiga": "ägarmässig",
    "ägarmässigare": "ägarmässig",
    "ägarmässigares": "ägarmässig",
    "ägarmässigas": "ägarmässig",
    "ägarmässigast": "ägarmässig",
    "ägarmässigaste": "ägarmässig",
    "ägarmässigastes": "ägarmässig",
    "ägarmässigasts": "ägarmässig",
    "ägarmässige": "ägarmässig",
    "ägarmässiges": "ägarmässig",
    "ägarmässigs": "ägarmässig",
    "ägarmässigt": "ägarmässig",
    "ägarmässigts": "ägarmässig",
    "ägarna": "ägare",
    "ägarnas": "ägare",
    "ägas": "äga",
    "ägd": "äga",
    "ägda": "äga",
    "ägdas": "äga",
    "ägde": "äga",
    "ägdes": "äga",
    "ägds": "äga",
    "äge": "äga",
    "äger": "äga",
    "äges": "äga",
    "äggblås": "äggblåsa",
    "äggblåsan": "äggblåsa",
    "äggblåsans": "äggblåsa",
    "äggblåsas": "äggblåsa",
    "äggblåse": "äggblåsa",
    "äggblåsor": "äggblåsa",
    "äggblåsorna": "äggblåsa",
    "äggblåsornas": "äggblåsa",
    "äggblåsors": "äggblåsa",
    "äggcellen": "äggcell",
    "äggcellens": "äggcell",
    "äggceller": "äggcell",
    "äggcellerna": "äggcell",
    "äggcellernas": "äggcell",
    "äggcellers": "äggcell",
    "äggcells": "äggcell",
    "äggen": "ägg",
    "äggens": "ägg",
    "ägget": "ägg",
    "äggets": "ägg",
    "äggfärgade": "äggfärgad",
    "äggfärgades": "äggfärgad",
    "äggfärgads": "äggfärgad",
    "äggfärgat": "äggfärgad",
    "äggfärgats": "äggfärgad",
    "äggfärgen": "äggfärg",
    "äggfärgens": "äggfärg",
    "äggfärgs": "äggfärg",
    "ägghinnan": "ägghinna",
    "ägghinnans": "ägghinna",
    "ägghinnas": "ägghinna",
    "ägghinne": "ägghinna",
    "ägghinnor": "ägghinna",
    "ägghinnorna": "ägghinna",
    "ägghinnornas": "ägghinna",
    "ägghinnors": "ägghinna",
    "ägghön": "ägghöna",
    "ägghönan": "ägghöna",
    "ägghönans": "ägghöna",
    "ägghönas": "ägghöna",
    "ägghöne": "ägghöna",
    "ägghönor": "ägghöna",
    "ägghönorna": "ägghöna",
    "ägghönornas": "ägghöna",
    "ägghönors": "ägghöna",
    "ägghöns": "ägghöna",
    "äggkak": "äggkaka",
    "äggkakan": "äggkaka",
    "äggkakans": "äggkaka",
    "äggkakas": "äggkaka",
    "äggkake": "äggkaka",
    "äggkakor": "äggkaka",
    "äggkakorna": "äggkaka",
    "äggkakornas": "äggkaka",
    "äggkakors": "äggkaka",
    "äggkaks": "äggkaka",
    "äggkastar": "äggkastare",
    "äggkastaren": "äggkastare",
    "äggkastarens": "äggkastare",
    "äggkastares": "äggkastare",
    "äggkastarna": "äggkastare",
    "äggkastarnas": "äggkastare",
    "äggkastningar": "äggkastning",
    "äggkastningarna": "äggkastning",
    "äggkastningarnas": "äggkastning",
    "äggkastningars": "äggkastning",
    "äggkastningen": "äggkastning",
    "äggkastningens": "äggkastning",
    "äggkastnings": "äggkastning",
    "äggklock": "äggklocka",
    "äggklockan": "äggklocka",
    "äggklockans": "äggklocka",
    "äggklockas": "äggklocka",
    "äggklocke": "äggklocka",
    "äggklockor": "äggklocka",
    "äggklockorna": "äggklocka",
    "äggklockornas": "äggklocka",
    "äggklockors": "äggklocka",
    "äggklocks": "äggklocka",
    "äggkläckningsmaskinen": "äggkläckningsmaskin",
    "äggkläckningsmaskinens": "äggkläckningsmaskin",
    "äggkläckningsmaskiner": "äggkläckningsmaskin",
    "äggkläckningsmaskinerna": "äggkläckningsmaskin",
    "äggkläckningsmaskinernas": "äggkläckningsmaskin",
    "äggkläckningsmaskiners": "äggkläckningsmaskin",
    "äggkläckningsmaskins": "äggkläckningsmaskin",
    "äggkokar": "äggkokare",
    "äggkokaren": "äggkokare",
    "äggkokarens": "äggkokare",
    "äggkokares": "äggkokare",
    "äggkokarna": "äggkokare",
    "äggkokarnas": "äggkokare",
    "äggkokningar": "äggkokning",
    "äggkokningarna": "äggkokning",
    "äggkokningarnas": "äggkokning",
    "äggkokningars": "äggkokning",
    "äggkokningen": "äggkokning",
    "äggkokningens": "äggkokning",
    "äggkoknings": "äggkokning",
    "äggkoppar": "äggkopp",
    "äggkopparna": "äggkopp",
    "äggkopparnas": "äggkopp",
    "äggkoppars": "äggkopp",
    "äggkoppen": "äggkopp",
    "äggkoppens": "äggkopp",
    "äggkopps": "äggkopp",
    "äggkornen": "äggkorn",
    "äggkornens": "äggkorn",
    "äggkornet": "äggkorn",
    "äggkornets": "äggkorn",
    "äggkorns": "äggkorn",
    "äggledar": "äggledare",
    "äggledaren": "äggledare",
    "äggledarens": "äggledare",
    "äggledares": "äggledare",
    "äggledarna": "äggledare",
    "äggledarnas": "äggledare",
    "äggledartrattar": "äggledartratt",
    "äggledartrattarna": "äggledartratt",
    "äggledartrattarnas": "äggledartratt",
    "äggledartrattars": "äggledartratt",
    "äggledartratten": "äggledartratt",
    "äggledartrattens": "äggledartratt",
    "äggledartratts": "äggledartratt",
    "ägglossningar": "ägglossning",
    "ägglossningarna": "ägglossning",
    "ägglossningarnas": "ägglossning",
    "ägglossningars": "ägglossning",
    "ägglossningen": "ägglossning",
    "ägglossningens": "ägglossning",
    "ägglossnings": "ägglossning",
    "äggläggningen": "äggläggning",
    "äggläggningens": "äggläggning",
    "äggläggnings": "äggläggning",
    "äggläggningsrören": "äggläggningsrör",
    "äggläggningsrörens": "äggläggningsrör",
    "äggläggningsröret": "äggläggningsrör",
    "äggläggningsrörets": "äggläggningsrör",
    "äggläggningsrörs": "äggläggningsrör",
    "ägglådan": "ägglåda",
    "ägglådans": "ägglåda",
    "ägglådas": "ägglåda",
    "äggostar": "äggost",
    "äggostarna": "äggost",
    "äggostarnas": "äggost",
    "äggostars": "äggost",
    "äggosten": "äggost",
    "äggostens": "äggost",
    "äggosts": "äggost",
    "äggplant": "äggplanta",
    "äggplantan": "äggplanta",
    "äggplantans": "äggplanta",
    "äggplantas": "äggplanta",
    "äggplante": "äggplanta",
    "äggplantor": "äggplanta",
    "äggplantorna": "äggplanta",
    "äggplantornas": "äggplanta",
    "äggplantors": "äggplanta",
    "äggplants": "äggplanta",
    "äggprickar": "äggprickare",
    "äggprickaren": "äggprickare",
    "äggprickarens": "äggprickare",
    "äggprickares": "äggprickare",
    "äggprickarna": "äggprickare",
    "äggprickarnas": "äggprickare",
    "äggpulvers": "äggpulver",
    "äggpulvret": "äggpulver",
    "äggpulvrets": "äggpulver",
    "äggrunda": "äggrund",
    "äggrundare": "äggrund",
    "äggrundares": "äggrund",
    "äggrundas": "äggrund",
    "äggrundast": "äggrund",
    "äggrundaste": "äggrund",
    "äggrundastes": "äggrund",
    "äggrundasts": "äggrund",
    "äggrunde": "äggrund",
    "äggrundes": "äggrund",
    "äggrunds": "äggrund",
    "äggrunt": "äggrund",
    "äggrunts": "äggrund",
    "äggröran": "äggröra",
    "äggrörans": "äggröra",
    "äggröras": "äggröra",
    "äggröre": "äggröra",
    "äggs": "ägg",
    "äggsjuka": "äggsjuk",
    "äggsjukare": "äggsjuk",
    "äggsjukares": "äggsjuk",
    "äggsjukas": "äggsjuk",
    "äggsjukast": "äggsjuk",
    "äggsjukaste": "äggsjuk",
    "äggsjukastes": "äggsjuk",
    "äggsjukasts": "äggsjuk",
    "äggsjuke": "äggsjuk",
    "äggsjukes": "äggsjuk",
    "äggsjukheten": "äggsjukhet",
    "äggsjukhetens": "äggsjukhet",
    "äggsjukhets": "äggsjukhet",
    "äggsjuks": "äggsjuk",
    "äggsjukt": "äggsjuk",
    "äggsjukts": "äggsjuk",
    "äggskalen": "äggskal",
    "äggskalens": "äggskal",
    "äggskalet": "äggskal",
    "äggskalets": "äggskal",
    "äggskals": "äggskal",
    "äggskalsfärgade": "äggskalsfärgad",
    "äggskalsfärgades": "äggskalsfärgad",
    "äggskalsfärgads": "äggskalsfärgad",
    "äggskalsfärgat": "äggskalsfärgad",
    "äggskalsfärgats": "äggskalsfärgad",
    "äggskedar": "äggsked",
    "äggskedarna": "äggsked",
    "äggskedarnas": "äggsked",
    "äggskedars": "äggsked",
    "äggskeden": "äggsked",
    "äggskedens": "äggsked",
    "äggskeds": "äggsked",
    "äggsnoddar": "äggsnodd",
    "äggsnoddarna": "äggsnodd",
    "äggsnoddarnas": "äggsnodd",
    "äggsnoddars": "äggsnodd",
    "äggsnodden": "äggsnodd",
    "äggsnoddens": "äggsnodd",
    "äggsnodds": "äggsnodd",
    "äggstanningar": "äggstanning",
    "äggstanningarna": "äggstanning",
    "äggstanningarnas": "äggstanning",
    "äggstanningars": "äggstanning",
    "äggstanningen": "äggstanning",
    "äggstanningens": "äggstanning",
    "äggstannings": "äggstanning",
    "äggstavar": "äggstav",
    "äggstavarna": "äggstav",
    "äggstavarnas": "äggstav",
    "äggstavars": "äggstav",
    "äggstaven": "äggstav",
    "äggstavens": "äggstav",
    "äggstavs": "äggstav",
    "äggstockar": "äggstock",
    "äggstockarna": "äggstock",
    "äggstockarnas": "äggstock",
    "äggstockars": "äggstock",
    "äggstocken": "äggstock",
    "äggstockens": "äggstock",
    "äggstocks": "äggstock",
    "äggstocksinflammationen": "äggstocksinflammation",
    "äggstocksinflammationens": "äggstocksinflammation",
    "äggstocksinflammationer": "äggstocksinflammation",
    "äggstocksinflammationerna": "äggstocksinflammation",
    "äggstocksinflammationernas": "äggstocksinflammation",
    "äggstocksinflammationers": "äggstocksinflammation",
    "äggstocksinflammations": "äggstocksinflammation",
    "äggsvampar": "äggsvamp",
    "äggsvamparna": "äggsvamp",
    "äggsvamparnas": "äggsvamp",
    "äggsvampars": "äggsvamp",
    "äggsvampen": "äggsvamp",
    "äggsvampens": "äggsvamp",
    "äggsvamps": "äggsvamp",
    "äggsäckar": "äggsäck",
    "äggsäckarna": "äggsäck",
    "äggsäckarnas": "äggsäck",
    "äggsäckars": "äggsäck",
    "äggsäcken": "äggsäck",
    "äggsäckens": "äggsäck",
    "äggsäcks": "äggsäck",
    "äggtoddar": "äggtoddy",
    "äggtoddarna": "äggtoddy",
    "äggtoddarnas": "äggtoddy",
    "äggtoddars": "äggtoddy",
    "äggtoddyar": "äggtoddy",
    "äggtoddyarna": "äggtoddy",
    "äggtoddyarnas": "äggtoddy",
    "äggtoddyars": "äggtoddy",
    "äggtoddyn": "äggtoddy",
    "äggtoddyns": "äggtoddy",
    "äggtoddys": "äggtoddy",
    "äggulan": "äggula",
    "äggulans": "äggula",
    "äggulas": "äggula",
    "äggule": "äggula",
    "äggulor": "äggula",
    "äggulorna": "äggula",
    "äggulornas": "äggula",
    "äggulors": "äggula",
    "äggvitan": "äggvita",
    "äggvitans": "äggvita",
    "äggvitas": "äggvita",
    "äggvite": "äggvita",
    "äggvitebehovet": "äggvitebehov",
    "äggvitebehovets": "äggvitebehov",
    "äggvitebehovs": "äggvitebehov",
    "äggvitegiv": "äggvitegiva",
    "äggvitegivan": "äggvitegiva",
    "äggvitegivans": "äggvitegiva",
    "äggvitegivas": "äggvitegiva",
    "äggvitegive": "äggvitegiva",
    "äggvitegivor": "äggvitegiva",
    "äggvitegivorna": "äggvitegiva",
    "äggvitegivornas": "äggvitegiva",
    "äggvitegivors": "äggvitegiva",
    "äggvitegivs": "äggvitegiva",
    "äggviteproven": "äggviteprov",
    "äggviteprovens": "äggviteprov",
    "äggviteprover": "äggviteprov",
    "äggviteproverna": "äggviteprov",
    "äggviteprovernas": "äggviteprov",
    "äggviteprovers": "äggviteprov",
    "äggviteprovet": "äggviteprov",
    "äggviteprovets": "äggviteprov",
    "äggviteprovs": "äggviteprov",
    "äggviteämnen": "äggviteämne",
    "äggviteämnena": "äggviteämne",
    "äggviteämnenas": "äggviteämne",
    "äggviteämnens": "äggviteämne",
    "äggviteämnes": "äggviteämne",
    "äggviteämnet": "äggviteämne",
    "äggviteämnets": "äggviteämne",
    "äggvitor": "äggvita",
    "äggvitorna": "äggvita",
    "äggvitornas": "äggvita",
    "äggvitors": "äggvita",
    "äggvärmar": "äggvärmare",
    "äggvärmaren": "äggvärmare",
    "äggvärmarens": "äggvärmare",
    "äggvärmares": "äggvärmare",
    "äggvärmarna": "äggvärmare",
    "äggvärmarnas": "äggvärmare",
    "ägiga": "ägig",
    "ägigare": "ägig",
    "ägigares": "ägig",
    "ägigas": "ägig",
    "ägigast": "ägig",
    "ägigaste": "ägig",
    "ägigastes": "ägig",
    "ägigasts": "ägig",
    "ägige": "ägig",
    "ägiges": "ägig",
    "ägigs": "ägig",
    "ägigt": "ägig",
    "ägigts": "ägig",
    "ägiljetten": "ägiljett",
    "ägiljettens": "ägiljett",
    "ägiljetter": "ägiljett",
    "ägiljetterna": "ägiljett",
    "ägiljetternas": "ägiljett",
    "ägiljetters": "ägiljett",
    "ägiljetts": "ägiljett",
    "ägn": "ägna",
    "ägnad": "ägna",
    "ägnade": "ägna",
    "ägnades": "ägna",
    "ägnads": "ägna",
    "ägnande": "ägna",
    "ägnanden": "ägnande",
    "ägnandena": "ägnande",
    "ägnandenas": "ägnande",
    "ägnandens": "ägnande",
    "ägnandes": "ägnande",
    "ägnandet": "ägnande",
    "ägnandets": "ägnande",
    "ägnar": "ägna",
    "ägnas": "ägna",
    "ägnat": "ägna",
    "ägnats": "ägna",
    "ägo": "äga",
    "ägodelar": "ägodel",
    "ägodelarna": "ägodel",
    "ägodelarnas": "ägodel",
    "ägodelars": "ägodel",
    "ägodelen": "ägodel",
    "ägodelens": "ägodel",
    "ägodelningar": "ägodelning",
    "ägodelningarna": "ägodelning",
    "ägodelningarnas": "ägodelning",
    "ägodelningars": "ägodelning",
    "ägodelningen": "ägodelning",
    "ägodelningens": "ägodelning",
    "ägodelnings": "ägodelning",
    "ägodels": "ägodel",
    "ägofreden": "ägofred",
    "ägofredens": "ägofred",
    "ägofreds": "ägofred",
    "ägograderingar": "ägogradering",
    "ägograderingarna": "ägogradering",
    "ägograderingarnas": "ägogradering",
    "ägograderingars": "ägogradering",
    "ägograderingen": "ägogradering",
    "ägograderingens": "ägogradering",
    "ägograderings": "ägogradering",
    "ägor": "äga",
    "ägorna": "äga",
    "ägornas": "äga",
    "ägors": "äga",
    "ägoskiften": "ägoskifte",
    "ägoskiftena": "ägoskifte",
    "ägoskiftenas": "ägoskifte",
    "ägoskiftens": "ägoskifte",
    "ägoskiftes": "ägoskifte",
    "ägoskiftet": "ägoskifte",
    "ägoskiftets": "ägoskifte",
    "ägoteckens": "ägotecken",
    "ägotecknen": "ägotecken",
    "ägotecknens": "ägotecken",
    "ägotecknet": "ägotecken",
    "ägotecknets": "ägotecken",
    "ägretten": "ägrett",
    "ägrettens": "ägrett",
    "ägretter": "ägrett",
    "ägretterna": "ägrett",
    "ägretternas": "ägrett",
    "ägretters": "ägrett",
    "ägretthägern": "ägretthäger",
    "ägretthägerns": "ägretthäger",
    "ägretthägers": "ägretthäger",
    "ägretthägrar": "ägretthäger",
    "ägretthägrarna": "ägretthäger",
    "ägretthägrarnas": "ägretthäger",
    "ägretthägrars": "ägretthäger",
    "ägretts": "ägrett",
    "ägs": "äga",
    "ägt": "äga",
    "ägts": "äga",
    "äkt": "äkta",
    "äktad": "äkta",
    "äktade": "äkta",
    "äktades": "äkta",
    "äktads": "äkta",
    "äktamakekuverten": "äktamakekuvert",
    "äktamakekuvertens": "äktamakekuvert",
    "äktamakekuvertet": "äktamakekuvert",
    "äktamakekuvertets": "äktamakekuvert",
    "äktamakekuverts": "äktamakekuvert",
    "äktande": "äkta",
    "äktanden": "äktande",
    "äktandena": "äktande",
    "äktandenas": "äktande",
    "äktandens": "äktande",
    "äktandes": "äktande",
    "äktandet": "äktande",
    "äktandets": "äktande",
    "äktar": "äkta",
    "äktas": "äkta",
    "äktat": "äkta",
    "äktats": "äkta",
    "äktenskapen": "äktenskap",
    "äktenskapens": "äktenskap",
    "äktenskapet": "äktenskap",
    "äktenskapets": "äktenskap",
    "äktenskapliga": "äktenskaplig",
    "äktenskapligare": "äktenskaplig",
    "äktenskapligares": "äktenskaplig",
    "äktenskapligas": "äktenskaplig",
    "äktenskapligast": "äktenskaplig",
    "äktenskapligaste": "äktenskaplig",
    "äktenskapligastes": "äktenskaplig",
    "äktenskapligasts": "äktenskaplig",
    "äktenskaplige": "äktenskaplig",
    "äktenskapliges": "äktenskaplig",
    "äktenskapligheten": "äktenskaplighet",
    "äktenskaplighetens": "äktenskaplighet",
    "äktenskaplighets": "äktenskaplighet",
    "äktenskapligs": "äktenskaplig",
    "äktenskapligt": "äktenskaplig",
    "äktenskapligts": "äktenskaplig",
    "äktenskaps": "äktenskap",
    "äktenskapsalliansen": "äktenskapsallians",
    "äktenskapsalliansens": "äktenskapsallians",
    "äktenskapsallianser": "äktenskapsallians",
    "äktenskapsallianserna": "äktenskapsallians",
    "äktenskapsalliansernas": "äktenskapsallians",
    "äktenskapsalliansers": "äktenskapsallians",
    "äktenskapsbetygen": "äktenskapsbetyg",
    "äktenskapsbetygens": "äktenskapsbetyg",
    "äktenskapsbetyget": "äktenskapsbetyg",
    "äktenskapsbetygets": "äktenskapsbetyg",
    "äktenskapsbetygs": "äktenskapsbetyg",
    "äktenskapsbrotten": "äktenskapsbrott",
    "äktenskapsbrottens": "äktenskapsbrott",
    "äktenskapsbrottet": "äktenskapsbrott",
    "äktenskapsbrottets": "äktenskapsbrott",
    "äktenskapsbrotts": "äktenskapsbrott",
    "äktenskapsbrytar": "äktenskapsbrytare",
    "äktenskapsbrytaren": "äktenskapsbrytare",
    "äktenskapsbrytarens": "äktenskapsbrytare",
    "äktenskapsbrytares": "äktenskapsbrytare",
    "äktenskapsbrytarna": "äktenskapsbrytare",
    "äktenskapsbrytarnas": "äktenskapsbrytare",
    "äktenskapsbyråer": "äktenskapsbyrå",
    "äktenskapsbyråerna": "äktenskapsbyrå",
    "äktenskapsbyråernas": "äktenskapsbyrå",
    "äktenskapsbyråers": "äktenskapsbyrå",
    "äktenskapsbyrån": "äktenskapsbyrå",
    "äktenskapsbyråns": "äktenskapsbyrå",
    "äktenskapsbyrås": "äktenskapsbyrå",
    "äktenskapscertifikaten": "äktenskapscertifikat",
    "äktenskapscertifikatens": "äktenskapscertifikat",
    "äktenskapscertifikatet": "äktenskapscertifikat",
    "äktenskapscertifikatets": "äktenskapscertifikat",
    "äktenskapscertifikats": "äktenskapscertifikat",
    "äktenskapsförorden": "äktenskapsförord",
    "äktenskapsförordens": "äktenskapsförord",
    "äktenskapsförordet": "äktenskapsförord",
    "äktenskapsförordets": "äktenskapsförord",
    "äktenskapsförords": "äktenskapsförord",
    "äktenskapshinderna": "äktenskapshinder",
    "äktenskapshindernas": "äktenskapshinder",
    "äktenskapshinders": "äktenskapshinder",
    "äktenskapshindren": "äktenskapshinder",
    "äktenskapshindrens": "äktenskapshinder",
    "äktenskapshindret": "äktenskapshinder",
    "äktenskapshindrets": "äktenskapshinder",
    "äktenskapskandidaten": "äktenskapskandidat",
    "äktenskapskandidatens": "äktenskapskandidat",
    "äktenskapskandidater": "äktenskapskandidat",
    "äktenskapskandidaterna": "äktenskapskandidat",
    "äktenskapskandidaternas": "äktenskapskandidat",
    "äktenskapskandidaters": "äktenskapskandidat",
    "äktenskapskandidats": "äktenskapskandidat",
    "äktenskapslöften": "äktenskapslöfte",
    "äktenskapslöftena": "äktenskapslöfte",
    "äktenskapslöftenas": "äktenskapslöfte",
    "äktenskapslöftens": "äktenskapslöfte",
    "äktenskapslöftes": "äktenskapslöfte",
    "äktenskapslöftet": "äktenskapslöfte",
    "äktenskapslöftets": "äktenskapslöfte",
    "äktenskapsmarknaden": "äktenskapsmarknad",
    "äktenskapsmarknadens": "äktenskapsmarknad",
    "äktenskapsmarknader": "äktenskapsmarknad",
    "äktenskapsmarknaderna": "äktenskapsmarknad",
    "äktenskapsmarknadernas": "äktenskapsmarknad",
    "äktenskapsmarknaders": "äktenskapsmarknad",
    "äktenskapsmarknads": "äktenskapsmarknad",
    "äktenskapsmäklar": "äktenskapsmäklare",
    "äktenskapsmäklaren": "äktenskapsmäklare",
    "äktenskapsmäklarens": "äktenskapsmäklare",
    "äktenskapsmäklares": "äktenskapsmäklare",
    "äktenskapsmäklarna": "äktenskapsmäklare",
    "äktenskapsmäklarnas": "äktenskapsmäklare",
    "äktenskapsskillnaden": "äktenskapsskillnad",
    "äktenskapsskillnadens": "äktenskapsskillnad",
    "äktenskapsskillnader": "äktenskapsskillnad",
    "äktenskapsskillnaderna": "äktenskapsskillnad",
    "äktenskapsskillnadernas": "äktenskapsskillnad",
    "äktenskapsskillnaders": "äktenskapsskillnad",
    "äktenskapsskillnads": "äktenskapsskillnad",
    "äktenskapstyckes": "äktenskapstycke",
    "äktenskapstycket": "äktenskapstycke",
    "äktenskapstyckets": "äktenskapstycke",
    "äktenskapsåldern": "äktenskapsålder",
    "äktenskapsålderns": "äktenskapsålder",
    "äktenskapsålders": "äktenskapsålder",
    "äktheten": "äkthet",
    "äkthetens": "äkthet",
    "äktheter": "äkthet",
    "äktheterna": "äkthet",
    "äktheternas": "äkthet",
    "äktheters": "äkthet",
    "äkthets": "äkthet",
    "äktsvenska": "äktsvensk",
    "äktsvenskare": "äktsvensk",
    "äktsvenskares": "äktsvensk",
    "äktsvenskas": "äktsvensk",
    "äktsvenskast": "äktsvensk",
    "äktsvenskaste": "äktsvensk",
    "äktsvenskastes": "äktsvensk",
    "äktsvenskasts": "äktsvensk",
    "äktsvenske": "äktsvensk",
    "äktsvenskes": "äktsvensk",
    "äktsvensks": "äktsvensk",
    "äktsvenskt": "äktsvensk",
    "äktsvenskts": "äktsvensk",
    "äldre": "gammal",
    "äldreministern": "äldreminister",
    "äldreministerns": "äldreminister",
    "äldreministers": "äldreminister",
    "äldreministrar": "äldreminister",
    "äldreministrarna": "äldreminister",
    "äldreministrarnas": "äldreminister",
    "äldreministrars": "äldreminister",
    "äldreomsorgen": "äldreomsorg",
    "äldreomsorgens": "äldreomsorg",
    "äldreomsorgs": "äldreomsorg",
    "äldres": "gammal",
    "äldresatsningar": "äldresatsning",
    "äldresatsningarna": "äldresatsning",
    "äldresatsningarnas": "äldresatsning",
    "äldresatsningars": "äldresatsning",
    "äldresatsningen": "äldresatsning",
    "äldresatsningens": "äldresatsning",
    "äldresatsnings": "äldresatsning",
    "äldrevården": "äldrevård",
    "äldrevårdens": "äldrevård",
    "äldrevårds": "äldrevård",
    "äldst": "gammal",
    "äldsta": "gammal",
    "äldstas": "gammal",
    "äldste": "gammal",
    "äldstes": "gammal",
    "äldsts": "gammal",
    "älg": "älga",
    "älgad": "älga",
    "älgade": "älga",
    "älgades": "älga",
    "älgads": "älga",
    "älgande": "älga",
    "älganden": "älgande",
    "älgandena": "älgande",
    "älgandenas": "älgande",
    "älgandens": "älgande",
    "älgandes": "älgande",
    "älgandet": "älgande",
    "älgandets": "älgande",
    "älgar": "älga",
    "älgarna": "älg",
    "älgarnas": "älg",
    "älgars": "älg",
    "älgas": "älga",
    "älgat": "älga",
    "älgats": "älga",
    "älgbesöken": "älgbesök",
    "älgbesökens": "älgbesök",
    "älgbesöket": "älgbesök",
    "älgbesökets": "älgbesök",
    "älgbesöks": "älgbesök",
    "älgen": "älg",
    "älgens": "älg",
    "älgfiguren": "älgfigur",
    "älgfigurens": "älgfigur",
    "älgfigurer": "älgfigur",
    "älgfigurerna": "älgfigur",
    "älgfigurernas": "älgfigur",
    "älgfigurers": "älgfigur",
    "älgfigurs": "älgfigur",
    "älggräset": "älggräs",
    "älggräsets": "älggräs",
    "älghuden": "älghud",
    "älghudens": "älghud",
    "älghuds": "älghud",
    "älgjakten": "älgjakt",
    "älgjaktens": "älgjakt",
    "älgjakter": "älgjakt",
    "älgjakterna": "älgjakt",
    "älgjakternas": "älgjakt",
    "älgjakters": "älgjakt",
    "älgjakts": "älgjakt",
    "älgjägar": "älgjägare",
    "älgjägaren": "älgjägare",
    "älgjägarens": "älgjägare",
    "älgjägares": "älgjägare",
    "älgjägarna": "älgjägare",
    "älgjägarnas": "älgjägare",
    "älgkalvar": "älgkalv",
    "älgkalvarna": "älgkalv",
    "älgkalvarnas": "älgkalv",
    "älgkalvars": "älgkalv",
    "älgkalven": "älgkalv",
    "älgkalvens": "älgkalv",
    "älgkalvs": "älgkalv",
    "älgkliven": "älgkliv",
    "älgklivens": "älgkliv",
    "älgklivet": "älgkliv",
    "älgklivets": "älgkliv",
    "älgklivs": "älgkliv",
    "älgköttet": "älgkött",
    "älgköttets": "älgkött",
    "älgkötts": "älgkött",
    "älgs": "älg",
    "älgskaven": "älgskav",
    "älgskavens": "älgskav",
    "älgskavet": "älgskav",
    "älgskavets": "älgskav",
    "älgskavs": "älgskav",
    "älgstekar": "älgstek",
    "älgstekarna": "älgstek",
    "älgstekarnas": "älgstek",
    "älgstekars": "älgstek",
    "älgsteken": "älgstek",
    "älgstekens": "älgstek",
    "älgsteks": "älgstek",
    "älgstudsar": "älgstudsare",
    "älgstudsaren": "älgstudsare",
    "älgstudsarens": "älgstudsare",
    "älgstudsares": "älgstudsare",
    "älgstudsarna": "älgstudsare",
    "älgstudsarnas": "älgstudsare",
    "ällingar": "älling",
    "ällingarna": "älling",
    "ällingarnas": "älling",
    "ällingars": "älling",
    "ällingen": "älling",
    "ällingens": "älling",
    "ällings": "älling",
    "älskad": "älska",
    "älskade": "älskad",
    "älskades": "älskad",
    "älskads": "älskad",
    "älskande": "älska",
    "älskanden": "älskande",
    "älskandena": "älskande",
    "älskandenas": "älskande",
    "älskandens": "älskande",
    "älskandes": "älskande",
    "älskandet": "älskande",
    "älskandets": "älskande",
    "älskar": "älskare",
    "älskaren": "älskare",
    "älskarens": "älskare",
    "älskares": "älskare",
    "älskarinnan": "älskarinna",
    "älskarinnans": "älskarinna",
    "älskarinnas": "älskarinna",
    "älskarinne": "älskarinna",
    "älskarinnor": "älskarinna",
    "älskarinnorna": "älskarinna",
    "älskarinnornas": "älskarinna",
    "älskarinnors": "älskarinna",
    "älskarna": "älskare",
    "älskarnas": "älskare",
    "älskas": "älska",
    "älskat": "älskad",
    "älskats": "älskad",
    "älskliga": "älsklig",
    "älskligare": "älsklig",
    "älskligares": "älsklig",
    "älskligas": "älsklig",
    "älskligast": "älsklig",
    "älskligaste": "älsklig",
    "älskligastes": "älsklig",
    "älskligasts": "älsklig",
    "älsklige": "älsklig",
    "älskliges": "älsklig",
    "älskligheten": "älsklighet",
    "älsklighetens": "älsklighet",
    "älskligheter": "älsklighet",
    "älskligheterna": "älsklighet",
    "älskligheternas": "älsklighet",
    "älskligheters": "älsklighet",
    "älsklighets": "älsklighet",
    "älskligs": "älsklig",
    "älskligt": "älsklig",
    "älskligts": "älsklig",
    "älsklingar": "älskling",
    "älsklingarna": "älskling",
    "älsklingarnas": "älskling",
    "älsklingars": "älskling",
    "älsklingen": "älskling",
    "älsklingens": "älskling",
    "älsklings": "älskling",
    "älsklingsblom": "älsklingsblomma",
    "älsklingsblomman": "älsklingsblomma",
    "älsklingsblommans": "älsklingsblomma",
    "älsklingsblommas": "älsklingsblomma",
    "älsklingsblomme": "älsklingsblomma",
    "älsklingsblommor": "älsklingsblomma",
    "älsklingsblommorna": "älsklingsblomma",
    "älsklingsblommornas": "älsklingsblomma",
    "älsklingsblommors": "älsklingsblomma",
    "älsklingsbloms": "älsklingsblomma",
    "älsklingsidéen": "älsklingsidé",
    "älsklingsidéens": "älsklingsidé",
    "älsklingsidéer": "älsklingsidé",
    "älsklingsidéerna": "älsklingsidé",
    "älsklingsidéernas": "älsklingsidé",
    "älsklingsidéers": "älsklingsidé",
    "älsklingsidén": "älsklingsidé",
    "älsklingsidéns": "älsklingsidé",
    "älsklingsidés": "älsklingsidé",
    "älsklingsrätten": "älsklingsrätt",
    "älsklingsrättens": "älsklingsrätt",
    "älsklingsrätter": "älsklingsrätt",
    "älsklingsrätterna": "älsklingsrätt",
    "älsklingsrätternas": "älsklingsrätt",
    "älsklingsrätters": "älsklingsrätt",
    "älsklingsrätts": "älsklingsrätt",
    "älskogen": "älskog",
    "älskogens": "älskog",
    "älskogs": "älskog",
    "älskogsgnabben": "älskogsgnabb",
    "älskogsgnabbens": "älskogsgnabb",
    "älskogsgnabbet": "älskogsgnabb",
    "älskogsgnabbets": "älskogsgnabb",
    "älskogsgnabbs": "älskogsgnabb",
    "älskogskranka": "älskogskrank",
    "älskogskrankare": "älskogskrank",
    "älskogskrankares": "älskogskrank",
    "älskogskrankas": "älskogskrank",
    "älskogskrankast": "älskogskrank",
    "älskogskrankaste": "älskogskrank",
    "älskogskrankastes": "älskogskrank",
    "älskogskrankasts": "älskogskrank",
    "älskogskranke": "älskogskrank",
    "älskogskrankes": "älskogskrank",
    "älskogskrankheten": "älskogskrankhet",
    "älskogskrankhetens": "älskogskrankhet",
    "älskogskrankhets": "älskogskrankhet",
    "älskogskranks": "älskogskrank",
    "älskogskrankt": "älskogskrank",
    "älskogskrankts": "älskogskrank",
    "älskvärda": "älskvärd",
    "älskvärdare": "älskvärd",
    "älskvärdares": "älskvärd",
    "älskvärdas": "älskvärd",
    "älskvärdast": "älskvärd",
    "älskvärdaste": "älskvärd",
    "älskvärdastes": "älskvärd",
    "älskvärdasts": "älskvärd",
    "älskvärde": "älskvärd",
    "älskvärdes": "älskvärd",
    "älskvärdheten": "älskvärdhet",
    "älskvärdhetens": "älskvärdhet",
    "älskvärdheter": "älskvärdhet",
    "älskvärdheterna": "älskvärdhet",
    "älskvärdheternas": "älskvärdhet",
    "älskvärdheters": "älskvärdhet",
    "älskvärdhets": "älskvärdhet",
    "älskvärds": "älskvärd",
    "älskvärt": "älskvärd",
    "älskvärts": "älskvärd",
    "ält": "älta",
    "ältad": "älta",
    "ältade": "älta",
    "ältades": "älta",
    "ältads": "älta",
    "ältan": "älta",
    "ältande": "älta",
    "ältanden": "ältande",
    "ältandena": "ältande",
    "ältandenas": "ältande",
    "ältandens": "ältande",
    "ältandes": "ältande",
    "ältandet": "ältande",
    "ältandets": "ältande",
    "ältans": "älta",
    "ältar": "älta",
    "ältas": "älta",
    "ältat": "älta",
    "ältats": "älta",
    "ältgräset": "ältgräs",
    "ältgräsets": "ältgräs",
    "älv": "älva",
    "älvan": "älva",
    "älvans": "älva",
    "älvar": "älv",
    "älvarna": "älv",
    "älvarnas": "älv",
    "älvars": "älv",
    "älvas": "älva",
    "älvbrinkar": "älvbrink",
    "älvbrinkarna": "älvbrink",
    "älvbrinkarnas": "älvbrink",
    "älvbrinkars": "älvbrink",
    "älvbrinken": "älvbrink",
    "älvbrinkens": "älvbrink",
    "älvbrinks": "älvbrink",
    "älvbäddar": "älvbädd",
    "älvbäddarna": "älvbädd",
    "älvbäddarnas": "älvbädd",
    "älvbäddars": "älvbädd",
    "älvbädden": "älvbädd",
    "älvbäddens": "älvbädd",
    "älvbädds": "älvbädd",
    "älvdalingar": "älvdaling",
    "älvdalingarna": "älvdaling",
    "älvdalingarnas": "älvdaling",
    "älvdalingars": "älvdaling",
    "älvdalingen": "älvdaling",
    "älvdalingens": "älvdaling",
    "älvdalings": "älvdaling",
    "älve": "älva",
    "älven": "älv",
    "älvens": "älv",
    "älvkvarnar": "älvkvarn",
    "älvkvarnarna": "älvkvarn",
    "älvkvarnarnas": "älvkvarn",
    "älvkvarnars": "älvkvarn",
    "älvkvarnen": "älvkvarn",
    "älvkvarnens": "älvkvarn",
    "älvkvarns": "älvkvarn",
    "älvmynningar": "älvmynning",
    "älvmynningarna": "älvmynning",
    "älvmynningarnas": "älvmynning",
    "älvmynningars": "älvmynning",
    "älvmynningen": "älvmynning",
    "älvmynningens": "älvmynning",
    "älvmynnings": "älvmynning",
    "älvor": "älva",
    "älvorna": "älva",
    "älvornas": "älva",
    "älvors": "älva",
    "älvs": "älva",
    "älvstranden": "älvstrand",
    "älvstrandens": "älvstrand",
    "älvstrands": "älvstrand",
    "älvstränder": "älvstrand",
    "älvstränderna": "älvstrand",
    "älvsträndernas": "älvstrand",
    "älvstränders": "älvstrand",
    "älväxingen": "älväxing",
    "älväxingens": "älväxing",
    "älväxings": "älväxing",
    "ämabels": "ämabel",
    "ämabelt": "ämabel",
    "ämabelts": "ämabel",
    "ämabla": "ämabel",
    "ämablare": "ämabel",
    "ämablares": "ämabel",
    "ämablas": "ämabel",
    "ämablast": "ämabel",
    "ämablaste": "ämabel",
    "ämablastes": "ämabel",
    "ämablasts": "ämabel",
    "ämable": "ämabel",
    "ämables": "ämabel",
    "ämbaren": "ämbar",
    "ämbarens": "ämbar",
    "ämbaret": "ämbar",
    "ämbarets": "ämbar",
    "ämbars": "ämbar",
    "ämbeten": "ämbete",
    "ämbetena": "ämbete",
    "ämbetenas": "ämbete",
    "ämbetens": "ämbete",
    "ämbetes": "ämbete",
    "ämbetet": "ämbete",
    "ämbetets": "ämbete",
    "ämbets": "ämbete",
    "ämbetsadeln": "ämbetsadel",
    "ämbetsadelns": "ämbetsadel",
    "ämbetsadels": "ämbetsadel",
    "ämbetsansvaret": "ämbetsansvar",
    "ämbetsansvarets": "ämbetsansvar",
    "ämbetsansvars": "ämbetsansvar",
    "ämbetsbrotten": "ämbetsbrott",
    "ämbetsbrottens": "ämbetsbrott",
    "ämbetsbrottet": "ämbetsbrott",
    "ämbetsbrottets": "ämbetsbrott",
    "ämbetsbrotts": "ämbetsbrott",
    "ämbetseden": "ämbetsed",
    "ämbetsedens": "ämbetsed",
    "ämbetseder": "ämbetsed",
    "ämbetsederna": "ämbetsed",
    "ämbetsedernas": "ämbetsed",
    "ämbetseders": "ämbetsed",
    "ämbetseds": "ämbetsed",
    "ämbetsexamens": "ämbetsexamen",
    "ämbetsexamina": "ämbetsexamen",
    "ämbetsexaminas": "ämbetsexamen",
    "ämbetsmannaadeln": "ämbetsmannaadel",
    "ämbetsmannaadelns": "ämbetsmannaadel",
    "ämbetsmannaadels": "ämbetsmannaadel",
    "ämbetsmannaansvaret": "ämbetsmannaansvar",
    "ämbetsmannaansvarets": "ämbetsmannaansvar",
    "ämbetsmannaansvars": "ämbetsmannaansvar",
    "ämbetsmannamässiga": "ämbetsmannamässig",
    "ämbetsmannamässigare": "ämbetsmannamässig",
    "ämbetsmannamässigares": "ämbetsmannamässig",
    "ämbetsmannamässigas": "ämbetsmannamässig",
    "ämbetsmannamässigast": "ämbetsmannamässig",
    "ämbetsmannamässigaste": "ämbetsmannamässig",
    "ämbetsmannamässigastes": "ämbetsmannamässig",
    "ämbetsmannamässigasts": "ämbetsmannamässig",
    "ämbetsmannamässige": "ämbetsmannamässig",
    "ämbetsmannamässiges": "ämbetsmannamässig",
    "ämbetsmannamässigs": "ämbetsmannamässig",
    "ämbetsmannamässigt": "ämbetsmannamässig",
    "ämbetsmannamässigts": "ämbetsmannamässig",
    "ämbetsmannaregeringar": "ämbetsmannaregering",
    "ämbetsmannaregeringarna": "ämbetsmannaregering",
    "ämbetsmannaregeringarnas": "ämbetsmannaregering",
    "ämbetsmannaregeringars": "ämbetsmannaregering",
    "ämbetsmannaregeringen": "ämbetsmannaregering",
    "ämbetsmannaregeringens": "ämbetsmannaregering",
    "ämbetsmannaregerings": "ämbetsmannaregering",
    "ämbetsmannen": "ämbetsman",
    "ämbetsmannens": "ämbetsman",
    "ämbetsmans": "ämbetsman",
    "ämbetsmän": "ämbetsman",
    "ämbetsmännen": "ämbetsman",
    "ämbetsmännens": "ämbetsman",
    "ämbetsmäns": "ämbetsman",
    "ämbetsmässiga": "ämbetsmässig",
    "ämbetsmässigare": "ämbetsmässig",
    "ämbetsmässigares": "ämbetsmässig",
    "ämbetsmässigas": "ämbetsmässig",
    "ämbetsmässigast": "ämbetsmässig",
    "ämbetsmässigaste": "ämbetsmässig",
    "ämbetsmässigastes": "ämbetsmässig",
    "ämbetsmässigasts": "ämbetsmässig",
    "ämbetsmässige": "ämbetsmässig",
    "ämbetsmässiges": "ämbetsmässig",
    "ämbetsmässigs": "ämbetsmässig",
    "ämbetsmässigt": "ämbetsmässig",
    "ämbetsmässigts": "ämbetsmässig",
    "ämbetsperioden": "ämbetsperiod",
    "ämbetsperiodens": "ämbetsperiod",
    "ämbetsperioder": "ämbetsperiod",
    "ämbetsperioderna": "ämbetsperiod",
    "ämbetsperiodernas": "ämbetsperiod",
    "ämbetsperioders": "ämbetsperiod",
    "ämbetsperiods": "ämbetsperiod",
    "ämbetsskrudar": "ämbetsskrud",
    "ämbetsskrudarna": "ämbetsskrud",
    "ämbetsskrudarnas": "ämbetsskrud",
    "ämbetsskrudars": "ämbetsskrud",
    "ämbetsskruden": "ämbetsskrud",
    "ämbetsskrudens": "ämbetsskrud",
    "ämbetsskruds": "ämbetsskrud",
    "ämbetsställningar": "ämbetsställning",
    "ämbetsställningarna": "ämbetsställning",
    "ämbetsställningarnas": "ämbetsställning",
    "ämbetsställningars": "ämbetsställning",
    "ämbetsställningen": "ämbetsställning",
    "ämbetsställningens": "ämbetsställning",
    "ämbetsställnings": "ämbetsställning",
    "ämbetstiteln": "ämbetstitel",
    "ämbetstitelns": "ämbetstitel",
    "ämbetstitels": "ämbetstitel",
    "ämbetstitlar": "ämbetstitel",
    "ämbetstitlarna": "ämbetstitel",
    "ämbetstitlarnas": "ämbetstitel",
    "ämbetstitlars": "ämbetstitel",
    "ämbetsverken": "ämbetsverk",
    "ämbetsverkens": "ämbetsverk",
    "ämbetsverket": "ämbetsverk",
    "ämbetsverkets": "ämbetsverk",
    "ämbetsverks": "ämbetsverk",
    "ämbetsåligganden": "ämbetsåliggande",
    "ämbetsåliggandena": "ämbetsåliggande",
    "ämbetsåliggandenas": "ämbetsåliggande",
    "ämbetsåliggandens": "ämbetsåliggande",
    "ämbetsåliggandes": "ämbetsåliggande",
    "ämbetsåliggandet": "ämbetsåliggande",
    "ämbetsåliggandets": "ämbetsåliggande",
    "ämn": "ämna",
    "ämnad": "ämna",
    "ämnade": "ämna",
    "ämnades": "ämna",
    "ämnads": "ämna",
    "ämnande": "ämna",
    "ämnanden": "ämnande",
    "ämnandena": "ämnande",
    "ämnandenas": "ämnande",
    "ämnandens": "ämnande",
    "ämnandes": "ämnande",
    "ämnandet": "ämnande",
    "ämnandets": "ämnande",
    "ämnar": "ämna",
    "ämnas": "ämna",
    "ämnat": "ämna",
    "ämnats": "ämna",
    "ämnen": "ämne",
    "ämnena": "ämne",
    "ämnenas": "ämne",
    "ämnens": "ämne",
    "ämnes": "ämne",
    "ämnesblocken": "ämnesblock",
    "ämnesblockens": "ämnesblock",
    "ämnesblocket": "ämnesblock",
    "ämnesblockets": "ämnesblock",
    "ämnesblocks": "ämnesblock",
    "ämnesföreträdar": "ämnesföreträdare",
    "ämnesföreträdaren": "ämnesföreträdare",
    "ämnesföreträdarens": "ämnesföreträdare",
    "ämnesföreträdares": "ämnesföreträdare",
    "ämnesföreträdarna": "ämnesföreträdare",
    "ämnesföreträdarnas": "ämnesföreträdare",
    "ämnesgruppen": "ämnesgrupp",
    "ämnesgruppens": "ämnesgrupp",
    "ämnesgrupper": "ämnesgrupp",
    "ämnesgrupperna": "ämnesgrupp",
    "ämnesgruppernas": "ämnesgrupp",
    "ämnesgruppers": "ämnesgrupp",
    "ämnesgrupps": "ämnesgrupp",
    "ämnesintegrationen": "ämnesintegration",
    "ämnesintegrationens": "ämnesintegration",
    "ämnesintegrationer": "ämnesintegration",
    "ämnesintegrationerna": "ämnesintegration",
    "ämnesintegrationernas": "ämnesintegration",
    "ämnesintegrationers": "ämnesintegration",
    "ämnesintegrations": "ämnesintegration",
    "ämnesintegrerad": "ämnesintegrera",
    "ämnesintegrerade": "ämnesintegrera",
    "ämnesintegrerades": "ämnesintegrera",
    "ämnesintegrerads": "ämnesintegrera",
    "ämnesintegrerande": "ämnesintegrera",
    "ämnesintegreranden": "ämnesintegrerande",
    "ämnesintegrerandena": "ämnesintegrerande",
    "ämnesintegrerandenas": "ämnesintegrerande",
    "ämnesintegrerandens": "ämnesintegrerande",
    "ämnesintegrerandes": "ämnesintegrerande",
    "ämnesintegrerandet": "ämnesintegrerande",
    "ämnesintegrerandets": "ämnesintegrerande",
    "ämnesintegrerar": "ämnesintegrera",
    "ämnesintegreras": "ämnesintegrera",
    "ämnesintegrerat": "ämnesintegrera",
    "ämnesintegrerats": "ämnesintegrera",
    "ämnesintegrerbara": "ämnesintegrerbar",
    "ämnesintegrerbarare": "ämnesintegrerbar",
    "ämnesintegrerbarares": "ämnesintegrerbar",
    "ämnesintegrerbaras": "ämnesintegrerbar",
    "ämnesintegrerbarast": "ämnesintegrerbar",
    "ämnesintegrerbaraste": "ämnesintegrerbar",
    "ämnesintegrerbarastes": "ämnesintegrerbar",
    "ämnesintegrerbarasts": "ämnesintegrerbar",
    "ämnesintegrerbare": "ämnesintegrerbar",
    "ämnesintegrerbares": "ämnesintegrerbar",
    "ämnesintegrerbarheten": "ämnesintegrerbarhet",
    "ämnesintegrerbarhetens": "ämnesintegrerbarhet",
    "ämnesintegrerbarhets": "ämnesintegrerbarhet",
    "ämnesintegrerbars": "ämnesintegrerbar",
    "ämnesintegrerbart": "ämnesintegrerbar",
    "ämnesintegrerbarts": "ämnesintegrerbar",
    "ämnesintegreringar": "ämnesintegrering",
    "ämnesintegreringarna": "ämnesintegrering",
    "ämnesintegreringarnas": "ämnesintegrering",
    "ämnesintegreringars": "ämnesintegrering",
    "ämnesintegreringen": "ämnesintegrering",
    "ämnesintegreringens": "ämnesintegrering",
    "ämnesintegrerings": "ämnesintegrering",
    "ämnesjärnen": "ämnesjärn",
    "ämnesjärnens": "ämnesjärn",
    "ämnesjärnet": "ämnesjärn",
    "ämnesjärnets": "ämnesjärn",
    "ämnesjärns": "ämnesjärn",
    "ämneskombinationen": "ämneskombination",
    "ämneskombinationens": "ämneskombination",
    "ämneskombinationer": "ämneskombination",
    "ämneskombinationerna": "ämneskombination",
    "ämneskombinationernas": "ämneskombination",
    "ämneskombinationers": "ämneskombination",
    "ämneskombinations": "ämneskombination",
    "ämneskonferensen": "ämneskonferens",
    "ämneskonferensens": "ämneskonferens",
    "ämneskonferenser": "ämneskonferens",
    "ämneskonferenserna": "ämneskonferens",
    "ämneskonferensernas": "ämneskonferens",
    "ämneskonferensers": "ämneskonferens",
    "ämneslärar": "ämneslärare",
    "ämnesläraren": "ämneslärare",
    "ämneslärarens": "ämneslärare",
    "ämneslärares": "ämneslärare",
    "ämneslärarna": "ämneslärare",
    "ämneslärarnas": "ämneslärare",
    "ämnesmetodiken": "ämnesmetodik",
    "ämnesmetodikens": "ämnesmetodik",
    "ämnesmetodiks": "ämnesmetodik",
    "ämnesmässiga": "ämnesmässig",
    "ämnesmässigare": "ämnesmässig",
    "ämnesmässigares": "ämnesmässig",
    "ämnesmässigas": "ämnesmässig",
    "ämnesmässigast": "ämnesmässig",
    "ämnesmässigaste": "ämnesmässig",
    "ämnesmässigastes": "ämnesmässig",
    "ämnesmässigasts": "ämnesmässig",
    "ämnesmässige": "ämnesmässig",
    "ämnesmässiges": "ämnesmässig",
    "ämnesmässigs": "ämnesmässig",
    "ämnesmässigt": "ämnesmässig",
    "ämnesmässigts": "ämnesmässig",
    "ämnesnamnen": "ämnesnamn",
    "ämnesnamnens": "ämnesnamn",
    "ämnesnamnet": "ämnesnamn",
    "ämnesnamnets": "ämnesnamn",
    "ämnesnamns": "ämnesnamn",
    "ämnesområden": "ämnesområde",
    "ämnesområdena": "ämnesområde",
    "ämnesområdenas": "ämnesområde",
    "ämnesområdens": "ämnesområde",
    "ämnesområdes": "ämnesområde",
    "ämnesområdet": "ämnesområde",
    "ämnesområdets": "ämnesområde",
    "ämnesomsättningar": "ämnesomsättning",
    "ämnesomsättningarna": "ämnesomsättning",
    "ämnesomsättningarnas": "ämnesomsättning",
    "ämnesomsättningars": "ämnesomsättning",
    "ämnesomsättningen": "ämnesomsättning",
    "ämnesomsättningens": "ämnesomsättning",
    "ämnesomsättnings": "ämnesomsättning",
    "ämnessfären": "ämnessfär",
    "ämnessfärens": "ämnessfär",
    "ämnessfärer": "ämnessfär",
    "ämnessfärerna": "ämnessfär",
    "ämnessfärernas": "ämnessfär",
    "ämnessfärers": "ämnessfär",
    "ämnessfärs": "ämnessfär",
    "ämnet": "ämne",
    "ämnets": "ämne",
    "änd": "ände",
    "ändad": "ända",
    "ändade": "ända",
    "ändades": "ändas",
    "ändads": "ända",
    "ändalykten": "ändalykt",
    "ändalyktens": "ändalykt",
    "ändalykts": "ändalykt",
    "ändamålen": "ändamål",
    "ändamålens": "ändamål",
    "ändamålet": "ändamål",
    "ändamålets": "ändamål",
    "ändamåls": "ändamål",
    "ändamålsenliga": "ändamålsenlig",
    "ändamålsenligare": "ändamålsenlig",
    "ändamålsenligares": "ändamålsenlig",
    "ändamålsenligas": "ändamålsenlig",
    "ändamålsenligast": "ändamålsenlig",
    "ändamålsenligaste": "ändamålsenlig",
    "ändamålsenligastes": "ändamålsenlig",
    "ändamålsenligasts": "ändamålsenlig",
    "ändamålsenlige": "ändamålsenlig",
    "ändamålsenliges": "ändamålsenlig",
    "ändamålsenligheten": "ändamålsenlighet",
    "ändamålsenlighetens": "ändamålsenlighet",
    "ändamålsenligheter": "ändamålsenlighet",
    "ändamålsenligheterna": "ändamålsenlighet",
    "ändamålsenligheternas": "ändamålsenlighet",
    "ändamålsenligheters": "ändamålsenlighet",
    "ändamålsenlighets": "ändamålsenlighet",
    "ändamålsenlighetsavväganden": "ändamålsenlighetsavvägande",
    "ändamålsenlighetsavvägandena": "ändamålsenlighetsavvägande",
    "ändamålsenlighetsavvägandenas": "ändamålsenlighetsavvägande",
    "ändamålsenlighetsavvägandens": "ändamålsenlighetsavvägande",
    "ändamålsenlighetsavvägandes": "ändamålsenlighetsavvägande",
    "ändamålsenlighetsavvägandet": "ändamålsenlighetsavvägande",
    "ändamålsenlighetsavvägandets": "ändamålsenlighetsavvägande",
    "ändamålsenligs": "ändamålsenlig",
    "ändamålsenligt": "ändamålsenlig",
    "ändamålsenligts": "ändamålsenlig",
    "ändamålslösa": "ändamålslös",
    "ändamålslösare": "ändamålslös",
    "ändamålslösares": "ändamålslös",
    "ändamålslösas": "ändamålslös",
    "ändamålslösast": "ändamålslös",
    "ändamålslösaste": "ändamålslös",
    "ändamålslösastes": "ändamålslös",
    "ändamålslösasts": "ändamålslös",
    "ändamålslöse": "ändamålslös",
    "ändamålslöses": "ändamålslös",
    "ändamålslösheten": "ändamålslöshet",
    "ändamålslöshetens": "ändamålslöshet",
    "ändamålslöshets": "ändamålslöshet",
    "ändamålslöst": "ändamålslös",
    "ändamålslösts": "ändamålslös",
    "ändan": "ända",
    "ändande": "ända",
    "ändanden": "ändande",
    "ändandena": "ändande",
    "ändandenas": "ändande",
    "ändandens": "ändande",
    "ändandes": "ändande",
    "ändandet": "ändande",
    "ändandets": "ändande",
    "ändans": "ända",
    "ändar": "ände",
    "ändarna": "ände",
    "ändarnas": "ände",
    "ändars": "ände",
    "ändas": "ända",
    "ändat": "ända",
    "ändats": "ändas",
    "ände": "ända",
    "ändelsen": "ändelse",
    "ändelsens": "ändelse",
    "ändelser": "ändelse",
    "ändelserna": "ändelse",
    "ändelsernas": "ändelse",
    "ändelsers": "ändelse",
    "ändelses": "ändelse",
    "änden": "ände",
    "ändens": "ände",
    "änder": "and",
    "änderna": "and",
    "ändernas": "and",
    "änders": "and",
    "ändes": "ände",
    "ändliga": "ändlig",
    "ändligare": "ändlig",
    "ändligares": "ändlig",
    "ändligas": "ändlig",
    "ändligast": "ändlig",
    "ändligaste": "ändlig",
    "ändligastes": "ändlig",
    "ändligasts": "ändlig",
    "ändlige": "ändlig",
    "ändliges": "ändlig",
    "ändligheten": "ändlighet",
    "ändlighetens": "ändlighet",
    "ändlighets": "ändlighet",
    "ändligs": "ändlig",
    "ändligt": "ändlig",
    "ändligts": "ändlig",
    "ändlösa": "ändlös",
    "ändlösare": "ändlös",
    "ändlösares": "ändlös",
    "ändlösas": "ändlös",
    "ändlösast": "ändlös",
    "ändlösaste": "ändlös",
    "ändlösastes": "ändlös",
    "ändlösasts": "ändlös",
    "ändlöse": "ändlös",
    "ändlöses": "ändlös",
    "ändlösheten": "ändlöshet",
    "ändlöshetens": "ändlöshet",
    "ändlöshets": "ändlöshet",
    "ändlöst": "ändlös",
    "ändlösts": "ändlös",
    "ändmoränen": "ändmorän",
    "ändmoränens": "ändmorän",
    "ändmoräner": "ändmorän",
    "ändmoränerna": "ändmorän",
    "ändmoränernas": "ändmorän",
    "ändmoräners": "ändmorän",
    "ändmoräns": "ändmorän",
    "ändor": "ända",
    "ändorna": "ända",
    "ändornas": "ända",
    "ändors": "ända",
    "ändpunkten": "ändpunkt",
    "ändpunktens": "ändpunkt",
    "ändpunkter": "ändpunkt",
    "ändpunkterna": "ändpunkt",
    "ändpunkternas": "ändpunkt",
    "ändpunkters": "ändpunkt",
    "ändpunkts": "ändpunkt",
    "ändrad": "ändra",
    "ändrade": "ändra",
    "ändrades": "ändra",
    "ändrads": "ändra",
    "ändrande": "ändra",
    "ändranden": "ändrande",
    "ändrandena": "ändrande",
    "ändrandenas": "ändrande",
    "ändrandens": "ändrande",
    "ändrandes": "ändrande",
    "ändrandet": "ändrande",
    "ändrandets": "ändrande",
    "ändrar": "ändra",
    "ändras": "ändra",
    "ändrat": "ändra",
    "ändrats": "ändra",
    "ändrimmen": "ändrim",
    "ändrimmens": "ändrim",
    "ändrimmet": "ändrim",
    "ändrimmets": "ändrim",
    "ändrims": "ändrim",
    "ändringar": "ändring",
    "ändringarna": "ändring",
    "ändringarnas": "ändring",
    "ändringars": "ändring",
    "ändringen": "ändring",
    "ändringens": "ändring",
    "ändrings": "ändring",
    "änds": "ände",
    "ändstationen": "ändstation",
    "ändstationens": "ändstation",
    "ändstationer": "ändstation",
    "ändstationerna": "ändstation",
    "ändstationernas": "ändstation",
    "ändstationers": "ändstation",
    "ändstations": "ändstation",
    "ändtarmar": "ändtarm",
    "ändtarmarna": "ändtarm",
    "ändtarmarnas": "ändtarm",
    "ändtarmars": "ändtarm",
    "ändtarmen": "ändtarm",
    "ändtarmens": "ändtarm",
    "ändtarms": "ändtarm",
    "ändträet": "ändträ",
    "ändträets": "ändträ",
    "ändträs": "ändträ",
    "ändträt": "ändträ",
    "ändträts": "ändträ",
    "ändvänd": "ändvända",
    "ändvändande": "ändvända",
    "ändvändanden": "ändvändande",
    "ändvändandena": "ändvändande",
    "ändvändandenas": "ändvändande",
    "ändvändandens": "ändvändande",
    "ändvändandes": "ändvändande",
    "ändvändandet": "ändvändande",
    "ändvändandets": "ändvändande",
    "ändvändas": "ändvända",
    "ändvände": "ändvända",
    "ändvänder": "ändvända",
    "ändvändes": "ändvända",
    "ändvänds": "ändvända",
    "ändvänt": "ändvända",
    "ändvänts": "ändvända",
    "ändytan": "ändyta",
    "ändytans": "ändyta",
    "ändytas": "ändyta",
    "ändyte": "ändyta",
    "ändytor": "ändyta",
    "ändytorna": "ändyta",
    "ändytornas": "ändyta",
    "ändytors": "ändyta",
    "äng-ljuden": "äng-ljud",
    "äng-ljudens": "äng-ljud",
    "äng-ljudet": "äng-ljud",
    "äng-ljudets": "äng-ljud",
    "äng-ljuds": "äng-ljud",
    "ängar": "äng",
    "ängarna": "äng",
    "ängarnas": "äng",
    "ängars": "äng",
    "ängden": "ängd",
    "ängdens": "ängd",
    "ängder": "ängd",
    "ängderna": "ängd",
    "ängdernas": "ängd",
    "ängders": "ängd",
    "ängds": "ängd",
    "ängeln": "ängel",
    "ängelns": "ängel",
    "ängels": "ängel",
    "ängen": "äng",
    "ängens": "äng",
    "ängern": "änger",
    "ängerns": "änger",
    "ängers": "änger",
    "ängla": "ängel",
    "änglafiguren": "änglafigur",
    "änglafigurens": "änglafigur",
    "änglafigurer": "änglafigur",
    "änglafigurerna": "änglafigur",
    "änglafigurernas": "änglafigur",
    "änglafigurers": "änglafigur",
    "änglafigurs": "änglafigur",
    "änglakören": "änglakör",
    "änglakörens": "änglakör",
    "änglakörer": "änglakör",
    "änglakörerna": "änglakör",
    "änglakörernas": "änglakör",
    "änglakörers": "änglakör",
    "änglakörs": "änglakör",
    "änglalika": "änglalik",
    "änglalikare": "änglalik",
    "änglalikares": "änglalik",
    "änglalikas": "änglalik",
    "änglalikast": "änglalik",
    "änglalikaste": "änglalik",
    "änglalikastes": "änglalik",
    "änglalikasts": "änglalik",
    "änglalike": "änglalik",
    "änglalikes": "änglalik",
    "änglalikheten": "änglalikhet",
    "änglalikhetens": "änglalikhet",
    "änglalikhets": "änglalikhet",
    "änglaliks": "änglalik",
    "änglalikt": "änglalik",
    "änglalikts": "änglalik",
    "änglamakerskan": "änglamakerska",
    "änglamakerskans": "änglamakerska",
    "änglamakerskas": "änglamakerska",
    "änglamakerske": "änglamakerska",
    "änglamakerskor": "änglamakerska",
    "änglamakerskorna": "änglamakerska",
    "änglamakerskornas": "änglamakerska",
    "änglamakerskors": "änglamakerska",
    "änglamaten": "änglamat",
    "änglamatens": "änglamat",
    "änglamats": "änglamat",
    "änglar": "ängel",
    "änglarna": "ängel",
    "änglarnas": "ängel",
    "änglars": "ängel",
    "änglaspelen": "änglaspel",
    "änglaspelens": "änglaspel",
    "änglaspelet": "änglaspel",
    "änglaspelets": "änglaspel",
    "änglaspels": "änglaspel",
    "änglavakten": "änglavakt",
    "änglavaktens": "änglavakt",
    "änglavakts": "änglavakt",
    "ängrar": "änger",
    "ängrarna": "änger",
    "ängrarnas": "änger",
    "ängrars": "änger",
    "ängs": "äng",
    "ängsblom": "ängsblomma",
    "ängsblomman": "ängsblomma",
    "ängsblommans": "ängsblomma",
    "ängsblommas": "ängsblomma",
    "ängsblomme": "ängsblomma",
    "ängsblommor": "ängsblomma",
    "ängsblommorna": "ängsblomma",
    "ängsblommornas": "ängsblomma",
    "ängsblommors": "ängsblomma",
    "ängsbloms": "ängsblomma",
    "ängsbollen": "ängsboll",
    "ängsbollens": "ängsboll",
    "ängsbolls": "ängsboll",
    "ängsel": "ängsla",
    "ängsgröen": "ängsgröe",
    "ängsgröens": "ängsgröe",
    "ängsgröes": "ängsgröe",
    "ängsknarrar": "ängsknarr",
    "ängsknarrarna": "ängsknarr",
    "ängsknarrarnas": "ängsknarr",
    "ängsknarrars": "ängsknarr",
    "ängsknarren": "ängsknarr",
    "ängsknarrens": "ängsknarr",
    "ängsknarrs": "ängsknarr",
    "ängslade": "ängsla",
    "ängslades": "ängslas",
    "ängslande": "ängsla",
    "ängslanden": "ängslande",
    "ängslandena": "ängslande",
    "ängslandenas": "ängslande",
    "ängslandens": "ängslande",
    "ängslandes": "ängslande",
    "ängslandet": "ängslande",
    "ängslandets": "ängslande",
    "ängslans": "ängslan",
    "ängslar": "ängsla",
    "ängslas": "ängsla",
    "ängslat": "ängsla",
    "ängslats": "ängslas",
    "ängsliga": "ängslig",
    "ängsligare": "ängslig",
    "ängsligares": "ängslig",
    "ängsligas": "ängslig",
    "ängsligast": "ängslig",
    "ängsligaste": "ängslig",
    "ängsligastes": "ängslig",
    "ängsligasts": "ängslig",
    "ängslige": "ängslig",
    "ängsliges": "ängslig",
    "ängsligheten": "ängslighet",
    "ängslighetens": "ängslighet",
    "ängslighets": "ängslighet",
    "ängsligs": "ängslig",
    "ängsligt": "ängslig",
    "ängsligts": "ängslig",
    "ängsmarken": "ängsmark",
    "ängsmarkens": "ängsmark",
    "ängsmarker": "ängsmark",
    "ängsmarkerna": "ängsmark",
    "ängsmarkernas": "ängsmark",
    "ängsmarkers": "ängsmark",
    "ängsmarks": "ängsmark",
    "ängsrutan": "ängsruta",
    "ängsrutans": "ängsruta",
    "ängsrutas": "ängsruta",
    "ängsrute": "ängsruta",
    "ängsrutor": "ängsruta",
    "ängsrutorna": "ängsruta",
    "ängsrutornas": "ängsruta",
    "ängsrutors": "ängsruta",
    "ängsskäran": "ängsskära",
    "ängsskärans": "ängsskära",
    "ängsskäras": "ängsskära",
    "ängsskäre": "ängsskära",
    "ängsskäror": "ängsskära",
    "ängsskärorna": "ängsskära",
    "ängsskärornas": "ängsskära",
    "ängsskärors": "ängsskära",
    "ängssyran": "ängssyra",
    "ängssyrans": "ängssyra",
    "ängssyras": "ängssyra",
    "ängssyre": "ängssyra",
    "ängssyror": "ängssyra",
    "ängssyrorna": "ängssyra",
    "ängssyrornas": "ängssyra",
    "ängssyrors": "ängssyra",
    "ängsullen": "ängsull",
    "ängsullens": "ängsull",
    "ängsulls": "ängsull",
    "ängsvialen": "ängsvial",
    "ängsvialens": "ängsvial",
    "ängsvialer": "ängsvial",
    "ängsvialerna": "ängsvial",
    "ängsvialernas": "ängsvial",
    "ängsvialers": "ängsvial",
    "ängsvials": "ängsvial",
    "änk": "änka",
    "änkan": "änka",
    "änkans": "änka",
    "änkas": "änka",
    "änke": "änka",
    "änkedoken": "änkedok",
    "änkedokens": "änkedok",
    "änkedoket": "änkedok",
    "änkedokets": "änkedok",
    "änkedoks": "änkedok",
    "änkedrottningar": "änkedrottning",
    "änkedrottningarna": "änkedrottning",
    "änkedrottningarnas": "änkedrottning",
    "änkedrottningars": "änkedrottning",
    "änkedrottningen": "änkedrottning",
    "änkedrottningens": "änkedrottning",
    "änkedrottnings": "änkedrottning",
    "änkefruar": "änkefru",
    "änkefruarna": "änkefru",
    "änkefruarnas": "änkefru",
    "änkefruars": "änkefru",
    "änkefrun": "änkefru",
    "änkefruns": "änkefru",
    "änkefrus": "änkefru",
    "änkemannen": "änkeman",
    "änkemannens": "änkeman",
    "änkemans": "änkeman",
    "änkemän": "änkeman",
    "änkemännen": "änkeman",
    "änkemännens": "änkeman",
    "änkemäns": "änkeman",
    "änkenåden": "änkenåd",
    "änkenådens": "änkenåd",
    "änkenåder": "änkenåd",
    "änkenåderna": "änkenåd",
    "änkenådernas": "änkenåd",
    "änkenåders": "änkenåd",
    "änkenåds": "änkenåd",
    "änkepensionen": "änkepension",
    "änkepensionens": "änkepension",
    "änkepensioner": "änkepension",
    "änkepensionerna": "änkepension",
    "änkepensionernas": "änkepension",
    "änkepensioners": "änkepension",
    "änkepensions": "änkepension",
    "änkestötar": "änkestöt",
    "änkestötarna": "änkestöt",
    "änkestötarnas": "änkestöt",
    "änkestötars": "änkestöt",
    "änkestöten": "änkestöt",
    "änkestötens": "änkestöt",
    "änkestöts": "änkestöt",
    "änkeåren": "änkeår",
    "änkeårens": "änkeår",
    "änkeåret": "änkeår",
    "änkeårets": "änkeår",
    "änkeårs": "änkeår",
    "änklingar": "änkling",
    "änklingarna": "änkling",
    "änklingarnas": "änkling",
    "änklingars": "änkling",
    "änklingen": "änkling",
    "änklingens": "änkling",
    "änklings": "änkling",
    "änkor": "änka",
    "änkorna": "änka",
    "änkornas": "änka",
    "änkors": "änka",
    "änks": "änka",
    "ännen": "änne",
    "ännena": "änne",
    "ännenas": "änne",
    "ännens": "änne",
    "ännes": "änne",
    "ännet": "änne",
    "ännets": "änne",
    "änns": "änne",
    "änter": "äntra",
    "änterbil": "änterbila",
    "änterbilan": "änterbila",
    "änterbilans": "änterbila",
    "änterbilas": "änterbila",
    "änterbile": "änterbila",
    "änterbilor": "änterbila",
    "änterbilorna": "änterbila",
    "änterbilornas": "änterbila",
    "änterbilors": "änterbila",
    "änterbils": "änterbila",
    "änterhakar": "änterhake",
    "änterhakarna": "änterhake",
    "änterhakarnas": "änterhake",
    "änterhakars": "änterhake",
    "änterhaken": "änterhake",
    "änterhakens": "änterhake",
    "änterhakes": "änterhake",
    "änterpikar": "änterpik",
    "änterpikarna": "änterpik",
    "änterpikarnas": "änterpik",
    "änterpikars": "änterpik",
    "änterpiken": "änterpik",
    "änterpikens": "änterpik",
    "änterpiks": "änterpik",
    "äntrad": "äntra",
    "äntrade": "äntra",
    "äntrades": "äntra",
    "äntrads": "äntra",
    "äntrande": "äntra",
    "äntranden": "äntrande",
    "äntrandena": "äntrande",
    "äntrandenas": "äntrande",
    "äntrandens": "äntrande",
    "äntrandes": "äntrande",
    "äntrandet": "äntrande",
    "äntrandets": "äntrande",
    "äntrar": "äntra",
    "äntras": "äntra",
    "äntrat": "äntra",
    "äntrats": "äntra",
    "äntringar": "äntring",
    "äntringarna": "äntring",
    "äntringarnas": "äntring",
    "äntringars": "äntring",
    "äntringen": "äntring",
    "äntringens": "äntring",
    "äntrings": "äntring",
    "äntringsstriden": "äntringsstrid",
    "äntringsstridens": "äntringsstrid",
    "äntringsstrider": "äntringsstrid",
    "äntringsstriderna": "äntringsstrid",
    "äntringsstridernas": "äntringsstrid",
    "äntringsstriders": "äntringsstrid",
    "äntringsstrids": "äntringsstrid",
    "äppelblommen": "äppelblom",
    "äppelblommens": "äppelblom",
    "äppelbloms": "äppelblom",
    "äppelkak": "äppelkaka",
    "äppelkakan": "äppelkaka",
    "äppelkakans": "äppelkaka",
    "äppelkakas": "äppelkaka",
    "äppelkake": "äppelkaka",
    "äppelkakor": "äppelkaka",
    "äppelkakorna": "äppelkaka",
    "äppelkakornas": "äppelkaka",
    "äppelkakors": "äppelkaka",
    "äppelkaks": "äppelkaka",
    "äppelkartar": "äppelkart",
    "äppelkartarna": "äppelkart",
    "äppelkartarnas": "äppelkart",
    "äppelkartars": "äppelkart",
    "äppelkarten": "äppelkart",
    "äppelkartens": "äppelkart",
    "äppelkarts": "äppelkart",
    "äppelkindade": "äppelkindad",
    "äppelkindades": "äppelkindad",
    "äppelkindads": "äppelkindad",
    "äppelkindat": "äppelkindad",
    "äppelkindats": "äppelkindad",
    "äppelmosen": "äppelmos",
    "äppelmosens": "äppelmos",
    "äppelmoset": "äppelmos",
    "äppelmosets": "äppelmos",
    "äppelpräktiga": "äppelpräktig",
    "äppelpräktigare": "äppelpräktig",
    "äppelpräktigares": "äppelpräktig",
    "äppelpräktigas": "äppelpräktig",
    "äppelpräktigast": "äppelpräktig",
    "äppelpräktigaste": "äppelpräktig",
    "äppelpräktigastes": "äppelpräktig",
    "äppelpräktigasts": "äppelpräktig",
    "äppelpräktige": "äppelpräktig",
    "äppelpräktiges": "äppelpräktig",
    "äppelpräktigheten": "äppelpräktighet",
    "äppelpräktighetens": "äppelpräktighet",
    "äppelpräktighets": "äppelpräktighet",
    "äppelpräktigs": "äppelpräktig",
    "äppelpräktigt": "äppelpräktig",
    "äppelpräktigts": "äppelpräktig",
    "äppelskorven": "äppelskorv",
    "äppelskorvens": "äppelskorv",
    "äppelskorvs": "äppelskorv",
    "äppelskrottar": "äppelskrott",
    "äppelskrottarna": "äppelskrott",
    "äppelskrottarnas": "äppelskrott",
    "äppelskrottars": "äppelskrott",
    "äppelskrotten": "äppelskrott",
    "äppelskrottens": "äppelskrott",
    "äppelskrotts": "äppelskrott",
    "äppelskruttar": "äppelskrutt",
    "äppelskruttarna": "äppelskrutt",
    "äppelskruttarnas": "äppelskrutt",
    "äppelskruttars": "äppelskrutt",
    "äppelskrutten": "äppelskrutt",
    "äppelskruttens": "äppelskrutt",
    "äppelskrutts": "äppelskrutt",
    "äppelsyran": "äppelsyra",
    "äppelsyrans": "äppelsyra",
    "äppelsyras": "äppelsyra",
    "äppelsyre": "äppelsyra",
    "äppelträden": "äppelträd",
    "äppelträdens": "äppelträd",
    "äppelträdet": "äppelträd",
    "äppelträdets": "äppelträd",
    "äppelträds": "äppelträd",
    "äppelvecklar": "äppelvecklare",
    "äppelvecklaren": "äppelvecklare",
    "äppelvecklarens": "äppelvecklare",
    "äppelvecklares": "äppelvecklare",
    "äppelvecklarna": "äppelvecklare",
    "äppelvecklarnas": "äppelvecklare",
    "äpplekak": "äpplekaka",
    "äpplekakan": "äpplekaka",
    "äpplekakans": "äpplekaka",
    "äpplekakas": "äpplekaka",
    "äpplekake": "äpplekaka",
    "äpplekakor": "äpplekaka",
    "äpplekakorna": "äpplekaka",
    "äpplekakornas": "äpplekaka",
    "äpplekakors": "äpplekaka",
    "äpplekaks": "äpplekaka",
    "äpplekartar": "äpplekart",
    "äpplekartarna": "äpplekart",
    "äpplekartarnas": "äpplekart",
    "äpplekartars": "äpplekart",
    "äpplekarten": "äpplekart",
    "äpplekartens": "äpplekart",
    "äpplekarts": "äpplekart",
    "äpplemosen": "äpplemos",
    "äpplemosens": "äpplemos",
    "äpplemoset": "äpplemos",
    "äpplemosets": "äpplemos",
    "äpplen": "äpple",
    "äpplena": "äpple",
    "äpplenas": "äpple",
    "äpplens": "äpple",
    "äpples": "äpple",
    "äppleskorven": "äppleskorv",
    "äppleskorvens": "äppleskorv",
    "äppleskorvs": "äppleskorv",
    "äppleskrottar": "äppleskrott",
    "äppleskrottarna": "äppleskrott",
    "äppleskrottarnas": "äppleskrott",
    "äppleskrottars": "äppleskrott",
    "äppleskrotten": "äppleskrott",
    "äppleskrottens": "äppleskrott",
    "äppleskrotts": "äppleskrott",
    "äpplesyran": "äpplesyra",
    "äpplesyrans": "äpplesyra",
    "äpplesyras": "äpplesyra",
    "äpplesyre": "äpplesyra",
    "äpplesyror": "äpplesyra",
    "äpplesyrorna": "äpplesyra",
    "äpplesyrornas": "äpplesyra",
    "äpplesyrors": "äpplesyra",
    "äpplet": "äpple",
    "äppleträden": "äppleträd",
    "äppleträdens": "äppleträd",
    "äppleträdet": "äppleträd",
    "äppleträdets": "äppleträd",
    "äppleträds": "äppleträd",
    "äpplets": "äpple",
    "är": "vara",
    "ärad": "ära",
    "ärade": "ärad",
    "ärades": "ärad",
    "ärads": "ärad",
    "äran": "ära",
    "ärande": "ära",
    "äranden": "ärande",
    "ärandena": "ärande",
    "ärandenas": "ärande",
    "ärandens": "ärande",
    "ärandes": "ärande",
    "ärandet": "ärande",
    "ärandets": "ärande",
    "ärans": "ära",
    "ärar": "ära",
    "äras": "ära",
    "ärat": "ärad",
    "ärats": "ärad",
    "ärbara": "ärbar",
    "ärbarare": "ärbar",
    "ärbarares": "ärbar",
    "ärbaras": "ärbar",
    "ärbarast": "ärbar",
    "ärbaraste": "ärbar",
    "ärbarastes": "ärbar",
    "ärbarasts": "ärbar",
    "ärbare": "ärbar",
    "ärbares": "ärbar",
    "ärbarheten": "ärbarhet",
    "ärbarhetens": "ärbarhet",
    "ärbarhets": "ärbarhet",
    "ärbars": "ärbar",
    "ärbart": "ärbar",
    "ärbarts": "ärbar",
    "ärebetygelsen": "ärebetygelse",
    "ärebetygelsens": "ärebetygelse",
    "ärebetygelser": "ärebetygelse",
    "ärebetygelserna": "ärebetygelse",
    "ärebetygelsernas": "ärebetygelse",
    "ärebetygelsers": "ärebetygelse",
    "ärebetygelses": "ärebetygelse",
    "äreförgätens": "äreförgäten",
    "äreförgätet": "äreförgäten",
    "äreförgätets": "äreförgäten",
    "äreförgätna": "äreförgäten",
    "äreförgätnare": "äreförgäten",
    "äreförgätnares": "äreförgäten",
    "äreförgätnas": "äreförgäten",
    "äreförgätnast": "äreförgäten",
    "äreförgätnaste": "äreförgäten",
    "äreförgätnastes": "äreförgäten",
    "äreförgätnasts": "äreförgäten",
    "äreförgätne": "äreförgäten",
    "äreförgätnes": "äreförgäten",
    "äregiriga": "äregirig",
    "äregirigare": "äregirig",
    "äregirigares": "äregirig",
    "äregirigas": "äregirig",
    "äregirigast": "äregirig",
    "äregirigaste": "äregirig",
    "äregirigastes": "äregirig",
    "äregirigasts": "äregirig",
    "äregirige": "äregirig",
    "äregiriges": "äregirig",
    "äregirigheten": "äregirighet",
    "äregirighetens": "äregirighet",
    "äregirighets": "äregirighet",
    "äregirigs": "äregirig",
    "äregirigt": "äregirig",
    "äregirigts": "äregirig",
    "ärekränk": "ärekränka",
    "ärekränkande": "ärekränka",
    "ärekränkanden": "ärekränkande",
    "ärekränkandena": "ärekränkande",
    "ärekränkandenas": "ärekränkande",
    "ärekränkandens": "ärekränkande",
    "ärekränkandes": "ärekränkande",
    "ärekränkandet": "ärekränkande",
    "ärekränkandets": "ärekränkande",
    "ärekränkas": "ärekränka",
    "ärekränker": "ärekränka",
    "ärekränkes": "ärekränka",
    "ärekränkningar": "ärekränkning",
    "ärekränkningarna": "ärekränkning",
    "ärekränkningarnas": "ärekränkning",
    "ärekränkningars": "ärekränkning",
    "ärekränkningen": "ärekränkning",
    "ärekränkningens": "ärekränkning",
    "ärekränknings": "ärekränkning",
    "ärekränks": "ärekränka",
    "ärekränkt": "ärekränka",
    "ärekränkta": "ärekränka",
    "ärekränktas": "ärekränka",
    "ärekränkte": "ärekränka",
    "ärekränktes": "ärekränka",
    "ärekränkts": "ärekränka",
    "ärelystens": "ärelysten",
    "ärelystet": "ärelysten",
    "ärelystets": "ärelysten",
    "ärelystna": "ärelysten",
    "ärelystnaden": "ärelystnad",
    "ärelystnadens": "ärelystnad",
    "ärelystnader": "ärelystnad",
    "ärelystnaderna": "ärelystnad",
    "ärelystnadernas": "ärelystnad",
    "ärelystnaders": "ärelystnad",
    "ärelystnads": "ärelystnad",
    "ärelystnare": "ärelysten",
    "ärelystnares": "ärelysten",
    "ärelystnas": "ärelysten",
    "ärelystnast": "ärelysten",
    "ärelystnaste": "ärelysten",
    "ärelystnastes": "ärelysten",
    "ärelystnasts": "ärelysten",
    "ärelystne": "ärelysten",
    "ärelystnes": "ärelysten",
    "ärelösa": "ärelös",
    "ärelösare": "ärelös",
    "ärelösares": "ärelös",
    "ärelösas": "ärelös",
    "ärelösast": "ärelös",
    "ärelösaste": "ärelös",
    "ärelösastes": "ärelös",
    "ärelösasts": "ärelös",
    "ärelöse": "ärelös",
    "ärelöses": "ärelös",
    "ärelösheten": "ärelöshet",
    "ärelöshetens": "ärelöshet",
    "ärelöshets": "ärelöshet",
    "ärelöst": "ärelös",
    "ärelösts": "ärelös",
    "äreminnen": "äreminne",
    "äreminnena": "äreminne",
    "äreminnenas": "äreminne",
    "äreminnens": "äreminne",
    "äreminnes": "äreminne",
    "äreminnet": "äreminne",
    "äreminnets": "äreminne",
    "ärenden": "ärende",
    "ärendena": "ärende",
    "ärendenas": "ärende",
    "ärendens": "ärende",
    "ärendes": "ärende",
    "ärendet": "ärende",
    "ärendets": "ärende",
    "ärenprisen": "ärenpris",
    "ärenprisens": "ärenpris",
    "äreportar": "äreport",
    "äreportarna": "äreport",
    "äreportarnas": "äreport",
    "äreportars": "äreport",
    "äreporten": "äreport",
    "äreportens": "äreport",
    "äreports": "äreport",
    "äreräddningar": "äreräddning",
    "äreräddningarna": "äreräddning",
    "äreräddningarnas": "äreräddning",
    "äreräddningars": "äreräddning",
    "äreräddningen": "äreräddning",
    "äreräddningens": "äreräddning",
    "äreräddnings": "äreräddning",
    "äreröriga": "ärerörig",
    "ärerörigare": "ärerörig",
    "ärerörigares": "ärerörig",
    "ärerörigas": "ärerörig",
    "ärerörigast": "ärerörig",
    "ärerörigaste": "ärerörig",
    "ärerörigastes": "ärerörig",
    "ärerörigasts": "ärerörig",
    "ärerörige": "ärerörig",
    "äreröriges": "ärerörig",
    "ärerörigheten": "ärerörighet",
    "ärerörighetens": "ärerörighet",
    "ärerörigheter": "ärerörighet",
    "ärerörigheterna": "ärerörighet",
    "ärerörigheternas": "ärerörighet",
    "ärerörigheters": "ärerörighet",
    "ärerörighets": "ärerörighet",
    "ärerörigs": "ärerörig",
    "ärerörigt": "ärerörig",
    "ärerörigts": "ärerörig",
    "äresaken": "äresak",
    "äresakens": "äresak",
    "äresaker": "äresak",
    "äresakerna": "äresak",
    "äresakernas": "äresak",
    "äresakers": "äresak",
    "äresaks": "äresak",
    "ärevarven": "ärevarv",
    "ärevarvens": "ärevarv",
    "ärevarvet": "ärevarv",
    "ärevarvets": "ärevarv",
    "ärevarvs": "ärevarv",
    "ärevördiga": "ärevördig",
    "ärevördigare": "ärevördig",
    "ärevördigares": "ärevördig",
    "ärevördigas": "ärevördig",
    "ärevördigast": "ärevördig",
    "ärevördigaste": "ärevördig",
    "ärevördigastes": "ärevördig",
    "ärevördigasts": "ärevördig",
    "ärevördige": "ärevördig",
    "ärevördiges": "ärevördig",
    "ärevördigheten": "ärevördighet",
    "ärevördighetens": "ärevördighet",
    "ärevördighets": "ärevördighet",
    "ärevördigs": "ärevördig",
    "ärevördigt": "ärevördig",
    "ärevördigts": "ärevördig",
    "ärftliga": "ärftlig",
    "ärftligare": "ärftlig",
    "ärftligares": "ärftlig",
    "ärftligas": "ärftlig",
    "ärftligast": "ärftlig",
    "ärftligaste": "ärftlig",
    "ärftligastes": "ärftlig",
    "ärftligasts": "ärftlig",
    "ärftlige": "ärftlig",
    "ärftliges": "ärftlig",
    "ärftligheten": "ärftlighet",
    "ärftlighetens": "ärftlighet",
    "ärftligheter": "ärftlighet",
    "ärftligheterna": "ärftlighet",
    "ärftligheternas": "ärftlighet",
    "ärftligheters": "ärftlighet",
    "ärftlighets": "ärftlighet",
    "ärftlighetsforskar": "ärftlighetsforskare",
    "ärftlighetsforskaren": "ärftlighetsforskare",
    "ärftlighetsforskarens": "ärftlighetsforskare",
    "ärftlighetsforskares": "ärftlighetsforskare",
    "ärftlighetsforskarna": "ärftlighetsforskare",
    "ärftlighetsforskarnas": "ärftlighetsforskare",
    "ärftlighetslagar": "ärftlighetslag",
    "ärftlighetslagarna": "ärftlighetslag",
    "ärftlighetslagarnas": "ärftlighetslag",
    "ärftlighetslagars": "ärftlighetslag",
    "ärftlighetslagen": "ärftlighetslag",
    "ärftlighetslagens": "ärftlighetslag",
    "ärftlighetslags": "ärftlighetslag",
    "ärftlighetsläran": "ärftlighetslära",
    "ärftlighetslärans": "ärftlighetslära",
    "ärftlighetsläras": "ärftlighetslära",
    "ärftligs": "ärftlig",
    "ärftligt": "ärftlig",
    "ärftligts": "ärftlig",
    "ärg": "ärga",
    "ärgad": "ärga",
    "ärgade": "ärga",
    "ärgades": "ärgas",
    "ärgads": "ärga",
    "ärgande": "ärga",
    "ärganden": "ärgande",
    "ärgandena": "ärgande",
    "ärgandenas": "ärgande",
    "ärgandens": "ärgande",
    "ärgandes": "ärgande",
    "ärgandet": "ärgande",
    "ärgandets": "ärgande",
    "ärgar": "ärga",
    "ärgas": "ärga",
    "ärgat": "ärga",
    "ärgats": "ärgas",
    "ärgen": "ärg",
    "ärgens": "ärg",
    "ärggröna": "ärggrön",
    "ärggrönare": "ärggrön",
    "ärggrönares": "ärggrön",
    "ärggrönas": "ärggrön",
    "ärggrönast": "ärggrön",
    "ärggrönaste": "ärggrön",
    "ärggrönastes": "ärggrön",
    "ärggrönasts": "ärggrön",
    "ärggröne": "ärggrön",
    "ärggrönes": "ärggrön",
    "ärggröns": "ärggrön",
    "ärggrönt": "ärggrön",
    "ärggrönts": "ärggrön",
    "ärgiga": "ärgig",
    "ärgigare": "ärgig",
    "ärgigares": "ärgig",
    "ärgigas": "ärgig",
    "ärgigast": "ärgig",
    "ärgigaste": "ärgig",
    "ärgigastes": "ärgig",
    "ärgigasts": "ärgig",
    "ärgige": "ärgig",
    "ärgiges": "ärgig",
    "ärgigheten": "ärgighet",
    "ärgighetens": "ärgighet",
    "ärgighets": "ärgighet",
    "ärgigs": "ärgig",
    "ärgigt": "ärgig",
    "ärgigts": "ärgig",
    "ärgs": "ärg",
    "ärilar": "äril",
    "ärilarna": "äril",
    "ärilarnas": "äril",
    "ärilars": "äril",
    "ärilen": "äril",
    "ärilens": "äril",
    "äriln": "äril",
    "ärilns": "äril",
    "ärils": "äril",
    "äringen": "äring",
    "äringens": "äring",
    "ärings": "äring",
    "ärj": "ärja",
    "ärjad": "ärja",
    "ärjade": "ärja",
    "ärjades": "ärja",
    "ärjads": "ärja",
    "ärjande": "ärja",
    "ärjanden": "ärjande",
    "ärjandena": "ärjande",
    "ärjandenas": "ärjande",
    "ärjandens": "ärjande",
    "ärjandes": "ärjande",
    "ärjandet": "ärjande",
    "ärjandets": "ärjande",
    "ärjar": "ärja",
    "ärjas": "ärja",
    "ärjat": "ärja",
    "ärjats": "ärja",
    "ärjkrokar": "ärjkrok",
    "ärjkrokarna": "ärjkrok",
    "ärjkrokarnas": "ärjkrok",
    "ärjkrokars": "ärjkrok",
    "ärjkroken": "ärjkrok",
    "ärjkrokens": "ärjkrok",
    "ärjkroks": "ärjkrok",
    "ärkebiskopar": "ärkebiskop",
    "ärkebiskoparna": "ärkebiskop",
    "ärkebiskoparnas": "ärkebiskop",
    "ärkebiskopars": "ärkebiskop",
    "ärkebiskopen": "ärkebiskop",
    "ärkebiskopens": "ärkebiskop",
    "ärkebiskops": "ärkebiskop",
    "ärkefienden": "ärkefiende",
    "ärkefiendens": "ärkefiende",
    "ärkefiender": "ärkefiende",
    "ärkefienderna": "ärkefiende",
    "ärkefiendernas": "ärkefiende",
    "ärkefienders": "ärkefiende",
    "ärkefiendes": "ärkefiende",
    "ärkehertigar": "ärkehertig",
    "ärkehertigarna": "ärkehertig",
    "ärkehertigarnas": "ärkehertig",
    "ärkehertigars": "ärkehertig",
    "ärkehertigen": "ärkehertig",
    "ärkehertigens": "ärkehertig",
    "ärkehertigs": "ärkehertig",
    "ärkekonservativa": "ärkekonservativ",
    "ärkekonservativare": "ärkekonservativ",
    "ärkekonservativares": "ärkekonservativ",
    "ärkekonservativas": "ärkekonservativ",
    "ärkekonservativast": "ärkekonservativ",
    "ärkekonservativaste": "ärkekonservativ",
    "ärkekonservativastes": "ärkekonservativ",
    "ärkekonservativasts": "ärkekonservativ",
    "ärkekonservative": "ärkekonservativ",
    "ärkekonservatives": "ärkekonservativ",
    "ärkekonservativs": "ärkekonservativ",
    "ärkekonservativt": "ärkekonservativ",
    "ärkekonservativts": "ärkekonservativ",
    "ärkenöten": "ärkenöt",
    "ärkenötens": "ärkenöt",
    "ärkenötet": "ärkenöt",
    "ärkenötets": "ärkenöt",
    "ärkenöts": "ärkenöt",
    "ärkereaktionären": "ärkereaktionär",
    "ärkereaktionärens": "ärkereaktionär",
    "ärkereaktionärer": "ärkereaktionär",
    "ärkereaktionärerna": "ärkereaktionär",
    "ärkereaktionärernas": "ärkereaktionär",
    "ärkereaktionärers": "ärkereaktionär",
    "ärkereaktionärs": "ärkereaktionär",
    "ärkeskurkar": "ärkeskurk",
    "ärkeskurkarna": "ärkeskurk",
    "ärkeskurkarnas": "ärkeskurk",
    "ärkeskurkars": "ärkeskurk",
    "ärkeskurken": "ärkeskurk",
    "ärkeskurkens": "ärkeskurk",
    "ärkeskurks": "ärkeskurk",
    "ärkestiften": "ärkestift",
    "ärkestiftens": "ärkestift",
    "ärkestiftet": "ärkestift",
    "ärkestiftets": "ärkestift",
    "ärkestifts": "ärkestift",
    "ärkeängeln": "ärkeängel",
    "ärkeängelns": "ärkeängel",
    "ärkeängels": "ärkeängel",
    "ärkeängla": "ärkeängel",
    "ärkeänglar": "ärkeängel",
    "ärkeänglarna": "ärkeängel",
    "ärkeänglarnas": "ärkeängel",
    "ärkeänglars": "ärkeängel",
    "ärl": "ärla",
    "ärlan": "ärla",
    "ärlans": "ärla",
    "ärlas": "ärla",
    "ärle": "ärla",
    "ärliga": "ärlig",
    "ärligare": "ärlig",
    "ärligares": "ärlig",
    "ärligas": "ärlig",
    "ärligast": "ärlig",
    "ärligaste": "ärlig",
    "ärligastes": "ärlig",
    "ärligasts": "ärlig",
    "ärlige": "ärlig",
    "ärliges": "ärlig",
    "ärligheten": "ärlighet",
    "ärlighetens": "ärlighet",
    "ärligheter": "ärlighet",
    "ärligheterna": "ärlighet",
    "ärligheternas": "ärlighet",
    "ärligheters": "ärlighet",
    "ärlighets": "ärlighet",
    "ärligs": "ärlig",
    "ärligt": "ärlig",
    "ärligts": "ärlig",
    "ärlor": "ärla",
    "ärlorna": "ärla",
    "ärlornas": "ärla",
    "ärlors": "ärla",
    "ärls": "ärla",
    "ärmar": "ärm",
    "ärmarna": "ärm",
    "ärmarnas": "ärm",
    "ärmars": "ärm",
    "ärmbräd": "ärmbräda",
    "ärmbrädan": "ärmbräda",
    "ärmbrädans": "ärmbräda",
    "ärmbrädas": "ärmbräda",
    "ärmbräde": "ärmbräda",
    "ärmbräden": "ärmbräde",
    "ärmbrädena": "ärmbräde",
    "ärmbrädenas": "ärmbräde",
    "ärmbrädens": "ärmbräde",
    "ärmbrädes": "ärmbräde",
    "ärmbrädet": "ärmbräde",
    "ärmbrädets": "ärmbräde",
    "ärmbrädor": "ärmbräda",
    "ärmbrädorna": "ärmbräda",
    "ärmbrädornas": "ärmbräda",
    "ärmbrädors": "ärmbräda",
    "ärmbräds": "ärmbräda",
    "ärmen": "ärm",
    "ärmens": "ärm",
    "ärmhålen": "ärmhål",
    "ärmhålens": "ärmhål",
    "ärmhålet": "ärmhål",
    "ärmhålets": "ärmhål",
    "ärmhållar": "ärmhållare",
    "ärmhållaren": "ärmhållare",
    "ärmhållarens": "ärmhållare",
    "ärmhållares": "ärmhållare",
    "ärmhållarna": "ärmhållare",
    "ärmhållarnas": "ärmhållare",
    "ärmhåls": "ärmhål",
    "ärmlinningar": "ärmlinning",
    "ärmlinningarna": "ärmlinning",
    "ärmlinningarnas": "ärmlinning",
    "ärmlinningars": "ärmlinning",
    "ärmlinningen": "ärmlinning",
    "ärmlinningens": "ärmlinning",
    "ärmlinnings": "ärmlinning",
    "ärmlösa": "ärmlös",
    "ärmlösare": "ärmlös",
    "ärmlösares": "ärmlös",
    "ärmlösas": "ärmlös",
    "ärmlösast": "ärmlös",
    "ärmlösaste": "ärmlös",
    "ärmlösastes": "ärmlös",
    "ärmlösasts": "ärmlös",
    "ärmlöse": "ärmlös",
    "ärmlöses": "ärmlös",
    "ärmlösheten": "ärmlöshet",
    "ärmlöshetens": "ärmlöshet",
    "ärmlöshets": "ärmlöshet",
    "ärmlöst": "ärmlös",
    "ärmlösts": "ärmlös",
    "ärms": "ärm",
    "ärn": "ärna",
    "ärnad": "ärna",
    "ärnade": "ärna",
    "ärnades": "ärna",
    "ärnads": "ärna",
    "ärnande": "ärna",
    "ärnanden": "ärnande",
    "ärnandena": "ärnande",
    "ärnandenas": "ärnande",
    "ärnandens": "ärnande",
    "ärnandes": "ärnande",
    "ärnandet": "ärnande",
    "ärnandets": "ärnande",
    "ärnar": "ärna",
    "ärnas": "ärna",
    "ärnat": "ärna",
    "ärnats": "ärna",
    "ärofulla": "ärofull",
    "ärofullare": "ärofull",
    "ärofullares": "ärofull",
    "ärofullas": "ärofull",
    "ärofullast": "ärofull",
    "ärofullaste": "ärofull",
    "ärofullastes": "ärofull",
    "ärofullasts": "ärofull",
    "ärofulle": "ärofull",
    "ärofulles": "ärofull",
    "ärofullheten": "ärofullhet",
    "ärofullhetens": "ärofullhet",
    "ärofullhets": "ärofullhet",
    "ärofulls": "ärofull",
    "ärofullt": "ärofull",
    "ärofullts": "ärofull",
    "ärofyllda": "ärofylld",
    "ärofylldare": "ärofylld",
    "ärofylldares": "ärofylld",
    "ärofylldas": "ärofylld",
    "ärofylldast": "ärofylld",
    "ärofylldaste": "ärofylld",
    "ärofylldastes": "ärofylld",
    "ärofylldasts": "ärofylld",
    "ärofyllde": "ärofylld",
    "ärofylldes": "ärofylld",
    "ärofylldheten": "ärofylldhet",
    "ärofylldhetens": "ärofylldhet",
    "ärofylldhets": "ärofylldhet",
    "ärofyllds": "ärofylld",
    "ärofyllt": "ärofylld",
    "ärofyllts": "ärofylld",
    "ärorika": "ärorik",
    "ärorikare": "ärorik",
    "ärorikares": "ärorik",
    "ärorikas": "ärorik",
    "ärorikast": "ärorik",
    "ärorikaste": "ärorik",
    "ärorikastes": "ärorik",
    "ärorikasts": "ärorik",
    "ärorike": "ärorik",
    "ärorikes": "ärorik",
    "ärorikheten": "ärorikhet",
    "ärorikhetens": "ärorikhet",
    "ärorikhets": "ärorikhet",
    "äroriks": "ärorik",
    "ärorikt": "ärorik",
    "ärorikts": "ärorik",
    "ärrades": "ärras",
    "ärrats": "ärras",
    "ärrbildningar": "ärrbildning",
    "ärrbildningarna": "ärrbildning",
    "ärrbildningarnas": "ärrbildning",
    "ärrbildningars": "ärrbildning",
    "ärrbildningen": "ärrbildning",
    "ärrbildningens": "ärrbildning",
    "ärrbildnings": "ärrbildning",
    "ärren": "ärr",
    "ärrens": "ärr",
    "ärret": "ärr",
    "ärrets": "ärr",
    "ärriga": "ärrig",
    "ärrigare": "ärrig",
    "ärrigares": "ärrig",
    "ärrigas": "ärrig",
    "ärrigast": "ärrig",
    "ärrigaste": "ärrig",
    "ärrigastes": "ärrig",
    "ärrigasts": "ärrig",
    "ärrige": "ärrig",
    "ärriges": "ärrig",
    "ärrigheten": "ärrighet",
    "ärrighetens": "ärrighet",
    "ärrighets": "ärrighet",
    "ärrigs": "ärrig",
    "ärrigt": "ärrig",
    "ärrigts": "ärrig",
    "ärrs": "ärr",
    "ärrtatueringar": "ärrtatuering",
    "ärrtatueringarna": "ärrtatuering",
    "ärrtatueringarnas": "ärrtatuering",
    "ärrtatueringars": "ärrtatuering",
    "ärrtatueringen": "ärrtatuering",
    "ärrtatueringens": "ärrtatuering",
    "ärrtatuerings": "ärrtatuering",
    "ärtan": "ärta",
    "ärtans": "ärta",
    "ärtas": "ärta",
    "ärtbalj": "ärtbalja",
    "ärtbaljan": "ärtbalja",
    "ärtbaljans": "ärtbalja",
    "ärtbaljas": "ärtbalja",
    "ärtbalje": "ärtbalja",
    "ärtbaljor": "ärtbalja",
    "ärtbaljorna": "ärtbalja",
    "ärtbaljornas": "ärtbalja",
    "ärtbaljors": "ärtbalja",
    "ärtbaljs": "ärtbalja",
    "ärten": "ärt",
    "ärtens": "ärt",
    "ärter": "ärta",
    "ärterna": "ärta",
    "ärternas": "ärta",
    "ärters": "ärta",
    "ärtiga": "ärtig",
    "ärtigare": "ärtig",
    "ärtigares": "ärtig",
    "ärtigas": "ärtig",
    "ärtigast": "ärtig",
    "ärtigaste": "ärtig",
    "ärtigastes": "ärtig",
    "ärtigasts": "ärtig",
    "ärtige": "ärtig",
    "ärtiges": "ärtig",
    "ärtigheten": "ärtighet",
    "ärtighetens": "ärtighet",
    "ärtighets": "ärtighet",
    "ärtigs": "ärtig",
    "ärtigt": "ärtig",
    "ärtigts": "ärtig",
    "ärtor": "ärta",
    "ärtorna": "ärta",
    "ärtornas": "ärta",
    "ärtors": "ärta",
    "ärts": "ärt",
    "ärtskid": "ärtskida",
    "ärtskidan": "ärtskida",
    "ärtskidans": "ärtskida",
    "ärtskidas": "ärtskida",
    "ärtskide": "ärtskida",
    "ärtskidor": "ärtskida",
    "ärtskidorna": "ärtskida",
    "ärtskidornas": "ärtskida",
    "ärtskidors": "ärtskida",
    "ärtskids": "ärtskida",
    "ärtskock": "ärtskocka",
    "ärtskockan": "ärtskocka",
    "ärtskockans": "ärtskocka",
    "ärtskockas": "ärtskocka",
    "ärtskocke": "ärtskocka",
    "ärtskockor": "ärtskocka",
    "ärtskockorna": "ärtskocka",
    "ärtskockornas": "ärtskocka",
    "ärtskockors": "ärtskocka",
    "ärtskocks": "ärtskocka",
    "ärtsoppan": "ärtsoppa",
    "ärtsoppans": "ärtsoppa",
    "ärtsoppas": "ärtsoppa",
    "ärtvecklar": "ärtvecklare",
    "ärtvecklaren": "ärtvecklare",
    "ärtvecklarens": "ärtvecklare",
    "ärtvecklares": "ärtvecklare",
    "ärtvecklarna": "ärtvecklare",
    "ärtvecklarnas": "ärtvecklare",
    "ärtväxten": "ärtväxt",
    "ärtväxtens": "ärtväxt",
    "ärtväxter": "ärtväxt",
    "ärtväxterna": "ärtväxt",
    "ärtväxternas": "ärtväxt",
    "ärtväxters": "ärtväxt",
    "ärtväxts": "ärtväxt",
    "ärv": "ärva",
    "ärvande": "ärva",
    "ärvanden": "ärvande",
    "ärvandena": "ärvande",
    "ärvandenas": "ärvande",
    "ärvandens": "ärvande",
    "ärvandes": "ärvande",
    "ärvandet": "ärvande",
    "ärvandets": "ärvande",
    "ärvas": "ärva",
    "ärvd": "ärva",
    "ärvda": "ärva",
    "ärvdabalken": "ärvdabalk",
    "ärvdabalkens": "ärvdabalk",
    "ärvdabalks": "ärvdabalk",
    "ärvdas": "ärva",
    "ärvde": "ärva",
    "ärvdes": "ärva",
    "ärvds": "ärva",
    "ärver": "ärva",
    "ärves": "ärva",
    "ärvs": "ärva",
    "ärvt": "ärva",
    "ärvts": "ärva",
    "äsk": "äska",
    "äskad": "äska",
    "äskade": "äska",
    "äskades": "äska",
    "äskads": "äska",
    "äskande": "äska",
    "äskanden": "äskande",
    "äskandena": "äskande",
    "äskandenas": "äskande",
    "äskandens": "äskande",
    "äskandes": "äskande",
    "äskandet": "äskande",
    "äskandets": "äskande",
    "äskar": "äska",
    "äskas": "äska",
    "äskat": "äska",
    "äskats": "äska",
    "äspingar": "äsping",
    "äspingarna": "äsping",
    "äspingarnas": "äsping",
    "äspingars": "äsping",
    "äspingen": "äsping",
    "äspingens": "äsping",
    "äspings": "äsping",
    "ässen": "äss",
    "ässens": "äss",
    "ässet": "äss",
    "ässets": "äss",
    "ässj": "ässja",
    "ässjan": "ässja",
    "ässjans": "ässja",
    "ässjas": "ässja",
    "ässje": "ässja",
    "ässjor": "ässja",
    "ässjorna": "ässja",
    "ässjornas": "ässja",
    "ässjors": "ässja",
    "ät": "äta",
    "ätande": "äta",
    "ätanden": "ätande",
    "ätandena": "ätande",
    "ätandenas": "ätande",
    "ätandens": "ätande",
    "ätandes": "ätande",
    "ätandet": "ätande",
    "ätandets": "ätande",
    "ätas": "äta",
    "ätbara": "ätbar",
    "ätbarare": "ätbar",
    "ätbarares": "ätbar",
    "ätbaras": "ätbar",
    "ätbarast": "ätbar",
    "ätbaraste": "ätbar",
    "ätbarastes": "ätbar",
    "ätbarasts": "ätbar",
    "ätbare": "ätbar",
    "ätbares": "ätbar",
    "ätbarheten": "ätbarhet",
    "ätbarhetens": "ätbarhet",
    "ätbarhets": "ätbarhet",
    "ätbars": "ätbar",
    "ätbart": "ätbar",
    "ätbarts": "ätbar",
    "äte": "äta",
    "äten": "äta",
    "ätens": "äta",
    "äter": "äta",
    "ätes": "äta",
    "ätet": "äta",
    "ätets": "äta",
    "ätit": "äta",
    "ätits": "äta",
    "ätliga": "ätlig",
    "ätligare": "ätlig",
    "ätligares": "ätlig",
    "ätligas": "ätlig",
    "ätligast": "ätlig",
    "ätligaste": "ätlig",
    "ätligastes": "ätlig",
    "ätligasts": "ätlig",
    "ätlige": "ätlig",
    "ätliges": "ätlig",
    "ätligheten": "ätlighet",
    "ätlighetens": "ätlighet",
    "ätligheter": "ätlighet",
    "ätligheterna": "ätlighet",
    "ätligheternas": "ätlighet",
    "ätligheters": "ätlighet",
    "ätlighets": "ätlighet",
    "ätligs": "ätlig",
    "ätligt": "ätlig",
    "ätligts": "ätlig",
    "ätna": "äta",
    "ätnas": "äta",
    "ätne": "äta",
    "ätnes": "äta",
    "ätningar": "ätning",
    "ätningarna": "ätning",
    "ätningarnas": "ätning",
    "ätningars": "ätning",
    "ätningen": "ätning",
    "ätningens": "ätning",
    "ätnings": "ätning",
    "ätpinn": "ätpinne",
    "ätpinnar": "ätpinne",
    "ätpinnarna": "ätpinne",
    "ätpinnarnas": "ätpinne",
    "ätpinnars": "ätpinne",
    "ätpinnen": "ätpinne",
    "ätpinnens": "ätpinne",
    "ätpinnes": "ätpinne",
    "ätpinns": "ätpinne",
    "äts": "äta",
    "ätstörningar": "ätstörning",
    "ätstörningarna": "ätstörning",
    "ätstörningarnas": "ätstörning",
    "ätstörningars": "ätstörning",
    "ätstörningen": "ätstörning",
    "ätstörningens": "ätstörning",
    "ätstörnings": "ätstörning",
    "ätstörningsproblematiken": "ätstörningsproblematik",
    "ätstörningsproblematikens": "ätstörningsproblematik",
    "ätstörningsproblematiker": "ätstörningsproblematik",
    "ätstörningsproblematikerna": "ätstörningsproblematik",
    "ätstörningsproblematikernas": "ätstörningsproblematik",
    "ätstörningsproblematikers": "ätstörningsproblematik",
    "ätstörningsproblematiks": "ätstörningsproblematik",
    "ättartalen": "ättartal",
    "ättartalens": "ättartal",
    "ättartalet": "ättartal",
    "ättartalets": "ättartal",
    "ättartals": "ättartal",
    "ättartavel": "ättartavla",
    "ättartavlan": "ättartavla",
    "ättartavlans": "ättartavla",
    "ättartavlas": "ättartavla",
    "ättartavle": "ättartavla",
    "ättartavlor": "ättartavla",
    "ättartavlorna": "ättartavla",
    "ättartavlornas": "ättartavla",
    "ättartavlors": "ättartavla",
    "ättefadern": "ättefader",
    "ättefaderns": "ättefader",
    "ättefaders": "ättefader",
    "ättefäder": "ättefader",
    "ättefäderna": "ättefader",
    "ättefädernas": "ättefader",
    "ättefäders": "ättefader",
    "ätteleden": "ätteled",
    "ätteledens": "ätteled",
    "ätteledet": "ätteled",
    "ätteledets": "ätteled",
    "ätteleds": "ätteled",
    "ätteläggar": "ättelägg",
    "ätteläggarna": "ättelägg",
    "ätteläggarnas": "ättelägg",
    "ätteläggars": "ättelägg",
    "ätteläggen": "ättelägg",
    "ätteläggens": "ättelägg",
    "ättelägget": "ättelägg",
    "ätteläggets": "ättelägg",
    "ätteläggs": "ättelägg",
    "ätten": "ätt",
    "ättens": "ätt",
    "ätter": "ätt",
    "ätterna": "ätt",
    "ätternas": "ätt",
    "ätters": "ätt",
    "ättestup": "ättestupa",
    "ättestupan": "ättestupa",
    "ättestupans": "ättestupa",
    "ättestupas": "ättestupa",
    "ättestupe": "ättestupa",
    "ättestupor": "ättestupa",
    "ättestuporna": "ättestupa",
    "ättestupornas": "ättestupa",
    "ättestupors": "ättestupa",
    "ättestups": "ättestupa",
    "ättetalen": "ättetal",
    "ättetalens": "ättetal",
    "ättetalet": "ättetal",
    "ättetalets": "ättetal",
    "ättetals": "ättetal",
    "ättetavel": "ättetavla",
    "ättetavlan": "ättetavla",
    "ättetavlans": "ättetavla",
    "ättetavlas": "ättetavla",
    "ättetavle": "ättetavla",
    "ättetavlor": "ättetavla",
    "ättetavlorna": "ättetavla",
    "ättetavlornas": "ättetavla",
    "ättetavlors": "ättetavla",
    "ättikan": "ättika",
    "ättikans": "ättika",
    "ättikas": "ättika",
    "ättiksgurk": "ättiksgurka",
    "ättiksgurkan": "ättiksgurka",
    "ättiksgurkans": "ättiksgurka",
    "ättiksgurkas": "ättiksgurka",
    "ättiksgurke": "ättiksgurka",
    "ättiksgurkor": "ättiksgurka",
    "ättiksgurkorna": "ättiksgurka",
    "ättiksgurkornas": "ättiksgurka",
    "ättiksgurkors": "ättiksgurka",
    "ättiksgurks": "ättiksgurka",
    "ättiksinläggningar": "ättiksinläggning",
    "ättiksinläggningarna": "ättiksinläggning",
    "ättiksinläggningarnas": "ättiksinläggning",
    "ättiksinläggningars": "ättiksinläggning",
    "ättiksinläggningen": "ättiksinläggning",
    "ättiksinläggningens": "ättiksinläggning",
    "ättiksinläggnings": "ättiksinläggning",
    "ättikspriten": "ättiksprit",
    "ättikspritens": "ättiksprit",
    "ättiksprits": "ättiksprit",
    "ättiksyran": "ättiksyra",
    "ättiksyrans": "ättiksyra",
    "ättiksyras": "ättiksyra",
    "ättiksyre": "ättiksyra",
    "ättleden": "ättled",
    "ättledens": "ättled",
    "ättleder": "ättled",
    "ättlederna": "ättled",
    "ättledernas": "ättled",
    "ättleders": "ättled",
    "ättledet": "ättled",
    "ättledets": "ättled",
    "ättleds": "ättled",
    "ättlingar": "ättling",
    "ättlingarna": "ättling",
    "ättlingarnas": "ättling",
    "ättlingars": "ättling",
    "ättlingen": "ättling",
    "ättlingens": "ättling",
    "ättlings": "ättling",
    "ättlängden": "ättlängd",
    "ättlängdens": "ättlängd",
    "ättlängder": "ättlängd",
    "ättlängderna": "ättlängd",
    "ättlängdernas": "ättlängd",
    "ättlängders": "ättlängd",
    "ättlängds": "ättlängd",
    "ättnummerna": "ättnummer",
    "ättnummernas": "ättnummer",
    "ättnummers": "ättnummer",
    "ättnumren": "ättnummer",
    "ättnumrens": "ättnummer",
    "ättnumret": "ättnummer",
    "ättnumrets": "ättnummer",
    "ätts": "ätt",
    "äventyr": "äventyra",
    "äventyrad": "äventyra",
    "äventyrade": "äventyra",
    "äventyrades": "äventyra",
    "äventyrads": "äventyra",
    "äventyrande": "äventyra",
    "äventyranden": "äventyrande",
    "äventyrandena": "äventyrande",
    "äventyrandenas": "äventyrande",
    "äventyrandens": "äventyrande",
    "äventyrandes": "äventyrande",
    "äventyrandet": "äventyrande",
    "äventyrandets": "äventyrande",
    "äventyrar": "äventyrare",
    "äventyraren": "äventyrare",
    "äventyrarens": "äventyrare",
    "äventyrares": "äventyrare",
    "äventyrarna": "äventyrare",
    "äventyrarnas": "äventyrare",
    "äventyras": "äventyra",
    "äventyrat": "äventyra",
    "äventyrats": "äventyra",
    "äventyren": "äventyr",
    "äventyrens": "äventyr",
    "äventyret": "äventyr",
    "äventyrets": "äventyr",
    "äventyrliga": "äventyrlig",
    "äventyrligare": "äventyrlig",
    "äventyrligares": "äventyrlig",
    "äventyrligas": "äventyrlig",
    "äventyrligast": "äventyrlig",
    "äventyrligaste": "äventyrlig",
    "äventyrligastes": "äventyrlig",
    "äventyrligasts": "äventyrlig",
    "äventyrlige": "äventyrlig",
    "äventyrliges": "äventyrlig",
    "äventyrligheten": "äventyrlighet",
    "äventyrlighetens": "äventyrlighet",
    "äventyrligheter": "äventyrlighet",
    "äventyrligheterna": "äventyrlighet",
    "äventyrligheternas": "äventyrlighet",
    "äventyrligheters": "äventyrlighet",
    "äventyrlighets": "äventyrlighet",
    "äventyrligs": "äventyrlig",
    "äventyrligt": "äventyrlig",
    "äventyrligts": "äventyrlig",
    "äventyrs": "äventyr",
    "äventyrsbaden": "äventyrsbad",
    "äventyrsbadens": "äventyrsbad",
    "äventyrsbadet": "äventyrsbad",
    "äventyrsbadets": "äventyrsbad",
    "äventyrsbads": "äventyrsbad",
    "äventyrsboken": "äventyrsbok",
    "äventyrsbokens": "äventyrsbok",
    "äventyrsboks": "äventyrsbok",
    "äventyrsböcker": "äventyrsbok",
    "äventyrsböckerna": "äventyrsbok",
    "äventyrsböckernas": "äventyrsbok",
    "äventyrsböckers": "äventyrsbok",
    "äventyrsfilmen": "äventyrsfilm",
    "äventyrsfilmens": "äventyrsfilm",
    "äventyrsfilmer": "äventyrsfilm",
    "äventyrsfilmerna": "äventyrsfilm",
    "äventyrsfilmernas": "äventyrsfilm",
    "äventyrsfilmers": "äventyrsfilm",
    "äventyrsfilms": "äventyrsfilm",
    "äventyrsromanen": "äventyrsroman",
    "äventyrsromanens": "äventyrsroman",
    "äventyrsromaner": "äventyrsroman",
    "äventyrsromanerna": "äventyrsroman",
    "äventyrsromanernas": "äventyrsroman",
    "äventyrsromaners": "äventyrsroman",
    "äventyrsromans": "äventyrsroman",
    "ävjan": "ävja",
    "ävjans": "ävja",
    "ävjas": "ävja",
    "ävlades": "ävlas",
    "ävlans": "ävlan",
    "ävlats": "ävlas",
    "äxingar": "äxing",
    "äxingarna": "äxing",
    "äxingarnas": "äxing",
    "äxingars": "äxing",
    "äxingen": "äxing",
    "äxingens": "äxing",
    "äxings": "äxing",
    "å-et": "å",
    "å-ets": "å",
    "å-n": "å",
    "å-na": "å",
    "å-nas": "å",
    "å-ns": "å",
    "å-s": "å",
    "å-t": "å",
    "å-ts": "å",
    "å:et": "å",
    "å:ets": "å",
    "å:n": "å",
    "å:na": "å",
    "å:nas": "å",
    "å:ns": "å",
    "å:s": "å",
    "å:t": "å",
    "å:ts": "å",
    "åar": "å",
    "åarna": "å",
    "åarnas": "å",
    "åars": "å",
    "åberop": "åberopa",
    "åberopad": "åberopa",
    "åberopade": "åberopa",
    "åberopades": "åberopa",
    "åberopads": "åberopa",
    "åberopande": "åberopa",
    "åberopanden": "åberopande",
    "åberopandena": "åberopande",
    "åberopandenas": "åberopande",
    "åberopandens": "åberopande",
    "åberopandes": "åberopande",
    "åberopandet": "åberopande",
    "åberopandets": "åberopande",
    "åberopar": "åberopa",
    "åberopas": "åberopa",
    "åberopat": "åberopa",
    "åberopats": "åberopa",
    "åbon": "åbo",
    "åbons": "åbo",
    "åbor": "åbo",
    "åborna": "åbo",
    "åbornas": "åbo",
    "åbors": "åbo",
    "åborätten": "åborätt",
    "åborättens": "åborätt",
    "åborätts": "åborätt",
    "åbos": "åbo",
    "åbrodden": "åbrodd",
    "åbroddens": "åbrodd",
    "åbrodds": "åbrodd",
    "åbäken": "åbäke",
    "åbäkena": "åbäke",
    "åbäkenas": "åbäke",
    "åbäkens": "åbäke",
    "åbäkes": "åbäke",
    "åbäket": "åbäke",
    "åbäkets": "åbäke",
    "åbäkiga": "åbäkig",
    "åbäkigare": "åbäkig",
    "åbäkigares": "åbäkig",
    "åbäkigas": "åbäkig",
    "åbäkigast": "åbäkig",
    "åbäkigaste": "åbäkig",
    "åbäkigastes": "åbäkig",
    "åbäkigasts": "åbäkig",
    "åbäkige": "åbäkig",
    "åbäkiges": "åbäkig",
    "åbäkigheten": "åbäkighet",
    "åbäkighetens": "åbäkighet",
    "åbäkighets": "åbäkighet",
    "åbäkigs": "åbäkig",
    "åbäkigt": "åbäkig",
    "åbäkigts": "åbäkig",
    "åbäkliga": "åbäklig",
    "åbäkligare": "åbäklig",
    "åbäkligares": "åbäklig",
    "åbäkligas": "åbäklig",
    "åbäkligast": "åbäklig",
    "åbäkligaste": "åbäklig",
    "åbäkligastes": "åbäklig",
    "åbäkligasts": "åbäklig",
    "åbäklige": "åbäklig",
    "åbäkliges": "åbäklig",
    "åbäkligs": "åbäklig",
    "åbäkligt": "åbäklig",
    "åbäkligts": "åbäklig",
    "åbäks": "åbäke",
    "åd": "åda",
    "ådagala": "ådagalägga",
    "ådagalade": "ådagalägga",
    "ådagalades": "ådagalägga",
    "ådagalagd": "ådagalägga",
    "ådagalagda": "ådagalägga",
    "ådagalagdas": "ådagalägga",
    "ådagalagde": "ådagalägga",
    "ådagalagdes": "ådagalägga",
    "ådagalagds": "ådagalägga",
    "ådagalagt": "ådagalägga",
    "ådagalagts": "ådagalägga",
    "ådagalas": "ådagalägga",
    "ådagalägg": "ådagalägga",
    "ådagaläggande": "ådagalägga",
    "ådagalägganden": "ådagaläggande",
    "ådagaläggandena": "ådagaläggande",
    "ådagaläggandenas": "ådagaläggande",
    "ådagaläggandens": "ådagaläggande",
    "ådagaläggandes": "ådagaläggande",
    "ådagaläggandet": "ådagaläggande",
    "ådagaläggandets": "ådagaläggande",
    "ådagaläggas": "ådagalägga",
    "ådagalägger": "ådagalägga",
    "ådagalägges": "ådagalägga",
    "ådagaläggs": "ådagalägga",
    "ådan": "åda",
    "ådans": "åda",
    "ådas": "åda",
    "åde": "åda",
    "åder": "ådra",
    "åderbrocken": "åderbrock",
    "åderbrockens": "åderbrock",
    "åderbrocket": "åderbrock",
    "åderbrockets": "åderbrock",
    "åderbrocks": "åderbrock",
    "åderbråcken": "åderbråck",
    "åderbråckens": "åderbråck",
    "åderbråcket": "åderbråck",
    "åderbråckets": "åderbråck",
    "åderbråcks": "åderbråck",
    "åderförkalkade": "åderförkalkad",
    "åderförkalkades": "åderförkalkad",
    "åderförkalkads": "åderförkalkad",
    "åderförkalkat": "åderförkalkad",
    "åderförkalkats": "åderförkalkad",
    "åderförkalkningar": "åderförkalkning",
    "åderförkalkningarna": "åderförkalkning",
    "åderförkalkningarnas": "åderförkalkning",
    "åderförkalkningars": "åderförkalkning",
    "åderförkalkningen": "åderförkalkning",
    "åderförkalkningens": "åderförkalkning",
    "åderförkalknings": "åderförkalkning",
    "åderhinnan": "åderhinna",
    "åderhinnans": "åderhinna",
    "åderhinnas": "åderhinna",
    "åderhinne": "åderhinna",
    "åderhinnor": "åderhinna",
    "åderhinnorna": "åderhinna",
    "åderhinnornas": "åderhinna",
    "åderhinnors": "åderhinna",
    "åderlät": "åderlåta",
    "åderläts": "åderlåta",
    "åderlåt": "åderlåta",
    "åderlåtande": "åderlåta",
    "åderlåtanden": "åderlåtande",
    "åderlåtandena": "åderlåtande",
    "åderlåtandenas": "åderlåtande",
    "åderlåtandens": "åderlåtande",
    "åderlåtandes": "åderlåtande",
    "åderlåtandet": "åderlåtande",
    "åderlåtandets": "åderlåtande",
    "åderlåtas": "åderlåta",
    "åderlåte": "åderlåta",
    "åderlåten": "åderlåta",
    "åderlåtens": "åderlåta",
    "åderlåter": "åderlåta",
    "åderlåtes": "åderlåta",
    "åderlåtet": "åderlåta",
    "åderlåtets": "åderlåta",
    "åderlåtit": "åderlåta",
    "åderlåtits": "åderlåta",
    "åderlåtna": "åderlåta",
    "åderlåtnas": "åderlåta",
    "åderlåtne": "åderlåta",
    "åderlåtnes": "åderlåta",
    "åderlåts": "åderlåta",
    "ådern": "åder",
    "åderns": "åder",
    "åders": "åder",
    "ådor": "åda",
    "ådorna": "åda",
    "ådornas": "åda",
    "ådors": "åda",
    "ådra": "åder",
    "ådrad": "ådra",
    "ådrade": "ådra",
    "ådrades": "ådra",
    "ådrads": "ådra",
    "ådrag": "ådra",
    "ådraga": "ådra",
    "ådragande": "ådra",
    "ådraganden": "ådragande",
    "ådragandena": "ådragande",
    "ådragandenas": "ådragande",
    "ådragandens": "ådragande",
    "ådragandes": "ådragande",
    "ådragandet": "ådragande",
    "ådragandets": "ådragande",
    "ådragas": "ådra",
    "ådrage": "ådra",
    "ådragen": "ådra",
    "ådragens": "ådra",
    "ådrager": "ådra",
    "ådrages": "ådra",
    "ådraget": "ådra",
    "ådragets": "ådra",
    "ådragit": "ådra",
    "ådragits": "ådra",
    "ådragna": "ådra",
    "ådragnas": "ådra",
    "ådragne": "ådra",
    "ådragnes": "ådra",
    "ådrags": "ådra",
    "ådran": "ådra",
    "ådrande": "ådra",
    "ådranden": "ådrande",
    "ådrandena": "ådrande",
    "ådrandenas": "ådrande",
    "ådrandens": "ådrande",
    "ådrandes": "ådrande",
    "ådrandet": "ådrande",
    "ådrandets": "ådrande",
    "ådrans": "ådra",
    "ådrar": "ådra",
    "ådras": "ådra",
    "ådrat": "ådra",
    "ådrats": "ådra",
    "ådre": "ådra",
    "ådriga": "ådrig",
    "ådrigare": "ådrig",
    "ådrigares": "ådrig",
    "ådrigas": "ådrig",
    "ådrigast": "ådrig",
    "ådrigaste": "ådrig",
    "ådrigastes": "ådrig",
    "ådrigasts": "ådrig",
    "ådrige": "ådrig",
    "ådriges": "ådrig",
    "ådrigheten": "ådrighet",
    "ådrighetens": "ådrighet",
    "ådrighets": "ådrighet",
    "ådrigs": "ådrig",
    "ådrigt": "ådrig",
    "ådrigts": "ådrig",
    "ådringar": "ådring",
    "ådringarna": "ådring",
    "ådringarnas": "ådring",
    "ådringars": "ådring",
    "ådringen": "ådring",
    "ådringens": "ådring",
    "ådrings": "ådring",
    "ådrog": "ådra",
    "ådroge": "ådra",
    "ådroges": "ådra",
    "ådrogs": "ådra",
    "ådror": "ådra",
    "ådrorna": "ådra",
    "ådrornas": "ådra",
    "ådrors": "ådra",
    "åds": "åda",
    "ådöm": "ådöma",
    "ådömande": "ådöma",
    "ådömanden": "ådömande",
    "ådömandena": "ådömande",
    "ådömandenas": "ådömande",
    "ådömandens": "ådömande",
    "ådömandes": "ådömande",
    "ådömandet": "ådömande",
    "ådömandets": "ådömande",
    "ådömas": "ådöma",
    "ådömd": "ådöma",
    "ådömda": "ådöma",
    "ådömdas": "ådöma",
    "ådömde": "ådöma",
    "ådömdes": "ådöma",
    "ådömds": "ådöma",
    "ådömer": "ådöma",
    "ådöms": "ådöma",
    "ådömt": "ådöma",
    "ådömts": "ådöma",
    "ågrens": "ågren",
    "åhåg": "åhåga",
    "åhågan": "åhåga",
    "åhågans": "åhåga",
    "åhågas": "åhåga",
    "åhåge": "åhåga",
    "åhågor": "åhåga",
    "åhågorna": "åhåga",
    "åhågornas": "åhåga",
    "åhågors": "åhåga",
    "åhågs": "åhåga",
    "åhör": "åhöra",
    "åhörande": "åhöra",
    "åhöranden": "åhörande",
    "åhörandena": "åhörande",
    "åhörandenas": "åhörande",
    "åhörandens": "åhörande",
    "åhörandes": "åhörande",
    "åhörandet": "åhörande",
    "åhörandets": "åhörande",
    "åhörar": "åhörare",
    "åhörardagar": "åhörardag",
    "åhörardagarna": "åhörardag",
    "åhörardagarnas": "åhörardag",
    "åhörardagars": "åhörardag",
    "åhörardagen": "åhörardag",
    "åhörardagens": "åhörardag",
    "åhörardags": "åhörardag",
    "åhöraren": "åhörare",
    "åhörarens": "åhörare",
    "åhörares": "åhörare",
    "åhörarna": "åhörare",
    "åhörarnas": "åhörare",
    "åhörarplatsen": "åhörarplats",
    "åhörarplatsens": "åhörarplats",
    "åhörarplatser": "åhörarplats",
    "åhörarplatserna": "åhörarplats",
    "åhörarplatsernas": "åhörarplats",
    "åhörarplatsers": "åhörarplats",
    "åhöras": "åhöra",
    "åhörd": "åhöra",
    "åhörda": "åhöra",
    "åhördas": "åhöra",
    "åhörde": "åhöra",
    "åhördes": "åhöra",
    "åhörds": "åhöra",
    "åhöres": "åhöra",
    "åhörs": "åhöra",
    "åhört": "åhöra",
    "åhörts": "åhöra",
    "åk": "åka",
    "åkall": "åkalla",
    "åkallad": "åkalla",
    "åkallade": "åkalla",
    "åkallades": "åkalla",
    "åkallads": "åkalla",
    "åkallande": "åkalla",
    "åkallanden": "åkallande",
    "åkallandena": "åkallande",
    "åkallandenas": "åkallande",
    "åkallandens": "åkallande",
    "åkallandes": "åkallande",
    "åkallandet": "åkallande",
    "åkallandets": "åkallande",
    "åkallans": "åkallan",
    "åkallar": "åkalla",
    "åkallas": "åkalla",
    "åkallat": "åkalla",
    "åkallats": "åkalla",
    "åkande": "åka",
    "åkanden": "åkande",
    "åkandena": "åkande",
    "åkandenas": "åkande",
    "åkandens": "åkande",
    "åkandes": "åkande",
    "åkandet": "åkande",
    "åkandets": "åkande",
    "åkar": "åkare",
    "åkarbras": "åkarbrasa",
    "åkarbrasan": "åkarbrasa",
    "åkarbrasans": "åkarbrasa",
    "åkarbrasas": "åkarbrasa",
    "åkarbrase": "åkarbrasa",
    "åkarbrasor": "åkarbrasa",
    "åkarbrasorna": "åkarbrasa",
    "åkarbrasornas": "åkarbrasa",
    "åkarbrasors": "åkarbrasa",
    "åkaren": "åkare",
    "åkarens": "åkare",
    "åkares": "åkare",
    "åkarhästar": "åkarhäst",
    "åkarhästarna": "åkarhäst",
    "åkarhästarnas": "åkarhäst",
    "åkarhästars": "åkarhäst",
    "åkarhästen": "åkarhäst",
    "åkarhästens": "åkarhäst",
    "åkarhästs": "åkarhäst",
    "åkarkampar": "åkarkamp",
    "åkarkamparna": "åkarkamp",
    "åkarkamparnas": "åkarkamp",
    "åkarkampars": "åkarkamp",
    "åkarkampen": "åkarkamp",
    "åkarkampens": "åkarkamp",
    "åkarkamps": "åkarkamp",
    "åkarna": "åkare",
    "åkarnas": "åkare",
    "åkas": "åka",
    "åkattraktionen": "åkattraktion",
    "åkattraktionens": "åkattraktion",
    "åkattraktioner": "åkattraktion",
    "åkattraktionerna": "åkattraktion",
    "åkattraktionernas": "åkattraktion",
    "åkattraktioners": "åkattraktion",
    "åkattraktions": "åkattraktion",
    "åkdonen": "åkdon",
    "åkdonens": "åkdon",
    "åkdonet": "åkdon",
    "åkdonets": "åkdon",
    "åkdons": "åkdon",
    "åken": "åk",
    "åkens": "åk",
    "åker": "åka",
    "åkerbindan": "åkerbinda",
    "åkerbindans": "åkerbinda",
    "åkerbindas": "åkerbinda",
    "åkerbitar": "åkerbit",
    "åkerbitarna": "åkerbit",
    "åkerbitarnas": "åkerbit",
    "åkerbitars": "åkerbit",
    "åkerbiten": "åkerbit",
    "åkerbitens": "åkerbit",
    "åkerbits": "åkerbit",
    "åkerbrukar": "åkerbrukare",
    "åkerbrukaren": "åkerbrukare",
    "åkerbrukarens": "åkerbrukare",
    "åkerbrukares": "åkerbrukare",
    "åkerbrukarna": "åkerbrukare",
    "åkerbrukarnas": "åkerbrukare",
    "åkerbruken": "åkerbruk",
    "åkerbrukens": "åkerbruk",
    "åkerbruket": "åkerbruk",
    "åkerbrukets": "åkerbruk",
    "åkerbruks": "åkerbruk",
    "åkerbären": "åkerbär",
    "åkerbärens": "åkerbär",
    "åkerbäret": "åkerbär",
    "åkerbärets": "åkerbär",
    "åkerbärs": "åkerbär",
    "åkerfräkenn": "åkerfräken",
    "åkerfräkenns": "åkerfräken",
    "åkerfräkens": "åkerfräken",
    "åkerfräknar": "åkerfräken",
    "åkerfräknarna": "åkerfräken",
    "åkerfräknarnas": "åkerfräken",
    "åkerfräknars": "åkerfräken",
    "åkerfälten": "åkerfält",
    "åkerfältens": "åkerfält",
    "åkerfältet": "åkerfält",
    "åkerfältets": "åkerfält",
    "åkerfälts": "åkerfält",
    "åkergärden": "åkergärde",
    "åkergärdena": "åkergärde",
    "åkergärdenas": "åkergärde",
    "åkergärdens": "åkergärde",
    "åkergärdes": "åkergärde",
    "åkergärdet": "åkergärde",
    "åkergärdets": "åkergärde",
    "åkerhön": "åkerhöna",
    "åkerhönan": "åkerhöna",
    "åkerhönans": "åkerhöna",
    "åkerhönas": "åkerhöna",
    "åkerhöne": "åkerhöna",
    "åkerhönor": "åkerhöna",
    "åkerhönorna": "åkerhöna",
    "åkerhönornas": "åkerhöna",
    "åkerhönors": "åkerhöna",
    "åkerhöns": "åkerhöna",
    "åkerier": "åkeri",
    "åkerierna": "åkeri",
    "åkeriernas": "åkeri",
    "åkeriers": "åkeri",
    "åkeriet": "åkeri",
    "åkeriets": "åkeri",
    "åkeris": "åkeri",
    "åkerit": "åkeri",
    "åkerits": "åkeri",
    "åkerjordar": "åkerjord",
    "åkerjordarna": "åkerjord",
    "åkerjordarnas": "åkerjord",
    "åkerjordars": "åkerjord",
    "åkerjorden": "åkerjord",
    "åkerjordens": "åkerjord",
    "åkerjords": "åkerjord",
    "åkerlappar": "åkerlapp",
    "åkerlapparna": "åkerlapp",
    "åkerlapparnas": "åkerlapp",
    "åkerlappars": "åkerlapp",
    "åkerlappen": "åkerlapp",
    "åkerlappens": "åkerlapp",
    "åkerlapps": "åkerlapp",
    "åkermarken": "åkermark",
    "åkermarkens": "åkermark",
    "åkermarker": "åkermark",
    "åkermarkerna": "åkermark",
    "åkermarkernas": "åkermark",
    "åkermarkers": "åkermark",
    "åkermarks": "åkermark",
    "åkern": "åker",
    "åkerns": "åker",
    "åkerogräset": "åkerogräs",
    "åkerogräsets": "åkerogräs",
    "åkerrenar": "åkerren",
    "åkerrenarna": "åkerren",
    "åkerrenarnas": "åkerren",
    "åkerrenars": "åkerren",
    "åkerrenen": "åkerren",
    "åkerrenens": "åkerren",
    "åkerrens": "åkerren",
    "åkers": "åker",
    "åkersenapen": "åkersenap",
    "åkersenapens": "åkersenap",
    "åkersenaps": "åkersenap",
    "åkersorkar": "åkersork",
    "åkersorkarna": "åkersork",
    "åkersorkarnas": "åkersork",
    "åkersorkars": "åkersork",
    "åkersorken": "åkersork",
    "åkersorkens": "åkersork",
    "åkersorks": "åkersork",
    "åkerspergeln": "åkerspergel",
    "åkerspergelns": "åkerspergel",
    "åkerspergels": "åkerspergel",
    "åkersperglar": "åkerspergel",
    "åkersperglarna": "åkerspergel",
    "åkersperglarnas": "åkerspergel",
    "åkersperglars": "åkerspergel",
    "åkerspöken": "åkerspöke",
    "åkerspökena": "åkerspöke",
    "åkerspökenas": "åkerspöke",
    "åkerspökens": "åkerspöke",
    "åkerspökes": "åkerspöke",
    "åkerspöket": "åkerspöke",
    "åkerspökets": "åkerspöke",
    "åkerspöks": "åkerspöke",
    "åkerstigar": "åkerstig",
    "åkerstigarna": "åkerstig",
    "åkerstigarnas": "åkerstig",
    "åkerstigars": "åkerstig",
    "åkerstigen": "åkerstig",
    "åkerstigens": "åkerstig",
    "åkerstigs": "åkerstig",
    "åkertegar": "åkerteg",
    "åkertegarna": "åkerteg",
    "åkertegarnas": "åkerteg",
    "åkertegars": "åkerteg",
    "åkertegen": "åkerteg",
    "åkertegens": "åkerteg",
    "åkertegs": "åkerteg",
    "åkertisteln": "åkertistel",
    "åkertistelns": "åkertistel",
    "åkertistels": "åkertistel",
    "åkertistlar": "åkertistel",
    "åkertistlarna": "åkertistel",
    "åkertistlarnas": "åkertistel",
    "åkertistlars": "åkertistel",
    "åkervallar": "åkervall",
    "åkervallarna": "åkervall",
    "åkervallarnas": "åkervall",
    "åkervallars": "åkervall",
    "åkervallen": "åkervall",
    "åkervallens": "åkervall",
    "åkervalls": "åkervall",
    "åkervindan": "åkervinda",
    "åkervindans": "åkervinda",
    "åkervindas": "åkervinda",
    "åkerväxten": "åkerväxt",
    "åkerväxtens": "åkerväxt",
    "åkerväxter": "åkerväxt",
    "åkerväxterna": "åkerväxt",
    "åkerväxternas": "åkerväxt",
    "åkerväxters": "åkerväxt",
    "åkerväxts": "åkerväxt",
    "åkerärten": "åkerärt",
    "åkerärtens": "åkerärt",
    "åkerärter": "åkerärt",
    "åkerärterna": "åkerärt",
    "åkerärternas": "åkerärt",
    "åkerärters": "åkerärt",
    "åkerärts": "åkerärt",
    "åkes": "åka",
    "åket": "åk",
    "åkets": "åk",
    "åkgräsklippar": "åkgräsklippare",
    "åkgräsklipparen": "åkgräsklippare",
    "åkgräsklipparens": "åkgräsklippare",
    "åkgräsklippares": "åkgräsklippare",
    "åkgräsklipparna": "åkgräsklippare",
    "åkgräsklipparnas": "åkgräsklippare",
    "åklag": "åklaga",
    "åklagad": "åklaga",
    "åklagade": "åklaga",
    "åklagades": "åklaga",
    "åklagads": "åklaga",
    "åklagande": "åklaga",
    "åklaganden": "åklagande",
    "åklagandena": "åklagande",
    "åklagandenas": "åklagande",
    "åklagandens": "åklagande",
    "åklagandes": "åklagande",
    "åklagandet": "åklagande",
    "åklagandets": "åklagande",
    "åklagar": "åklagare",
    "åklagarbesluten": "åklagarbeslut",
    "åklagarbeslutens": "åklagarbeslut",
    "åklagarbeslutet": "åklagarbeslut",
    "åklagarbeslutets": "åklagarbeslut",
    "åklagarbesluts": "åklagarbeslut",
    "åklagaren": "åklagare",
    "åklagarens": "åklagare",
    "åklagares": "åklagare",
    "åklagarmyndigheten": "åklagarmyndighet",
    "åklagarmyndighetens": "åklagarmyndighet",
    "åklagarmyndigheter": "åklagarmyndighet",
    "åklagarmyndigheterna": "åklagarmyndighet",
    "åklagarmyndigheternas": "åklagarmyndighet",
    "åklagarmyndigheters": "åklagarmyndighet",
    "åklagarmyndighets": "åklagarmyndighet",
    "åklagarna": "åklagare",
    "åklagarnas": "åklagare",
    "åklagas": "åklaga",
    "åklagat": "åklaga",
    "åklagats": "åklaga",
    "åklappar": "åklapp",
    "åklapparna": "åklapp",
    "åklapparnas": "åklapp",
    "åklappars": "åklapp",
    "åklappen": "åklapp",
    "åklappens": "åklapp",
    "åklapps": "åklapp",
    "åkmässiga": "åkmässig",
    "åkmässigare": "åkmässig",
    "åkmässigares": "åkmässig",
    "åkmässigas": "åkmässig",
    "åkmässigast": "åkmässig",
    "åkmässigaste": "åkmässig",
    "åkmässigastes": "åkmässig",
    "åkmässigasts": "åkmässig",
    "åkmässige": "åkmässig",
    "åkmässiges": "åkmässig",
    "åkmässigs": "åkmässig",
    "åkmässigt": "åkmässig",
    "åkmässigts": "åkmässig",
    "åkningar": "åkning",
    "åkningarna": "åkning",
    "åkningarnas": "åkning",
    "åkningars": "åkning",
    "åkningen": "åkning",
    "åkningens": "åkning",
    "åknings": "åkning",
    "åkom": "åkomma",
    "åkomman": "åkomma",
    "åkommans": "åkomma",
    "åkommas": "åkomma",
    "åkomme": "åkomma",
    "åkommor": "åkomma",
    "åkommorna": "åkomma",
    "åkommornas": "åkomma",
    "åkommors": "åkomma",
    "åkoms": "åkomma",
    "åkpås": "åkpåse",
    "åkpåsar": "åkpåse",
    "åkpåsarna": "åkpåse",
    "åkpåsarnas": "åkpåse",
    "åkpåsars": "åkpåse",
    "åkpåsen": "åkpåse",
    "åkpåsens": "åkpåse",
    "åkpåses": "åkpåse",
    "åkrar": "åker",
    "åkrarna": "åker",
    "åkrarnas": "åker",
    "åkrars": "åker",
    "åkrökar": "åkrök",
    "åkrökarna": "åkrök",
    "åkrökarnas": "åkrök",
    "åkrökars": "åkrök",
    "åkröken": "åkrök",
    "åkrökens": "åkrök",
    "åkröks": "åkrök",
    "åks": "åka",
    "åksjuka": "åksjuk",
    "åksjukan": "åksjuka",
    "åksjukans": "åksjuka",
    "åksjukare": "åksjuk",
    "åksjukares": "åksjuk",
    "åksjukas": "åksjuka",
    "åksjukast": "åksjuk",
    "åksjukaste": "åksjuk",
    "åksjukastes": "åksjuk",
    "åksjukasts": "åksjuk",
    "åksjuke": "åksjuka",
    "åksjukes": "åksjuk",
    "åksjukheten": "åksjukhet",
    "åksjukhetens": "åksjukhet",
    "åksjukhets": "åksjukhet",
    "åksjuks": "åksjuka",
    "åksjukt": "åksjuk",
    "åksjukts": "åksjuk",
    "åkt": "åka",
    "åkta": "åka",
    "åktas": "åka",
    "åkte": "åka",
    "åktes": "åka",
    "åkts": "åka",
    "åkturen": "åktur",
    "åkturens": "åktur",
    "åkturer": "åktur",
    "åkturerna": "åktur",
    "åkturernas": "åktur",
    "åkturers": "åktur",
    "åkturs": "åktur",
    "ål": "åla",
    "åla": "ålägga",
    "ålad": "åla",
    "ålade": "ålägga",
    "ålades": "ålägga",
    "ålads": "åla",
    "ålagd": "ålägga",
    "ålagda": "ålägga",
    "ålagdas": "ålägga",
    "ålagde": "ålägga",
    "ålagdes": "ålägga",
    "ålagds": "ålägga",
    "ålagillen": "ålagille",
    "ålagillena": "ålagille",
    "ålagillenas": "ålagille",
    "ålagillens": "ålagille",
    "ålagilles": "ålagille",
    "ålagillet": "ålagille",
    "ålagillets": "ålagille",
    "ålagt": "ålägga",
    "ålagts": "ålägga",
    "ålamörkers": "ålamörker",
    "ålamörkret": "ålamörker",
    "ålamörkrets": "ålamörker",
    "ålande": "åla",
    "ålanden": "ålande",
    "ålandena": "ålande",
    "ålandenas": "ålande",
    "ålandens": "ålande",
    "ålandes": "ålande",
    "ålandet": "ålande",
    "ålandets": "ålande",
    "ålandsroten": "ålandsrot",
    "ålandsrotens": "ålandsrot",
    "ålandsrots": "ålandsrot",
    "ålandsrötter": "ålandsrot",
    "ålandsrötterna": "ålandsrot",
    "ålandsrötternas": "ålandsrot",
    "ålandsrötters": "ålandsrot",
    "ålar": "åla",
    "ålarna": "ål",
    "ålarnas": "ål",
    "ålars": "ål",
    "ålas": "ålägga",
    "ålat": "åla",
    "ålats": "åla",
    "ålbestånden": "ålbestånd",
    "ålbeståndens": "ålbestånd",
    "ålbeståndet": "ålbestånd",
    "ålbeståndets": "ålbestånd",
    "ålbestånds": "ålbestånd",
    "ålderdomar": "ålderdom",
    "ålderdomarna": "ålderdom",
    "ålderdomarnas": "ålderdom",
    "ålderdomars": "ålderdom",
    "ålderdomen": "ålderdom",
    "ålderdomens": "ålderdom",
    "ålderdomliga": "ålderdomlig",
    "ålderdomligare": "ålderdomlig",
    "ålderdomligares": "ålderdomlig",
    "ålderdomligas": "ålderdomlig",
    "ålderdomligast": "ålderdomlig",
    "ålderdomligaste": "ålderdomlig",
    "ålderdomligastes": "ålderdomlig",
    "ålderdomligasts": "ålderdomlig",
    "ålderdomlige": "ålderdomlig",
    "ålderdomliges": "ålderdomlig",
    "ålderdomligheten": "ålderdomlighet",
    "ålderdomlighetens": "ålderdomlighet",
    "ålderdomligheter": "ålderdomlighet",
    "ålderdomligheterna": "ålderdomlighet",
    "ålderdomligheternas": "ålderdomlighet",
    "ålderdomligheters": "ålderdomlighet",
    "ålderdomlighets": "ålderdomlighet",
    "ålderdomligs": "ålderdomlig",
    "ålderdomligt": "ålderdomlig",
    "ålderdomligts": "ålderdomlig",
    "ålderdoms": "ålderdom",
    "ålderdomsförsäkringar": "ålderdomsförsäkring",
    "ålderdomsförsäkringarna": "ålderdomsförsäkring",
    "ålderdomsförsäkringarnas": "ålderdomsförsäkring",
    "ålderdomsförsäkringars": "ålderdomsförsäkring",
    "ålderdomsförsäkringen": "ålderdomsförsäkring",
    "ålderdomsförsäkringens": "ålderdomsförsäkring",
    "ålderdomsförsäkrings": "ålderdomsförsäkring",
    "ålderdomshemmen": "ålderdomshem",
    "ålderdomshemmens": "ålderdomshem",
    "ålderdomshemmet": "ålderdomshem",
    "ålderdomshemmets": "ålderdomshem",
    "ålderdomshems": "ålderdomshem",
    "ålderdomskrämp": "ålderdomskrämpa",
    "ålderdomskrämpan": "ålderdomskrämpa",
    "ålderdomskrämpans": "ålderdomskrämpa",
    "ålderdomskrämpas": "ålderdomskrämpa",
    "ålderdomskrämpe": "ålderdomskrämpa",
    "ålderdomskrämpor": "ålderdomskrämpa",
    "ålderdomskrämporna": "ålderdomskrämpa",
    "ålderdomskrämpornas": "ålderdomskrämpa",
    "ålderdomskrämpors": "ålderdomskrämpa",
    "ålderdomskrämps": "ålderdomskrämpa",
    "ålderdomspensionen": "ålderdomspension",
    "ålderdomspensionens": "ålderdomspension",
    "ålderdomspensioner": "ålderdomspension",
    "ålderdomspensionerna": "ålderdomspension",
    "ålderdomspensionernas": "ålderdomspension",
    "ålderdomspensioners": "ålderdomspension",
    "ålderdomspensions": "ålderdomspension",
    "ålderdomssvaga": "ålderdomssvag",
    "ålderdomssvagare": "ålderdomssvag",
    "ålderdomssvagares": "ålderdomssvag",
    "ålderdomssvagas": "ålderdomssvag",
    "ålderdomssvagast": "ålderdomssvag",
    "ålderdomssvagaste": "ålderdomssvag",
    "ålderdomssvagastes": "ålderdomssvag",
    "ålderdomssvagasts": "ålderdomssvag",
    "ålderdomssvage": "ålderdomssvag",
    "ålderdomssvages": "ålderdomssvag",
    "ålderdomssvagheten": "ålderdomssvaghet",
    "ålderdomssvaghetens": "ålderdomssvaghet",
    "ålderdomssvagheter": "ålderdomssvaghet",
    "ålderdomssvagheterna": "ålderdomssvaghet",
    "ålderdomssvagheternas": "ålderdomssvaghet",
    "ålderdomssvagheters": "ålderdomssvaghet",
    "ålderdomssvaghets": "ålderdomssvaghet",
    "ålderdomssvags": "ålderdomssvag",
    "ålderdomssvagt": "ålderdomssvag",
    "ålderdomssvagts": "ålderdomssvag",
    "åldermannen": "ålderman",
    "åldermannens": "ålderman",
    "åldermans": "ålderman",
    "åldermän": "ålderman",
    "åldermännen": "ålderman",
    "åldermännens": "ålderman",
    "åldermäns": "ålderman",
    "åldern": "ålder",
    "ålderns": "ålder",
    "ålders": "ålder",
    "åldersbestäm": "åldersbestämma",
    "åldersbestämd": "åldersbestämma",
    "åldersbestämda": "åldersbestämma",
    "åldersbestämdas": "åldersbestämma",
    "åldersbestämde": "åldersbestämma",
    "åldersbestämdes": "åldersbestämma",
    "åldersbestämds": "åldersbestämma",
    "åldersbestämmande": "åldersbestämma",
    "åldersbestämmanden": "åldersbestämmande",
    "åldersbestämmandena": "åldersbestämmande",
    "åldersbestämmandenas": "åldersbestämmande",
    "åldersbestämmandens": "åldersbestämmande",
    "åldersbestämmandes": "åldersbestämmande",
    "åldersbestämmandet": "åldersbestämmande",
    "åldersbestämmandets": "åldersbestämmande",
    "åldersbestämmas": "åldersbestämma",
    "åldersbestämmer": "åldersbestämma",
    "åldersbestämningar": "åldersbestämning",
    "åldersbestämningarna": "åldersbestämning",
    "åldersbestämningarnas": "åldersbestämning",
    "åldersbestämningars": "åldersbestämning",
    "åldersbestämningen": "åldersbestämning",
    "åldersbestämningens": "åldersbestämning",
    "åldersbestämnings": "åldersbestämning",
    "åldersbestäms": "åldersbestämma",
    "åldersbestämt": "åldersbestämma",
    "åldersbestämts": "åldersbestämma",
    "åldersbetygen": "åldersbetyg",
    "åldersbetygens": "åldersbetyg",
    "åldersbetyget": "åldersbetyg",
    "åldersbetygets": "åldersbetyg",
    "åldersbetygs": "åldersbetyg",
    "åldersdiskriminerad": "åldersdiskriminera",
    "åldersdiskriminerade": "åldersdiskriminera",
    "åldersdiskriminerades": "åldersdiskriminera",
    "åldersdiskriminerads": "åldersdiskriminera",
    "åldersdiskriminerande": "åldersdiskriminera",
    "åldersdiskrimineranden": "åldersdiskriminerande",
    "åldersdiskriminerandena": "åldersdiskriminerande",
    "åldersdiskriminerandenas": "åldersdiskriminerande",
    "åldersdiskriminerandens": "åldersdiskriminerande",
    "åldersdiskriminerandes": "åldersdiskriminerande",
    "åldersdiskriminerandet": "åldersdiskriminerande",
    "åldersdiskriminerandets": "åldersdiskriminerande",
    "åldersdiskriminerar": "åldersdiskriminera",
    "åldersdiskrimineras": "åldersdiskriminera",
    "åldersdiskriminerat": "åldersdiskriminera",
    "åldersdiskriminerats": "åldersdiskriminera",
    "åldersdiskrimineringar": "åldersdiskriminering",
    "åldersdiskrimineringarna": "åldersdiskriminering",
    "åldersdiskrimineringarnas": "åldersdiskriminering",
    "åldersdiskrimineringars": "åldersdiskriminering",
    "åldersdiskrimineringen": "åldersdiskriminering",
    "åldersdiskrimineringens": "åldersdiskriminering",
    "åldersdiskriminerings": "åldersdiskriminering",
    "åldersforskningar": "åldersforskning",
    "åldersforskningarna": "åldersforskning",
    "åldersforskningarnas": "åldersforskning",
    "åldersforskningars": "åldersforskning",
    "åldersforskningen": "åldersforskning",
    "åldersforskningens": "åldersforskning",
    "åldersforsknings": "åldersforskning",
    "åldersfördelningar": "åldersfördelning",
    "åldersfördelningarna": "åldersfördelning",
    "åldersfördelningarnas": "åldersfördelning",
    "åldersfördelningars": "åldersfördelning",
    "åldersfördelningen": "åldersfördelning",
    "åldersfördelningens": "åldersfördelning",
    "åldersfördelnings": "åldersfördelning",
    "åldersförändrade": "åldersförändrad",
    "åldersförändrades": "åldersförändrad",
    "åldersförändrads": "åldersförändrad",
    "åldersförändrat": "åldersförändrad",
    "åldersförändrats": "åldersförändrad",
    "åldersförändringar": "åldersförändring",
    "åldersförändringarna": "åldersförändring",
    "åldersförändringarnas": "åldersförändring",
    "åldersförändringars": "åldersförändring",
    "åldersförändringen": "åldersförändring",
    "åldersförändringens": "åldersförändring",
    "åldersförändrings": "åldersförändring",
    "åldersgruppen": "åldersgrupp",
    "åldersgruppens": "åldersgrupp",
    "åldersgrupper": "åldersgrupp",
    "åldersgrupperna": "åldersgrupp",
    "åldersgruppernas": "åldersgrupp",
    "åldersgruppers": "åldersgrupp",
    "åldersgrupps": "åldersgrupp",
    "åldersgränsen": "åldersgräns",
    "åldersgränsens": "åldersgräns",
    "åldersgränser": "åldersgräns",
    "åldersgränserna": "åldersgräns",
    "åldersgränsernas": "åldersgräns",
    "åldersgränsers": "åldersgräns",
    "åldersklassen": "åldersklass",
    "åldersklassens": "åldersklass",
    "åldersklasser": "åldersklass",
    "åldersklasserna": "åldersklass",
    "åldersklassernas": "åldersklass",
    "åldersklassers": "åldersklass",
    "ålderskrämp": "ålderskrämpa",
    "ålderskrämpan": "ålderskrämpa",
    "ålderskrämpans": "ålderskrämpa",
    "ålderskrämpas": "ålderskrämpa",
    "ålderskrämpe": "ålderskrämpa",
    "ålderskrämpor": "ålderskrämpa",
    "ålderskrämporna": "ålderskrämpa",
    "ålderskrämpornas": "ålderskrämpa",
    "ålderskrämpors": "ålderskrämpa",
    "ålderskrämps": "ålderskrämpa",
    "ålderslångsyntheten": "ålderslångsynthet",
    "ålderslångsynthetens": "ålderslångsynthet",
    "ålderslångsyntheter": "ålderslångsynthet",
    "ålderslångsyntheterna": "ålderslångsynthet",
    "ålderslångsyntheternas": "ålderslångsynthet",
    "ålderslångsyntheters": "ålderslångsynthet",
    "ålderslångsynthets": "ålderslångsynthet",
    "åldersmässiga": "åldersmässig",
    "åldersmässigare": "åldersmässig",
    "åldersmässigares": "åldersmässig",
    "åldersmässigas": "åldersmässig",
    "åldersmässigast": "åldersmässig",
    "åldersmässigaste": "åldersmässig",
    "åldersmässigastes": "åldersmässig",
    "åldersmässigasts": "åldersmässig",
    "åldersmässige": "åldersmässig",
    "åldersmässiges": "åldersmässig",
    "åldersmässigs": "åldersmässig",
    "åldersmässigt": "åldersmässig",
    "åldersmässigts": "åldersmässig",
    "ålderspensionen": "ålderspension",
    "ålderspensionens": "ålderspension",
    "ålderspensioner": "ålderspension",
    "ålderspensionerna": "ålderspension",
    "ålderspensionernas": "ålderspension",
    "ålderspensioners": "ålderspension",
    "ålderspensions": "ålderspension",
    "ålderspensionären": "ålderspensionär",
    "ålderspensionärens": "ålderspensionär",
    "ålderspensionärer": "ålderspensionär",
    "ålderspensionärerna": "ålderspensionär",
    "ålderspensionärernas": "ålderspensionär",
    "ålderspensionärers": "ålderspensionär",
    "ålderspensionärs": "ålderspensionär",
    "ålderspresidenten": "ålderspresident",
    "ålderspresidentens": "ålderspresident",
    "ålderspresidenter": "ålderspresident",
    "ålderspresidenterna": "ålderspresident",
    "ålderspresidenternas": "ålderspresident",
    "ålderspresidenters": "ålderspresident",
    "ålderspresidents": "ålderspresident",
    "ålderssjukdomar": "ålderssjukdom",
    "ålderssjukdomarna": "ålderssjukdom",
    "ålderssjukdomarnas": "ålderssjukdom",
    "ålderssjukdomars": "ålderssjukdom",
    "ålderssjukdomen": "ålderssjukdom",
    "ålderssjukdomens": "ålderssjukdom",
    "ålderssjukdoms": "ålderssjukdom",
    "åldersskillnaden": "åldersskillnad",
    "åldersskillnadens": "åldersskillnad",
    "åldersskillnader": "åldersskillnad",
    "åldersskillnaderna": "åldersskillnad",
    "åldersskillnadernas": "åldersskillnad",
    "åldersskillnaders": "åldersskillnad",
    "åldersskillnads": "åldersskillnad",
    "åldersskälen": "åldersskäl",
    "åldersskälens": "åldersskäl",
    "åldersskälet": "åldersskäl",
    "åldersskälets": "åldersskäl",
    "åldersskäls": "åldersskäl",
    "åldersspärrar": "åldersspärr",
    "åldersspärrarna": "åldersspärr",
    "åldersspärrarnas": "åldersspärr",
    "åldersspärrars": "åldersspärr",
    "åldersspärren": "åldersspärr",
    "åldersspärrens": "åldersspärr",
    "åldersspärrs": "åldersspärr",
    "åldersstadie": "åldersstadium",
    "åldersstadier": "åldersstadium",
    "åldersstadierna": "åldersstadium",
    "åldersstadiernas": "åldersstadium",
    "åldersstadiers": "åldersstadium",
    "åldersstadiet": "åldersstadium",
    "åldersstadiets": "åldersstadium",
    "åldersstadiums": "åldersstadium",
    "åldersstrecket": "åldersstreck",
    "åldersstreckets": "åldersstreck",
    "åldersstrecks": "åldersstreck",
    "åldersstrukturen": "åldersstruktur",
    "åldersstrukturens": "åldersstruktur",
    "åldersstrukturer": "åldersstruktur",
    "åldersstrukturerna": "åldersstruktur",
    "åldersstrukturernas": "åldersstruktur",
    "åldersstrukturers": "åldersstruktur",
    "åldersstrukturs": "åldersstruktur",
    "ålderssvaga": "ålderssvag",
    "ålderssvagare": "ålderssvag",
    "ålderssvagares": "ålderssvag",
    "ålderssvagas": "ålderssvag",
    "ålderssvagast": "ålderssvag",
    "ålderssvagaste": "ålderssvag",
    "ålderssvagastes": "ålderssvag",
    "ålderssvagasts": "ålderssvag",
    "ålderssvage": "ålderssvag",
    "ålderssvages": "ålderssvag",
    "ålderssvagheten": "ålderssvaghet",
    "ålderssvaghetens": "ålderssvaghet",
    "ålderssvaghets": "ålderssvaghet",
    "ålderssvags": "ålderssvag",
    "ålderssvagt": "ålderssvag",
    "ålderssvagts": "ålderssvag",
    "åldersteckens": "ålderstecken",
    "ålderstecknen": "ålderstecken",
    "ålderstecknens": "ålderstecken",
    "ålderstecknet": "ålderstecken",
    "ålderstecknets": "ålderstecken",
    "ålderstigens": "ålderstigen",
    "ålderstiget": "ålderstigen",
    "ålderstigets": "ålderstigen",
    "ålderstigna": "ålderstigen",
    "ålderstignare": "ålderstigen",
    "ålderstignares": "ålderstigen",
    "ålderstignas": "ålderstigen",
    "ålderstignast": "ålderstigen",
    "ålderstignaste": "ålderstigen",
    "ålderstignastes": "ålderstigen",
    "ålderstignasts": "ålderstigen",
    "ålderstigne": "ålderstigen",
    "ålderstignes": "ålderstigen",
    "ålderstilläggen": "ålderstillägg",
    "ålderstilläggens": "ålderstillägg",
    "ålderstillägget": "ålderstillägg",
    "ålderstilläggets": "ålderstillägg",
    "ålderstilläggs": "ålderstillägg",
    "ålderstyngda": "ålderstyngd",
    "ålderstyngdare": "ålderstyngd",
    "ålderstyngdares": "ålderstyngd",
    "ålderstyngdas": "ålderstyngd",
    "ålderstyngdast": "ålderstyngd",
    "ålderstyngdaste": "ålderstyngd",
    "ålderstyngdastes": "ålderstyngd",
    "ålderstyngdasts": "ålderstyngd",
    "ålderstyngde": "ålderstyngd",
    "ålderstyngdes": "ålderstyngd",
    "ålderstyngdheten": "ålderstyngdhet",
    "ålderstyngdhetens": "ålderstyngdhet",
    "ålderstyngdhets": "ålderstyngdhet",
    "ålderstyngds": "ålderstyngd",
    "ålderstyngt": "ålderstyngd",
    "ålderstyngts": "ålderstyngd",
    "åldfruar": "åldfru",
    "åldfruarna": "åldfru",
    "åldfruarnas": "åldfru",
    "åldfruars": "åldfru",
    "åldfrun": "åldfru",
    "åldfruns": "åldfru",
    "åldfrus": "åldfru",
    "åldrade": "åldrad",
    "åldrades": "åldras",
    "åldrads": "åldrad",
    "åldrandes": "åldrande",
    "åldrandet": "åldrande",
    "åldrandets": "åldrande",
    "åldrar": "ålder",
    "åldrarna": "ålder",
    "åldrarnas": "ålder",
    "åldrars": "ålder",
    "åldrat": "åldrad",
    "åldrats": "åldras",
    "åldriga": "åldrig",
    "åldrigare": "åldrig",
    "åldrigares": "åldrig",
    "åldrigas": "åldrig",
    "åldrigast": "åldrig",
    "åldrigaste": "åldrig",
    "åldrigastes": "åldrig",
    "åldrigasts": "åldrig",
    "åldrige": "åldrig",
    "åldriges": "åldrig",
    "åldrigheten": "åldrighet",
    "åldrighetens": "åldrighet",
    "åldrighets": "åldrighet",
    "åldrigs": "åldrig",
    "åldrigt": "åldrig",
    "åldrigts": "åldrig",
    "åldringar": "åldring",
    "åldringarna": "åldring",
    "åldringarnas": "åldring",
    "åldringars": "åldring",
    "åldringen": "åldring",
    "åldringens": "åldring",
    "åldrings": "åldring",
    "åldringsvården": "åldringsvård",
    "åldringsvårdens": "åldringsvård",
    "åldringsvårds": "åldringsvård",
    "ålegat": "åligga",
    "ålegats": "åligga",
    "ålen": "ål",
    "ålens": "ål",
    "ålfiskar": "ålfiskare",
    "ålfiskaren": "ålfiskare",
    "ålfiskarens": "ålfiskare",
    "ålfiskares": "ålfiskare",
    "ålfiskarna": "ålfiskare",
    "ålfiskarnas": "ålfiskare",
    "ålfiskes": "ålfiske",
    "ålfisket": "ålfiske",
    "ålfiskets": "ålfiske",
    "ålhom": "ålhomma",
    "ålhomman": "ålhomma",
    "ålhommans": "ålhomma",
    "ålhommas": "ålhomma",
    "ålhomme": "ålhomma",
    "ålhommor": "ålhomma",
    "ålhommorna": "ålhomma",
    "ålhommornas": "ålhomma",
    "ålhommors": "ålhomma",
    "ålhoms": "ålhomma",
    "åligg": "åligga",
    "åliggande": "åligga",
    "åligganden": "åliggande",
    "åliggandena": "åliggande",
    "åliggandenas": "åliggande",
    "åliggandens": "åliggande",
    "åliggandes": "åliggande",
    "åliggandet": "åliggande",
    "åliggandets": "åliggande",
    "åliggas": "åligga",
    "åligge": "åligga",
    "åligger": "åligga",
    "åligges": "åligga",
    "åliggs": "åligga",
    "ålkist": "ålkista",
    "ålkistan": "ålkista",
    "ålkistans": "ålkista",
    "ålkistas": "ålkista",
    "ålkiste": "ålkista",
    "ålkistor": "ålkista",
    "ålkistorna": "ålkista",
    "ålkistornas": "ålkista",
    "ålkistors": "ålkista",
    "ålkus": "ålkusa",
    "ålkusan": "ålkusa",
    "ålkusans": "ålkusa",
    "ålkusas": "ålkusa",
    "ålkuse": "ålkusa",
    "ålkusor": "ålkusa",
    "ålkusorna": "ålkusa",
    "ålkusornas": "ålkusa",
    "ålkusors": "ålkusa",
    "åll": "ålla",
    "ållan": "ålla",
    "ållans": "ålla",
    "ållas": "ålla",
    "ålle": "ålla",
    "ållor": "ålla",
    "ållorna": "ålla",
    "ållornas": "ålla",
    "ållors": "ålla",
    "ålls": "ålla",
    "ålmörkers": "ålmörker",
    "ålmörkret": "ålmörker",
    "ålmörkrets": "ålmörker",
    "ålningar": "ålning",
    "ålningarna": "ålning",
    "ålningarnas": "ålning",
    "ålningars": "ålning",
    "ålningen": "ålning",
    "ålningens": "ålning",
    "ålnings": "ålning",
    "åls": "ål",
    "ålskinnen": "ålskinn",
    "ålskinnens": "ålskinn",
    "ålskinnet": "ålskinn",
    "ålskinnets": "ålskinn",
    "ålskinns": "ålskinn",
    "ålspetsar": "ålspets",
    "ålspetsarna": "ålspets",
    "ålspetsarnas": "ålspets",
    "ålspetsars": "ålspets",
    "ålspetsen": "ålspets",
    "ålspetsens": "ålspets",
    "ålägg": "ålägga",
    "åläggande": "ålägga",
    "ålägganden": "åläggande",
    "åläggandena": "åläggande",
    "åläggandenas": "åläggande",
    "åläggandens": "åläggande",
    "åläggandes": "åläggande",
    "åläggandet": "åläggande",
    "åläggandets": "åläggande",
    "åläggas": "ålägga",
    "ålägger": "ålägga",
    "ålägges": "ålägga",
    "åläggs": "ålägga",
    "åländsk": "åländska",
    "åländska": "åländsk",
    "åländskan": "åländska",
    "åländskans": "åländska",
    "åländskare": "åländsk",
    "åländskares": "åländsk",
    "åländskas": "åländska",
    "åländskast": "åländsk",
    "åländskaste": "åländsk",
    "åländskastes": "åländsk",
    "åländskasts": "åländsk",
    "åländske": "åländska",
    "åländskes": "åländsk",
    "åländskor": "åländska",
    "åländskorna": "åländska",
    "åländskornas": "åländska",
    "åländskors": "åländska",
    "åländsks": "åländsk",
    "åländskt": "åländsk",
    "åländskts": "åländsk",
    "ålänningar": "ålänning",
    "ålänningarna": "ålänning",
    "ålänningarnas": "ålänning",
    "ålänningars": "ålänning",
    "ålänningen": "ålänning",
    "ålänningens": "ålänning",
    "ålännings": "ålänning",
    "ålåg": "åligga",
    "ålågge": "åligga",
    "ålågges": "åligga",
    "ålågs": "åligga",
    "åmar": "åm",
    "åmarna": "åm",
    "åmarnas": "åm",
    "åmars": "åm",
    "åmen": "åm",
    "åmens": "åm",
    "åmiga": "åmig",
    "åmigare": "åmig",
    "åmigares": "åmig",
    "åmigas": "åmig",
    "åmigast": "åmig",
    "åmigaste": "åmig",
    "åmigastes": "åmig",
    "åmigasts": "åmig",
    "åmige": "åmig",
    "åmiges": "åmig",
    "åmigs": "åmig",
    "åmigt": "åmig",
    "åmigts": "åmig",
    "åminnelsen": "åminnelse",
    "åminnelsens": "åminnelse",
    "åminnelses": "åminnelse",
    "åmningar": "åmning",
    "åmningarna": "åmning",
    "åmningarnas": "åmning",
    "åmningars": "åmning",
    "åmningen": "åmning",
    "åmningens": "åmning",
    "åmnings": "åmning",
    "åms": "åm",
    "åmynningar": "åmynning",
    "åmynningarna": "åmynning",
    "åmynningarnas": "åmynning",
    "åmynningars": "åmynning",
    "åmynningen": "åmynning",
    "åmynningens": "åmynning",
    "åmynnings": "åmynning",
    "ån": "å",
    "ång": "ånga",
    "ångackumulatorer": "ångackumulator",
    "ångackumulatorerna": "ångackumulator",
    "ångackumulatorernas": "ångackumulator",
    "ångackumulatorers": "ångackumulator",
    "ångackumulatorn": "ångackumulator",
    "ångackumulatorns": "ångackumulator",
    "ångackumulators": "ångackumulator",
    "ångad": "ånga",
    "ångade": "ånga",
    "ångades": "ånga",
    "ångads": "ånga",
    "ångan": "ånga",
    "ångande": "ånga",
    "ånganden": "ångande",
    "ångandena": "ångande",
    "ångandenas": "ångande",
    "ångandens": "ångande",
    "ångandes": "ångande",
    "ångandet": "ångande",
    "ångandets": "ångande",
    "ånganläggningar": "ånganläggning",
    "ånganläggningarna": "ånganläggning",
    "ånganläggningarnas": "ånganläggning",
    "ånganläggningars": "ånganläggning",
    "ånganläggningen": "ånganläggning",
    "ånganläggningens": "ånganläggning",
    "ånganläggnings": "ånganläggning",
    "ångans": "ånga",
    "ångar": "ångare",
    "ångaren": "ångare",
    "ångarens": "ångare",
    "ångares": "ångare",
    "ångarna": "ångare",
    "ångarnas": "ångare",
    "ångas": "ånga",
    "ångat": "ånga",
    "ångats": "ånga",
    "ångbagerier": "ångbageri",
    "ångbagerierna": "ångbageri",
    "ångbageriernas": "ångbageri",
    "ångbageriers": "ångbageri",
    "ångbageriet": "ångbageri",
    "ångbageriets": "ångbageri",
    "ångbageris": "ångbageri",
    "ångbagerit": "ångbageri",
    "ångbagerits": "ångbageri",
    "ångbildningar": "ångbildning",
    "ångbildningarna": "ångbildning",
    "ångbildningarnas": "ångbildning",
    "ångbildningars": "ångbildning",
    "ångbildningen": "ångbildning",
    "ångbildningens": "ångbildning",
    "ångbildnings": "ångbildning",
    "ångbildningsvärmen": "ångbildningsvärme",
    "ångbildningsvärmens": "ångbildningsvärme",
    "ångbildningsvärmes": "ångbildningsvärme",
    "ångblästern": "ångbläster",
    "ångblästerns": "ångbläster",
    "ångblästers": "ångbläster",
    "ångblästrar": "ångbläster",
    "ångblästrarna": "ångbläster",
    "ångblästrarnas": "ångbläster",
    "ångblästrars": "ångbläster",
    "ångbåtar": "ångbåt",
    "ångbåtarna": "ångbåt",
    "ångbåtarnas": "ångbåt",
    "ångbåtars": "ångbåt",
    "ångbåten": "ångbåt",
    "ångbåtens": "ångbåt",
    "ångbåts": "ångbåt",
    "ångbåtsbrygg": "ångbåtsbrygga",
    "ångbåtsbryggan": "ångbåtsbrygga",
    "ångbåtsbryggans": "ångbåtsbrygga",
    "ångbåtsbryggas": "ångbåtsbrygga",
    "ångbåtsbrygge": "ångbåtsbrygga",
    "ångbåtsbryggor": "ångbåtsbrygga",
    "ångbåtsbryggorna": "ångbåtsbrygga",
    "ångbåtsbryggornas": "ångbåtsbrygga",
    "ångbåtsbryggors": "ångbåtsbrygga",
    "ångbåtsbryggs": "ångbåtsbrygga",
    "ångbåtsränn": "ångbåtsränna",
    "ångbåtsrännan": "ångbåtsränna",
    "ångbåtsrännans": "ångbåtsränna",
    "ångbåtsrännas": "ångbåtsränna",
    "ångbåtsränne": "ångbåtsränna",
    "ångbåtsrännor": "ångbåtsränna",
    "ångbåtsrännorna": "ångbåtsränna",
    "ångbåtsrännornas": "ångbåtsränna",
    "ångbåtsrännors": "ångbåtsränna",
    "ångbåtsränns": "ångbåtsränna",
    "ångbåtsvissel": "ångbåtsvissla",
    "ångbåtsvisslan": "ångbåtsvissla",
    "ångbåtsvisslans": "ångbåtsvissla",
    "ångbåtsvisslas": "ångbåtsvissla",
    "ångbåtsvissle": "ångbåtsvissla",
    "ångbåtsvisslor": "ångbåtsvissla",
    "ångbåtsvisslorna": "ångbåtsvissla",
    "ångbåtsvisslornas": "ångbåtsvissla",
    "ångbåtsvisslors": "ångbåtsvissla",
    "ångcentralen": "ångcentral",
    "ångcentralens": "ångcentral",
    "ångcentraler": "ångcentral",
    "ångcentralerna": "ångcentral",
    "ångcentralernas": "ångcentral",
    "ångcentralers": "ångcentral",
    "ångcentrals": "ångcentral",
    "ångdriften": "ångdrift",
    "ångdriftens": "ångdrift",
    "ångdrifts": "ångdrift",
    "ångdrivens": "ångdriven",
    "ångdrivet": "ångdriven",
    "ångdrivets": "ångdriven",
    "ångdrivna": "ångdriven",
    "ångdrivnare": "ångdriven",
    "ångdrivnares": "ångdriven",
    "ångdrivnas": "ångdriven",
    "ångdrivnast": "ångdriven",
    "ångdrivnaste": "ångdriven",
    "ångdrivnastes": "ångdriven",
    "ångdrivnasts": "ångdriven",
    "ångdrivne": "ångdriven",
    "ångdrivnes": "ångdriven",
    "ånge": "ånga",
    "ånger": "ångra",
    "ångerfristen": "ångerfrist",
    "ångerfristens": "ångerfrist",
    "ångerfrists": "ångerfrist",
    "ångerfulla": "ångerfull",
    "ångerfullare": "ångerfull",
    "ångerfullares": "ångerfull",
    "ångerfullas": "ångerfull",
    "ångerfullast": "ångerfull",
    "ångerfullaste": "ångerfull",
    "ångerfullastes": "ångerfull",
    "ångerfullasts": "ångerfull",
    "ångerfulle": "ångerfull",
    "ångerfulles": "ångerfull",
    "ångerfullheten": "ångerfullhet",
    "ångerfullhetens": "ångerfullhet",
    "ångerfullhets": "ångerfullhet",
    "ångerfulls": "ångerfull",
    "ångerfullt": "ångerfull",
    "ångerfullts": "ångerfull",
    "ångerköpta": "ångerköpt",
    "ångerköptare": "ångerköpt",
    "ångerköptares": "ångerköpt",
    "ångerköptas": "ångerköpt",
    "ångerköptast": "ångerköpt",
    "ångerköptaste": "ångerköpt",
    "ångerköptastes": "ångerköpt",
    "ångerköptasts": "ångerköpt",
    "ångerköpte": "ångerköpt",
    "ångerköptes": "ångerköpt",
    "ångerköptheten": "ångerköpthet",
    "ångerköpthetens": "ångerköpthet",
    "ångerköpthets": "ångerköpthet",
    "ångerköpts": "ångerköpt",
    "ångermanländska": "ångermanländsk",
    "ångermanländskare": "ångermanländsk",
    "ångermanländskares": "ångermanländsk",
    "ångermanländskas": "ångermanländsk",
    "ångermanländskast": "ångermanländsk",
    "ångermanländskaste": "ångermanländsk",
    "ångermanländskastes": "ångermanländsk",
    "ångermanländskasts": "ångermanländsk",
    "ångermanländske": "ångermanländsk",
    "ångermanländskes": "ångermanländsk",
    "ångermanländsks": "ångermanländsk",
    "ångermanländskt": "ångermanländsk",
    "ångermanländskts": "ångermanländsk",
    "ångermanlänningar": "ångermanlänning",
    "ångermanlänningarna": "ångermanlänning",
    "ångermanlänningarnas": "ångermanlänning",
    "ångermanlänningars": "ångermanlänning",
    "ångermanlänningen": "ångermanlänning",
    "ångermanlänningens": "ångermanlänning",
    "ångermanlännings": "ångermanlänning",
    "ångern": "ånger",
    "ångerns": "ånger",
    "ångers": "ånger",
    "ångerveck": "ångervecka",
    "ångerveckan": "ångervecka",
    "ångerveckans": "ångervecka",
    "ångerveckas": "ångervecka",
    "ångervecke": "ångervecka",
    "ångervecko": "ångervecka",
    "ångerveckor": "ångervecka",
    "ångerveckorna": "ångervecka",
    "ångerveckornas": "ångervecka",
    "ångerveckors": "ångervecka",
    "ångervecks": "ångervecka",
    "ångestanfallen": "ångestanfall",
    "ångestanfallens": "ångestanfall",
    "ångestanfallet": "ångestanfall",
    "ångestanfallets": "ångestanfall",
    "ångestanfalls": "ångestanfall",
    "ångestattacken": "ångestattack",
    "ångestattackens": "ångestattack",
    "ångestattacker": "ångestattack",
    "ångestattackerna": "ångestattack",
    "ångestattackernas": "ångestattack",
    "ångestattackers": "ångestattack",
    "ångestattacks": "ångestattack",
    "ångesten": "ångest",
    "ångestens": "ångest",
    "ångestfulla": "ångestfull",
    "ångestfullare": "ångestfull",
    "ångestfullares": "ångestfull",
    "ångestfullas": "ångestfull",
    "ångestfullast": "ångestfull",
    "ångestfullaste": "ångestfull",
    "ångestfullastes": "ångestfull",
    "ångestfullasts": "ångestfull",
    "ångestfulle": "ångestfull",
    "ångestfulles": "ångestfull",
    "ångestfullheten": "ångestfullhet",
    "ångestfullhetens": "ångestfullhet",
    "ångestfullhets": "ångestfullhet",
    "ångestfulls": "ångestfull",
    "ångestfullt": "ångestfull",
    "ångestfullts": "ångestfull",
    "ångestfyllda": "ångestfylld",
    "ångestfylldare": "ångestfylld",
    "ångestfylldares": "ångestfylld",
    "ångestfylldas": "ångestfylld",
    "ångestfylldast": "ångestfylld",
    "ångestfylldaste": "ångestfylld",
    "ångestfylldastes": "ångestfylld",
    "ångestfylldasts": "ångestfylld",
    "ångestfyllde": "ångestfylld",
    "ångestfylldes": "ångestfylld",
    "ångestfylldheten": "ångestfylldhet",
    "ångestfylldhetens": "ångestfylldhet",
    "ångestfylldhets": "ångestfylldhet",
    "ångestfyllds": "ångestfylld",
    "ångestfyllt": "ångestfylld",
    "ångestfyllts": "ångestfylld",
    "ångestladdade": "ångestladdad",
    "ångestladdades": "ångestladdad",
    "ångestladdads": "ångestladdad",
    "ångestladdat": "ångestladdad",
    "ångestladdats": "ångestladdad",
    "ångestneurosen": "ångestneuros",
    "ångestneurosens": "ångestneuros",
    "ångestneuroser": "ångestneuros",
    "ångestneuroserna": "ångestneuros",
    "ångestneurosernas": "ångestneuros",
    "ångestneurosers": "ångestneuros",
    "ångestridens": "ångestriden",
    "ångestridet": "ångestriden",
    "ångestridets": "ångestriden",
    "ångestridna": "ångestriden",
    "ångestridnas": "ångestriden",
    "ångestridne": "ångestriden",
    "ångestridnes": "ångestriden",
    "ångests": "ångest",
    "ångestskrien": "ångestskri",
    "ångestskriens": "ångestskri",
    "ångestskriet": "ångestskri",
    "ångestskriets": "ångestskri",
    "ångestskrin": "ångestskri",
    "ångestskrina": "ångestskri",
    "ångestskrinas": "ångestskri",
    "ångestskrins": "ångestskri",
    "ångestskris": "ångestskri",
    "ångestskrit": "ångestskri",
    "ångestskrits": "ångestskri",
    "ångestsymptomen": "ångestsymptom",
    "ångestsymptomens": "ångestsymptom",
    "ångestsymptomet": "ångestsymptom",
    "ångestsymptomets": "ångestsymptom",
    "ångestsymptoms": "ångestsymptom",
    "ångestsymtomen": "ångestsymtom",
    "ångestsymtomens": "ångestsymtom",
    "ångestsymtomet": "ångestsymtom",
    "ångestsymtomets": "ångestsymtom",
    "ångestsymtoms": "ångestsymtom",
    "ångfartygen": "ångfartyg",
    "ångfartygens": "ångfartyg",
    "ångfartyget": "ångfartyg",
    "ångfartygets": "ångfartyg",
    "ångfartygs": "ångfartyg",
    "ångförväll": "ångförvälla",
    "ångförvällande": "ångförvälla",
    "ångförvällanden": "ångförvällande",
    "ångförvällandena": "ångförvällande",
    "ångförvällandenas": "ångförvällande",
    "ångförvällandens": "ångförvällande",
    "ångförvällandes": "ångförvällande",
    "ångförvällandet": "ångförvällande",
    "ångförvällandets": "ångförvällande",
    "ångförvällas": "ångförvälla",
    "ångförvälld": "ångförvälla",
    "ångförvällda": "ångförvälla",
    "ångförvälldas": "ångförvälla",
    "ångförvällde": "ångförvälla",
    "ångförvälldes": "ångförvälla",
    "ångförvällds": "ångförvälla",
    "ångförväller": "ångförvälla",
    "ångförvälles": "ångförvälla",
    "ångförvälls": "ångförvälla",
    "ångförvällt": "ångförvälla",
    "ångförvällts": "ångförvälla",
    "ånggeneratorer": "ånggenerator",
    "ånggeneratorerna": "ånggenerator",
    "ånggeneratorernas": "ånggenerator",
    "ånggeneratorers": "ånggenerator",
    "ånggeneratorn": "ånggenerator",
    "ånggeneratorns": "ånggenerator",
    "ånggenerators": "ånggenerator",
    "ångkok": "ångkoka",
    "ångkokad": "ångkoka",
    "ångkokade": "ångkoka",
    "ångkokades": "ångkoka",
    "ångkokads": "ångkoka",
    "ångkokande": "ångkoka",
    "ångkokanden": "ångkokande",
    "ångkokandena": "ångkokande",
    "ångkokandenas": "ångkokande",
    "ångkokandens": "ångkokande",
    "ångkokandes": "ångkokande",
    "ångkokandet": "ångkokande",
    "ångkokandets": "ångkokande",
    "ångkokar": "ångkokare",
    "ångkokaren": "ångkokare",
    "ångkokarens": "ångkokare",
    "ångkokares": "ångkokare",
    "ångkokarna": "ångkokare",
    "ångkokarnas": "ångkokare",
    "ångkokas": "ångkoka",
    "ångkokat": "ångkoka",
    "ångkokats": "ångkoka",
    "ångkoker": "ångkoka",
    "ångkokes": "ångkoka",
    "ångkoks": "ångkoka",
    "ångkokt": "ångkoka",
    "ångkokta": "ångkoka",
    "ångkoktas": "ångkoka",
    "ångkokte": "ångkoka",
    "ångkoktes": "ångkoka",
    "ångkokts": "ångkoka",
    "ångkolen": "ångkol",
    "ångkolens": "ångkol",
    "ångkolet": "ångkol",
    "ångkolets": "ångkol",
    "ångkols": "ångkol",
    "ångkraftverken": "ångkraftverk",
    "ångkraftverkens": "ångkraftverk",
    "ångkraftverket": "ångkraftverk",
    "ångkraftverkets": "ångkraftverk",
    "ångkraftverks": "ångkraftverk",
    "ångköken": "ångkök",
    "ångkökens": "ångkök",
    "ångköket": "ångkök",
    "ångkökets": "ångkök",
    "ångköks": "ångkök",
    "ångloken": "ånglok",
    "ånglokens": "ånglok",
    "ångloket": "ånglok",
    "ånglokets": "ånglok",
    "ånglokomotiven": "ånglokomotiv",
    "ånglokomotivens": "ånglokomotiv",
    "ånglokomotivet": "ånglokomotiv",
    "ånglokomotivets": "ånglokomotiv",
    "ånglokomotivs": "ånglokomotiv",
    "ångloks": "ånglok",
    "ångmaskinen": "ångmaskin",
    "ångmaskinens": "ångmaskin",
    "ångmaskiner": "ångmaskin",
    "ångmaskinerna": "ångmaskin",
    "ångmaskinernas": "ångmaskin",
    "ångmaskiners": "ångmaskin",
    "ångmaskins": "ångmaskin",
    "ångningar": "ångning",
    "ångningarna": "ångning",
    "ångningarnas": "ångning",
    "ångningars": "ångning",
    "ångningen": "ångning",
    "ångningens": "ångning",
    "ångnings": "ångning",
    "ångor": "ånga",
    "ångorna": "ånga",
    "ångornas": "ånga",
    "ångors": "ånga",
    "ångpann": "ångpanna",
    "ångpannan": "ångpanna",
    "ångpannans": "ångpanna",
    "ångpannas": "ångpanna",
    "ångpanne": "ångpanna",
    "ångpannor": "ångpanna",
    "ångpannorna": "ångpanna",
    "ångpannornas": "ångpanna",
    "ångpannors": "ångpanna",
    "ångpanns": "ångpanna",
    "ångrad": "ångra",
    "ångrade": "ångra",
    "ångrades": "ångra",
    "ångradion": "ångradio",
    "ångradions": "ångradio",
    "ångradios": "ångradio",
    "ångrads": "ångra",
    "ångrande": "ångra",
    "ångranden": "ångrande",
    "ångrandena": "ångrande",
    "ångrandenas": "ångrande",
    "ångrandens": "ångrande",
    "ångrandes": "ångrande",
    "ångrandet": "ångrande",
    "ångrandets": "ångrande",
    "ångrar": "ångra",
    "ångras": "ångra",
    "ångrat": "ångra",
    "ångrats": "ångra",
    "ångs": "ånga",
    "ångslupar": "ångslup",
    "ångsluparna": "ångslup",
    "ångsluparnas": "ångslup",
    "ångslupars": "ångslup",
    "ångslupen": "ångslup",
    "ångslupens": "ångslup",
    "ångslups": "ångslup",
    "ångstrykjärnen": "ångstrykjärn",
    "ångstrykjärnens": "ångstrykjärn",
    "ångstrykjärnet": "ångstrykjärn",
    "ångstrykjärnets": "ångstrykjärn",
    "ångstrykjärns": "ångstrykjärn",
    "ångströmen": "ångström",
    "ångströmens": "ångström",
    "ångströms": "ångström",
    "ångtrycken": "ångtryck",
    "ångtryckens": "ångtryck",
    "ångtrycket": "ångtryck",
    "ångtryckets": "ångtryck",
    "ångtrycks": "ångtryck",
    "ångturbinen": "ångturbin",
    "ångturbinens": "ångturbin",
    "ångturbiner": "ångturbin",
    "ångturbinerna": "ångturbin",
    "ångturbinernas": "ångturbin",
    "ångturbiners": "ångturbin",
    "ångturbins": "ångturbin",
    "ångvinschar": "ångvinsch",
    "ångvinscharna": "ångvinsch",
    "ångvinscharnas": "ångvinsch",
    "ångvinschars": "ångvinsch",
    "ångvinschen": "ångvinsch",
    "ångvinschens": "ångvinsch",
    "ångvinschs": "ångvinsch",
    "ångvissel": "ångvissla",
    "ångvisslan": "ångvissla",
    "ångvisslans": "ångvissla",
    "ångvisslas": "ångvissla",
    "ångvissle": "ångvissla",
    "ångvisslor": "ångvissla",
    "ångvisslorna": "ångvissla",
    "ångvisslornas": "ångvissla",
    "ångvisslors": "ångvissla",
    "ångvältar": "ångvält",
    "ångvältarna": "ångvält",
    "ångvältarnas": "ångvält",
    "ångvältars": "ångvält",
    "ångvälten": "ångvält",
    "ångvältens": "ångvält",
    "ångvälts": "ångvält",
    "åns": "å",
    "åpens": "åpen",
    "åpet": "åpen",
    "åpets": "åpen",
    "åpna": "åpen",
    "åpnare": "åpen",
    "åpnares": "åpen",
    "åpnas": "åpen",
    "åpnast": "åpen",
    "åpnaste": "åpen",
    "åpnastes": "åpen",
    "åpnasts": "åpen",
    "åpne": "åpen",
    "åpnes": "åpen",
    "år": "åra",
    "åran": "åra",
    "årans": "åra",
    "åras": "åra",
    "årbladen": "årblad",
    "årbladens": "årblad",
    "årbladet": "årblad",
    "årbladets": "årblad",
    "årblads": "årblad",
    "årbräckta": "årbräckt",
    "årbräcktare": "årbräckt",
    "årbräcktares": "årbräckt",
    "årbräcktas": "årbräckt",
    "årbräcktast": "årbräckt",
    "årbräcktaste": "årbräckt",
    "årbräcktastes": "årbräckt",
    "årbräcktasts": "årbräckt",
    "årbräckte": "årbräckt",
    "årbräcktes": "årbräckt",
    "årbräcktheten": "årbräckthet",
    "årbräckthetens": "årbräckthet",
    "årbräckthets": "årbräckthet",
    "årbräckts": "årbräckt",
    "årdern": "årder",
    "årderna": "årder",
    "årdernas": "årder",
    "årderns": "årder",
    "årders": "årder",
    "årdren": "årder",
    "årdrens": "årder",
    "årdret": "årder",
    "årdrets": "årder",
    "åre": "åra",
    "åren": "år",
    "årens": "år",
    "året": "år",
    "åretruntbostaden": "åretruntbostad",
    "åretruntbostadens": "åretruntbostad",
    "åretruntbostads": "åretruntbostad",
    "åretruntbostan": "åretruntbostad",
    "åretruntbostans": "åretruntbostad",
    "åretruntbostäder": "åretruntbostad",
    "åretruntbostäderna": "åretruntbostad",
    "åretruntbostädernas": "åretruntbostad",
    "åretruntbostäders": "åretruntbostad",
    "åretruntoljan": "åretruntolja",
    "åretruntoljans": "åretruntolja",
    "åretruntoljas": "åretruntolja",
    "åretruntolje": "åretruntolja",
    "åretruntoljor": "åretruntolja",
    "åretruntoljorna": "åretruntolja",
    "åretruntoljornas": "åretruntolja",
    "åretruntoljors": "åretruntolja",
    "årets": "år",
    "årfoten": "årfot",
    "årfotens": "årfot",
    "årfots": "årfot",
    "årfötter": "årfot",
    "årfötterna": "årfot",
    "årfötternas": "årfot",
    "årfötters": "årfot",
    "årgångar": "årgång",
    "årgångarna": "årgång",
    "årgångarnas": "årgång",
    "årgångars": "årgång",
    "årgången": "årgång",
    "årgångens": "årgång",
    "årgångs": "årgång",
    "årgångsviner": "årgångsvin",
    "årgångsvinerna": "årgångsvin",
    "årgångsvinernas": "årgångsvin",
    "årgångsviners": "årgångsvin",
    "årgångsvinet": "årgångsvin",
    "årgångsvinets": "årgångsvin",
    "årgångsvins": "årgångsvin",
    "århundraden": "århundrade",
    "århundradena": "århundrade",
    "århundradenas": "århundrade",
    "århundradens": "århundrade",
    "århundrades": "århundrade",
    "århundradet": "århundrade",
    "århundradets": "århundrade",
    "århundrads": "århundrade",
    "åriga": "årig",
    "årigare": "årig",
    "årigares": "årig",
    "årigas": "årig",
    "årigast": "årig",
    "årigaste": "årig",
    "årigastes": "årig",
    "årigasts": "årig",
    "årige": "årig",
    "åriges": "årig",
    "årigs": "årig",
    "årigt": "årig",
    "årigts": "årig",
    "åringar": "åring",
    "åringarna": "åring",
    "åringarnas": "åring",
    "åringars": "åring",
    "åringen": "åring",
    "åringens": "åring",
    "årings": "åring",
    "årklyk": "årklyka",
    "årklykan": "årklyka",
    "årklykans": "årklyka",
    "årklykas": "årklyka",
    "årklyke": "årklyka",
    "årklykor": "årklyka",
    "årklykorna": "årklyka",
    "årklykornas": "årklyka",
    "årklykors": "årklyka",
    "årklyks": "årklyka",
    "årliga": "årlig",
    "årligare": "årlig",
    "årligares": "årlig",
    "årligas": "årlig",
    "årligast": "årlig",
    "årligaste": "årlig",
    "årligastes": "årlig",
    "årligasts": "årlig",
    "årlige": "årlig",
    "årliges": "årlig",
    "årligs": "årlig",
    "årligt": "årlig",
    "årligts": "årlig",
    "årlommar": "årlom",
    "årlommarna": "årlom",
    "årlommarnas": "årlom",
    "årlommars": "årlom",
    "årlommen": "årlom",
    "årlommens": "årlom",
    "årloms": "årlom",
    "årmiljonen": "årmiljon",
    "årmiljonens": "årmiljon",
    "årmiljoner": "årmiljon",
    "årmiljonerna": "årmiljon",
    "årmiljonernas": "årmiljon",
    "årmiljoners": "årmiljon",
    "årmiljons": "årmiljon",
    "åror": "åra",
    "årorna": "åra",
    "årornas": "åra",
    "årors": "åra",
    "årpinn": "årpinne",
    "årpinnar": "årpinne",
    "årpinnarna": "årpinne",
    "årpinnarnas": "årpinne",
    "årpinnars": "årpinne",
    "årpinnen": "årpinne",
    "årpinnens": "årpinne",
    "årpinnes": "årpinne",
    "årpinns": "årpinne",
    "års": "åra",
    "årsavgiften": "årsavgift",
    "årsavgiftens": "årsavgift",
    "årsavgifter": "årsavgift",
    "årsavgifterna": "årsavgift",
    "årsavgifternas": "årsavgift",
    "årsavgifters": "årsavgift",
    "årsavgifts": "årsavgift",
    "årsbarnen": "årsbarn",
    "årsbarnens": "årsbarn",
    "årsbarnet": "årsbarn",
    "årsbarnets": "årsbarn",
    "årsbarns": "årsbarn",
    "årsberättelsen": "årsberättelse",
    "årsberättelsens": "årsberättelse",
    "årsberättelser": "årsberättelse",
    "årsberättelserna": "årsberättelse",
    "årsberättelsernas": "årsberättelse",
    "årsberättelsers": "årsberättelse",
    "årsberättelses": "årsberättelse",
    "årsboken": "årsbok",
    "årsbokens": "årsbok",
    "årsboks": "årsbok",
    "årsbokstaven": "årsbokstav",
    "årsbokstavens": "årsbokstav",
    "årsbokstavs": "årsbokstav",
    "årsbokstäver": "årsbokstav",
    "årsbokstäverna": "årsbokstav",
    "årsbokstävernas": "årsbokstav",
    "årsbokstävers": "årsbokstav",
    "årsböcker": "årsbok",
    "årsböckerna": "årsbok",
    "årsböckernas": "årsbok",
    "årsböckers": "årsbok",
    "årscykeln": "årscykel",
    "årscykelns": "årscykel",
    "årscykels": "årscykel",
    "årscyklar": "årscykel",
    "årscyklarna": "årscykel",
    "årscyklarnas": "årscykel",
    "årscyklars": "årscykel",
    "årscykler": "årscykel",
    "årscyklerna": "årscykel",
    "årscyklernas": "årscykel",
    "årscyklers": "årscykel",
    "årsdagar": "årsdag",
    "årsdagarna": "årsdag",
    "årsdagarnas": "årsdag",
    "årsdagars": "årsdag",
    "årsdagen": "årsdag",
    "årsdagens": "årsdag",
    "årsdags": "årsdag",
    "årsdosen": "årsdos",
    "årsdosens": "årsdos",
    "årsdoser": "årsdos",
    "årsdoserna": "årsdos",
    "årsdosernas": "årsdos",
    "årsdosers": "årsdos",
    "årsgamla": "årsgammal",
    "årsgamlas": "årsgammal",
    "årsgamle": "årsgammal",
    "årsgamles": "årsgammal",
    "årsgammals": "årsgammal",
    "årsgammalt": "årsgammal",
    "årsgammalts": "årsgammal",
    "årsgången": "årsgång",
    "årsgångens": "årsgång",
    "årsgångs": "årsgång",
    "årsinkomsten": "årsinkomst",
    "årsinkomstens": "årsinkomst",
    "årsinkomster": "årsinkomst",
    "årsinkomsterna": "årsinkomst",
    "årsinkomsternas": "årsinkomst",
    "årsinkomsters": "årsinkomst",
    "årsinkomsts": "årsinkomst",
    "årsklassen": "årsklass",
    "årsklassens": "årsklass",
    "årsklasser": "årsklass",
    "årsklasserna": "årsklass",
    "årsklassernas": "årsklass",
    "årsklassers": "årsklass",
    "årskullar": "årskull",
    "årskullarna": "årskull",
    "årskullarnas": "årskull",
    "årskullars": "årskull",
    "årskullen": "årskull",
    "årskullens": "årskull",
    "årskulls": "årskull",
    "årskursen": "årskurs",
    "årskursens": "årskurs",
    "årskurser": "årskurs",
    "årskurserna": "årskurs",
    "årskursernas": "årskurs",
    "årskursers": "årskurs",
    "årslånga": "årslång",
    "årslångas": "årslång",
    "årslånge": "årslång",
    "årslånges": "årslång",
    "årslångs": "årslång",
    "årslångt": "årslång",
    "årslångts": "årslång",
    "årsmedeltemperaturen": "årsmedeltemperatur",
    "årsmedeltemperaturens": "årsmedeltemperatur",
    "årsmedeltemperaturer": "årsmedeltemperatur",
    "årsmedeltemperaturerna": "årsmedeltemperatur",
    "årsmedeltemperaturernas": "årsmedeltemperatur",
    "årsmedeltemperaturers": "årsmedeltemperatur",
    "årsmedeltemperaturs": "årsmedeltemperatur",
    "årsmodellen": "årsmodell",
    "årsmodellens": "årsmodell",
    "årsmodeller": "årsmodell",
    "årsmodellerna": "årsmodell",
    "årsmodellernas": "årsmodell",
    "årsmodellers": "årsmodell",
    "årsmodells": "årsmodell",
    "årsmoränen": "årsmorän",
    "årsmoränens": "årsmorän",
    "årsmoräns": "årsmorän",
    "årsmöten": "årsmöte",
    "årsmötena": "årsmöte",
    "årsmötenas": "årsmöte",
    "årsmötens": "årsmöte",
    "årsmötes": "årsmöte",
    "årsmötet": "årsmöte",
    "årsmötets": "årsmöte",
    "årsredovisningar": "årsredovisning",
    "årsredovisningarna": "årsredovisning",
    "årsredovisningarnas": "årsredovisning",
    "årsredovisningars": "årsredovisning",
    "årsredovisningen": "årsredovisning",
    "årsredovisningens": "årsredovisning",
    "årsredovisnings": "årsredovisning",
    "årsringar": "årsring",
    "årsringarna": "årsring",
    "årsringarnas": "årsring",
    "årsringars": "årsring",
    "årsringen": "årsring",
    "årsringens": "årsring",
    "årsrings": "årsring",
    "årsskiften": "årsskifte",
    "årsskiftena": "årsskifte",
    "årsskiftenas": "årsskifte",
    "årsskiftens": "årsskifte",
    "årsskiftes": "årsskifte",
    "årsskiftet": "årsskifte",
    "årsskiftets": "årsskifte",
    "årsstämman": "årsstämma",
    "årsstämmans": "årsstämma",
    "årsstämmas": "årsstämma",
    "årsstämme": "årsstämma",
    "årsstämmo": "årsstämma",
    "årsstämmor": "årsstämma",
    "årsstämmorna": "årsstämma",
    "årsstämmornas": "årsstämma",
    "årsstämmors": "årsstämma",
    "årstiden": "årstid",
    "årstidens": "årstid",
    "årstider": "årstid",
    "årstiderna": "årstid",
    "årstidernas": "årstid",
    "årstiders": "årstid",
    "årstids": "årstid",
    "årstidsvindar": "årstidsvind",
    "årstidsvindarna": "årstidsvind",
    "årstidsvindarnas": "årstidsvind",
    "årstidsvindars": "årstidsvind",
    "årstidsvinden": "årstidsvind",
    "årstidsvindens": "årstidsvind",
    "årstidsvinds": "årstidsvind",
    "årstidsväxlingar": "årstidsväxling",
    "årstidsväxlingarna": "årstidsväxling",
    "årstidsväxlingarnas": "årstidsväxling",
    "årstidsväxlingars": "årstidsväxling",
    "årstidsväxlingen": "årstidsväxling",
    "årstidsväxlingens": "årstidsväxling",
    "årstidsväxlings": "årstidsväxling",
    "årstrycken": "årstryck",
    "årstryckens": "årstryck",
    "årstrycket": "årstryck",
    "årstryckets": "årstryck",
    "årstrycks": "årstryck",
    "årsvisa": "årsvis",
    "årsvisare": "årsvis",
    "årsvisares": "årsvis",
    "årsvisas": "årsvis",
    "årsvisast": "årsvis",
    "årsvisaste": "årsvis",
    "årsvisastes": "årsvis",
    "årsvisasts": "årsvis",
    "årsvise": "årsvis",
    "årsvises": "årsvis",
    "årsvist": "årsvis",
    "årsvists": "årsvis",
    "årsväxten": "årsväxt",
    "årsväxtens": "årsväxt",
    "årsväxts": "årsväxt",
    "årsålderns": "årsåldern",
    "årt": "årta",
    "årtagen": "årtag",
    "årtagens": "årtag",
    "årtaget": "årtag",
    "årtagets": "årtag",
    "årtags": "årtag",
    "årtalen": "årtal",
    "årtalens": "årtal",
    "årtalet": "årtal",
    "årtalets": "årtal",
    "årtals": "årtal",
    "årtan": "årta",
    "årtans": "årta",
    "årtas": "årta",
    "årte": "årta",
    "årtionden": "årtionde",
    "årtiondena": "årtionde",
    "årtiondenas": "årtionde",
    "årtiondens": "årtionde",
    "årtiondes": "årtionde",
    "årtiondet": "årtionde",
    "årtiondets": "årtionde",
    "årtor": "årta",
    "årtorna": "årta",
    "årtornas": "årta",
    "årtors": "årta",
    "årts": "årta",
    "årtullar": "årtull",
    "årtullarna": "årtull",
    "årtullarnas": "årtull",
    "årtullars": "årtull",
    "årtullen": "årtull",
    "årtullens": "årtull",
    "årtulls": "årtull",
    "årtusenden": "årtusende",
    "årtusendena": "årtusende",
    "årtusendenas": "årtusende",
    "årtusendens": "årtusende",
    "årtusendes": "årtusende",
    "årtusendet": "årtusende",
    "årtusendets": "årtusende",
    "ås": "å",
    "åsamk": "åsamka",
    "åsamkad": "åsamka",
    "åsamkade": "åsamka",
    "åsamkades": "åsamka",
    "åsamkads": "åsamka",
    "åsamkande": "åsamka",
    "åsamkanden": "åsamkande",
    "åsamkandena": "åsamkande",
    "åsamkandenas": "åsamkande",
    "åsamkandens": "åsamkande",
    "åsamkandes": "åsamkande",
    "åsamkandet": "åsamkande",
    "åsamkandets": "åsamkande",
    "åsamkar": "åsamka",
    "åsamkas": "åsamka",
    "åsamkat": "åsamka",
    "åsamkats": "åsamka",
    "åsar": "ås",
    "åsarna": "ås",
    "åsarnas": "ås",
    "åsars": "ås",
    "åsatt": "åsätta",
    "åsatta": "åsätta",
    "åsattas": "åsätta",
    "åsatte": "åsätta",
    "åsattes": "åsätta",
    "åsatts": "åsätta",
    "åsedd": "åse",
    "åsedda": "åse",
    "åseddas": "åse",
    "åsedde": "åse",
    "åseddes": "åse",
    "åsedds": "åse",
    "åseende": "åse",
    "åseenden": "åseende",
    "åseendena": "åseende",
    "åseendenas": "åseende",
    "åseendens": "åseende",
    "åseendes": "åseende",
    "åseendet": "åseende",
    "åseendets": "åseende",
    "åsen": "ås",
    "åsens": "ås",
    "åser": "åse",
    "åses": "åse",
    "åsett": "åse",
    "åsetts": "åse",
    "åsgropar": "åsgrop",
    "åsgroparna": "åsgrop",
    "åsgroparnas": "åsgrop",
    "åsgropars": "åsgrop",
    "åsgropen": "åsgrop",
    "åsgropens": "åsgrop",
    "åsgrops": "åsgrop",
    "åsidosatt": "åsidosätta",
    "åsidosatta": "åsidosätta",
    "åsidosattas": "åsidosätta",
    "åsidosatte": "åsidosätta",
    "åsidosattes": "åsidosätta",
    "åsidosatts": "åsidosätta",
    "åsidosätt": "åsidosätta",
    "åsidosättande": "åsidosätta",
    "åsidosättanden": "åsidosättande",
    "åsidosättandena": "åsidosättande",
    "åsidosättandenas": "åsidosättande",
    "åsidosättandens": "åsidosättande",
    "åsidosättandes": "åsidosättande",
    "åsidosättandet": "åsidosättande",
    "åsidosättandets": "åsidosättande",
    "åsidosättas": "åsidosätta",
    "åsidosätter": "åsidosätta",
    "åsidosättes": "åsidosätta",
    "åsidosätts": "åsidosätta",
    "åsikten": "åsikt",
    "åsiktens": "åsikt",
    "åsikter": "åsikt",
    "åsikterna": "åsikt",
    "åsikternas": "åsikt",
    "åsikters": "åsikt",
    "åsikts": "åsikt",
    "åsiktsbildningar": "åsiktsbildning",
    "åsiktsbildningarna": "åsiktsbildning",
    "åsiktsbildningarnas": "åsiktsbildning",
    "åsiktsbildningars": "åsiktsbildning",
    "åsiktsbildningen": "åsiktsbildning",
    "åsiktsbildningens": "åsiktsbildning",
    "åsiktsbildnings": "åsiktsbildning",
    "åsiktsdiktaturen": "åsiktsdiktatur",
    "åsiktsdiktaturens": "åsiktsdiktatur",
    "åsiktsdiktaturer": "åsiktsdiktatur",
    "åsiktsdiktaturerna": "åsiktsdiktatur",
    "åsiktsdiktaturernas": "åsiktsdiktatur",
    "åsiktsdiktaturers": "åsiktsdiktatur",
    "åsiktsdiktaturs": "åsiktsdiktatur",
    "åsiktsfriheten": "åsiktsfrihet",
    "åsiktsfrihetens": "åsiktsfrihet",
    "åsiktsfriheter": "åsiktsfrihet",
    "åsiktsfriheterna": "åsiktsfrihet",
    "åsiktsfriheternas": "åsiktsfrihet",
    "åsiktsfriheters": "åsiktsfrihet",
    "åsiktsfrihets": "åsiktsfrihet",
    "åsiktsförföljelsen": "åsiktsförföljelse",
    "åsiktsförföljelsens": "åsiktsförföljelse",
    "åsiktsförföljelser": "åsiktsförföljelse",
    "åsiktsförföljelserna": "åsiktsförföljelse",
    "åsiktsförföljelsernas": "åsiktsförföljelse",
    "åsiktsförföljelsers": "åsiktsförföljelse",
    "åsiktsförföljelses": "åsiktsförföljelse",
    "åsiktsförtrycket": "åsiktsförtryck",
    "åsiktsförtryckets": "åsiktsförtryck",
    "åsiktsförtrycks": "åsiktsförtryck",
    "åsiktsgemenskapen": "åsiktsgemenskap",
    "åsiktsgemenskapens": "åsiktsgemenskap",
    "åsiktsgemenskaps": "åsiktsgemenskap",
    "åsiktsmässiga": "åsiktsmässig",
    "åsiktsmässigare": "åsiktsmässig",
    "åsiktsmässigares": "åsiktsmässig",
    "åsiktsmässigas": "åsiktsmässig",
    "åsiktsmässigast": "åsiktsmässig",
    "åsiktsmässigaste": "åsiktsmässig",
    "åsiktsmässigastes": "åsiktsmässig",
    "åsiktsmässigasts": "åsiktsmässig",
    "åsiktsmässige": "åsiktsmässig",
    "åsiktsmässiges": "åsiktsmässig",
    "åsiktsmässigheten": "åsiktsmässighet",
    "åsiktsmässighetens": "åsiktsmässighet",
    "åsiktsmässighets": "åsiktsmässighet",
    "åsiktsmässigs": "åsiktsmässig",
    "åsiktsmässigt": "åsiktsmässig",
    "åsiktsmässigts": "åsiktsmässig",
    "åsiktsregistrerad": "åsiktsregistrera",
    "åsiktsregistrerade": "åsiktsregistrera",
    "åsiktsregistrerades": "åsiktsregistrera",
    "åsiktsregistrerads": "åsiktsregistrera",
    "åsiktsregistrerande": "åsiktsregistrera",
    "åsiktsregistreranden": "åsiktsregistrerande",
    "åsiktsregistrerandena": "åsiktsregistrerande",
    "åsiktsregistrerandenas": "åsiktsregistrerande",
    "åsiktsregistrerandens": "åsiktsregistrerande",
    "åsiktsregistrerandes": "åsiktsregistrerande",
    "åsiktsregistrerandet": "åsiktsregistrerande",
    "åsiktsregistrerandets": "åsiktsregistrerande",
    "åsiktsregistrerar": "åsiktsregistrera",
    "åsiktsregistreras": "åsiktsregistrera",
    "åsiktsregistrerat": "åsiktsregistrera",
    "åsiktsregistrerats": "åsiktsregistrera",
    "åsiktsregistrerbara": "åsiktsregistrerbar",
    "åsiktsregistrerbarare": "åsiktsregistrerbar",
    "åsiktsregistrerbarares": "åsiktsregistrerbar",
    "åsiktsregistrerbaras": "åsiktsregistrerbar",
    "åsiktsregistrerbarast": "åsiktsregistrerbar",
    "åsiktsregistrerbaraste": "åsiktsregistrerbar",
    "åsiktsregistrerbarastes": "åsiktsregistrerbar",
    "åsiktsregistrerbarasts": "åsiktsregistrerbar",
    "åsiktsregistrerbare": "åsiktsregistrerbar",
    "åsiktsregistrerbares": "åsiktsregistrerbar",
    "åsiktsregistrerbarheten": "åsiktsregistrerbarhet",
    "åsiktsregistrerbarhetens": "åsiktsregistrerbarhet",
    "åsiktsregistrerbarhets": "åsiktsregistrerbarhet",
    "åsiktsregistrerbars": "åsiktsregistrerbar",
    "åsiktsregistrerbart": "åsiktsregistrerbar",
    "åsiktsregistrerbarts": "åsiktsregistrerbar",
    "åsiktsregistreringar": "åsiktsregistrering",
    "åsiktsregistreringarna": "åsiktsregistrering",
    "åsiktsregistreringarnas": "åsiktsregistrering",
    "åsiktsregistreringars": "åsiktsregistrering",
    "åsiktsregistreringen": "åsiktsregistrering",
    "åsiktsregistreringens": "åsiktsregistrering",
    "åsiktsregistrerings": "åsiktsregistrering",
    "åsiktsriktningar": "åsiktsriktning",
    "åsiktsriktningarna": "åsiktsriktning",
    "åsiktsriktningarnas": "åsiktsriktning",
    "åsiktsriktningars": "åsiktsriktning",
    "åsiktsriktningen": "åsiktsriktning",
    "åsiktsriktningens": "åsiktsriktning",
    "åsiktsriktnings": "åsiktsriktning",
    "åsiktsskillnaden": "åsiktsskillnad",
    "åsiktsskillnadens": "åsiktsskillnad",
    "åsiktsskillnader": "åsiktsskillnad",
    "åsiktsskillnaderna": "åsiktsskillnad",
    "åsiktsskillnadernas": "åsiktsskillnad",
    "åsiktsskillnaders": "åsiktsskillnad",
    "åsiktsskillnads": "åsiktsskillnad",
    "åsiktsutbyten": "åsiktsutbyte",
    "åsiktsutbytena": "åsiktsutbyte",
    "åsiktsutbytenas": "åsiktsutbyte",
    "åsiktsutbytens": "åsiktsutbyte",
    "åsiktsutbytes": "åsiktsutbyte",
    "åsiktsutbytet": "åsiktsutbyte",
    "åsiktsutbytets": "åsiktsutbyte",
    "åsiktsyttringar": "åsiktsyttring",
    "åsiktsyttringarna": "åsiktsyttring",
    "åsiktsyttringarnas": "åsiktsyttring",
    "åsiktsyttringars": "åsiktsyttring",
    "åsiktsyttringen": "åsiktsyttring",
    "åsiktsyttringens": "åsiktsyttring",
    "åsiktsyttrings": "åsiktsyttring",
    "åsk": "åska",
    "åskad": "åska",
    "åskade": "åska",
    "åskades": "åska",
    "åskads": "åska",
    "åskan": "åska",
    "åskande": "åska",
    "åskanden": "åskande",
    "åskandena": "åskande",
    "åskandenas": "åskande",
    "åskandens": "åskande",
    "åskandes": "åskande",
    "åskandet": "åskande",
    "åskandets": "åskande",
    "åskans": "åska",
    "åskar": "åska",
    "åskas": "åska",
    "åskat": "åska",
    "åskats": "åska",
    "åskbyar": "åskby",
    "åskbyarna": "åskby",
    "åskbyarnas": "åskby",
    "åskbyars": "åskby",
    "åskbyn": "åskby",
    "åskbyns": "åskby",
    "åskbys": "åskby",
    "åskdigers": "åskdiger",
    "åskdigert": "åskdiger",
    "åskdigerts": "åskdiger",
    "åskdigra": "åskdiger",
    "åskdigrare": "åskdiger",
    "åskdigrares": "åskdiger",
    "åskdigras": "åskdiger",
    "åskdigrast": "åskdiger",
    "åskdigraste": "åskdiger",
    "åskdigrastes": "åskdiger",
    "åskdigrasts": "åskdiger",
    "åskdigre": "åskdiger",
    "åskdigres": "åskdiger",
    "åske": "åska",
    "åskfronten": "åskfront",
    "åskfrontens": "åskfront",
    "åskfronter": "åskfront",
    "åskfronterna": "åskfront",
    "åskfronternas": "åskfront",
    "åskfronters": "åskfront",
    "åskfronts": "åskfront",
    "åskledar": "åskledare",
    "åskledaren": "åskledare",
    "åskledarens": "åskledare",
    "åskledares": "åskledare",
    "åskledarna": "åskledare",
    "åskledarnas": "åskledare",
    "åskmolnen": "åskmoln",
    "åskmolnens": "åskmoln",
    "åskmolnet": "åskmoln",
    "åskmolnets": "åskmoln",
    "åskmolns": "åskmoln",
    "åskor": "åska",
    "åskorna": "åska",
    "åskornas": "åska",
    "åskors": "åska",
    "åskregnen": "åskregn",
    "åskregnens": "åskregn",
    "åskregnet": "åskregn",
    "åskregnets": "åskregn",
    "åskregns": "åskregn",
    "åskväderna": "åskväder",
    "åskvädernas": "åskväder",
    "åskväders": "åskväder",
    "åskvädren": "åskväder",
    "åskvädrens": "åskväder",
    "åskvädret": "åskväder",
    "åskvädrets": "åskväder",
    "åskåd": "åskåda",
    "åskådad": "åskåda",
    "åskådade": "åskåda",
    "åskådades": "åskåda",
    "åskådads": "åskåda",
    "åskådande": "åskåda",
    "åskådanden": "åskådande",
    "åskådandena": "åskådande",
    "åskådandenas": "åskådande",
    "åskådandens": "åskådande",
    "åskådandes": "åskådande",
    "åskådandet": "åskådande",
    "åskådandets": "åskådande",
    "åskådar": "åskådare",
    "åskådaren": "åskådare",
    "åskådarens": "åskådare",
    "åskådares": "åskådare",
    "åskådarhopar": "åskådarhop",
    "åskådarhoparna": "åskådarhop",
    "åskådarhoparnas": "åskådarhop",
    "åskådarhopars": "åskådarhop",
    "åskådarhopen": "åskådarhop",
    "åskådarhopens": "åskådarhop",
    "åskådarhops": "åskådarhop",
    "åskådarläktar": "åskådarläktare",
    "åskådarläktaren": "åskådarläktare",
    "åskådarläktarens": "åskådarläktare",
    "åskådarläktares": "åskådarläktare",
    "åskådarläktarna": "åskådarläktare",
    "åskådarläktarnas": "åskådarläktare",
    "åskådarmassan": "åskådarmassa",
    "åskådarmassans": "åskådarmassa",
    "åskådarmassas": "åskådarmassa",
    "åskådarmasse": "åskådarmassa",
    "åskådarmassor": "åskådarmassa",
    "åskådarmassorna": "åskådarmassa",
    "åskådarmassornas": "åskådarmassa",
    "åskådarmassors": "åskådarmassa",
    "åskådarna": "åskådare",
    "åskådarnas": "åskådare",
    "åskådas": "åskåda",
    "åskådat": "åskåda",
    "åskådats": "åskåda",
    "åskådliga": "åskådlig",
    "åskådligare": "åskådlig",
    "åskådligares": "åskådlig",
    "åskådligas": "åskådlig",
    "åskådligast": "åskådlig",
    "åskådligaste": "åskådlig",
    "åskådligastes": "åskådlig",
    "åskådligasts": "åskådlig",
    "åskådlige": "åskådlig",
    "åskådliges": "åskådlig",
    "åskådliggjord": "åskådliggöra",
    "åskådliggjorda": "åskådliggöra",
    "åskådliggjordas": "åskådliggöra",
    "åskådliggjorde": "åskådliggöra",
    "åskådliggjordes": "åskådliggöra",
    "åskådliggjords": "åskådliggöra",
    "åskådliggjort": "åskådliggöra",
    "åskådliggjorts": "åskådliggöra",
    "åskådliggör": "åskådliggöra",
    "åskådliggörande": "åskådliggöra",
    "åskådliggöranden": "åskådliggörande",
    "åskådliggörandena": "åskådliggörande",
    "åskådliggörandenas": "åskådliggörande",
    "åskådliggörandens": "åskådliggörande",
    "åskådliggörandes": "åskådliggörande",
    "åskådliggörandet": "åskådliggörande",
    "åskådliggörandets": "åskådliggörande",
    "åskådliggöras": "åskådliggöra",
    "åskådliggöres": "åskådliggöra",
    "åskådliggörs": "åskådliggöra",
    "åskådligheten": "åskådlighet",
    "åskådlighetens": "åskådlighet",
    "åskådligheter": "åskådlighet",
    "åskådligheterna": "åskådlighet",
    "åskådligheternas": "åskådlighet",
    "åskådligheters": "åskådlighet",
    "åskådlighets": "åskådlighet",
    "åskådligs": "åskådlig",
    "åskådligt": "åskådlig",
    "åskådligts": "åskådlig",
    "åskådningar": "åskådning",
    "åskådningarna": "åskådning",
    "åskådningarnas": "åskådning",
    "åskådningars": "åskådning",
    "åskådningen": "åskådning",
    "åskådningens": "åskådning",
    "åskådnings": "åskådning",
    "åskådningsmaterialet": "åskådningsmaterial",
    "åskådningsmaterialets": "åskådningsmaterial",
    "åskådningsmaterials": "åskådningsmaterial",
    "åskådningsmaterielen": "åskådningsmateriel",
    "åskådningsmaterielens": "åskådningsmateriel",
    "åskådningsmateriels": "åskådningsmateriel",
    "åskådningsmässiga": "åskådningsmässig",
    "åskådningsmässigare": "åskådningsmässig",
    "åskådningsmässigares": "åskådningsmässig",
    "åskådningsmässigas": "åskådningsmässig",
    "åskådningsmässigast": "åskådningsmässig",
    "åskådningsmässigaste": "åskådningsmässig",
    "åskådningsmässigastes": "åskådningsmässig",
    "åskådningsmässigasts": "åskådningsmässig",
    "åskådningsmässige": "åskådningsmässig",
    "åskådningsmässiges": "åskådningsmässig",
    "åskådningsmässigs": "åskådningsmässig",
    "åskådningsmässigt": "åskådningsmässig",
    "åskådningsmässigts": "åskådningsmässig",
    "åskådningsundervisningar": "åskådningsundervisning",
    "åskådningsundervisningarna": "åskådningsundervisning",
    "åskådningsundervisningarnas": "åskådningsundervisning",
    "åskådningsundervisningars": "åskådningsundervisning",
    "åskådningsundervisningen": "åskådningsundervisning",
    "åskådningsundervisningens": "åskådningsundervisning",
    "åskådningsundervisnings": "åskådningsundervisning",
    "åsnan": "åsna",
    "åsnans": "åsna",
    "åsnas": "åsna",
    "åsne": "åsna",
    "åsnebrygg": "åsnebrygga",
    "åsnebryggan": "åsnebrygga",
    "åsnebryggans": "åsnebrygga",
    "åsnebryggas": "åsnebrygga",
    "åsnebrygge": "åsnebrygga",
    "åsnebryggor": "åsnebrygga",
    "åsnebryggorna": "åsnebrygga",
    "åsnebryggornas": "åsnebrygga",
    "åsnebryggors": "åsnebrygga",
    "åsnebryggs": "åsnebrygga",
    "åsnedrivar": "åsnedrivare",
    "åsnedrivaren": "åsnedrivare",
    "åsnedrivarens": "åsnedrivare",
    "åsnedrivares": "åsnedrivare",
    "åsnedrivarna": "åsnedrivare",
    "åsnedrivarnas": "åsnedrivare",
    "åsnemjölken": "åsnemjölk",
    "åsnemjölkens": "åsnemjölk",
    "åsnemjölks": "åsnemjölk",
    "åsneskrien": "åsneskri",
    "åsneskriens": "åsneskri",
    "åsneskriet": "åsneskri",
    "åsneskriets": "åsneskri",
    "åsneskrin": "åsneskri",
    "åsneskrina": "åsneskri",
    "åsneskrinas": "åsneskri",
    "åsneskrins": "åsneskri",
    "åsneskris": "åsneskri",
    "åsneskrit": "åsneskri",
    "åsneskrits": "åsneskri",
    "åsnesparkar": "åsnespark",
    "åsnesparkarna": "åsnespark",
    "åsnesparkarnas": "åsnespark",
    "åsnesparkars": "åsnespark",
    "åsnesparken": "åsnespark",
    "åsnesparkens": "åsnespark",
    "åsnesparks": "åsnespark",
    "åsneöras": "åsneöra",
    "åsneörat": "åsneöra",
    "åsneörats": "åsneöra",
    "åsneöron": "åsneöra",
    "åsneöronen": "åsneöra",
    "åsneöronens": "åsneöra",
    "åsneörons": "åsneöra",
    "åsnor": "åsna",
    "åsnorna": "åsna",
    "åsnornas": "åsna",
    "åsnors": "åsna",
    "åsstänger": "åsstång",
    "åsstängerna": "åsstång",
    "åsstängernas": "åsstång",
    "åsstängers": "åsstång",
    "åsstången": "åsstång",
    "åsstångens": "åsstång",
    "åsstångs": "åsstång",
    "åstadkom": "åstadkomma",
    "åstadkomet": "åstadkomma",
    "åstadkomets": "åstadkomma",
    "åstadkommande": "åstadkomma",
    "åstadkommanden": "åstadkommande",
    "åstadkommandena": "åstadkommande",
    "åstadkommandenas": "åstadkommande",
    "åstadkommandens": "åstadkommande",
    "åstadkommandes": "åstadkommande",
    "åstadkommandet": "åstadkommande",
    "åstadkommandets": "åstadkommande",
    "åstadkommas": "åstadkomma",
    "åstadkomme": "åstadkomma",
    "åstadkommen": "åstadkomma",
    "åstadkommens": "åstadkomma",
    "åstadkommer": "åstadkomma",
    "åstadkommes": "åstadkomma",
    "åstadkommit": "åstadkomma",
    "åstadkommits": "åstadkomma",
    "åstadkomna": "åstadkomma",
    "åstadkomnas": "åstadkomma",
    "åstadkomne": "åstadkomma",
    "åstadkomnes": "åstadkomma",
    "åstadkoms": "åstadkomma",
    "åstund": "åstunda",
    "åstundad": "åstunda",
    "åstundade": "åstunda",
    "åstundades": "åstunda",
    "åstundads": "åstunda",
    "åstundande": "åstunda",
    "åstundanden": "åstundande",
    "åstundandena": "åstundande",
    "åstundandenas": "åstundande",
    "åstundandens": "åstundande",
    "åstundandes": "åstundande",
    "åstundandet": "åstundande",
    "åstundandets": "åstundande",
    "åstundans": "åstundan",
    "åstundar": "åstunda",
    "åstundas": "åstunda",
    "åstundat": "åstunda",
    "åstundats": "åstunda",
    "åsyft": "åsyfta",
    "åsyftad": "åsyfta",
    "åsyftade": "åsyfta",
    "åsyftades": "åsyfta",
    "åsyftads": "åsyfta",
    "åsyftande": "åsyfta",
    "åsyftanden": "åsyftande",
    "åsyftandena": "åsyftande",
    "åsyftandenas": "åsyftande",
    "åsyftandens": "åsyftande",
    "åsyftandes": "åsyftande",
    "åsyftandet": "åsyftande",
    "åsyftandets": "åsyftande",
    "åsyftar": "åsyfta",
    "åsyftas": "åsyfta",
    "åsyftat": "åsyfta",
    "åsyftats": "åsyfta",
    "åsynen": "åsyn",
    "åsynens": "åsyn",
    "åsyns": "åsyn",
    "åsätt": "åsätta",
    "åsättande": "åsätta",
    "åsättanden": "åsättande",
    "åsättandena": "åsättande",
    "åsättandenas": "åsättande",
    "åsättandens": "åsättande",
    "åsättandes": "åsättande",
    "åsättandet": "åsättande",
    "åsättandets": "åsättande",
    "åsättas": "åsätta",
    "åsätter": "åsätta",
    "åsättes": "åsätta",
    "åsätts": "åsätta",
    "åsåg": "åse",
    "åsåge": "åse",
    "åsåges": "åse",
    "åsågs": "åse",
    "åt": "äta",
    "åtaganden": "åtagande",
    "åtagandena": "åtagande",
    "åtagandenas": "åtagande",
    "åtagandens": "åtagande",
    "åtagandes": "åtagande",
    "åtagandet": "åtagande",
    "åtagandets": "åtagande",
    "åtal": "åtala",
    "åtalad": "åtala",
    "åtalade": "åtalad",
    "åtalades": "åtalad",
    "åtalads": "åtalad",
    "åtalande": "åtala",
    "åtalanden": "åtalande",
    "åtalandena": "åtalande",
    "åtalandenas": "åtalande",
    "åtalandens": "åtalande",
    "åtalandes": "åtalande",
    "åtalandet": "åtalande",
    "åtalandets": "åtalande",
    "åtalar": "åtala",
    "åtalas": "åtala",
    "åtalat": "åtalad",
    "åtalats": "åtalad",
    "åtalen": "åtal",
    "åtalens": "åtal",
    "åtalet": "åtal",
    "åtalets": "åtal",
    "åtals": "åtal",
    "åtalsbesluten": "åtalsbeslut",
    "åtalsbeslutens": "åtalsbeslut",
    "åtalsbeslutet": "åtalsbeslut",
    "åtalsbeslutets": "åtalsbeslut",
    "åtalsbesluts": "åtalsbeslut",
    "åtalseftergiften": "åtalseftergift",
    "åtalseftergiftens": "åtalseftergift",
    "åtalseftergifts": "åtalseftergift",
    "åtalspunkten": "åtalspunkt",
    "åtalspunktens": "åtalspunkt",
    "åtalspunkter": "åtalspunkt",
    "åtalspunkterna": "åtalspunkt",
    "åtalspunkternas": "åtalspunkt",
    "åtalspunkters": "åtalspunkt",
    "åtalspunkts": "åtalspunkt",
    "åtalsrätten": "åtalsrätt",
    "åtalsrättens": "åtalsrätt",
    "åtalsrätts": "åtalsrätt",
    "åtbörden": "åtbörd",
    "åtbördens": "åtbörd",
    "åtbörder": "åtbörd",
    "åtbörderna": "åtbörd",
    "åtbördernas": "åtbörd",
    "åtbörders": "åtbörd",
    "åtbörds": "åtbörd",
    "åte": "äta",
    "åteln": "åtel",
    "åtelns": "åtel",
    "åtels": "åtel",
    "återanländ": "återanlända",
    "återanländande": "återanlända",
    "återanländanden": "återanländande",
    "återanländandena": "återanländande",
    "återanländandenas": "återanländande",
    "återanländandens": "återanländande",
    "återanländandes": "återanländande",
    "återanländandet": "återanländande",
    "återanländandets": "återanländande",
    "återanländas": "återanlända",
    "återanlände": "återanlända",
    "återanländer": "återanlända",
    "återanländes": "återanlända",
    "återanländs": "återanlända",
    "återanlänt": "återanlända",
    "återanlänts": "återanlända",
    "återanpassad": "återanpassa",
    "återanpassade": "återanpassa",
    "återanpassades": "återanpassa",
    "återanpassads": "återanpassa",
    "återanpassande": "återanpassa",
    "återanpassanden": "återanpassande",
    "återanpassandena": "återanpassande",
    "återanpassandenas": "återanpassande",
    "återanpassandens": "återanpassande",
    "återanpassandes": "återanpassande",
    "återanpassandet": "återanpassande",
    "återanpassandets": "återanpassande",
    "återanpassar": "återanpassa",
    "återanpassas": "återanpassa",
    "återanpassat": "återanpassa",
    "återanpassats": "återanpassa",
    "återanpassningar": "återanpassning",
    "återanpassningarna": "återanpassning",
    "återanpassningarnas": "återanpassning",
    "återanpassningars": "återanpassning",
    "återanpassningen": "återanpassning",
    "återanpassningens": "återanpassning",
    "återanpassnings": "återanpassning",
    "återanskaff": "återanskaffa",
    "återanskaffad": "återanskaffa",
    "återanskaffade": "återanskaffa",
    "återanskaffades": "återanskaffa",
    "återanskaffads": "återanskaffa",
    "återanskaffande": "återanskaffa",
    "återanskaffanden": "återanskaffande",
    "återanskaffandena": "återanskaffande",
    "återanskaffandenas": "återanskaffande",
    "återanskaffandens": "återanskaffande",
    "återanskaffandes": "återanskaffande",
    "återanskaffandet": "återanskaffande",
    "återanskaffandets": "återanskaffande",
    "återanskaffar": "återanskaffa",
    "återanskaffas": "återanskaffa",
    "återanskaffat": "återanskaffa",
    "återanskaffats": "återanskaffa",
    "återanskaffningsvärdes": "återanskaffningsvärde",
    "återanskaffningsvärdet": "återanskaffningsvärde",
    "återanskaffningsvärdets": "återanskaffningsvärde",
    "återanvänd": "återanvända",
    "återanvändande": "återanvända",
    "återanvändanden": "återanvändande",
    "återanvändandena": "återanvändande",
    "återanvändandenas": "återanvändande",
    "återanvändandens": "återanvändande",
    "återanvändandes": "återanvändande",
    "återanvändandet": "återanvändande",
    "återanvändandets": "återanvändande",
    "återanvändas": "återanvända",
    "återanvände": "återanvända",
    "återanvänder": "återanvända",
    "återanvändes": "återanvända",
    "återanvändningar": "återanvändning",
    "återanvändningarna": "återanvändning",
    "återanvändningarnas": "återanvändning",
    "återanvändningars": "återanvändning",
    "återanvändningen": "återanvändning",
    "återanvändningens": "återanvändning",
    "återanvändnings": "återanvändning",
    "återanvänds": "återanvända",
    "återanvänt": "återanvända",
    "återanvänts": "återanvända",
    "återberätt": "återberätta",
    "återberättad": "återberätta",
    "återberättade": "återberätta",
    "återberättades": "återberätta",
    "återberättads": "återberätta",
    "återberättande": "återberätta",
    "återberättanden": "återberättande",
    "återberättandena": "återberättande",
    "återberättandenas": "återberättande",
    "återberättandens": "återberättande",
    "återberättandes": "återberättande",
    "återberättandet": "återberättande",
    "återberättandets": "återberättande",
    "återberättar": "återberätta",
    "återberättas": "återberätta",
    "återberättat": "återberätta",
    "återberättats": "återberätta",
    "återbesök": "återbesöka",
    "återbesökande": "återbesöka",
    "återbesökanden": "återbesökande",
    "återbesökandena": "återbesökande",
    "återbesökandenas": "återbesökande",
    "återbesökandens": "återbesökande",
    "återbesökandes": "återbesökande",
    "återbesökandet": "återbesökande",
    "återbesökandets": "återbesökande",
    "återbesökas": "återbesöka",
    "återbesöken": "återbesök",
    "återbesökens": "återbesök",
    "återbesöker": "återbesöka",
    "återbesökes": "återbesöka",
    "återbesöket": "återbesök",
    "återbesökets": "återbesök",
    "återbesöks": "återbesöka",
    "återbesökt": "återbesöka",
    "återbesökta": "återbesöka",
    "återbesöktas": "återbesöka",
    "återbesökte": "återbesöka",
    "återbesöktes": "återbesöka",
    "återbesökts": "återbesöka",
    "återbetal": "återbetala",
    "återbetalad": "återbetala",
    "återbetalade": "återbetala",
    "återbetalades": "återbetala",
    "återbetalads": "återbetala",
    "återbetalande": "återbetala",
    "återbetalanden": "återbetalande",
    "återbetalandena": "återbetalande",
    "återbetalandenas": "återbetalande",
    "återbetalandens": "återbetalande",
    "återbetalandes": "återbetalande",
    "återbetalandet": "återbetalande",
    "återbetalandets": "återbetalande",
    "återbetalar": "återbetala",
    "återbetalas": "återbetala",
    "återbetalat": "återbetala",
    "återbetalats": "återbetala",
    "återbetald": "återbetala",
    "återbetalda": "återbetala",
    "återbetaldas": "återbetala",
    "återbetalde": "återbetala",
    "återbetaldes": "återbetala",
    "återbetalds": "återbetala",
    "återbetalningar": "återbetalning",
    "återbetalningarna": "återbetalning",
    "återbetalningarnas": "återbetalning",
    "återbetalningars": "återbetalning",
    "återbetalningen": "återbetalning",
    "återbetalningens": "återbetalning",
    "återbetalnings": "återbetalning",
    "återbetalt": "återbetala",
    "återbetalte": "återbetala",
    "återbetaltes": "återbetala",
    "återbetalts": "återbetala",
    "återbildad": "återbilda",
    "återbildade": "återbilda",
    "återbildades": "återbilda",
    "återbildads": "återbilda",
    "återbildande": "återbilda",
    "återbildanden": "återbildande",
    "återbildandena": "återbildande",
    "återbildandenas": "återbildande",
    "återbildandens": "återbildande",
    "återbildandes": "återbildande",
    "återbildandet": "återbildande",
    "återbildandets": "återbildande",
    "återbildar": "återbilda",
    "återbildas": "återbilda",
    "återbildat": "återbilda",
    "återbildats": "återbilda",
    "återblickar": "återblick",
    "återblickarna": "återblick",
    "återblickarnas": "återblick",
    "återblickars": "återblick",
    "återblicken": "återblick",
    "återblickens": "återblick",
    "återblicks": "återblick",
    "återbruket": "återbruk",
    "återbrukets": "återbruk",
    "återbruks": "återbruk",
    "återbuden": "återbud",
    "återbudens": "återbud",
    "återbudet": "återbud",
    "återbudets": "återbud",
    "återbuds": "återbud",
    "återbäringar": "återbäring",
    "återbäringarna": "återbäring",
    "återbäringarnas": "återbäring",
    "återbäringars": "återbäring",
    "återbäringen": "återbäring",
    "återbäringens": "återbäring",
    "återbärings": "återbäring",
    "återbördad": "återbörda",
    "återbördade": "återbörda",
    "återbördades": "återbörda",
    "återbördads": "återbörda",
    "återbördande": "återbörda",
    "återbördanden": "återbördande",
    "återbördandena": "återbördande",
    "återbördandenas": "återbördande",
    "återbördandens": "återbördande",
    "återbördandes": "återbördande",
    "återbördandet": "återbördande",
    "återbördandets": "återbördande",
    "återbördar": "återbörda",
    "återbördas": "återbörda",
    "återbördat": "återbörda",
    "återbördats": "återbörda",
    "återerövrad": "återerövra",
    "återerövrade": "återerövra",
    "återerövrades": "återerövra",
    "återerövrads": "återerövra",
    "återerövrande": "återerövra",
    "återerövranden": "återerövrande",
    "återerövrandena": "återerövrande",
    "återerövrandenas": "återerövrande",
    "återerövrandens": "återerövrande",
    "återerövrandes": "återerövrande",
    "återerövrandet": "återerövrande",
    "återerövrandets": "återerövrande",
    "återerövrar": "återerövra",
    "återerövras": "återerövra",
    "återerövrat": "återerövra",
    "återerövrats": "återerövra",
    "återerövringar": "återerövring",
    "återerövringarna": "återerövring",
    "återerövringarnas": "återerövring",
    "återerövringars": "återerövring",
    "återerövringen": "återerövring",
    "återerövringens": "återerövring",
    "återerövrings": "återerövring",
    "återfall": "återfalla",
    "återfallande": "återfalla",
    "återfallanden": "återfallande",
    "återfallandena": "återfallande",
    "återfallandenas": "återfallande",
    "återfallandens": "återfallande",
    "återfallandes": "återfallande",
    "återfallandet": "återfallande",
    "återfallandets": "återfallande",
    "återfallas": "återfalla",
    "återfalle": "återfalla",
    "återfallen": "återfalla",
    "återfallens": "återfalla",
    "återfaller": "återfalla",
    "återfalles": "återfalla",
    "återfallet": "återfalla",
    "återfallets": "återfalla",
    "återfallit": "återfalla",
    "återfallits": "återfalla",
    "återfallna": "återfalla",
    "återfallnas": "återfalla",
    "återfallne": "återfalla",
    "återfallnes": "återfalla",
    "återfalls": "återfalla",
    "återfallsfebern": "återfallsfeber",
    "återfallsfeberns": "återfallsfeber",
    "återfallsfebers": "återfallsfeber",
    "återfallsförbrytar": "återfallsförbrytare",
    "återfallsförbrytaren": "återfallsförbrytare",
    "återfallsförbrytarens": "återfallsförbrytare",
    "återfallsförbrytares": "återfallsförbrytare",
    "återfallsförbrytarna": "återfallsförbrytare",
    "återfallsförbrytarnas": "återfallsförbrytare",
    "återfann": "återfinna",
    "återfanns": "återfinna",
    "återfick": "återfå",
    "återficks": "återfå",
    "återfinge": "återfå",
    "återfinges": "återfå",
    "återfinn": "återfinna",
    "återfinnande": "återfinna",
    "återfinnanden": "återfinnande",
    "återfinnandena": "återfinnande",
    "återfinnandenas": "återfinnande",
    "återfinnandens": "återfinnande",
    "återfinnandes": "återfinnande",
    "återfinnandet": "återfinnande",
    "återfinnandets": "återfinnande",
    "återfinnas": "återfinna",
    "återfinne": "återfinna",
    "återfinner": "återfinna",
    "återfinnes": "återfinna",
    "återfinns": "återfinna",
    "återflytt": "återflytta",
    "återflyttad": "återflytta",
    "återflyttade": "återflytta",
    "återflyttades": "återflytta",
    "återflyttads": "återflytta",
    "återflyttande": "återflytta",
    "återflyttanden": "återflyttande",
    "återflyttandena": "återflyttande",
    "återflyttandenas": "återflyttande",
    "återflyttandens": "återflyttande",
    "återflyttandes": "återflyttande",
    "återflyttandet": "återflyttande",
    "återflyttandets": "återflyttande",
    "återflyttar": "återflytta",
    "återflyttas": "återflytta",
    "återflyttat": "återflytta",
    "återflyttats": "återflytta",
    "återflyttningar": "återflyttning",
    "återflyttningarna": "återflyttning",
    "återflyttningarnas": "återflyttning",
    "återflyttningars": "återflyttning",
    "återflyttningen": "återflyttning",
    "återflyttningens": "återflyttning",
    "återflyttnings": "återflyttning",
    "återfunna": "återfinna",
    "återfunnas": "återfinna",
    "återfunne": "återfinna",
    "återfunnen": "återfinna",
    "återfunnens": "återfinna",
    "återfunnes": "återfinna",
    "återfunnet": "återfinna",
    "återfunnets": "återfinna",
    "återfunnit": "återfinna",
    "återfunnits": "återfinna",
    "återfående": "återfå",
    "återfåenden": "återfående",
    "återfåendena": "återfående",
    "återfåendenas": "återfående",
    "återfåendens": "återfående",
    "återfåendes": "återfående",
    "återfåendet": "återfående",
    "återfåendets": "återfående",
    "återfår": "återfå",
    "återfås": "återfå",
    "återfått": "återfå",
    "återfåtts": "återfå",
    "återfödats": "återfödas",
    "återföddes": "återfödas",
    "återfödelsen": "återfödelse",
    "återfödelsens": "återfödelse",
    "återfödelses": "återfödelse",
    "återföderskan": "återföderska",
    "återföderskans": "återföderska",
    "återföderskas": "återföderska",
    "återföderske": "återföderska",
    "återföderskor": "återföderska",
    "återföderskorna": "återföderska",
    "återföderskornas": "återföderska",
    "återföderskors": "återföderska",
    "återfödes": "återfödas",
    "återföds": "återfödas",
    "återföll": "återfalla",
    "återfölle": "återfalla",
    "återfölles": "återfalla",
    "återfölls": "återfalla",
    "återför": "återföra",
    "återförande": "återföra",
    "återföranden": "återförande",
    "återförandena": "återförande",
    "återförandenas": "återförande",
    "återförandens": "återförande",
    "återförandes": "återförande",
    "återförandet": "återförande",
    "återförandets": "återförande",
    "återföras": "återföra",
    "återförd": "återföra",
    "återförda": "återföra",
    "återfördas": "återföra",
    "återförde": "återföra",
    "återfördes": "återföra",
    "återförds": "återföra",
    "återfören": "återförena",
    "återförenad": "återförena",
    "återförenade": "återförena",
    "återförenades": "återförena",
    "återförenads": "återförena",
    "återförenande": "återförena",
    "återförenanden": "återförenande",
    "återförenandena": "återförenande",
    "återförenandenas": "återförenande",
    "återförenandens": "återförenande",
    "återförenandes": "återförenande",
    "återförenandet": "återförenande",
    "återförenandets": "återförenande",
    "återförenar": "återförena",
    "återförenas": "återförena",
    "återförenat": "återförena",
    "återförenats": "återförena",
    "återföreningar": "återförening",
    "återföreningarna": "återförening",
    "återföreningarnas": "återförening",
    "återföreningars": "återförening",
    "återföreningen": "återförening",
    "återföreningens": "återförening",
    "återförenings": "återförening",
    "återföres": "återföra",
    "återföringar": "återföring",
    "återföringarna": "återföring",
    "återföringarnas": "återföring",
    "återföringars": "återföring",
    "återföringen": "återföring",
    "återföringens": "återföring",
    "återförings": "återföring",
    "återförs": "återföra",
    "återförslut": "återförsluta",
    "återförslutande": "återförsluta",
    "återförslutanden": "återförslutande",
    "återförslutandena": "återförslutande",
    "återförslutandenas": "återförslutande",
    "återförslutandens": "återförslutande",
    "återförslutandes": "återförslutande",
    "återförslutandet": "återförslutande",
    "återförslutandets": "återförslutande",
    "återförslutas": "återförsluta",
    "återförslute": "återförsluta",
    "återförsluten": "återförsluta",
    "återförslutens": "återförsluta",
    "återförsluter": "återförsluta",
    "återförslutes": "återförsluta",
    "återförslutet": "återförsluta",
    "återförslutets": "återförsluta",
    "återförslutit": "återförsluta",
    "återförslutits": "återförsluta",
    "återförslutna": "återförsluta",
    "återförslutnas": "återförsluta",
    "återförslutne": "återförsluta",
    "återförslutnes": "återförsluta",
    "återförslutningsbara": "återförslutningsbar",
    "återförslutningsbaras": "återförslutningsbar",
    "återförslutningsbare": "återförslutningsbar",
    "återförslutningsbares": "återförslutningsbar",
    "återförslutningsbars": "återförslutningsbar",
    "återförslutningsbart": "återförslutningsbar",
    "återförslutningsbarts": "återförslutningsbar",
    "återförsluts": "återförsluta",
    "återförslöt": "återförsluta",
    "återförslöte": "återförsluta",
    "återförslötes": "återförsluta",
    "återförslöts": "återförsluta",
    "återförsäkrad": "återförsäkra",
    "återförsäkrade": "återförsäkra",
    "återförsäkrades": "återförsäkra",
    "återförsäkrads": "återförsäkra",
    "återförsäkrande": "återförsäkra",
    "återförsäkranden": "återförsäkrande",
    "återförsäkrandena": "återförsäkrande",
    "återförsäkrandenas": "återförsäkrande",
    "återförsäkrandens": "återförsäkrande",
    "återförsäkrandes": "återförsäkrande",
    "återförsäkrandet": "återförsäkrande",
    "återförsäkrandets": "återförsäkrande",
    "återförsäkrar": "återförsäkra",
    "återförsäkras": "återförsäkra",
    "återförsäkrat": "återförsäkra",
    "återförsäkrats": "återförsäkra",
    "återförsäkringar": "återförsäkring",
    "återförsäkringarna": "återförsäkring",
    "återförsäkringarnas": "återförsäkring",
    "återförsäkringars": "återförsäkring",
    "återförsäkringen": "återförsäkring",
    "återförsäkringens": "återförsäkring",
    "återförsäkrings": "återförsäkring",
    "återförsälj": "återförsälja",
    "återförsäljande": "återförsälja",
    "återförsäljanden": "återförsäljande",
    "återförsäljandena": "återförsäljande",
    "återförsäljandenas": "återförsäljande",
    "återförsäljandens": "återförsäljande",
    "återförsäljandes": "återförsäljande",
    "återförsäljandet": "återförsäljande",
    "återförsäljandets": "återförsäljande",
    "återförsäljar": "återförsäljare",
    "återförsäljaren": "återförsäljare",
    "återförsäljarens": "återförsäljare",
    "återförsäljares": "återförsäljare",
    "återförsäljarna": "återförsäljare",
    "återförsäljarnas": "återförsäljare",
    "återförsäljas": "återförsälja",
    "återförsäljer": "återförsälja",
    "återförsäljes": "återförsälja",
    "återförsäljs": "återförsälja",
    "återförsåld": "återförsälja",
    "återförsålda": "återförsälja",
    "återförsåldas": "återförsälja",
    "återförsålde": "återförsälja",
    "återförsåldes": "återförsälja",
    "återförsålds": "återförsälja",
    "återförsålt": "återförsälja",
    "återförsålts": "återförsälja",
    "återfört": "återföra",
    "återförts": "återföra",
    "återfötts": "återfödas",
    "återgav": "återge",
    "återgavs": "återge",
    "återgeende": "återge",
    "återgeendes": "återge",
    "återger": "återge",
    "återges": "återge",
    "återgett": "återge",
    "återgetts": "återge",
    "återgick": "återgå",
    "återgicks": "återgå",
    "återginge": "återgå",
    "återginges": "återgå",
    "återgiv": "återge",
    "återgiva": "återge",
    "återgivande": "återge",
    "återgivanden": "återgivande",
    "återgivandena": "återgivande",
    "återgivandenas": "återgivande",
    "återgivandens": "återgivande",
    "återgivandes": "återgivande",
    "återgivandet": "återgivande",
    "återgivandets": "återgivande",
    "återgivas": "återge",
    "återgive": "återge",
    "återgiven": "återge",
    "återgivens": "återge",
    "återgiver": "återge",
    "återgives": "återge",
    "återgivet": "återge",
    "återgivets": "återge",
    "återgivit": "återge",
    "återgivits": "återge",
    "återgivna": "återge",
    "återgivnas": "återge",
    "återgivne": "återge",
    "återgivnes": "återge",
    "återgivningar": "återgivning",
    "återgivningarna": "återgivning",
    "återgivningarnas": "återgivning",
    "återgivningars": "återgivning",
    "återgivningen": "återgivning",
    "återgivningens": "återgivning",
    "återgivnings": "återgivning",
    "återgivs": "återge",
    "återgäld": "återgälda",
    "återgäldad": "återgälda",
    "återgäldade": "återgälda",
    "återgäldades": "återgälda",
    "återgäldads": "återgälda",
    "återgäldande": "återgälda",
    "återgäldanden": "återgäldande",
    "återgäldandena": "återgäldande",
    "återgäldandenas": "återgäldande",
    "återgäldandens": "återgäldande",
    "återgäldandes": "återgäldande",
    "återgäldandet": "återgäldande",
    "återgäldandets": "återgäldande",
    "återgäldar": "återgälda",
    "återgäldas": "återgälda",
    "återgäldat": "återgälda",
    "återgäldats": "återgälda",
    "återgående": "återgå",
    "återgåenden": "återgående",
    "återgåendena": "återgående",
    "återgåendenas": "återgående",
    "återgåendens": "återgående",
    "återgåendes": "återgående",
    "återgåendet": "återgående",
    "återgåendets": "återgående",
    "återgånge": "återgå",
    "återgången": "återgång",
    "återgångens": "återgång",
    "återgånges": "återgå",
    "återgånget": "återgå",
    "återgångets": "återgå",
    "återgångna": "återgå",
    "återgångnas": "återgå",
    "återgångne": "återgå",
    "återgångnes": "återgå",
    "återgångs": "återgång",
    "återgångstullen": "återgångstull",
    "återgångstullens": "återgångstull",
    "återgångstulls": "återgångstull",
    "återgår": "återgå",
    "återgås": "återgå",
    "återgått": "återgå",
    "återgåtts": "återgå",
    "återgåve": "återge",
    "återgåves": "återge",
    "återhämt": "återhämta",
    "återhämtad": "återhämta",
    "återhämtade": "återhämta",
    "återhämtades": "återhämta",
    "återhämtads": "återhämta",
    "återhämtande": "återhämta",
    "återhämtanden": "återhämtande",
    "återhämtandena": "återhämtande",
    "återhämtandenas": "återhämtande",
    "återhämtandens": "återhämtande",
    "återhämtandes": "återhämtande",
    "återhämtandet": "återhämtande",
    "återhämtandets": "återhämtande",
    "återhämtar": "återhämta",
    "återhämtas": "återhämta",
    "återhämtat": "återhämta",
    "återhämtats": "återhämta",
    "återhämtningar": "återhämtning",
    "återhämtningarna": "återhämtning",
    "återhämtningarnas": "återhämtning",
    "återhämtningars": "återhämtning",
    "återhämtningen": "återhämtning",
    "återhämtningens": "återhämtning",
    "återhämtnings": "återhämtning",
    "återhämtningsfasen": "återhämtningsfas",
    "återhämtningsfasens": "återhämtningsfas",
    "återhämtningsfaser": "återhämtningsfas",
    "återhämtningsfaserna": "återhämtningsfas",
    "återhämtningsfasernas": "återhämtningsfas",
    "återhämtningsfasers": "återhämtningsfas",
    "återhåll": "återhålla",
    "återhållande": "återhålla",
    "återhållanden": "återhållande",
    "återhållandena": "återhållande",
    "återhållandenas": "återhållande",
    "återhållandens": "återhållande",
    "återhållandes": "återhållande",
    "återhållandet": "återhållande",
    "återhållandets": "återhållande",
    "återhållas": "återhålla",
    "återhålle": "återhålla",
    "återhållen": "återhålla",
    "återhållens": "återhålla",
    "återhåller": "återhålla",
    "återhålles": "återhålla",
    "återhållet": "återhålla",
    "återhållets": "återhålla",
    "återhållit": "återhålla",
    "återhållits": "återhålla",
    "återhållna": "återhålla",
    "återhållnas": "återhålla",
    "återhållne": "återhålla",
    "återhållnes": "återhålla",
    "återhålls": "återhålla",
    "återhållsamheten": "återhållsamhet",
    "återhållsamhetens": "återhållsamhet",
    "återhållsamheter": "återhållsamhet",
    "återhållsamheterna": "återhållsamhet",
    "återhållsamheternas": "återhållsamhet",
    "återhållsamheters": "återhållsamhet",
    "återhållsamhets": "återhållsamhet",
    "återhållsamma": "återhållsam",
    "återhållsammare": "återhållsam",
    "återhållsammares": "återhållsam",
    "återhållsammas": "återhållsam",
    "återhållsammast": "återhållsam",
    "återhållsammaste": "återhållsam",
    "återhållsammastes": "återhållsam",
    "återhållsammasts": "återhållsam",
    "återhållsamme": "återhållsam",
    "återhållsammes": "återhållsam",
    "återhållsams": "återhållsam",
    "återhållsamt": "återhållsam",
    "återhållsamts": "återhållsam",
    "återhöll": "återhålla",
    "återhölle": "återhålla",
    "återhölles": "återhålla",
    "återhölls": "återhålla",
    "återinför": "återinföra",
    "återinförande": "återinföra",
    "återinföranden": "återinförande",
    "återinförandena": "återinförande",
    "återinförandenas": "återinförande",
    "återinförandens": "återinförande",
    "återinförandes": "återinförande",
    "återinförandet": "återinförande",
    "återinförandets": "återinförande",
    "återinföras": "återinföra",
    "återinförd": "återinföra",
    "återinförda": "återinföra",
    "återinfördas": "återinföra",
    "återinförde": "återinföra",
    "återinfördes": "återinföra",
    "återinförds": "återinföra",
    "återinföres": "återinföra",
    "återinförs": "återinföra",
    "återinfört": "återinföra",
    "återinförts": "återinföra",
    "återinstallerad": "återinstallera",
    "återinstallerade": "återinstallera",
    "återinstallerades": "återinstallera",
    "återinstallerads": "återinstallera",
    "återinstallerande": "återinstallera",
    "återinstalleranden": "återinstallerande",
    "återinstallerandena": "återinstallerande",
    "återinstallerandenas": "återinstallerande",
    "återinstallerandens": "återinstallerande",
    "återinstallerandes": "återinstallerande",
    "återinstallerandet": "återinstallerande",
    "återinstallerandets": "återinstallerande",
    "återinstallerar": "återinstallera",
    "återinstalleras": "återinstallera",
    "återinstallerat": "återinstallera",
    "återinstallerats": "återinstallera",
    "återinstallerbara": "återinstallerbar",
    "återinstallerbarare": "återinstallerbar",
    "återinstallerbarares": "återinstallerbar",
    "återinstallerbaras": "återinstallerbar",
    "återinstallerbarast": "återinstallerbar",
    "återinstallerbaraste": "återinstallerbar",
    "återinstallerbarastes": "återinstallerbar",
    "återinstallerbarasts": "återinstallerbar",
    "återinstallerbare": "återinstallerbar",
    "återinstallerbares": "återinstallerbar",
    "återinstallerbarheten": "återinstallerbarhet",
    "återinstallerbarhetens": "återinstallerbarhet",
    "återinstallerbarhets": "återinstallerbarhet",
    "återinstallerbars": "återinstallerbar",
    "återinstallerbart": "återinstallerbar",
    "återinstallerbarts": "återinstallerbar",
    "återkall": "återkalla",
    "återkallad": "återkalla",
    "återkallade": "återkalla",
    "återkallades": "återkalla",
    "återkallads": "återkalla",
    "återkallande": "återkalla",
    "återkallanden": "återkallande",
    "återkallandena": "återkallande",
    "återkallandenas": "återkallande",
    "återkallandens": "återkallande",
    "återkallandes": "återkallande",
    "återkallandet": "återkallande",
    "återkallandets": "återkallande",
    "återkallar": "återkalla",
    "återkallas": "återkalla",
    "återkallat": "återkalla",
    "återkallats": "återkalla",
    "återkallelsen": "återkallelse",
    "återkallelsens": "återkallelse",
    "återkallelser": "återkallelse",
    "återkallelserna": "återkallelse",
    "återkallelsernas": "återkallelse",
    "återkallelsers": "återkallelse",
    "återkallelses": "återkallelse",
    "återkast": "återkasta",
    "återkastad": "återkasta",
    "återkastade": "återkasta",
    "återkastades": "återkasta",
    "återkastads": "återkasta",
    "återkastande": "återkasta",
    "återkastanden": "återkastande",
    "återkastandena": "återkastande",
    "återkastandenas": "återkastande",
    "återkastandens": "återkastande",
    "återkastandes": "återkastande",
    "återkastandet": "återkastande",
    "återkastandets": "återkastande",
    "återkastar": "återkasta",
    "återkastas": "återkasta",
    "återkastat": "återkasta",
    "återkastats": "återkasta",
    "återklangen": "återklang",
    "återklangens": "återklang",
    "återklangs": "återklang",
    "återkling": "återklinga",
    "återklingad": "återklinga",
    "återklingade": "återklinga",
    "återklingades": "återklinga",
    "återklingads": "återklinga",
    "återklingande": "återklinga",
    "återklinganden": "återklingande",
    "återklingandena": "återklingande",
    "återklingandenas": "återklingande",
    "återklingandens": "återklingande",
    "återklingandes": "återklingande",
    "återklingandet": "återklingande",
    "återklingandets": "återklingande",
    "återklingar": "återklinga",
    "återklingas": "återklinga",
    "återklingat": "återklinga",
    "återklingats": "återklinga",
    "återknuten": "återknyta",
    "återknutens": "återknyta",
    "återknutet": "återknyta",
    "återknutets": "återknyta",
    "återknutit": "återknyta",
    "återknutits": "återknyta",
    "återknutna": "återknyta",
    "återknutnas": "återknyta",
    "återknutne": "återknyta",
    "återknutnes": "återknyta",
    "återknyt": "återknyta",
    "återknytande": "återknyta",
    "återknytanden": "återknytande",
    "återknytandena": "återknytande",
    "återknytandenas": "återknytande",
    "återknytandens": "återknytande",
    "återknytandes": "återknytande",
    "återknytandet": "återknytande",
    "återknytandets": "återknytande",
    "återknytas": "återknyta",
    "återknyte": "återknyta",
    "återknyter": "återknyta",
    "återknytes": "återknyta",
    "återknyts": "återknyta",
    "återknöt": "återknyta",
    "återknöte": "återknyta",
    "återknötes": "återknyta",
    "återknöts": "återknyta",
    "återkom": "återkomma",
    "återkomet": "återkomma",
    "återkomets": "återkomma",
    "återkommande": "återkomma",
    "återkommanden": "återkommande",
    "återkommandena": "återkommande",
    "återkommandenas": "återkommande",
    "återkommandens": "återkommande",
    "återkommandes": "återkommande",
    "återkommandet": "återkommande",
    "återkommandets": "återkommande",
    "återkommas": "återkomma",
    "återkomme": "återkomma",
    "återkommen": "återkomma",
    "återkommens": "återkomma",
    "återkommer": "återkomma",
    "återkommes": "återkomma",
    "återkommit": "återkomma",
    "återkommits": "återkomma",
    "återkomna": "återkomma",
    "återkomnas": "återkomma",
    "återkomne": "återkomma",
    "återkomnes": "återkomma",
    "återkoms": "återkomma",
    "återkomsten": "återkomst",
    "återkomstens": "återkomst",
    "återkomsts": "återkomst",
    "återkopplad": "återkoppla",
    "återkopplade": "återkoppla",
    "återkopplades": "återkoppla",
    "återkopplads": "återkoppla",
    "återkopplande": "återkoppla",
    "återkopplanden": "återkopplande",
    "återkopplandena": "återkopplande",
    "återkopplandenas": "återkopplande",
    "återkopplandens": "återkopplande",
    "återkopplandes": "återkopplande",
    "återkopplandet": "återkopplande",
    "återkopplandets": "återkopplande",
    "återkopplar": "återkoppla",
    "återkopplas": "återkoppla",
    "återkopplat": "återkoppla",
    "återkopplats": "återkoppla",
    "återkopplingar": "återkoppling",
    "återkopplingarna": "återkoppling",
    "återkopplingarnas": "återkoppling",
    "återkopplingars": "återkoppling",
    "återkopplingen": "återkoppling",
    "återkopplingens": "återkoppling",
    "återkopplings": "återkoppling",
    "återkräv": "återkräva",
    "återkrävande": "återkräva",
    "återkrävandes": "återkräva",
    "återkrävas": "återkräva",
    "återkrävd": "återkräva",
    "återkrävda": "återkräva",
    "återkrävdas": "återkräva",
    "återkrävde": "återkräva",
    "återkrävdes": "återkräva",
    "återkrävds": "återkräva",
    "återkräver": "återkräva",
    "återkräves": "återkräva",
    "återkrävs": "återkräva",
    "återkrävt": "återkräva",
    "återkrävts": "återkräva",
    "återköpen": "återköp",
    "återköpens": "återköp",
    "återköpet": "återköp",
    "återköpets": "återköp",
    "återköps": "återköp",
    "återköpsrätten": "återköpsrätt",
    "återköpsrättens": "återköpsrätt",
    "återköpsrätts": "återköpsrätt",
    "återlämnad": "återlämna",
    "återlämnade": "återlämna",
    "återlämnades": "återlämna",
    "återlämnads": "återlämna",
    "återlämnande": "återlämna",
    "återlämnanden": "återlämnande",
    "återlämnandena": "återlämnande",
    "återlämnandenas": "återlämnande",
    "återlämnandens": "återlämnande",
    "återlämnandes": "återlämnande",
    "återlämnandet": "återlämnande",
    "återlämnandets": "återlämnande",
    "återlämnar": "återlämna",
    "återlämnas": "återlämna",
    "återlämnat": "återlämna",
    "återlämnats": "återlämna",
    "återlös": "återlösa",
    "återlösande": "återlösa",
    "återlösanden": "återlösande",
    "återlösandena": "återlösande",
    "återlösandenas": "återlösande",
    "återlösandens": "återlösande",
    "återlösandes": "återlösande",
    "återlösandet": "återlösande",
    "återlösandets": "återlösande",
    "återlösas": "återlösa",
    "återlöser": "återlösa",
    "återlöses": "återlösa",
    "återlösningar": "återlösning",
    "återlösningarna": "återlösning",
    "återlösningarnas": "återlösning",
    "återlösningars": "återlösning",
    "återlösningen": "återlösning",
    "återlösningens": "återlösning",
    "återlösnings": "återlösning",
    "återlöst": "återlösa",
    "återlösta": "återlösa",
    "återlöstas": "återlösa",
    "återlöste": "återlösa",
    "återlöstes": "återlösa",
    "återlösts": "återlösa",
    "återplanterad": "återplantera",
    "återplanterade": "återplantera",
    "återplanterades": "återplantera",
    "återplanterads": "återplantera",
    "återplanterande": "återplantera",
    "återplanterandes": "återplantera",
    "återplanterar": "återplantera",
    "återplanteras": "återplantera",
    "återplanterat": "återplantera",
    "återplanterats": "återplantera",
    "återresan": "återresa",
    "återresans": "återresa",
    "återresas": "återresa",
    "återrese": "återresa",
    "återresor": "återresa",
    "återresorna": "återresa",
    "återresornas": "återresa",
    "återresors": "återresa",
    "återrop": "återropa",
    "återropad": "återropa",
    "återropade": "återropa",
    "återropades": "återropa",
    "återropads": "återropa",
    "återropande": "återropa",
    "återropanden": "återropande",
    "återropandena": "återropande",
    "återropandenas": "återropande",
    "återropandens": "återropande",
    "återropandes": "återropande",
    "återropandet": "återropande",
    "återropandets": "återropande",
    "återropar": "återropa",
    "återropas": "återropa",
    "återropat": "återropa",
    "återropats": "återropa",
    "återropen": "återrop",
    "återropens": "återrop",
    "återropet": "återrop",
    "återropets": "återrop",
    "återrops": "återrop",
    "återsamlingar": "återsamling",
    "återsamlingarna": "återsamling",
    "återsamlingarnas": "återsamling",
    "återsamlingars": "återsamling",
    "återsamlingen": "återsamling",
    "återsamlingens": "återsamling",
    "återsamlings": "återsamling",
    "återsedd": "återse",
    "återsedda": "återse",
    "återseddas": "återse",
    "återsedde": "återse",
    "återseddes": "återse",
    "återsedds": "återse",
    "återseende": "återse",
    "återseendes": "återseende",
    "återseendet": "återseende",
    "återseendets": "återseende",
    "återser": "återse",
    "återses": "återse",
    "återsett": "återse",
    "återsetts": "återse",
    "återskenet": "återsken",
    "återskenets": "återsken",
    "återskens": "återsken",
    "återspeglad": "återspegla",
    "återspeglade": "återspegla",
    "återspeglades": "återspegla",
    "återspeglads": "återspegla",
    "återspeglande": "återspegla",
    "återspeglanden": "återspeglande",
    "återspeglandena": "återspeglande",
    "återspeglandenas": "återspeglande",
    "återspeglandens": "återspeglande",
    "återspeglandes": "återspeglande",
    "återspeglandet": "återspeglande",
    "återspeglandets": "återspeglande",
    "återspeglar": "återspegla",
    "återspeglas": "återspegla",
    "återspeglat": "återspegla",
    "återspeglats": "återspegla",
    "återspeglingar": "återspegling",
    "återspeglingarna": "återspegling",
    "återspeglingarnas": "återspegling",
    "återspeglingars": "återspegling",
    "återspeglingen": "återspegling",
    "återspeglingens": "återspegling",
    "återspeglings": "återspegling",
    "återstod": "återstå",
    "återstode": "återstå",
    "återstoden": "återstod",
    "återstodens": "återstod",
    "återstoder": "återstod",
    "återstoderna": "återstod",
    "återstodernas": "återstod",
    "återstoders": "återstod",
    "återstodes": "återstå",
    "återstods": "återstod",
    "återstuds": "återstudsa",
    "återstudsad": "återstudsa",
    "återstudsade": "återstudsa",
    "återstudsades": "återstudsa",
    "återstudsads": "återstudsa",
    "återstudsande": "återstudsa",
    "återstudsanden": "återstudsande",
    "återstudsandena": "återstudsande",
    "återstudsandenas": "återstudsande",
    "återstudsandens": "återstudsande",
    "återstudsandes": "återstudsande",
    "återstudsandet": "återstudsande",
    "återstudsandets": "återstudsande",
    "återstudsar": "återstudsa",
    "återstudsas": "återstudsa",
    "återstudsat": "återstudsa",
    "återstudsats": "återstudsa",
    "återställ": "återställa",
    "återställande": "återställa",
    "återställanden": "återställande",
    "återställandena": "återställande",
    "återställandenas": "återställande",
    "återställandens": "återställande",
    "återställandes": "återställande",
    "återställandet": "återställande",
    "återställandets": "återställande",
    "återställar": "återställare",
    "återställaren": "återställare",
    "återställarens": "återställare",
    "återställares": "återställare",
    "återställarna": "återställare",
    "återställarnas": "återställare",
    "återställas": "återställa",
    "återställd": "återställa",
    "återställda": "återställa",
    "återställdas": "återställa",
    "återställde": "återställa",
    "återställdes": "återställa",
    "återställds": "återställa",
    "återställer": "återställa",
    "återställes": "återställa",
    "återställningsteckens": "återställningstecken",
    "återställningstecknen": "återställningstecken",
    "återställningstecknens": "återställningstecken",
    "återställningstecknet": "återställningstecken",
    "återställningstecknets": "återställningstecken",
    "återställs": "återställa",
    "återställt": "återställa",
    "återställts": "återställa",
    "återstående": "återstå",
    "återståenden": "återstående",
    "återståendena": "återstående",
    "återståendenas": "återstående",
    "återståendens": "återstående",
    "återståendes": "återstående",
    "återståendet": "återstående",
    "återståendets": "återstående",
    "återstår": "återstå",
    "återstås": "återstå",
    "återstått": "återstå",
    "återståtts": "återstå",
    "återsälj": "återsälja",
    "återsäljande": "återsälja",
    "återsäljanden": "återsäljande",
    "återsäljandena": "återsäljande",
    "återsäljandenas": "återsäljande",
    "återsäljandens": "återsäljande",
    "återsäljandes": "återsäljande",
    "återsäljandet": "återsäljande",
    "återsäljandets": "återsäljande",
    "återsäljar": "återsäljare",
    "återsäljaren": "återsäljare",
    "återsäljarens": "återsäljare",
    "återsäljares": "återsäljare",
    "återsäljarna": "återsäljare",
    "återsäljarnas": "återsäljare",
    "återsäljas": "återsälja",
    "återsäljer": "återsälja",
    "återsäljes": "återsälja",
    "återsäljs": "återsälja",
    "återsänd": "återsända",
    "återsändande": "återsända",
    "återsändanden": "återsändande",
    "återsändandena": "återsändande",
    "återsändandenas": "återsändande",
    "återsändandens": "återsändande",
    "återsändandes": "återsändande",
    "återsändandet": "återsändande",
    "återsändandets": "återsändande",
    "återsändas": "återsända",
    "återsände": "återsända",
    "återsänder": "återsända",
    "återsändes": "återsända",
    "återsänds": "återsända",
    "återsänt": "återsända",
    "återsänts": "återsända",
    "återsåg": "återse",
    "återsåge": "återse",
    "återsåges": "återse",
    "återsågs": "återse",
    "återsåld": "återsälja",
    "återsålda": "återsälja",
    "återsåldas": "återsälja",
    "återsålde": "återsälja",
    "återsåldes": "återsälja",
    "återsålds": "återsälja",
    "återsålt": "återsälja",
    "återsålts": "återsälja",
    "återtag": "återta",
    "återtaga": "återta",
    "återtagande": "återta",
    "återtaganden": "återtagande",
    "återtagandena": "återtagande",
    "återtagandenas": "återtagande",
    "återtagandens": "återtagande",
    "återtagandes": "återtagande",
    "återtagandet": "återtagande",
    "återtagandets": "återtagande",
    "återtagas": "återta",
    "återtage": "återta",
    "återtagen": "återta",
    "återtagens": "återta",
    "återtager": "återta",
    "återtages": "återta",
    "återtaget": "återta",
    "återtagets": "återta",
    "återtagit": "återta",
    "återtagits": "återta",
    "återtagna": "återta",
    "återtagnas": "återta",
    "återtagne": "återta",
    "återtagnes": "återta",
    "återtags": "återta",
    "återtar": "återta",
    "återtas": "återta",
    "återtjänsten": "återtjänst",
    "återtjänstens": "återtjänst",
    "återtjänster": "återtjänst",
    "återtjänsterna": "återtjänst",
    "återtjänsternas": "återtjänst",
    "återtjänsters": "återtjänst",
    "återtjänsts": "återtjänst",
    "återtog": "återta",
    "återtoge": "återta",
    "återtoges": "återta",
    "återtogs": "återta",
    "återtåg": "återtåga",
    "återtågad": "återtåga",
    "återtågade": "återtåga",
    "återtågades": "återtåga",
    "återtågads": "återtåga",
    "återtågande": "återtåga",
    "återtåganden": "återtågande",
    "återtågandena": "återtågande",
    "återtågandenas": "återtågande",
    "återtågandens": "återtågande",
    "återtågandes": "återtågande",
    "återtågandet": "återtågande",
    "återtågandets": "återtågande",
    "återtågar": "återtåga",
    "återtågas": "återtåga",
    "återtågat": "återtåga",
    "återtågats": "återtåga",
    "återtågen": "återtåg",
    "återtågens": "återtåg",
    "återtåget": "återtåg",
    "återtågets": "återtåg",
    "återtågs": "återtåg",
    "återuppbygg": "återuppbygga",
    "återuppbyggande": "återuppbygga",
    "återuppbygganden": "återuppbyggande",
    "återuppbyggandena": "återuppbyggande",
    "återuppbyggandenas": "återuppbyggande",
    "återuppbyggandens": "återuppbyggande",
    "återuppbyggandes": "återuppbyggande",
    "återuppbyggandet": "återuppbyggande",
    "återuppbyggandets": "återuppbyggande",
    "återuppbyggas": "återuppbygga",
    "återuppbyggd": "återuppbygga",
    "återuppbyggda": "återuppbygga",
    "återuppbyggdas": "återuppbygga",
    "återuppbyggde": "återuppbygga",
    "återuppbyggdes": "återuppbygga",
    "återuppbyggds": "återuppbygga",
    "återuppbygger": "återuppbygga",
    "återuppbygges": "återuppbygga",
    "återuppbyggs": "återuppbygga",
    "återuppbyggt": "återuppbygga",
    "återuppbyggts": "återuppbygga",
    "återuppliv": "återuppliva",
    "återupplivad": "återuppliva",
    "återupplivade": "återuppliva",
    "återupplivades": "återuppliva",
    "återupplivads": "återuppliva",
    "återupplivande": "återuppliva",
    "återupplivanden": "återupplivande",
    "återupplivandena": "återupplivande",
    "återupplivandenas": "återupplivande",
    "återupplivandens": "återupplivande",
    "återupplivandes": "återupplivande",
    "återupplivandet": "återupplivande",
    "återupplivandets": "återupplivande",
    "återupplivar": "återuppliva",
    "återupplivas": "återuppliva",
    "återupplivat": "återuppliva",
    "återupplivats": "återuppliva",
    "återupplivningar": "återupplivning",
    "återupplivningarna": "återupplivning",
    "återupplivningarnas": "återupplivning",
    "återupplivningars": "återupplivning",
    "återupplivningen": "återupplivning",
    "återupplivningens": "återupplivning",
    "återupplivnings": "återupplivning",
    "återupplivningsförsöken": "återupplivningsförsök",
    "återupplivningsförsökens": "återupplivningsförsök",
    "återupplivningsförsöket": "återupplivningsförsök",
    "återupplivningsförsökets": "återupplivningsförsök",
    "återupplivningsförsöks": "återupplivningsförsök",
    "återupprätt": "återupprätta",
    "återupprättad": "återupprätta",
    "återupprättade": "återupprätta",
    "återupprättades": "återupprätta",
    "återupprättads": "återupprätta",
    "återupprättande": "återupprätta",
    "återupprättanden": "återupprättande",
    "återupprättandena": "återupprättande",
    "återupprättandenas": "återupprättande",
    "återupprättandens": "återupprättande",
    "återupprättandes": "återupprättande",
    "återupprättandet": "återupprättande",
    "återupprättandets": "återupprättande",
    "återupprättar": "återupprätta",
    "återupprättas": "återupprätta",
    "återupprättat": "återupprätta",
    "återupprättats": "återupprätta",
    "återuppstod": "återuppstå",
    "återuppstode": "återuppstå",
    "återuppstodes": "återuppstå",
    "återuppstods": "återuppstå",
    "återuppstående": "återuppstå",
    "återuppståenden": "återuppstående",
    "återuppståendena": "återuppstående",
    "återuppståendenas": "återuppstående",
    "återuppståendens": "återuppstående",
    "återuppståendes": "återuppstående",
    "återuppståendet": "återuppstående",
    "återuppståendets": "återuppstående",
    "återuppståndelsen": "återuppståndelse",
    "återuppståndelsens": "återuppståndelse",
    "återuppståndelser": "återuppståndelse",
    "återuppståndelserna": "återuppståndelse",
    "återuppståndelsernas": "återuppståndelse",
    "återuppståndelsers": "återuppståndelse",
    "återuppståndelses": "återuppståndelse",
    "återuppstånden": "återuppstå",
    "återuppståndens": "återuppstå",
    "återuppståndet": "återuppstå",
    "återuppståndets": "återuppstå",
    "återuppståndna": "återuppstå",
    "återuppståndnas": "återuppstå",
    "återuppståndne": "återuppstå",
    "återuppståndnes": "återuppstå",
    "återuppstår": "återuppstå",
    "återuppstås": "återuppstå",
    "återuppstått": "återuppstå",
    "återuppståtts": "återuppstå",
    "återupptag": "återuppta",
    "återupptaga": "återuppta",
    "återupptagande": "återuppta",
    "återupptaganden": "återupptagande",
    "återupptagandena": "återupptagande",
    "återupptagandenas": "återupptagande",
    "återupptagandens": "återupptagande",
    "återupptagandes": "återupptagande",
    "återupptagandet": "återupptagande",
    "återupptagandets": "återupptagande",
    "återupptagas": "återuppta",
    "återupptage": "återuppta",
    "återupptagen": "återuppta",
    "återupptagens": "återuppta",
    "återupptager": "återuppta",
    "återupptages": "återuppta",
    "återupptaget": "återuppta",
    "återupptagets": "återuppta",
    "återupptagit": "återuppta",
    "återupptagits": "återuppta",
    "återupptagna": "återuppta",
    "återupptagnas": "återuppta",
    "återupptagne": "återuppta",
    "återupptagnes": "återuppta",
    "återupptags": "återuppta",
    "återupptar": "återuppta",
    "återupptas": "återuppta",
    "återupptog": "återuppta",
    "återupptoge": "återuppta",
    "återupptoges": "återuppta",
    "återupptogs": "återuppta",
    "återuppväck": "återuppväcka",
    "återuppväckande": "återuppväcka",
    "återuppväckanden": "återuppväckande",
    "återuppväckandena": "återuppväckande",
    "återuppväckandenas": "återuppväckande",
    "återuppväckandens": "återuppväckande",
    "återuppväckandes": "återuppväckande",
    "återuppväckandet": "återuppväckande",
    "återuppväckandets": "återuppväckande",
    "återuppväckas": "återuppväcka",
    "återuppväcker": "återuppväcka",
    "återuppväckes": "återuppväcka",
    "återuppväcks": "återuppväcka",
    "återuppväckt": "återuppväcka",
    "återuppväckta": "återuppväcka",
    "återuppväcktas": "återuppväcka",
    "återuppväckte": "återuppväcka",
    "återuppväcktes": "återuppväcka",
    "återuppväckts": "återuppväcka",
    "återutstrål": "återutstråla",
    "återutstrålad": "återutstråla",
    "återutstrålade": "återutstråla",
    "återutstrålades": "återutstråla",
    "återutstrålads": "återutstråla",
    "återutstrålande": "återutstråla",
    "återutstrålanden": "återutstrålande",
    "återutstrålandena": "återutstrålande",
    "återutstrålandenas": "återutstrålande",
    "återutstrålandens": "återutstrålande",
    "återutstrålandes": "återutstrålande",
    "återutstrålandet": "återutstrålande",
    "återutstrålandets": "återutstrålande",
    "återutstrålar": "återutstråla",
    "återutstrålas": "återutstråla",
    "återutstrålat": "återutstråla",
    "återutstrålats": "återutstråla",
    "återutsänd": "återutsända",
    "återutsändande": "återutsända",
    "återutsändanden": "återutsändande",
    "återutsändandena": "återutsändande",
    "återutsändandenas": "återutsändande",
    "återutsändandens": "återutsändande",
    "återutsändandes": "återutsändande",
    "återutsändandet": "återutsändande",
    "återutsändandets": "återutsändande",
    "återutsändas": "återutsända",
    "återutsände": "återutsända",
    "återutsänder": "återutsända",
    "återutsändes": "återutsända",
    "återutsänds": "återutsända",
    "återutsänt": "återutsända",
    "återutsänts": "återutsända",
    "återvald": "återvälja",
    "återvalda": "återvälja",
    "återvaldas": "återvälja",
    "återvalde": "återvälja",
    "återvaldes": "återvälja",
    "återvalds": "återvälja",
    "återvalen": "återval",
    "återvalens": "återval",
    "återvalet": "återval",
    "återvalets": "återval",
    "återvals": "återval",
    "återvalt": "återvälja",
    "återvalts": "återvälja",
    "återvann": "återvinna",
    "återvanns": "återvinna",
    "återverk": "återverka",
    "återverkad": "återverka",
    "återverkade": "återverka",
    "återverkades": "återverka",
    "återverkads": "återverka",
    "återverkande": "återverka",
    "återverkanden": "återverkande",
    "återverkandena": "återverkande",
    "återverkandenas": "återverkande",
    "återverkandens": "återverkande",
    "återverkandes": "återverkande",
    "återverkandet": "återverkande",
    "återverkandets": "återverkande",
    "återverkans": "återverkan",
    "återverkar": "återverka",
    "återverkas": "återverka",
    "återverkat": "återverka",
    "återverkats": "återverka",
    "återverkningar": "återverkning",
    "återverkningarna": "återverkning",
    "återverkningarnas": "återverkning",
    "återverkningars": "återverkning",
    "återverkningen": "återverkning",
    "återverkningens": "återverkning",
    "återverknings": "återverkning",
    "återvinn": "återvinna",
    "återvinnande": "återvinna",
    "återvinnanden": "återvinnande",
    "återvinnandena": "återvinnande",
    "återvinnandenas": "återvinnande",
    "återvinnandens": "återvinnande",
    "återvinnandes": "återvinnande",
    "återvinnandet": "återvinnande",
    "återvinnandets": "återvinnande",
    "återvinnas": "återvinna",
    "återvinne": "återvinna",
    "återvinner": "återvinna",
    "återvinnes": "återvinna",
    "återvinningar": "återvinning",
    "återvinningarna": "återvinning",
    "återvinningarnas": "återvinning",
    "återvinningars": "återvinning",
    "återvinningen": "återvinning",
    "återvinningens": "återvinning",
    "återvinnings": "återvinning",
    "återvinningsstationen": "återvinningsstation",
    "återvinningsstationens": "återvinningsstation",
    "återvinningsstationer": "återvinningsstation",
    "återvinningsstationerna": "återvinningsstation",
    "återvinningsstationernas": "återvinningsstation",
    "återvinningsstationers": "återvinningsstation",
    "återvinningsstations": "återvinningsstation",
    "återvinns": "återvinna",
    "återvunna": "återvinna",
    "återvunnas": "återvinna",
    "återvunne": "återvinna",
    "återvunnen": "återvinna",
    "återvunnens": "återvinna",
    "återvunnes": "återvinna",
    "återvunnet": "återvinna",
    "återvunnets": "återvinna",
    "återvunnit": "återvinna",
    "återvunnits": "återvinna",
    "återvägen": "återväg",
    "återvägens": "återväg",
    "återvägs": "återväg",
    "återvälj": "återvälja",
    "återväljande": "återvälja",
    "återväljanden": "återväljande",
    "återväljandena": "återväljande",
    "återväljandenas": "återväljande",
    "återväljandens": "återväljande",
    "återväljandes": "återväljande",
    "återväljandet": "återväljande",
    "återväljandets": "återväljande",
    "återväljas": "återvälja",
    "återväljer": "återvälja",
    "återväljes": "återvälja",
    "återväljs": "återvälja",
    "återvänd": "återvända",
    "återvändande": "återvända",
    "återvändanden": "återvändande",
    "återvändandena": "återvändande",
    "återvändandenas": "återvändande",
    "återvändandens": "återvändande",
    "återvändandes": "återvändande",
    "återvändandet": "återvändande",
    "återvändandets": "återvändande",
    "återvändas": "återvända",
    "återvände": "återvända",
    "återvänder": "återvända",
    "återvändes": "återvända",
    "återvändos": "återvändo",
    "återvänds": "återvända",
    "återvändsgat": "återvändsgata",
    "återvändsgatan": "återvändsgata",
    "återvändsgatans": "återvändsgata",
    "återvändsgatas": "återvändsgata",
    "återvändsgate": "återvändsgata",
    "återvändsgator": "återvändsgata",
    "återvändsgatorna": "återvändsgata",
    "återvändsgatornas": "återvändsgata",
    "återvändsgators": "återvändsgata",
    "återvändsgats": "återvändsgata",
    "återvändsgränden": "återvändsgränd",
    "återvändsgrändens": "återvändsgränd",
    "återvändsgränder": "återvändsgränd",
    "återvändsgränderna": "återvändsgränd",
    "återvändsgrändernas": "återvändsgränd",
    "återvändsgränders": "återvändsgränd",
    "återvändsgränds": "återvändsgränd",
    "återvänt": "återvända",
    "återvänts": "återvända",
    "återväxten": "återväxt",
    "återväxtens": "återväxt",
    "återväxts": "återväxt",
    "åtes": "äta",
    "åtet": "åt",
    "åtets": "åt",
    "åtfölj": "åtfölja",
    "åtföljande": "åtfölja",
    "åtföljanden": "åtföljande",
    "åtföljandena": "åtföljande",
    "åtföljandenas": "åtföljande",
    "åtföljandens": "åtföljande",
    "åtföljandes": "åtföljande",
    "åtföljandet": "åtföljande",
    "åtföljandets": "åtföljande",
    "åtföljas": "åtfölja",
    "åtföljd": "åtfölja",
    "åtföljda": "åtfölja",
    "åtföljdas": "åtfölja",
    "åtföljde": "åtfölja",
    "åtföljdes": "åtfölja",
    "åtföljds": "åtfölja",
    "åtföljer": "åtfölja",
    "åtföljes": "åtfölja",
    "åtföljs": "åtfölja",
    "åtföljt": "åtfölja",
    "åtföljts": "åtfölja",
    "åtgick": "åtgå",
    "åtgicks": "åtgå",
    "åtginge": "åtgå",
    "åtginges": "åtgå",
    "åtgärd": "åtgärda",
    "åtgärdad": "åtgärda",
    "åtgärdade": "åtgärda",
    "åtgärdades": "åtgärda",
    "åtgärdads": "åtgärda",
    "åtgärdande": "åtgärda",
    "åtgärdanden": "åtgärdande",
    "åtgärdandena": "åtgärdande",
    "åtgärdandenas": "åtgärdande",
    "åtgärdandens": "åtgärdande",
    "åtgärdandes": "åtgärdande",
    "åtgärdandet": "åtgärdande",
    "åtgärdandets": "åtgärdande",
    "åtgärdar": "åtgärda",
    "åtgärdas": "åtgärda",
    "åtgärdat": "åtgärda",
    "åtgärdats": "åtgärda",
    "åtgärden": "åtgärd",
    "åtgärdens": "åtgärd",
    "åtgärder": "åtgärd",
    "åtgärderna": "åtgärd",
    "åtgärdernas": "åtgärd",
    "åtgärders": "åtgärd",
    "åtgärds": "åtgärd",
    "åtgärdspaketen": "åtgärdspaket",
    "åtgärdspaketens": "åtgärdspaket",
    "åtgärdspaketet": "åtgärdspaket",
    "åtgärdspaketets": "åtgärdspaket",
    "åtgärdspakets": "åtgärdspaket",
    "åtgående": "åtgå",
    "åtgåenden": "åtgående",
    "åtgåendena": "åtgående",
    "åtgåendenas": "åtgående",
    "åtgåendens": "åtgående",
    "åtgåendes": "åtgående",
    "åtgåendet": "åtgående",
    "åtgåendets": "åtgående",
    "åtgånge": "åtgå",
    "åtgången": "åtgång",
    "åtgångens": "åtgången",
    "åtgånges": "åtgå",
    "åtgånget": "åtgången",
    "åtgångets": "åtgången",
    "åtgångna": "åtgången",
    "åtgångnare": "åtgången",
    "åtgångnares": "åtgången",
    "åtgångnas": "åtgången",
    "åtgångnast": "åtgången",
    "åtgångnaste": "åtgången",
    "åtgångnastes": "åtgången",
    "åtgångnasts": "åtgången",
    "åtgångne": "åtgången",
    "åtgångnes": "åtgången",
    "åtgångs": "åtgång",
    "åtgår": "åtgå",
    "åtgås": "åtgå",
    "åtgått": "åtgå",
    "åtgåtts": "åtgå",
    "åthutningar": "åthutning",
    "åthutningarna": "åthutning",
    "åthutningarnas": "åthutning",
    "åthutningars": "åthutning",
    "åthutningen": "åthutning",
    "åthutningens": "åthutning",
    "åthutnings": "åthutning",
    "åthävorna": "åthävor",
    "åthävornas": "åthävor",
    "åthävors": "åthävor",
    "åtkomliga": "åtkomlig",
    "åtkomligare": "åtkomlig",
    "åtkomligares": "åtkomlig",
    "åtkomligas": "åtkomlig",
    "åtkomligast": "åtkomlig",
    "åtkomligaste": "åtkomlig",
    "åtkomligastes": "åtkomlig",
    "åtkomligasts": "åtkomlig",
    "åtkomlige": "åtkomlig",
    "åtkomliges": "åtkomlig",
    "åtkomligheten": "åtkomlighet",
    "åtkomlighetens": "åtkomlighet",
    "åtkomlighets": "åtkomlighet",
    "åtkomligs": "åtkomlig",
    "åtkomligt": "åtkomlig",
    "åtkomligts": "åtkomlig",
    "åtkomsten": "åtkomst",
    "åtkomstens": "åtkomst",
    "åtkomsts": "åtkomst",
    "åtlar": "åtel",
    "åtlarna": "åtel",
    "åtlarnas": "åtel",
    "åtlars": "åtel",
    "åtlyd": "åtlyda",
    "åtlydande": "åtlyda",
    "åtlydanden": "åtlydande",
    "åtlydandena": "åtlydande",
    "åtlydandenas": "åtlydande",
    "åtlydandens": "åtlydande",
    "åtlydandes": "åtlydande",
    "åtlydandet": "åtlydande",
    "åtlydandets": "åtlydande",
    "åtlydas": "åtlyda",
    "åtlydd": "åtlyda",
    "åtlydda": "åtlyda",
    "åtlyddas": "åtlyda",
    "åtlydde": "åtlyda",
    "åtlyddes": "åtlyda",
    "åtlydds": "åtlyda",
    "åtlyde": "åtlyda",
    "åtlyder": "åtlyda",
    "åtlydes": "åtlyda",
    "åtlydnaden": "åtlydnad",
    "åtlydnadens": "åtlydnad",
    "åtlydnader": "åtlydnad",
    "åtlydnaderna": "åtlydnad",
    "åtlydnadernas": "åtlydnad",
    "åtlydnaders": "åtlydnad",
    "åtlydnads": "åtlydnad",
    "åtlyds": "åtlyda",
    "åtlytt": "åtlyda",
    "åtlytts": "åtlyda",
    "åtlöd": "åtlyda",
    "åtlöde": "åtlyda",
    "åtlödes": "åtlyda",
    "åtlöds": "åtlyda",
    "åtlöjes": "åtlöje",
    "åtlöjet": "åtlöje",
    "åtlöjets": "åtlöje",
    "åtnjut": "åtnjuta",
    "åtnjutande": "åtnjuta",
    "åtnjutandes": "åtnjutande",
    "åtnjutandet": "åtnjutande",
    "åtnjutandets": "åtnjutande",
    "åtnjutas": "åtnjuta",
    "åtnjute": "åtnjuta",
    "åtnjuten": "åtnjuta",
    "åtnjutens": "åtnjuta",
    "åtnjuter": "åtnjuta",
    "åtnjutes": "åtnjuta",
    "åtnjutet": "åtnjuta",
    "åtnjutets": "åtnjuta",
    "åtnjutit": "åtnjuta",
    "åtnjutits": "åtnjuta",
    "åtnjutna": "åtnjuta",
    "åtnjutnas": "åtnjuta",
    "åtnjutne": "åtnjuta",
    "åtnjutnes": "åtnjuta",
    "åtnjuts": "åtnjuta",
    "åtnjöt": "åtnjuta",
    "åtnjöte": "åtnjuta",
    "åtnjötes": "åtnjuta",
    "åtnjöts": "åtnjuta",
    "åtnöjdes": "åtnöjas",
    "åtnöjs": "åtnöjas",
    "åtnöjts": "åtnöjas",
    "åtrad": "åtra",
    "åtrade": "åtra",
    "åtrades": "åtra",
    "åtrads": "åtra",
    "åtrande": "åtra",
    "åtranden": "åtrande",
    "åtrandena": "åtrande",
    "åtrandenas": "åtrande",
    "åtrandens": "åtrande",
    "åtrandes": "åtrande",
    "åtrandet": "åtrande",
    "åtrandets": "åtrande",
    "åtrar": "åtra",
    "åtras": "åtra",
    "åtrat": "åtra",
    "åtrats": "åtra",
    "åtrådd": "åtrå",
    "åtrådda": "åtrå",
    "åtråddas": "åtrå",
    "åtrådde": "åtrå",
    "åtråddes": "åtrå",
    "åtrådds": "åtrå",
    "åtrående": "åtrå",
    "åtråenden": "åtrående",
    "åtråendena": "åtrående",
    "åtråendenas": "åtrående",
    "åtråendens": "åtrående",
    "åtråendes": "åtrående",
    "åtråendet": "åtrående",
    "åtråendets": "åtrående",
    "åtrån": "åtrå",
    "åtråns": "åtrå",
    "åtrår": "åtrå",
    "åtrås": "åtrå",
    "åtrått": "åtrå",
    "åtråtts": "åtrå",
    "åtråvärda": "åtråvärd",
    "åtråvärdare": "åtråvärd",
    "åtråvärdares": "åtråvärd",
    "åtråvärdas": "åtråvärd",
    "åtråvärdast": "åtråvärd",
    "åtråvärdaste": "åtråvärd",
    "åtråvärdastes": "åtråvärd",
    "åtråvärdasts": "åtråvärd",
    "åtråvärde": "åtråvärd",
    "åtråvärdes": "åtråvärd",
    "åtråvärdheten": "åtråvärdhet",
    "åtråvärdhetens": "åtråvärdhet",
    "åtråvärdhets": "åtråvärdhet",
    "åtråvärds": "åtråvärd",
    "åtråvärt": "åtråvärd",
    "åtråvärts": "åtråvärd",
    "åts": "äta",
    "åtsidan": "åtsida",
    "åtsidans": "åtsida",
    "åtsidas": "åtsida",
    "åtside": "åtsida",
    "åtsides": "åtsida",
    "åtsidor": "åtsida",
    "åtsidorna": "åtsida",
    "åtsidornas": "åtsida",
    "åtsidors": "åtsida",
    "åtskild": "åtskilja",
    "åtskilda": "åtskilja",
    "åtskildas": "åtskilja",
    "åtskilde": "åtskilja",
    "åtskildes": "åtskilja",
    "åtskilds": "åtskilja",
    "åtskilj": "åtskilja",
    "åtskiljande": "åtskilja",
    "åtskiljanden": "åtskiljande",
    "åtskiljandena": "åtskiljande",
    "åtskiljandenas": "åtskiljande",
    "åtskiljandens": "åtskiljande",
    "åtskiljandes": "åtskiljande",
    "åtskiljandet": "åtskiljande",
    "åtskiljandets": "åtskiljande",
    "åtskiljas": "åtskilja",
    "åtskiljer": "åtskilja",
    "åtskiljes": "åtskilja",
    "åtskiljs": "åtskilja",
    "åtskilliga": "åtskillig",
    "åtskilligas": "åtskillig",
    "åtskilligs": "åtskillig",
    "åtskilligt": "åtskillig",
    "åtskilligts": "åtskillig",
    "åtskillnaden": "åtskillnad",
    "åtskillnadens": "åtskillnad",
    "åtskillnader": "åtskillnad",
    "åtskillnaderna": "åtskillnad",
    "åtskillnadernas": "åtskillnad",
    "åtskillnaders": "åtskillnad",
    "åtskillnads": "åtskillnad",
    "åtskilt": "åtskilja",
    "åtskilts": "åtskilja",
    "åtstram": "åtstrama",
    "åtstramad": "åtstrama",
    "åtstramade": "åtstrama",
    "åtstramades": "åtstrama",
    "åtstramads": "åtstrama",
    "åtstramande": "åtstrama",
    "åtstramanden": "åtstramande",
    "åtstramandena": "åtstramande",
    "åtstramandenas": "åtstramande",
    "åtstramandens": "åtstramande",
    "åtstramandes": "åtstramande",
    "åtstramandet": "åtstramande",
    "åtstramandets": "åtstramande",
    "åtstramar": "åtstrama",
    "åtstramas": "åtstrama",
    "åtstramat": "åtstrama",
    "åtstramats": "åtstrama",
    "åtstramningar": "åtstramning",
    "åtstramningarna": "åtstramning",
    "åtstramningarnas": "åtstramning",
    "åtstramningars": "åtstramning",
    "åtstramningen": "åtstramning",
    "åtstramningens": "åtstramning",
    "åtstramnings": "åtstramning",
    "åtstramningsbudgetar": "åtstramningsbudget",
    "åtstramningsbudgetarna": "åtstramningsbudget",
    "åtstramningsbudgetarnas": "åtstramningsbudget",
    "åtstramningsbudgetars": "åtstramningsbudget",
    "åtstramningsbudgeten": "åtstramningsbudget",
    "åtstramningsbudgetens": "åtstramningsbudget",
    "åtstramningsbudgets": "åtstramningsbudget",
    "åtstramningsprogrammen": "åtstramningsprogram",
    "åtstramningsprogrammens": "åtstramningsprogram",
    "åtstramningsprogrammet": "åtstramningsprogram",
    "åtstramningsprogrammets": "åtstramningsprogram",
    "åtstramningsprograms": "åtstramningsprogram",
    "åttadubben": "åttadubbel",
    "åttadubbens": "åttadubbel",
    "åttadubbet": "åttadubbel",
    "åttadubbets": "åttadubbel",
    "åttadubbna": "åttadubbel",
    "åttadubbnas": "åttadubbel",
    "åttadubbne": "åttadubbel",
    "åttadubbnes": "åttadubbel",
    "åttafaldiga": "åttafaldig",
    "åttafaldigas": "åttafaldig",
    "åttafaldige": "åttafaldig",
    "åttafaldiges": "åttafaldig",
    "åttafaldigs": "åttafaldig",
    "åttafaldigt": "åttafaldig",
    "åttafaldigts": "åttafaldig",
    "åttahörniga": "åttahörnig",
    "åttahörnigare": "åttahörnig",
    "åttahörnigares": "åttahörnig",
    "åttahörnigas": "åttahörnig",
    "åttahörnigast": "åttahörnig",
    "åttahörnigaste": "åttahörnig",
    "åttahörnigastes": "åttahörnig",
    "åttahörnigasts": "åttahörnig",
    "åttahörnige": "åttahörnig",
    "åttahörniges": "åttahörnig",
    "åttahörnigs": "åttahörnig",
    "åttahörnigt": "åttahörnig",
    "åttahörnigts": "åttahörnig",
    "åttan": "åtta",
    "åttans": "åtta",
    "åttas": "åtta",
    "åttasnårets": "åttasnåret",
    "åttatidens": "åttatiden",
    "åttatimmarsdagar": "åttatimmarsdag",
    "åttatimmarsdagarna": "åttatimmarsdag",
    "åttatimmarsdagarnas": "åttatimmarsdag",
    "åttatimmarsdagars": "åttatimmarsdag",
    "åttatimmarsdagen": "åttatimmarsdag",
    "åttatimmarsdagens": "åttatimmarsdag",
    "åttatimmarsdags": "åttatimmarsdag",
    "åttatumsspikar": "åttatumsspik",
    "åttatumsspikarna": "åttatumsspik",
    "åttatumsspikarnas": "åttatumsspik",
    "åttatumsspikars": "åttatumsspik",
    "åttatumsspiken": "åttatumsspik",
    "åttatumsspikens": "åttatumsspik",
    "åttatumsspiks": "åttatumsspik",
    "åttaåriga": "åttaårig",
    "åttaårigas": "åttaårig",
    "åttaårige": "åttaårig",
    "åttaåriges": "åttaårig",
    "åttaårigs": "åttaårig",
    "åttaårigt": "åttaårig",
    "åttaårigts": "åttaårig",
    "åttaåringar": "åttaåring",
    "åttaåringarna": "åttaåring",
    "åttaåringarnas": "åttaåring",
    "åttaåringars": "åttaåring",
    "åttaåringen": "åttaåring",
    "åttaåringens": "åttaåring",
    "åttaårings": "åttaåring",
    "åttaårscykeln": "åttaårscykel",
    "åttaårscykelns": "åttaårscykel",
    "åttaårscykels": "åttaårscykel",
    "åttaårscyklar": "åttaårscykel",
    "åttaårscyklarna": "åttaårscykel",
    "åttaårscyklarnas": "åttaårscykel",
    "åttaårscyklars": "åttaårscykel",
    "åttaårscykler": "åttaårscykel",
    "åttaårscyklerna": "åttaårscykel",
    "åttaårscyklernas": "åttaårscykel",
    "åttaårscyklers": "åttaårscykel",
    "åttionde": "åttio",
    "åttiondelar": "åttiondel",
    "åttiondelarna": "åttiondel",
    "åttiondelarnas": "åttiondel",
    "åttiondelars": "åttiondel",
    "åttiondelen": "åttiondel",
    "åttiondelens": "åttiondel",
    "åttiondels": "åttiondel",
    "åttiondes": "åttio",
    "åttioprocentiga": "åttioprocentig",
    "åttioprocentigas": "åttioprocentig",
    "åttioprocentige": "åttioprocentig",
    "åttioprocentiges": "åttioprocentig",
    "åttioprocentigs": "åttioprocentig",
    "åttioprocentigt": "åttioprocentig",
    "åttioprocentigts": "åttioprocentig",
    "åttios": "åttio",
    "åttiotalet": "åttiotal",
    "åttiotalets": "åttiotal",
    "åttiotalismen": "åttiotalism",
    "åttiotalismens": "åttiotalism",
    "åttiotalismer": "åttiotalism",
    "åttiotalismerna": "åttiotalism",
    "åttiotalismernas": "åttiotalism",
    "åttiotalismers": "åttiotalism",
    "åttiotalisms": "åttiotalism",
    "åttiotalisten": "åttiotalist",
    "åttiotalistens": "åttiotalist",
    "åttiotalister": "åttiotalist",
    "åttiotalisterna": "åttiotalist",
    "åttiotalisternas": "åttiotalist",
    "åttiotalisters": "åttiotalist",
    "åttiotalistiska": "åttiotalistisk",
    "åttiotalistiskas": "åttiotalistisk",
    "åttiotalistiske": "åttiotalistisk",
    "åttiotalistiskes": "åttiotalistisk",
    "åttiotalistisks": "åttiotalistisk",
    "åttiotalistiskt": "åttiotalistisk",
    "åttiotalistiskts": "åttiotalistisk",
    "åttiotalists": "åttiotalist",
    "åttiotals": "åttiotal",
    "åttis": "åtti",
    "åttitalet": "åttital",
    "åttitalets": "åttital",
    "åttitalismen": "åttitalism",
    "åttitalismens": "åttitalism",
    "åttitalismer": "åttitalism",
    "åttitalismerna": "åttitalism",
    "åttitalismernas": "åttitalism",
    "åttitalismers": "åttitalism",
    "åttitalisms": "åttitalism",
    "åttitalisten": "åttitalist",
    "åttitalistens": "åttitalist",
    "åttitalister": "åttitalist",
    "åttitalisterna": "åttitalist",
    "åttitalisternas": "åttitalist",
    "åttitalisters": "åttitalist",
    "åttitalists": "åttitalist",
    "åttitals": "åttital",
    "åttlingar": "åttling",
    "åttlingarna": "åttling",
    "åttlingarnas": "åttling",
    "åttlingars": "åttling",
    "åttlingen": "åttling",
    "åttlingens": "åttling",
    "åttlingmamman": "åttlingmamma",
    "åttlingmammans": "åttlingmamma",
    "åttlingmammas": "åttlingmamma",
    "åttlingmamme": "åttlingmamma",
    "åttlingmammor": "åttlingmamma",
    "åttlingmammorna": "åttlingmamma",
    "åttlingmammornas": "åttlingmamma",
    "åttlingmammors": "åttlingmamma",
    "åttlings": "åttling",
    "åttonde": "åtta",
    "åttondedelar": "åttondedel",
    "åttondedelarna": "åttondedel",
    "åttondedelarnas": "åttondedel",
    "åttondedelars": "åttondedel",
    "åttondedelen": "åttondedel",
    "åttondedelens": "åttondedel",
    "åttondedels": "åttondedel",
    "åttondelar": "åttondel",
    "åttondelarna": "åttondel",
    "åttondelarnas": "åttondel",
    "åttondelars": "åttondel",
    "åttondelen": "åttondel",
    "åttondelens": "åttondel",
    "åttondels": "åttondel",
    "åttondelsfinalen": "åttondelsfinal",
    "åttondelsfinalens": "åttondelsfinal",
    "åttondelsfinaler": "åttondelsfinal",
    "åttondelsfinalerna": "åttondelsfinal",
    "åttondelsfinalernas": "åttondelsfinal",
    "åttondelsfinalers": "åttondelsfinal",
    "åttondelsfinals": "åttondelsfinal",
    "åttondes": "åtta",
    "åttor": "åtta",
    "åttorna": "åtta",
    "åttornas": "åtta",
    "åttors": "åtta",
    "åverkans": "åverkan",
    "åvilade": "åvila",
    "åvilades": "åvila",
    "åvilande": "åvila",
    "åvilanden": "åvilande",
    "åvilandena": "åvilande",
    "åvilandenas": "åvilande",
    "åvilandens": "åvilande",
    "åvilandes": "åvilande",
    "åvilandet": "åvilande",
    "åvilandets": "åvilande",
    "åvilar": "åvila",
    "åvilas": "åvila",
    "åvilat": "åvila",
    "åvilats": "åvila",
    "åvägabragt": "åvägabringa",
    "åvägabragte": "åvägabringa",
    "åvägabragtes": "åvägabringa",
    "åvägabragts": "åvägabringa",
    "åvägabring": "åvägabringa",
    "åvägabringad": "åvägabringa",
    "åvägabringade": "åvägabringa",
    "åvägabringades": "åvägabringa",
    "åvägabringads": "åvägabringa",
    "åvägabringande": "åvägabringa",
    "åvägabringanden": "åvägabringande",
    "åvägabringandena": "åvägabringande",
    "åvägabringandenas": "åvägabringande",
    "åvägabringandens": "åvägabringande",
    "åvägabringandes": "åvägabringande",
    "åvägabringandet": "åvägabringande",
    "åvägabringandets": "åvägabringande",
    "åvägabringar": "åvägabringa",
    "åvägabringas": "åvägabringa",
    "åvägabringat": "åvägabringa",
    "åvägabringats": "åvägabringa",
    "élanen": "élan",
    "élanens": "élan",
    "élans": "élan",
    "ö-et": "ö",
    "ö-ets": "ö",
    "ö-n": "ö",
    "ö-na": "ö",
    "ö-nas": "ö",
    "ö-ns": "ö",
    "ö-s": "ö",
    "ö-t": "ö",
    "ö-ts": "ö",
    "ö:et": "ö",
    "ö:ets": "ö",
    "ö:n": "ö",
    "ö:na": "ö",
    "ö:nas": "ö",
    "ö:ns": "ö",
    "ö:s": "ö",
    "ö:t": "ö",
    "ö:ts": "ö",
    "öar": "ö",
    "öarna": "ö",
    "öarnas": "ö",
    "öars": "ö",
    "öbodd": "öbo",
    "öbodda": "öbo",
    "öboddas": "öbo",
    "öbodde": "öbo",
    "öboddes": "öbo",
    "öbodds": "öbo",
    "öboende": "öbo",
    "öboendes": "öbo",
    "öbor": "öbo",
    "öbos": "öbo",
    "öbott": "öbo",
    "öbotts": "öbo",
    "öd": "öda",
    "ödande": "öda",
    "ödanden": "ödande",
    "ödandena": "ödande",
    "ödandenas": "ödande",
    "ödandens": "ödande",
    "ödandes": "ödande",
    "ödandet": "ödande",
    "ödandets": "ödande",
    "ödas": "öda",
    "ödd": "öda",
    "ödda": "öda",
    "öddas": "öda",
    "ödde": "öda",
    "öddes": "öda",
    "ödds": "öda",
    "ödebygdsvägar": "ödebygdsväg",
    "ödebygdsvägarna": "ödebygdsväg",
    "ödebygdsvägarnas": "ödebygdsväg",
    "ödebygdsvägars": "ödebygdsväg",
    "ödebygdsvägen": "ödebygdsväg",
    "ödebygdsvägens": "ödebygdsväg",
    "ödebygdsvägs": "ödebygdsväg",
    "ödegårdar": "ödegård",
    "ödegårdarna": "ödegård",
    "ödegårdarnas": "ödegård",
    "ödegårdars": "ödegård",
    "ödegården": "ödegård",
    "ödegårdens": "ödegård",
    "ödegårds": "ödegård",
    "ödela": "ödelägga",
    "ödelade": "ödelägga",
    "ödelades": "ödelägga",
    "ödelagd": "ödelägga",
    "ödelagda": "ödelägga",
    "ödelagdas": "ödelägga",
    "ödelagde": "ödelägga",
    "ödelagdes": "ödelägga",
    "ödelagds": "ödelägga",
    "ödelagt": "ödelägga",
    "ödelagts": "ödelägga",
    "ödelas": "ödelägga",
    "ödelägg": "ödelägga",
    "ödeläggande": "ödelägga",
    "ödelägganden": "ödeläggande",
    "ödeläggandena": "ödeläggande",
    "ödeläggandenas": "ödeläggande",
    "ödeläggandens": "ödeläggande",
    "ödeläggandes": "ödeläggande",
    "ödeläggandet": "ödeläggande",
    "ödeläggandets": "ödeläggande",
    "ödeläggas": "ödelägga",
    "ödeläggelsen": "ödeläggelse",
    "ödeläggelsens": "ödeläggelse",
    "ödeläggelser": "ödeläggelse",
    "ödeläggelserna": "ödeläggelse",
    "ödeläggelsernas": "ödeläggelse",
    "ödeläggelsers": "ödeläggelse",
    "ödeläggelses": "ödeläggelse",
    "ödelägger": "ödelägga",
    "ödelägges": "ödelägga",
    "ödeläggs": "ödelägga",
    "ödemarken": "ödemark",
    "ödemarkens": "ödemark",
    "ödemarker": "ödemark",
    "ödemarkerna": "ödemark",
    "ödemarkernas": "ödemark",
    "ödemarkers": "ödemark",
    "ödemarks": "ödemark",
    "ödemarksområden": "ödemarksområde",
    "ödemarksområdena": "ödemarksområde",
    "ödemarksområdenas": "ödemarksområde",
    "ödemarksområdens": "ödemarksområde",
    "ödemarksområdes": "ödemarksområde",
    "ödemarksområdet": "ödemarksområde",
    "ödemarksområdets": "ödemarksområde",
    "ödematösa": "ödematös",
    "ödematösare": "ödematös",
    "ödematösares": "ödematös",
    "ödematösas": "ödematös",
    "ödematösast": "ödematös",
    "ödematösaste": "ödematös",
    "ödematösastes": "ödematös",
    "ödematösasts": "ödematös",
    "ödematöse": "ödematös",
    "ödematöses": "ödematös",
    "ödematöst": "ödematös",
    "ödematösts": "ödematös",
    "ödemen": "ödem",
    "ödemens": "ödem",
    "ödemet": "ödem",
    "ödemets": "ödem",
    "ödems": "ödem",
    "öden": "öde",
    "ödena": "öde",
    "ödenas": "öde",
    "ödens": "öde",
    "öder": "öda",
    "ödes": "öde",
    "ödesbestämda": "ödesbestämd",
    "ödesbestämdare": "ödesbestämd",
    "ödesbestämdares": "ödesbestämd",
    "ödesbestämdas": "ödesbestämd",
    "ödesbestämdast": "ödesbestämd",
    "ödesbestämdaste": "ödesbestämd",
    "ödesbestämdastes": "ödesbestämd",
    "ödesbestämdasts": "ödesbestämd",
    "ödesbestämde": "ödesbestämd",
    "ödesbestämdes": "ödesbestämd",
    "ödesbestämdheten": "ödesbestämdhet",
    "ödesbestämdhetens": "ödesbestämdhet",
    "ödesbestämdhets": "ödesbestämdhet",
    "ödesbestämds": "ödesbestämd",
    "ödesbestämt": "ödesbestämd",
    "ödesbestämts": "ödesbestämd",
    "ödesdigerheten": "ödesdigerhet",
    "ödesdigerhetens": "ödesdigerhet",
    "ödesdigerhets": "ödesdigerhet",
    "ödesdigers": "ödesdiger",
    "ödesdigert": "ödesdiger",
    "ödesdigerts": "ödesdiger",
    "ödesdigra": "ödesdiger",
    "ödesdigrare": "ödesdiger",
    "ödesdigrares": "ödesdiger",
    "ödesdigras": "ödesdiger",
    "ödesdigrast": "ödesdiger",
    "ödesdigraste": "ödesdiger",
    "ödesdigrastes": "ödesdiger",
    "ödesdigrasts": "ödesdiger",
    "ödesdigre": "ödesdiger",
    "ödesdigres": "ödesdiger",
    "ödesdraman": "ödesdrama",
    "ödesdramana": "ödesdrama",
    "ödesdramanas": "ödesdrama",
    "ödesdramans": "ödesdrama",
    "ödesdramas": "ödesdrama",
    "ödesdramat": "ödesdrama",
    "ödesdramats": "ödesdrama",
    "ödesdramer": "ödesdrama",
    "ödesdramerna": "ödesdrama",
    "ödesdramernas": "ödesdrama",
    "ödesdramers": "ödesdrama",
    "ödesgemenskapen": "ödesgemenskap",
    "ödesgemenskapens": "ödesgemenskap",
    "ödesgemenskaps": "ödesgemenskap",
    "ödesgudinnan": "ödesgudinna",
    "ödesgudinnans": "ödesgudinna",
    "ödesgudinnas": "ödesgudinna",
    "ödesgudinne": "ödesgudinna",
    "ödesgudinnor": "ödesgudinna",
    "ödesgudinnorna": "ödesgudinna",
    "ödesgudinnornas": "ödesgudinna",
    "ödesgudinnors": "ödesgudinna",
    "ödesmättade": "ödesmättad",
    "ödesmättades": "ödesmättad",
    "ödesmättads": "ödesmättad",
    "ödesmättat": "ödesmättad",
    "ödesmättats": "ödesmättad",
    "ödesmåls": "ödesmål",
    "ödesstunden": "ödesstund",
    "ödesstundens": "ödesstund",
    "ödesstunder": "ödesstund",
    "ödesstunderna": "ödesstund",
    "ödesstundernas": "ödesstund",
    "ödesstunders": "ödesstund",
    "ödesstunds": "ödesstund",
    "ödestron": "ödestro",
    "ödestrons": "ödestro",
    "ödestros": "ödestro",
    "ödestugan": "ödestuga",
    "ödestugans": "ödestuga",
    "ödestugas": "ödestuga",
    "ödestuge": "ödestuga",
    "ödestugor": "ödestuga",
    "ödestugorna": "ödestuga",
    "ödestugornas": "ödestuga",
    "ödestugors": "ödestuga",
    "ödestugu": "ödestuga",
    "ödet": "öde",
    "ödets": "öde",
    "ödlan": "ödla",
    "ödlans": "ödla",
    "ödlas": "ödla",
    "ödle": "ödla",
    "ödlor": "ödla",
    "ödlorna": "ödla",
    "ödlornas": "ödla",
    "ödlors": "ödla",
    "ödmjuk": "ödmjuka",
    "ödmjuka": "ödmjuk",
    "ödmjukad": "ödmjuka",
    "ödmjukade": "ödmjuka",
    "ödmjukades": "ödmjuka",
    "ödmjukads": "ödmjuka",
    "ödmjukande": "ödmjuka",
    "ödmjukanden": "ödmjukande",
    "ödmjukandena": "ödmjukande",
    "ödmjukandenas": "ödmjukande",
    "ödmjukandens": "ödmjukande",
    "ödmjukandes": "ödmjukande",
    "ödmjukandet": "ödmjukande",
    "ödmjukandets": "ödmjukande",
    "ödmjukar": "ödmjuka",
    "ödmjukare": "ödmjuk",
    "ödmjukares": "ödmjuk",
    "ödmjukas": "ödmjuka",
    "ödmjukast": "ödmjuk",
    "ödmjukaste": "ödmjuk",
    "ödmjukastes": "ödmjuk",
    "ödmjukasts": "ödmjuk",
    "ödmjukat": "ödmjuka",
    "ödmjukats": "ödmjuka",
    "ödmjuke": "ödmjuk",
    "ödmjukes": "ödmjuk",
    "ödmjukheten": "ödmjukhet",
    "ödmjukhetens": "ödmjukhet",
    "ödmjukheter": "ödmjukhet",
    "ödmjukheterna": "ödmjukhet",
    "ödmjukheternas": "ödmjukhet",
    "ödmjukheters": "ödmjukhet",
    "ödmjukhets": "ödmjukhet",
    "ödmjuks": "ödmjuk",
    "ödmjukt": "ödmjuk",
    "ödmjukts": "ödmjuk",
    "öds": "öda",
    "ödslad": "ödsla",
    "ödslade": "ödsla",
    "ödslades": "ödsla",
    "ödslads": "ödsla",
    "ödslande": "ödsla",
    "ödslanden": "ödslande",
    "ödslandena": "ödslande",
    "ödslandenas": "ödslande",
    "ödslandens": "ödslande",
    "ödslandes": "ödslande",
    "ödslandet": "ödslande",
    "ödslandets": "ödslande",
    "ödslar": "ödsla",
    "ödslas": "ödsla",
    "ödslat": "ödsla",
    "ödslats": "ödsla",
    "ödsliga": "ödslig",
    "ödsligare": "ödslig",
    "ödsligares": "ödslig",
    "ödsligas": "ödslig",
    "ödsligast": "ödslig",
    "ödsligaste": "ödslig",
    "ödsligastes": "ödslig",
    "ödsligasts": "ödslig",
    "ödslige": "ödslig",
    "ödsliges": "ödslig",
    "ödsligheten": "ödslighet",
    "ödslighetens": "ödslighet",
    "ödsligheter": "ödslighet",
    "ödsligheterna": "ödslighet",
    "ödsligheternas": "ödslighet",
    "ödsligheters": "ödslighet",
    "ödslighets": "ödslighet",
    "ödsligs": "ödslig",
    "ödsligt": "ödslig",
    "ödsligts": "ödslig",
    "ögas": "öga",
    "ögat": "öga",
    "ögats": "öga",
    "öglan": "ögla",
    "öglans": "ögla",
    "öglas": "ögla",
    "ögle": "ögla",
    "öglor": "ögla",
    "öglorna": "ögla",
    "öglornas": "ögla",
    "öglors": "ögla",
    "ögn": "ögna",
    "ögnad": "ögna",
    "ögnade": "ögna",
    "ögnades": "ögna",
    "ögnads": "ögna",
    "ögnande": "ögna",
    "ögnanden": "ögnande",
    "ögnandena": "ögnande",
    "ögnandenas": "ögnande",
    "ögnandens": "ögnande",
    "ögnandes": "ögnande",
    "ögnandet": "ögnande",
    "ögnandets": "ögnande",
    "ögnar": "ögna",
    "ögnas": "ögna",
    "ögnat": "ögna",
    "ögnats": "ögna",
    "ögon": "öga",
    "ögonbindeln": "ögonbindel",
    "ögonbindelns": "ögonbindel",
    "ögonbindels": "ögonbindel",
    "ögonbindlar": "ögonbindel",
    "ögonbindlarna": "ögonbindel",
    "ögonbindlarnas": "ögonbindel",
    "ögonbindlars": "ögonbindel",
    "ögonblicken": "ögonblick",
    "ögonblickens": "ögonblick",
    "ögonblicket": "ögonblick",
    "ögonblickets": "ögonblick",
    "ögonblickliga": "ögonblicklig",
    "ögonblickligare": "ögonblicklig",
    "ögonblickligares": "ögonblicklig",
    "ögonblickligas": "ögonblicklig",
    "ögonblickligast": "ögonblicklig",
    "ögonblickligaste": "ögonblicklig",
    "ögonblickligastes": "ögonblicklig",
    "ögonblickligasts": "ögonblicklig",
    "ögonblicklige": "ögonblicklig",
    "ögonblickliges": "ögonblicklig",
    "ögonblickligheten": "ögonblicklighet",
    "ögonblicklighetens": "ögonblicklighet",
    "ögonblicklighets": "ögonblicklighet",
    "ögonblickligs": "ögonblicklig",
    "ögonblickligt": "ögonblicklig",
    "ögonblickligts": "ögonblicklig",
    "ögonblicks": "ögonblick",
    "ögonblicksbilden": "ögonblicksbild",
    "ögonblicksbildens": "ögonblicksbild",
    "ögonblicksbilder": "ögonblicksbild",
    "ögonblicksbilderna": "ögonblicksbild",
    "ögonblicksbildernas": "ögonblicksbild",
    "ögonblicksbilders": "ögonblicksbild",
    "ögonblicksbilds": "ögonblicksbild",
    "ögonbottens": "ögonbotten",
    "ögonbottnar": "ögonbotten",
    "ögonbottnarna": "ögonbotten",
    "ögonbottnarnas": "ögonbotten",
    "ögonbottnars": "ögonbotten",
    "ögonbottnen": "ögonbotten",
    "ögonbottnens": "ögonbotten",
    "ögonbrynen": "ögonbryn",
    "ögonbrynens": "ögonbryn",
    "ögonbrynet": "ögonbryn",
    "ögonbrynets": "ögonbryn",
    "ögonbryns": "ögonbryn",
    "ögondiagnostiken": "ögondiagnostik",
    "ögondiagnostikens": "ögondiagnostik",
    "ögondiagnostiks": "ögondiagnostik",
    "ögondroppet": "ögondropp",
    "ögondroppets": "ögondropp",
    "ögondropps": "ögondropp",
    "ögonen": "öga",
    "ögonens": "öga",
    "ögonflirtad": "ögonflirta",
    "ögonflirtade": "ögonflirta",
    "ögonflirtades": "ögonflirta",
    "ögonflirtads": "ögonflirta",
    "ögonflirtande": "ögonflirta",
    "ögonflirtanden": "ögonflirtande",
    "ögonflirtandena": "ögonflirtande",
    "ögonflirtandenas": "ögonflirtande",
    "ögonflirtandens": "ögonflirtande",
    "ögonflirtandes": "ögonflirtande",
    "ögonflirtandet": "ögonflirtande",
    "ögonflirtandets": "ögonflirtande",
    "ögonflirtar": "ögonflirta",
    "ögonflirtas": "ögonflirta",
    "ögonflirtat": "ögonflirta",
    "ögonflirtats": "ögonflirta",
    "ögonflirten": "ögonflirt",
    "ögonflirtens": "ögonflirt",
    "ögonflirter": "ögonflirt",
    "ögonflirterna": "ögonflirt",
    "ögonflirternas": "ögonflirt",
    "ögonflirters": "ögonflirt",
    "ögonflirts": "ögonflirt",
    "ögonflörtad": "ögonflörta",
    "ögonflörtade": "ögonflörta",
    "ögonflörtades": "ögonflörta",
    "ögonflörtads": "ögonflörta",
    "ögonflörtande": "ögonflörta",
    "ögonflörtanden": "ögonflörtande",
    "ögonflörtandena": "ögonflörtande",
    "ögonflörtandenas": "ögonflörtande",
    "ögonflörtandens": "ögonflörtande",
    "ögonflörtandes": "ögonflörtande",
    "ögonflörtandet": "ögonflörtande",
    "ögonflörtandets": "ögonflörtande",
    "ögonflörtar": "ögonflörta",
    "ögonflörtas": "ögonflörta",
    "ögonflörtat": "ögonflörta",
    "ögonflörtats": "ögonflörta",
    "ögonflörten": "ögonflört",
    "ögonflörtens": "ögonflört",
    "ögonflörter": "ögonflört",
    "ögonflörterna": "ögonflört",
    "ögonflörternas": "ögonflört",
    "ögonflörters": "ögonflört",
    "ögonflörts": "ögonflört",
    "ögonfransar": "ögonfrans",
    "ögonfransarna": "ögonfrans",
    "ögonfransarnas": "ögonfrans",
    "ögonfransars": "ögonfrans",
    "ögonfransen": "ögonfrans",
    "ögonfransens": "ögonfrans",
    "ögonfröjden": "ögonfröjd",
    "ögonfröjdens": "ögonfröjd",
    "ögonfröjder": "ögonfröjd",
    "ögonfröjderna": "ögonfröjd",
    "ögonfröjdernas": "ögonfröjd",
    "ögonfröjders": "ögonfröjd",
    "ögonfröjds": "ögonfröjd",
    "ögonfägnaden": "ögonfägnad",
    "ögonfägnadens": "ögonfägnad",
    "ögonfägnader": "ögonfägnad",
    "ögonfägnaderna": "ögonfägnad",
    "ögonfägnadernas": "ögonfägnad",
    "ögonfägnaders": "ögonfägnad",
    "ögonfägnads": "ögonfägnad",
    "ögonfärgen": "ögonfärg",
    "ögonfärgens": "ögonfärg",
    "ögonfärger": "ögonfärg",
    "ögonfärgerna": "ögonfärg",
    "ögonfärgernas": "ögonfärg",
    "ögonfärgers": "ögonfärg",
    "ögonfärgs": "ögonfärg",
    "ögongloben": "ögonglob",
    "ögonglobens": "ögonglob",
    "ögonglober": "ögonglob",
    "ögongloberna": "ögonglob",
    "ögonglobernas": "ögonglob",
    "ögonglobers": "ögonglob",
    "ögonglobs": "ögonglob",
    "ögonhinnan": "ögonhinna",
    "ögonhinnans": "ögonhinna",
    "ögonhinnas": "ögonhinna",
    "ögonhinne": "ögonhinna",
    "ögonhinnor": "ögonhinna",
    "ögonhinnorna": "ögonhinna",
    "ögonhinnornas": "ögonhinna",
    "ögonhinnors": "ögonhinna",
    "ögonhål": "ögonhåla",
    "ögonhålan": "ögonhåla",
    "ögonhålans": "ögonhåla",
    "ögonhålas": "ögonhåla",
    "ögonhåle": "ögonhåla",
    "ögonhålor": "ögonhåla",
    "ögonhålorna": "ögonhåla",
    "ögonhålornas": "ögonhåla",
    "ögonhålors": "ögonhåla",
    "ögonhåls": "ögonhåla",
    "ögonhåren": "ögonhår",
    "ögonhårens": "ögonhår",
    "ögonhåret": "ögonhår",
    "ögonhårets": "ögonhår",
    "ögonhårs": "ögonhår",
    "ögonkameran": "ögonkamera",
    "ögonkamerans": "ögonkamera",
    "ögonkameras": "ögonkamera",
    "ögonkameror": "ögonkamera",
    "ögonkamerorna": "ögonkamera",
    "ögonkamerornas": "ögonkamera",
    "ögonkamerors": "ögonkamera",
    "ögonkasten": "ögonkast",
    "ögonkastens": "ögonkast",
    "ögonkastet": "ögonkast",
    "ögonkastets": "ögonkast",
    "ögonkasts": "ögonkast",
    "ögonlocken": "ögonlock",
    "ögonlockens": "ögonlock",
    "ögonlocket": "ögonlock",
    "ögonlockets": "ögonlock",
    "ögonlocks": "ögonlock",
    "ögonmuskeln": "ögonmuskel",
    "ögonmuskelns": "ögonmuskel",
    "ögonmuskels": "ögonmuskel",
    "ögonmuskler": "ögonmuskel",
    "ögonmusklerna": "ögonmuskel",
    "ögonmusklernas": "ögonmuskel",
    "ögonmusklers": "ögonmuskel",
    "ögonmärken": "ögonmärke",
    "ögonmärkena": "ögonmärke",
    "ögonmärkenas": "ögonmärke",
    "ögonmärkens": "ögonmärke",
    "ögonmärkes": "ögonmärke",
    "ögonmärket": "ögonmärke",
    "ögonmärkets": "ögonmärke",
    "ögonmåttet": "ögonmått",
    "ögonmåttets": "ögonmått",
    "ögonmåtts": "ögonmått",
    "ögonoperationen": "ögonoperation",
    "ögonoperationens": "ögonoperation",
    "ögonoperationer": "ögonoperation",
    "ögonoperationerna": "ögonoperation",
    "ögonoperationernas": "ögonoperation",
    "ögonoperationers": "ögonoperation",
    "ögonoperations": "ögonoperation",
    "ögonprotesen": "ögonprotes",
    "ögonprotesens": "ögonprotes",
    "ögonproteser": "ögonprotes",
    "ögonproteserna": "ögonprotes",
    "ögonprotesernas": "ögonprotes",
    "ögonprotesers": "ögonprotes",
    "ögonrörelsemönsterna": "ögonrörelsemönster",
    "ögonrörelsemönsternas": "ögonrörelsemönster",
    "ögonrörelsemönsters": "ögonrörelsemönster",
    "ögonrörelsemönstren": "ögonrörelsemönster",
    "ögonrörelsemönstrens": "ögonrörelsemönster",
    "ögonrörelsemönstret": "ögonrörelsemönster",
    "ögonrörelsemönstrets": "ögonrörelsemönster",
    "ögonrörelsen": "ögonrörelse",
    "ögonrörelsens": "ögonrörelse",
    "ögonrörelser": "ögonrörelse",
    "ögonrörelserna": "ögonrörelse",
    "ögonrörelsernas": "ögonrörelse",
    "ögonrörelsers": "ögonrörelse",
    "ögonrörelses": "ögonrörelse",
    "ögons": "öga",
    "ögonsiktes": "ögonsikte",
    "ögonsjukdomar": "ögonsjukdom",
    "ögonsjukdomarna": "ögonsjukdom",
    "ögonsjukdomarnas": "ögonsjukdom",
    "ögonsjukdomars": "ögonsjukdom",
    "ögonsjukdomen": "ögonsjukdom",
    "ögonsjukdomens": "ögonsjukdom",
    "ögonsjukdoms": "ögonsjukdom",
    "ögonskenliga": "ögonskenlig",
    "ögonskenligare": "ögonskenlig",
    "ögonskenligares": "ögonskenlig",
    "ögonskenligas": "ögonskenlig",
    "ögonskenligast": "ögonskenlig",
    "ögonskenligaste": "ögonskenlig",
    "ögonskenligastes": "ögonskenlig",
    "ögonskenligasts": "ögonskenlig",
    "ögonskenlige": "ögonskenlig",
    "ögonskenliges": "ögonskenlig",
    "ögonskenligheten": "ögonskenlighet",
    "ögonskenlighetens": "ögonskenlighet",
    "ögonskenlighets": "ögonskenlighet",
    "ögonskenligs": "ögonskenlig",
    "ögonskenligt": "ögonskenlig",
    "ögonskenligts": "ögonskenlig",
    "ögonskuggan": "ögonskugga",
    "ögonskuggans": "ögonskugga",
    "ögonskuggas": "ögonskugga",
    "ögonspegeln": "ögonspegel",
    "ögonspegelns": "ögonspegel",
    "ögonspegels": "ögonspegel",
    "ögonspeglar": "ögonspegel",
    "ögonspeglarna": "ögonspegel",
    "ögonspeglarnas": "ögonspegel",
    "ögonspeglars": "ögonspegel",
    "ögonstenar": "ögonsten",
    "ögonstenarna": "ögonsten",
    "ögonstenarnas": "ögonsten",
    "ögonstenars": "ögonsten",
    "ögonstenen": "ögonsten",
    "ögonstenens": "ögonsten",
    "ögonstens": "ögonsten",
    "ögontaggar": "ögontagg",
    "ögontaggarna": "ögontagg",
    "ögontaggarnas": "ögontagg",
    "ögontaggars": "ögontagg",
    "ögontaggen": "ögontagg",
    "ögontaggens": "ögontagg",
    "ögontaggs": "ögontagg",
    "ögontanden": "ögontand",
    "ögontandens": "ögontand",
    "ögontands": "ögontand",
    "ögontjänar": "ögontjänare",
    "ögontjänaren": "ögontjänare",
    "ögontjänarens": "ögontjänare",
    "ögontjänares": "ögontjänare",
    "ögontjänarna": "ögontjänare",
    "ögontjänarnas": "ögontjänare",
    "ögontrösten": "ögontröst",
    "ögontröstens": "ögontröst",
    "ögontrösts": "ögontröst",
    "ögontänder": "ögontand",
    "ögontänderna": "ögontand",
    "ögontändernas": "ögontand",
    "ögontänders": "ögontand",
    "ögonvidden": "ögonvidd",
    "ögonviddens": "ögonvidd",
    "ögonvidder": "ögonvidd",
    "ögonvidderna": "ögonvidd",
    "ögonviddernas": "ögonvidd",
    "ögonvidders": "ögonvidd",
    "ögonvidds": "ögonvidd",
    "ögonvinkeln": "ögonvinkel",
    "ögonvinkelns": "ögonvinkel",
    "ögonvinkels": "ögonvinkel",
    "ögonvinklar": "ögonvinkel",
    "ögonvinklarna": "ögonvinkel",
    "ögonvinklarnas": "ögonvinkel",
    "ögonvinklars": "ögonvinkel",
    "ögonvit": "ögonvita",
    "ögonvitan": "ögonvita",
    "ögonvitans": "ögonvita",
    "ögonvitas": "ögonvita",
    "ögonvite": "ögonvita",
    "ögonvitor": "ögonvita",
    "ögonvitorna": "ögonvita",
    "ögonvitornas": "ögonvita",
    "ögonvitors": "ögonvita",
    "ögonvits": "ögonvita",
    "ögonvittnen": "ögonvittne",
    "ögonvittnena": "ögonvittne",
    "ögonvittnenas": "ögonvittne",
    "ögonvittnens": "ögonvittne",
    "ögonvittnes": "ögonvittne",
    "ögonvittnesskildringar": "ögonvittnesskildring",
    "ögonvittnesskildringarna": "ögonvittnesskildring",
    "ögonvittnesskildringarnas": "ögonvittnesskildring",
    "ögonvittnesskildringars": "ögonvittnesskildring",
    "ögonvittnesskildringen": "ögonvittnesskildring",
    "ögonvittnesskildringens": "ögonvittnesskildring",
    "ögonvittnesskildrings": "ögonvittnesskildring",
    "ögonvittnet": "ögonvittne",
    "ögonvittnets": "ögonvittne",
    "ögonvrån": "ögonvrå",
    "ögonvråns": "ögonvrå",
    "ögonvrår": "ögonvrå",
    "ögonvrårna": "ögonvrå",
    "ögonvrårnas": "ögonvrå",
    "ögonvrårs": "ögonvrå",
    "ögonvrås": "ögonvrå",
    "ögruppen": "ögrupp",
    "ögruppens": "ögrupp",
    "ögrupper": "ögrupp",
    "ögrupperna": "ögrupp",
    "ögruppernas": "ögrupp",
    "ögruppers": "ögrupp",
    "ögrupps": "ögrupp",
    "ök": "öka",
    "ökad": "öka",
    "ökade": "öka",
    "ökades": "öka",
    "ökads": "öka",
    "ökande": "öka",
    "ökanden": "ökande",
    "ökandena": "ökande",
    "ökandenas": "ökande",
    "ökandens": "ökande",
    "ökandes": "ökande",
    "ökandet": "ökande",
    "ökandets": "ökande",
    "ökar": "öka",
    "ökas": "öka",
    "ökat": "öka",
    "ökats": "öka",
    "öken": "ök",
    "ökenklimatet": "ökenklimat",
    "ökenklimatets": "ökenklimat",
    "ökenklimats": "ökenklimat",
    "ökenlandskapen": "ökenlandskap",
    "ökenlandskapens": "ökenlandskap",
    "ökenlandskapet": "ökenlandskap",
    "ökenlandskapets": "ökenlandskap",
    "ökenlandskaps": "ökenlandskap",
    "ökenrallyn": "ökenrally",
    "ökenrallyna": "ökenrally",
    "ökenrallynas": "ökenrally",
    "ökenrallyns": "ökenrally",
    "ökenrallys": "ökenrally",
    "ökenrallyt": "ökenrally",
    "ökenrallyts": "ökenrally",
    "ökenrått": "ökenråtta",
    "ökenråttan": "ökenråtta",
    "ökenråttans": "ökenråtta",
    "ökenråttas": "ökenråtta",
    "ökenråtte": "ökenråtta",
    "ökenråttor": "ökenråtta",
    "ökenråttorna": "ökenråtta",
    "ökenråttornas": "ökenråtta",
    "ökenråttors": "ökenråtta",
    "ökenråtts": "ökenråtta",
    "ökens": "öken",
    "ökenvandringar": "ökenvandring",
    "ökenvandringarna": "ökenvandring",
    "ökenvandringarnas": "ökenvandring",
    "ökenvandringars": "ökenvandring",
    "ökenvandringen": "ökenvandring",
    "ökenvandringens": "ökenvandring",
    "ökenvandrings": "ökenvandring",
    "ökenvindar": "ökenvind",
    "ökenvindarna": "ökenvind",
    "ökenvindarnas": "ökenvind",
    "ökenvindars": "ökenvind",
    "ökenvinden": "ökenvind",
    "ökenvindens": "ökenvind",
    "ökenvinds": "ökenvind",
    "ökenväxten": "ökenväxt",
    "ökenväxtens": "ökenväxt",
    "ökenväxter": "ökenväxt",
    "ökenväxterna": "ökenväxt",
    "ökenväxternas": "ökenväxt",
    "ökenväxters": "ökenväxt",
    "ökenväxts": "ökenväxt",
    "öket": "ök",
    "ökets": "ök",
    "öknamnen": "öknamn",
    "öknamnens": "öknamn",
    "öknamnet": "öknamn",
    "öknamnets": "öknamn",
    "öknamns": "öknamn",
    "öknar": "öken",
    "öknarna": "öken",
    "öknarnas": "öken",
    "öknars": "öken",
    "öknen": "öken",
    "öknens": "öken",
    "ökningar": "ökning",
    "ökningarna": "ökning",
    "ökningarnas": "ökning",
    "ökningars": "ökning",
    "ökningen": "ökning",
    "ökningens": "ökning",
    "öknings": "ökning",
    "öks": "ök",
    "ökstockar": "ökstock",
    "ökstockarna": "ökstock",
    "ökstockarnas": "ökstock",
    "ökstockars": "ökstock",
    "ökstocken": "ökstock",
    "ökstockens": "ökstock",
    "ökstocks": "ökstock",
    "ökända": "ökänd",
    "ökändare": "ökänd",
    "ökändares": "ökänd",
    "ökändas": "ökänd",
    "ökändast": "ökänd",
    "ökändaste": "ökänd",
    "ökändastes": "ökänd",
    "ökändasts": "ökänd",
    "ökände": "ökänd",
    "ökändes": "ökänd",
    "ökändheten": "ökändhet",
    "ökändhetens": "ökändhet",
    "ökändhets": "ökändhet",
    "ökänds": "ökänd",
    "ökänt": "ökänd",
    "ökänts": "ökänd",
    "öl": "öla",
    "ölad": "öla",
    "ölade": "öla",
    "ölades": "öla",
    "ölads": "öla",
    "ölande": "öla",
    "ölanden": "ölande",
    "ölandena": "ölande",
    "ölandenas": "ölande",
    "ölandens": "ölande",
    "ölandes": "ölande",
    "ölandet": "ölande",
    "ölandets": "ölande",
    "ölandshästar": "ölandshäst",
    "ölandshästarna": "ölandshäst",
    "ölandshästarnas": "ölandshäst",
    "ölandshästars": "ölandshäst",
    "ölandshästen": "ölandshäst",
    "ölandshästens": "ölandshäst",
    "ölandshästs": "ölandshäst",
    "ölandstoken": "ölandstok",
    "ölandstokens": "ölandstok",
    "ölandstoks": "ölandstok",
    "ölar": "öla",
    "ölas": "öla",
    "ölat": "öla",
    "ölats": "öla",
    "ölbackar": "ölback",
    "ölbackarna": "ölback",
    "ölbackarnas": "ölback",
    "ölbackars": "ölback",
    "ölbacken": "ölback",
    "ölbackens": "ölback",
    "ölbacks": "ölback",
    "ölbryggerier": "ölbryggeri",
    "ölbryggerierna": "ölbryggeri",
    "ölbryggeriernas": "ölbryggeri",
    "ölbryggeriers": "ölbryggeri",
    "ölbryggeriet": "ölbryggeri",
    "ölbryggeriets": "ölbryggeri",
    "ölbryggeris": "ölbryggeri",
    "ölbryggerit": "ölbryggeri",
    "ölbryggerits": "ölbryggeri",
    "ölburkar": "ölburk",
    "ölburkarna": "ölburk",
    "ölburkarnas": "ölburk",
    "ölburkars": "ölburk",
    "ölburken": "ölburk",
    "ölburkens": "ölburk",
    "ölburks": "ölburk",
    "ölen": "öl",
    "ölens": "öl",
    "öler": "öl",
    "ölerna": "öl",
    "ölernas": "öl",
    "ölers": "öl",
    "ölet": "öl",
    "ölets": "öl",
    "ölflask": "ölflaska",
    "ölflaskan": "ölflaska",
    "ölflaskans": "ölflaska",
    "ölflaskas": "ölflaska",
    "ölflaske": "ölflaska",
    "ölflaskor": "ölflaska",
    "ölflaskorna": "ölflaska",
    "ölflaskornas": "ölflaska",
    "ölflaskors": "ölflaska",
    "ölglasen": "ölglas",
    "ölglasens": "ölglas",
    "ölglaset": "ölglas",
    "ölglasets": "ölglas",
    "ölgubb": "ölgubbe",
    "ölgubbar": "ölgubbe",
    "ölgubbarna": "ölgubbe",
    "ölgubbarnas": "ölgubbe",
    "ölgubbars": "ölgubbe",
    "ölgubben": "ölgubbe",
    "ölgubbens": "ölgubbe",
    "ölgubbes": "ölgubbe",
    "ölgubbs": "ölgubbe",
    "ölhallar": "ölhall",
    "ölhallarna": "ölhall",
    "ölhallarnas": "ölhall",
    "ölhallars": "ölhall",
    "ölhallen": "ölhall",
    "ölhallens": "ölhall",
    "ölhalls": "ölhall",
    "öljetten": "öljett",
    "öljettens": "öljett",
    "öljetter": "öljett",
    "öljetterna": "öljett",
    "öljetternas": "öljett",
    "öljetters": "öljett",
    "öljetts": "öljett",
    "ölkaféer": "ölkafé",
    "ölkaféerna": "ölkafé",
    "ölkaféernas": "ölkafé",
    "ölkaféers": "ölkafé",
    "ölkaféet": "ölkafé",
    "ölkaféets": "ölkafé",
    "ölkafés": "ölkafé",
    "ölkafét": "ölkafé",
    "ölkaféts": "ölkafé",
    "ölosten": "ölost",
    "ölostens": "ölost",
    "ölosts": "ölost",
    "ölrättigheten": "ölrättighet",
    "ölrättighetens": "ölrättighet",
    "ölrättigheter": "ölrättighet",
    "ölrättigheterna": "ölrättighet",
    "ölrättigheternas": "ölrättighet",
    "ölrättigheters": "ölrättighet",
    "ölrättighets": "ölrättighet",
    "öls": "öl",
    "ölserveringar": "ölservering",
    "ölserveringarna": "ölservering",
    "ölserveringarnas": "ölservering",
    "ölserveringars": "ölservering",
    "ölserveringen": "ölservering",
    "ölserveringens": "ölservering",
    "ölserverings": "ölservering",
    "ölsinnes": "ölsinne",
    "ölsinnet": "ölsinne",
    "ölsinnets": "ölsinne",
    "ölstugan": "ölstuga",
    "ölstugans": "ölstuga",
    "ölstugas": "ölstuga",
    "ölstuge": "ölstuga",
    "ölstugor": "ölstuga",
    "ölstugorna": "ölstuga",
    "ölstugornas": "ölstuga",
    "ölstugors": "ölstuga",
    "ölstugu": "ölstuga",
    "ölsupan": "ölsupa",
    "ölsupans": "ölsupa",
    "ölsupas": "ölsupa",
    "ölsörplar": "ölsörplare",
    "ölsörplaren": "ölsörplare",
    "ölsörplarens": "ölsörplare",
    "ölsörplares": "ölsörplare",
    "ölsörplarna": "ölsörplare",
    "ölsörplarnas": "ölsörplare",
    "öltillverkningar": "öltillverkning",
    "öltillverkningarna": "öltillverkning",
    "öltillverkningarnas": "öltillverkning",
    "öltillverkningars": "öltillverkning",
    "öltillverkningen": "öltillverkning",
    "öltillverkningens": "öltillverkning",
    "öltillverknings": "öltillverkning",
    "öluffar": "öluff",
    "öluffarna": "öluff",
    "öluffarnas": "öluff",
    "öluffars": "öluff",
    "öluffen": "öluff",
    "öluffens": "öluff",
    "öluffs": "öluff",
    "ölunderläggen": "ölunderlägg",
    "ölunderläggens": "ölunderlägg",
    "ölunderlägget": "ölunderlägg",
    "ölunderläggets": "ölunderlägg",
    "ölunderläggs": "ölunderlägg",
    "ölutkörar": "ölutkörare",
    "ölutköraren": "ölutkörare",
    "ölutkörarens": "ölutkörare",
    "ölutkörares": "ölutkörare",
    "ölutkörarna": "ölutkörare",
    "ölutkörarnas": "ölutkörare",
    "öländsk": "öländska",
    "öländska": "öländsk",
    "öländskan": "öländska",
    "öländskans": "öländska",
    "öländskare": "öländsk",
    "öländskares": "öländsk",
    "öländskas": "öländska",
    "öländskast": "öländsk",
    "öländskaste": "öländsk",
    "öländskastes": "öländsk",
    "öländskasts": "öländsk",
    "öländske": "öländska",
    "öländskes": "öländsk",
    "öländskor": "öländska",
    "öländskorna": "öländska",
    "öländskornas": "öländska",
    "öländskors": "öländska",
    "öländsks": "öländsk",
    "öländskt": "öländsk",
    "öländskts": "öländsk",
    "ölänningar": "ölänning",
    "ölänningarna": "ölänning",
    "ölänningarnas": "ölänning",
    "ölänningars": "ölänning",
    "ölänningen": "ölänning",
    "ölänningens": "ölänning",
    "ölännings": "ölänning",
    "ölöppnar": "ölöppnare",
    "ölöppnaren": "ölöppnare",
    "ölöppnarens": "ölöppnare",
    "ölöppnares": "ölöppnare",
    "ölöppnarna": "ölöppnare",
    "ölöppnarnas": "ölöppnare",
    "ömfotade": "ömfotad",
    "ömfotades": "ömfotad",
    "ömfotads": "ömfotad",
    "ömfotat": "ömfotad",
    "ömfotats": "ömfotad",
    "ömheten": "ömhet",
    "ömhetens": "ömhet",
    "ömheter": "ömhet",
    "ömheterna": "ömhet",
    "ömheternas": "ömhet",
    "ömheters": "ömhet",
    "ömhets": "ömhet",
    "ömhetslängtans": "ömhetslängtan",
    "ömhjärtade": "ömhjärtad",
    "ömhjärtades": "ömhjärtad",
    "ömhjärtads": "ömhjärtad",
    "ömhjärtat": "ömhjärtad",
    "ömhjärtats": "ömhjärtad",
    "ömhudade": "ömhudad",
    "ömhudades": "ömhudad",
    "ömhudads": "ömhudad",
    "ömhudat": "ömhudad",
    "ömhudats": "ömhudad",
    "ömk": "ömka",
    "ömkad": "ömka",
    "ömkade": "ömka",
    "ömkades": "ömka",
    "ömkads": "ömka",
    "ömkande": "ömka",
    "ömkanden": "ömkande",
    "ömkandena": "ömkande",
    "ömkandenas": "ömkande",
    "ömkandens": "ömkande",
    "ömkandes": "ömkande",
    "ömkandet": "ömkande",
    "ömkandets": "ömkande",
    "ömkans": "ömkan",
    "ömkansvärda": "ömkansvärd",
    "ömkansvärdare": "ömkansvärd",
    "ömkansvärdares": "ömkansvärd",
    "ömkansvärdas": "ömkansvärd",
    "ömkansvärdast": "ömkansvärd",
    "ömkansvärdaste": "ömkansvärd",
    "ömkansvärdastes": "ömkansvärd",
    "ömkansvärdasts": "ömkansvärd",
    "ömkansvärde": "ömkansvärd",
    "ömkansvärdes": "ömkansvärd",
    "ömkansvärdheten": "ömkansvärdhet",
    "ömkansvärdhetens": "ömkansvärdhet",
    "ömkansvärdhets": "ömkansvärdhet",
    "ömkansvärds": "ömkansvärd",
    "ömkansvärt": "ömkansvärd",
    "ömkansvärts": "ömkansvärd",
    "ömkar": "ömka",
    "ömkas": "ömka",
    "ömkat": "ömka",
    "ömkats": "ömka",
    "ömkliga": "ömklig",
    "ömkligare": "ömklig",
    "ömkligares": "ömklig",
    "ömkligas": "ömklig",
    "ömkligast": "ömklig",
    "ömkligaste": "ömklig",
    "ömkligastes": "ömklig",
    "ömkligasts": "ömklig",
    "ömklige": "ömklig",
    "ömkliges": "ömklig",
    "ömkligheten": "ömklighet",
    "ömklighetens": "ömklighet",
    "ömkligheter": "ömklighet",
    "ömkligheterna": "ömklighet",
    "ömkligheternas": "ömklighet",
    "ömkligheters": "ömklighet",
    "ömklighets": "ömklighet",
    "ömkligs": "ömklig",
    "ömkligt": "ömklig",
    "ömkligts": "ömklig",
    "ömkylan": "ömkyla",
    "ömkylans": "ömkyla",
    "ömkylas": "ömkyla",
    "ömma": "öm",
    "ömmade": "ömma",
    "ömmades": "ömma",
    "ömmande": "ömma",
    "ömmanden": "ömmande",
    "ömmandena": "ömmande",
    "ömmandenas": "ömmande",
    "ömmandens": "ömmande",
    "ömmandes": "ömmande",
    "ömmandet": "ömmande",
    "ömmandets": "ömmande",
    "ömmar": "ömma",
    "ömmare": "öm",
    "ömmares": "öm",
    "ömmas": "ömma",
    "ömmast": "öm",
    "ömmaste": "öm",
    "ömmastes": "öm",
    "ömmasts": "öm",
    "ömmat": "ömma",
    "ömmats": "ömma",
    "ömme": "öm",
    "ömmes": "öm",
    "öms": "ömsa",
    "ömsad": "ömsa",
    "ömsade": "ömsa",
    "ömsades": "ömsa",
    "ömsads": "ömsa",
    "ömsande": "ömsa",
    "ömsanden": "ömsande",
    "ömsandena": "ömsande",
    "ömsandenas": "ömsande",
    "ömsandens": "ömsande",
    "ömsandes": "ömsande",
    "ömsandet": "ömsande",
    "ömsandets": "ömsande",
    "ömsar": "ömsa",
    "ömsas": "ömsa",
    "ömsat": "ömsa",
    "ömsats": "ömsa",
    "ömsesidiga": "ömsesidig",
    "ömsesidigare": "ömsesidig",
    "ömsesidigares": "ömsesidig",
    "ömsesidigas": "ömsesidig",
    "ömsesidigast": "ömsesidig",
    "ömsesidigaste": "ömsesidig",
    "ömsesidigastes": "ömsesidig",
    "ömsesidigasts": "ömsesidig",
    "ömsesidige": "ömsesidig",
    "ömsesidiges": "ömsesidig",
    "ömsesidigheten": "ömsesidighet",
    "ömsesidighetens": "ömsesidighet",
    "ömsesidighets": "ömsesidighet",
    "ömsesidigs": "ömsesidig",
    "ömsesidigt": "ömsesidig",
    "ömsesidigts": "ömsesidig",
    "ömsinta": "ömsint",
    "ömsintare": "ömsint",
    "ömsintares": "ömsint",
    "ömsintas": "ömsint",
    "ömsintast": "ömsint",
    "ömsintaste": "ömsint",
    "ömsintastes": "ömsint",
    "ömsintasts": "ömsint",
    "ömsinte": "ömsint",
    "ömsintes": "ömsint",
    "ömsintheten": "ömsinthet",
    "ömsinthetens": "ömsinthet",
    "ömsinthets": "ömsinthet",
    "ömsints": "ömsint",
    "ömt": "öm",
    "ömts": "öm",
    "ömtåliga": "ömtålig",
    "ömtåligare": "ömtålig",
    "ömtåligares": "ömtålig",
    "ömtåligas": "ömtålig",
    "ömtåligast": "ömtålig",
    "ömtåligaste": "ömtålig",
    "ömtåligastes": "ömtålig",
    "ömtåligasts": "ömtålig",
    "ömtålige": "ömtålig",
    "ömtåliges": "ömtålig",
    "ömtåligheten": "ömtålighet",
    "ömtålighetens": "ömtålighet",
    "ömtåligheter": "ömtålighet",
    "ömtåligheterna": "ömtålighet",
    "ömtåligheternas": "ömtålighet",
    "ömtåligheters": "ömtålighet",
    "ömtålighets": "ömtålighet",
    "ömtåligs": "ömtålig",
    "ömtåligt": "ömtålig",
    "ömtåligts": "ömtålig",
    "ön": "ö",
    "öns": "ö",
    "önsk": "önska",
    "önskad": "önska",
    "önskade": "önska",
    "önskades": "önska",
    "önskads": "önska",
    "önskande": "önska",
    "önskanden": "önskande",
    "önskandena": "önskande",
    "önskandenas": "önskande",
    "önskandens": "önskande",
    "önskandes": "önskande",
    "önskandet": "önskande",
    "önskandets": "önskande",
    "önskans": "önskan",
    "önskar": "önska",
    "önskas": "önska",
    "önskat": "önska",
    "önskats": "önska",
    "önske": "önska",
    "önskebarnen": "önskebarn",
    "önskebarnens": "önskebarn",
    "önskebarnet": "önskebarn",
    "önskebarnets": "önskebarn",
    "önskebarns": "önskebarn",
    "önskedrömmar": "önskedröm",
    "önskedrömmarna": "önskedröm",
    "önskedrömmarnas": "önskedröm",
    "önskedrömmars": "önskedröm",
    "önskedrömmen": "önskedröm",
    "önskedrömmens": "önskedröm",
    "önskedröms": "önskedröm",
    "önskelistan": "önskelista",
    "önskelistans": "önskelista",
    "önskelistas": "önskelista",
    "önskeliste": "önskelista",
    "önskelistor": "önskelista",
    "önskelistorna": "önskelista",
    "önskelistornas": "önskelista",
    "önskelistors": "önskelista",
    "önskemålen": "önskemål",
    "önskemålens": "önskemål",
    "önskemålet": "önskemål",
    "önskemålets": "önskemål",
    "önskemåls": "önskemål",
    "önskeringar": "önskering",
    "önskeringarna": "önskering",
    "önskeringarnas": "önskering",
    "önskeringars": "önskering",
    "önskeringen": "önskering",
    "önskeringens": "önskering",
    "önskerings": "önskering",
    "önskerollen": "önskeroll",
    "önskerollens": "önskeroll",
    "önskeroller": "önskeroll",
    "önskerollerna": "önskeroll",
    "önskerollernas": "önskeroll",
    "önskerollers": "önskeroll",
    "önskerolls": "önskeroll",
    "önskesatsen": "önskesats",
    "önskesatsens": "önskesats",
    "önskesatser": "önskesats",
    "önskesatserna": "önskesats",
    "önskesatsernas": "önskesats",
    "önskesatsers": "önskesats",
    "önsketänkandes": "önsketänkande",
    "önsketänkandet": "önsketänkande",
    "önsketänkandets": "önsketänkande",
    "önskliga": "önsklig",
    "önskligare": "önsklig",
    "önskligares": "önsklig",
    "önskligas": "önsklig",
    "önskligast": "önsklig",
    "önskligaste": "önsklig",
    "önskligastes": "önsklig",
    "önskligasts": "önsklig",
    "önsklige": "önsklig",
    "önskliges": "önsklig",
    "önskligheten": "önsklighet",
    "önsklighetens": "önsklighet",
    "önsklighets": "önsklighet",
    "önskligs": "önsklig",
    "önskligt": "önsklig",
    "önskligts": "önsklig",
    "önskningar": "önskning",
    "önskningarna": "önskning",
    "önskningarnas": "önskning",
    "önskningars": "önskning",
    "önskningen": "önskning",
    "önskningens": "önskning",
    "önsknings": "önskning",
    "önskvärda": "önskvärd",
    "önskvärdare": "önskvärd",
    "önskvärdares": "önskvärd",
    "önskvärdas": "önskvärd",
    "önskvärdast": "önskvärd",
    "önskvärdaste": "önskvärd",
    "önskvärdastes": "önskvärd",
    "önskvärdasts": "önskvärd",
    "önskvärde": "önskvärd",
    "önskvärdes": "önskvärd",
    "önskvärdheten": "önskvärdhet",
    "önskvärdhetens": "önskvärdhet",
    "önskvärdhets": "önskvärdhet",
    "önskvärds": "önskvärd",
    "önskvärt": "önskvärd",
    "önskvärts": "önskvärd",
    "öppenheten": "öppenhet",
    "öppenhetens": "öppenhet",
    "öppenheter": "öppenhet",
    "öppenheterna": "öppenhet",
    "öppenheternas": "öppenhet",
    "öppenheters": "öppenhet",
    "öppenhets": "öppenhet",
    "öppenhjärtiga": "öppenhjärtig",
    "öppenhjärtigare": "öppenhjärtig",
    "öppenhjärtigares": "öppenhjärtig",
    "öppenhjärtigas": "öppenhjärtig",
    "öppenhjärtigast": "öppenhjärtig",
    "öppenhjärtigaste": "öppenhjärtig",
    "öppenhjärtigastes": "öppenhjärtig",
    "öppenhjärtigasts": "öppenhjärtig",
    "öppenhjärtige": "öppenhjärtig",
    "öppenhjärtiges": "öppenhjärtig",
    "öppenhjärtigheten": "öppenhjärtighet",
    "öppenhjärtighetens": "öppenhjärtighet",
    "öppenhjärtighets": "öppenhjärtighet",
    "öppenhjärtigs": "öppenhjärtig",
    "öppenhjärtigt": "öppenhjärtig",
    "öppenhjärtigts": "öppenhjärtig",
    "öppenhjärtliga": "öppenhjärtlig",
    "öppenhjärtligare": "öppenhjärtlig",
    "öppenhjärtligares": "öppenhjärtlig",
    "öppenhjärtligas": "öppenhjärtlig",
    "öppenhjärtligast": "öppenhjärtlig",
    "öppenhjärtligaste": "öppenhjärtlig",
    "öppenhjärtligastes": "öppenhjärtlig",
    "öppenhjärtligasts": "öppenhjärtlig",
    "öppenhjärtlige": "öppenhjärtlig",
    "öppenhjärtliges": "öppenhjärtlig",
    "öppenhjärtligheten": "öppenhjärtlighet",
    "öppenhjärtlighetens": "öppenhjärtlighet",
    "öppenhjärtlighets": "öppenhjärtlighet",
    "öppenhjärtligs": "öppenhjärtlig",
    "öppenhjärtligt": "öppenhjärtlig",
    "öppenhjärtligts": "öppenhjärtlig",
    "öppens": "öppen",
    "öppenvården": "öppenvård",
    "öppenvårdens": "öppenvård",
    "öppenvårds": "öppenvård",
    "öppet": "öppen",
    "öppethållandes": "öppethållande",
    "öppethållandet": "öppethållande",
    "öppethållandets": "öppethållande",
    "öppets": "öppen",
    "öppettiden": "öppettid",
    "öppettidens": "öppettid",
    "öppettider": "öppettid",
    "öppettiderna": "öppettid",
    "öppettidernas": "öppettid",
    "öppettiders": "öppettid",
    "öppettids": "öppettid",
    "öppna": "öppen",
    "öppnad": "öppna",
    "öppnade": "öppna",
    "öppnades": "öppna",
    "öppnads": "öppna",
    "öppnaknappar": "öppnaknapp",
    "öppnaknapparna": "öppnaknapp",
    "öppnaknapparnas": "öppnaknapp",
    "öppnaknappars": "öppnaknapp",
    "öppnaknappen": "öppnaknapp",
    "öppnaknappens": "öppnaknapp",
    "öppnaknapps": "öppnaknapp",
    "öppnande": "öppna",
    "öppnanden": "öppnande",
    "öppnandena": "öppnande",
    "öppnandenas": "öppnande",
    "öppnandens": "öppnande",
    "öppnandes": "öppnande",
    "öppnandet": "öppnande",
    "öppnandets": "öppnande",
    "öppnar": "öppnare",
    "öppnare": "öppen",
    "öppnaren": "öppnare",
    "öppnarens": "öppnare",
    "öppnares": "öppnare",
    "öppnarna": "öppnare",
    "öppnarnas": "öppnare",
    "öppnas": "öppna",
    "öppnast": "öppen",
    "öppnaste": "öppen",
    "öppnastes": "öppen",
    "öppnasts": "öppen",
    "öppnat": "öppna",
    "öppnats": "öppna",
    "öppne": "öppen",
    "öppnes": "öppen",
    "öppningar": "öppning",
    "öppningarna": "öppning",
    "öppningarnas": "öppning",
    "öppningars": "öppning",
    "öppningen": "öppning",
    "öppningens": "öppning",
    "öppnings": "öppning",
    "öppningsbuden": "öppningsbud",
    "öppningsbudens": "öppningsbud",
    "öppningsbudet": "öppningsbud",
    "öppningsbudets": "öppningsbud",
    "öppningsbuds": "öppningsbud",
    "öppningsceremonien": "öppningsceremoni",
    "öppningsceremoniens": "öppningsceremoni",
    "öppningsceremonier": "öppningsceremoni",
    "öppningsceremonierna": "öppningsceremoni",
    "öppningsceremoniernas": "öppningsceremoni",
    "öppningsceremoniers": "öppningsceremoni",
    "öppningsceremonin": "öppningsceremoni",
    "öppningsceremonins": "öppningsceremoni",
    "öppningsceremonis": "öppningsceremoni",
    "öras": "öra",
    "örat": "öra",
    "örats": "öra",
    "örclipsen": "örclips",
    "örclipsens": "örclips",
    "örclipset": "örclips",
    "örclipsets": "örclips",
    "örel": "örla",
    "ören": "öre",
    "örena": "öre",
    "örenas": "öre",
    "örens": "öre",
    "öres": "öre",
    "öret": "öre",
    "örets": "öre",
    "örfil": "örfila",
    "örfilad": "örfila",
    "örfilade": "örfila",
    "örfilades": "örfila",
    "örfilads": "örfila",
    "örfilande": "örfila",
    "örfilanden": "örfilande",
    "örfilandena": "örfilande",
    "örfilandenas": "örfilande",
    "örfilandens": "örfilande",
    "örfilandes": "örfilande",
    "örfilandet": "örfilande",
    "örfilandets": "örfilande",
    "örfilar": "örfila",
    "örfilarna": "örfil",
    "örfilarnas": "örfil",
    "örfilars": "örfil",
    "örfilas": "örfila",
    "örfilat": "örfila",
    "örfilats": "örfila",
    "örfilen": "örfil",
    "örfilens": "örfil",
    "örfils": "örfil",
    "örfilsdomar": "örfilsdom",
    "örfilsdomarna": "örfilsdom",
    "örfilsdomarnas": "örfilsdom",
    "örfilsdomars": "örfilsdom",
    "örfilsdomen": "örfilsdom",
    "örfilsdomens": "örfilsdom",
    "örfilsdoms": "örfilsdom",
    "örflikar": "örflik",
    "örflikarna": "örflik",
    "örflikarnas": "örflik",
    "örflikars": "örflik",
    "örfliken": "örflik",
    "örflikens": "örflik",
    "örfliks": "örflik",
    "örhängen": "örhänge",
    "örhängena": "örhänge",
    "örhängenas": "örhänge",
    "örhängens": "örhänge",
    "örhänges": "örhänge",
    "örhänget": "örhänge",
    "örhängets": "örhänge",
    "örhängs": "örhänge",
    "öriken": "örike",
    "örikena": "örike",
    "örikenas": "örike",
    "örikens": "örike",
    "örikes": "örike",
    "öriket": "örike",
    "örikets": "örike",
    "öringar": "öring",
    "öringarna": "öring",
    "öringarnas": "öring",
    "öringars": "öring",
    "öringen": "öring",
    "öringens": "öring",
    "örings": "öring",
    "örlade": "örla",
    "örlades": "örla",
    "örlande": "örla",
    "örlanden": "örlande",
    "örlandena": "örlande",
    "örlandenas": "örlande",
    "örlandens": "örlande",
    "örlandes": "örlande",
    "örlandet": "örlande",
    "örlandets": "örlande",
    "örlar": "örla",
    "örlas": "örla",
    "örlat": "örla",
    "örlats": "örla",
    "örligen": "örlig",
    "örligens": "örlig",
    "örliget": "örlig",
    "örligets": "örlig",
    "örligs": "örlig",
    "örlogen": "örlog",
    "örlogens": "örlog",
    "örloget": "örlog",
    "örlogets": "örlog",
    "örlogs": "örlog",
    "örlogsbasen": "örlogsbas",
    "örlogsbasens": "örlogsbas",
    "örlogsbaser": "örlogsbas",
    "örlogsbaserna": "örlogsbas",
    "örlogsbasernas": "örlogsbas",
    "örlogsbasers": "örlogsbas",
    "örlogsfartygen": "örlogsfartyg",
    "örlogsfartygens": "örlogsfartyg",
    "örlogsfartyget": "örlogsfartyg",
    "örlogsfartygets": "örlogsfartyg",
    "örlogsfartygs": "örlogsfartyg",
    "örlogsflagg": "örlogsflagga",
    "örlogsflaggan": "örlogsflagga",
    "örlogsflaggans": "örlogsflagga",
    "örlogsflaggas": "örlogsflagga",
    "örlogsflagge": "örlogsflagga",
    "örlogsflaggen": "örlogsflagg",
    "örlogsflaggens": "örlogsflagg",
    "örlogsflaggor": "örlogsflagga",
    "örlogsflaggorna": "örlogsflagga",
    "örlogsflaggornas": "örlogsflagga",
    "örlogsflaggors": "örlogsflagga",
    "örlogsflaggs": "örlogsflagga",
    "örlogsmannen": "örlogsman",
    "örlogsmannens": "örlogsman",
    "örlogsmans": "örlogsman",
    "örlogsmatrosen": "örlogsmatros",
    "örlogsmatrosens": "örlogsmatros",
    "örlogsmatroser": "örlogsmatros",
    "örlogsmatroserna": "örlogsmatros",
    "örlogsmatrosernas": "örlogsmatros",
    "örlogsmatrosers": "örlogsmatros",
    "örlogsmän": "örlogsman",
    "örlogsmännen": "örlogsman",
    "örlogsmännens": "örlogsman",
    "örlogsmäns": "örlogsman",
    "örlogsvarven": "örlogsvarv",
    "örlogsvarvens": "örlogsvarv",
    "örlogsvarvet": "örlogsvarv",
    "örlogsvarvets": "örlogsvarv",
    "örlogsvarvs": "örlogsvarv",
    "örmag": "örmage",
    "örmagar": "örmage",
    "örmagarna": "örmage",
    "örmagarnas": "örmage",
    "örmagars": "örmage",
    "örmagen": "örmage",
    "örmagens": "örmage",
    "örmages": "örmage",
    "örmags": "örmage",
    "örnar": "örn",
    "örnarna": "örn",
    "örnarnas": "örn",
    "örnars": "örn",
    "örnbräkens": "örnbräken",
    "örnbräknar": "örnbräken",
    "örnbräknarna": "örnbräken",
    "örnbräknarnas": "örnbräken",
    "örnbräknars": "örnbräken",
    "örnbräknen": "örnbräkne",
    "örnbräknens": "örnbräkne",
    "örnbräknes": "örnbräkne",
    "örnen": "örn",
    "örnens": "örn",
    "örngotten": "örngott",
    "örngottens": "örngott",
    "örngottet": "örngott",
    "örngottets": "örngott",
    "örngotts": "örngott",
    "örngottsbanden": "örngottsband",
    "örngottsbandens": "örngottsband",
    "örngottsbandet": "örngottsband",
    "örngottsbandets": "örngottsband",
    "örngottsbands": "örngottsband",
    "örngottsbandskrusar": "örngottsbandskrusare",
    "örngottsbandskrusaren": "örngottsbandskrusare",
    "örngottsbandskrusarens": "örngottsbandskrusare",
    "örngottsbandskrusares": "örngottsbandskrusare",
    "örngottsbandskrusarna": "örngottsbandskrusare",
    "örngottsbandskrusarnas": "örngottsbandskrusare",
    "örnkollen": "örnkoll",
    "örnkollens": "örnkoll",
    "örnkolls": "örnkoll",
    "örnnäs": "örnnäsa",
    "örnnäsan": "örnnäsa",
    "örnnäsans": "örnnäsa",
    "örnnäsas": "örnnäsa",
    "örnnäse": "örnnäsa",
    "örnnäsor": "örnnäsa",
    "örnnäsorna": "örnnäsa",
    "örnnäsornas": "örnnäsa",
    "örnnäsors": "örnnäsa",
    "örns": "örn",
    "öron": "öra",
    "öronen": "öra",
    "öronens": "öra",
    "öroninflammationen": "öroninflammation",
    "öroninflammationens": "öroninflammation",
    "öroninflammationer": "öroninflammation",
    "öroninflammationerna": "öroninflammation",
    "öroninflammationernas": "öroninflammation",
    "öroninflammationers": "öroninflammation",
    "öroninflammations": "öroninflammation",
    "öronlappsfåtöljen": "öronlappsfåtölj",
    "öronlappsfåtöljens": "öronlappsfåtölj",
    "öronlappsfåtöljer": "öronlappsfåtölj",
    "öronlappsfåtöljerna": "öronlappsfåtölj",
    "öronlappsfåtöljernas": "öronlappsfåtölj",
    "öronlappsfåtöljers": "öronlappsfåtölj",
    "öronlappsfåtöljs": "öronlappsfåtölj",
    "öronmussel": "öronmussla",
    "öronmusslan": "öronmussla",
    "öronmusslans": "öronmussla",
    "öronmusslas": "öronmussla",
    "öronmussle": "öronmussla",
    "öronmusslor": "öronmussla",
    "öronmusslorna": "öronmussla",
    "öronmusslornas": "öronmussla",
    "öronmusslors": "öronmussla",
    "öronmärk": "öronmärka",
    "öronmärkande": "öronmärka",
    "öronmärkanden": "öronmärkande",
    "öronmärkandena": "öronmärkande",
    "öronmärkandenas": "öronmärkande",
    "öronmärkandens": "öronmärkande",
    "öronmärkandes": "öronmärkande",
    "öronmärkandet": "öronmärkande",
    "öronmärkandets": "öronmärkande",
    "öronmärkas": "öronmärka",
    "öronmärker": "öronmärka",
    "öronmärkes": "öronmärka",
    "öronmärks": "öronmärka",
    "öronmärkt": "öronmärka",
    "öronmärkta": "öronmärka",
    "öronmärktas": "öronmärka",
    "öronmärkte": "öronmärka",
    "öronmärktes": "öronmärka",
    "öronmärkts": "öronmärka",
    "öronoperationen": "öronoperation",
    "öronoperationens": "öronoperation",
    "öronoperationer": "öronoperation",
    "öronoperationerna": "öronoperation",
    "öronoperationernas": "öronoperation",
    "öronoperationers": "öronoperation",
    "öronoperations": "öronoperation",
    "öronproppar": "öronpropp",
    "öronpropparna": "öronpropp",
    "öronpropparnas": "öronpropp",
    "öronproppars": "öronpropp",
    "öronproppen": "öronpropp",
    "öronproppens": "öronpropp",
    "öronpropps": "öronpropp",
    "örons": "öra",
    "öronsnibbar": "öronsnibb",
    "öronsnibbarna": "öronsnibb",
    "öronsnibbarnas": "öronsnibb",
    "öronsnibbars": "öronsnibb",
    "öronsnibben": "öronsnibb",
    "öronsnibbens": "öronsnibb",
    "öronsnibbs": "öronsnibb",
    "öronsnäck": "öronsnäcka",
    "öronsnäckan": "öronsnäcka",
    "öronsnäckans": "öronsnäcka",
    "öronsnäckas": "öronsnäcka",
    "öronsnäcke": "öronsnäcka",
    "öronsnäckor": "öronsnäcka",
    "öronsnäckorna": "öronsnäcka",
    "öronsnäckornas": "öronsnäcka",
    "öronsnäckors": "öronsnäcka",
    "öronsnäcks": "öronsnäcka",
    "öronsusningar": "öronsusning",
    "öronsusningarna": "öronsusning",
    "öronsusningarnas": "öronsusning",
    "öronsusningars": "öronsusning",
    "öronsusningen": "öronsusning",
    "öronsusningens": "öronsusning",
    "öronsusnings": "öronsusning",
    "örontasslar": "örontasslare",
    "örontasslaren": "örontasslare",
    "örontasslarens": "örontasslare",
    "örontasslares": "örontasslare",
    "örontasslarna": "örontasslare",
    "örontasslarnas": "örontasslare",
    "örontrumpeten": "örontrumpet",
    "örontrumpetens": "örontrumpet",
    "örontrumpeter": "örontrumpet",
    "örontrumpeterna": "örontrumpet",
    "örontrumpeternas": "örontrumpet",
    "örontrumpeters": "örontrumpet",
    "örontrumpets": "örontrumpet",
    "öronvaxet": "öronvax",
    "öronvaxets": "öronvax",
    "örrågen": "örråg",
    "örrågens": "örråg",
    "örrågs": "örråg",
    "örs": "ör",
    "örsnibbar": "örsnibb",
    "örsnibbarna": "örsnibb",
    "örsnibbarnas": "örsnibb",
    "örsnibbars": "örsnibb",
    "örsnibben": "örsnibb",
    "örsnibbens": "örsnibb",
    "örsnibbs": "örsnibb",
    "örsprånget": "örsprång",
    "örsprångets": "örsprång",
    "örsprångs": "örsprång",
    "örtagårdar": "örtagård",
    "örtagårdarna": "örtagård",
    "örtagårdarnas": "örtagård",
    "örtagårdars": "örtagård",
    "örtagården": "örtagård",
    "örtagårdens": "örtagård",
    "örtagårds": "örtagård",
    "örten": "ört",
    "örtens": "ört",
    "örter": "ört",
    "örterna": "ört",
    "örternas": "ört",
    "örters": "ört",
    "örtesängar": "örtesäng",
    "örtesängarna": "örtesäng",
    "örtesängarnas": "örtesäng",
    "örtesängars": "örtesäng",
    "örtesängen": "örtesäng",
    "örtesängens": "örtesäng",
    "örtesängs": "örtesäng",
    "örtkrydd": "örtkrydda",
    "örtkryddan": "örtkrydda",
    "örtkryddans": "örtkrydda",
    "örtkryddas": "örtkrydda",
    "örtkrydde": "örtkrydda",
    "örtkryddor": "örtkrydda",
    "örtkryddorna": "örtkrydda",
    "örtkryddornas": "örtkrydda",
    "örtkryddors": "örtkrydda",
    "örtkrydds": "örtkrydda",
    "örts": "ört",
    "örtsängar": "örtsäng",
    "örtsängarna": "örtsäng",
    "örtsängarnas": "örtsäng",
    "örtsängars": "örtsäng",
    "örtsängen": "örtsäng",
    "örtsängens": "örtsäng",
    "örtsängs": "örtsäng",
    "örtteet": "örtte",
    "örtteets": "örtte",
    "örttes": "örtte",
    "örttet": "örtte",
    "örttets": "örtte",
    "örtugar": "örtug",
    "örtugarna": "örtug",
    "örtugarnas": "örtug",
    "örtugars": "örtug",
    "örtugen": "örtug",
    "örtugens": "örtug",
    "örtugs": "örtug",
    "ös": "ösa",
    "ösande": "ösa",
    "ösanden": "ösande",
    "ösandena": "ösande",
    "ösandenas": "ösande",
    "ösandens": "ösande",
    "ösandes": "ösande",
    "ösandet": "ösande",
    "ösandets": "ösande",
    "ösas": "ösa",
    "öser": "ösa",
    "öses": "ösa",
    "öset": "ös",
    "ösets": "ös",
    "öskaren": "öskar",
    "öskarens": "öskar",
    "öskaret": "öskar",
    "öskarets": "öskar",
    "öskars": "öskar",
    "ösregn": "ösregna",
    "ösregnad": "ösregna",
    "ösregnade": "ösregna",
    "ösregnades": "ösregna",
    "ösregnads": "ösregna",
    "ösregnande": "ösregna",
    "ösregnanden": "ösregnande",
    "ösregnandena": "ösregnande",
    "ösregnandenas": "ösregnande",
    "ösregnandens": "ösregnande",
    "ösregnandes": "ösregnande",
    "ösregnandet": "ösregnande",
    "ösregnandets": "ösregnande",
    "ösregnar": "ösregna",
    "ösregnas": "ösregna",
    "ösregnat": "ösregna",
    "ösregnats": "ösregna",
    "ösregnen": "ösregn",
    "ösregnens": "ösregn",
    "ösregnet": "ösregn",
    "ösregnets": "ösregn",
    "ösregns": "ösregn",
    "öst": "ösa",
    "öst-västliga": "öst-västlig",
    "öst-västligare": "öst-västlig",
    "öst-västligares": "öst-västlig",
    "öst-västligas": "öst-västlig",
    "öst-västligast": "öst-västlig",
    "öst-västligaste": "öst-västlig",
    "öst-västligastes": "öst-västlig",
    "öst-västligasts": "öst-västlig",
    "öst-västlige": "öst-västlig",
    "öst-västliges": "öst-västlig",
    "öst-västligs": "öst-västlig",
    "öst-västligt": "öst-västlig",
    "öst-västligts": "öst-västlig",
    "östa": "ösa",
    "östans": "östan",
    "östanvinden": "östanvind",
    "östanvindens": "östanvind",
    "östanvinds": "östanvind",
    "östas": "ösa",
    "östasiaten": "östasiat",
    "östasiatens": "östasiat",
    "östasiater": "östasiat",
    "östasiaterna": "östasiat",
    "östasiaternas": "östasiat",
    "östasiaters": "östasiat",
    "östasiats": "östasiat",
    "östblocket": "östblock",
    "östblockets": "östblock",
    "östblocks": "östblock",
    "öste": "ösa",
    "österbottningar": "österbottning",
    "österbottningarna": "österbottning",
    "österbottningarnas": "österbottning",
    "österbottningars": "österbottning",
    "österbottningen": "österbottning",
    "österbottningens": "österbottning",
    "österbottnings": "österbottning",
    "österbottniska": "österbottnisk",
    "österbottniskare": "österbottnisk",
    "österbottniskares": "österbottnisk",
    "österbottniskas": "österbottnisk",
    "österbottniskast": "österbottnisk",
    "österbottniskaste": "österbottnisk",
    "österbottniskastes": "österbottnisk",
    "österbottniskasts": "österbottnisk",
    "österbottniske": "österbottnisk",
    "österbottniskes": "österbottnisk",
    "österbottnisks": "österbottnisk",
    "österbottniskt": "österbottnisk",
    "österbottniskts": "österbottnisk",
    "östergöken": "östergök",
    "östergökens": "östergök",
    "östergöks": "östergök",
    "österlandet": "österland",
    "österlandets": "österland",
    "österlands": "österland",
    "österländska": "österländsk",
    "österländskare": "österländsk",
    "österländskares": "österländsk",
    "österländskas": "österländsk",
    "österländskast": "österländsk",
    "österländskaste": "österländsk",
    "österländskastes": "österländsk",
    "österländskasts": "österländsk",
    "österländske": "österländsk",
    "österländskes": "österländsk",
    "österländsks": "österländsk",
    "österländskt": "österländsk",
    "österländskts": "österländsk",
    "österlänningar": "österlänning",
    "österlänningarna": "österlänning",
    "österlänningarnas": "österlänning",
    "österlänningars": "österlänning",
    "österlänningen": "österlänning",
    "österlänningens": "österlänning",
    "österlännings": "österlänning",
    "östern": "öster",
    "österns": "öster",
    "österrikar": "österrikare",
    "österrikaren": "österrikare",
    "österrikarens": "österrikare",
    "österrikares": "österrikare",
    "österrikarna": "österrikare",
    "österrikarnas": "österrikare",
    "österrikiska": "österrikisk",
    "österrikiskare": "österrikisk",
    "österrikiskares": "österrikisk",
    "österrikiskas": "österrikisk",
    "österrikiskast": "österrikisk",
    "österrikiskaste": "österrikisk",
    "österrikiskastes": "österrikisk",
    "österrikiskasts": "österrikisk",
    "österrikiske": "österrikisk",
    "österrikiskes": "österrikisk",
    "österrikisks": "österrikisk",
    "österrikiskt": "österrikisk",
    "österrikiskts": "österrikisk",
    "östers": "öster",
    "östersjöfiskar": "östersjöfisk",
    "östersjöfiskarna": "östersjöfisk",
    "östersjöfiskarnas": "östersjöfisk",
    "östersjöfiskars": "östersjöfisk",
    "östersjöfisken": "östersjöfisk",
    "östersjöfiskens": "östersjöfisk",
    "östersjöfiskes": "östersjöfiske",
    "östersjöfisket": "östersjöfiske",
    "östersjöfiskets": "östersjöfiske",
    "östersjöfisks": "östersjöfisk",
    "östes": "ösa",
    "östeuropeiska": "östeuropeisk",
    "östeuropeiskare": "östeuropeisk",
    "östeuropeiskares": "östeuropeisk",
    "östeuropeiskas": "östeuropeisk",
    "östeuropeiskast": "östeuropeisk",
    "östeuropeiskaste": "östeuropeisk",
    "östeuropeiskastes": "östeuropeisk",
    "östeuropeiskasts": "östeuropeisk",
    "östeuropeiske": "östeuropeisk",
    "östeuropeiskes": "östeuropeisk",
    "östeuropeisks": "östeuropeisk",
    "östeuropeiskt": "östeuropeisk",
    "östeuropeiskts": "östeuropeisk",
    "östgoten": "östgot",
    "östgotens": "östgot",
    "östgoter": "östgot",
    "östgoterna": "östgot",
    "östgoternas": "östgot",
    "östgoters": "östgot",
    "östgotisk": "östgotiska",
    "östgotiska": "östgotisk",
    "östgotiskan": "östgotiska",
    "östgotiskans": "östgotiska",
    "östgotiskare": "östgotisk",
    "östgotiskares": "östgotisk",
    "östgotiskas": "östgotiska",
    "östgotiskast": "östgotisk",
    "östgotiskaste": "östgotisk",
    "östgotiskastes": "östgotisk",
    "östgotiskasts": "östgotisk",
    "östgotiske": "östgotisk",
    "östgotiskes": "östgotisk",
    "östgotisks": "östgotisk",
    "östgotiskt": "östgotisk",
    "östgotiskts": "östgotisk",
    "östgots": "östgot",
    "östgöt": "östgöte",
    "östgötar": "östgöte",
    "östgötarna": "östgöte",
    "östgötarnas": "östgöte",
    "östgötars": "östgöte",
    "östgöten": "östgöte",
    "östgötens": "östgöte",
    "östgötes": "östgöte",
    "östgöts": "östgöte",
    "östgötsk": "östgötska",
    "östgötska": "östgötsk",
    "östgötskan": "östgötska",
    "östgötskans": "östgötska",
    "östgötskare": "östgötsk",
    "östgötskares": "östgötsk",
    "östgötskas": "östgötska",
    "östgötskast": "östgötsk",
    "östgötskaste": "östgötsk",
    "östgötskastes": "östgötsk",
    "östgötskasts": "östgötsk",
    "östgötske": "östgötska",
    "östgötskes": "östgötsk",
    "östgötskor": "östgötska",
    "östgötskorna": "östgötska",
    "östgötskornas": "östgötska",
    "östgötskors": "östgötska",
    "östgötsks": "östgötsk",
    "östgötskt": "östgötsk",
    "östgötskts": "östgötsk",
    "östkanten": "östkant",
    "östkantens": "östkant",
    "östkanter": "östkant",
    "östkanterna": "östkant",
    "östkanternas": "östkant",
    "östkanters": "östkant",
    "östkants": "östkant",
    "östkusten": "östkust",
    "östkustens": "östkust",
    "östkuster": "östkust",
    "östkusterna": "östkust",
    "östkusternas": "östkust",
    "östkusters": "östkust",
    "östkustmiljöer": "östkustmiljö",
    "östkustmiljöerna": "östkustmiljö",
    "östkustmiljöernas": "östkustmiljö",
    "östkustmiljöers": "östkustmiljö",
    "östkustmiljön": "östkustmiljö",
    "östkustmiljöns": "östkustmiljö",
    "östkustmiljös": "östkustmiljö",
    "östkusts": "östkust",
    "östliga": "östlig",
    "östligare": "östlig",
    "östligares": "östlig",
    "östligas": "östlig",
    "östligast": "östlig",
    "östligaste": "östlig",
    "östligastes": "östlig",
    "östligasts": "östlig",
    "östlige": "östlig",
    "östliges": "östlig",
    "östligs": "östlig",
    "östligt": "östlig",
    "östligts": "östlig",
    "östrogener": "östrogen",
    "östrogenerna": "östrogen",
    "östrogenernas": "östrogen",
    "östrogeners": "östrogen",
    "östrogenet": "östrogen",
    "östrogenets": "östrogen",
    "östrogens": "östrogen",
    "östronet": "östron",
    "östronets": "östron",
    "östrons": "östron",
    "östs": "öst",
    "öststaten": "öststat",
    "öststatens": "öststat",
    "öststater": "öststat",
    "öststaterna": "öststat",
    "öststaternas": "öststat",
    "öststaters": "öststat",
    "öststats": "öststat",
    "öststatsförtrycken": "öststatsförtryck",
    "öststatsförtryckens": "öststatsförtryck",
    "öststatsförtrycket": "öststatsförtryck",
    "öststatsförtryckets": "öststatsförtryck",
    "öststatsförtrycks": "öststatsförtryck",
    "öststatsledar": "öststatsledare",
    "öststatsledaren": "öststatsledare",
    "öststatsledarens": "öststatsledare",
    "öststatsledares": "öststatsledare",
    "öststatsledarna": "öststatsledare",
    "öststatsledarnas": "öststatsledare",
    "östtyska": "östtysk",
    "östtyskar": "östtysk",
    "östtyskare": "östtysk",
    "östtyskares": "östtysk",
    "östtyskarna": "östtysk",
    "östtyskarnas": "östtysk",
    "östtyskars": "östtysk",
    "östtyskas": "östtysk",
    "östtyskast": "östtysk",
    "östtyskaste": "östtysk",
    "östtyskastes": "östtysk",
    "östtyskasts": "östtysk",
    "östtyske": "östtysk",
    "östtysken": "östtysk",
    "östtyskens": "östtysk",
    "östtyskes": "östtysk",
    "östtysks": "östtysk",
    "östtyskt": "östtysk",
    "östtyskts": "östtysk",
    "ött": "öda",
    "ötts": "öda",
    "öv": "öva",
    "övad": "öva",
    "övade": "öva",
    "övades": "öva",
    "övads": "öva",
    "övande": "öva",
    "övanden": "övande",
    "övandena": "övande",
    "övandenas": "övande",
    "övandens": "övande",
    "övandes": "övande",
    "övandet": "övande",
    "övandets": "övande",
    "övar": "öva",
    "övas": "öva",
    "övat": "öva",
    "övats": "öva",
    "överaktiva": "överaktiv",
    "överaktivare": "överaktiv",
    "överaktivares": "överaktiv",
    "överaktivas": "överaktiv",
    "överaktivast": "överaktiv",
    "överaktivaste": "överaktiv",
    "överaktivastes": "överaktiv",
    "överaktivasts": "överaktiv",
    "överaktive": "överaktiv",
    "överaktives": "överaktiv",
    "överaktiviteten": "överaktivitet",
    "överaktivitetens": "överaktivitet",
    "överaktivitets": "överaktivitet",
    "överaktivs": "överaktiv",
    "överaktivt": "överaktiv",
    "överaktivts": "överaktiv",
    "överambitiösa": "överambitiös",
    "överambitiösare": "överambitiös",
    "överambitiösares": "överambitiös",
    "överambitiösas": "överambitiös",
    "överambitiösast": "överambitiös",
    "överambitiösaste": "överambitiös",
    "överambitiösastes": "överambitiös",
    "överambitiösasts": "överambitiös",
    "överambitiöse": "överambitiös",
    "överambitiöses": "överambitiös",
    "överambitiöst": "överambitiös",
    "överambitiösts": "överambitiös",
    "överansträng": "överanstränga",
    "överansträngande": "överanstränga",
    "överanstränganden": "överansträngande",
    "överansträngandena": "överansträngande",
    "överansträngandenas": "överansträngande",
    "överansträngandens": "överansträngande",
    "överansträngandes": "överansträngande",
    "överansträngandet": "överansträngande",
    "överansträngandets": "överansträngande",
    "överansträngas": "överanstränga",
    "överansträngd": "överanstränga",
    "överansträngda": "överanstränga",
    "överansträngdas": "överanstränga",
    "överansträngde": "överanstränga",
    "överansträngdes": "överanstränga",
    "överansträngds": "överanstränga",
    "överanstränger": "överanstränga",
    "överanstränges": "överanstränga",
    "överansträngningar": "överansträngning",
    "överansträngningarna": "överansträngning",
    "överansträngningarnas": "överansträngning",
    "överansträngningars": "överansträngning",
    "överansträngningen": "överansträngning",
    "överansträngningens": "överansträngning",
    "överansträngnings": "överansträngning",
    "överansträngs": "överanstränga",
    "överansträngt": "överanstränga",
    "överansträngts": "överanstränga",
    "överantvard": "överantvarda",
    "överantvardad": "överantvarda",
    "överantvardade": "överantvarda",
    "överantvardades": "överantvarda",
    "överantvardads": "överantvarda",
    "överantvardande": "överantvarda",
    "överantvardanden": "överantvardande",
    "överantvardandena": "överantvardande",
    "överantvardandenas": "överantvardande",
    "överantvardandens": "överantvardande",
    "överantvardandes": "överantvardande",
    "överantvardandet": "överantvardande",
    "överantvardandets": "överantvardande",
    "överantvardar": "överantvarda",
    "överantvardas": "överantvarda",
    "överantvardat": "överantvarda",
    "överantvardats": "överantvarda",
    "överanvänd": "överanvända",
    "överanvändande": "överanvända",
    "överanvändanden": "överanvändande",
    "överanvändandena": "överanvändande",
    "överanvändandenas": "överanvändande",
    "överanvändandens": "överanvändande",
    "överanvändandes": "överanvändande",
    "överanvändandet": "överanvändande",
    "överanvändandets": "överanvändande",
    "överanvändas": "överanvända",
    "överanvände": "överanvända",
    "överanvänder": "överanvända",
    "överanvändes": "överanvända",
    "överanvändningar": "överanvändning",
    "överanvändningarna": "överanvändning",
    "överanvändningarnas": "överanvändning",
    "överanvändningars": "överanvändning",
    "överanvändningen": "överanvändning",
    "överanvändningens": "överanvändning",
    "överanvändnings": "överanvändning",
    "överanvänds": "överanvända",
    "överanvänt": "överanvända",
    "överanvänts": "överanvända",
    "överarbet": "överarbeta",
    "överarbetad": "överarbeta",
    "överarbetade": "överarbeta",
    "överarbetades": "överarbeta",
    "överarbetads": "överarbeta",
    "överarbetande": "överarbeta",
    "överarbetanden": "överarbetande",
    "överarbetandena": "överarbetande",
    "överarbetandenas": "överarbetande",
    "överarbetandens": "överarbetande",
    "överarbetandes": "överarbetande",
    "överarbetandet": "överarbetande",
    "överarbetandets": "överarbetande",
    "överarbetar": "överarbeta",
    "överarbetas": "överarbeta",
    "överarbetat": "överarbeta",
    "överarbetats": "överarbeta",
    "överarmar": "överarm",
    "överarmarna": "överarm",
    "överarmarnas": "överarm",
    "överarmars": "överarm",
    "överarmen": "överarm",
    "överarmens": "överarm",
    "överarms": "överarm",
    "överarmsmuskeln": "överarmsmuskel",
    "överarmsmuskelns": "överarmsmuskel",
    "överarmsmuskels": "överarmsmuskel",
    "överarmsmuskler": "överarmsmuskel",
    "överarmsmusklerna": "överarmsmuskel",
    "överarmsmusklernas": "överarmsmuskel",
    "överarmsmusklers": "överarmsmuskel",
    "överbalanserade": "överbalanserad",
    "överbalanserades": "överbalanserad",
    "överbalanserads": "överbalanserad",
    "överbalanserat": "överbalanserad",
    "överbalanserats": "överbalanserad",
    "överbefolk": "överbefolka",
    "överbefolkad": "överbefolka",
    "överbefolkade": "överbefolkad",
    "överbefolkades": "överbefolkad",
    "överbefolkads": "överbefolkad",
    "överbefolkande": "överbefolka",
    "överbefolkanden": "överbefolkande",
    "överbefolkandena": "överbefolkande",
    "överbefolkandenas": "överbefolkande",
    "överbefolkandens": "överbefolkande",
    "överbefolkandes": "överbefolkande",
    "överbefolkandet": "överbefolkande",
    "överbefolkandets": "överbefolkande",
    "överbefolkar": "överbefolka",
    "överbefolkas": "överbefolka",
    "överbefolkat": "överbefolkad",
    "överbefolkats": "överbefolkad",
    "överbefolkningar": "överbefolkning",
    "överbefolkningarna": "överbefolkning",
    "överbefolkningarnas": "överbefolkning",
    "överbefolkningars": "överbefolkning",
    "överbefolkningen": "överbefolkning",
    "överbefolkningens": "överbefolkning",
    "överbefolknings": "överbefolkning",
    "överbefälhavar": "överbefälhavare",
    "överbefälhavaren": "överbefälhavare",
    "överbefälhavarens": "överbefälhavare",
    "överbefälhavares": "överbefälhavare",
    "överbefälhavarna": "överbefälhavare",
    "överbefälhavarnas": "överbefälhavare",
    "överbegreppen": "överbegrepp",
    "överbegreppens": "överbegrepp",
    "överbegreppet": "överbegrepp",
    "överbegreppets": "överbegrepp",
    "överbegrepps": "överbegrepp",
    "överbegåvade": "överbegåvad",
    "överbegåvades": "överbegåvad",
    "överbegåvads": "överbegåvad",
    "överbegåvat": "överbegåvad",
    "överbegåvats": "överbegåvad",
    "överbehandlingar": "överbehandling",
    "överbehandlingarna": "överbehandling",
    "överbehandlingarnas": "överbehandling",
    "överbehandlingars": "överbehandling",
    "överbehandlingen": "överbehandling",
    "överbehandlingens": "överbehandling",
    "överbehandlings": "överbehandling",
    "överbela": "överbelägga",
    "överbelade": "överbelägga",
    "överbelades": "överbelägga",
    "överbelagd": "överbelägga",
    "överbelagda": "överbelägga",
    "överbelagdas": "överbelägga",
    "överbelagde": "överbelägga",
    "överbelagdes": "överbelägga",
    "överbelagds": "överbelägga",
    "överbelagt": "överbelägga",
    "överbelagts": "överbelägga",
    "överbelas": "överbelägga",
    "överbelastade": "överbelastad",
    "överbelastades": "överbelastad",
    "överbelastads": "överbelastad",
    "överbelastat": "överbelastad",
    "överbelastats": "överbelastad",
    "överbelägg": "överbelägga",
    "överbeläggande": "överbelägga",
    "överbelägganden": "överbeläggande",
    "överbeläggandena": "överbeläggande",
    "överbeläggandenas": "överbeläggande",
    "överbeläggandens": "överbeläggande",
    "överbeläggandes": "överbeläggande",
    "överbeläggandet": "överbeläggande",
    "överbeläggandets": "överbeläggande",
    "överbeläggas": "överbelägga",
    "överbelägger": "överbelägga",
    "överbelägges": "överbelägga",
    "överbeläggningar": "överbeläggning",
    "överbeläggningarna": "överbeläggning",
    "överbeläggningarnas": "överbeläggning",
    "överbeläggningars": "överbeläggning",
    "överbeläggningen": "överbeläggning",
    "överbeläggningens": "överbeläggning",
    "överbeläggnings": "överbeläggning",
    "överbeläggs": "överbelägga",
    "överbeskydd": "överbeskydda",
    "överbeskyddad": "överbeskydda",
    "överbeskyddade": "överbeskydda",
    "överbeskyddades": "överbeskydda",
    "överbeskyddads": "överbeskydda",
    "överbeskyddande": "överbeskydda",
    "överbeskyddanden": "överbeskyddande",
    "överbeskyddandena": "överbeskyddande",
    "överbeskyddandenas": "överbeskyddande",
    "överbeskyddandens": "överbeskyddande",
    "överbeskyddandes": "överbeskyddande",
    "överbeskyddandet": "överbeskyddande",
    "överbeskyddandets": "överbeskyddande",
    "överbeskyddar": "överbeskydda",
    "överbeskyddas": "överbeskydda",
    "överbeskyddat": "överbeskydda",
    "överbeskyddats": "överbeskydda",
    "överbeton": "överbetona",
    "överbetonad": "överbetona",
    "överbetonade": "överbetona",
    "överbetonades": "överbetona",
    "överbetonads": "överbetona",
    "överbetonande": "överbetona",
    "överbetonanden": "överbetonande",
    "överbetonandena": "överbetonande",
    "överbetonandenas": "överbetonande",
    "överbetonandens": "överbetonande",
    "överbetonandes": "överbetonande",
    "överbetonandet": "överbetonande",
    "överbetonandets": "överbetonande",
    "överbetonar": "överbetona",
    "överbetonas": "överbetona",
    "överbetonat": "överbetona",
    "överbetonats": "överbetona",
    "överbettet": "överbett",
    "överbettets": "överbett",
    "överbetts": "överbett",
    "överbetygen": "överbetyg",
    "överbetygens": "överbetyg",
    "överbetyget": "överbetyg",
    "överbetygets": "överbetyg",
    "överbetygs": "överbetyg",
    "överbevis": "överbevisa",
    "överbevisad": "överbevisa",
    "överbevisade": "överbevisa",
    "överbevisades": "överbevisa",
    "överbevisads": "överbevisa",
    "överbevisande": "överbevisa",
    "överbevisanden": "överbevisande",
    "överbevisandena": "överbevisande",
    "överbevisandenas": "överbevisande",
    "överbevisandens": "överbevisande",
    "överbevisandes": "överbevisande",
    "överbevisandet": "överbevisande",
    "överbevisandets": "överbevisande",
    "överbevisar": "överbevisa",
    "överbevisas": "överbevisa",
    "överbevisat": "överbevisa",
    "överbevisats": "överbevisa",
    "överbjud": "överbjuda",
    "överbjudande": "överbjuda",
    "överbjudanden": "överbjudande",
    "överbjudandena": "överbjudande",
    "överbjudandenas": "överbjudande",
    "överbjudandens": "överbjudande",
    "överbjudandes": "överbjudande",
    "överbjudandet": "överbjudande",
    "överbjudandets": "överbjudande",
    "överbjudas": "överbjuda",
    "överbjude": "överbjuda",
    "överbjuden": "överbjuda",
    "överbjudens": "överbjuda",
    "överbjuder": "överbjuda",
    "överbjudes": "överbjuda",
    "överbjudet": "överbjuda",
    "överbjudets": "överbjuda",
    "överbjudit": "överbjuda",
    "överbjudits": "överbjuda",
    "överbjudna": "överbjuda",
    "överbjudnas": "överbjuda",
    "överbjudne": "överbjuda",
    "överbjudnes": "överbjuda",
    "överbjuds": "överbjuda",
    "överbjöd": "överbjuda",
    "överbjöde": "överbjuda",
    "överbjödes": "överbjuda",
    "överbjöds": "överbjuda",
    "överblick": "överblicka",
    "överblickad": "överblicka",
    "överblickade": "överblicka",
    "överblickades": "överblicka",
    "överblickads": "överblicka",
    "överblickande": "överblicka",
    "överblickanden": "överblickande",
    "överblickandena": "överblickande",
    "överblickandenas": "överblickande",
    "överblickandens": "överblickande",
    "överblickandes": "överblickande",
    "överblickandet": "överblickande",
    "överblickandets": "överblickande",
    "överblickar": "överblicka",
    "överblickarna": "överblick",
    "överblickarnas": "överblick",
    "överblickars": "överblick",
    "överblickas": "överblicka",
    "överblickat": "överblicka",
    "överblickats": "överblicka",
    "överblickbara": "överblickbar",
    "överblickbarare": "överblickbar",
    "överblickbarares": "överblickbar",
    "överblickbaras": "överblickbar",
    "överblickbarast": "överblickbar",
    "överblickbaraste": "överblickbar",
    "överblickbarastes": "överblickbar",
    "överblickbarasts": "överblickbar",
    "överblickbare": "överblickbar",
    "överblickbares": "överblickbar",
    "överblickbarheten": "överblickbarhet",
    "överblickbarhetens": "överblickbarhet",
    "överblickbarhets": "överblickbarhet",
    "överblickbars": "överblickbar",
    "överblickbart": "överblickbar",
    "överblickbarts": "överblickbar",
    "överblicken": "överblick",
    "överblickens": "överblick",
    "överblicks": "överblick",
    "överblivens": "överbliven",
    "överblivet": "överbliven",
    "överblivets": "överbliven",
    "överblivna": "överbliven",
    "överblivnare": "överbliven",
    "överblivnares": "överbliven",
    "överblivnas": "överbliven",
    "överblivnast": "överbliven",
    "överblivnaste": "överbliven",
    "överblivnastes": "överbliven",
    "överblivnasts": "överbliven",
    "överblivne": "överbliven",
    "överblivnes": "överbliven",
    "överbok": "överboka",
    "överbokad": "överboka",
    "överbokade": "överboka",
    "överbokades": "överboka",
    "överbokads": "överboka",
    "överbokande": "överboka",
    "överbokanden": "överbokande",
    "överbokandena": "överbokande",
    "överbokandenas": "överbokande",
    "överbokandens": "överbokande",
    "överbokandes": "överbokande",
    "överbokandet": "överbokande",
    "överbokandets": "överbokande",
    "överbokar": "överboka",
    "överbokas": "överboka",
    "överbokat": "överboka",
    "överbokats": "överboka",
    "överbragt": "överbringa",
    "överbragte": "överbringa",
    "överbragtes": "överbringa",
    "överbragts": "överbringa",
    "överbring": "överbringa",
    "överbringad": "överbringa",
    "överbringade": "överbringa",
    "överbringades": "överbringa",
    "överbringads": "överbringa",
    "överbringande": "överbringa",
    "överbringanden": "överbringande",
    "överbringandena": "överbringande",
    "överbringandenas": "överbringande",
    "överbringandens": "överbringande",
    "överbringandes": "överbringande",
    "överbringandet": "överbringande",
    "överbringandets": "överbringande",
    "överbringar": "överbringa",
    "överbringas": "överbringa",
    "överbringat": "överbringa",
    "överbringats": "överbringa",
    "överbrygg": "överbrygga",
    "överbryggad": "överbrygga",
    "överbryggade": "överbrygga",
    "överbryggades": "överbrygga",
    "överbryggads": "överbrygga",
    "överbryggande": "överbrygga",
    "överbrygganden": "överbryggande",
    "överbryggandena": "överbryggande",
    "överbryggandenas": "överbryggande",
    "överbryggandens": "överbryggande",
    "överbryggandes": "överbryggande",
    "överbryggandet": "överbryggande",
    "överbryggandets": "överbryggande",
    "överbryggar": "överbrygga",
    "överbryggas": "överbrygga",
    "överbryggat": "överbrygga",
    "överbryggats": "överbrygga",
    "överbuden": "överbud",
    "överbudens": "överbud",
    "överbudet": "överbud",
    "överbudets": "överbud",
    "överbuds": "överbud",
    "överbyggda": "överbyggd",
    "överbyggdare": "överbyggd",
    "överbyggdares": "överbyggd",
    "överbyggdas": "överbyggd",
    "överbyggdast": "överbyggd",
    "överbyggdaste": "överbyggd",
    "överbyggdastes": "överbyggd",
    "överbyggdasts": "överbyggd",
    "överbyggde": "överbyggd",
    "överbyggdes": "överbyggd",
    "överbyggds": "överbyggd",
    "överbyggnaden": "överbyggnad",
    "överbyggnadens": "överbyggnad",
    "överbyggnader": "överbyggnad",
    "överbyggnaderna": "överbyggnad",
    "överbyggnadernas": "överbyggnad",
    "överbyggnaders": "överbyggnad",
    "överbyggnads": "överbyggnad",
    "överbyggt": "överbyggd",
    "överbyggts": "överbyggd",
    "överbäddar": "överbädd",
    "överbäddarna": "överbädd",
    "överbäddarnas": "överbädd",
    "överbäddars": "överbädd",
    "överbädden": "överbädd",
    "överbäddens": "överbädd",
    "överbädds": "överbädd",
    "överdelar": "överdel",
    "överdelarna": "överdel",
    "överdelarnas": "överdel",
    "överdelars": "överdel",
    "överdelen": "överdel",
    "överdelens": "överdel",
    "överdels": "överdel",
    "överdiagnostiken": "överdiagnostik",
    "överdiagnostikens": "överdiagnostik",
    "överdiagnostiks": "överdiagnostik",
    "överdimensionerad": "överdimensionera",
    "överdimensionerade": "överdimensionera",
    "överdimensionerades": "överdimensionera",
    "överdimensionerads": "överdimensionera",
    "överdimensionerande": "överdimensionera",
    "överdimensioneranden": "överdimensionerande",
    "överdimensionerandena": "överdimensionerande",
    "överdimensionerandenas": "överdimensionerande",
    "överdimensionerandens": "överdimensionerande",
    "överdimensionerandes": "överdimensionerande",
    "överdimensionerandet": "överdimensionerande",
    "överdimensionerandets": "överdimensionerande",
    "överdimensionerar": "överdimensionera",
    "överdimensioneras": "överdimensionera",
    "överdimensionerat": "överdimensionera",
    "överdimensionerats": "överdimensionera",
    "överdimensionerbara": "överdimensionerbar",
    "överdimensionerbarare": "överdimensionerbar",
    "överdimensionerbarares": "överdimensionerbar",
    "överdimensionerbaras": "överdimensionerbar",
    "överdimensionerbarast": "överdimensionerbar",
    "överdimensionerbaraste": "överdimensionerbar",
    "överdimensionerbarastes": "överdimensionerbar",
    "överdimensionerbarasts": "överdimensionerbar",
    "överdimensionerbare": "överdimensionerbar",
    "överdimensionerbares": "överdimensionerbar",
    "överdimensionerbarheten": "överdimensionerbarhet",
    "överdimensionerbarhetens": "överdimensionerbarhet",
    "överdimensionerbarhets": "överdimensionerbarhet",
    "överdimensionerbars": "överdimensionerbar",
    "överdimensionerbart": "överdimensionerbar",
    "överdimensionerbarts": "överdimensionerbar",
    "överdimensioneringar": "överdimensionering",
    "överdimensioneringarna": "överdimensionering",
    "överdimensioneringarnas": "överdimensionering",
    "överdimensioneringars": "överdimensionering",
    "överdimensioneringen": "överdimensionering",
    "överdimensioneringens": "överdimensionering",
    "överdimensionerings": "överdimensionering",
    "överdirektören": "överdirektör",
    "överdirektörens": "överdirektör",
    "överdirektörer": "överdirektör",
    "överdirektörerna": "överdirektör",
    "överdirektörernas": "överdirektör",
    "överdirektörers": "överdirektör",
    "överdirektörn": "överdirektör",
    "överdirektörns": "överdirektör",
    "överdirektörs": "överdirektör",
    "överdomar": "överdomare",
    "överdomaren": "överdomare",
    "överdomarens": "överdomare",
    "överdomares": "överdomare",
    "överdomarna": "överdomare",
    "överdomarnas": "överdomare",
    "överdosen": "överdos",
    "överdosens": "överdos",
    "överdoser": "överdos",
    "överdoserad": "överdosera",
    "överdoserade": "överdosera",
    "överdoserades": "överdosera",
    "överdoserads": "överdosera",
    "överdoserande": "överdosera",
    "överdoseranden": "överdoserande",
    "överdoserandena": "överdoserande",
    "överdoserandenas": "överdoserande",
    "överdoserandens": "överdoserande",
    "överdoserandes": "överdoserande",
    "överdoserandet": "överdoserande",
    "överdoserandets": "överdoserande",
    "överdoserar": "överdosera",
    "överdoseras": "överdosera",
    "överdoserat": "överdosera",
    "överdoserats": "överdosera",
    "överdoserbara": "överdoserbar",
    "överdoserbarare": "överdoserbar",
    "överdoserbarares": "överdoserbar",
    "överdoserbaras": "överdoserbar",
    "överdoserbarast": "överdoserbar",
    "överdoserbaraste": "överdoserbar",
    "överdoserbarastes": "överdoserbar",
    "överdoserbarasts": "överdoserbar",
    "överdoserbare": "överdoserbar",
    "överdoserbares": "överdoserbar",
    "överdoserbarheten": "överdoserbarhet",
    "överdoserbarhetens": "överdoserbarhet",
    "överdoserbarhets": "överdoserbarhet",
    "överdoserbars": "överdoserbar",
    "överdoserbart": "överdoserbar",
    "överdoserbarts": "överdoserbar",
    "överdoseringar": "överdosering",
    "överdoseringarna": "överdosering",
    "överdoseringarnas": "överdosering",
    "överdoseringars": "överdosering",
    "överdoseringen": "överdosering",
    "överdoseringens": "överdosering",
    "överdoserings": "överdosering",
    "överdoserna": "överdos",
    "överdosernas": "överdos",
    "överdosers": "överdos",
    "överdrag": "överdra",
    "överdraga": "överdra",
    "överdragande": "överdra",
    "överdraganden": "överdragande",
    "överdragandena": "överdragande",
    "överdragandenas": "överdragande",
    "överdragandens": "överdragande",
    "överdragandes": "överdragande",
    "överdragandet": "överdragande",
    "överdragandets": "överdragande",
    "överdragas": "överdra",
    "överdrage": "överdra",
    "överdragen": "överdrag",
    "överdragens": "överdrag",
    "överdrager": "överdra",
    "överdrages": "överdra",
    "överdraget": "överdrag",
    "överdragets": "överdrag",
    "överdragit": "överdra",
    "överdragits": "överdra",
    "överdragna": "överdra",
    "överdragnas": "överdra",
    "överdragne": "överdra",
    "överdragnes": "överdra",
    "överdrags": "överdrag",
    "överdragsdräkten": "överdragsdräkt",
    "överdragsdräktens": "överdragsdräkt",
    "överdragsdräkter": "överdragsdräkt",
    "överdragsdräkterna": "överdragsdräkt",
    "överdragsdräkternas": "överdragsdräkt",
    "överdragsdräkters": "överdragsdräkt",
    "överdragsdräkts": "överdragsdräkt",
    "överdragskläderna": "överdragskläder",
    "överdragsklädernas": "överdragskläder",
    "överdragskläders": "överdragskläder",
    "överdragsklädes": "överdragskläder",
    "överdragskläds": "överdragskläder",
    "överdrar": "överdra",
    "överdras": "överdra",
    "överdrev": "överdriva",
    "överdrevs": "överdriva",
    "överdriften": "överdrift",
    "överdriftens": "överdrift",
    "överdrifter": "överdrift",
    "överdrifterna": "överdrift",
    "överdrifternas": "överdrift",
    "överdrifters": "överdrift",
    "överdrifts": "överdrift",
    "överdriv": "överdriva",
    "överdrivande": "överdriva",
    "överdrivanden": "överdrivande",
    "överdrivandena": "överdrivande",
    "överdrivandenas": "överdrivande",
    "överdrivandens": "överdrivande",
    "överdrivandes": "överdrivande",
    "överdrivandet": "överdrivande",
    "överdrivandets": "överdrivande",
    "överdrivas": "överdriva",
    "överdrive": "överdriva",
    "överdriven": "överdriva",
    "överdrivens": "överdriven",
    "överdriver": "överdriva",
    "överdrives": "överdriva",
    "överdrivet": "överdriven",
    "överdrivets": "överdriven",
    "överdrivit": "överdriva",
    "överdrivits": "överdriva",
    "överdrivna": "överdriven",
    "överdrivnare": "överdriven",
    "överdrivnares": "överdriven",
    "överdrivnas": "överdriven",
    "överdrivnast": "överdriven",
    "överdrivnaste": "överdriven",
    "överdrivnastes": "överdriven",
    "överdrivnasts": "överdriven",
    "överdrivne": "överdriven",
    "överdrivnes": "överdriven",
    "överdrivs": "överdriva",
    "överdrog": "överdra",
    "överdroge": "överdra",
    "överdroges": "överdra",
    "överdrogs": "överdra",
    "överdängar": "överdängare",
    "överdängaren": "överdängare",
    "överdängarens": "överdängare",
    "överdängares": "överdängare",
    "överdängarna": "överdängare",
    "överdängarnas": "överdängare",
    "överdåden": "överdåd",
    "överdådens": "överdåd",
    "överdådet": "överdåd",
    "överdådets": "överdåd",
    "överdådiga": "överdådig",
    "överdådigare": "överdådig",
    "överdådigares": "överdådig",
    "överdådigas": "överdådig",
    "överdådigast": "överdådig",
    "överdådigaste": "överdådig",
    "överdådigastes": "överdådig",
    "överdådigasts": "överdådig",
    "överdådige": "överdådig",
    "överdådiges": "överdådig",
    "överdådigheten": "överdådighet",
    "överdådighetens": "överdådighet",
    "överdådighets": "överdådighet",
    "överdådigs": "överdådig",
    "överdådigt": "överdådig",
    "överdådigts": "överdådig",
    "överdåds": "överdåd",
    "överdödligheten": "överdödlighet",
    "överdödlighetens": "överdödlighet",
    "överdödligheter": "överdödlighet",
    "överdödligheterna": "överdödlighet",
    "överdödligheternas": "överdödlighet",
    "överdödligheters": "överdödlighet",
    "överdödlighets": "överdödlighet",
    "överensfyrar": "överensfyr",
    "överensfyrarna": "överensfyr",
    "överensfyrarnas": "överensfyr",
    "överensfyrars": "överensfyr",
    "överensfyren": "överensfyr",
    "överensfyrens": "överensfyr",
    "överensfyrs": "överensfyr",
    "överenskom": "överenskomma",
    "överenskomet": "överenskomma",
    "överenskomets": "överenskomma",
    "överenskommande": "överenskomma",
    "överenskommanden": "överenskommande",
    "överenskommandena": "överenskommande",
    "överenskommandenas": "överenskommande",
    "överenskommandens": "överenskommande",
    "överenskommandes": "överenskommande",
    "överenskommandet": "överenskommande",
    "överenskommandets": "överenskommande",
    "överenskommas": "överenskomma",
    "överenskomme": "överenskomma",
    "överenskommelsen": "överenskommelse",
    "överenskommelsens": "överenskommelse",
    "överenskommelser": "överenskommelse",
    "överenskommelserna": "överenskommelse",
    "överenskommelsernas": "överenskommelse",
    "överenskommelsers": "överenskommelse",
    "överenskommelses": "överenskommelse",
    "överenskommen": "överenskomma",
    "överenskommens": "överenskomma",
    "överenskommer": "överenskomma",
    "överenskommes": "överenskomma",
    "överenskommit": "överenskomma",
    "överenskommits": "överenskomma",
    "överenskomna": "överenskomma",
    "överenskomnas": "överenskomma",
    "överenskomne": "överenskomma",
    "överenskomnes": "överenskomma",
    "överenskoms": "överenskomma",
    "överensstäm": "överensstämma",
    "överensstämd": "överensstämma",
    "överensstämda": "överensstämma",
    "överensstämdas": "överensstämma",
    "överensstämde": "överensstämma",
    "överensstämdes": "överensstämma",
    "överensstämds": "överensstämma",
    "överensstämmande": "överensstämma",
    "överensstämmanden": "överensstämmande",
    "överensstämmandena": "överensstämmande",
    "överensstämmandenas": "överensstämmande",
    "överensstämmandens": "överensstämmande",
    "överensstämmandes": "överensstämmande",
    "överensstämmandet": "överensstämmande",
    "överensstämmandets": "överensstämmande",
    "överensstämmas": "överensstämma",
    "överensstämmelsen": "överensstämmelse",
    "överensstämmelsens": "överensstämmelse",
    "överensstämmelser": "överensstämmelse",
    "överensstämmelserna": "överensstämmelse",
    "överensstämmelsernas": "överensstämmelse",
    "överensstämmelsers": "överensstämmelse",
    "överensstämmelses": "överensstämmelse",
    "överensstämmer": "överensstämma",
    "överensstäms": "överensstämma",
    "överensstämt": "överensstämma",
    "överensstämts": "överensstämma",
    "överexponerad": "överexponera",
    "överexponerade": "överexponera",
    "överexponerades": "överexponera",
    "överexponerads": "överexponera",
    "överexponerande": "överexponera",
    "överexponeranden": "överexponerande",
    "överexponerandena": "överexponerande",
    "överexponerandenas": "överexponerande",
    "överexponerandens": "överexponerande",
    "överexponerandes": "överexponerande",
    "överexponerandet": "överexponerande",
    "överexponerandets": "överexponerande",
    "överexponerar": "överexponera",
    "överexponeras": "överexponera",
    "överexponerat": "överexponera",
    "överexponerats": "överexponera",
    "överexponerbara": "överexponerbar",
    "överexponerbarare": "överexponerbar",
    "överexponerbarares": "överexponerbar",
    "överexponerbaras": "överexponerbar",
    "överexponerbarast": "överexponerbar",
    "överexponerbaraste": "överexponerbar",
    "överexponerbarastes": "överexponerbar",
    "överexponerbarasts": "överexponerbar",
    "överexponerbare": "överexponerbar",
    "överexponerbares": "överexponerbar",
    "överexponerbarheten": "överexponerbarhet",
    "överexponerbarhetens": "överexponerbarhet",
    "överexponerbarhets": "överexponerbarhet",
    "överexponerbars": "överexponerbar",
    "överexponerbart": "överexponerbar",
    "överexponerbarts": "överexponerbar",
    "överexponeringar": "överexponering",
    "överexponeringarna": "överexponering",
    "överexponeringarnas": "överexponering",
    "överexponeringars": "överexponering",
    "överexponeringen": "överexponering",
    "överexponeringens": "överexponering",
    "överexponerings": "överexponering",
    "överfall": "överfalla",
    "överfallande": "överfalla",
    "överfallanden": "överfallande",
    "överfallandena": "överfallande",
    "överfallandenas": "överfallande",
    "överfallandens": "överfallande",
    "överfallandes": "överfallande",
    "överfallandet": "överfallande",
    "överfallandets": "överfallande",
    "överfallas": "överfalla",
    "överfalle": "överfalla",
    "överfallen": "överfalla",
    "överfallens": "överfalla",
    "överfaller": "överfalla",
    "överfalles": "överfalla",
    "överfallet": "överfalla",
    "överfallets": "överfalla",
    "överfallit": "överfalla",
    "överfallits": "överfalla",
    "överfallna": "överfalla",
    "överfallnas": "överfalla",
    "överfallne": "överfalla",
    "överfallnes": "överfalla",
    "överfalls": "överfalla",
    "överfallsvåldtäkten": "överfallsvåldtäkt",
    "överfallsvåldtäktens": "överfallsvåldtäkt",
    "överfallsvåldtäkter": "överfallsvåldtäkt",
    "överfallsvåldtäkterna": "överfallsvåldtäkt",
    "överfallsvåldtäkternas": "överfallsvåldtäkt",
    "överfallsvåldtäkters": "överfallsvåldtäkt",
    "överfallsvåldtäkts": "överfallsvåldtäkt",
    "överfarten": "överfart",
    "överfartens": "överfart",
    "överfarter": "överfart",
    "överfarterna": "överfart",
    "överfarternas": "överfart",
    "överfarters": "överfart",
    "överfarts": "överfart",
    "överfluge": "överflyga",
    "överfluges": "överflyga",
    "överflugit": "överflyga",
    "överflugits": "överflyga",
    "överflyg": "överflyga",
    "överflygande": "överflyga",
    "överflygandes": "överflyga",
    "överflygas": "överflyga",
    "överflyge": "överflyga",
    "överflyger": "överflyga",
    "överflyges": "överflyga",
    "överflyglad": "överflygla",
    "överflyglade": "överflygla",
    "överflyglades": "överflygla",
    "överflyglads": "överflygla",
    "överflyglande": "överflygla",
    "överflyglanden": "överflyglande",
    "överflyglandena": "överflyglande",
    "överflyglandenas": "överflyglande",
    "överflyglandens": "överflyglande",
    "överflyglandes": "överflyglande",
    "överflyglandet": "överflyglande",
    "överflyglandets": "överflyglande",
    "överflyglar": "överflygla",
    "överflyglas": "överflygla",
    "överflyglat": "överflygla",
    "överflyglats": "överflygla",
    "överflygningar": "överflygning",
    "överflygningarna": "överflygning",
    "överflygningarnas": "överflygning",
    "överflygningars": "överflygning",
    "överflygningen": "överflygning",
    "överflygningens": "överflygning",
    "överflygnings": "överflygning",
    "överflygs": "överflyga",
    "överflytt": "överflytta",
    "överflyttad": "överflytta",
    "överflyttade": "överflytta",
    "överflyttades": "överflytta",
    "överflyttads": "överflytta",
    "överflyttande": "överflytta",
    "överflyttanden": "överflyttande",
    "överflyttandena": "överflyttande",
    "överflyttandenas": "överflyttande",
    "överflyttandens": "överflyttande",
    "överflyttandes": "överflyttande",
    "överflyttandet": "överflyttande",
    "överflyttandets": "överflyttande",
    "överflyttar": "överflytta",
    "överflyttas": "överflytta",
    "överflyttat": "överflytta",
    "överflyttats": "överflytta",
    "överflyttningar": "överflyttning",
    "överflyttningarna": "överflyttning",
    "överflyttningarnas": "överflyttning",
    "överflyttningars": "överflyttning",
    "överflyttningen": "överflyttning",
    "överflyttningens": "överflyttning",
    "överflyttnings": "överflyttning",
    "överflödade": "överflöda",
    "överflödades": "överflöda",
    "överflödande": "överflöda",
    "överflödanden": "överflödande",
    "överflödandena": "överflödande",
    "överflödandenas": "överflödande",
    "överflödandens": "överflödande",
    "överflödandes": "överflödande",
    "överflödandet": "överflödande",
    "överflödandets": "överflödande",
    "överflödar": "överflöda",
    "överflödas": "överflöda",
    "överflödat": "överflöda",
    "överflödats": "överflöda",
    "överflödet": "överflöd",
    "överflödets": "överflöd",
    "överflödiga": "överflödig",
    "överflödigare": "överflödig",
    "överflödigares": "överflödig",
    "överflödigas": "överflödig",
    "överflödigast": "överflödig",
    "överflödigaste": "överflödig",
    "överflödigastes": "överflödig",
    "överflödigasts": "överflödig",
    "överflödige": "överflödig",
    "överflödiges": "överflödig",
    "överflödigheten": "överflödighet",
    "överflödighetens": "överflödighet",
    "överflödighets": "överflödighet",
    "överflödigs": "överflödig",
    "överflödigt": "överflödig",
    "överflödigts": "överflödig",
    "överflöds": "överflöd",
    "överflödssamhällen": "överflödssamhälle",
    "överflödssamhällena": "överflödssamhälle",
    "överflödssamhällenas": "överflödssamhälle",
    "överflödssamhällens": "överflödssamhälle",
    "överflödssamhälles": "överflödssamhälle",
    "överflödssamhället": "överflödssamhälle",
    "överflödssamhällets": "överflödssamhälle",
    "överflödssamhälls": "överflödssamhälle",
    "överflög": "överflyga",
    "överflögs": "överflyga",
    "överfulla": "överfull",
    "överfullare": "överfull",
    "överfullares": "överfull",
    "överfullas": "överfull",
    "överfullast": "överfull",
    "överfullaste": "överfull",
    "överfullastes": "överfull",
    "överfullasts": "överfull",
    "överfulle": "överfull",
    "överfulles": "överfull",
    "överfullheten": "överfullhet",
    "överfullhetens": "överfullhet",
    "överfullhets": "överfullhet",
    "överfulls": "överfull",
    "överfullt": "överfull",
    "överfullts": "överfull",
    "överfuriren": "överfurir",
    "överfurirens": "överfurir",
    "överfurirer": "överfurir",
    "överfurirerna": "överfurir",
    "överfurirernas": "överfurir",
    "överfurirers": "överfurir",
    "överfurirs": "överfurir",
    "överfyllda": "överfylld",
    "överfylldare": "överfylld",
    "överfylldares": "överfylld",
    "överfylldas": "överfylld",
    "överfylldast": "överfylld",
    "överfylldaste": "överfylld",
    "överfylldastes": "överfylld",
    "överfylldasts": "överfylld",
    "överfyllde": "överfylld",
    "överfylldes": "överfylld",
    "överfylldheten": "överfylldhet",
    "överfylldhetens": "överfylldhet",
    "överfylldhets": "överfylldhet",
    "överfyllds": "överfylld",
    "överfyllt": "överfylld",
    "överfyllts": "överfylld",
    "överfärden": "överfärd",
    "överfärdens": "överfärd",
    "överfärder": "överfärd",
    "överfärderna": "överfärd",
    "överfärdernas": "överfärd",
    "överfärders": "överfärd",
    "överfärds": "överfärd",
    "överfångsglasen": "överfångsglas",
    "överfångsglasens": "överfångsglas",
    "överfångsglaset": "överfångsglas",
    "överfångsglasets": "överfångsglas",
    "överföll": "överfalla",
    "överfölle": "överfalla",
    "överfölles": "överfalla",
    "överfölls": "överfalla",
    "överför": "överföra",
    "överförande": "överföra",
    "överföranden": "överförande",
    "överförandena": "överförande",
    "överförandenas": "överförande",
    "överförandens": "överförande",
    "överförandes": "överförande",
    "överförandet": "överförande",
    "överförandets": "överförande",
    "överföras": "överföra",
    "överförbara": "överförbar",
    "överförbaras": "överförbar",
    "överförbare": "överförbar",
    "överförbares": "överförbar",
    "överförbars": "överförbar",
    "överförbart": "överförbar",
    "överförbarts": "överförbar",
    "överförd": "överföra",
    "överförda": "överförd",
    "överfördare": "överförd",
    "överfördares": "överförd",
    "överfördas": "överförd",
    "överfördast": "överförd",
    "överfördaste": "överförd",
    "överfördastes": "överförd",
    "överfördasts": "överförd",
    "överförde": "överförd",
    "överfördes": "överförd",
    "överförds": "överförd",
    "överföres": "överföra",
    "överförfriskade": "överförfriskad",
    "överförfriskades": "överförfriskad",
    "överförfriskads": "överförfriskad",
    "överförfriskat": "överförfriskad",
    "överförfriskats": "överförfriskad",
    "överföringar": "överföring",
    "överföringarna": "överföring",
    "överföringarnas": "överföring",
    "överföringars": "överföring",
    "överföringen": "överföring",
    "överföringens": "överföring",
    "överförings": "överföring",
    "överföringsbilden": "överföringsbild",
    "överföringsbildens": "överföringsbild",
    "överföringsbilder": "överföringsbild",
    "överföringsbilderna": "överföringsbild",
    "överföringsbildernas": "överföringsbild",
    "överföringsbilders": "överföringsbild",
    "överföringsbilds": "överföringsbild",
    "överföringskarakteristiken": "överföringskarakteristik",
    "överföringskarakteristikens": "överföringskarakteristik",
    "överföringskarakteristiker": "överföringskarakteristik",
    "överföringskarakteristikerna": "överföringskarakteristik",
    "överföringskarakteristikernas": "överföringskarakteristik",
    "överföringskarakteristikers": "överföringskarakteristik",
    "överföringskarakteristiks": "överföringskarakteristik",
    "överföringskaraktäristiken": "överföringskaraktäristik",
    "överföringskaraktäristikens": "överföringskaraktäristik",
    "överföringskaraktäristiker": "överföringskaraktäristik",
    "överföringskaraktäristikerna": "överföringskaraktäristik",
    "överföringskaraktäristikernas": "överföringskaraktäristik",
    "överföringskaraktäristikers": "överföringskaraktäristik",
    "överföringskaraktäristiks": "överföringskaraktäristik",
    "överförmyndar": "överförmyndare",
    "överförmyndaren": "överförmyndare",
    "överförmyndarens": "överförmyndare",
    "överförmyndares": "överförmyndare",
    "överförmyndarna": "överförmyndare",
    "överförmyndarnas": "överförmyndare",
    "överförs": "överföra",
    "överfört": "överförd",
    "överförtjusta": "överförtjust",
    "överförtjustare": "överförtjust",
    "överförtjustares": "överförtjust",
    "överförtjustas": "överförtjust",
    "överförtjustast": "överförtjust",
    "överförtjustaste": "överförtjust",
    "överförtjustastes": "överförtjust",
    "överförtjustasts": "överförtjust",
    "överförtjuste": "överförtjust",
    "överförtjustes": "överförtjust",
    "överförtjustheten": "överförtjusthet",
    "överförtjusthetens": "överförtjusthet",
    "överförtjusthets": "överförtjusthet",
    "överförtjusts": "överförtjust",
    "överförts": "överförd",
    "övergav": "överge",
    "övergavs": "överge",
    "övergeende": "överge",
    "övergeendes": "överge",
    "överger": "överge",
    "överges": "överge",
    "övergett": "överge",
    "övergetts": "överge",
    "övergick": "övergå",
    "övergicks": "övergå",
    "överginge": "övergå",
    "överginges": "övergå",
    "övergiv": "överge",
    "övergiva": "överge",
    "övergivande": "överge",
    "övergivanden": "övergivande",
    "övergivandena": "övergivande",
    "övergivandenas": "övergivande",
    "övergivandens": "övergivande",
    "övergivandes": "övergivande",
    "övergivandet": "övergivande",
    "övergivandets": "övergivande",
    "övergivas": "överge",
    "övergive": "överge",
    "övergiven": "överge",
    "övergivenheten": "övergivenhet",
    "övergivenhetens": "övergivenhet",
    "övergivenhets": "övergivenhet",
    "övergivens": "övergiven",
    "övergiver": "överge",
    "övergives": "överge",
    "övergivet": "övergiven",
    "övergivets": "övergiven",
    "övergivit": "överge",
    "övergivits": "överge",
    "övergivna": "övergiven",
    "övergivnare": "övergiven",
    "övergivnares": "övergiven",
    "övergivnas": "övergiven",
    "övergivnast": "övergiven",
    "övergivnaste": "övergiven",
    "övergivnastes": "övergiven",
    "övergivnasts": "övergiven",
    "övergivne": "övergiven",
    "övergivnes": "övergiven",
    "övergivs": "överge",
    "övergläns": "överglänsa",
    "överglänsande": "överglänsa",
    "överglänsanden": "överglänsande",
    "överglänsandena": "överglänsande",
    "överglänsandenas": "överglänsande",
    "överglänsandens": "överglänsande",
    "överglänsandes": "överglänsande",
    "överglänsandet": "överglänsande",
    "överglänsandets": "överglänsande",
    "överglänsas": "överglänsa",
    "överglänser": "överglänsa",
    "överglänses": "överglänsa",
    "överglänst": "överglänsa",
    "överglänsta": "överglänsa",
    "överglänstas": "överglänsa",
    "överglänste": "överglänsa",
    "överglänstes": "överglänsa",
    "överglänsts": "överglänsa",
    "övergreppen": "övergrepp",
    "övergreppens": "övergrepp",
    "övergreppet": "övergrepp",
    "övergreppets": "övergrepp",
    "övergrepps": "övergrepp",
    "övergående": "övergå",
    "övergåenden": "övergående",
    "övergåendena": "övergående",
    "övergåendenas": "övergående",
    "övergåendens": "övergående",
    "övergåendes": "övergående",
    "övergåendet": "övergående",
    "övergåendets": "övergående",
    "övergångar": "övergång",
    "övergångarna": "övergång",
    "övergångarnas": "övergång",
    "övergångars": "övergång",
    "övergången": "övergång",
    "övergångens": "övergång",
    "övergångs": "övergång",
    "övergångsformen": "övergångsform",
    "övergångsformens": "övergångsform",
    "övergångsformer": "övergångsform",
    "övergångsformerna": "övergångsform",
    "övergångsformernas": "övergångsform",
    "övergångsformers": "övergångsform",
    "övergångsforms": "övergångsform",
    "övergångsmetallen": "övergångsmetall",
    "övergångsmetallens": "övergångsmetall",
    "övergångsmetaller": "övergångsmetall",
    "övergångsmetallerna": "övergångsmetall",
    "övergångsmetallernas": "övergångsmetall",
    "övergångsmetallers": "övergångsmetall",
    "övergångsmetalls": "övergångsmetall",
    "övergångsmiljöer": "övergångsmiljö",
    "övergångsmiljöerna": "övergångsmiljö",
    "övergångsmiljöernas": "övergångsmiljö",
    "övergångsmiljöers": "övergångsmiljö",
    "övergångsmiljön": "övergångsmiljö",
    "övergångsmiljöns": "övergångsmiljö",
    "övergångsmiljös": "övergångsmiljö",
    "övergångsproblemen": "övergångsproblem",
    "övergångsproblemens": "övergångsproblem",
    "övergångsproblemet": "övergångsproblem",
    "övergångsproblemets": "övergångsproblem",
    "övergångsproblems": "övergångsproblem",
    "övergångsskeden": "övergångsskede",
    "övergångsskedena": "övergångsskede",
    "övergångsskedenas": "övergångsskede",
    "övergångsskedens": "övergångsskede",
    "övergångsskedes": "övergångsskede",
    "övergångsskedet": "övergångsskede",
    "övergångsskedets": "övergångsskede",
    "övergångsstaten": "övergångsstat",
    "övergångsstatens": "övergångsstat",
    "övergångsstats": "övergångsstat",
    "övergångsställen": "övergångsställe",
    "övergångsställena": "övergångsställe",
    "övergångsställenas": "övergångsställe",
    "övergångsställens": "övergångsställe",
    "övergångsställes": "övergångsställe",
    "övergångsstället": "övergångsställe",
    "övergångsställets": "övergångsställe",
    "övergångstiden": "övergångstid",
    "övergångstidens": "övergångstid",
    "övergångstider": "övergångstid",
    "övergångstiderna": "övergångstid",
    "övergångstidernas": "övergångstid",
    "övergångstiders": "övergångstid",
    "övergångstids": "övergångstid",
    "övergångsverben": "övergångsverb",
    "övergångsverbens": "övergångsverb",
    "övergångsverbet": "övergångsverb",
    "övergångsverbets": "övergångsverb",
    "övergångsverbs": "övergångsverb",
    "övergångsåldern": "övergångsålder",
    "övergångsålderns": "övergångsålder",
    "övergångsålders": "övergångsålder",
    "övergångsåldrar": "övergångsålder",
    "övergångsåldrarna": "övergångsålder",
    "övergångsåldrarnas": "övergångsålder",
    "övergångsåldrars": "övergångsålder",
    "övergår": "övergå",
    "övergås": "övergå",
    "övergått": "övergå",
    "övergåtts": "övergå",
    "övergåve": "överge",
    "övergåves": "överge",
    "övergöd": "övergöda",
    "övergödande": "övergöda",
    "övergödanden": "övergödande",
    "övergödandena": "övergödande",
    "övergödandenas": "övergödande",
    "övergödandens": "övergödande",
    "övergödandes": "övergödande",
    "övergödandet": "övergödande",
    "övergödandets": "övergödande",
    "övergödas": "övergöda",
    "övergödd": "övergöda",
    "övergödda": "övergöda",
    "övergöddas": "övergöda",
    "övergödde": "övergöda",
    "övergöddes": "övergöda",
    "övergödds": "övergöda",
    "övergöder": "övergöda",
    "övergödes": "övergöda",
    "övergöds": "övergöda",
    "övergött": "övergöda",
    "övergötts": "övergöda",
    "överhalningar": "överhalning",
    "överhalningarna": "överhalning",
    "överhalningarnas": "överhalning",
    "överhalningars": "överhalning",
    "överhalningen": "överhalning",
    "överhalningens": "överhalning",
    "överhalnings": "överhalning",
    "överhanden": "överhand",
    "överhandens": "överhand",
    "överhands": "överhand",
    "överhandsfräsar": "överhandsfräs",
    "överhandsfräsarna": "överhandsfräs",
    "överhandsfräsarnas": "överhandsfräs",
    "överhandsfräsars": "överhandsfräs",
    "överhandsfräsen": "överhandsfräs",
    "överhandsfräsens": "överhandsfräs",
    "överhandsknopar": "överhandsknop",
    "överhandsknoparna": "överhandsknop",
    "överhandsknoparnas": "överhandsknop",
    "överhandsknopars": "överhandsknop",
    "överhandsknopen": "överhandsknop",
    "överhandsknopens": "överhandsknop",
    "överhandsknops": "överhandsknop",
    "överheten": "överhet",
    "överhetens": "överhet",
    "överheter": "överhet",
    "överheterna": "överhet",
    "överheternas": "överhet",
    "överheters": "överhet",
    "överhetliga": "överhetlig",
    "överhetligare": "överhetlig",
    "överhetligares": "överhetlig",
    "överhetligas": "överhetlig",
    "överhetligast": "överhetlig",
    "överhetligaste": "överhetlig",
    "överhetligastes": "överhetlig",
    "överhetligasts": "överhetlig",
    "överhetlige": "överhetlig",
    "överhetliges": "överhetlig",
    "överhetligheten": "överhetlighet",
    "överhetlighetens": "överhetlighet",
    "överhetlighets": "överhetlighet",
    "överhetligs": "överhetlig",
    "överhetligt": "överhetlig",
    "överhetligts": "överhetlig",
    "överhets": "överhet",
    "överhett": "överhetta",
    "överhettad": "överhetta",
    "överhettade": "överhetta",
    "överhettades": "överhetta",
    "överhettads": "överhetta",
    "överhettande": "överhetta",
    "överhettanden": "överhettande",
    "överhettandena": "överhettande",
    "överhettandenas": "överhettande",
    "överhettandens": "överhettande",
    "överhettandes": "överhettande",
    "överhettandet": "överhettande",
    "överhettandets": "överhettande",
    "överhettar": "överhetta",
    "överhettas": "överhetta",
    "överhettat": "överhetta",
    "överhettats": "överhetta",
    "överhettningar": "överhettning",
    "överhettningarna": "överhettning",
    "överhettningarnas": "överhettning",
    "överhettningars": "överhettning",
    "överhettningen": "överhettning",
    "överhettningens": "överhettning",
    "överhettnings": "överhettning",
    "överhettningsskydden": "överhettningsskydd",
    "överhettningsskyddens": "överhettningsskydd",
    "överhettningsskyddet": "överhettningsskydd",
    "överhettningsskyddets": "överhettningsskydd",
    "överhettningsskydds": "överhettningsskydd",
    "överhop": "överhopa",
    "överhopad": "överhopa",
    "överhopade": "överhopad",
    "överhopades": "överhopad",
    "överhopads": "överhopad",
    "överhopande": "överhopa",
    "överhopanden": "överhopande",
    "överhopandena": "överhopande",
    "överhopandenas": "överhopande",
    "överhopandens": "överhopande",
    "överhopandes": "överhopande",
    "överhopandet": "överhopande",
    "överhopandets": "överhopande",
    "överhopar": "överhopa",
    "överhopas": "överhopa",
    "överhopat": "överhopad",
    "överhopats": "överhopad",
    "överhopp": "överhoppa",
    "överhoppad": "överhoppa",
    "överhoppade": "överhoppa",
    "överhoppades": "överhoppa",
    "överhoppads": "överhoppa",
    "överhoppande": "överhoppa",
    "överhoppanden": "överhoppande",
    "överhoppandena": "överhoppande",
    "överhoppandenas": "överhoppande",
    "överhoppandens": "överhoppande",
    "överhoppandes": "överhoppande",
    "överhoppandet": "överhoppande",
    "överhoppandets": "överhoppande",
    "överhoppar": "överhoppa",
    "överhoppas": "överhoppa",
    "överhoppat": "överhoppa",
    "överhoppats": "överhoppa",
    "överhuden": "överhud",
    "överhudens": "överhud",
    "överhuds": "överhud",
    "överhuset": "överhus",
    "överhusets": "överhus",
    "överhuvuden": "överhuvud",
    "överhuvudena": "överhuvud",
    "överhuvudenas": "överhuvud",
    "överhuvudens": "överhuvud",
    "överhuvudet": "överhuvud",
    "överhuvudets": "överhuvud",
    "överhuvuds": "överhuvud",
    "överhängen": "överhäng",
    "överhängens": "överhäng",
    "överhänget": "överhäng",
    "överhängets": "överhäng",
    "överhängs": "överhäng",
    "överhärdiga": "överhärdig",
    "överhärdigare": "överhärdig",
    "överhärdigares": "överhärdig",
    "överhärdigas": "överhärdig",
    "överhärdigast": "överhärdig",
    "överhärdigaste": "överhärdig",
    "överhärdigastes": "överhärdig",
    "överhärdigasts": "överhärdig",
    "överhärdige": "överhärdig",
    "överhärdiges": "överhärdig",
    "överhärdigheten": "överhärdighet",
    "överhärdighetens": "överhärdighet",
    "överhärdighets": "överhärdighet",
    "överhärdigs": "överhärdig",
    "överhärdigt": "överhärdig",
    "överhärdigts": "överhärdig",
    "överhögheten": "överhöghet",
    "överhöghetens": "överhöghet",
    "överhögheter": "överhöghet",
    "överhögheterna": "överhöghet",
    "överhögheternas": "överhöghet",
    "överhögheters": "överhöghet",
    "överhöghets": "överhöghet",
    "överhölj": "överhölja",
    "överhöljande": "överhölja",
    "överhöljanden": "överhöljande",
    "överhöljandena": "överhöljande",
    "överhöljandenas": "överhöljande",
    "överhöljandens": "överhöljande",
    "överhöljandes": "överhöljande",
    "överhöljandet": "överhöljande",
    "överhöljandets": "överhöljande",
    "överhöljas": "överhölja",
    "överhöljd": "överhölja",
    "överhöljda": "överhölja",
    "överhöljdas": "överhölja",
    "överhöljde": "överhölja",
    "överhöljdes": "överhölja",
    "överhöljds": "överhölja",
    "överhöljer": "överhölja",
    "överhöljes": "överhölja",
    "överhöljs": "överhölja",
    "överhöljt": "överhölja",
    "överhöljts": "överhölja",
    "överilade": "överilad",
    "överilades": "överilad",
    "överilads": "överilad",
    "överilat": "överilad",
    "överilats": "överilad",
    "överilningar": "överilning",
    "överilningarna": "överilning",
    "överilningarnas": "överilning",
    "överilningars": "överilning",
    "överilningen": "överilning",
    "överilningens": "överilning",
    "överilnings": "överilning",
    "överingenjören": "överingenjör",
    "överingenjörens": "överingenjör",
    "överingenjörer": "överingenjör",
    "överingenjörerna": "överingenjör",
    "överingenjörernas": "överingenjör",
    "överingenjörers": "överingenjör",
    "överingenjörn": "överingenjör",
    "överingenjörns": "överingenjör",
    "överingenjörs": "överingenjör",
    "överinlärningar": "överinlärning",
    "överinlärningarna": "överinlärning",
    "överinlärningarnas": "överinlärning",
    "överinlärningars": "överinlärning",
    "överinlärningen": "överinlärning",
    "överinlärningens": "överinlärning",
    "överinlärnings": "överinlärning",
    "överinseendes": "överinseende",
    "överinseendet": "överinseende",
    "överinseendets": "överinseende",
    "överintendenten": "överintendent",
    "överintendentens": "överintendent",
    "överintendenter": "överintendent",
    "överintendenterna": "överintendent",
    "överintendenternas": "överintendent",
    "överintendenters": "överintendent",
    "överintendents": "överintendent",
    "överjaget": "överjag",
    "överjagets": "överjag",
    "överjags": "överjag",
    "överjordiska": "överjordisk",
    "överjordiskare": "överjordisk",
    "överjordiskares": "överjordisk",
    "överjordiskas": "överjordisk",
    "överjordiskast": "överjordisk",
    "överjordiskaste": "överjordisk",
    "överjordiskastes": "överjordisk",
    "överjordiskasts": "överjordisk",
    "överjordiske": "överjordisk",
    "överjordiskes": "överjordisk",
    "överjordisks": "överjordisk",
    "överjordiskt": "överjordisk",
    "överjordiskts": "överjordisk",
    "överjäsningar": "överjäsning",
    "överjäsningarna": "överjäsning",
    "överjäsningarnas": "överjäsning",
    "överjäsningars": "överjäsning",
    "överjäsningen": "överjäsning",
    "överjäsningens": "överjäsning",
    "överjäsnings": "överjäsning",
    "överkasten": "överkast",
    "överkastens": "överkast",
    "överkastet": "överkast",
    "överkastets": "överkast",
    "överkasts": "överkast",
    "överklag": "överklaga",
    "överklagad": "överklaga",
    "överklagade": "överklaga",
    "överklagades": "överklaga",
    "överklagads": "överklaga",
    "överklagande": "överklaga",
    "överklaganden": "överklagande",
    "överklagandena": "överklagande",
    "överklagandenas": "överklagande",
    "överklagandens": "överklagande",
    "överklagandes": "överklagande",
    "överklagandet": "överklagande",
    "överklagandets": "överklagande",
    "överklagar": "överklaga",
    "överklagas": "överklaga",
    "överklagat": "överklaga",
    "överklagats": "överklaga",
    "överklassar": "överklassare",
    "överklassaren": "överklassare",
    "överklassarens": "överklassare",
    "överklassares": "överklassare",
    "överklassarna": "överklassare",
    "överklassarnas": "överklassare",
    "överklassen": "överklass",
    "överklassens": "överklass",
    "överklasser": "överklass",
    "överklasserna": "överklass",
    "överklassernas": "överklass",
    "överklassers": "överklass",
    "överklassflick": "överklassflicka",
    "överklassflickan": "överklassflicka",
    "överklassflickans": "överklassflicka",
    "överklassflickas": "överklassflicka",
    "överklassflicke": "överklassflicka",
    "överklassflickor": "överklassflicka",
    "överklassflickorna": "överklassflicka",
    "överklassflickornas": "överklassflicka",
    "överklassflickors": "överklassflicka",
    "överklassflicks": "överklassflicka",
    "överklassiga": "överklassig",
    "överklassigare": "överklassig",
    "överklassigares": "överklassig",
    "överklassigas": "överklassig",
    "överklassigast": "överklassig",
    "överklassigaste": "överklassig",
    "överklassigastes": "överklassig",
    "överklassigasts": "överklassig",
    "överklassige": "överklassig",
    "överklassiges": "överklassig",
    "överklassigheten": "överklassighet",
    "överklassighetens": "överklassighet",
    "överklassighets": "överklassighet",
    "överklassigs": "överklassig",
    "överklassigt": "överklassig",
    "överklassigts": "överklassig",
    "överklassmiljöer": "överklassmiljö",
    "överklassmiljöerna": "överklassmiljö",
    "överklassmiljöernas": "överklassmiljö",
    "överklassmiljöers": "överklassmiljö",
    "överklassmiljön": "överklassmiljö",
    "överklassmiljöns": "överklassmiljö",
    "överklassmiljös": "överklassmiljö",
    "överklasstanten": "överklasstant",
    "överklasstantens": "överklasstant",
    "överklasstanter": "överklasstant",
    "överklasstanterna": "överklasstant",
    "överklasstanternas": "överklasstant",
    "överklasstanters": "överklasstant",
    "överklasstants": "överklasstant",
    "överklivningar": "överklivning",
    "överklivningarna": "överklivning",
    "överklivningarnas": "överklivning",
    "överklivningars": "överklivning",
    "överklivningen": "överklivning",
    "överklivningens": "överklivning",
    "överklivnings": "överklivning",
    "överkomliga": "överkomlig",
    "överkomligare": "överkomlig",
    "överkomligares": "överkomlig",
    "överkomligas": "överkomlig",
    "överkomligast": "överkomlig",
    "överkomligaste": "överkomlig",
    "överkomligastes": "överkomlig",
    "överkomligasts": "överkomlig",
    "överkomlige": "överkomlig",
    "överkomliges": "överkomlig",
    "överkomligheten": "överkomlighet",
    "överkomlighetens": "överkomlighet",
    "överkomlighets": "överkomlighet",
    "överkomligs": "överkomlig",
    "överkomligt": "överkomlig",
    "överkomligts": "överkomlig",
    "överkommandon": "överkommando",
    "överkommandona": "överkommando",
    "överkommandonas": "överkommando",
    "överkommandons": "överkommando",
    "överkommandos": "överkommando",
    "överkommandot": "överkommando",
    "överkommandots": "överkommando",
    "överkompenserad": "överkompensera",
    "överkompenserade": "överkompensera",
    "överkompenserades": "överkompensera",
    "överkompenserads": "överkompensera",
    "överkompenserande": "överkompensera",
    "överkompenseranden": "överkompenserande",
    "överkompenserandena": "överkompenserande",
    "överkompenserandenas": "överkompenserande",
    "överkompenserandens": "överkompenserande",
    "överkompenserandes": "överkompenserande",
    "överkompenserandet": "överkompenserande",
    "överkompenserandets": "överkompenserande",
    "överkompenserar": "överkompensera",
    "överkompenseras": "överkompensera",
    "överkompenserat": "överkompensera",
    "överkompenserats": "överkompensera",
    "överkompenserbara": "överkompenserbar",
    "överkompenserbarare": "överkompenserbar",
    "överkompenserbarares": "överkompenserbar",
    "överkompenserbaras": "överkompenserbar",
    "överkompenserbarast": "överkompenserbar",
    "överkompenserbaraste": "överkompenserbar",
    "överkompenserbarastes": "överkompenserbar",
    "överkompenserbarasts": "överkompenserbar",
    "överkompenserbare": "överkompenserbar",
    "överkompenserbares": "överkompenserbar",
    "överkompenserbarheten": "överkompenserbarhet",
    "överkompenserbarhetens": "överkompenserbarhet",
    "överkompenserbarhets": "överkompenserbarhet",
    "överkompenserbars": "överkompenserbar",
    "överkompenserbart": "överkompenserbar",
    "överkompenserbarts": "överkompenserbar",
    "överkompenseringar": "överkompensering",
    "överkompenseringarna": "överkompensering",
    "överkompenseringarnas": "överkompensering",
    "överkompenseringars": "överkompensering",
    "överkompenseringen": "överkompensering",
    "överkompenseringens": "överkompensering",
    "överkompenserings": "överkompensering",
    "överkonsumtionen": "överkonsumtion",
    "överkonsumtionens": "överkonsumtion",
    "överkonsumtioner": "överkonsumtion",
    "överkonsumtionerna": "överkonsumtion",
    "överkonsumtionernas": "överkonsumtion",
    "överkonsumtioners": "överkonsumtion",
    "överkonsumtions": "överkonsumtion",
    "överkragningar": "överkragning",
    "överkragningarna": "överkragning",
    "överkragningarnas": "överkragning",
    "överkragningars": "överkragning",
    "överkragningen": "överkragning",
    "överkragningens": "överkragning",
    "överkragnings": "överkragning",
    "överkroppar": "överkropp",
    "överkropparna": "överkropp",
    "överkropparnas": "överkropp",
    "överkroppars": "överkropp",
    "överkroppen": "överkropp",
    "överkroppens": "överkropp",
    "överkropps": "överkropp",
    "överkuckuar": "överkucku",
    "överkuckuarna": "överkucku",
    "överkuckuarnas": "överkucku",
    "överkuckuars": "överkucku",
    "överkuckun": "överkucku",
    "överkuckuns": "överkucku",
    "överkuckus": "överkucku",
    "överkursen": "överkurs",
    "överkursens": "överkurs",
    "överkurser": "överkurs",
    "överkurserna": "överkurs",
    "överkursernas": "överkurs",
    "överkursers": "överkurs",
    "överkvalificerade": "överkvalificerad",
    "överkvalificerades": "överkvalificerad",
    "överkvalificerads": "överkvalificerad",
    "överkvalificerat": "överkvalificerad",
    "överkvalificerats": "överkvalificerad",
    "överkäk": "överkäke",
    "överkäkar": "överkäke",
    "överkäkarna": "överkäke",
    "överkäkarnas": "överkäke",
    "överkäkars": "överkäke",
    "överkäken": "överkäke",
    "överkäkens": "överkäke",
    "överkäkes": "överkäke",
    "överkäks": "överkäke",
    "överkäksbenen": "överkäksben",
    "överkäksbenens": "överkäksben",
    "överkäksbenet": "överkäksben",
    "överkäksbenets": "överkäksben",
    "överkäksbens": "överkäksben",
    "överkänsliga": "överkänslig",
    "överkänsligare": "överkänslig",
    "överkänsligares": "överkänslig",
    "överkänsligas": "överkänslig",
    "överkänsligast": "överkänslig",
    "överkänsligaste": "överkänslig",
    "överkänsligastes": "överkänslig",
    "överkänsligasts": "överkänslig",
    "överkänslige": "överkänslig",
    "överkänsliges": "överkänslig",
    "överkänsligheten": "överkänslighet",
    "överkänslighetens": "överkänslighet",
    "överkänsligheter": "överkänslighet",
    "överkänsligheterna": "överkänslighet",
    "överkänsligheternas": "överkänslighet",
    "överkänsligheters": "överkänslighet",
    "överkänslighets": "överkänslighet",
    "överkänsligs": "överkänslig",
    "överkänsligt": "överkänslig",
    "överkänsligts": "överkänslig",
    "överkörda": "överkörd",
    "överkördare": "överkörd",
    "överkördares": "överkörd",
    "överkördas": "överkörd",
    "överkördast": "överkörd",
    "överkördaste": "överkörd",
    "överkördastes": "överkörd",
    "överkördasts": "överkörd",
    "överkörde": "överkörd",
    "överkördes": "överkörd",
    "överkörds": "överkörd",
    "överkört": "överkörd",
    "överkörts": "överkörd",
    "överla": "överlägga",
    "överlackerbara": "överlackerbar",
    "överlackerbarare": "överlackerbar",
    "överlackerbarares": "överlackerbar",
    "överlackerbaras": "överlackerbar",
    "överlackerbarast": "överlackerbar",
    "överlackerbaraste": "överlackerbar",
    "överlackerbarastes": "överlackerbar",
    "överlackerbarasts": "överlackerbar",
    "överlackerbare": "överlackerbar",
    "överlackerbares": "överlackerbar",
    "överlackerbarheten": "överlackerbarhet",
    "överlackerbarhetens": "överlackerbarhet",
    "överlackerbarhets": "överlackerbarhet",
    "överlackerbars": "överlackerbar",
    "överlackerbart": "överlackerbar",
    "överlackerbarts": "överlackerbar",
    "överlackeringsbara": "överlackeringsbar",
    "överlackeringsbarare": "överlackeringsbar",
    "överlackeringsbarares": "överlackeringsbar",
    "överlackeringsbaras": "överlackeringsbar",
    "överlackeringsbarast": "överlackeringsbar",
    "överlackeringsbaraste": "överlackeringsbar",
    "överlackeringsbarastes": "överlackeringsbar",
    "överlackeringsbarasts": "överlackeringsbar",
    "överlackeringsbare": "överlackeringsbar",
    "överlackeringsbares": "överlackeringsbar",
    "överlackeringsbarheten": "överlackeringsbarhet",
    "överlackeringsbarhetens": "överlackeringsbarhet",
    "överlackeringsbarhets": "överlackeringsbarhet",
    "överlackeringsbars": "överlackeringsbar",
    "överlackeringsbart": "överlackeringsbar",
    "överlackeringsbarts": "överlackeringsbar",
    "överladdningen": "överladdning",
    "överladdningens": "överladdning",
    "överladdnings": "överladdning",
    "överladdningsskydden": "överladdningsskydd",
    "överladdningsskyddens": "överladdningsskydd",
    "överladdningsskyddet": "överladdningsskydd",
    "överladdningsskyddets": "överladdningsskydd",
    "överladdningsskydds": "överladdningsskydd",
    "överlade": "överlägga",
    "överlades": "överlägga",
    "överlagd": "överlägga",
    "överlagda": "överlägga",
    "överlagdare": "överlagd",
    "överlagdares": "överlagd",
    "överlagdas": "överlägga",
    "överlagdast": "överlagd",
    "överlagdaste": "överlagd",
    "överlagdastes": "överlagd",
    "överlagdasts": "överlagd",
    "överlagde": "överlägga",
    "överlagdes": "överlägga",
    "överlagdheten": "överlagdhet",
    "överlagdhetens": "överlagdhet",
    "överlagdhets": "överlagdhet",
    "överlagds": "överlägga",
    "överlagrad": "överlagra",
    "överlagrade": "överlagra",
    "överlagrades": "överlagra",
    "överlagrads": "överlagra",
    "överlagrande": "överlagra",
    "överlagranden": "överlagrande",
    "överlagrandena": "överlagrande",
    "överlagrandenas": "överlagrande",
    "överlagrandens": "överlagrande",
    "överlagrandes": "överlagrande",
    "överlagrandet": "överlagrande",
    "överlagrandets": "överlagrande",
    "överlagrar": "överlagra",
    "överlagras": "överlagra",
    "överlagrat": "överlagra",
    "överlagrats": "överlagra",
    "överlagt": "överlägga",
    "överlagts": "överlägga",
    "överlakanen": "överlakan",
    "överlakanens": "överlakan",
    "överlakanet": "överlakan",
    "överlakanets": "överlakan",
    "överlakans": "överlakan",
    "överlapp": "överlappa",
    "överlappad": "överlappa",
    "överlappade": "överlappa",
    "överlappades": "överlappa",
    "överlappads": "överlappa",
    "överlappande": "överlappa",
    "överlappanden": "överlappande",
    "överlappandena": "överlappande",
    "överlappandenas": "överlappande",
    "överlappandens": "överlappande",
    "överlappandes": "överlappande",
    "överlappandet": "överlappande",
    "överlappandets": "överlappande",
    "överlappar": "överlappa",
    "överlapparna": "överlapp",
    "överlapparnas": "överlapp",
    "överlappars": "överlapp",
    "överlappas": "överlappa",
    "överlappat": "överlappa",
    "överlappats": "överlappa",
    "överlappen": "överlapp",
    "överlappens": "överlapp",
    "överlappningar": "överlappning",
    "överlappningarna": "överlappning",
    "överlappningarnas": "överlappning",
    "överlappningars": "överlappning",
    "överlappningen": "överlappning",
    "överlappningens": "överlappning",
    "överlappnings": "överlappning",
    "överlapps": "överlapp",
    "överlas": "överlägga",
    "överlast": "överlasta",
    "överlastade": "överlastad",
    "överlastades": "överlastad",
    "överlastads": "överlastad",
    "överlastande": "överlasta",
    "överlastandes": "överlasta",
    "överlastar": "överlasta",
    "överlastas": "överlasta",
    "överlastat": "överlastad",
    "överlastats": "överlastad",
    "överlasten": "överlast",
    "överlastens": "överlast",
    "överlaster": "överlast",
    "överlasterna": "överlast",
    "överlasternas": "överlast",
    "överlasters": "överlast",
    "överlastningen": "överlastning",
    "överlastningens": "överlastning",
    "överlastnings": "överlastning",
    "överlasts": "överlast",
    "överlev": "överleva",
    "överlevan": "överleva",
    "överlevande": "överleva",
    "överlevanden": "överlevande",
    "överlevandena": "överlevande",
    "överlevandenas": "överlevande",
    "överlevandens": "överlevande",
    "överlevandes": "överlevande",
    "överlevandet": "överlevande",
    "överlevandets": "överlevande",
    "överlevans": "överleva",
    "överlevas": "överleva",
    "överlevat": "överleva",
    "överlevats": "överleva",
    "överlevd": "överleva",
    "överlevda": "överleva",
    "överlevdas": "överleva",
    "överlevde": "överleva",
    "överlevdes": "överleva",
    "överlevds": "överleva",
    "överleve": "överleva",
    "överlever": "överleva",
    "överleves": "överleva",
    "överlevnaden": "överlevnad",
    "överlevnadens": "överlevnad",
    "överlevnader": "överlevnad",
    "överlevnaderna": "överlevnad",
    "överlevnadernas": "överlevnad",
    "överlevnaders": "överlevnad",
    "överlevnads": "överlevnad",
    "överlevnadschansen": "överlevnadschans",
    "överlevnadschansens": "överlevnadschans",
    "överlevnadschanser": "överlevnadschans",
    "överlevnadschanserna": "överlevnadschans",
    "överlevnadschansernas": "överlevnadschans",
    "överlevnadschansers": "överlevnadschans",
    "överlevnadsförmågan": "överlevnadsförmåga",
    "överlevnadsförmågans": "överlevnadsförmåga",
    "överlevnadsförmågas": "överlevnadsförmåga",
    "överlevnadsförmåge": "överlevnadsförmåga",
    "överlevnadsförmågor": "överlevnadsförmåga",
    "överlevnadsförmågorna": "överlevnadsförmåga",
    "överlevnadsförmågornas": "överlevnadsförmåga",
    "överlevnadsförmågors": "överlevnadsförmåga",
    "överlevnadsinstinkten": "överlevnadsinstinkt",
    "överlevnadsinstinktens": "överlevnadsinstinkt",
    "överlevnadsinstinkter": "överlevnadsinstinkt",
    "överlevnadsinstinkterna": "överlevnadsinstinkt",
    "överlevnadsinstinkternas": "överlevnadsinstinkt",
    "överlevnadsinstinkters": "överlevnadsinstinkt",
    "överlevnadsinstinkts": "överlevnadsinstinkt",
    "överlevnadskursen": "överlevnadskurs",
    "överlevnadskursens": "överlevnadskurs",
    "överlevnadskurser": "överlevnadskurs",
    "överlevnadskurserna": "överlevnadskurs",
    "överlevnadskursernas": "överlevnadskurs",
    "överlevnadskursers": "överlevnadskurs",
    "överlevnadsskälen": "överlevnadsskäl",
    "överlevnadsskälens": "överlevnadsskäl",
    "överlevnadsskälet": "överlevnadsskäl",
    "överlevnadsskälets": "överlevnadsskäl",
    "överlevnadsskäls": "överlevnadsskäl",
    "överlevnadsångesten": "överlevnadsångest",
    "överlevnadsångestens": "överlevnadsångest",
    "överlevnadsångests": "överlevnadsångest",
    "överlevor": "överleva",
    "överlevorna": "överleva",
    "överlevornas": "överleva",
    "överlevors": "överleva",
    "överlevs": "överleva",
    "överlevt": "överleva",
    "överlevts": "överleva",
    "överliggar": "överliggare",
    "överliggaren": "överliggare",
    "överliggarens": "överliggare",
    "överliggares": "överliggare",
    "överliggarna": "överliggare",
    "överliggarnas": "överliggare",
    "överlist": "överlista",
    "överlistad": "överlista",
    "överlistade": "överlista",
    "överlistades": "överlista",
    "överlistads": "överlista",
    "överlistande": "överlista",
    "överlistanden": "överlistande",
    "överlistandena": "överlistande",
    "överlistandenas": "överlistande",
    "överlistandens": "överlistande",
    "överlistandes": "överlistande",
    "överlistandet": "överlistande",
    "överlistandets": "överlistande",
    "överlistar": "överlista",
    "överlistas": "överlista",
    "överlistat": "överlista",
    "överlistats": "överlista",
    "överliven": "överliv",
    "överlivens": "överliv",
    "överlivet": "överliv",
    "överlivets": "överliv",
    "överlivs": "överliv",
    "överljudsfarten": "överljudsfart",
    "överljudsfartens": "överljudsfart",
    "överljudsfarter": "överljudsfart",
    "överljudsfarterna": "överljudsfart",
    "överljudsfarternas": "överljudsfart",
    "överljudsfarters": "överljudsfart",
    "överljudsfarts": "överljudsfart",
    "överljudsplanen": "överljudsplan",
    "överljudsplanens": "överljudsplan",
    "överljudsplanet": "överljudsplan",
    "överljudsplanets": "överljudsplan",
    "överljudsplans": "överljudsplan",
    "överloppsenergien": "överloppsenergi",
    "överloppsenergiens": "överloppsenergi",
    "överloppsenergin": "överloppsenergi",
    "överloppsenergins": "överloppsenergi",
    "överloppsenergis": "överloppsenergi",
    "överloppsgärningar": "överloppsgärning",
    "överloppsgärningarna": "överloppsgärning",
    "överloppsgärningarnas": "överloppsgärning",
    "överloppsgärningars": "överloppsgärning",
    "överloppsgärningen": "överloppsgärning",
    "överloppsgärningens": "överloppsgärning",
    "överloppsgärnings": "överloppsgärning",
    "överlupens": "överlupen",
    "överlupet": "överlupen",
    "överlupets": "överlupen",
    "överlupna": "överlupen",
    "överlupnare": "överlupen",
    "överlupnares": "överlupen",
    "överlupnas": "överlupen",
    "överlupnast": "överlupen",
    "överlupnaste": "överlupen",
    "överlupnastes": "överlupen",
    "överlupnasts": "överlupen",
    "överlupne": "överlupen",
    "överlupnes": "överlupen",
    "överlyckliga": "överlycklig",
    "överlyckligare": "överlycklig",
    "överlyckligares": "överlycklig",
    "överlyckligas": "överlycklig",
    "överlyckligast": "överlycklig",
    "överlyckligaste": "överlycklig",
    "överlyckligastes": "överlycklig",
    "överlyckligasts": "överlycklig",
    "överlycklige": "överlycklig",
    "överlyckliges": "överlycklig",
    "överlyckligheten": "överlycklighet",
    "överlycklighetens": "överlycklighet",
    "överlycklighets": "överlycklighet",
    "överlyckligs": "överlycklig",
    "överlyckligt": "överlycklig",
    "överlyckligts": "överlycklig",
    "överlägen": "överläge",
    "överlägena": "överläge",
    "överlägenas": "överläge",
    "överlägens": "överläge",
    "överläges": "överläge",
    "överläget": "överläge",
    "överlägets": "överläge",
    "överlägg": "överlägga",
    "överläggande": "överlägga",
    "överlägganden": "överläggande",
    "överläggandena": "överläggande",
    "överläggandenas": "överläggande",
    "överläggandens": "överläggande",
    "överläggandes": "överläggande",
    "överläggandet": "överläggande",
    "överläggandets": "överläggande",
    "överläggas": "överlägga",
    "överlägger": "överlägga",
    "överlägges": "överlägga",
    "överläggningar": "överläggning",
    "överläggningarna": "överläggning",
    "överläggningarnas": "överläggning",
    "överläggningars": "överläggning",
    "överläggningen": "överläggning",
    "överläggningens": "överläggning",
    "överläggnings": "överläggning",
    "överläggs": "överlägga",
    "överlägsenheten": "överlägsenhet",
    "överlägsenhetens": "överlägsenhet",
    "överlägsenheter": "överlägsenhet",
    "överlägsenheterna": "överlägsenhet",
    "överlägsenheternas": "överlägsenhet",
    "överlägsenheters": "överlägsenhet",
    "överlägsenhets": "överlägsenhet",
    "överlägsens": "överlägsen",
    "överlägset": "överlägsen",
    "överlägsets": "överlägsen",
    "överlägsna": "överlägsen",
    "överlägsnare": "överlägsen",
    "överlägsnares": "överlägsen",
    "överlägsnas": "överlägsen",
    "överlägsnast": "överlägsen",
    "överlägsnaste": "överlägsen",
    "överlägsnastes": "överlägsen",
    "överlägsnasts": "överlägsen",
    "överlägsne": "överlägsen",
    "överlägsnes": "överlägsen",
    "överläkar": "överläkare",
    "överläkaren": "överläkare",
    "överläkarens": "överläkare",
    "överläkares": "överläkare",
    "överläkarna": "överläkare",
    "överläkarnas": "överläkare",
    "överlämnad": "överlämna",
    "överlämnade": "överlämna",
    "överlämnades": "överlämna",
    "överlämnads": "överlämna",
    "överlämnande": "överlämna",
    "överlämnanden": "överlämnande",
    "överlämnandena": "överlämnande",
    "överlämnandenas": "överlämnande",
    "överlämnandens": "överlämnande",
    "överlämnandes": "överlämnande",
    "överlämnandet": "överlämnande",
    "överlämnandets": "överlämnande",
    "överlämnar": "överlämna",
    "överlämnas": "överlämna",
    "överlämnat": "överlämna",
    "överlämnats": "överlämna",
    "överläppar": "överläpp",
    "överläpparna": "överläpp",
    "överläpparnas": "överläpp",
    "överläppars": "överläpp",
    "överläppen": "överläpp",
    "överläppens": "överläpp",
    "överläpps": "överläpp",
    "överlärar": "överlärare",
    "överläraren": "överlärare",
    "överlärarens": "överlärare",
    "överlärares": "överlärare",
    "överlärarna": "överlärare",
    "överlärarnas": "överlärare",
    "överlät": "överlåta",
    "överläts": "överlåta",
    "överlåt": "överlåta",
    "överlåtande": "överlåta",
    "överlåtanden": "överlåtande",
    "överlåtandena": "överlåtande",
    "överlåtandenas": "överlåtande",
    "överlåtandens": "överlåtande",
    "överlåtandes": "överlåtande",
    "överlåtandet": "överlåtande",
    "överlåtandets": "överlåtande",
    "överlåtas": "överlåta",
    "överlåte": "överlåta",
    "överlåtelsen": "överlåtelse",
    "överlåtelsens": "överlåtelse",
    "överlåtelser": "överlåtelse",
    "överlåtelserna": "överlåtelse",
    "överlåtelsernas": "överlåtelse",
    "överlåtelsers": "överlåtelse",
    "överlåtelses": "överlåtelse",
    "överlåten": "överlåta",
    "överlåtens": "överlåta",
    "överlåter": "överlåta",
    "överlåtes": "överlåta",
    "överlåtet": "överlåta",
    "överlåtets": "överlåta",
    "överlåtit": "överlåta",
    "överlåtits": "överlåta",
    "överlåtna": "överlåta",
    "överlåtnas": "överlåta",
    "överlåtne": "överlåta",
    "överlåtnes": "överlåta",
    "överlåts": "överlåta",
    "överlöpar": "överlöpare",
    "överlöparen": "överlöpare",
    "överlöparens": "överlöpare",
    "överlöpares": "överlöpare",
    "överlöparna": "överlöpare",
    "överlöparnas": "överlöpare",
    "övermakten": "övermakt",
    "övermaktens": "övermakt",
    "övermakts": "övermakt",
    "övermann": "övermanna",
    "övermannad": "övermanna",
    "övermannade": "övermanna",
    "övermannades": "övermanna",
    "övermannads": "övermanna",
    "övermannande": "övermanna",
    "övermannanden": "övermannande",
    "övermannandena": "övermannande",
    "övermannandenas": "övermannande",
    "övermannandens": "övermannande",
    "övermannandes": "övermannande",
    "övermannandet": "övermannande",
    "övermannandets": "övermannande",
    "övermannar": "övermanna",
    "övermannas": "övermanna",
    "övermannat": "övermanna",
    "övermannats": "övermanna",
    "övermannen": "överman",
    "övermannens": "överman",
    "övermans": "överman",
    "övermodet": "övermod",
    "övermodets": "övermod",
    "övermodiga": "övermodig",
    "övermodigare": "övermodig",
    "övermodigares": "övermodig",
    "övermodigas": "övermodig",
    "övermodigast": "övermodig",
    "övermodigaste": "övermodig",
    "övermodigastes": "övermodig",
    "övermodigasts": "övermodig",
    "övermodige": "övermodig",
    "övermodiges": "övermodig",
    "övermodigheten": "övermodighet",
    "övermodighetens": "övermodighet",
    "övermodighets": "övermodighet",
    "övermodigs": "övermodig",
    "övermodigt": "övermodig",
    "övermodigts": "övermodig",
    "övermods": "övermod",
    "övermogens": "övermogen",
    "övermoget": "övermogen",
    "övermogets": "övermogen",
    "övermogna": "övermogen",
    "övermognare": "övermogen",
    "övermognares": "övermogen",
    "övermognas": "övermogen",
    "övermognast": "övermogen",
    "övermognaste": "övermogen",
    "övermognastes": "övermogen",
    "övermognasts": "övermogen",
    "övermogne": "övermogen",
    "övermognes": "övermogen",
    "övermäktiga": "övermäktig",
    "övermäktigare": "övermäktig",
    "övermäktigares": "övermäktig",
    "övermäktigas": "övermäktig",
    "övermäktigast": "övermäktig",
    "övermäktigaste": "övermäktig",
    "övermäktigastes": "övermäktig",
    "övermäktigasts": "övermäktig",
    "övermäktige": "övermäktig",
    "övermäktiges": "övermäktig",
    "övermäktigheten": "övermäktighet",
    "övermäktighetens": "övermäktighet",
    "övermäktighets": "övermäktighet",
    "övermäktigs": "övermäktig",
    "övermäktigt": "övermäktig",
    "övermäktigts": "övermäktig",
    "övermän": "överman",
    "övermännen": "överman",
    "övermännens": "överman",
    "övermänniskan": "övermänniska",
    "övermänniskans": "övermänniska",
    "övermänniskas": "övermänniska",
    "övermännisko": "övermänniska",
    "övermänniskor": "övermänniska",
    "övermänniskorna": "övermänniska",
    "övermänniskornas": "övermänniska",
    "övermänniskors": "övermänniska",
    "övermäns": "överman",
    "övermänskliga": "övermänsklig",
    "övermänskligare": "övermänsklig",
    "övermänskligares": "övermänsklig",
    "övermänskligas": "övermänsklig",
    "övermänskligast": "övermänsklig",
    "övermänskligaste": "övermänsklig",
    "övermänskligastes": "övermänsklig",
    "övermänskligasts": "övermänsklig",
    "övermänsklige": "övermänsklig",
    "övermänskliges": "övermänsklig",
    "övermänskligheten": "övermänsklighet",
    "övermänsklighetens": "övermänsklighet",
    "övermänsklighets": "övermänsklighet",
    "övermänskligs": "övermänsklig",
    "övermänskligt": "övermänsklig",
    "övermänskligts": "övermänsklig",
    "övermätta": "övermätt",
    "övermättare": "övermätt",
    "övermättares": "övermätt",
    "övermättas": "övermätt",
    "övermättast": "övermätt",
    "övermättaste": "övermätt",
    "övermättastes": "övermätt",
    "övermättasts": "övermätt",
    "övermätte": "övermätt",
    "övermättes": "övermätt",
    "övermättheten": "övermätthet",
    "övermätthetens": "övermätthet",
    "övermätthets": "övermätthet",
    "övermätts": "övermätt",
    "övermålningsbara": "övermålningsbar",
    "övermålningsbarare": "övermålningsbar",
    "övermålningsbarares": "övermålningsbar",
    "övermålningsbaras": "övermålningsbar",
    "övermålningsbarast": "övermålningsbar",
    "övermålningsbaraste": "övermålningsbar",
    "övermålningsbarastes": "övermålningsbar",
    "övermålningsbarasts": "övermålningsbar",
    "övermålningsbare": "övermålningsbar",
    "övermålningsbares": "övermålningsbar",
    "övermålningsbarheten": "övermålningsbarhet",
    "övermålningsbarhetens": "övermålningsbarhet",
    "övermålningsbarhets": "övermålningsbarhet",
    "övermålningsbars": "övermålningsbar",
    "övermålningsbart": "övermålningsbar",
    "övermålningsbarts": "övermålningsbar",
    "övermåttet": "övermått",
    "övermåttets": "övermått",
    "övermåtts": "övermått",
    "övernationella": "övernationell",
    "övernationellare": "övernationell",
    "övernationellares": "övernationell",
    "övernationellas": "övernationell",
    "övernationellast": "övernationell",
    "övernationellaste": "övernationell",
    "övernationellastes": "övernationell",
    "övernationellasts": "övernationell",
    "övernationelle": "övernationell",
    "övernationelles": "övernationell",
    "övernationells": "övernationell",
    "övernationellt": "övernationell",
    "övernationellts": "övernationell",
    "övernattade": "övernatta",
    "övernattades": "övernatta",
    "övernattande": "övernatta",
    "övernattanden": "övernattande",
    "övernattandena": "övernattande",
    "övernattandenas": "övernattande",
    "övernattandens": "övernattande",
    "övernattandes": "övernattande",
    "övernattandet": "övernattande",
    "övernattandets": "övernattande",
    "övernattar": "övernatta",
    "övernattas": "övernatta",
    "övernattat": "övernatta",
    "övernattats": "övernatta",
    "övernattningar": "övernattning",
    "övernattningarna": "övernattning",
    "övernattningarnas": "övernattning",
    "övernattningars": "övernattning",
    "övernattningen": "övernattning",
    "övernattningens": "övernattning",
    "övernattnings": "övernattning",
    "övernattningslägenheten": "övernattningslägenhet",
    "övernattningslägenhetens": "övernattningslägenhet",
    "övernattningslägenheter": "övernattningslägenhet",
    "övernattningslägenheterna": "övernattningslägenhet",
    "övernattningslägenheternas": "övernattningslägenhet",
    "övernattningslägenheters": "övernattningslägenhet",
    "övernattningslägenhets": "övernattningslägenhet",
    "övernattningsmöjligheten": "övernattningsmöjlighet",
    "övernattningsmöjlighetens": "övernattningsmöjlighet",
    "övernattningsmöjligheter": "övernattningsmöjlighet",
    "övernattningsmöjligheterna": "övernattningsmöjlighet",
    "övernattningsmöjligheternas": "övernattningsmöjlighet",
    "övernattningsmöjligheters": "övernattningsmöjlighet",
    "övernattningsmöjlighets": "övernattningsmöjlighet",
    "övernattningsrummen": "övernattningsrum",
    "övernattningsrummens": "övernattningsrum",
    "övernattningsrummet": "övernattningsrum",
    "övernattningsrummets": "övernattningsrum",
    "övernattningsrums": "övernattningsrum",
    "övernaturliga": "övernaturlig",
    "övernaturligare": "övernaturlig",
    "övernaturligares": "övernaturlig",
    "övernaturligas": "övernaturlig",
    "övernaturligast": "övernaturlig",
    "övernaturligaste": "övernaturlig",
    "övernaturligastes": "övernaturlig",
    "övernaturligasts": "övernaturlig",
    "övernaturlige": "övernaturlig",
    "övernaturliges": "övernaturlig",
    "övernaturligheten": "övernaturlighet",
    "övernaturlighetens": "övernaturlighet",
    "övernaturligheter": "övernaturlighet",
    "övernaturligheterna": "övernaturlighet",
    "övernaturligheternas": "övernaturlighet",
    "övernaturligheters": "övernaturlighet",
    "övernaturlighets": "övernaturlighet",
    "övernaturligs": "övernaturlig",
    "övernaturligt": "övernaturlig",
    "övernaturligts": "övernaturlig",
    "överniten": "övernit",
    "övernitens": "övernit",
    "övernitet": "övernit",
    "övernitets": "övernit",
    "övernitiska": "övernitisk",
    "övernitiskare": "övernitisk",
    "övernitiskares": "övernitisk",
    "övernitiskas": "övernitisk",
    "övernitiskast": "övernitisk",
    "övernitiskaste": "övernitisk",
    "övernitiskastes": "övernitisk",
    "övernitiskasts": "övernitisk",
    "övernitiske": "övernitisk",
    "övernitiskes": "övernitisk",
    "övernitisks": "övernitisk",
    "övernitiskt": "övernitisk",
    "övernitiskts": "övernitisk",
    "övernits": "övernit",
    "överorden": "överord",
    "överordens": "överord",
    "överordet": "överord",
    "överordets": "överord",
    "överordnad": "överordna",
    "överordnade": "överordnad",
    "överordnades": "överordnad",
    "överordnads": "överordnad",
    "överordnande": "överordna",
    "överordnanden": "överordnande",
    "överordnandena": "överordnande",
    "överordnandenas": "överordnande",
    "överordnandens": "överordnande",
    "överordnandes": "överordnande",
    "överordnandet": "överordnande",
    "överordnandets": "överordnande",
    "överordnar": "överordna",
    "överordnas": "överordna",
    "överordnat": "överordnad",
    "överordnats": "överordnad",
    "överords": "överord",
    "överplaggen": "överplagg",
    "överplaggens": "överplagg",
    "överplagget": "överplagg",
    "överplaggets": "överplagg",
    "överplaggs": "överplagg",
    "överprisen": "överpris",
    "överprisens": "överpris",
    "överpriser": "överpris",
    "överpriserna": "överpris",
    "överprisernas": "överpris",
    "överprisers": "överpris",
    "överpriset": "överpris",
    "överprisets": "överpris",
    "överproduktionen": "överproduktion",
    "överproduktionens": "överproduktion",
    "överproduktioner": "överproduktion",
    "överproduktionerna": "överproduktion",
    "överproduktionernas": "överproduktion",
    "överproduktioners": "överproduktion",
    "överproduktions": "överproduktion",
    "överpröv": "överpröva",
    "överprövad": "överpröva",
    "överprövade": "överpröva",
    "överprövades": "överpröva",
    "överprövads": "överpröva",
    "överprövande": "överpröva",
    "överprövanden": "överprövande",
    "överprövandena": "överprövande",
    "överprövandenas": "överprövande",
    "överprövandens": "överprövande",
    "överprövandes": "överprövande",
    "överprövandet": "överprövande",
    "överprövandets": "överprövande",
    "överprövar": "överpröva",
    "överprövas": "överpröva",
    "överprövat": "överpröva",
    "överprövats": "överpröva",
    "överraskad": "överraska",
    "överraskade": "överraskad",
    "överraskades": "överraskad",
    "överraskads": "överraskad",
    "överraskande": "överraska",
    "överraskanden": "överraskande",
    "överraskandena": "överraskande",
    "överraskandenas": "överraskande",
    "överraskandens": "överraskande",
    "överraskandes": "överraskande",
    "överraskandet": "överraskande",
    "överraskandets": "överraskande",
    "överraskar": "överraska",
    "överraskas": "överraska",
    "överraskat": "överraskad",
    "överraskats": "överraskad",
    "överraskningar": "överraskning",
    "överraskningarna": "överraskning",
    "överraskningarnas": "överraskning",
    "överraskningars": "överraskning",
    "överraskningen": "överraskning",
    "överraskningens": "överraskning",
    "överrasknings": "överraskning",
    "överraskningsanfallen": "överraskningsanfall",
    "överraskningsanfallens": "överraskningsanfall",
    "överraskningsanfallet": "överraskningsanfall",
    "överraskningsanfallets": "överraskningsanfall",
    "överraskningsanfalls": "överraskningsanfall",
    "överreden": "överrede",
    "överredena": "överrede",
    "överredenas": "överrede",
    "överredens": "överrede",
    "överredes": "överrede",
    "överredet": "överrede",
    "överredets": "överrede",
    "överreklamerade": "överreklamerad",
    "överreklamerades": "överreklamerad",
    "överreklamerads": "överreklamerad",
    "överreklamerat": "överreklamerad",
    "överreklamerats": "överreklamerad",
    "överrenoverad": "överrenovera",
    "överrenoverade": "överrenovera",
    "överrenoverades": "överrenovera",
    "överrenoverads": "överrenovera",
    "överrenoverande": "överrenovera",
    "överrenoverandes": "överrenovera",
    "överrenoverar": "överrenovera",
    "överrenoveras": "överrenovera",
    "överrenoverat": "överrenovera",
    "överrenoverats": "överrenovera",
    "överrepresenterade": "överrepresenterad",
    "överrepresenterades": "överrepresenterad",
    "överrepresenterads": "överrepresenterad",
    "överrepresenterat": "överrepresenterad",
    "överrepresenterats": "överrepresenterad",
    "överresan": "överresa",
    "överresans": "överresa",
    "överresas": "överresa",
    "överrese": "överresa",
    "överresor": "överresa",
    "överresorna": "överresa",
    "överresornas": "överresa",
    "överresors": "överresa",
    "överriggade": "överriggad",
    "överriggades": "överriggad",
    "överriggads": "överriggad",
    "överriggat": "överriggad",
    "överriggats": "överriggad",
    "överrockar": "överrock",
    "överrockarna": "överrock",
    "överrockarnas": "överrock",
    "överrockars": "överrock",
    "överrocken": "överrock",
    "överrockens": "överrock",
    "överrocks": "överrock",
    "överrumplad": "överrumpla",
    "överrumplade": "överrumpla",
    "överrumplades": "överrumpla",
    "överrumplads": "överrumpla",
    "överrumplande": "överrumpla",
    "överrumplanden": "överrumplande",
    "överrumplandena": "överrumplande",
    "överrumplandenas": "överrumplande",
    "överrumplandens": "överrumplande",
    "överrumplandes": "överrumplande",
    "överrumplandet": "överrumplande",
    "överrumplandets": "överrumplande",
    "överrumplar": "överrumpla",
    "överrumplas": "överrumpla",
    "överrumplat": "överrumpla",
    "överrumplats": "överrumpla",
    "överräck": "överräcka",
    "överräckande": "överräcka",
    "överräckanden": "överräckande",
    "överräckandena": "överräckande",
    "överräckandenas": "överräckande",
    "överräckandens": "överräckande",
    "överräckandes": "överräckande",
    "överräckandet": "överräckande",
    "överräckandets": "överräckande",
    "överräckas": "överräcka",
    "överräcker": "överräcka",
    "överräckes": "överräcka",
    "överräcks": "överräcka",
    "överräckt": "överräcka",
    "överräckta": "överräcka",
    "överräcktas": "överräcka",
    "överräckte": "överräcka",
    "överräcktes": "överräcka",
    "överräckts": "överräcka",
    "överrätten": "överrätt",
    "överrättens": "överrätt",
    "överrätter": "överrätt",
    "överrätterna": "överrätt",
    "överrätternas": "överrätt",
    "överrätters": "överrätt",
    "överrätts": "överrätt",
    "överröst": "överrösta",
    "överröstad": "överrösta",
    "överröstade": "överrösta",
    "överröstades": "överrösta",
    "överröstads": "överrösta",
    "överröstande": "överrösta",
    "överröstanden": "överröstande",
    "överröstandena": "överröstande",
    "överröstandenas": "överröstande",
    "överröstandens": "överröstande",
    "överröstandes": "överröstande",
    "överröstandet": "överröstande",
    "överröstandets": "överröstande",
    "överröstar": "överrösta",
    "överröstas": "överrösta",
    "överröstat": "överrösta",
    "överröstats": "överrösta",
    "översatt": "översätta",
    "översatta": "översätta",
    "översattas": "översätta",
    "översatte": "översätta",
    "översattes": "översätta",
    "översatts": "översätta",
    "översedd": "överse",
    "översedda": "överse",
    "överseddas": "överse",
    "översedde": "överse",
    "överseddes": "överse",
    "översedds": "överse",
    "överseende": "överse",
    "överseenden": "överseende",
    "överseendena": "överseende",
    "överseendenas": "överseende",
    "överseendens": "överseende",
    "överseendes": "överseende",
    "överseendet": "överseende",
    "överseendets": "överseende",
    "överser": "överse",
    "överses": "överse",
    "översett": "överse",
    "översetts": "överse",
    "översidan": "översida",
    "översidans": "översida",
    "översidas": "översida",
    "överside": "översida",
    "översides": "översida",
    "översidor": "översida",
    "översidorna": "översida",
    "översidornas": "översida",
    "översidors": "översida",
    "översiggivens": "översiggiven",
    "översiggivet": "översiggiven",
    "översiggivets": "översiggiven",
    "översiggivna": "översiggiven",
    "översiggivnare": "översiggiven",
    "översiggivnares": "översiggiven",
    "översiggivnas": "översiggiven",
    "översiggivnast": "översiggiven",
    "översiggivnaste": "översiggiven",
    "översiggivnastes": "översiggiven",
    "översiggivnasts": "översiggiven",
    "översiggivne": "översiggiven",
    "översiggivnes": "översiggiven",
    "översikten": "översikt",
    "översiktens": "översikt",
    "översikter": "översikt",
    "översikterna": "översikt",
    "översikternas": "översikt",
    "översikters": "översikt",
    "översiktliga": "översiktlig",
    "översiktligare": "översiktlig",
    "översiktligares": "översiktlig",
    "översiktligas": "översiktlig",
    "översiktligast": "översiktlig",
    "översiktligaste": "översiktlig",
    "översiktligastes": "översiktlig",
    "översiktligasts": "översiktlig",
    "översiktlige": "översiktlig",
    "översiktliges": "översiktlig",
    "översiktligheten": "översiktlighet",
    "översiktlighetens": "översiktlighet",
    "översiktlighets": "översiktlighet",
    "översiktligs": "översiktlig",
    "översiktligt": "översiktlig",
    "översiktligts": "översiktlig",
    "översikts": "översikt",
    "översiktsverken": "översiktsverk",
    "översiktsverkens": "översiktsverk",
    "översiktsverket": "översiktsverk",
    "översiktsverkets": "översiktsverk",
    "översiktsverks": "översiktsverk",
    "översinnliga": "översinnlig",
    "översinnligare": "översinnlig",
    "översinnligares": "översinnlig",
    "översinnligas": "översinnlig",
    "översinnligast": "översinnlig",
    "översinnligaste": "översinnlig",
    "översinnligastes": "översinnlig",
    "översinnligasts": "översinnlig",
    "översinnlige": "översinnlig",
    "översinnliges": "översinnlig",
    "översinnligheten": "översinnlighet",
    "översinnlighetens": "översinnlighet",
    "översinnlighets": "översinnlighet",
    "översinnligs": "översinnlig",
    "översinnligt": "översinnlig",
    "översinnligts": "översinnlig",
    "översittar": "översittare",
    "översittaren": "översittare",
    "översittarens": "översittare",
    "översittares": "översittare",
    "översittarna": "översittare",
    "översittarnas": "översittare",
    "översitterier": "översitteri",
    "översitterierna": "översitteri",
    "översitteriernas": "översitteri",
    "översitteriers": "översitteri",
    "översitteris": "översitteri",
    "översitterit": "översitteri",
    "översitterits": "översitteri",
    "överskatt": "överskatta",
    "överskattad": "överskatta",
    "överskattade": "överskatta",
    "överskattades": "överskatta",
    "överskattads": "överskatta",
    "överskattande": "överskatta",
    "överskattanden": "överskattande",
    "överskattandena": "överskattande",
    "överskattandenas": "överskattande",
    "överskattandens": "överskattande",
    "överskattandes": "överskattande",
    "överskattandet": "överskattande",
    "överskattandets": "överskattande",
    "överskattar": "överskatta",
    "överskattas": "överskatta",
    "överskattat": "överskatta",
    "överskattats": "överskatta",
    "överskeppningsbåtar": "överskeppningsbåt",
    "överskeppningsbåtarna": "överskeppningsbåt",
    "överskeppningsbåtarnas": "överskeppningsbåt",
    "överskeppningsbåtars": "överskeppningsbåt",
    "överskeppningsbåten": "överskeppningsbåt",
    "överskeppningsbåtens": "överskeppningsbåt",
    "överskeppningsbåts": "överskeppningsbåt",
    "överskjutningar": "överskjutning",
    "överskjutningarna": "överskjutning",
    "överskjutningarnas": "överskjutning",
    "överskjutningars": "överskjutning",
    "överskjutningen": "överskjutning",
    "överskjutningens": "överskjutning",
    "överskjutnings": "överskjutning",
    "överskotten": "överskott",
    "överskottens": "överskott",
    "överskottet": "överskott",
    "överskottets": "överskott",
    "överskotts": "överskott",
    "överskottsång": "överskottsånga",
    "överskottsångan": "överskottsånga",
    "överskottsångans": "överskottsånga",
    "överskottsångas": "överskottsånga",
    "överskottsånge": "överskottsånga",
    "överskottsångor": "överskottsånga",
    "överskottsångorna": "överskottsånga",
    "överskottsångornas": "överskottsånga",
    "överskottsångors": "överskottsånga",
    "överskottsångs": "överskottsånga",
    "överskred": "överskrida",
    "överskreds": "överskrida",
    "överskrid": "överskrida",
    "överskridande": "överskrida",
    "överskridanden": "överskridande",
    "överskridandena": "överskridande",
    "överskridandenas": "överskridande",
    "överskridandens": "överskridande",
    "överskridandes": "överskridande",
    "överskridandet": "överskridande",
    "överskridandets": "överskridande",
    "överskridas": "överskrida",
    "överskride": "överskrida",
    "överskriden": "överskrida",
    "överskridens": "överskrida",
    "överskrider": "överskrida",
    "överskrides": "överskrida",
    "överskridet": "överskrida",
    "överskridets": "överskrida",
    "överskridit": "överskrida",
    "överskridits": "överskrida",
    "överskridna": "överskrida",
    "överskridnas": "överskrida",
    "överskridne": "överskrida",
    "överskridnes": "överskrida",
    "överskrids": "överskrida",
    "överskriften": "överskrift",
    "överskriftens": "överskrift",
    "överskrifter": "överskrift",
    "överskrifterna": "överskrift",
    "överskrifternas": "överskrift",
    "överskrifters": "överskrift",
    "överskrifts": "överskrift",
    "överskruvar": "överskruv",
    "överskruvarna": "överskruv",
    "överskruvarnas": "överskruv",
    "överskruvars": "överskruv",
    "överskruven": "överskruv",
    "överskruvens": "överskruv",
    "överskruvs": "överskruv",
    "överskugg": "överskugga",
    "överskuggad": "överskugga",
    "överskuggade": "överskugga",
    "överskuggades": "överskugga",
    "överskuggads": "överskugga",
    "överskuggande": "överskugga",
    "överskugganden": "överskuggande",
    "överskuggandena": "överskuggande",
    "överskuggandenas": "överskuggande",
    "överskuggandens": "överskuggande",
    "överskuggandes": "överskuggande",
    "överskuggandet": "överskuggande",
    "överskuggandets": "överskuggande",
    "överskuggar": "överskugga",
    "överskuggas": "överskugga",
    "överskuggat": "överskugga",
    "överskuggats": "överskugga",
    "överskygg": "överskygga",
    "överskyggad": "överskygga",
    "överskyggade": "överskygga",
    "överskyggades": "överskygga",
    "överskyggads": "överskygga",
    "överskyggande": "överskygga",
    "överskygganden": "överskyggande",
    "överskyggandena": "överskyggande",
    "överskyggandenas": "överskyggande",
    "överskyggandens": "överskyggande",
    "överskyggandes": "överskyggande",
    "överskyggandet": "överskyggande",
    "överskyggandets": "överskyggande",
    "överskyggar": "överskygga",
    "överskyggas": "överskygga",
    "överskyggat": "överskygga",
    "överskyggats": "överskygga",
    "överskåd": "överskåda",
    "överskådad": "överskåda",
    "överskådade": "överskåda",
    "överskådades": "överskåda",
    "överskådads": "överskåda",
    "överskådande": "överskåda",
    "överskådanden": "överskådande",
    "överskådandena": "överskådande",
    "överskådandenas": "överskådande",
    "överskådandens": "överskådande",
    "överskådandes": "överskådande",
    "överskådandet": "överskådande",
    "överskådandets": "överskådande",
    "överskådar": "överskåda",
    "överskådas": "överskåda",
    "överskådat": "överskåda",
    "överskådats": "överskåda",
    "överskådliga": "överskådlig",
    "överskådligare": "överskådlig",
    "överskådligares": "överskådlig",
    "överskådligas": "överskådlig",
    "överskådligast": "överskådlig",
    "överskådligaste": "överskådlig",
    "överskådligastes": "överskådlig",
    "överskådligasts": "överskådlig",
    "överskådlige": "överskådlig",
    "överskådliges": "överskådlig",
    "överskådligheten": "överskådlighet",
    "överskådlighetens": "överskådlighet",
    "överskådlighets": "överskådlighet",
    "överskådligs": "överskådlig",
    "överskådligt": "överskådlig",
    "överskådligts": "överskådlig",
    "överskåpen": "överskåp",
    "överskåpens": "överskåp",
    "överskåpet": "överskåp",
    "överskåpets": "överskåp",
    "överskåps": "överskåp",
    "överskölj": "överskölja",
    "översköljande": "överskölja",
    "översköljanden": "översköljande",
    "översköljandena": "översköljande",
    "översköljandenas": "översköljande",
    "översköljandens": "översköljande",
    "översköljandes": "översköljande",
    "översköljandet": "översköljande",
    "översköljandets": "översköljande",
    "översköljas": "överskölja",
    "översköljd": "överskölja",
    "översköljda": "överskölja",
    "översköljdas": "överskölja",
    "översköljde": "överskölja",
    "översköljdes": "överskölja",
    "översköljds": "överskölja",
    "översköljer": "överskölja",
    "översköljes": "överskölja",
    "översköljningssäkerheten": "översköljningssäkerhet",
    "översköljningssäkerhetens": "översköljningssäkerhet",
    "översköljningssäkerhets": "översköljningssäkerhet",
    "översköljningssäkers": "översköljningssäker",
    "översköljningssäkert": "översköljningssäker",
    "översköljningssäkerts": "översköljningssäker",
    "översköljningssäkra": "översköljningssäker",
    "översköljningssäkrare": "översköljningssäker",
    "översköljningssäkrares": "översköljningssäker",
    "översköljningssäkras": "översköljningssäker",
    "översköljningssäkrast": "översköljningssäker",
    "översköljningssäkraste": "översköljningssäker",
    "översköljningssäkrastes": "översköljningssäker",
    "översköljningssäkrasts": "översköljningssäker",
    "översköljningssäkre": "översköljningssäker",
    "översköljningssäkres": "översköljningssäker",
    "översköljs": "överskölja",
    "översköljt": "överskölja",
    "översköljts": "överskölja",
    "översköterskan": "översköterska",
    "översköterskans": "översköterska",
    "översköterskas": "översköterska",
    "översköterske": "översköterska",
    "översköterskor": "översköterska",
    "översköterskorna": "översköterska",
    "översköterskornas": "översköterska",
    "översköterskors": "översköterska",
    "överslagen": "överslag",
    "överslagens": "överslag",
    "överslaget": "överslag",
    "överslagets": "överslag",
    "överslags": "överslag",
    "överslagsberäkningar": "överslagsberäkning",
    "överslagsberäkningarna": "överslagsberäkning",
    "överslagsberäkningarnas": "överslagsberäkning",
    "överslagsberäkningars": "överslagsberäkning",
    "överslagsberäkningen": "överslagsberäkning",
    "överslagsberäkningens": "överslagsberäkning",
    "överslagsberäknings": "överslagsberäkning",
    "överslagsmässiga": "överslagsmässig",
    "överslagsmässigare": "överslagsmässig",
    "överslagsmässigares": "överslagsmässig",
    "överslagsmässigas": "överslagsmässig",
    "överslagsmässigast": "överslagsmässig",
    "överslagsmässigaste": "överslagsmässig",
    "överslagsmässigastes": "överslagsmässig",
    "överslagsmässigasts": "överslagsmässig",
    "överslagsmässige": "överslagsmässig",
    "överslagsmässiges": "överslagsmässig",
    "överslagsmässigs": "överslagsmässig",
    "överslagsmässigt": "överslagsmässig",
    "överslagsmässigts": "överslagsmässig",
    "översnöade": "översnöad",
    "översnöades": "översnöad",
    "översnöads": "översnöad",
    "översnöat": "översnöad",
    "översnöats": "översnöad",
    "överspelade": "överspelad",
    "överspelades": "överspelad",
    "överspelads": "överspelad",
    "överspelat": "överspelad",
    "överspelats": "överspelad",
    "överspelen": "överspel",
    "överspelens": "överspel",
    "överspelet": "överspel",
    "överspelets": "överspel",
    "överspels": "överspel",
    "överspända": "överspänd",
    "överspändare": "överspänd",
    "överspändares": "överspänd",
    "överspändas": "överspänd",
    "överspändast": "överspänd",
    "överspändaste": "överspänd",
    "överspändastes": "överspänd",
    "överspändasts": "överspänd",
    "överspände": "överspänd",
    "överspändes": "överspänd",
    "överspändheten": "överspändhet",
    "överspändhetens": "överspändhet",
    "överspändheter": "överspändhet",
    "överspändheterna": "överspändhet",
    "överspändheternas": "överspändhet",
    "överspändheters": "överspändhet",
    "överspändhets": "överspändhet",
    "överspänds": "överspänd",
    "överspänningar": "överspänning",
    "överspänningarna": "överspänning",
    "överspänningarnas": "överspänning",
    "överspänningars": "överspänning",
    "överspänningen": "överspänning",
    "överspänningens": "överspänning",
    "överspännings": "överspänning",
    "överspänt": "överspänd",
    "överspänts": "överspänd",
    "överst": "överste",
    "översta": "övre",
    "överstar": "överste",
    "överstarna": "överste",
    "överstarnas": "överste",
    "överstars": "överste",
    "överstas": "övre",
    "överste": "övre",
    "översteg": "överstiga",
    "överstegrad": "överstegra",
    "överstegrade": "överstegra",
    "överstegrades": "överstegra",
    "överstegrads": "överstegra",
    "överstegrande": "överstegra",
    "överstegranden": "överstegrande",
    "överstegrandena": "överstegrande",
    "överstegrandenas": "överstegrande",
    "överstegrandens": "överstegrande",
    "överstegrandes": "överstegrande",
    "överstegrandet": "överstegrande",
    "överstegrandets": "överstegrande",
    "överstegrar": "överstegra",
    "överstegras": "överstegra",
    "överstegrat": "överstegra",
    "överstegrats": "överstegra",
    "överstegs": "överstiga",
    "överstelöjtnanten": "överstelöjtnant",
    "överstelöjtnantens": "överstelöjtnant",
    "överstelöjtnanter": "överstelöjtnant",
    "överstelöjtnanterna": "överstelöjtnant",
    "överstelöjtnanternas": "överstelöjtnant",
    "överstelöjtnanters": "överstelöjtnant",
    "överstelöjtnants": "överstelöjtnant",
    "översten": "överste",
    "överstens": "överste",
    "översteprästen": "överstepräst",
    "översteprästens": "överstepräst",
    "överstepräster": "överstepräst",
    "översteprästerna": "överstepräst",
    "översteprästernas": "överstepräst",
    "översteprästers": "överstepräst",
    "översteprästs": "överstepräst",
    "överstes": "övre",
    "överstig": "överstiga",
    "överstigande": "överstiga",
    "överstiganden": "överstigande",
    "överstigandena": "överstigande",
    "överstigandenas": "överstigande",
    "överstigandens": "överstigande",
    "överstigandes": "överstigande",
    "överstigandet": "överstigande",
    "överstigandets": "överstigande",
    "överstigas": "överstiga",
    "överstige": "överstiga",
    "överstigen": "överstiga",
    "överstigens": "överstiga",
    "överstiger": "överstiga",
    "överstiges": "överstiga",
    "överstiget": "överstiga",
    "överstigets": "överstiga",
    "överstigit": "överstiga",
    "överstigits": "överstiga",
    "överstigliga": "överstiglig",
    "överstigligare": "överstiglig",
    "överstigligares": "överstiglig",
    "överstigligas": "överstiglig",
    "överstigligast": "överstiglig",
    "överstigligaste": "överstiglig",
    "överstigligastes": "överstiglig",
    "överstigligasts": "överstiglig",
    "överstiglige": "överstiglig",
    "överstigliges": "överstiglig",
    "överstigligheten": "överstiglighet",
    "överstiglighetens": "överstiglighet",
    "överstiglighets": "överstiglighet",
    "överstigligs": "överstiglig",
    "överstigligt": "överstiglig",
    "överstigligts": "överstiglig",
    "överstigna": "överstiga",
    "överstignas": "överstiga",
    "överstigne": "överstiga",
    "överstignes": "överstiga",
    "överstigs": "överstiga",
    "överstrykningar": "överstrykning",
    "överstrykningarna": "överstrykning",
    "överstrykningarnas": "överstrykning",
    "överstrykningars": "överstrykning",
    "överstrykningen": "överstrykning",
    "överstrykningens": "överstrykning",
    "överstryknings": "överstrykning",
    "överstrykningspenn": "överstrykningspenna",
    "överstrykningspennan": "överstrykningspenna",
    "överstrykningspennans": "överstrykningspenna",
    "överstrykningspennas": "överstrykningspenna",
    "överstrykningspenne": "överstrykningspenna",
    "överstrykningspennor": "överstrykningspenna",
    "överstrykningspennorna": "överstrykningspenna",
    "överstrykningspennornas": "överstrykningspenna",
    "överstrykningspennors": "överstrykningspenna",
    "överstrykningspenns": "överstrykningspenna",
    "överströmsskydden": "överströmsskydd",
    "överströmsskyddens": "överströmsskydd",
    "överströmsskyddet": "överströmsskydd",
    "överströmsskyddets": "överströmsskydd",
    "överströmsskydds": "överströmsskydd",
    "överstycken": "överstycke",
    "överstyckena": "överstycke",
    "överstyckenas": "överstycke",
    "överstyckens": "överstycke",
    "överstyckes": "överstycke",
    "överstycket": "överstycke",
    "överstyckets": "överstycke",
    "överstycks": "överstycke",
    "överstyrda": "överstyrd",
    "överstyrdare": "överstyrd",
    "överstyrdares": "överstyrd",
    "överstyrdas": "överstyrd",
    "överstyrdast": "överstyrd",
    "överstyrdaste": "överstyrd",
    "överstyrdastes": "överstyrd",
    "överstyrdasts": "överstyrd",
    "överstyrde": "överstyrd",
    "överstyrdes": "överstyrd",
    "överstyrdheten": "överstyrdhet",
    "överstyrdhetens": "överstyrdhet",
    "överstyrdhets": "överstyrdhet",
    "överstyrds": "överstyrd",
    "överstyrt": "överstyrd",
    "överstyrts": "överstyrd",
    "överståndens": "överstånden",
    "överståndet": "överstånden",
    "överståndets": "överstånden",
    "överståndna": "överstånden",
    "överståndnare": "överstånden",
    "överståndnares": "överstånden",
    "överståndnas": "överstånden",
    "överståndnast": "överstånden",
    "överståndnaste": "överstånden",
    "överståndnastes": "överstånden",
    "överståndnasts": "överstånden",
    "överståndne": "överstånden",
    "överståndnes": "överstånden",
    "överståthållar": "överståthållare",
    "överståthållaren": "överståthållare",
    "överståthållarens": "överståthållare",
    "överståthållares": "överståthållare",
    "överståthållarna": "överståthållare",
    "överståthållarnas": "överståthållare",
    "överstökade": "överstökad",
    "överstökades": "överstökad",
    "överstökads": "överstökad",
    "överstökat": "överstökad",
    "överstökats": "överstökad",
    "översvinneliga": "översvinnelig",
    "översvinneligare": "översvinnelig",
    "översvinneligares": "översvinnelig",
    "översvinneligas": "översvinnelig",
    "översvinneligast": "översvinnelig",
    "översvinneligaste": "översvinnelig",
    "översvinneligastes": "översvinnelig",
    "översvinneligasts": "översvinnelig",
    "översvinnelige": "översvinnelig",
    "översvinneliges": "översvinnelig",
    "översvinneligheten": "översvinnelighet",
    "översvinnelighetens": "översvinnelighet",
    "översvinnelighets": "översvinnelighet",
    "översvinneligs": "översvinnelig",
    "översvinneligt": "översvinnelig",
    "översvinneligts": "översvinnelig",
    "översvinnliga": "översvinnlig",
    "översvinnligare": "översvinnlig",
    "översvinnligares": "översvinnlig",
    "översvinnligas": "översvinnlig",
    "översvinnligast": "översvinnlig",
    "översvinnligaste": "översvinnlig",
    "översvinnligastes": "översvinnlig",
    "översvinnligasts": "översvinnlig",
    "översvinnlige": "översvinnlig",
    "översvinnliges": "översvinnlig",
    "översvinnligheten": "översvinnlighet",
    "översvinnlighetens": "översvinnlighet",
    "översvinnlighets": "översvinnlighet",
    "översvinnligs": "översvinnlig",
    "översvinnligt": "översvinnlig",
    "översvinnligts": "översvinnlig",
    "översvämmad": "översvämma",
    "översvämmade": "översvämma",
    "översvämmades": "översvämma",
    "översvämmads": "översvämma",
    "översvämmande": "översvämma",
    "översvämmanden": "översvämmande",
    "översvämmandena": "översvämmande",
    "översvämmandenas": "översvämmande",
    "översvämmandens": "översvämmande",
    "översvämmandes": "översvämmande",
    "översvämmandet": "översvämmande",
    "översvämmandets": "översvämmande",
    "översvämmar": "översvämma",
    "översvämmas": "översvämma",
    "översvämmat": "översvämma",
    "översvämmats": "översvämma",
    "översvämningar": "översvämning",
    "översvämningarna": "översvämning",
    "översvämningarnas": "översvämning",
    "översvämningars": "översvämning",
    "översvämningen": "översvämning",
    "översvämningens": "översvämning",
    "översvämnings": "översvämning",
    "översynen": "översyn",
    "översynens": "översyn",
    "översyner": "översyn",
    "översynerna": "översyn",
    "översynernas": "översyn",
    "översyners": "översyn",
    "översyns": "översyn",
    "översynta": "översynt",
    "översyntare": "översynt",
    "översyntares": "översynt",
    "översyntas": "översynt",
    "översyntast": "översynt",
    "översyntaste": "översynt",
    "översyntastes": "översynt",
    "översyntasts": "översynt",
    "översynte": "översynt",
    "översyntes": "översynt",
    "översyntheten": "översynthet",
    "översynthetens": "översynthet",
    "översynthets": "översynthet",
    "översynts": "översynt",
    "översänd": "översända",
    "översändande": "översända",
    "översändanden": "översändande",
    "översändandena": "översändande",
    "översändandenas": "översändande",
    "översändandens": "översändande",
    "översändandes": "översändande",
    "översändandet": "översändande",
    "översändandets": "översändande",
    "översändas": "översända",
    "översände": "översända",
    "översänder": "översända",
    "översändes": "översända",
    "översänds": "översända",
    "översänt": "översända",
    "översänts": "översända",
    "översätt": "översätta",
    "översättande": "översätta",
    "översättanden": "översättande",
    "översättandena": "översättande",
    "översättandenas": "översättande",
    "översättandens": "översättande",
    "översättandes": "översättande",
    "översättandet": "översättande",
    "översättandets": "översättande",
    "översättar": "översättare",
    "översättaren": "översättare",
    "översättarens": "översättare",
    "översättares": "översättare",
    "översättarna": "översättare",
    "översättarnas": "översättare",
    "översättas": "översätta",
    "översätter": "översätta",
    "översättes": "översätta",
    "översättningar": "översättning",
    "översättningarna": "översättning",
    "översättningarnas": "översättning",
    "översättningars": "översättning",
    "översättningen": "översättning",
    "översättningens": "översättning",
    "översättnings": "översättning",
    "översättningskvaliteten": "översättningskvalitet",
    "översättningskvalitetens": "översättningskvalitet",
    "översättningskvalitets": "översättningskvalitet",
    "översättningslånen": "översättningslån",
    "översättningslånens": "översättningslån",
    "översättningslånet": "översättningslån",
    "översättningslånets": "översättningslån",
    "översättningslåns": "översättningslån",
    "översättningsmaskinen": "översättningsmaskin",
    "översättningsmaskinens": "översättningsmaskin",
    "översättningsmaskiner": "översättningsmaskin",
    "översättningsmaskinerna": "översättningsmaskin",
    "översättningsmaskinernas": "översättningsmaskin",
    "översättningsmaskiners": "översättningsmaskin",
    "översättningsmaskins": "översättningsmaskin",
    "översättningsproven": "översättningsprov",
    "översättningsprovens": "översättningsprov",
    "översättningsprovet": "översättningsprov",
    "översättningsprovets": "översättningsprov",
    "översättningsprovs": "översättningsprov",
    "översätts": "översätta",
    "översåg": "överse",
    "översåge": "överse",
    "översåges": "överse",
    "översågs": "överse",
    "översållade": "översållad",
    "översållades": "översållad",
    "översållads": "översållad",
    "översållat": "översållad",
    "översållats": "översållad",
    "översåt": "översåte",
    "översåtar": "översåte",
    "översåtarna": "översåte",
    "översåtarnas": "översåte",
    "översåtars": "översåte",
    "översåten": "översåte",
    "översåtens": "översåte",
    "översåtes": "översåte",
    "översåts": "översåte",
    "övertag": "överta",
    "övertaga": "överta",
    "övertagande": "överta",
    "övertaganden": "övertagande",
    "övertagandena": "övertagande",
    "övertagandenas": "övertagande",
    "övertagandens": "övertagande",
    "övertagandes": "övertagande",
    "övertagandet": "övertagande",
    "övertagandets": "övertagande",
    "övertagas": "överta",
    "övertage": "överta",
    "övertagen": "övertag",
    "övertagens": "övertag",
    "övertager": "överta",
    "övertages": "överta",
    "övertaget": "övertag",
    "övertagets": "övertag",
    "övertagit": "överta",
    "övertagits": "överta",
    "övertagna": "överta",
    "övertagnas": "överta",
    "övertagne": "överta",
    "övertagnes": "överta",
    "övertags": "övertag",
    "övertal": "övertala",
    "övertalad": "övertala",
    "övertalade": "övertala",
    "övertalades": "övertala",
    "övertalads": "övertala",
    "övertalande": "övertala",
    "övertalanden": "övertalande",
    "övertalandena": "övertalande",
    "övertalandenas": "övertalande",
    "övertalandens": "övertalande",
    "övertalandes": "övertalande",
    "övertalandet": "övertalande",
    "övertalandets": "övertalande",
    "övertalar": "övertala",
    "övertalas": "övertala",
    "övertalat": "övertala",
    "övertalats": "övertala",
    "övertaliga": "övertalig",
    "övertaligare": "övertalig",
    "övertaligares": "övertalig",
    "övertaligas": "övertalig",
    "övertaligast": "övertalig",
    "övertaligaste": "övertalig",
    "övertaligastes": "övertalig",
    "övertaligasts": "övertalig",
    "övertalige": "övertalig",
    "övertaliges": "övertalig",
    "övertaligheten": "övertalighet",
    "övertalighetens": "övertalighet",
    "övertalighets": "övertalighet",
    "övertaligs": "övertalig",
    "övertaligt": "övertalig",
    "övertaligts": "övertalig",
    "övertalningar": "övertalning",
    "övertalningarna": "övertalning",
    "övertalningarnas": "övertalning",
    "övertalningars": "övertalning",
    "övertalningen": "övertalning",
    "övertalningens": "övertalning",
    "övertalnings": "övertalning",
    "övertalningsförmågan": "övertalningsförmåga",
    "övertalningsförmågans": "övertalningsförmåga",
    "övertalningsförmågas": "övertalningsförmåga",
    "övertalningsförmåge": "övertalningsförmåga",
    "övertalningsförmågor": "övertalningsförmåga",
    "övertalningsförmågorna": "övertalningsförmåga",
    "övertalningsförmågornas": "övertalningsförmåga",
    "övertalningsförmågors": "övertalningsförmåga",
    "övertalningsförsöken": "övertalningsförsök",
    "övertalningsförsökens": "övertalningsförsök",
    "övertalningsförsöket": "övertalningsförsök",
    "övertalningsförsökets": "övertalningsförsök",
    "övertalningsförsöks": "övertalningsförsök",
    "övertar": "överta",
    "övertas": "överta",
    "överteckn": "överteckna",
    "övertecknad": "överteckna",
    "övertecknade": "överteckna",
    "övertecknades": "överteckna",
    "övertecknads": "överteckna",
    "övertecknande": "överteckna",
    "övertecknanden": "övertecknande",
    "övertecknandena": "övertecknande",
    "övertecknandenas": "övertecknande",
    "övertecknandens": "övertecknande",
    "övertecknandes": "övertecknande",
    "övertecknandet": "övertecknande",
    "övertecknandets": "övertecknande",
    "övertecknar": "överteckna",
    "övertecknas": "överteckna",
    "övertecknat": "överteckna",
    "övertecknats": "överteckna",
    "övertiden": "övertid",
    "övertidens": "övertid",
    "övertids": "övertid",
    "övertidsarbeten": "övertidsarbete",
    "övertidsarbetena": "övertidsarbete",
    "övertidsarbetenas": "övertidsarbete",
    "övertidsarbetens": "övertidsarbete",
    "övertidsarbetes": "övertidsarbete",
    "övertidsarbetet": "övertidsarbete",
    "övertidsarbetets": "övertidsarbete",
    "övertidsarbets": "övertidsarbete",
    "övertog": "överta",
    "övertoge": "överta",
    "övertoges": "överta",
    "övertogs": "överta",
    "övertonen": "överton",
    "övertonens": "överton",
    "övertoner": "överton",
    "övertonerna": "överton",
    "övertonernas": "överton",
    "övertoners": "överton",
    "övertons": "överton",
    "övertrampen": "övertramp",
    "övertrampens": "övertramp",
    "övertrampet": "övertramp",
    "övertrampets": "övertramp",
    "övertramps": "övertramp",
    "övertrasserad": "övertrassera",
    "övertrasserade": "övertrassera",
    "övertrasserades": "övertrassera",
    "övertrasserads": "övertrassera",
    "övertrasserande": "övertrassera",
    "övertrasseranden": "övertrasserande",
    "övertrasserandena": "övertrasserande",
    "övertrasserandenas": "övertrasserande",
    "övertrasserandens": "övertrasserande",
    "övertrasserandes": "övertrasserande",
    "övertrasserandet": "övertrasserande",
    "övertrasserandets": "övertrasserande",
    "övertrasserar": "övertrassera",
    "övertrasseras": "övertrassera",
    "övertrasserat": "övertrassera",
    "övertrasserats": "övertrassera",
    "övertrasserbara": "övertrasserbar",
    "övertrasserbarare": "övertrasserbar",
    "övertrasserbarares": "övertrasserbar",
    "övertrasserbaras": "övertrasserbar",
    "övertrasserbarast": "övertrasserbar",
    "övertrasserbaraste": "övertrasserbar",
    "övertrasserbarastes": "övertrasserbar",
    "övertrasserbarasts": "övertrasserbar",
    "övertrasserbare": "övertrasserbar",
    "övertrasserbares": "övertrasserbar",
    "övertrasserbarheten": "övertrasserbarhet",
    "övertrasserbarhetens": "övertrasserbarhet",
    "övertrasserbarhets": "övertrasserbarhet",
    "övertrasserbars": "övertrasserbar",
    "övertrasserbart": "övertrasserbar",
    "övertrasserbarts": "övertrasserbar",
    "övertrasseringar": "övertrassering",
    "övertrasseringarna": "övertrassering",
    "övertrasseringarnas": "övertrassering",
    "övertrasseringars": "övertrassering",
    "övertrasseringen": "övertrassering",
    "övertrasseringens": "övertrassering",
    "övertrasserings": "övertrassering",
    "övertron": "övertro",
    "övertrons": "övertro",
    "övertros": "övertro",
    "övertrumf": "övertrumfa",
    "övertrumfad": "övertrumfa",
    "övertrumfade": "övertrumfa",
    "övertrumfades": "övertrumfa",
    "övertrumfads": "övertrumfa",
    "övertrumfande": "övertrumfa",
    "övertrumfanden": "övertrumfande",
    "övertrumfandena": "övertrumfande",
    "övertrumfandenas": "övertrumfande",
    "övertrumfandens": "övertrumfande",
    "övertrumfandes": "övertrumfande",
    "övertrumfandet": "övertrumfande",
    "övertrumfandets": "övertrumfande",
    "övertrumfar": "övertrumfa",
    "övertrumfas": "övertrumfa",
    "övertrumfat": "övertrumfa",
    "övertrumfats": "övertrumfa",
    "övertrycket": "övertryck",
    "övertryckets": "övertryck",
    "övertrycks": "övertryck",
    "överträd": "överträda",
    "överträdande": "överträda",
    "överträdanden": "överträdande",
    "överträdandena": "överträdande",
    "överträdandenas": "överträdande",
    "överträdandens": "överträdande",
    "överträdandes": "överträdande",
    "överträdandet": "överträdande",
    "överträdandets": "överträdande",
    "överträdas": "överträda",
    "överträdd": "överträda",
    "överträdda": "överträda",
    "överträddas": "överträda",
    "överträdde": "överträda",
    "överträddes": "överträda",
    "överträdds": "överträda",
    "överträdelsen": "överträdelse",
    "överträdelsens": "överträdelse",
    "överträdelser": "överträdelse",
    "överträdelserna": "överträdelse",
    "överträdelsernas": "överträdelse",
    "överträdelsers": "överträdelse",
    "överträdelses": "överträdelse",
    "överträder": "överträda",
    "överträdes": "överträda",
    "överträds": "överträda",
    "överträff": "överträffa",
    "överträffad": "överträffa",
    "överträffade": "överträffa",
    "överträffades": "överträffa",
    "överträffads": "överträffa",
    "överträffande": "överträffa",
    "överträffanden": "överträffande",
    "överträffandena": "överträffande",
    "överträffandenas": "överträffande",
    "överträffandens": "överträffande",
    "överträffandes": "överträffande",
    "överträffandet": "överträffande",
    "överträffandets": "överträffande",
    "överträffar": "överträffa",
    "överträffas": "överträffa",
    "överträffat": "överträffa",
    "överträffats": "överträffa",
    "överträtt": "överträda",
    "överträtts": "överträda",
    "övertydliga": "övertydlig",
    "övertydligare": "övertydlig",
    "övertydligares": "övertydlig",
    "övertydligas": "övertydlig",
    "övertydligast": "övertydlig",
    "övertydligaste": "övertydlig",
    "övertydligastes": "övertydlig",
    "övertydligasts": "övertydlig",
    "övertydlige": "övertydlig",
    "övertydliges": "övertydlig",
    "övertydligheten": "övertydlighet",
    "övertydlighetens": "övertydlighet",
    "övertydligheter": "övertydlighet",
    "övertydligheterna": "övertydlighet",
    "övertydligheternas": "övertydlighet",
    "övertydligheters": "övertydlighet",
    "övertydlighets": "övertydlighet",
    "övertydligs": "övertydlig",
    "övertydligt": "övertydlig",
    "övertydligts": "övertydlig",
    "övertyg": "övertyga",
    "övertygad": "övertyga",
    "övertygade": "övertygad",
    "övertygades": "övertygad",
    "övertygads": "övertygad",
    "övertygande": "övertyga",
    "övertyganden": "övertygande",
    "övertygandena": "övertygande",
    "övertygandenas": "övertygande",
    "övertygandens": "övertygande",
    "övertygandes": "övertygande",
    "övertygandet": "övertygande",
    "övertygandets": "övertygande",
    "övertygar": "övertyga",
    "övertygas": "övertyga",
    "övertygat": "övertygad",
    "övertygats": "övertygad",
    "övertygelsen": "övertygelse",
    "övertygelsens": "övertygelse",
    "övertygelser": "övertygelse",
    "övertygelserna": "övertygelse",
    "övertygelsernas": "övertygelse",
    "övertygelsers": "övertygelse",
    "övertygelses": "övertygelse",
    "övertända": "övertänd",
    "övertändare": "övertänd",
    "övertändares": "övertänd",
    "övertändas": "övertänd",
    "övertändast": "övertänd",
    "övertändaste": "övertänd",
    "övertändastes": "övertänd",
    "övertändasts": "övertänd",
    "övertände": "övertänd",
    "övertändes": "övertänd",
    "övertänds": "övertänd",
    "övertänkta": "övertänkt",
    "övertänktare": "övertänkt",
    "övertänktares": "övertänkt",
    "övertänktas": "övertänkt",
    "övertänktast": "övertänkt",
    "övertänktaste": "övertänkt",
    "övertänktastes": "övertänkt",
    "övertänktasts": "övertänkt",
    "övertänkte": "övertänkt",
    "övertänktes": "övertänkt",
    "övertänktheten": "övertänkthet",
    "övertänkthetens": "övertänkthet",
    "övertänkthets": "övertänkthet",
    "övertänkts": "övertänkt",
    "övertänt": "övertänd",
    "övertänts": "övertänd",
    "överutnyttjad": "överutnyttja",
    "överutnyttjade": "överutnyttja",
    "överutnyttjades": "överutnyttja",
    "överutnyttjads": "överutnyttja",
    "överutnyttjande": "överutnyttja",
    "överutnyttjanden": "överutnyttjande",
    "överutnyttjandena": "överutnyttjande",
    "överutnyttjandenas": "överutnyttjande",
    "överutnyttjandens": "överutnyttjande",
    "överutnyttjandes": "överutnyttjande",
    "överutnyttjandet": "överutnyttjande",
    "överutnyttjandets": "överutnyttjande",
    "överutnyttjar": "överutnyttja",
    "överutnyttjas": "överutnyttja",
    "överutnyttjat": "överutnyttja",
    "överutnyttjats": "överutnyttja",
    "övervak": "övervaka",
    "övervakad": "övervaka",
    "övervakade": "övervaka",
    "övervakades": "övervaka",
    "övervakads": "övervaka",
    "övervakande": "övervaka",
    "övervakanden": "övervakande",
    "övervakandena": "övervakande",
    "övervakandenas": "övervakande",
    "övervakandens": "övervakande",
    "övervakandes": "övervakande",
    "övervakandet": "övervakande",
    "övervakandets": "övervakande",
    "övervakar": "övervakare",
    "övervakaren": "övervakare",
    "övervakarens": "övervakare",
    "övervakares": "övervakare",
    "övervakarna": "övervakare",
    "övervakarnas": "övervakare",
    "övervakas": "övervaka",
    "övervakat": "övervaka",
    "övervakats": "övervaka",
    "övervakningar": "övervakning",
    "övervakningarna": "övervakning",
    "övervakningarnas": "övervakning",
    "övervakningars": "övervakning",
    "övervakningen": "övervakning",
    "övervakningens": "övervakning",
    "övervaknings": "övervakning",
    "övervakningsbilden": "övervakningsbild",
    "övervakningsbildens": "övervakningsbild",
    "övervakningsbilder": "övervakningsbild",
    "övervakningsbilderna": "övervakningsbild",
    "övervakningsbildernas": "övervakningsbild",
    "övervakningsbilders": "övervakningsbild",
    "övervakningsbilds": "övervakningsbild",
    "övervakningskameran": "övervakningskamera",
    "övervakningskamerans": "övervakningskamera",
    "övervakningskameras": "övervakningskamera",
    "övervakningskameror": "övervakningskamera",
    "övervakningskamerorna": "övervakningskamera",
    "övervakningskamerornas": "övervakningskamera",
    "övervakningskamerors": "övervakningskamera",
    "övervakningssamhällen": "övervakningssamhälle",
    "övervakningssamhällena": "övervakningssamhälle",
    "övervakningssamhällenas": "övervakningssamhälle",
    "övervakningssamhällens": "övervakningssamhälle",
    "övervakningssamhälles": "övervakningssamhälle",
    "övervakningssamhället": "övervakningssamhälle",
    "övervakningssamhällets": "övervakningssamhälle",
    "övervakningssamhälls": "övervakningssamhälle",
    "övervakningsutrustningar": "övervakningsutrustning",
    "övervakningsutrustningarna": "övervakningsutrustning",
    "övervakningsutrustningarnas": "övervakningsutrustning",
    "övervakningsutrustningars": "övervakningsutrustning",
    "övervakningsutrustningen": "övervakningsutrustning",
    "övervakningsutrustningens": "övervakningsutrustning",
    "övervakningsutrustnings": "övervakningsutrustning",
    "övervallningar": "övervallning",
    "övervallningarna": "övervallning",
    "övervallningarnas": "övervallning",
    "övervallningars": "övervallning",
    "övervallningen": "övervallning",
    "övervallningens": "övervallning",
    "övervallnings": "övervallning",
    "övervann": "övervinna",
    "övervanns": "övervinna",
    "övervar": "övervara",
    "övervarade": "övervara",
    "övervarades": "övervara",
    "övervarande": "övervara",
    "övervaranden": "övervarande",
    "övervarandena": "övervarande",
    "övervarandenas": "övervarande",
    "övervarandens": "övervarande",
    "övervarandes": "övervarande",
    "övervarandet": "övervarande",
    "övervarandets": "övervarande",
    "övervarar": "övervara",
    "övervaras": "övervara",
    "övervarat": "övervara",
    "övervarats": "övervara",
    "övervarit": "övervara",
    "övervarits": "övervara",
    "övervattensfartygen": "övervattensfartyg",
    "övervattensfartygens": "övervattensfartyg",
    "övervattensfartyget": "övervattensfartyg",
    "övervattensfartygets": "övervattensfartyg",
    "övervattensfartygs": "övervattensfartyg",
    "övervattensläges": "övervattensläge",
    "övervattensläget": "övervattensläge",
    "övervattenslägets": "övervattensläge",
    "övervikten": "övervikt",
    "överviktens": "övervikt",
    "överviktiga": "överviktig",
    "överviktigare": "överviktig",
    "överviktigares": "överviktig",
    "överviktigas": "överviktig",
    "överviktigast": "överviktig",
    "överviktigaste": "överviktig",
    "överviktigastes": "överviktig",
    "överviktigasts": "överviktig",
    "överviktige": "överviktig",
    "överviktiges": "överviktig",
    "överviktigheten": "överviktighet",
    "överviktighetens": "överviktighet",
    "överviktighets": "överviktighet",
    "överviktigs": "överviktig",
    "överviktigt": "överviktig",
    "överviktigts": "överviktig",
    "övervikts": "övervikt",
    "övervinn": "övervinna",
    "övervinnande": "övervinna",
    "övervinnanden": "övervinnande",
    "övervinnandena": "övervinnande",
    "övervinnandenas": "övervinnande",
    "övervinnandens": "övervinnande",
    "övervinnandes": "övervinnande",
    "övervinnandet": "övervinnande",
    "övervinnandets": "övervinnande",
    "övervinnas": "övervinna",
    "övervinne": "övervinna",
    "övervinner": "övervinna",
    "övervinnes": "övervinna",
    "övervinns": "övervinna",
    "övervintrad": "övervintra",
    "övervintrade": "övervintra",
    "övervintrades": "övervintra",
    "övervintrads": "övervintra",
    "övervintrande": "övervintra",
    "övervintranden": "övervintrande",
    "övervintrandena": "övervintrande",
    "övervintrandenas": "övervintrande",
    "övervintrandens": "övervintrande",
    "övervintrandes": "övervintrande",
    "övervintrandet": "övervintrande",
    "övervintrandets": "övervintrande",
    "övervintrar": "övervintra",
    "övervintras": "övervintra",
    "övervintrat": "övervintra",
    "övervintrats": "övervintra",
    "övervunna": "övervinna",
    "övervunnas": "övervinna",
    "övervunne": "övervinna",
    "övervunnen": "övervinna",
    "övervunnens": "övervinna",
    "övervunnes": "övervinna",
    "övervunnet": "övervinna",
    "övervunnets": "övervinna",
    "övervunnit": "övervinna",
    "övervunnits": "övervinna",
    "övervuxens": "övervuxen",
    "övervuxet": "övervuxen",
    "övervuxets": "övervuxen",
    "övervuxna": "övervuxen",
    "övervuxnare": "övervuxen",
    "övervuxnares": "övervuxen",
    "övervuxnas": "övervuxen",
    "övervuxnast": "övervuxen",
    "övervuxnaste": "övervuxen",
    "övervuxnastes": "övervuxen",
    "övervuxnasts": "övervuxen",
    "övervuxne": "övervuxen",
    "övervuxnes": "övervuxen",
    "överväg": "överväga",
    "övervägande": "överväga",
    "överväganden": "övervägande",
    "övervägandena": "övervägande",
    "övervägandenas": "övervägande",
    "övervägandens": "övervägande",
    "övervägandes": "övervägande",
    "övervägandet": "övervägande",
    "övervägandets": "övervägande",
    "övervägas": "överväga",
    "övervägd": "överväga",
    "övervägda": "överväga",
    "övervägdas": "överväga",
    "övervägde": "överväga",
    "övervägdes": "överväga",
    "övervägds": "överväga",
    "överväger": "överväga",
    "överväges": "överväga",
    "övervägs": "överväga",
    "övervägt": "överväga",
    "övervägts": "överväga",
    "överväldig": "överväldiga",
    "överväldigad": "överväldiga",
    "överväldigade": "överväldiga",
    "överväldigades": "överväldiga",
    "överväldigads": "överväldiga",
    "överväldigande": "överväldiga",
    "överväldiganden": "överväldigande",
    "överväldigandena": "överväldigande",
    "överväldigandenas": "överväldigande",
    "överväldigandens": "överväldigande",
    "överväldigandes": "överväldigande",
    "överväldigandet": "överväldigande",
    "överväldigandets": "överväldigande",
    "överväldigar": "överväldiga",
    "överväldigas": "överväldiga",
    "överväldigat": "överväldiga",
    "överväldigats": "överväldiga",
    "övervältrad": "övervältra",
    "övervältrade": "övervältra",
    "övervältrades": "övervältra",
    "övervältrads": "övervältra",
    "övervältrande": "övervältra",
    "övervältranden": "övervältrande",
    "övervältrandena": "övervältrande",
    "övervältrandenas": "övervältrande",
    "övervältrandens": "övervältrande",
    "övervältrandes": "övervältrande",
    "övervältrandet": "övervältrande",
    "övervältrandets": "övervältrande",
    "övervältrar": "övervältra",
    "övervältras": "övervältra",
    "övervältrat": "övervältra",
    "övervältrats": "övervältra",
    "övervärderad": "övervärdera",
    "övervärderade": "övervärdera",
    "övervärderades": "övervärdera",
    "övervärderads": "övervärdera",
    "övervärderande": "övervärdera",
    "övervärderanden": "övervärderande",
    "övervärderandena": "övervärderande",
    "övervärderandenas": "övervärderande",
    "övervärderandens": "övervärderande",
    "övervärderandes": "övervärderande",
    "övervärderandet": "övervärderande",
    "övervärderandets": "övervärderande",
    "övervärderar": "övervärdera",
    "övervärderas": "övervärdera",
    "övervärderat": "övervärdera",
    "övervärderats": "övervärdera",
    "övervärderbara": "övervärderbar",
    "övervärderbarare": "övervärderbar",
    "övervärderbarares": "övervärderbar",
    "övervärderbaras": "övervärderbar",
    "övervärderbarast": "övervärderbar",
    "övervärderbaraste": "övervärderbar",
    "övervärderbarastes": "övervärderbar",
    "övervärderbarasts": "övervärderbar",
    "övervärderbare": "övervärderbar",
    "övervärderbares": "övervärderbar",
    "övervärderbarheten": "övervärderbarhet",
    "övervärderbarhetens": "övervärderbarhet",
    "övervärderbarhets": "övervärderbarhet",
    "övervärderbars": "övervärderbar",
    "övervärderbart": "övervärderbar",
    "övervärderbarts": "övervärderbar",
    "övervärderingar": "övervärdering",
    "övervärderingarna": "övervärdering",
    "övervärderingarnas": "övervärdering",
    "övervärderingars": "övervärdering",
    "övervärderingen": "övervärdering",
    "övervärderingens": "övervärdering",
    "övervärderings": "övervärdering",
    "övervärmen": "övervärme",
    "övervärmens": "övervärme",
    "övervärmes": "övervärme",
    "överväxeln": "överväxel",
    "överväxelns": "överväxel",
    "överväxels": "överväxel",
    "överväxlar": "överväxel",
    "överväxlarna": "överväxel",
    "överväxlarnas": "överväxel",
    "överväxlars": "överväxel",
    "övervåldet": "övervåld",
    "övervåldets": "övervåld",
    "övervålds": "övervåld",
    "övervåningar": "övervåning",
    "övervåningarna": "övervåning",
    "övervåningarnas": "övervåning",
    "övervåningars": "övervåning",
    "övervåningen": "övervåning",
    "övervåningens": "övervåning",
    "övervånings": "övervåning",
    "överåriga": "överårig",
    "överårigare": "överårig",
    "överårigares": "överårig",
    "överårigas": "överårig",
    "överårigast": "överårig",
    "överårigaste": "överårig",
    "överårigastes": "överårig",
    "överårigasts": "överårig",
    "överårige": "överårig",
    "överåriges": "överårig",
    "överårigheten": "överårighet",
    "överårighetens": "överårighet",
    "överårighets": "överårighet",
    "överårigs": "överårig",
    "överårigt": "överårig",
    "överårigts": "överårig",
    "övliga": "övlig",
    "övligare": "övlig",
    "övligares": "övlig",
    "övligas": "övlig",
    "övligast": "övlig",
    "övligaste": "övlig",
    "övligastes": "övlig",
    "övligasts": "övlig",
    "övlige": "övlig",
    "övliges": "övlig",
    "övligheten": "övlighet",
    "övlighetens": "övlighet",
    "övlighets": "övlighet",
    "övligs": "övlig",
    "övligt": "övlig",
    "övligts": "övlig",
    "övningar": "övning",
    "övningarna": "övning",
    "övningarnas": "övning",
    "övningars": "övning",
    "övningen": "övning",
    "övningens": "övning",
    "övnings": "övning",
    "övningskör": "övningsköra",
    "övningskörande": "övningsköra",
    "övningskörandes": "övningsköra",
    "övningsköras": "övningsköra",
    "övningskörd": "övningsköra",
    "övningskörda": "övningsköra",
    "övningskördas": "övningsköra",
    "övningskörde": "övningsköra",
    "övningskördes": "övningsköra",
    "övningskörds": "övningsköra",
    "övningsköres": "övningsköra",
    "övningskörs": "övningsköra",
    "övningskört": "övningsköra",
    "övningskörts": "övningsköra",
    "övningslärar": "övningslärare",
    "övningsläraren": "övningslärare",
    "övningslärarens": "övningslärare",
    "övningslärares": "övningslärare",
    "övningslärarna": "övningslärare",
    "övningslärarnas": "övningslärare",
    "övningsskjutningar": "övningsskjutning",
    "övningsskjutningarna": "övningsskjutning",
    "övningsskjutningarnas": "övningsskjutning",
    "övningsskjutningars": "övningsskjutning",
    "övningsskjutningen": "övningsskjutning",
    "övningsskjutningens": "övningsskjutning",
    "övningsskjutnings": "övningsskjutning",
    "övningsämnen": "övningsämne",
    "övningsämnena": "övningsämne",
    "övningsämnenas": "övningsämne",
    "övningsämnens": "övningsämne",
    "övningsämnes": "övningsämne",
    "övningsämnet": "övningsämne",
    "övningsämnets": "övningsämne",
    "övres": "övre",
    "övriga": "övrig",
    "övrigas": "övrig",
    "övrigs": "övrig",
    "övrigt": "övrig",
    "övrigts": "övrig",
    "övärldar": "övärld",
    "övärldarna": "övärld",
    "övärldarnas": "övärld",
    "övärldars": "övärld",
    "övärlden": "övärld",
    "övärldens": "övärld",
    "övärlds": "övärld"
}
